import codecs
import struct
import array

class Codec(codecs.Codec):
	def encode(self,input,errors='strict'):
    	# 此 encode 流程修改自 https://gist.github.com/NEJmark/add42a5d812e2909c7aee24a42b23836
		# 字元表則更新至 uao250-u2b 多支援很多很多字 (羞
		encdoe_str = []
		for unichar in input:
			_ucode =  ord(unichar)
			if _ucode in encoding_map:
				_bcode = encoding_map[_ucode]
				encdoe_str.extend(struct.pack('>i',_bcode)[2:])
			else:
				# use big5hkscs
				# 支援範圍比較廣
				encdoe_str.extend(unichar.encode('big5hkscs', 'ignore'))
		return bytes(encdoe_str), len(encdoe_str)

	def decode(self,input,errors='strict'):
		unistr = ''
		ptr = 0
		
		input_len = len(input)
		
		while input_len > ptr:
			try :
				hex = input[ptr:ptr+2]
				mapkey = struct.unpack('!H', hex)[0]
				uni = chr(decoding_map[mapkey])
				unistr += uni
				ptr += 2
			except:
				hex = input[ptr:ptr+1]	
				val = struct.unpack('!B', hex)[0]
				uni = chr(val)
				unistr += uni
				ptr += 1
			
		return unistr, len(unistr)

class IncrementalEncoder(codecs.IncrementalEncoder):
	pass

class IncrementalDecoder(codecs.IncrementalDecoder):
	pass

class StreamWriter(Codec,codecs.StreamWriter):
	pass

class StreamReader(Codec,codecs.StreamReader):
	pass

	
def getregentry(codec_name):
	return codecs.CodecInfo(
		name='big5ext',
		encode=Codec().encode,
		decode=Codec().decode,
		incrementalencoder=IncrementalEncoder,
		incrementaldecoder=IncrementalDecoder,
		streamreader=StreamReader,
		streamwriter=StreamWriter,
	)

codecs.register(getregentry) 	

### Decoding Map

decoding_map = {
	0xFFFD: 0x0081,
	0xFFFD: 0x0082,
	0xFFFD: 0x0083,
	0xFFFD: 0x0084,
	0xFFFD: 0x0085,
	0xFFFD: 0x0086,
	0xFFFD: 0x0087,
	0xFFFD: 0x0088,
	0xFFFD: 0x0089,
	0xFFFD: 0x008A,
	0xFFFD: 0x008B,
	0xFFFD: 0x008C,
	0xFFFD: 0x008D,
	0xFFFD: 0x008E,
	0xFFFD: 0x008F,
	0xFFFD: 0x0090,
	0xFFFD: 0x0091,
	0xFFFD: 0x0092,
	0xFFFD: 0x0093,
	0xFFFD: 0x0094,
	0xFFFD: 0x0095,
	0xFFFD: 0x0096,
	0xFFFD: 0x0097,
	0xFFFD: 0x0098,
	0xFFFD: 0x0099,
	0xFFFD: 0x009A,
	0xFFFD: 0x009B,
	0xFFFD: 0x009C,
	0xFFFD: 0x009D,
	0xFFFD: 0x009E,
	0xFFFD: 0x009F,
	0xFFFD: 0x00A0,
	0xA0DF: 0x00A1,
	0xA246: 0x00A2,
	0xA247: 0x00A3,
	0xA0FC: 0x00A4,
	0xA244: 0x00A5,
	0x7C20: 0x00A6,
	0xA1B1: 0x00A7,
	0xC6D8: 0x00A8,
	0x6320: 0x00A9,
	0xA0DE: 0x00AA,
	0xFFFD: 0x00AB,
	0xFFFD: 0x00AC,
	0x2D20: 0x00AD,
	0x97FB: 0x00AE,
	0xA1C2: 0x00AF,
	0xA258: 0x00B0,
	0xA1D3: 0x00B1,
	0x3220: 0x00B2,
	0x3320: 0x00B3,
	0xA1AC: 0x00B4,
	0xA367: 0x00B5,
	0x91F8: 0x00B6,
	0xA150: 0x00B7,
	0xA0FB: 0x00B8,
	0x3120: 0x00B9,
	0xA0EE: 0x00BA,
	0xFFFD: 0x00BB,
	0xFEB3: 0x00BC,
	0xFEB0: 0x00BD,
	0xFEB4: 0x00BE,
	0xA0EF: 0x00BF,
	0xA0A7: 0x00C0,
	0xA0AC: 0x00C1,
	0xA0F6: 0x00C2,
	0xA0BE: 0x00C3,
	0xA0B6: 0x00C4,
	0xA0D6: 0x00C5,
	0xA0BB: 0x00C6,
	0xA0BC: 0x00C7,
	0xA0A8: 0x00C8,
	0xA0D7: 0x00C9,
	0xA0F7: 0x00CA,
	0xA0B7: 0x00CB,
	0xA0A9: 0x00CC,
	0xA0AD: 0x00CD,
	0xA0F8: 0x00CE,
	0xA0B8: 0x00CF,
	0xA0DA: 0x00D0,
	0xA0BD: 0x00D1,
	0xA0AA: 0x00D2,
	0xA0AE: 0x00D3,
	0xA0F9: 0x00D4,
	0xA0BF: 0x00D5,
	0xA0B9: 0x00D6,
	0xA1D1: 0x00D7,
	0xA0D9: 0x00D8,
	0xA0AB: 0x00D9,
	0xA0AF: 0x00DA,
	0xA0FA: 0x00DB,
	0xA0BA: 0x00DC,
	0x5920: 0x00DD,
	0xA0DC: 0x00DE,
	0xA0DD: 0x00DF,
	0xA0E0: 0x00E0,
	0xA0C0: 0x00E1,
	0xA0F0: 0x00E2,
	0xA0CE: 0x00E3,
	0xA0C6: 0x00E4,
	0xA0E6: 0x00E5,
	0xA0CB: 0x00E6,
	0xA0CC: 0x00E7,
	0xA0E1: 0x00E8,
	0xA0C1: 0x00E9,
	0xA0F1: 0x00EA,
	0xA0C7: 0x00EB,
	0xA0E2: 0x00EC,
	0xA0C2: 0x00ED,
	0xA0F2: 0x00EE,
	0xA0C8: 0x00EF,
	0xA0EA: 0x00F0,
	0xA0CD: 0x00F1,
	0xA0E3: 0x00F2,
	0xA0C3: 0x00F3,
	0xA0F3: 0x00F4,
	0xA0CF: 0x00F5,
	0xA0C9: 0x00F6,
	0xA1D2: 0x00F7,
	0xA0E9: 0x00F8,
	0xA0E4: 0x00F9,
	0xA0C4: 0x00FA,
	0xA0F4: 0x00FB,
	0xA0CA: 0x00FC,
	0x7920: 0x00FD,
	0xA0EC: 0x00FE,
	0xA0ED: 0x00FF,
	0xFFFD: 0x0100,
	0xA0B0: 0x0101,
	0xFFFD: 0x0102,
	0xFFFD: 0x0103,
	0xFFFD: 0x0104,
	0xFFFD: 0x0105,
	0xFFFD: 0x0106,
	0xFFFD: 0x0107,
	0xFFFD: 0x0108,
	0xFFFD: 0x0109,
	0xFFFD: 0x010A,
	0xFFFD: 0x010B,
	0xFFFD: 0x010C,
	0xFFFD: 0x010D,
	0xFFFD: 0x010E,
	0xFFFD: 0x010F,
	0xFFFD: 0x0110,
	0xFFFD: 0x0111,
	0xFFFD: 0x0112,
	0xA0B1: 0x0113,
	0xFFFD: 0x0114,
	0xFFFD: 0x0115,
	0xFFFD: 0x0116,
	0xFFFD: 0x0117,
	0xFFFD: 0x0118,
	0xFFFD: 0x0119,
	0xFFFD: 0x011A,
	0xA0D1: 0x011B,
	0xFFFD: 0x011C,
	0xFFFD: 0x011D,
	0xFFFD: 0x011E,
	0xFFFD: 0x011F,
	0xFFFD: 0x0120,
	0xFFFD: 0x0121,
	0xFFFD: 0x0122,
	0xFFFD: 0x0123,
	0xFFFD: 0x0124,
	0xFFFD: 0x0125,
	0xFFFD: 0x0126,
	0xFFFD: 0x0127,
	0xFFFD: 0x0128,
	0xFFFD: 0x0129,
	0xFFFD: 0x012A,
	0xA0B2: 0x012B,
	0xFFFD: 0x012C,
	0xFFFD: 0x012D,
	0xFFFD: 0x012E,
	0xFFFD: 0x012F,
	0xFFFD: 0x0130,
	0xFFFD: 0x0131,
	0xFFFD: 0x0132,
	0xFFFD: 0x0133,
	0xFFFD: 0x0134,
	0xFFFD: 0x0135,
	0xFFFD: 0x0136,
	0xFFFD: 0x0137,
	0xFFFD: 0x0138,
	0xFFFD: 0x0139,
	0xFFFD: 0x013A,
	0xFFFD: 0x013B,
	0xFFFD: 0x013C,
	0xFFFD: 0x013D,
	0xFFFD: 0x013E,
	0xFFFD: 0x013F,
	0xFFFD: 0x0140,
	0xFFFD: 0x0141,
	0xFFFD: 0x0142,
	0xFFFD: 0x0143,
	0xFFFD: 0x0144,
	0xFFFD: 0x0145,
	0xFFFD: 0x0146,
	0xFFFD: 0x0147,
	0xFFFD: 0x0148,
	0xFFFD: 0x0149,
	0x9BD5: 0x014A,
	0xFFFD: 0x014B,
	0xFFFD: 0x014C,
	0xA0B3: 0x014D,
	0xFFFD: 0x014E,
	0xFFFD: 0x014F,
	0xFFFD: 0x0150,
	0xFFFD: 0x0151,
	0xFFFD: 0x0152,
	0x9BE5: 0x0153,
	0xFFFD: 0x0154,
	0xFFFD: 0x0155,
	0xFFFD: 0x0156,
	0xFFFD: 0x0157,
	0xFFFD: 0x0158,
	0xFFFD: 0x0159,
	0xFFFD: 0x015A,
	0xFFFD: 0x015B,
	0xFFFD: 0x015C,
	0xFFFD: 0x015D,
	0xFFFD: 0x015E,
	0xFFFD: 0x015F,
	0xFFFD: 0x0160,
	0xFFFD: 0x0161,
	0xFFFD: 0x0162,
	0xFFFD: 0x0163,
	0xFFFD: 0x0164,
	0xFFFD: 0x0165,
	0xFFFD: 0x0166,
	0xFFFD: 0x0167,
	0xFFFD: 0x0168,
	0xFFFD: 0x0169,
	0xFFFD: 0x016A,
	0xA0B4: 0x016B,
	0xFFFD: 0x016C,
	0xFFFD: 0x016D,
	0xFFFD: 0x016E,
	0xFFFD: 0x016F,
	0xFFFD: 0x0170,
	0xFFFD: 0x0171,
	0xFFFD: 0x0172,
	0xFFFD: 0x0173,
	0xFFFD: 0x0174,
	0xFFFD: 0x0175,
	0xFFFD: 0x0176,
	0xFFFD: 0x0177,
	0xFFFD: 0x0178,
	0xFFFD: 0x0179,
	0xFFFD: 0x017A,
	0xFFFD: 0x017B,
	0xFFFD: 0x017C,
	0xFFFD: 0x017D,
	0xFFFD: 0x017E,
	0xFFFD: 0x017F,
	0xFFFD: 0x0180,
	0xFFFD: 0x0181,
	0xFFFD: 0x0182,
	0xFFFD: 0x0183,
	0xFFFD: 0x0184,
	0xFFFD: 0x0185,
	0xFFFD: 0x0186,
	0xFFFD: 0x0187,
	0xFFFD: 0x0188,
	0xFFFD: 0x0189,
	0xFFFD: 0x018A,
	0xFFFD: 0x018B,
	0xFFFD: 0x018C,
	0xFFFD: 0x018D,
	0xFFFD: 0x018E,
	0xFFFD: 0x018F,
	0xFFFD: 0x0190,
	0xFFFD: 0x0191,
	0xA0FE: 0x0192,
	0xFFFD: 0x0193,
	0xFFFD: 0x0194,
	0xFFFD: 0x0195,
	0xFFFD: 0x0196,
	0xFFFD: 0x0197,
	0xFFFD: 0x0198,
	0xFFFD: 0x0199,
	0xFFFD: 0x019A,
	0xFFFD: 0x019B,
	0xFFFD: 0x019C,
	0xFFFD: 0x019D,
	0xFFFD: 0x019E,
	0xFFFD: 0x019F,
	0xFFFD: 0x01A0,
	0xFFFD: 0x01A1,
	0xFFFD: 0x01A2,
	0xFFFD: 0x01A3,
	0xFFFD: 0x01A4,
	0xFFFD: 0x01A5,
	0xFFFD: 0x01A6,
	0xFFFD: 0x01A7,
	0xFFFD: 0x01A8,
	0xFFFD: 0x01A9,
	0xFFFD: 0x01AA,
	0xFFFD: 0x01AB,
	0xFFFD: 0x01AC,
	0xFFFD: 0x01AD,
	0xFFFD: 0x01AE,
	0xFFFD: 0x01AF,
	0xFFFD: 0x01B0,
	0xFFFD: 0x01B1,
	0xFFFD: 0x01B2,
	0xFFFD: 0x01B3,
	0xFFFD: 0x01B4,
	0xFFFD: 0x01B5,
	0xFFFD: 0x01B6,
	0xFFFD: 0x01B7,
	0xFFFD: 0x01B8,
	0xFFFD: 0x01B9,
	0xFFFD: 0x01BA,
	0xFFFD: 0x01BB,
	0xFFFD: 0x01BC,
	0xFFFD: 0x01BD,
	0xFFFD: 0x01BE,
	0xFFFD: 0x01BF,
	0xFFFD: 0x01C0,
	0xFFFD: 0x01C1,
	0xFFFD: 0x01C2,
	0xFFFD: 0x01C3,
	0xFFFD: 0x01C4,
	0xFFFD: 0x01C5,
	0xFFFD: 0x01C6,
	0xFFFD: 0x01C7,
	0xFFFD: 0x01C8,
	0xFFFD: 0x01C9,
	0xFFFD: 0x01CA,
	0xFFFD: 0x01CB,
	0xFFFD: 0x01CC,
	0xFFFD: 0x01CD,
	0xA0D0: 0x01CE,
	0xFFFD: 0x01CF,
	0xA0D2: 0x01D0,
	0xFFFD: 0x01D1,
	0xA0D3: 0x01D2,
	0xFFFD: 0x01D3,
	0xA0D4: 0x01D4,
	0xFFFD: 0x01D5,
	0xA0B5: 0x01D6,
	0xFFFD: 0x01D7,
	0xA0C5: 0x01D8,
	0xFFFD: 0x01D9,
	0xA0D5: 0x01DA,
	0xFFFD: 0x01DB,
	0xA0E5: 0x01DC,
	0xFFFD: 0x01DD,
	0xFFFD: 0x01DE,
	0xFFFD: 0x01DF,
	0xFFFD: 0x01E0,
	0xFFFD: 0x01E1,
	0xFFFD: 0x01E2,
	0xFFFD: 0x01E3,
	0xFFFD: 0x01E4,
	0xFFFD: 0x01E5,
	0xFFFD: 0x01E6,
	0xFFFD: 0x01E7,
	0xFFFD: 0x01E8,
	0xFFFD: 0x01E9,
	0xFFFD: 0x01EA,
	0xFFFD: 0x01EB,
	0xFFFD: 0x01EC,
	0xFFFD: 0x01ED,
	0xFFFD: 0x01EE,
	0xFFFD: 0x01EF,
	0xFFFD: 0x01F0,
	0xFFFD: 0x01F1,
	0xFFFD: 0x01F2,
	0xFFFD: 0x01F3,
	0xFFFD: 0x01F4,
	0xFFFD: 0x01F5,
	0xFFFD: 0x01F6,
	0xFFFD: 0x01F7,
	0xFFFD: 0x01F8,
	0xFFFD: 0x01F9,
	0xFFFD: 0x01FA,
	0xFFFD: 0x01FB,
	0xFFFD: 0x01FC,
	0xFFFD: 0x01FD,
	0xFFFD: 0x01FE,
	0xFFFD: 0x01FF,
	0xFFFD: 0x0200,
	0xFFFD: 0x0201,
	0xFFFD: 0x0202,
	0xFFFD: 0x0203,
	0xFFFD: 0x0204,
	0xFFFD: 0x0205,
	0xFFFD: 0x0206,
	0xFFFD: 0x0207,
	0xFFFD: 0x0208,
	0xFFFD: 0x0209,
	0xFFFD: 0x020A,
	0xFFFD: 0x020B,
	0xFFFD: 0x020C,
	0xFFFD: 0x020D,
	0xFFFD: 0x020E,
	0xFFFD: 0x020F,
	0xFFFD: 0x0210,
	0xFFFD: 0x0211,
	0xFFFD: 0x0212,
	0xFFFD: 0x0213,
	0xFFFD: 0x0214,
	0xFFFD: 0x0215,
	0xFFFD: 0x0216,
	0xFFFD: 0x0217,
	0xFFFD: 0x0218,
	0xFFFD: 0x0219,
	0xFFFD: 0x021A,
	0xFFFD: 0x021B,
	0xFFFD: 0x021C,
	0xFFFD: 0x021D,
	0xFFFD: 0x021E,
	0xFFFD: 0x021F,
	0xFFFD: 0x0220,
	0xFFFD: 0x0221,
	0xFFFD: 0x0222,
	0xFFFD: 0x0223,
	0xFFFD: 0x0224,
	0xFFFD: 0x0225,
	0xFFFD: 0x0226,
	0xFFFD: 0x0227,
	0xFFFD: 0x0228,
	0xFFFD: 0x0229,
	0xFFFD: 0x022A,
	0xFFFD: 0x022B,
	0xFFFD: 0x022C,
	0xFFFD: 0x022D,
	0xFFFD: 0x022E,
	0xFFFD: 0x022F,
	0xFFFD: 0x0230,
	0xFFFD: 0x0231,
	0xFFFD: 0x0232,
	0xFFFD: 0x0233,
	0xFFFD: 0x0234,
	0xFFFD: 0x0235,
	0xFFFD: 0x0236,
	0xFFFD: 0x0237,
	0xFFFD: 0x0238,
	0xFFFD: 0x0239,
	0xFFFD: 0x023A,
	0xFFFD: 0x023B,
	0xFFFD: 0x023C,
	0xFFFD: 0x023D,
	0xFFFD: 0x023E,
	0xFFFD: 0x023F,
	0xFFFD: 0x0240,
	0xFFFD: 0x0241,
	0xFFFD: 0x0242,
	0xFFFD: 0x0243,
	0xFFFD: 0x0244,
	0xFFFD: 0x0245,
	0xFFFD: 0x0246,
	0xFFFD: 0x0247,
	0xFFFD: 0x0248,
	0xFFFD: 0x0249,
	0xFFFD: 0x024A,
	0xFFFD: 0x024B,
	0xFFFD: 0x024C,
	0xFFFD: 0x024D,
	0xFFFD: 0x024E,
	0xFFFD: 0x024F,
	0xFFFD: 0x0250,
	0x9BCB: 0x0251,
	0x9BE6: 0x0252,
	0xFFFD: 0x0253,
	0x9BCC: 0x0254,
	0xFFFD: 0x0255,
	0xFFFD: 0x0256,
	0xFFFD: 0x0257,
	0xFFFD: 0x0258,
	0x9BCF: 0x0259,
	0x9BD0: 0x025A,
	0x9BC8: 0x025B,
	0x9BD1: 0x025C,
	0x9BCE: 0x025D,
	0xFFFD: 0x025E,
	0xFFFD: 0x025F,
	0xFFFD: 0x0260,
	0x9BD2: 0x0261,
	0xFFFD: 0x0262,
	0xFFFD: 0x0263,
	0xFFFD: 0x0264,
	0xFFFD: 0x0265,
	0xFFFD: 0x0266,
	0xFFFD: 0x0267,
	0xFFFD: 0x0268,
	0xFFFD: 0x0269,
	0x9BC7: 0x026A,
	0xFFFD: 0x026B,
	0xFFFD: 0x026C,
	0xFFFD: 0x026D,
	0xFFFD: 0x026E,
	0x9BE0: 0x026F,
	0xFFFD: 0x0270,
	0xFFFD: 0x0271,
	0xFFFD: 0x0272,
	0xFFFD: 0x0273,
	0xFFFD: 0x0274,
	0x9BD7: 0x0275,
	0xFFFD: 0x0276,
	0xFFFD: 0x0277,
	0x9BE1: 0x0278,
	0xFFFD: 0x0279,
	0xFFFD: 0x027A,
	0xFFFD: 0x027B,
	0xFFFD: 0x027C,
	0xFFFD: 0x027D,
	0xFFFD: 0x027E,
	0xFFFD: 0x027F,
	0xFFFD: 0x0280,
	0xFFFD: 0x0281,
	0xFFFD: 0x0282,
	0x9BD9: 0x0283,
	0xFFFD: 0x0284,
	0xFFFD: 0x0285,
	0xFFFD: 0x0286,
	0x9BE2: 0x0287,
	0xFFFD: 0x0288,
	0xFFFD: 0x0289,
	0x9BCD: 0x028A,
	0xFFFD: 0x028B,
	0x9BCA: 0x028C,
	0xFFFD: 0x028D,
	0xFFFD: 0x028E,
	0xFFFD: 0x028F,
	0xFFFD: 0x0290,
	0xFFFD: 0x0291,
	0x9BDA: 0x0292,
	0xFFFD: 0x0293,
	0xFFFD: 0x0294,
	0xFFFD: 0x0295,
	0xFFFD: 0x0296,
	0xFFFD: 0x0297,
	0xFFFD: 0x0298,
	0xFFFD: 0x0299,
	0xFFFD: 0x029A,
	0xFFFD: 0x029B,
	0xFFFD: 0x029C,
	0xFFFD: 0x029D,
	0xFFFD: 0x029E,
	0xFFFD: 0x029F,
	0xFFFD: 0x02A0,
	0xFFFD: 0x02A1,
	0xFFFD: 0x02A2,
	0xFFFD: 0x02A3,
	0x9BDC: 0x02A4,
	0xFFFD: 0x02A5,
	0xFFFD: 0x02A6,
	0x9BDB: 0x02A7,
	0xFFFD: 0x02A8,
	0xFFFD: 0x02A9,
	0xFFFD: 0x02AA,
	0xFFFD: 0x02AB,
	0xFFFD: 0x02AC,
	0xFFFD: 0x02AD,
	0xFFFD: 0x02AE,
	0xFFFD: 0x02AF,
	0xFFFD: 0x02B0,
	0xFFFD: 0x02B1,
	0xFFFD: 0x02B2,
	0xFFFD: 0x02B3,
	0xFFFD: 0x02B4,
	0xFFFD: 0x02B5,
	0xFFFD: 0x02B6,
	0xFFFD: 0x02B7,
	0xFFFD: 0x02B8,
	0xFFFD: 0x02B9,
	0xFFFD: 0x02BA,
	0xFFFD: 0x02BB,
	0xFFFD: 0x02BC,
	0xFFFD: 0x02BD,
	0xFFFD: 0x02BE,
	0xFFFD: 0x02BF,
	0xFFFD: 0x02C0,
	0xFFFD: 0x02C1,
	0xFFFD: 0x02C2,
	0xFFFD: 0x02C3,
	0xFFFD: 0x02C4,
	0xFFFD: 0x02C5,
	0xC6D9: 0x02C6,
	0xA3BE: 0x02C7,
	0xFFFD: 0x02C8,
	0xA3BC: 0x02C9,
	0xA3BD: 0x02CA,
	0xA3BF: 0x02CB,
	0xFFFD: 0x02CC,
	0xA1C5: 0x02CD,
	0xFFFD: 0x02CE,
	0x9BE9: 0x02CF,
	0xFFFD: 0x02D0,
	0xFFFD: 0x02D1,
	0xFFFD: 0x02D2,
	0xFFFD: 0x02D3,
	0xFFFD: 0x02D4,
	0xFFFD: 0x02D5,
	0xFFFD: 0x02D6,
	0xFFFD: 0x02D7,
	0xFFFD: 0x02D8,
	0xA3BB: 0x02D9,
	0xFFFD: 0x02DA,
	0xFFFD: 0x02DB,
	0xFFFD: 0x02DC,
	0xFFFD: 0x02DD,
	0xFFFD: 0x02DE,
	0xFFFD: 0x02DF,
	0xFFFD: 0x02E0,
	0xFFFD: 0x02E1,
	0xFFFD: 0x02E2,
	0xFFFD: 0x02E3,
	0xFFFD: 0x02E4,
	0xFFFD: 0x02E5,
	0xFFFD: 0x02E6,
	0xFFFD: 0x02E7,
	0xFFFD: 0x02E8,
	0xFFFD: 0x02E9,
	0xFFFD: 0x02EA,
	0xFFFD: 0x02EB,
	0xFFFD: 0x02EC,
	0xFFFD: 0x02ED,
	0xFFFD: 0x02EE,
	0xFFFD: 0x02EF,
	0xFFFD: 0x02F0,
	0xFFFD: 0x02F1,
	0xFFFD: 0x02F2,
	0xFFFD: 0x02F3,
	0xFFFD: 0x02F4,
	0xFFFD: 0x02F5,
	0xFFFD: 0x02F6,
	0xFFFD: 0x02F7,
	0xFFFD: 0x02F8,
	0xFFFD: 0x02F9,
	0xFFFD: 0x02FA,
	0xFFFD: 0x02FB,
	0xFFFD: 0x02FC,
	0xFFFD: 0x02FD,
	0xFFFD: 0x02FE,
	0xFFFD: 0x02FF,
	0xFFFD: 0x0300,
	0xFFFD: 0x0301,
	0xFFFD: 0x0302,
	0xFFFD: 0x0303,
	0xFFFD: 0x0304,
	0xFFFD: 0x0305,
	0xFFFD: 0x0306,
	0xFFFD: 0x0307,
	0xFFFD: 0x0308,
	0xFFFD: 0x0309,
	0xFFFD: 0x030A,
	0xFFFD: 0x030B,
	0xFFFD: 0x030C,
	0xFFFD: 0x030D,
	0xFFFD: 0x030E,
	0xFFFD: 0x030F,
	0xFFFD: 0x0310,
	0xFFFD: 0x0311,
	0xFFFD: 0x0312,
	0xFFFD: 0x0313,
	0xFFFD: 0x0314,
	0xFFFD: 0x0315,
	0xFFFD: 0x0316,
	0xFFFD: 0x0317,
	0xFFFD: 0x0318,
	0xFFFD: 0x0319,
	0xFFFD: 0x031A,
	0xFFFD: 0x031B,
	0xFFFD: 0x031C,
	0xFFFD: 0x031D,
	0xFFFD: 0x031E,
	0xFFFD: 0x031F,
	0xFFFD: 0x0320,
	0xFFFD: 0x0321,
	0xFFFD: 0x0322,
	0xFFFD: 0x0323,
	0xFFFD: 0x0324,
	0xFFFD: 0x0325,
	0xFFFD: 0x0326,
	0xFFFD: 0x0327,
	0xFFFD: 0x0328,
	0xFFFD: 0x0329,
	0xFFFD: 0x032A,
	0xFFFD: 0x032B,
	0xFFFD: 0x032C,
	0xFFFD: 0x032D,
	0xFFFD: 0x032E,
	0xFFFD: 0x032F,
	0xFFFD: 0x0330,
	0xFFFD: 0x0331,
	0xFFFD: 0x0332,
	0xFFFD: 0x0333,
	0xFFFD: 0x0334,
	0xFFFD: 0x0335,
	0xFFFD: 0x0336,
	0xFFFD: 0x0337,
	0xFFFD: 0x0338,
	0xFFFD: 0x0339,
	0xFFFD: 0x033A,
	0xFFFD: 0x033B,
	0xFFFD: 0x033C,
	0xFFFD: 0x033D,
	0xFFFD: 0x033E,
	0xFFFD: 0x033F,
	0xFFFD: 0x0340,
	0xFFFD: 0x0341,
	0xFFFD: 0x0342,
	0xFFFD: 0x0343,
	0xFFFD: 0x0344,
	0xFFFD: 0x0345,
	0xFFFD: 0x0346,
	0xFFFD: 0x0347,
	0xFFFD: 0x0348,
	0xFFFD: 0x0349,
	0xFFFD: 0x034A,
	0xFFFD: 0x034B,
	0xFFFD: 0x034C,
	0xFFFD: 0x034D,
	0xFFFD: 0x034E,
	0xFFFD: 0x034F,
	0xFFFD: 0x0350,
	0xFFFD: 0x0351,
	0xFFFD: 0x0352,
	0xFFFD: 0x0353,
	0xFFFD: 0x0354,
	0xFFFD: 0x0355,
	0xFFFD: 0x0356,
	0xFFFD: 0x0357,
	0xFFFD: 0x0358,
	0xFFFD: 0x0359,
	0xFFFD: 0x035A,
	0xFFFD: 0x035B,
	0xFFFD: 0x035C,
	0xFFFD: 0x035D,
	0xFFFD: 0x035E,
	0xFFFD: 0x035F,
	0xFFFD: 0x0360,
	0xFFFD: 0x0361,
	0xFFFD: 0x0362,
	0xFFFD: 0x0363,
	0xFFFD: 0x0364,
	0xFFFD: 0x0365,
	0xFFFD: 0x0366,
	0xFFFD: 0x0367,
	0xFFFD: 0x0368,
	0xFFFD: 0x0369,
	0xFFFD: 0x036A,
	0xFFFD: 0x036B,
	0xFFFD: 0x036C,
	0xFFFD: 0x036D,
	0xFFFD: 0x036E,
	0xFFFD: 0x036F,
	0xFFFD: 0x0370,
	0xFFFD: 0x0371,
	0xFFFD: 0x0372,
	0xFFFD: 0x0373,
	0xFFFD: 0x0374,
	0xFFFD: 0x0375,
	0xFFFD: 0x0376,
	0xFFFD: 0x0377,
	0xFFFD: 0x0378,
	0xFFFD: 0x0379,
	0xFFFD: 0x037A,
	0xFFFD: 0x037B,
	0xFFFD: 0x037C,
	0xFFFD: 0x037D,
	0xFFFD: 0x037E,
	0xFFFD: 0x037F,
	0xFFFD: 0x0380,
	0xFFFD: 0x0381,
	0xFFFD: 0x0382,
	0xFFFD: 0x0383,
	0xFFFD: 0x0384,
	0xFFFD: 0x0385,
	0xFFFD: 0x0386,
	0xFFFD: 0x0387,
	0xFFFD: 0x0388,
	0xFFFD: 0x0389,
	0xFFFD: 0x038A,
	0xFFFD: 0x038B,
	0xFFFD: 0x038C,
	0xFFFD: 0x038D,
	0xFFFD: 0x038E,
	0xFFFD: 0x038F,
	0xFFFD: 0x0390,
	0xA344: 0x0391,
	0xA345: 0x0392,
	0xA346: 0x0393,
	0xA347: 0x0394,
	0xA348: 0x0395,
	0xA349: 0x0396,
	0xA34A: 0x0397,
	0xA34B: 0x0398,
	0xA34C: 0x0399,
	0xA34D: 0x039A,
	0xA34E: 0x039B,
	0xA34F: 0x039C,
	0xA350: 0x039D,
	0xA351: 0x039E,
	0xA352: 0x039F,
	0xA353: 0x03A0,
	0xA354: 0x03A1,
	0xFFFD: 0x03A2,
	0xA355: 0x03A3,
	0xA356: 0x03A4,
	0xA357: 0x03A5,
	0xA358: 0x03A6,
	0xA359: 0x03A7,
	0xA35A: 0x03A8,
	0xA35B: 0x03A9,
	0xFFFD: 0x03AA,
	0xFFFD: 0x03AB,
	0xFFFD: 0x03AC,
	0xFFFD: 0x03AD,
	0xFFFD: 0x03AE,
	0xFFFD: 0x03AF,
	0xFFFD: 0x03B0,
	0xA35C: 0x03B1,
	0xA35D: 0x03B2,
	0xA35E: 0x03B3,
	0xA35F: 0x03B4,
	0xA360: 0x03B5,
	0xA361: 0x03B6,
	0xA362: 0x03B7,
	0xA363: 0x03B8,
	0xA364: 0x03B9,
	0xA365: 0x03BA,
	0xA366: 0x03BB,
	0xA367: 0x03BC,
	0xA368: 0x03BD,
	0xA369: 0x03BE,
	0xA36A: 0x03BF,
	0xA36B: 0x03C0,
	0xA36C: 0x03C1,
	0xFFFD: 0x03C2,
	0xA36D: 0x03C3,
	0xA36E: 0x03C4,
	0xA36F: 0x03C5,
	0xA370: 0x03C6,
	0xA371: 0x03C7,
	0xA372: 0x03C8,
	0xA373: 0x03C9,
	0xFFFD: 0x03CA,
	0xFFFD: 0x03CB,
	0xFFFD: 0x03CC,
	0xFFFD: 0x03CD,
	0xFFFD: 0x03CE,
	0xFFFD: 0x03CF,
	0xFFFD: 0x03D0,
	0xFFFD: 0x03D1,
	0xFFFD: 0x03D2,
	0xFFFD: 0x03D3,
	0xFFFD: 0x03D4,
	0xFFFD: 0x03D5,
	0xFFFD: 0x03D6,
	0xFFFD: 0x03D7,
	0xFFFD: 0x03D8,
	0xFFFD: 0x03D9,
	0xFFFD: 0x03DA,
	0xFFFD: 0x03DB,
	0xFFFD: 0x03DC,
	0xFFFD: 0x03DD,
	0xFFFD: 0x03DE,
	0xFFFD: 0x03DF,
	0xFFFD: 0x03E0,
	0xFFFD: 0x03E1,
	0xFFFD: 0x03E2,
	0xFFFD: 0x03E3,
	0xFFFD: 0x03E4,
	0xFFFD: 0x03E5,
	0xFFFD: 0x03E6,
	0xFFFD: 0x03E7,
	0xFFFD: 0x03E8,
	0xFFFD: 0x03E9,
	0xFFFD: 0x03EA,
	0xFFFD: 0x03EB,
	0xFFFD: 0x03EC,
	0xFFFD: 0x03ED,
	0xFFFD: 0x03EE,
	0xFFFD: 0x03EF,
	0xFFFD: 0x03F0,
	0xFFFD: 0x03F1,
	0xFFFD: 0x03F2,
	0xFFFD: 0x03F3,
	0xFFFD: 0x03F4,
	0xFFFD: 0x03F5,
	0xFFFD: 0x03F6,
	0xFFFD: 0x03F7,
	0xFFFD: 0x03F8,
	0xFFFD: 0x03F9,
	0xFFFD: 0x03FA,
	0xFFFD: 0x03FB,
	0xFFFD: 0x03FC,
	0xFFFD: 0x03FD,
	0xFFFD: 0x03FE,
	0xFFFD: 0x03FF,
	0xFFFD: 0x0400,
	0xC7F9: 0x0401,
	0xFFFD: 0x0402,
	0xFFFD: 0x0403,
	0xFFFD: 0x0404,
	0xFFFD: 0x0405,
	0xFFFD: 0x0406,
	0xFFFD: 0x0407,
	0xFFFD: 0x0408,
	0xFFFD: 0x0409,
	0xFFFD: 0x040A,
	0xFFFD: 0x040B,
	0xFFFD: 0x040C,
	0xFFFD: 0x040D,
	0xFFFD: 0x040E,
	0xFFFD: 0x040F,
	0xC7F3: 0x0410,
	0xC7F4: 0x0411,
	0xC7F5: 0x0412,
	0xC7F6: 0x0413,
	0xC7F7: 0x0414,
	0xC7F8: 0x0415,
	0xC7FA: 0x0416,
	0xC7FB: 0x0417,
	0xC7FC: 0x0418,
	0xC7FD: 0x0419,
	0xC7FE: 0x041A,
	0xC840: 0x041B,
	0xC841: 0x041C,
	0xC842: 0x041D,
	0xC843: 0x041E,
	0xC844: 0x041F,
	0xC845: 0x0420,
	0xC846: 0x0421,
	0xC847: 0x0422,
	0xC848: 0x0423,
	0xC849: 0x0424,
	0xC84A: 0x0425,
	0xC84B: 0x0426,
	0xC84C: 0x0427,
	0xC84D: 0x0428,
	0xC84E: 0x0429,
	0xC84F: 0x042A,
	0xC850: 0x042B,
	0xC851: 0x042C,
	0xC852: 0x042D,
	0xC853: 0x042E,
	0xC854: 0x042F,
	0xC855: 0x0430,
	0xC856: 0x0431,
	0xC857: 0x0432,
	0xC858: 0x0433,
	0xC859: 0x0434,
	0xC85A: 0x0435,
	0xC85C: 0x0436,
	0xC85D: 0x0437,
	0xC85E: 0x0438,
	0xC85F: 0x0439,
	0xC860: 0x043A,
	0xC861: 0x043B,
	0xC862: 0x043C,
	0xC863: 0x043D,
	0xC864: 0x043E,
	0xC865: 0x043F,
	0xC866: 0x0440,
	0xC867: 0x0441,
	0xC868: 0x0442,
	0xC869: 0x0443,
	0xC86A: 0x0444,
	0xC86B: 0x0445,
	0xC86C: 0x0446,
	0xC86D: 0x0447,
	0xC86E: 0x0448,
	0xC86F: 0x0449,
	0xC870: 0x044A,
	0xC871: 0x044B,
	0xC872: 0x044C,
	0xC873: 0x044D,
	0xC874: 0x044E,
	0xC875: 0x044F,
	0xFFFD: 0x0450,
	0xC85B: 0x0451,
	0xFFFD: 0x0452,
	0xFFFD: 0x0453,
	0xFFFD: 0x0454,
	0xFFFD: 0x0455,
	0xFFFD: 0x0456,
	0xFFFD: 0x0457,
	0xFFFD: 0x0458,
	0xFFFD: 0x0459,
	0xFFFD: 0x045A,
	0xFFFD: 0x045B,
	0xFFFD: 0x045C,
	0xFFFD: 0x045D,
	0xFFFD: 0x045E,
	0xFFFD: 0x045F,
	0xFFFD: 0x0460,
	0xFFFD: 0x0461,
	0xFFFD: 0x0462,
	0xFFFD: 0x0463,
	0xFFFD: 0x0464,
	0xFFFD: 0x0465,
	0xFFFD: 0x0466,
	0xFFFD: 0x0467,
	0xFFFD: 0x0468,
	0xFFFD: 0x0469,
	0xFFFD: 0x046A,
	0xFFFD: 0x046B,
	0xFFFD: 0x046C,
	0xFFFD: 0x046D,
	0xFFFD: 0x046E,
	0xFFFD: 0x046F,
	0xFFFD: 0x0470,
	0xFFFD: 0x0471,
	0xFFFD: 0x0472,
	0xFFFD: 0x0473,
	0xFFFD: 0x0474,
	0xFFFD: 0x0475,
	0xFFFD: 0x0476,
	0xFFFD: 0x0477,
	0xFFFD: 0x0478,
	0xFFFD: 0x0479,
	0xFFFD: 0x047A,
	0xFFFD: 0x047B,
	0xFFFD: 0x047C,
	0xFFFD: 0x047D,
	0xFFFD: 0x047E,
	0xFFFD: 0x047F,
	0xFFFD: 0x0480,
	0xFFFD: 0x0481,
	0xFFFD: 0x0482,
	0xFFFD: 0x0483,
	0xFFFD: 0x0484,
	0xFFFD: 0x0485,
	0xFFFD: 0x0486,
	0xFFFD: 0x0487,
	0xFFFD: 0x0488,
	0xFFFD: 0x0489,
	0xFFFD: 0x048A,
	0xFFFD: 0x048B,
	0xFFFD: 0x048C,
	0xFFFD: 0x048D,
	0xFFFD: 0x048E,
	0xFFFD: 0x048F,
	0xFFFD: 0x0490,
	0xFFFD: 0x0491,
	0xFFFD: 0x0492,
	0xFFFD: 0x0493,
	0xFFFD: 0x0494,
	0xFFFD: 0x0495,
	0xFFFD: 0x0496,
	0xFFFD: 0x0497,
	0xFFFD: 0x0498,
	0xFFFD: 0x0499,
	0xFFFD: 0x049A,
	0xFFFD: 0x049B,
	0xFFFD: 0x049C,
	0xFFFD: 0x049D,
	0xFFFD: 0x049E,
	0xFFFD: 0x049F,
	0xFFFD: 0x04A0,
	0xFFFD: 0x04A1,
	0xFFFD: 0x04A2,
	0xFFFD: 0x04A3,
	0xFFFD: 0x04A4,
	0xFFFD: 0x04A5,
	0xFFFD: 0x04A6,
	0xFFFD: 0x04A7,
	0xFFFD: 0x04A8,
	0xFFFD: 0x04A9,
	0xFFFD: 0x04AA,
	0xFFFD: 0x04AB,
	0xFFFD: 0x04AC,
	0xFFFD: 0x04AD,
	0xFFFD: 0x04AE,
	0xFFFD: 0x04AF,
	0xFFFD: 0x04B0,
	0xFFFD: 0x04B1,
	0xFFFD: 0x04B2,
	0xFFFD: 0x04B3,
	0xFFFD: 0x04B4,
	0xFFFD: 0x04B5,
	0xFFFD: 0x04B6,
	0xFFFD: 0x04B7,
	0xFFFD: 0x04B8,
	0xFFFD: 0x04B9,
	0xFFFD: 0x04BA,
	0xFFFD: 0x04BB,
	0xFFFD: 0x04BC,
	0xFFFD: 0x04BD,
	0xFFFD: 0x04BE,
	0xFFFD: 0x04BF,
	0xFFFD: 0x04C0,
	0xFFFD: 0x04C1,
	0xFFFD: 0x04C2,
	0xFFFD: 0x04C3,
	0xFFFD: 0x04C4,
	0xFFFD: 0x04C5,
	0xFFFD: 0x04C6,
	0xFFFD: 0x04C7,
	0xFFFD: 0x04C8,
	0xFFFD: 0x04C9,
	0xFFFD: 0x04CA,
	0xFFFD: 0x04CB,
	0xFFFD: 0x04CC,
	0xFFFD: 0x04CD,
	0xFFFD: 0x04CE,
	0xFFFD: 0x04CF,
	0xFFFD: 0x04D0,
	0xFFFD: 0x04D1,
	0xFFFD: 0x04D2,
	0xFFFD: 0x04D3,
	0xFFFD: 0x04D4,
	0xFFFD: 0x04D5,
	0xFFFD: 0x04D6,
	0xFFFD: 0x04D7,
	0xFFFD: 0x04D8,
	0xFFFD: 0x04D9,
	0xFFFD: 0x04DA,
	0xFFFD: 0x04DB,
	0xFFFD: 0x04DC,
	0xFFFD: 0x04DD,
	0xFFFD: 0x04DE,
	0xFFFD: 0x04DF,
	0xFFFD: 0x04E0,
	0xFFFD: 0x04E1,
	0xFFFD: 0x04E2,
	0xFFFD: 0x04E3,
	0xFFFD: 0x04E4,
	0xFFFD: 0x04E5,
	0xFFFD: 0x04E6,
	0xFFFD: 0x04E7,
	0xFFFD: 0x04E8,
	0xFFFD: 0x04E9,
	0xFFFD: 0x04EA,
	0xFFFD: 0x04EB,
	0xFFFD: 0x04EC,
	0xFFFD: 0x04ED,
	0xFFFD: 0x04EE,
	0xFFFD: 0x04EF,
	0xFFFD: 0x04F0,
	0xFFFD: 0x04F1,
	0xFFFD: 0x04F2,
	0xFFFD: 0x04F3,
	0xFFFD: 0x04F4,
	0xFFFD: 0x04F5,
	0xFFFD: 0x04F6,
	0xFFFD: 0x04F7,
	0xFFFD: 0x04F8,
	0xFFFD: 0x04F9,
	0xFFFD: 0x04FA,
	0xFFFD: 0x04FB,
	0xFFFD: 0x04FC,
	0xFFFD: 0x04FD,
	0xFFFD: 0x04FE,
	0xFFFD: 0x04FF,
	0xFFFD: 0x0500,
	0xFFFD: 0x0501,
	0xFFFD: 0x0502,
	0xFFFD: 0x0503,
	0xFFFD: 0x0504,
	0xFFFD: 0x0505,
	0xFFFD: 0x0506,
	0xFFFD: 0x0507,
	0xFFFD: 0x0508,
	0xFFFD: 0x0509,
	0xFFFD: 0x050A,
	0xFFFD: 0x050B,
	0xFFFD: 0x050C,
	0xFFFD: 0x050D,
	0xFFFD: 0x050E,
	0xFFFD: 0x050F,
	0xFFFD: 0x0510,
	0xFFFD: 0x0511,
	0xFFFD: 0x0512,
	0xFFFD: 0x0513,
	0xFFFD: 0x0514,
	0xFFFD: 0x0515,
	0xFFFD: 0x0516,
	0xFFFD: 0x0517,
	0xFFFD: 0x0518,
	0xFFFD: 0x0519,
	0xFFFD: 0x051A,
	0xFFFD: 0x051B,
	0xFFFD: 0x051C,
	0xFFFD: 0x051D,
	0xFFFD: 0x051E,
	0xFFFD: 0x051F,
	0xFFFD: 0x0520,
	0xFFFD: 0x0521,
	0xFFFD: 0x0522,
	0xFFFD: 0x0523,
	0xFFFD: 0x0524,
	0xFFFD: 0x0525,
	0xFFFD: 0x0526,
	0xFFFD: 0x0527,
	0xFFFD: 0x0528,
	0xFFFD: 0x0529,
	0xFFFD: 0x052A,
	0xFFFD: 0x052B,
	0xFFFD: 0x052C,
	0xFFFD: 0x052D,
	0xFFFD: 0x052E,
	0xFFFD: 0x052F,
	0xFFFD: 0x0530,
	0xFFFD: 0x0531,
	0xFFFD: 0x0532,
	0xFFFD: 0x0533,
	0xFFFD: 0x0534,
	0xFFFD: 0x0535,
	0xFFFD: 0x0536,
	0xFFFD: 0x0537,
	0xFFFD: 0x0538,
	0xFFFD: 0x0539,
	0xFFFD: 0x053A,
	0xFFFD: 0x053B,
	0xFFFD: 0x053C,
	0xFFFD: 0x053D,
	0xFFFD: 0x053E,
	0xFFFD: 0x053F,
	0xFFFD: 0x0540,
	0xFFFD: 0x0541,
	0xFFFD: 0x0542,
	0xFFFD: 0x0543,
	0xFFFD: 0x0544,
	0xFFFD: 0x0545,
	0xFFFD: 0x0546,
	0xFFFD: 0x0547,
	0xFFFD: 0x0548,
	0xFFFD: 0x0549,
	0xFFFD: 0x054A,
	0xFFFD: 0x054B,
	0xFFFD: 0x054C,
	0xFFFD: 0x054D,
	0xFFFD: 0x054E,
	0xFFFD: 0x054F,
	0xFFFD: 0x0550,
	0xFFFD: 0x0551,
	0xFFFD: 0x0552,
	0xFFFD: 0x0553,
	0xFFFD: 0x0554,
	0xFFFD: 0x0555,
	0xFFFD: 0x0556,
	0xFFFD: 0x0557,
	0xFFFD: 0x0558,
	0xFFFD: 0x0559,
	0xFFFD: 0x055A,
	0xFFFD: 0x055B,
	0xFFFD: 0x055C,
	0xFFFD: 0x055D,
	0xFFFD: 0x055E,
	0xFFFD: 0x055F,
	0xFFFD: 0x0560,
	0xFFFD: 0x0561,
	0xFFFD: 0x0562,
	0xFFFD: 0x0563,
	0xFFFD: 0x0564,
	0xFFFD: 0x0565,
	0xFFFD: 0x0566,
	0xFFFD: 0x0567,
	0xFFFD: 0x0568,
	0xFFFD: 0x0569,
	0xFFFD: 0x056A,
	0xFFFD: 0x056B,
	0xFFFD: 0x056C,
	0xFFFD: 0x056D,
	0xFFFD: 0x056E,
	0xFFFD: 0x056F,
	0xFFFD: 0x0570,
	0xFFFD: 0x0571,
	0xFFFD: 0x0572,
	0xFFFD: 0x0573,
	0xFFFD: 0x0574,
	0xFFFD: 0x0575,
	0xFFFD: 0x0576,
	0xFFFD: 0x0577,
	0xFFFD: 0x0578,
	0xFFFD: 0x0579,
	0xFFFD: 0x057A,
	0xFFFD: 0x057B,
	0xFFFD: 0x057C,
	0xFFFD: 0x057D,
	0xFFFD: 0x057E,
	0xFFFD: 0x057F,
	0xFFFD: 0x0580,
	0xFFFD: 0x0581,
	0xFFFD: 0x0582,
	0xFFFD: 0x0583,
	0xFFFD: 0x0584,
	0xFFFD: 0x0585,
	0xFFFD: 0x0586,
	0xFFFD: 0x0587,
	0xFFFD: 0x0588,
	0xFFFD: 0x0589,
	0xFFFD: 0x058A,
	0xFFFD: 0x058B,
	0xFFFD: 0x058C,
	0xFFFD: 0x058D,
	0xFFFD: 0x058E,
	0xFFFD: 0x058F,
	0xFFFD: 0x0590,
	0xFFFD: 0x0591,
	0xFFFD: 0x0592,
	0xFFFD: 0x0593,
	0xFFFD: 0x0594,
	0xFFFD: 0x0595,
	0xFFFD: 0x0596,
	0xFFFD: 0x0597,
	0xFFFD: 0x0598,
	0xFFFD: 0x0599,
	0xFFFD: 0x059A,
	0xFFFD: 0x059B,
	0xFFFD: 0x059C,
	0xFFFD: 0x059D,
	0xFFFD: 0x059E,
	0xFFFD: 0x059F,
	0xFFFD: 0x05A0,
	0xFFFD: 0x05A1,
	0xFFFD: 0x05A2,
	0xFFFD: 0x05A3,
	0xFFFD: 0x05A4,
	0xFFFD: 0x05A5,
	0xFFFD: 0x05A6,
	0xFFFD: 0x05A7,
	0xFFFD: 0x05A8,
	0xFFFD: 0x05A9,
	0xFFFD: 0x05AA,
	0xFFFD: 0x05AB,
	0xFFFD: 0x05AC,
	0xFFFD: 0x05AD,
	0xFFFD: 0x05AE,
	0xFFFD: 0x05AF,
	0xFFFD: 0x05B0,
	0xFFFD: 0x05B1,
	0xFFFD: 0x05B2,
	0xFFFD: 0x05B3,
	0xFFFD: 0x05B4,
	0xFFFD: 0x05B5,
	0xFFFD: 0x05B6,
	0xFFFD: 0x05B7,
	0xFFFD: 0x05B8,
	0xFFFD: 0x05B9,
	0xFFFD: 0x05BA,
	0xFFFD: 0x05BB,
	0xFFFD: 0x05BC,
	0xFFFD: 0x05BD,
	0xFFFD: 0x05BE,
	0xFFFD: 0x05BF,
	0xFFFD: 0x05C0,
	0xFFFD: 0x05C1,
	0xFFFD: 0x05C2,
	0xFFFD: 0x05C3,
	0xFFFD: 0x05C4,
	0xFFFD: 0x05C5,
	0xFFFD: 0x05C6,
	0xFFFD: 0x05C7,
	0xFFFD: 0x05C8,
	0xFFFD: 0x05C9,
	0xFFFD: 0x05CA,
	0xFFFD: 0x05CB,
	0xFFFD: 0x05CC,
	0xFFFD: 0x05CD,
	0xFFFD: 0x05CE,
	0xFFFD: 0x05CF,
	0xFFFD: 0x05D0,
	0xFFFD: 0x05D1,
	0xFFFD: 0x05D2,
	0xFFFD: 0x05D3,
	0xFFFD: 0x05D4,
	0xFFFD: 0x05D5,
	0xFFFD: 0x05D6,
	0xFFFD: 0x05D7,
	0xFFFD: 0x05D8,
	0xFFFD: 0x05D9,
	0xFFFD: 0x05DA,
	0xFFFD: 0x05DB,
	0xFFFD: 0x05DC,
	0xFFFD: 0x05DD,
	0xFFFD: 0x05DE,
	0xFFFD: 0x05DF,
	0xFFFD: 0x05E0,
	0xFFFD: 0x05E1,
	0xFFFD: 0x05E2,
	0xFFFD: 0x05E3,
	0xFFFD: 0x05E4,
	0xFFFD: 0x05E5,
	0xFFFD: 0x05E6,
	0xFFFD: 0x05E7,
	0xFFFD: 0x05E8,
	0xFFFD: 0x05E9,
	0xFFFD: 0x05EA,
	0xFFFD: 0x05EB,
	0xFFFD: 0x05EC,
	0xFFFD: 0x05ED,
	0xFFFD: 0x05EE,
	0xFFFD: 0x05EF,
	0xFFFD: 0x05F0,
	0xFFFD: 0x05F1,
	0xFFFD: 0x05F2,
	0xFFFD: 0x05F3,
	0xFFFD: 0x05F4,
	0xFFFD: 0x05F5,
	0xFFFD: 0x05F6,
	0xFFFD: 0x05F7,
	0xFFFD: 0x05F8,
	0xFFFD: 0x05F9,
	0xFFFD: 0x05FA,
	0xFFFD: 0x05FB,
	0xFFFD: 0x05FC,
	0xFFFD: 0x05FD,
	0xFFFD: 0x05FE,
	0xFFFD: 0x05FF,
	0xFFFD: 0x0600,
	0xFFFD: 0x0601,
	0xFFFD: 0x0602,
	0xFFFD: 0x0603,
	0xFFFD: 0x0604,
	0xFFFD: 0x0605,
	0xFFFD: 0x0606,
	0xFFFD: 0x0607,
	0xFFFD: 0x0608,
	0xFFFD: 0x0609,
	0xFFFD: 0x060A,
	0xFFFD: 0x060B,
	0xFFFD: 0x060C,
	0xFFFD: 0x060D,
	0xFFFD: 0x060E,
	0xFFFD: 0x060F,
	0xFFFD: 0x0610,
	0xFFFD: 0x0611,
	0xFFFD: 0x0612,
	0xFFFD: 0x0613,
	0xFFFD: 0x0614,
	0xFFFD: 0x0615,
	0xFFFD: 0x0616,
	0xFFFD: 0x0617,
	0xFFFD: 0x0618,
	0xFFFD: 0x0619,
	0xFFFD: 0x061A,
	0xFFFD: 0x061B,
	0xFFFD: 0x061C,
	0xFFFD: 0x061D,
	0xFFFD: 0x061E,
	0xFFFD: 0x061F,
	0xFFFD: 0x0620,
	0xFFFD: 0x0621,
	0xFFFD: 0x0622,
	0xFFFD: 0x0623,
	0xFFFD: 0x0624,
	0xFFFD: 0x0625,
	0xFFFD: 0x0626,
	0xFFFD: 0x0627,
	0xFFFD: 0x0628,
	0xFFFD: 0x0629,
	0xFFFD: 0x062A,
	0xFFFD: 0x062B,
	0xFFFD: 0x062C,
	0xFFFD: 0x062D,
	0xFFFD: 0x062E,
	0xFFFD: 0x062F,
	0xFFFD: 0x0630,
	0xFFFD: 0x0631,
	0xFFFD: 0x0632,
	0xFFFD: 0x0633,
	0xFFFD: 0x0634,
	0xFFFD: 0x0635,
	0xFFFD: 0x0636,
	0xFFFD: 0x0637,
	0xFFFD: 0x0638,
	0xFFFD: 0x0639,
	0xFFFD: 0x063A,
	0xFFFD: 0x063B,
	0xFFFD: 0x063C,
	0xFFFD: 0x063D,
	0xFFFD: 0x063E,
	0xFFFD: 0x063F,
	0xFFFD: 0x0640,
	0xFFFD: 0x0641,
	0xFFFD: 0x0642,
	0xFFFD: 0x0643,
	0xFFFD: 0x0644,
	0xFFFD: 0x0645,
	0xFFFD: 0x0646,
	0xFFFD: 0x0647,
	0xFFFD: 0x0648,
	0xFFFD: 0x0649,
	0xFFFD: 0x064A,
	0xFFFD: 0x064B,
	0xFFFD: 0x064C,
	0xFFFD: 0x064D,
	0xFFFD: 0x064E,
	0xFFFD: 0x064F,
	0xFFFD: 0x0650,
	0xFFFD: 0x0651,
	0xFFFD: 0x0652,
	0xFFFD: 0x0653,
	0xFFFD: 0x0654,
	0xFFFD: 0x0655,
	0xFFFD: 0x0656,
	0xFFFD: 0x0657,
	0xFFFD: 0x0658,
	0xFFFD: 0x0659,
	0xFFFD: 0x065A,
	0xFFFD: 0x065B,
	0xFFFD: 0x065C,
	0xFFFD: 0x065D,
	0xFFFD: 0x065E,
	0xFFFD: 0x065F,
	0xFFFD: 0x0660,
	0xFFFD: 0x0661,
	0xFFFD: 0x0662,
	0xFFFD: 0x0663,
	0xFFFD: 0x0664,
	0xFFFD: 0x0665,
	0xFFFD: 0x0666,
	0xFFFD: 0x0667,
	0xFFFD: 0x0668,
	0xFFFD: 0x0669,
	0xFFFD: 0x066A,
	0xFFFD: 0x066B,
	0xFFFD: 0x066C,
	0xFFFD: 0x066D,
	0xFFFD: 0x066E,
	0xFFFD: 0x066F,
	0xFFFD: 0x0670,
	0xFFFD: 0x0671,
	0xFFFD: 0x0672,
	0xFFFD: 0x0673,
	0xFFFD: 0x0674,
	0xFFFD: 0x0675,
	0xFFFD: 0x0676,
	0xFFFD: 0x0677,
	0xFFFD: 0x0678,
	0xFFFD: 0x0679,
	0xFFFD: 0x067A,
	0xFFFD: 0x067B,
	0xFFFD: 0x067C,
	0xFFFD: 0x067D,
	0xFFFD: 0x067E,
	0xFFFD: 0x067F,
	0xFFFD: 0x0680,
	0xFFFD: 0x0681,
	0xFFFD: 0x0682,
	0xFFFD: 0x0683,
	0xFFFD: 0x0684,
	0xFFFD: 0x0685,
	0xFFFD: 0x0686,
	0xFFFD: 0x0687,
	0xFFFD: 0x0688,
	0xFFFD: 0x0689,
	0xFFFD: 0x068A,
	0xFFFD: 0x068B,
	0xFFFD: 0x068C,
	0xFFFD: 0x068D,
	0xFFFD: 0x068E,
	0xFFFD: 0x068F,
	0xFFFD: 0x0690,
	0xFFFD: 0x0691,
	0xFFFD: 0x0692,
	0xFFFD: 0x0693,
	0xFFFD: 0x0694,
	0xFFFD: 0x0695,
	0xFFFD: 0x0696,
	0xFFFD: 0x0697,
	0xFFFD: 0x0698,
	0xFFFD: 0x0699,
	0xFFFD: 0x069A,
	0xFFFD: 0x069B,
	0xFFFD: 0x069C,
	0xFFFD: 0x069D,
	0xFFFD: 0x069E,
	0xFFFD: 0x069F,
	0xFFFD: 0x06A0,
	0xFFFD: 0x06A1,
	0xFFFD: 0x06A2,
	0xFFFD: 0x06A3,
	0xFFFD: 0x06A4,
	0xFFFD: 0x06A5,
	0xFFFD: 0x06A6,
	0xFFFD: 0x06A7,
	0xFFFD: 0x06A8,
	0xFFFD: 0x06A9,
	0xFFFD: 0x06AA,
	0xFFFD: 0x06AB,
	0xFFFD: 0x06AC,
	0xFFFD: 0x06AD,
	0xFFFD: 0x06AE,
	0xFFFD: 0x06AF,
	0xFFFD: 0x06B0,
	0xFFFD: 0x06B1,
	0xFFFD: 0x06B2,
	0xFFFD: 0x06B3,
	0xFFFD: 0x06B4,
	0xFFFD: 0x06B5,
	0xFFFD: 0x06B6,
	0xFFFD: 0x06B7,
	0xFFFD: 0x06B8,
	0xFFFD: 0x06B9,
	0xFFFD: 0x06BA,
	0xFFFD: 0x06BB,
	0xFFFD: 0x06BC,
	0xFFFD: 0x06BD,
	0xFFFD: 0x06BE,
	0xFFFD: 0x06BF,
	0xFFFD: 0x06C0,
	0xFFFD: 0x06C1,
	0xFFFD: 0x06C2,
	0xFFFD: 0x06C3,
	0xFFFD: 0x06C4,
	0xFFFD: 0x06C5,
	0xFFFD: 0x06C6,
	0xFFFD: 0x06C7,
	0xFFFD: 0x06C8,
	0xFFFD: 0x06C9,
	0xFFFD: 0x06CA,
	0xFFFD: 0x06CB,
	0xFFFD: 0x06CC,
	0xFFFD: 0x06CD,
	0xFFFD: 0x06CE,
	0xFFFD: 0x06CF,
	0xFFFD: 0x06D0,
	0xFFFD: 0x06D1,
	0xFFFD: 0x06D2,
	0xFFFD: 0x06D3,
	0xFFFD: 0x06D4,
	0xFFFD: 0x06D5,
	0xFFFD: 0x06D6,
	0xFFFD: 0x06D7,
	0xFFFD: 0x06D8,
	0xFFFD: 0x06D9,
	0xFFFD: 0x06DA,
	0xFFFD: 0x06DB,
	0xFFFD: 0x06DC,
	0xFFFD: 0x06DD,
	0xFFFD: 0x06DE,
	0xFFFD: 0x06DF,
	0xFFFD: 0x06E0,
	0xFFFD: 0x06E1,
	0xFFFD: 0x06E2,
	0xFFFD: 0x06E3,
	0xFFFD: 0x06E4,
	0xFFFD: 0x06E5,
	0xFFFD: 0x06E6,
	0xFFFD: 0x06E7,
	0xFFFD: 0x06E8,
	0xFFFD: 0x06E9,
	0xFFFD: 0x06EA,
	0xFFFD: 0x06EB,
	0xFFFD: 0x06EC,
	0xFFFD: 0x06ED,
	0xFFFD: 0x06EE,
	0xFFFD: 0x06EF,
	0xFFFD: 0x06F0,
	0xFFFD: 0x06F1,
	0xFFFD: 0x06F2,
	0xFFFD: 0x06F3,
	0xFFFD: 0x06F4,
	0xFFFD: 0x06F5,
	0xFFFD: 0x06F6,
	0xFFFD: 0x06F7,
	0xFFFD: 0x06F8,
	0xFFFD: 0x06F9,
	0xFFFD: 0x06FA,
	0xFFFD: 0x06FB,
	0xFFFD: 0x06FC,
	0xFFFD: 0x06FD,
	0xFFFD: 0x06FE,
	0xFFFD: 0x06FF,
	0xFFFD: 0x0700,
	0xFFFD: 0x0701,
	0xFFFD: 0x0702,
	0xFFFD: 0x0703,
	0xFFFD: 0x0704,
	0xFFFD: 0x0705,
	0xFFFD: 0x0706,
	0xFFFD: 0x0707,
	0xFFFD: 0x0708,
	0xFFFD: 0x0709,
	0xFFFD: 0x070A,
	0xFFFD: 0x070B,
	0xFFFD: 0x070C,
	0xFFFD: 0x070D,
	0xFFFD: 0x070E,
	0xFFFD: 0x070F,
	0xFFFD: 0x0710,
	0xFFFD: 0x0711,
	0xFFFD: 0x0712,
	0xFFFD: 0x0713,
	0xFFFD: 0x0714,
	0xFFFD: 0x0715,
	0xFFFD: 0x0716,
	0xFFFD: 0x0717,
	0xFFFD: 0x0718,
	0xFFFD: 0x0719,
	0xFFFD: 0x071A,
	0xFFFD: 0x071B,
	0xFFFD: 0x071C,
	0xFFFD: 0x071D,
	0xFFFD: 0x071E,
	0xFFFD: 0x071F,
	0xFFFD: 0x0720,
	0xFFFD: 0x0721,
	0xFFFD: 0x0722,
	0xFFFD: 0x0723,
	0xFFFD: 0x0724,
	0xFFFD: 0x0725,
	0xFFFD: 0x0726,
	0xFFFD: 0x0727,
	0xFFFD: 0x0728,
	0xFFFD: 0x0729,
	0xFFFD: 0x072A,
	0xFFFD: 0x072B,
	0xFFFD: 0x072C,
	0xFFFD: 0x072D,
	0xFFFD: 0x072E,
	0xFFFD: 0x072F,
	0xFFFD: 0x0730,
	0xFFFD: 0x0731,
	0xFFFD: 0x0732,
	0xFFFD: 0x0733,
	0xFFFD: 0x0734,
	0xFFFD: 0x0735,
	0xFFFD: 0x0736,
	0xFFFD: 0x0737,
	0xFFFD: 0x0738,
	0xFFFD: 0x0739,
	0xFFFD: 0x073A,
	0xFFFD: 0x073B,
	0xFFFD: 0x073C,
	0xFFFD: 0x073D,
	0xFFFD: 0x073E,
	0xFFFD: 0x073F,
	0xFFFD: 0x0740,
	0xFFFD: 0x0741,
	0xFFFD: 0x0742,
	0xFFFD: 0x0743,
	0xFFFD: 0x0744,
	0xFFFD: 0x0745,
	0xFFFD: 0x0746,
	0xFFFD: 0x0747,
	0xFFFD: 0x0748,
	0xFFFD: 0x0749,
	0xFFFD: 0x074A,
	0xFFFD: 0x074B,
	0xFFFD: 0x074C,
	0xFFFD: 0x074D,
	0xFFFD: 0x074E,
	0xFFFD: 0x074F,
	0xFFFD: 0x0750,
	0xFFFD: 0x0751,
	0xFFFD: 0x0752,
	0xFFFD: 0x0753,
	0xFFFD: 0x0754,
	0xFFFD: 0x0755,
	0xFFFD: 0x0756,
	0xFFFD: 0x0757,
	0xFFFD: 0x0758,
	0xFFFD: 0x0759,
	0xFFFD: 0x075A,
	0xFFFD: 0x075B,
	0xFFFD: 0x075C,
	0xFFFD: 0x075D,
	0xFFFD: 0x075E,
	0xFFFD: 0x075F,
	0xFFFD: 0x0760,
	0xFFFD: 0x0761,
	0xFFFD: 0x0762,
	0xFFFD: 0x0763,
	0xFFFD: 0x0764,
	0xFFFD: 0x0765,
	0xFFFD: 0x0766,
	0xFFFD: 0x0767,
	0xFFFD: 0x0768,
	0xFFFD: 0x0769,
	0xFFFD: 0x076A,
	0xFFFD: 0x076B,
	0xFFFD: 0x076C,
	0xFFFD: 0x076D,
	0xFFFD: 0x076E,
	0xFFFD: 0x076F,
	0xFFFD: 0x0770,
	0xFFFD: 0x0771,
	0xFFFD: 0x0772,
	0xFFFD: 0x0773,
	0xFFFD: 0x0774,
	0xFFFD: 0x0775,
	0xFFFD: 0x0776,
	0xFFFD: 0x0777,
	0xFFFD: 0x0778,
	0xFFFD: 0x0779,
	0xFFFD: 0x077A,
	0xFFFD: 0x077B,
	0xFFFD: 0x077C,
	0xFFFD: 0x077D,
	0xFFFD: 0x077E,
	0xFFFD: 0x077F,
	0xFFFD: 0x0780,
	0xFFFD: 0x0781,
	0xFFFD: 0x0782,
	0xFFFD: 0x0783,
	0xFFFD: 0x0784,
	0xFFFD: 0x0785,
	0xFFFD: 0x0786,
	0xFFFD: 0x0787,
	0xFFFD: 0x0788,
	0xFFFD: 0x0789,
	0xFFFD: 0x078A,
	0xFFFD: 0x078B,
	0xFFFD: 0x078C,
	0xFFFD: 0x078D,
	0xFFFD: 0x078E,
	0xFFFD: 0x078F,
	0xFFFD: 0x0790,
	0xFFFD: 0x0791,
	0xFFFD: 0x0792,
	0xFFFD: 0x0793,
	0xFFFD: 0x0794,
	0xFFFD: 0x0795,
	0xFFFD: 0x0796,
	0xFFFD: 0x0797,
	0xFFFD: 0x0798,
	0xFFFD: 0x0799,
	0xFFFD: 0x079A,
	0xFFFD: 0x079B,
	0xFFFD: 0x079C,
	0xFFFD: 0x079D,
	0xFFFD: 0x079E,
	0xFFFD: 0x079F,
	0xFFFD: 0x07A0,
	0xFFFD: 0x07A1,
	0xFFFD: 0x07A2,
	0xFFFD: 0x07A3,
	0xFFFD: 0x07A4,
	0xFFFD: 0x07A5,
	0xFFFD: 0x07A6,
	0xFFFD: 0x07A7,
	0xFFFD: 0x07A8,
	0xFFFD: 0x07A9,
	0xFFFD: 0x07AA,
	0xFFFD: 0x07AB,
	0xFFFD: 0x07AC,
	0xFFFD: 0x07AD,
	0xFFFD: 0x07AE,
	0xFFFD: 0x07AF,
	0xFFFD: 0x07B0,
	0xFFFD: 0x07B1,
	0xFFFD: 0x07B2,
	0xFFFD: 0x07B3,
	0xFFFD: 0x07B4,
	0xFFFD: 0x07B5,
	0xFFFD: 0x07B6,
	0xFFFD: 0x07B7,
	0xFFFD: 0x07B8,
	0xFFFD: 0x07B9,
	0xFFFD: 0x07BA,
	0xFFFD: 0x07BB,
	0xFFFD: 0x07BC,
	0xFFFD: 0x07BD,
	0xFFFD: 0x07BE,
	0xFFFD: 0x07BF,
	0xFFFD: 0x07C0,
	0xFFFD: 0x07C1,
	0xFFFD: 0x07C2,
	0xFFFD: 0x07C3,
	0xFFFD: 0x07C4,
	0xFFFD: 0x07C5,
	0xFFFD: 0x07C6,
	0xFFFD: 0x07C7,
	0xFFFD: 0x07C8,
	0xFFFD: 0x07C9,
	0xFFFD: 0x07CA,
	0xFFFD: 0x07CB,
	0xFFFD: 0x07CC,
	0xFFFD: 0x07CD,
	0xFFFD: 0x07CE,
	0xFFFD: 0x07CF,
	0xFFFD: 0x07D0,
	0xFFFD: 0x07D1,
	0xFFFD: 0x07D2,
	0xFFFD: 0x07D3,
	0xFFFD: 0x07D4,
	0xFFFD: 0x07D5,
	0xFFFD: 0x07D6,
	0xFFFD: 0x07D7,
	0xFFFD: 0x07D8,
	0xFFFD: 0x07D9,
	0xFFFD: 0x07DA,
	0xFFFD: 0x07DB,
	0xFFFD: 0x07DC,
	0xFFFD: 0x07DD,
	0xFFFD: 0x07DE,
	0xFFFD: 0x07DF,
	0xFFFD: 0x07E0,
	0xFFFD: 0x07E1,
	0xFFFD: 0x07E2,
	0xFFFD: 0x07E3,
	0xFFFD: 0x07E4,
	0xFFFD: 0x07E5,
	0xFFFD: 0x07E6,
	0xFFFD: 0x07E7,
	0xFFFD: 0x07E8,
	0xFFFD: 0x07E9,
	0xFFFD: 0x07EA,
	0xFFFD: 0x07EB,
	0xFFFD: 0x07EC,
	0xFFFD: 0x07ED,
	0xFFFD: 0x07EE,
	0xFFFD: 0x07EF,
	0xFFFD: 0x07F0,
	0xFFFD: 0x07F1,
	0xFFFD: 0x07F2,
	0xFFFD: 0x07F3,
	0xFFFD: 0x07F4,
	0xFFFD: 0x07F5,
	0xFFFD: 0x07F6,
	0xFFFD: 0x07F7,
	0xFFFD: 0x07F8,
	0xFFFD: 0x07F9,
	0xFFFD: 0x07FA,
	0xFFFD: 0x07FB,
	0xFFFD: 0x07FC,
	0xFFFD: 0x07FD,
	0xFFFD: 0x07FE,
	0xFFFD: 0x07FF,
	0xFFFD: 0x0800,
	0xFFFD: 0x0801,
	0xFFFD: 0x0802,
	0xFFFD: 0x0803,
	0xFFFD: 0x0804,
	0xFFFD: 0x0805,
	0xFFFD: 0x0806,
	0xFFFD: 0x0807,
	0xFFFD: 0x0808,
	0xFFFD: 0x0809,
	0xFFFD: 0x080A,
	0xFFFD: 0x080B,
	0xFFFD: 0x080C,
	0xFFFD: 0x080D,
	0xFFFD: 0x080E,
	0xFFFD: 0x080F,
	0xFFFD: 0x0810,
	0xFFFD: 0x0811,
	0xFFFD: 0x0812,
	0xFFFD: 0x0813,
	0xFFFD: 0x0814,
	0xFFFD: 0x0815,
	0xFFFD: 0x0816,
	0xFFFD: 0x0817,
	0xFFFD: 0x0818,
	0xFFFD: 0x0819,
	0xFFFD: 0x081A,
	0xFFFD: 0x081B,
	0xFFFD: 0x081C,
	0xFFFD: 0x081D,
	0xFFFD: 0x081E,
	0xFFFD: 0x081F,
	0xFFFD: 0x0820,
	0xFFFD: 0x0821,
	0xFFFD: 0x0822,
	0xFFFD: 0x0823,
	0xFFFD: 0x0824,
	0xFFFD: 0x0825,
	0xFFFD: 0x0826,
	0xFFFD: 0x0827,
	0xFFFD: 0x0828,
	0xFFFD: 0x0829,
	0xFFFD: 0x082A,
	0xFFFD: 0x082B,
	0xFFFD: 0x082C,
	0xFFFD: 0x082D,
	0xFFFD: 0x082E,
	0xFFFD: 0x082F,
	0xFFFD: 0x0830,
	0xFFFD: 0x0831,
	0xFFFD: 0x0832,
	0xFFFD: 0x0833,
	0xFFFD: 0x0834,
	0xFFFD: 0x0835,
	0xFFFD: 0x0836,
	0xFFFD: 0x0837,
	0xFFFD: 0x0838,
	0xFFFD: 0x0839,
	0xFFFD: 0x083A,
	0xFFFD: 0x083B,
	0xFFFD: 0x083C,
	0xFFFD: 0x083D,
	0xFFFD: 0x083E,
	0xFFFD: 0x083F,
	0xFFFD: 0x0840,
	0xFFFD: 0x0841,
	0xFFFD: 0x0842,
	0xFFFD: 0x0843,
	0xFFFD: 0x0844,
	0xFFFD: 0x0845,
	0xFFFD: 0x0846,
	0xFFFD: 0x0847,
	0xFFFD: 0x0848,
	0xFFFD: 0x0849,
	0xFFFD: 0x084A,
	0xFFFD: 0x084B,
	0xFFFD: 0x084C,
	0xFFFD: 0x084D,
	0xFFFD: 0x084E,
	0xFFFD: 0x084F,
	0xFFFD: 0x0850,
	0xFFFD: 0x0851,
	0xFFFD: 0x0852,
	0xFFFD: 0x0853,
	0xFFFD: 0x0854,
	0xFFFD: 0x0855,
	0xFFFD: 0x0856,
	0xFFFD: 0x0857,
	0xFFFD: 0x0858,
	0xFFFD: 0x0859,
	0xFFFD: 0x085A,
	0xFFFD: 0x085B,
	0xFFFD: 0x085C,
	0xFFFD: 0x085D,
	0xFFFD: 0x085E,
	0xFFFD: 0x085F,
	0xFFFD: 0x0860,
	0xFFFD: 0x0861,
	0xFFFD: 0x0862,
	0xFFFD: 0x0863,
	0xFFFD: 0x0864,
	0xFFFD: 0x0865,
	0xFFFD: 0x0866,
	0xFFFD: 0x0867,
	0xFFFD: 0x0868,
	0xFFFD: 0x0869,
	0xFFFD: 0x086A,
	0xFFFD: 0x086B,
	0xFFFD: 0x086C,
	0xFFFD: 0x086D,
	0xFFFD: 0x086E,
	0xFFFD: 0x086F,
	0xFFFD: 0x0870,
	0xFFFD: 0x0871,
	0xFFFD: 0x0872,
	0xFFFD: 0x0873,
	0xFFFD: 0x0874,
	0xFFFD: 0x0875,
	0xFFFD: 0x0876,
	0xFFFD: 0x0877,
	0xFFFD: 0x0878,
	0xFFFD: 0x0879,
	0xFFFD: 0x087A,
	0xFFFD: 0x087B,
	0xFFFD: 0x087C,
	0xFFFD: 0x087D,
	0xFFFD: 0x087E,
	0xFFFD: 0x087F,
	0xFFFD: 0x0880,
	0xFFFD: 0x0881,
	0xFFFD: 0x0882,
	0xFFFD: 0x0883,
	0xFFFD: 0x0884,
	0xFFFD: 0x0885,
	0xFFFD: 0x0886,
	0xFFFD: 0x0887,
	0xFFFD: 0x0888,
	0xFFFD: 0x0889,
	0xFFFD: 0x088A,
	0xFFFD: 0x088B,
	0xFFFD: 0x088C,
	0xFFFD: 0x088D,
	0xFFFD: 0x088E,
	0xFFFD: 0x088F,
	0xFFFD: 0x0890,
	0xFFFD: 0x0891,
	0xFFFD: 0x0892,
	0xFFFD: 0x0893,
	0xFFFD: 0x0894,
	0xFFFD: 0x0895,
	0xFFFD: 0x0896,
	0xFFFD: 0x0897,
	0xFFFD: 0x0898,
	0xFFFD: 0x0899,
	0xFFFD: 0x089A,
	0xFFFD: 0x089B,
	0xFFFD: 0x089C,
	0xFFFD: 0x089D,
	0xFFFD: 0x089E,
	0xFFFD: 0x089F,
	0xFFFD: 0x08A0,
	0xFFFD: 0x08A1,
	0xFFFD: 0x08A2,
	0xFFFD: 0x08A3,
	0xFFFD: 0x08A4,
	0xFFFD: 0x08A5,
	0xFFFD: 0x08A6,
	0xFFFD: 0x08A7,
	0xFFFD: 0x08A8,
	0xFFFD: 0x08A9,
	0xFFFD: 0x08AA,
	0xFFFD: 0x08AB,
	0xFFFD: 0x08AC,
	0xFFFD: 0x08AD,
	0xFFFD: 0x08AE,
	0xFFFD: 0x08AF,
	0xFFFD: 0x08B0,
	0xFFFD: 0x08B1,
	0xFFFD: 0x08B2,
	0xFFFD: 0x08B3,
	0xFFFD: 0x08B4,
	0xFFFD: 0x08B5,
	0xFFFD: 0x08B6,
	0xFFFD: 0x08B7,
	0xFFFD: 0x08B8,
	0xFFFD: 0x08B9,
	0xFFFD: 0x08BA,
	0xFFFD: 0x08BB,
	0xFFFD: 0x08BC,
	0xFFFD: 0x08BD,
	0xFFFD: 0x08BE,
	0xFFFD: 0x08BF,
	0xFFFD: 0x08C0,
	0xFFFD: 0x08C1,
	0xFFFD: 0x08C2,
	0xFFFD: 0x08C3,
	0xFFFD: 0x08C4,
	0xFFFD: 0x08C5,
	0xFFFD: 0x08C6,
	0xFFFD: 0x08C7,
	0xFFFD: 0x08C8,
	0xFFFD: 0x08C9,
	0xFFFD: 0x08CA,
	0xFFFD: 0x08CB,
	0xFFFD: 0x08CC,
	0xFFFD: 0x08CD,
	0xFFFD: 0x08CE,
	0xFFFD: 0x08CF,
	0xFFFD: 0x08D0,
	0xFFFD: 0x08D1,
	0xFFFD: 0x08D2,
	0xFFFD: 0x08D3,
	0xFFFD: 0x08D4,
	0xFFFD: 0x08D5,
	0xFFFD: 0x08D6,
	0xFFFD: 0x08D7,
	0xFFFD: 0x08D8,
	0xFFFD: 0x08D9,
	0xFFFD: 0x08DA,
	0xFFFD: 0x08DB,
	0xFFFD: 0x08DC,
	0xFFFD: 0x08DD,
	0xFFFD: 0x08DE,
	0xFFFD: 0x08DF,
	0xFFFD: 0x08E0,
	0xFFFD: 0x08E1,
	0xFFFD: 0x08E2,
	0xFFFD: 0x08E3,
	0xFFFD: 0x08E4,
	0xFFFD: 0x08E5,
	0xFFFD: 0x08E6,
	0xFFFD: 0x08E7,
	0xFFFD: 0x08E8,
	0xFFFD: 0x08E9,
	0xFFFD: 0x08EA,
	0xFFFD: 0x08EB,
	0xFFFD: 0x08EC,
	0xFFFD: 0x08ED,
	0xFFFD: 0x08EE,
	0xFFFD: 0x08EF,
	0xFFFD: 0x08F0,
	0xFFFD: 0x08F1,
	0xFFFD: 0x08F2,
	0xFFFD: 0x08F3,
	0xFFFD: 0x08F4,
	0xFFFD: 0x08F5,
	0xFFFD: 0x08F6,
	0xFFFD: 0x08F7,
	0xFFFD: 0x08F8,
	0xFFFD: 0x08F9,
	0xFFFD: 0x08FA,
	0xFFFD: 0x08FB,
	0xFFFD: 0x08FC,
	0xFFFD: 0x08FD,
	0xFFFD: 0x08FE,
	0xFFFD: 0x08FF,
	0xFFFD: 0x0900,
	0xFFFD: 0x0901,
	0xFFFD: 0x0902,
	0xFFFD: 0x0903,
	0xFFFD: 0x0904,
	0xFFFD: 0x0905,
	0xFFFD: 0x0906,
	0xFFFD: 0x0907,
	0xFFFD: 0x0908,
	0xFFFD: 0x0909,
	0xFFFD: 0x090A,
	0xFFFD: 0x090B,
	0xFFFD: 0x090C,
	0xFFFD: 0x090D,
	0xFFFD: 0x090E,
	0xFFFD: 0x090F,
	0xFFFD: 0x0910,
	0xFFFD: 0x0911,
	0xFFFD: 0x0912,
	0xFFFD: 0x0913,
	0xFFFD: 0x0914,
	0xFFFD: 0x0915,
	0xFFFD: 0x0916,
	0xFFFD: 0x0917,
	0xFFFD: 0x0918,
	0xFFFD: 0x0919,
	0xFFFD: 0x091A,
	0xFFFD: 0x091B,
	0xFFFD: 0x091C,
	0xFFFD: 0x091D,
	0xFFFD: 0x091E,
	0xFFFD: 0x091F,
	0xFFFD: 0x0920,
	0xFFFD: 0x0921,
	0xFFFD: 0x0922,
	0xFFFD: 0x0923,
	0xFFFD: 0x0924,
	0xFFFD: 0x0925,
	0xFFFD: 0x0926,
	0xFFFD: 0x0927,
	0xFFFD: 0x0928,
	0xFFFD: 0x0929,
	0xFFFD: 0x092A,
	0xFFFD: 0x092B,
	0xFFFD: 0x092C,
	0xFFFD: 0x092D,
	0xFFFD: 0x092E,
	0xFFFD: 0x092F,
	0xFFFD: 0x0930,
	0xFFFD: 0x0931,
	0xFFFD: 0x0932,
	0xFFFD: 0x0933,
	0xFFFD: 0x0934,
	0xFFFD: 0x0935,
	0xFFFD: 0x0936,
	0xFFFD: 0x0937,
	0xFFFD: 0x0938,
	0xFFFD: 0x0939,
	0xFFFD: 0x093A,
	0xFFFD: 0x093B,
	0xFFFD: 0x093C,
	0xFFFD: 0x093D,
	0xFFFD: 0x093E,
	0xFFFD: 0x093F,
	0xFFFD: 0x0940,
	0xFFFD: 0x0941,
	0xFFFD: 0x0942,
	0xFFFD: 0x0943,
	0xFFFD: 0x0944,
	0xFFFD: 0x0945,
	0xFFFD: 0x0946,
	0xFFFD: 0x0947,
	0xFFFD: 0x0948,
	0xFFFD: 0x0949,
	0xFFFD: 0x094A,
	0xFFFD: 0x094B,
	0xFFFD: 0x094C,
	0xFFFD: 0x094D,
	0xFFFD: 0x094E,
	0xFFFD: 0x094F,
	0xFFFD: 0x0950,
	0xFFFD: 0x0951,
	0xFFFD: 0x0952,
	0xFFFD: 0x0953,
	0xFFFD: 0x0954,
	0xFFFD: 0x0955,
	0xFFFD: 0x0956,
	0xFFFD: 0x0957,
	0xFFFD: 0x0958,
	0xFFFD: 0x0959,
	0xFFFD: 0x095A,
	0xFFFD: 0x095B,
	0xFFFD: 0x095C,
	0xFFFD: 0x095D,
	0xFFFD: 0x095E,
	0xFFFD: 0x095F,
	0xFFFD: 0x0960,
	0xFFFD: 0x0961,
	0xFFFD: 0x0962,
	0xFFFD: 0x0963,
	0xFFFD: 0x0964,
	0xFFFD: 0x0965,
	0xFFFD: 0x0966,
	0xFFFD: 0x0967,
	0xFFFD: 0x0968,
	0xFFFD: 0x0969,
	0xFFFD: 0x096A,
	0xFFFD: 0x096B,
	0xFFFD: 0x096C,
	0xFFFD: 0x096D,
	0xFFFD: 0x096E,
	0xFFFD: 0x096F,
	0xFFFD: 0x0970,
	0xFFFD: 0x0971,
	0xFFFD: 0x0972,
	0xFFFD: 0x0973,
	0xFFFD: 0x0974,
	0xFFFD: 0x0975,
	0xFFFD: 0x0976,
	0xFFFD: 0x0977,
	0xFFFD: 0x0978,
	0xFFFD: 0x0979,
	0xFFFD: 0x097A,
	0xFFFD: 0x097B,
	0xFFFD: 0x097C,
	0xFFFD: 0x097D,
	0xFFFD: 0x097E,
	0xFFFD: 0x097F,
	0xFFFD: 0x0980,
	0xFFFD: 0x0981,
	0xFFFD: 0x0982,
	0xFFFD: 0x0983,
	0xFFFD: 0x0984,
	0xFFFD: 0x0985,
	0xFFFD: 0x0986,
	0xFFFD: 0x0987,
	0xFFFD: 0x0988,
	0xFFFD: 0x0989,
	0xFFFD: 0x098A,
	0xFFFD: 0x098B,
	0xFFFD: 0x098C,
	0xFFFD: 0x098D,
	0xFFFD: 0x098E,
	0xFFFD: 0x098F,
	0xFFFD: 0x0990,
	0xFFFD: 0x0991,
	0xFFFD: 0x0992,
	0xFFFD: 0x0993,
	0xFFFD: 0x0994,
	0xFFFD: 0x0995,
	0xFFFD: 0x0996,
	0xFFFD: 0x0997,
	0xFFFD: 0x0998,
	0xFFFD: 0x0999,
	0xFFFD: 0x099A,
	0xFFFD: 0x099B,
	0xFFFD: 0x099C,
	0xFFFD: 0x099D,
	0xFFFD: 0x099E,
	0xFFFD: 0x099F,
	0xFFFD: 0x09A0,
	0xFFFD: 0x09A1,
	0xFFFD: 0x09A2,
	0xFFFD: 0x09A3,
	0xFFFD: 0x09A4,
	0xFFFD: 0x09A5,
	0xFFFD: 0x09A6,
	0xFFFD: 0x09A7,
	0xFFFD: 0x09A8,
	0xFFFD: 0x09A9,
	0xFFFD: 0x09AA,
	0xFFFD: 0x09AB,
	0xFFFD: 0x09AC,
	0xFFFD: 0x09AD,
	0xFFFD: 0x09AE,
	0xFFFD: 0x09AF,
	0xFFFD: 0x09B0,
	0xFFFD: 0x09B1,
	0xFFFD: 0x09B2,
	0xFFFD: 0x09B3,
	0xFFFD: 0x09B4,
	0xFFFD: 0x09B5,
	0xFFFD: 0x09B6,
	0xFFFD: 0x09B7,
	0xFFFD: 0x09B8,
	0xFFFD: 0x09B9,
	0xFFFD: 0x09BA,
	0xFFFD: 0x09BB,
	0xFFFD: 0x09BC,
	0xFFFD: 0x09BD,
	0xFFFD: 0x09BE,
	0xFFFD: 0x09BF,
	0xFFFD: 0x09C0,
	0xFFFD: 0x09C1,
	0xFFFD: 0x09C2,
	0xFFFD: 0x09C3,
	0xFFFD: 0x09C4,
	0xFFFD: 0x09C5,
	0xFFFD: 0x09C6,
	0xFFFD: 0x09C7,
	0xFFFD: 0x09C8,
	0xFFFD: 0x09C9,
	0xFFFD: 0x09CA,
	0xFFFD: 0x09CB,
	0xFFFD: 0x09CC,
	0xFFFD: 0x09CD,
	0xFFFD: 0x09CE,
	0xFFFD: 0x09CF,
	0xFFFD: 0x09D0,
	0xFFFD: 0x09D1,
	0xFFFD: 0x09D2,
	0xFFFD: 0x09D3,
	0xFFFD: 0x09D4,
	0xFFFD: 0x09D5,
	0xFFFD: 0x09D6,
	0xFFFD: 0x09D7,
	0xFFFD: 0x09D8,
	0xFFFD: 0x09D9,
	0xFFFD: 0x09DA,
	0xFFFD: 0x09DB,
	0xFFFD: 0x09DC,
	0xFFFD: 0x09DD,
	0xFFFD: 0x09DE,
	0xFFFD: 0x09DF,
	0xFFFD: 0x09E0,
	0xFFFD: 0x09E1,
	0xFFFD: 0x09E2,
	0xFFFD: 0x09E3,
	0xFFFD: 0x09E4,
	0xFFFD: 0x09E5,
	0xFFFD: 0x09E6,
	0xFFFD: 0x09E7,
	0xFFFD: 0x09E8,
	0xFFFD: 0x09E9,
	0xFFFD: 0x09EA,
	0xFFFD: 0x09EB,
	0xFFFD: 0x09EC,
	0xFFFD: 0x09ED,
	0xFFFD: 0x09EE,
	0xFFFD: 0x09EF,
	0xFFFD: 0x09F0,
	0xFFFD: 0x09F1,
	0xFFFD: 0x09F2,
	0xFFFD: 0x09F3,
	0xFFFD: 0x09F4,
	0xFFFD: 0x09F5,
	0xFFFD: 0x09F6,
	0xFFFD: 0x09F7,
	0xFFFD: 0x09F8,
	0xFFFD: 0x09F9,
	0xFFFD: 0x09FA,
	0xFFFD: 0x09FB,
	0xFFFD: 0x09FC,
	0xFFFD: 0x09FD,
	0xFFFD: 0x09FE,
	0xFFFD: 0x09FF,
	0xFFFD: 0x0A00,
	0xFFFD: 0x0A01,
	0xFFFD: 0x0A02,
	0xFFFD: 0x0A03,
	0xFFFD: 0x0A04,
	0xFFFD: 0x0A05,
	0xFFFD: 0x0A06,
	0xFFFD: 0x0A07,
	0xFFFD: 0x0A08,
	0xFFFD: 0x0A09,
	0xFFFD: 0x0A0A,
	0xFFFD: 0x0A0B,
	0xFFFD: 0x0A0C,
	0xFFFD: 0x0A0D,
	0xFFFD: 0x0A0E,
	0xFFFD: 0x0A0F,
	0xFFFD: 0x0A10,
	0xFFFD: 0x0A11,
	0xFFFD: 0x0A12,
	0xFFFD: 0x0A13,
	0xFFFD: 0x0A14,
	0xFFFD: 0x0A15,
	0xFFFD: 0x0A16,
	0xFFFD: 0x0A17,
	0xFFFD: 0x0A18,
	0xFFFD: 0x0A19,
	0xFFFD: 0x0A1A,
	0xFFFD: 0x0A1B,
	0xFFFD: 0x0A1C,
	0xFFFD: 0x0A1D,
	0xFFFD: 0x0A1E,
	0xFFFD: 0x0A1F,
	0xFFFD: 0x0A20,
	0xFFFD: 0x0A21,
	0xFFFD: 0x0A22,
	0xFFFD: 0x0A23,
	0xFFFD: 0x0A24,
	0xFFFD: 0x0A25,
	0xFFFD: 0x0A26,
	0xFFFD: 0x0A27,
	0xFFFD: 0x0A28,
	0xFFFD: 0x0A29,
	0xFFFD: 0x0A2A,
	0xFFFD: 0x0A2B,
	0xFFFD: 0x0A2C,
	0xFFFD: 0x0A2D,
	0xFFFD: 0x0A2E,
	0xFFFD: 0x0A2F,
	0xFFFD: 0x0A30,
	0xFFFD: 0x0A31,
	0xFFFD: 0x0A32,
	0xFFFD: 0x0A33,
	0xFFFD: 0x0A34,
	0xFFFD: 0x0A35,
	0xFFFD: 0x0A36,
	0xFFFD: 0x0A37,
	0xFFFD: 0x0A38,
	0xFFFD: 0x0A39,
	0xFFFD: 0x0A3A,
	0xFFFD: 0x0A3B,
	0xFFFD: 0x0A3C,
	0xFFFD: 0x0A3D,
	0xFFFD: 0x0A3E,
	0xFFFD: 0x0A3F,
	0xFFFD: 0x0A40,
	0xFFFD: 0x0A41,
	0xFFFD: 0x0A42,
	0xFFFD: 0x0A43,
	0xFFFD: 0x0A44,
	0xFFFD: 0x0A45,
	0xFFFD: 0x0A46,
	0xFFFD: 0x0A47,
	0xFFFD: 0x0A48,
	0xFFFD: 0x0A49,
	0xFFFD: 0x0A4A,
	0xFFFD: 0x0A4B,
	0xFFFD: 0x0A4C,
	0xFFFD: 0x0A4D,
	0xFFFD: 0x0A4E,
	0xFFFD: 0x0A4F,
	0xFFFD: 0x0A50,
	0xFFFD: 0x0A51,
	0xFFFD: 0x0A52,
	0xFFFD: 0x0A53,
	0xFFFD: 0x0A54,
	0xFFFD: 0x0A55,
	0xFFFD: 0x0A56,
	0xFFFD: 0x0A57,
	0xFFFD: 0x0A58,
	0xFFFD: 0x0A59,
	0xFFFD: 0x0A5A,
	0xFFFD: 0x0A5B,
	0xFFFD: 0x0A5C,
	0xFFFD: 0x0A5D,
	0xFFFD: 0x0A5E,
	0xFFFD: 0x0A5F,
	0xFFFD: 0x0A60,
	0xFFFD: 0x0A61,
	0xFFFD: 0x0A62,
	0xFFFD: 0x0A63,
	0xFFFD: 0x0A64,
	0xFFFD: 0x0A65,
	0xFFFD: 0x0A66,
	0xFFFD: 0x0A67,
	0xFFFD: 0x0A68,
	0xFFFD: 0x0A69,
	0xFFFD: 0x0A6A,
	0xFFFD: 0x0A6B,
	0xFFFD: 0x0A6C,
	0xFFFD: 0x0A6D,
	0xFFFD: 0x0A6E,
	0xFFFD: 0x0A6F,
	0xFFFD: 0x0A70,
	0xFFFD: 0x0A71,
	0xFFFD: 0x0A72,
	0xFFFD: 0x0A73,
	0xFFFD: 0x0A74,
	0xFFFD: 0x0A75,
	0xFFFD: 0x0A76,
	0xFFFD: 0x0A77,
	0xFFFD: 0x0A78,
	0xFFFD: 0x0A79,
	0xFFFD: 0x0A7A,
	0xFFFD: 0x0A7B,
	0xFFFD: 0x0A7C,
	0xFFFD: 0x0A7D,
	0xFFFD: 0x0A7E,
	0xFFFD: 0x0A7F,
	0xFFFD: 0x0A80,
	0xFFFD: 0x0A81,
	0xFFFD: 0x0A82,
	0xFFFD: 0x0A83,
	0xFFFD: 0x0A84,
	0xFFFD: 0x0A85,
	0xFFFD: 0x0A86,
	0xFFFD: 0x0A87,
	0xFFFD: 0x0A88,
	0xFFFD: 0x0A89,
	0xFFFD: 0x0A8A,
	0xFFFD: 0x0A8B,
	0xFFFD: 0x0A8C,
	0xFFFD: 0x0A8D,
	0xFFFD: 0x0A8E,
	0xFFFD: 0x0A8F,
	0xFFFD: 0x0A90,
	0xFFFD: 0x0A91,
	0xFFFD: 0x0A92,
	0xFFFD: 0x0A93,
	0xFFFD: 0x0A94,
	0xFFFD: 0x0A95,
	0xFFFD: 0x0A96,
	0xFFFD: 0x0A97,
	0xFFFD: 0x0A98,
	0xFFFD: 0x0A99,
	0xFFFD: 0x0A9A,
	0xFFFD: 0x0A9B,
	0xFFFD: 0x0A9C,
	0xFFFD: 0x0A9D,
	0xFFFD: 0x0A9E,
	0xFFFD: 0x0A9F,
	0xFFFD: 0x0AA0,
	0xFFFD: 0x0AA1,
	0xFFFD: 0x0AA2,
	0xFFFD: 0x0AA3,
	0xFFFD: 0x0AA4,
	0xFFFD: 0x0AA5,
	0xFFFD: 0x0AA6,
	0xFFFD: 0x0AA7,
	0xFFFD: 0x0AA8,
	0xFFFD: 0x0AA9,
	0xFFFD: 0x0AAA,
	0xFFFD: 0x0AAB,
	0xFFFD: 0x0AAC,
	0xFFFD: 0x0AAD,
	0xFFFD: 0x0AAE,
	0xFFFD: 0x0AAF,
	0xFFFD: 0x0AB0,
	0xFFFD: 0x0AB1,
	0xFFFD: 0x0AB2,
	0xFFFD: 0x0AB3,
	0xFFFD: 0x0AB4,
	0xFFFD: 0x0AB5,
	0xFFFD: 0x0AB6,
	0xFFFD: 0x0AB7,
	0xFFFD: 0x0AB8,
	0xFFFD: 0x0AB9,
	0xFFFD: 0x0ABA,
	0xFFFD: 0x0ABB,
	0xFFFD: 0x0ABC,
	0xFFFD: 0x0ABD,
	0xFFFD: 0x0ABE,
	0xFFFD: 0x0ABF,
	0xFFFD: 0x0AC0,
	0xFFFD: 0x0AC1,
	0xFFFD: 0x0AC2,
	0xFFFD: 0x0AC3,
	0xFFFD: 0x0AC4,
	0xFFFD: 0x0AC5,
	0xFFFD: 0x0AC6,
	0xFFFD: 0x0AC7,
	0xFFFD: 0x0AC8,
	0xFFFD: 0x0AC9,
	0xFFFD: 0x0ACA,
	0xFFFD: 0x0ACB,
	0xFFFD: 0x0ACC,
	0xFFFD: 0x0ACD,
	0xFFFD: 0x0ACE,
	0xFFFD: 0x0ACF,
	0xFFFD: 0x0AD0,
	0xFFFD: 0x0AD1,
	0xFFFD: 0x0AD2,
	0xFFFD: 0x0AD3,
	0xFFFD: 0x0AD4,
	0xFFFD: 0x0AD5,
	0xFFFD: 0x0AD6,
	0xFFFD: 0x0AD7,
	0xFFFD: 0x0AD8,
	0xFFFD: 0x0AD9,
	0xFFFD: 0x0ADA,
	0xFFFD: 0x0ADB,
	0xFFFD: 0x0ADC,
	0xFFFD: 0x0ADD,
	0xFFFD: 0x0ADE,
	0xFFFD: 0x0ADF,
	0xFFFD: 0x0AE0,
	0xFFFD: 0x0AE1,
	0xFFFD: 0x0AE2,
	0xFFFD: 0x0AE3,
	0xFFFD: 0x0AE4,
	0xFFFD: 0x0AE5,
	0xFFFD: 0x0AE6,
	0xFFFD: 0x0AE7,
	0xFFFD: 0x0AE8,
	0xFFFD: 0x0AE9,
	0xFFFD: 0x0AEA,
	0xFFFD: 0x0AEB,
	0xFFFD: 0x0AEC,
	0xFFFD: 0x0AED,
	0xFFFD: 0x0AEE,
	0xFFFD: 0x0AEF,
	0xFFFD: 0x0AF0,
	0xFFFD: 0x0AF1,
	0xFFFD: 0x0AF2,
	0xFFFD: 0x0AF3,
	0xFFFD: 0x0AF4,
	0xFFFD: 0x0AF5,
	0xFFFD: 0x0AF6,
	0xFFFD: 0x0AF7,
	0xFFFD: 0x0AF8,
	0xFFFD: 0x0AF9,
	0xFFFD: 0x0AFA,
	0xFFFD: 0x0AFB,
	0xFFFD: 0x0AFC,
	0xFFFD: 0x0AFD,
	0xFFFD: 0x0AFE,
	0xFFFD: 0x0AFF,
	0xFFFD: 0x0B00,
	0xFFFD: 0x0B01,
	0xFFFD: 0x0B02,
	0xFFFD: 0x0B03,
	0xFFFD: 0x0B04,
	0xFFFD: 0x0B05,
	0xFFFD: 0x0B06,
	0xFFFD: 0x0B07,
	0xFFFD: 0x0B08,
	0xFFFD: 0x0B09,
	0xFFFD: 0x0B0A,
	0xFFFD: 0x0B0B,
	0xFFFD: 0x0B0C,
	0xFFFD: 0x0B0D,
	0xFFFD: 0x0B0E,
	0xFFFD: 0x0B0F,
	0xFFFD: 0x0B10,
	0xFFFD: 0x0B11,
	0xFFFD: 0x0B12,
	0xFFFD: 0x0B13,
	0xFFFD: 0x0B14,
	0xFFFD: 0x0B15,
	0xFFFD: 0x0B16,
	0xFFFD: 0x0B17,
	0xFFFD: 0x0B18,
	0xFFFD: 0x0B19,
	0xFFFD: 0x0B1A,
	0xFFFD: 0x0B1B,
	0xFFFD: 0x0B1C,
	0xFFFD: 0x0B1D,
	0xFFFD: 0x0B1E,
	0xFFFD: 0x0B1F,
	0xFFFD: 0x0B20,
	0xFFFD: 0x0B21,
	0xFFFD: 0x0B22,
	0xFFFD: 0x0B23,
	0xFFFD: 0x0B24,
	0xFFFD: 0x0B25,
	0xFFFD: 0x0B26,
	0xFFFD: 0x0B27,
	0xFFFD: 0x0B28,
	0xFFFD: 0x0B29,
	0xFFFD: 0x0B2A,
	0xFFFD: 0x0B2B,
	0xFFFD: 0x0B2C,
	0xFFFD: 0x0B2D,
	0xFFFD: 0x0B2E,
	0xFFFD: 0x0B2F,
	0xFFFD: 0x0B30,
	0xFFFD: 0x0B31,
	0xFFFD: 0x0B32,
	0xFFFD: 0x0B33,
	0xFFFD: 0x0B34,
	0xFFFD: 0x0B35,
	0xFFFD: 0x0B36,
	0xFFFD: 0x0B37,
	0xFFFD: 0x0B38,
	0xFFFD: 0x0B39,
	0xFFFD: 0x0B3A,
	0xFFFD: 0x0B3B,
	0xFFFD: 0x0B3C,
	0xFFFD: 0x0B3D,
	0xFFFD: 0x0B3E,
	0xFFFD: 0x0B3F,
	0xFFFD: 0x0B40,
	0xFFFD: 0x0B41,
	0xFFFD: 0x0B42,
	0xFFFD: 0x0B43,
	0xFFFD: 0x0B44,
	0xFFFD: 0x0B45,
	0xFFFD: 0x0B46,
	0xFFFD: 0x0B47,
	0xFFFD: 0x0B48,
	0xFFFD: 0x0B49,
	0xFFFD: 0x0B4A,
	0xFFFD: 0x0B4B,
	0xFFFD: 0x0B4C,
	0xFFFD: 0x0B4D,
	0xFFFD: 0x0B4E,
	0xFFFD: 0x0B4F,
	0xFFFD: 0x0B50,
	0xFFFD: 0x0B51,
	0xFFFD: 0x0B52,
	0xFFFD: 0x0B53,
	0xFFFD: 0x0B54,
	0xFFFD: 0x0B55,
	0xFFFD: 0x0B56,
	0xFFFD: 0x0B57,
	0xFFFD: 0x0B58,
	0xFFFD: 0x0B59,
	0xFFFD: 0x0B5A,
	0xFFFD: 0x0B5B,
	0xFFFD: 0x0B5C,
	0xFFFD: 0x0B5D,
	0xFFFD: 0x0B5E,
	0xFFFD: 0x0B5F,
	0xFFFD: 0x0B60,
	0xFFFD: 0x0B61,
	0xFFFD: 0x0B62,
	0xFFFD: 0x0B63,
	0xFFFD: 0x0B64,
	0xFFFD: 0x0B65,
	0xFFFD: 0x0B66,
	0xFFFD: 0x0B67,
	0xFFFD: 0x0B68,
	0xFFFD: 0x0B69,
	0xFFFD: 0x0B6A,
	0xFFFD: 0x0B6B,
	0xFFFD: 0x0B6C,
	0xFFFD: 0x0B6D,
	0xFFFD: 0x0B6E,
	0xFFFD: 0x0B6F,
	0xFFFD: 0x0B70,
	0xFFFD: 0x0B71,
	0xFFFD: 0x0B72,
	0xFFFD: 0x0B73,
	0xFFFD: 0x0B74,
	0xFFFD: 0x0B75,
	0xFFFD: 0x0B76,
	0xFFFD: 0x0B77,
	0xFFFD: 0x0B78,
	0xFFFD: 0x0B79,
	0xFFFD: 0x0B7A,
	0xFFFD: 0x0B7B,
	0xFFFD: 0x0B7C,
	0xFFFD: 0x0B7D,
	0xFFFD: 0x0B7E,
	0xFFFD: 0x0B7F,
	0xFFFD: 0x0B80,
	0xFFFD: 0x0B81,
	0xFFFD: 0x0B82,
	0xFFFD: 0x0B83,
	0xFFFD: 0x0B84,
	0xFFFD: 0x0B85,
	0xFFFD: 0x0B86,
	0xFFFD: 0x0B87,
	0xFFFD: 0x0B88,
	0xFFFD: 0x0B89,
	0xFFFD: 0x0B8A,
	0xFFFD: 0x0B8B,
	0xFFFD: 0x0B8C,
	0xFFFD: 0x0B8D,
	0xFFFD: 0x0B8E,
	0xFFFD: 0x0B8F,
	0xFFFD: 0x0B90,
	0xFFFD: 0x0B91,
	0xFFFD: 0x0B92,
	0xFFFD: 0x0B93,
	0xFFFD: 0x0B94,
	0xFFFD: 0x0B95,
	0xFFFD: 0x0B96,
	0xFFFD: 0x0B97,
	0xFFFD: 0x0B98,
	0xFFFD: 0x0B99,
	0xFFFD: 0x0B9A,
	0xFFFD: 0x0B9B,
	0xFFFD: 0x0B9C,
	0xFFFD: 0x0B9D,
	0xFFFD: 0x0B9E,
	0xFFFD: 0x0B9F,
	0xFFFD: 0x0BA0,
	0xFFFD: 0x0BA1,
	0xFFFD: 0x0BA2,
	0xFFFD: 0x0BA3,
	0xFFFD: 0x0BA4,
	0xFFFD: 0x0BA5,
	0xFFFD: 0x0BA6,
	0xFFFD: 0x0BA7,
	0xFFFD: 0x0BA8,
	0xFFFD: 0x0BA9,
	0xFFFD: 0x0BAA,
	0xFFFD: 0x0BAB,
	0xFFFD: 0x0BAC,
	0xFFFD: 0x0BAD,
	0xFFFD: 0x0BAE,
	0xFFFD: 0x0BAF,
	0xFFFD: 0x0BB0,
	0xFFFD: 0x0BB1,
	0xFFFD: 0x0BB2,
	0xFFFD: 0x0BB3,
	0xFFFD: 0x0BB4,
	0xFFFD: 0x0BB5,
	0xFFFD: 0x0BB6,
	0xFFFD: 0x0BB7,
	0xFFFD: 0x0BB8,
	0xFFFD: 0x0BB9,
	0xFFFD: 0x0BBA,
	0xFFFD: 0x0BBB,
	0xFFFD: 0x0BBC,
	0xFFFD: 0x0BBD,
	0xFFFD: 0x0BBE,
	0xFFFD: 0x0BBF,
	0xFFFD: 0x0BC0,
	0xFFFD: 0x0BC1,
	0xFFFD: 0x0BC2,
	0xFFFD: 0x0BC3,
	0xFFFD: 0x0BC4,
	0xFFFD: 0x0BC5,
	0xFFFD: 0x0BC6,
	0xFFFD: 0x0BC7,
	0xFFFD: 0x0BC8,
	0xFFFD: 0x0BC9,
	0xFFFD: 0x0BCA,
	0xFFFD: 0x0BCB,
	0xFFFD: 0x0BCC,
	0xFFFD: 0x0BCD,
	0xFFFD: 0x0BCE,
	0xFFFD: 0x0BCF,
	0xFFFD: 0x0BD0,
	0xFFFD: 0x0BD1,
	0xFFFD: 0x0BD2,
	0xFFFD: 0x0BD3,
	0xFFFD: 0x0BD4,
	0xFFFD: 0x0BD5,
	0xFFFD: 0x0BD6,
	0xFFFD: 0x0BD7,
	0xFFFD: 0x0BD8,
	0xFFFD: 0x0BD9,
	0xFFFD: 0x0BDA,
	0xFFFD: 0x0BDB,
	0xFFFD: 0x0BDC,
	0xFFFD: 0x0BDD,
	0xFFFD: 0x0BDE,
	0xFFFD: 0x0BDF,
	0xFFFD: 0x0BE0,
	0xFFFD: 0x0BE1,
	0xFFFD: 0x0BE2,
	0xFFFD: 0x0BE3,
	0xFFFD: 0x0BE4,
	0xFFFD: 0x0BE5,
	0xFFFD: 0x0BE6,
	0xFFFD: 0x0BE7,
	0xFFFD: 0x0BE8,
	0xFFFD: 0x0BE9,
	0xFFFD: 0x0BEA,
	0xFFFD: 0x0BEB,
	0xFFFD: 0x0BEC,
	0xFFFD: 0x0BED,
	0xFFFD: 0x0BEE,
	0xFFFD: 0x0BEF,
	0xFFFD: 0x0BF0,
	0xFFFD: 0x0BF1,
	0xFFFD: 0x0BF2,
	0xFFFD: 0x0BF3,
	0xFFFD: 0x0BF4,
	0xFFFD: 0x0BF5,
	0xFFFD: 0x0BF6,
	0xFFFD: 0x0BF7,
	0xFFFD: 0x0BF8,
	0xFFFD: 0x0BF9,
	0xFFFD: 0x0BFA,
	0xFFFD: 0x0BFB,
	0xFFFD: 0x0BFC,
	0xFFFD: 0x0BFD,
	0xFFFD: 0x0BFE,
	0xFFFD: 0x0BFF,
	0xFFFD: 0x0C00,
	0xFFFD: 0x0C01,
	0xFFFD: 0x0C02,
	0xFFFD: 0x0C03,
	0xFFFD: 0x0C04,
	0xFFFD: 0x0C05,
	0xFFFD: 0x0C06,
	0xFFFD: 0x0C07,
	0xFFFD: 0x0C08,
	0xFFFD: 0x0C09,
	0xFFFD: 0x0C0A,
	0xFFFD: 0x0C0B,
	0xFFFD: 0x0C0C,
	0xFFFD: 0x0C0D,
	0xFFFD: 0x0C0E,
	0xFFFD: 0x0C0F,
	0xFFFD: 0x0C10,
	0xFFFD: 0x0C11,
	0xFFFD: 0x0C12,
	0xFFFD: 0x0C13,
	0xFFFD: 0x0C14,
	0xFFFD: 0x0C15,
	0xFFFD: 0x0C16,
	0xFFFD: 0x0C17,
	0xFFFD: 0x0C18,
	0xFFFD: 0x0C19,
	0xFFFD: 0x0C1A,
	0xFFFD: 0x0C1B,
	0xFFFD: 0x0C1C,
	0xFFFD: 0x0C1D,
	0xFFFD: 0x0C1E,
	0xFFFD: 0x0C1F,
	0xFFFD: 0x0C20,
	0xFFFD: 0x0C21,
	0xFFFD: 0x0C22,
	0xFFFD: 0x0C23,
	0xFFFD: 0x0C24,
	0xFFFD: 0x0C25,
	0xFFFD: 0x0C26,
	0xFFFD: 0x0C27,
	0xFFFD: 0x0C28,
	0xFFFD: 0x0C29,
	0xFFFD: 0x0C2A,
	0xFFFD: 0x0C2B,
	0xFFFD: 0x0C2C,
	0xFFFD: 0x0C2D,
	0xFFFD: 0x0C2E,
	0xFFFD: 0x0C2F,
	0xFFFD: 0x0C30,
	0xFFFD: 0x0C31,
	0xFFFD: 0x0C32,
	0xFFFD: 0x0C33,
	0xFFFD: 0x0C34,
	0xFFFD: 0x0C35,
	0xFFFD: 0x0C36,
	0xFFFD: 0x0C37,
	0xFFFD: 0x0C38,
	0xFFFD: 0x0C39,
	0xFFFD: 0x0C3A,
	0xFFFD: 0x0C3B,
	0xFFFD: 0x0C3C,
	0xFFFD: 0x0C3D,
	0xFFFD: 0x0C3E,
	0xFFFD: 0x0C3F,
	0xFFFD: 0x0C40,
	0xFFFD: 0x0C41,
	0xFFFD: 0x0C42,
	0xFFFD: 0x0C43,
	0xFFFD: 0x0C44,
	0xFFFD: 0x0C45,
	0xFFFD: 0x0C46,
	0xFFFD: 0x0C47,
	0xFFFD: 0x0C48,
	0xFFFD: 0x0C49,
	0xFFFD: 0x0C4A,
	0xFFFD: 0x0C4B,
	0xFFFD: 0x0C4C,
	0xFFFD: 0x0C4D,
	0xFFFD: 0x0C4E,
	0xFFFD: 0x0C4F,
	0xFFFD: 0x0C50,
	0xFFFD: 0x0C51,
	0xFFFD: 0x0C52,
	0xFFFD: 0x0C53,
	0xFFFD: 0x0C54,
	0xFFFD: 0x0C55,
	0xFFFD: 0x0C56,
	0xFFFD: 0x0C57,
	0xFFFD: 0x0C58,
	0xFFFD: 0x0C59,
	0xFFFD: 0x0C5A,
	0xFFFD: 0x0C5B,
	0xFFFD: 0x0C5C,
	0xFFFD: 0x0C5D,
	0xFFFD: 0x0C5E,
	0xFFFD: 0x0C5F,
	0xFFFD: 0x0C60,
	0xFFFD: 0x0C61,
	0xFFFD: 0x0C62,
	0xFFFD: 0x0C63,
	0xFFFD: 0x0C64,
	0xFFFD: 0x0C65,
	0xFFFD: 0x0C66,
	0xFFFD: 0x0C67,
	0xFFFD: 0x0C68,
	0xFFFD: 0x0C69,
	0xFFFD: 0x0C6A,
	0xFFFD: 0x0C6B,
	0xFFFD: 0x0C6C,
	0xFFFD: 0x0C6D,
	0xFFFD: 0x0C6E,
	0xFFFD: 0x0C6F,
	0xFFFD: 0x0C70,
	0xFFFD: 0x0C71,
	0xFFFD: 0x0C72,
	0xFFFD: 0x0C73,
	0xFFFD: 0x0C74,
	0xFFFD: 0x0C75,
	0xFFFD: 0x0C76,
	0xFFFD: 0x0C77,
	0xFFFD: 0x0C78,
	0xFFFD: 0x0C79,
	0xFFFD: 0x0C7A,
	0xFFFD: 0x0C7B,
	0xFFFD: 0x0C7C,
	0xFFFD: 0x0C7D,
	0xFFFD: 0x0C7E,
	0xFFFD: 0x0C7F,
	0xFFFD: 0x0C80,
	0xFFFD: 0x0C81,
	0xFFFD: 0x0C82,
	0xFFFD: 0x0C83,
	0xFFFD: 0x0C84,
	0xFFFD: 0x0C85,
	0xFFFD: 0x0C86,
	0xFFFD: 0x0C87,
	0xFFFD: 0x0C88,
	0xFFFD: 0x0C89,
	0xFFFD: 0x0C8A,
	0xFFFD: 0x0C8B,
	0xFFFD: 0x0C8C,
	0xFFFD: 0x0C8D,
	0xFFFD: 0x0C8E,
	0xFFFD: 0x0C8F,
	0xFFFD: 0x0C90,
	0xFFFD: 0x0C91,
	0xFFFD: 0x0C92,
	0xFFFD: 0x0C93,
	0xFFFD: 0x0C94,
	0xFFFD: 0x0C95,
	0xFFFD: 0x0C96,
	0xFFFD: 0x0C97,
	0xFFFD: 0x0C98,
	0xFFFD: 0x0C99,
	0xFFFD: 0x0C9A,
	0xFFFD: 0x0C9B,
	0xFFFD: 0x0C9C,
	0xFFFD: 0x0C9D,
	0xFFFD: 0x0C9E,
	0xFFFD: 0x0C9F,
	0xFFFD: 0x0CA0,
	0xFFFD: 0x0CA1,
	0xFFFD: 0x0CA2,
	0xFFFD: 0x0CA3,
	0xFFFD: 0x0CA4,
	0xFFFD: 0x0CA5,
	0xFFFD: 0x0CA6,
	0xFFFD: 0x0CA7,
	0xFFFD: 0x0CA8,
	0xFFFD: 0x0CA9,
	0xFFFD: 0x0CAA,
	0xFFFD: 0x0CAB,
	0xFFFD: 0x0CAC,
	0xFFFD: 0x0CAD,
	0xFFFD: 0x0CAE,
	0xFFFD: 0x0CAF,
	0xFFFD: 0x0CB0,
	0xFFFD: 0x0CB1,
	0xFFFD: 0x0CB2,
	0xFFFD: 0x0CB3,
	0xFFFD: 0x0CB4,
	0xFFFD: 0x0CB5,
	0xFFFD: 0x0CB6,
	0xFFFD: 0x0CB7,
	0xFFFD: 0x0CB8,
	0xFFFD: 0x0CB9,
	0xFFFD: 0x0CBA,
	0xFFFD: 0x0CBB,
	0xFFFD: 0x0CBC,
	0xFFFD: 0x0CBD,
	0xFFFD: 0x0CBE,
	0xFFFD: 0x0CBF,
	0xFFFD: 0x0CC0,
	0xFFFD: 0x0CC1,
	0xFFFD: 0x0CC2,
	0xFFFD: 0x0CC3,
	0xFFFD: 0x0CC4,
	0xFFFD: 0x0CC5,
	0xFFFD: 0x0CC6,
	0xFFFD: 0x0CC7,
	0xFFFD: 0x0CC8,
	0xFFFD: 0x0CC9,
	0xFFFD: 0x0CCA,
	0xFFFD: 0x0CCB,
	0xFFFD: 0x0CCC,
	0xFFFD: 0x0CCD,
	0xFFFD: 0x0CCE,
	0xFFFD: 0x0CCF,
	0xFFFD: 0x0CD0,
	0xFFFD: 0x0CD1,
	0xFFFD: 0x0CD2,
	0xFFFD: 0x0CD3,
	0xFFFD: 0x0CD4,
	0xFFFD: 0x0CD5,
	0xFFFD: 0x0CD6,
	0xFFFD: 0x0CD7,
	0xFFFD: 0x0CD8,
	0xFFFD: 0x0CD9,
	0xFFFD: 0x0CDA,
	0xFFFD: 0x0CDB,
	0xFFFD: 0x0CDC,
	0xFFFD: 0x0CDD,
	0xFFFD: 0x0CDE,
	0xFFFD: 0x0CDF,
	0xFFFD: 0x0CE0,
	0xFFFD: 0x0CE1,
	0xFFFD: 0x0CE2,
	0xFFFD: 0x0CE3,
	0xFFFD: 0x0CE4,
	0xFFFD: 0x0CE5,
	0xFFFD: 0x0CE6,
	0xFFFD: 0x0CE7,
	0xFFFD: 0x0CE8,
	0xFFFD: 0x0CE9,
	0xFFFD: 0x0CEA,
	0xFFFD: 0x0CEB,
	0xFFFD: 0x0CEC,
	0xFFFD: 0x0CED,
	0xFFFD: 0x0CEE,
	0xFFFD: 0x0CEF,
	0xFFFD: 0x0CF0,
	0xFFFD: 0x0CF1,
	0xFFFD: 0x0CF2,
	0xFFFD: 0x0CF3,
	0xFFFD: 0x0CF4,
	0xFFFD: 0x0CF5,
	0xFFFD: 0x0CF6,
	0xFFFD: 0x0CF7,
	0xFFFD: 0x0CF8,
	0xFFFD: 0x0CF9,
	0xFFFD: 0x0CFA,
	0xFFFD: 0x0CFB,
	0xFFFD: 0x0CFC,
	0xFFFD: 0x0CFD,
	0xFFFD: 0x0CFE,
	0xFFFD: 0x0CFF,
	0xFFFD: 0x0D00,
	0xFFFD: 0x0D01,
	0xFFFD: 0x0D02,
	0xFFFD: 0x0D03,
	0xFFFD: 0x0D04,
	0xFFFD: 0x0D05,
	0xFFFD: 0x0D06,
	0xFFFD: 0x0D07,
	0xFFFD: 0x0D08,
	0xFFFD: 0x0D09,
	0xFFFD: 0x0D0A,
	0xFFFD: 0x0D0B,
	0xFFFD: 0x0D0C,
	0xFFFD: 0x0D0D,
	0xFFFD: 0x0D0E,
	0xFFFD: 0x0D0F,
	0xFFFD: 0x0D10,
	0xFFFD: 0x0D11,
	0xFFFD: 0x0D12,
	0xFFFD: 0x0D13,
	0xFFFD: 0x0D14,
	0xFFFD: 0x0D15,
	0xFFFD: 0x0D16,
	0xFFFD: 0x0D17,
	0xFFFD: 0x0D18,
	0xFFFD: 0x0D19,
	0xFFFD: 0x0D1A,
	0xFFFD: 0x0D1B,
	0xFFFD: 0x0D1C,
	0xFFFD: 0x0D1D,
	0xFFFD: 0x0D1E,
	0xFFFD: 0x0D1F,
	0xFFFD: 0x0D20,
	0xFFFD: 0x0D21,
	0xFFFD: 0x0D22,
	0xFFFD: 0x0D23,
	0xFFFD: 0x0D24,
	0xFFFD: 0x0D25,
	0xFFFD: 0x0D26,
	0xFFFD: 0x0D27,
	0xFFFD: 0x0D28,
	0xFFFD: 0x0D29,
	0xFFFD: 0x0D2A,
	0xFFFD: 0x0D2B,
	0xFFFD: 0x0D2C,
	0xFFFD: 0x0D2D,
	0xFFFD: 0x0D2E,
	0xFFFD: 0x0D2F,
	0xFFFD: 0x0D30,
	0xFFFD: 0x0D31,
	0xFFFD: 0x0D32,
	0xFFFD: 0x0D33,
	0xFFFD: 0x0D34,
	0xFFFD: 0x0D35,
	0xFFFD: 0x0D36,
	0xFFFD: 0x0D37,
	0xFFFD: 0x0D38,
	0xFFFD: 0x0D39,
	0xFFFD: 0x0D3A,
	0xFFFD: 0x0D3B,
	0xFFFD: 0x0D3C,
	0xFFFD: 0x0D3D,
	0xFFFD: 0x0D3E,
	0xFFFD: 0x0D3F,
	0xFFFD: 0x0D40,
	0xFFFD: 0x0D41,
	0xFFFD: 0x0D42,
	0xFFFD: 0x0D43,
	0xFFFD: 0x0D44,
	0xFFFD: 0x0D45,
	0xFFFD: 0x0D46,
	0xFFFD: 0x0D47,
	0xFFFD: 0x0D48,
	0xFFFD: 0x0D49,
	0xFFFD: 0x0D4A,
	0xFFFD: 0x0D4B,
	0xFFFD: 0x0D4C,
	0xFFFD: 0x0D4D,
	0xFFFD: 0x0D4E,
	0xFFFD: 0x0D4F,
	0xFFFD: 0x0D50,
	0xFFFD: 0x0D51,
	0xFFFD: 0x0D52,
	0xFFFD: 0x0D53,
	0xFFFD: 0x0D54,
	0xFFFD: 0x0D55,
	0xFFFD: 0x0D56,
	0xFFFD: 0x0D57,
	0xFFFD: 0x0D58,
	0xFFFD: 0x0D59,
	0xFFFD: 0x0D5A,
	0xFFFD: 0x0D5B,
	0xFFFD: 0x0D5C,
	0xFFFD: 0x0D5D,
	0xFFFD: 0x0D5E,
	0xFFFD: 0x0D5F,
	0xFFFD: 0x0D60,
	0xFFFD: 0x0D61,
	0xFFFD: 0x0D62,
	0xFFFD: 0x0D63,
	0xFFFD: 0x0D64,
	0xFFFD: 0x0D65,
	0xFFFD: 0x0D66,
	0xFFFD: 0x0D67,
	0xFFFD: 0x0D68,
	0xFFFD: 0x0D69,
	0xFFFD: 0x0D6A,
	0xFFFD: 0x0D6B,
	0xFFFD: 0x0D6C,
	0xFFFD: 0x0D6D,
	0xFFFD: 0x0D6E,
	0xFFFD: 0x0D6F,
	0xFFFD: 0x0D70,
	0xFFFD: 0x0D71,
	0xFFFD: 0x0D72,
	0xFFFD: 0x0D73,
	0xFFFD: 0x0D74,
	0xFFFD: 0x0D75,
	0xFFFD: 0x0D76,
	0xFFFD: 0x0D77,
	0xFFFD: 0x0D78,
	0xFFFD: 0x0D79,
	0xFFFD: 0x0D7A,
	0xFFFD: 0x0D7B,
	0xFFFD: 0x0D7C,
	0xFFFD: 0x0D7D,
	0xFFFD: 0x0D7E,
	0xFFFD: 0x0D7F,
	0xFFFD: 0x0D80,
	0xFFFD: 0x0D81,
	0xFFFD: 0x0D82,
	0xFFFD: 0x0D83,
	0xFFFD: 0x0D84,
	0xFFFD: 0x0D85,
	0xFFFD: 0x0D86,
	0xFFFD: 0x0D87,
	0xFFFD: 0x0D88,
	0xFFFD: 0x0D89,
	0xFFFD: 0x0D8A,
	0xFFFD: 0x0D8B,
	0xFFFD: 0x0D8C,
	0xFFFD: 0x0D8D,
	0xFFFD: 0x0D8E,
	0xFFFD: 0x0D8F,
	0xFFFD: 0x0D90,
	0xFFFD: 0x0D91,
	0xFFFD: 0x0D92,
	0xFFFD: 0x0D93,
	0xFFFD: 0x0D94,
	0xFFFD: 0x0D95,
	0xFFFD: 0x0D96,
	0xFFFD: 0x0D97,
	0xFFFD: 0x0D98,
	0xFFFD: 0x0D99,
	0xFFFD: 0x0D9A,
	0xFFFD: 0x0D9B,
	0xFFFD: 0x0D9C,
	0xFFFD: 0x0D9D,
	0xFFFD: 0x0D9E,
	0xFFFD: 0x0D9F,
	0xFFFD: 0x0DA0,
	0xFFFD: 0x0DA1,
	0xFFFD: 0x0DA2,
	0xFFFD: 0x0DA3,
	0xFFFD: 0x0DA4,
	0xFFFD: 0x0DA5,
	0xFFFD: 0x0DA6,
	0xFFFD: 0x0DA7,
	0xFFFD: 0x0DA8,
	0xFFFD: 0x0DA9,
	0xFFFD: 0x0DAA,
	0xFFFD: 0x0DAB,
	0xFFFD: 0x0DAC,
	0xFFFD: 0x0DAD,
	0xFFFD: 0x0DAE,
	0xFFFD: 0x0DAF,
	0xFFFD: 0x0DB0,
	0xFFFD: 0x0DB1,
	0xFFFD: 0x0DB2,
	0xFFFD: 0x0DB3,
	0xFFFD: 0x0DB4,
	0xFFFD: 0x0DB5,
	0xFFFD: 0x0DB6,
	0xFFFD: 0x0DB7,
	0xFFFD: 0x0DB8,
	0xFFFD: 0x0DB9,
	0xFFFD: 0x0DBA,
	0xFFFD: 0x0DBB,
	0xFFFD: 0x0DBC,
	0xFFFD: 0x0DBD,
	0xFFFD: 0x0DBE,
	0xFFFD: 0x0DBF,
	0xFFFD: 0x0DC0,
	0xFFFD: 0x0DC1,
	0xFFFD: 0x0DC2,
	0xFFFD: 0x0DC3,
	0xFFFD: 0x0DC4,
	0xFFFD: 0x0DC5,
	0xFFFD: 0x0DC6,
	0xFFFD: 0x0DC7,
	0xFFFD: 0x0DC8,
	0xFFFD: 0x0DC9,
	0xFFFD: 0x0DCA,
	0xFFFD: 0x0DCB,
	0xFFFD: 0x0DCC,
	0xFFFD: 0x0DCD,
	0xFFFD: 0x0DCE,
	0xFFFD: 0x0DCF,
	0xFFFD: 0x0DD0,
	0xFFFD: 0x0DD1,
	0xFFFD: 0x0DD2,
	0xFFFD: 0x0DD3,
	0xFFFD: 0x0DD4,
	0xFFFD: 0x0DD5,
	0xFFFD: 0x0DD6,
	0xFFFD: 0x0DD7,
	0xFFFD: 0x0DD8,
	0xFFFD: 0x0DD9,
	0xFFFD: 0x0DDA,
	0xFFFD: 0x0DDB,
	0xFFFD: 0x0DDC,
	0xFFFD: 0x0DDD,
	0xFFFD: 0x0DDE,
	0xFFFD: 0x0DDF,
	0xFFFD: 0x0DE0,
	0xFFFD: 0x0DE1,
	0xFFFD: 0x0DE2,
	0xFFFD: 0x0DE3,
	0xFFFD: 0x0DE4,
	0xFFFD: 0x0DE5,
	0xFFFD: 0x0DE6,
	0xFFFD: 0x0DE7,
	0xFFFD: 0x0DE8,
	0xFFFD: 0x0DE9,
	0xFFFD: 0x0DEA,
	0xFFFD: 0x0DEB,
	0xFFFD: 0x0DEC,
	0xFFFD: 0x0DED,
	0xFFFD: 0x0DEE,
	0xFFFD: 0x0DEF,
	0xFFFD: 0x0DF0,
	0xFFFD: 0x0DF1,
	0xFFFD: 0x0DF2,
	0xFFFD: 0x0DF3,
	0xFFFD: 0x0DF4,
	0xFFFD: 0x0DF5,
	0xFFFD: 0x0DF6,
	0xFFFD: 0x0DF7,
	0xFFFD: 0x0DF8,
	0xFFFD: 0x0DF9,
	0xFFFD: 0x0DFA,
	0xFFFD: 0x0DFB,
	0xFFFD: 0x0DFC,
	0xFFFD: 0x0DFD,
	0xFFFD: 0x0DFE,
	0xFFFD: 0x0DFF,
	0xFFFD: 0x0E00,
	0xFFFD: 0x0E01,
	0xFFFD: 0x0E02,
	0xFFFD: 0x0E03,
	0xFFFD: 0x0E04,
	0xFFFD: 0x0E05,
	0xFFFD: 0x0E06,
	0xFFFD: 0x0E07,
	0xFFFD: 0x0E08,
	0xFFFD: 0x0E09,
	0xFFFD: 0x0E0A,
	0xFFFD: 0x0E0B,
	0xFFFD: 0x0E0C,
	0xFFFD: 0x0E0D,
	0xFFFD: 0x0E0E,
	0xFFFD: 0x0E0F,
	0xFFFD: 0x0E10,
	0xFFFD: 0x0E11,
	0xFFFD: 0x0E12,
	0xFFFD: 0x0E13,
	0xFFFD: 0x0E14,
	0xFFFD: 0x0E15,
	0xFFFD: 0x0E16,
	0xFFFD: 0x0E17,
	0xFFFD: 0x0E18,
	0xFFFD: 0x0E19,
	0xFFFD: 0x0E1A,
	0xFFFD: 0x0E1B,
	0xFFFD: 0x0E1C,
	0xFFFD: 0x0E1D,
	0xFFFD: 0x0E1E,
	0xFFFD: 0x0E1F,
	0xFFFD: 0x0E20,
	0xFFFD: 0x0E21,
	0xFFFD: 0x0E22,
	0xFFFD: 0x0E23,
	0xFFFD: 0x0E24,
	0xFFFD: 0x0E25,
	0xFFFD: 0x0E26,
	0xFFFD: 0x0E27,
	0xFFFD: 0x0E28,
	0xFFFD: 0x0E29,
	0xFFFD: 0x0E2A,
	0xFFFD: 0x0E2B,
	0xFFFD: 0x0E2C,
	0xFFFD: 0x0E2D,
	0xFFFD: 0x0E2E,
	0xFFFD: 0x0E2F,
	0xFFFD: 0x0E30,
	0xFFFD: 0x0E31,
	0xFFFD: 0x0E32,
	0xFFFD: 0x0E33,
	0xFFFD: 0x0E34,
	0xFFFD: 0x0E35,
	0xFFFD: 0x0E36,
	0xFFFD: 0x0E37,
	0xFFFD: 0x0E38,
	0xFFFD: 0x0E39,
	0xFFFD: 0x0E3A,
	0xFFFD: 0x0E3B,
	0xFFFD: 0x0E3C,
	0xFFFD: 0x0E3D,
	0xFFFD: 0x0E3E,
	0xFFFD: 0x0E3F,
	0xFFFD: 0x0E40,
	0xFFFD: 0x0E41,
	0xFFFD: 0x0E42,
	0xFFFD: 0x0E43,
	0xFFFD: 0x0E44,
	0xFFFD: 0x0E45,
	0xFFFD: 0x0E46,
	0xFFFD: 0x0E47,
	0xFFFD: 0x0E48,
	0xFFFD: 0x0E49,
	0xFFFD: 0x0E4A,
	0xFFFD: 0x0E4B,
	0xFFFD: 0x0E4C,
	0xFFFD: 0x0E4D,
	0xFFFD: 0x0E4E,
	0xFFFD: 0x0E4F,
	0xFFFD: 0x0E50,
	0xFFFD: 0x0E51,
	0xFFFD: 0x0E52,
	0xFFFD: 0x0E53,
	0xFFFD: 0x0E54,
	0xFFFD: 0x0E55,
	0xFFFD: 0x0E56,
	0xFFFD: 0x0E57,
	0xFFFD: 0x0E58,
	0xFFFD: 0x0E59,
	0xFFFD: 0x0E5A,
	0xFFFD: 0x0E5B,
	0xFFFD: 0x0E5C,
	0xFFFD: 0x0E5D,
	0xFFFD: 0x0E5E,
	0xFFFD: 0x0E5F,
	0xFFFD: 0x0E60,
	0xFFFD: 0x0E61,
	0xFFFD: 0x0E62,
	0xFFFD: 0x0E63,
	0xFFFD: 0x0E64,
	0xFFFD: 0x0E65,
	0xFFFD: 0x0E66,
	0xFFFD: 0x0E67,
	0xFFFD: 0x0E68,
	0xFFFD: 0x0E69,
	0xFFFD: 0x0E6A,
	0xFFFD: 0x0E6B,
	0xFFFD: 0x0E6C,
	0xFFFD: 0x0E6D,
	0xFFFD: 0x0E6E,
	0xFFFD: 0x0E6F,
	0xFFFD: 0x0E70,
	0xFFFD: 0x0E71,
	0xFFFD: 0x0E72,
	0xFFFD: 0x0E73,
	0xFFFD: 0x0E74,
	0xFFFD: 0x0E75,
	0xFFFD: 0x0E76,
	0xFFFD: 0x0E77,
	0xFFFD: 0x0E78,
	0xFFFD: 0x0E79,
	0xFFFD: 0x0E7A,
	0xFFFD: 0x0E7B,
	0xFFFD: 0x0E7C,
	0xFFFD: 0x0E7D,
	0xFFFD: 0x0E7E,
	0xFFFD: 0x0E7F,
	0xFFFD: 0x0E80,
	0xFFFD: 0x0E81,
	0xFFFD: 0x0E82,
	0xFFFD: 0x0E83,
	0xFFFD: 0x0E84,
	0xFFFD: 0x0E85,
	0xFFFD: 0x0E86,
	0xFFFD: 0x0E87,
	0xFFFD: 0x0E88,
	0xFFFD: 0x0E89,
	0xFFFD: 0x0E8A,
	0xFFFD: 0x0E8B,
	0xFFFD: 0x0E8C,
	0xFFFD: 0x0E8D,
	0xFFFD: 0x0E8E,
	0xFFFD: 0x0E8F,
	0xFFFD: 0x0E90,
	0xFFFD: 0x0E91,
	0xFFFD: 0x0E92,
	0xFFFD: 0x0E93,
	0xFFFD: 0x0E94,
	0xFFFD: 0x0E95,
	0xFFFD: 0x0E96,
	0xFFFD: 0x0E97,
	0xFFFD: 0x0E98,
	0xFFFD: 0x0E99,
	0xFFFD: 0x0E9A,
	0xFFFD: 0x0E9B,
	0xFFFD: 0x0E9C,
	0xFFFD: 0x0E9D,
	0xFFFD: 0x0E9E,
	0xFFFD: 0x0E9F,
	0xFFFD: 0x0EA0,
	0xFFFD: 0x0EA1,
	0xFFFD: 0x0EA2,
	0xFFFD: 0x0EA3,
	0xFFFD: 0x0EA4,
	0xFFFD: 0x0EA5,
	0xFFFD: 0x0EA6,
	0xFFFD: 0x0EA7,
	0xFFFD: 0x0EA8,
	0xFFFD: 0x0EA9,
	0xFFFD: 0x0EAA,
	0xFFFD: 0x0EAB,
	0xFFFD: 0x0EAC,
	0xFFFD: 0x0EAD,
	0xFFFD: 0x0EAE,
	0xFFFD: 0x0EAF,
	0xFFFD: 0x0EB0,
	0xFFFD: 0x0EB1,
	0xFFFD: 0x0EB2,
	0xFFFD: 0x0EB3,
	0xFFFD: 0x0EB4,
	0xFFFD: 0x0EB5,
	0xFFFD: 0x0EB6,
	0xFFFD: 0x0EB7,
	0xFFFD: 0x0EB8,
	0xFFFD: 0x0EB9,
	0xFFFD: 0x0EBA,
	0xFFFD: 0x0EBB,
	0xFFFD: 0x0EBC,
	0xFFFD: 0x0EBD,
	0xFFFD: 0x0EBE,
	0xFFFD: 0x0EBF,
	0xFFFD: 0x0EC0,
	0xFFFD: 0x0EC1,
	0xFFFD: 0x0EC2,
	0xFFFD: 0x0EC3,
	0xFFFD: 0x0EC4,
	0xFFFD: 0x0EC5,
	0xFFFD: 0x0EC6,
	0xFFFD: 0x0EC7,
	0xFFFD: 0x0EC8,
	0xFFFD: 0x0EC9,
	0xFFFD: 0x0ECA,
	0xFFFD: 0x0ECB,
	0xFFFD: 0x0ECC,
	0xFFFD: 0x0ECD,
	0xFFFD: 0x0ECE,
	0xFFFD: 0x0ECF,
	0xFFFD: 0x0ED0,
	0xFFFD: 0x0ED1,
	0xFFFD: 0x0ED2,
	0xFFFD: 0x0ED3,
	0xFFFD: 0x0ED4,
	0xFFFD: 0x0ED5,
	0xFFFD: 0x0ED6,
	0xFFFD: 0x0ED7,
	0xFFFD: 0x0ED8,
	0xFFFD: 0x0ED9,
	0xFFFD: 0x0EDA,
	0xFFFD: 0x0EDB,
	0xFFFD: 0x0EDC,
	0xFFFD: 0x0EDD,
	0xFFFD: 0x0EDE,
	0xFFFD: 0x0EDF,
	0xFFFD: 0x0EE0,
	0xFFFD: 0x0EE1,
	0xFFFD: 0x0EE2,
	0xFFFD: 0x0EE3,
	0xFFFD: 0x0EE4,
	0xFFFD: 0x0EE5,
	0xFFFD: 0x0EE6,
	0xFFFD: 0x0EE7,
	0xFFFD: 0x0EE8,
	0xFFFD: 0x0EE9,
	0xFFFD: 0x0EEA,
	0xFFFD: 0x0EEB,
	0xFFFD: 0x0EEC,
	0xFFFD: 0x0EED,
	0xFFFD: 0x0EEE,
	0xFFFD: 0x0EEF,
	0xFFFD: 0x0EF0,
	0xFFFD: 0x0EF1,
	0xFFFD: 0x0EF2,
	0xFFFD: 0x0EF3,
	0xFFFD: 0x0EF4,
	0xFFFD: 0x0EF5,
	0xFFFD: 0x0EF6,
	0xFFFD: 0x0EF7,
	0xFFFD: 0x0EF8,
	0xFFFD: 0x0EF9,
	0xFFFD: 0x0EFA,
	0xFFFD: 0x0EFB,
	0xFFFD: 0x0EFC,
	0xFFFD: 0x0EFD,
	0xFFFD: 0x0EFE,
	0xFFFD: 0x0EFF,
	0xFFFD: 0x0F00,
	0xFFFD: 0x0F01,
	0xFFFD: 0x0F02,
	0xFFFD: 0x0F03,
	0xFFFD: 0x0F04,
	0xFFFD: 0x0F05,
	0xFFFD: 0x0F06,
	0xFFFD: 0x0F07,
	0xFFFD: 0x0F08,
	0xFFFD: 0x0F09,
	0xFFFD: 0x0F0A,
	0xFFFD: 0x0F0B,
	0xFFFD: 0x0F0C,
	0xFFFD: 0x0F0D,
	0xFFFD: 0x0F0E,
	0xFFFD: 0x0F0F,
	0xFFFD: 0x0F10,
	0xFFFD: 0x0F11,
	0xFFFD: 0x0F12,
	0xFFFD: 0x0F13,
	0xFFFD: 0x0F14,
	0xFFFD: 0x0F15,
	0xFFFD: 0x0F16,
	0xFFFD: 0x0F17,
	0xFFFD: 0x0F18,
	0xFFFD: 0x0F19,
	0xFFFD: 0x0F1A,
	0xFFFD: 0x0F1B,
	0xFFFD: 0x0F1C,
	0xFFFD: 0x0F1D,
	0xFFFD: 0x0F1E,
	0xFFFD: 0x0F1F,
	0xFFFD: 0x0F20,
	0xFFFD: 0x0F21,
	0xFFFD: 0x0F22,
	0xFFFD: 0x0F23,
	0xFFFD: 0x0F24,
	0xFFFD: 0x0F25,
	0xFFFD: 0x0F26,
	0xFFFD: 0x0F27,
	0xFFFD: 0x0F28,
	0xFFFD: 0x0F29,
	0xFFFD: 0x0F2A,
	0xFFFD: 0x0F2B,
	0xFFFD: 0x0F2C,
	0xFFFD: 0x0F2D,
	0xFFFD: 0x0F2E,
	0xFFFD: 0x0F2F,
	0xFFFD: 0x0F30,
	0xFFFD: 0x0F31,
	0xFFFD: 0x0F32,
	0xFFFD: 0x0F33,
	0xFFFD: 0x0F34,
	0xFFFD: 0x0F35,
	0xFFFD: 0x0F36,
	0xFFFD: 0x0F37,
	0xFFFD: 0x0F38,
	0xFFFD: 0x0F39,
	0xFFFD: 0x0F3A,
	0xFFFD: 0x0F3B,
	0xFFFD: 0x0F3C,
	0xFFFD: 0x0F3D,
	0xFFFD: 0x0F3E,
	0xFFFD: 0x0F3F,
	0xFFFD: 0x0F40,
	0xFFFD: 0x0F41,
	0xFFFD: 0x0F42,
	0xFFFD: 0x0F43,
	0xFFFD: 0x0F44,
	0xFFFD: 0x0F45,
	0xFFFD: 0x0F46,
	0xFFFD: 0x0F47,
	0xFFFD: 0x0F48,
	0xFFFD: 0x0F49,
	0xFFFD: 0x0F4A,
	0xFFFD: 0x0F4B,
	0xFFFD: 0x0F4C,
	0xFFFD: 0x0F4D,
	0xFFFD: 0x0F4E,
	0xFFFD: 0x0F4F,
	0xFFFD: 0x0F50,
	0xFFFD: 0x0F51,
	0xFFFD: 0x0F52,
	0xFFFD: 0x0F53,
	0xFFFD: 0x0F54,
	0xFFFD: 0x0F55,
	0xFFFD: 0x0F56,
	0xFFFD: 0x0F57,
	0xFFFD: 0x0F58,
	0xFFFD: 0x0F59,
	0xFFFD: 0x0F5A,
	0xFFFD: 0x0F5B,
	0xFFFD: 0x0F5C,
	0xFFFD: 0x0F5D,
	0xFFFD: 0x0F5E,
	0xFFFD: 0x0F5F,
	0xFFFD: 0x0F60,
	0xFFFD: 0x0F61,
	0xFFFD: 0x0F62,
	0xFFFD: 0x0F63,
	0xFFFD: 0x0F64,
	0xFFFD: 0x0F65,
	0xFFFD: 0x0F66,
	0xFFFD: 0x0F67,
	0xFFFD: 0x0F68,
	0xFFFD: 0x0F69,
	0xFFFD: 0x0F6A,
	0xFFFD: 0x0F6B,
	0xFFFD: 0x0F6C,
	0xFFFD: 0x0F6D,
	0xFFFD: 0x0F6E,
	0xFFFD: 0x0F6F,
	0xFFFD: 0x0F70,
	0xFFFD: 0x0F71,
	0xFFFD: 0x0F72,
	0xFFFD: 0x0F73,
	0xFFFD: 0x0F74,
	0xFFFD: 0x0F75,
	0xFFFD: 0x0F76,
	0xFFFD: 0x0F77,
	0xFFFD: 0x0F78,
	0xFFFD: 0x0F79,
	0xFFFD: 0x0F7A,
	0xFFFD: 0x0F7B,
	0xFFFD: 0x0F7C,
	0xFFFD: 0x0F7D,
	0xFFFD: 0x0F7E,
	0xFFFD: 0x0F7F,
	0xFFFD: 0x0F80,
	0xFFFD: 0x0F81,
	0xFFFD: 0x0F82,
	0xFFFD: 0x0F83,
	0xFFFD: 0x0F84,
	0xFFFD: 0x0F85,
	0xFFFD: 0x0F86,
	0xFFFD: 0x0F87,
	0xFFFD: 0x0F88,
	0xFFFD: 0x0F89,
	0xFFFD: 0x0F8A,
	0xFFFD: 0x0F8B,
	0xFFFD: 0x0F8C,
	0xFFFD: 0x0F8D,
	0xFFFD: 0x0F8E,
	0xFFFD: 0x0F8F,
	0xFFFD: 0x0F90,
	0xFFFD: 0x0F91,
	0xFFFD: 0x0F92,
	0xFFFD: 0x0F93,
	0xFFFD: 0x0F94,
	0xFFFD: 0x0F95,
	0xFFFD: 0x0F96,
	0xFFFD: 0x0F97,
	0xFFFD: 0x0F98,
	0xFFFD: 0x0F99,
	0xFFFD: 0x0F9A,
	0xFFFD: 0x0F9B,
	0xFFFD: 0x0F9C,
	0xFFFD: 0x0F9D,
	0xFFFD: 0x0F9E,
	0xFFFD: 0x0F9F,
	0xFFFD: 0x0FA0,
	0xFFFD: 0x0FA1,
	0xFFFD: 0x0FA2,
	0xFFFD: 0x0FA3,
	0xFFFD: 0x0FA4,
	0xFFFD: 0x0FA5,
	0xFFFD: 0x0FA6,
	0xFFFD: 0x0FA7,
	0xFFFD: 0x0FA8,
	0xFFFD: 0x0FA9,
	0xFFFD: 0x0FAA,
	0xFFFD: 0x0FAB,
	0xFFFD: 0x0FAC,
	0xFFFD: 0x0FAD,
	0xFFFD: 0x0FAE,
	0xFFFD: 0x0FAF,
	0xFFFD: 0x0FB0,
	0xFFFD: 0x0FB1,
	0xFFFD: 0x0FB2,
	0xFFFD: 0x0FB3,
	0xFFFD: 0x0FB4,
	0xFFFD: 0x0FB5,
	0xFFFD: 0x0FB6,
	0xFFFD: 0x0FB7,
	0xFFFD: 0x0FB8,
	0xFFFD: 0x0FB9,
	0xFFFD: 0x0FBA,
	0xFFFD: 0x0FBB,
	0xFFFD: 0x0FBC,
	0xFFFD: 0x0FBD,
	0xFFFD: 0x0FBE,
	0xFFFD: 0x0FBF,
	0xFFFD: 0x0FC0,
	0xFFFD: 0x0FC1,
	0xFFFD: 0x0FC2,
	0xFFFD: 0x0FC3,
	0xFFFD: 0x0FC4,
	0xFFFD: 0x0FC5,
	0xFFFD: 0x0FC6,
	0xFFFD: 0x0FC7,
	0xFFFD: 0x0FC8,
	0xFFFD: 0x0FC9,
	0xFFFD: 0x0FCA,
	0xFFFD: 0x0FCB,
	0xFFFD: 0x0FCC,
	0xFFFD: 0x0FCD,
	0xFFFD: 0x0FCE,
	0xFFFD: 0x0FCF,
	0xFFFD: 0x0FD0,
	0xFFFD: 0x0FD1,
	0xFFFD: 0x0FD2,
	0xFFFD: 0x0FD3,
	0xFFFD: 0x0FD4,
	0xFFFD: 0x0FD5,
	0xFFFD: 0x0FD6,
	0xFFFD: 0x0FD7,
	0xFFFD: 0x0FD8,
	0xFFFD: 0x0FD9,
	0xFFFD: 0x0FDA,
	0xFFFD: 0x0FDB,
	0xFFFD: 0x0FDC,
	0xFFFD: 0x0FDD,
	0xFFFD: 0x0FDE,
	0xFFFD: 0x0FDF,
	0xFFFD: 0x0FE0,
	0xFFFD: 0x0FE1,
	0xFFFD: 0x0FE2,
	0xFFFD: 0x0FE3,
	0xFFFD: 0x0FE4,
	0xFFFD: 0x0FE5,
	0xFFFD: 0x0FE6,
	0xFFFD: 0x0FE7,
	0xFFFD: 0x0FE8,
	0xFFFD: 0x0FE9,
	0xFFFD: 0x0FEA,
	0xFFFD: 0x0FEB,
	0xFFFD: 0x0FEC,
	0xFFFD: 0x0FED,
	0xFFFD: 0x0FEE,
	0xFFFD: 0x0FEF,
	0xFFFD: 0x0FF0,
	0xFFFD: 0x0FF1,
	0xFFFD: 0x0FF2,
	0xFFFD: 0x0FF3,
	0xFFFD: 0x0FF4,
	0xFFFD: 0x0FF5,
	0xFFFD: 0x0FF6,
	0xFFFD: 0x0FF7,
	0xFFFD: 0x0FF8,
	0xFFFD: 0x0FF9,
	0xFFFD: 0x0FFA,
	0xFFFD: 0x0FFB,
	0xFFFD: 0x0FFC,
	0xFFFD: 0x0FFD,
	0xFFFD: 0x0FFE,
	0xFFFD: 0x0FFF,
	0xFFFD: 0x1000,
	0xFFFD: 0x1001,
	0xFFFD: 0x1002,
	0xFFFD: 0x1003,
	0xFFFD: 0x1004,
	0xFFFD: 0x1005,
	0xFFFD: 0x1006,
	0xFFFD: 0x1007,
	0xFFFD: 0x1008,
	0xFFFD: 0x1009,
	0xFFFD: 0x100A,
	0xFFFD: 0x100B,
	0xFFFD: 0x100C,
	0xFFFD: 0x100D,
	0xFFFD: 0x100E,
	0xFFFD: 0x100F,
	0xFFFD: 0x1010,
	0xFFFD: 0x1011,
	0xFFFD: 0x1012,
	0xFFFD: 0x1013,
	0xFFFD: 0x1014,
	0xFFFD: 0x1015,
	0xFFFD: 0x1016,
	0xFFFD: 0x1017,
	0xFFFD: 0x1018,
	0xFFFD: 0x1019,
	0xFFFD: 0x101A,
	0xFFFD: 0x101B,
	0xFFFD: 0x101C,
	0xFFFD: 0x101D,
	0xFFFD: 0x101E,
	0xFFFD: 0x101F,
	0xFFFD: 0x1020,
	0xFFFD: 0x1021,
	0xFFFD: 0x1022,
	0xFFFD: 0x1023,
	0xFFFD: 0x1024,
	0xFFFD: 0x1025,
	0xFFFD: 0x1026,
	0xFFFD: 0x1027,
	0xFFFD: 0x1028,
	0xFFFD: 0x1029,
	0xFFFD: 0x102A,
	0xFFFD: 0x102B,
	0xFFFD: 0x102C,
	0xFFFD: 0x102D,
	0xFFFD: 0x102E,
	0xFFFD: 0x102F,
	0xFFFD: 0x1030,
	0xFFFD: 0x1031,
	0xFFFD: 0x1032,
	0xFFFD: 0x1033,
	0xFFFD: 0x1034,
	0xFFFD: 0x1035,
	0xFFFD: 0x1036,
	0xFFFD: 0x1037,
	0xFFFD: 0x1038,
	0xFFFD: 0x1039,
	0xFFFD: 0x103A,
	0xFFFD: 0x103B,
	0xFFFD: 0x103C,
	0xFFFD: 0x103D,
	0xFFFD: 0x103E,
	0xFFFD: 0x103F,
	0xFFFD: 0x1040,
	0xFFFD: 0x1041,
	0xFFFD: 0x1042,
	0xFFFD: 0x1043,
	0xFFFD: 0x1044,
	0xFFFD: 0x1045,
	0xFFFD: 0x1046,
	0xFFFD: 0x1047,
	0xFFFD: 0x1048,
	0xFFFD: 0x1049,
	0xFFFD: 0x104A,
	0xFFFD: 0x104B,
	0xFFFD: 0x104C,
	0xFFFD: 0x104D,
	0xFFFD: 0x104E,
	0xFFFD: 0x104F,
	0xFFFD: 0x1050,
	0xFFFD: 0x1051,
	0xFFFD: 0x1052,
	0xFFFD: 0x1053,
	0xFFFD: 0x1054,
	0xFFFD: 0x1055,
	0xFFFD: 0x1056,
	0xFFFD: 0x1057,
	0xFFFD: 0x1058,
	0xFFFD: 0x1059,
	0xFFFD: 0x105A,
	0xFFFD: 0x105B,
	0xFFFD: 0x105C,
	0xFFFD: 0x105D,
	0xFFFD: 0x105E,
	0xFFFD: 0x105F,
	0xFFFD: 0x1060,
	0xFFFD: 0x1061,
	0xFFFD: 0x1062,
	0xFFFD: 0x1063,
	0xFFFD: 0x1064,
	0xFFFD: 0x1065,
	0xFFFD: 0x1066,
	0xFFFD: 0x1067,
	0xFFFD: 0x1068,
	0xFFFD: 0x1069,
	0xFFFD: 0x106A,
	0xFFFD: 0x106B,
	0xFFFD: 0x106C,
	0xFFFD: 0x106D,
	0xFFFD: 0x106E,
	0xFFFD: 0x106F,
	0xFFFD: 0x1070,
	0xFFFD: 0x1071,
	0xFFFD: 0x1072,
	0xFFFD: 0x1073,
	0xFFFD: 0x1074,
	0xFFFD: 0x1075,
	0xFFFD: 0x1076,
	0xFFFD: 0x1077,
	0xFFFD: 0x1078,
	0xFFFD: 0x1079,
	0xFFFD: 0x107A,
	0xFFFD: 0x107B,
	0xFFFD: 0x107C,
	0xFFFD: 0x107D,
	0xFFFD: 0x107E,
	0xFFFD: 0x107F,
	0xFFFD: 0x1080,
	0xFFFD: 0x1081,
	0xFFFD: 0x1082,
	0xFFFD: 0x1083,
	0xFFFD: 0x1084,
	0xFFFD: 0x1085,
	0xFFFD: 0x1086,
	0xFFFD: 0x1087,
	0xFFFD: 0x1088,
	0xFFFD: 0x1089,
	0xFFFD: 0x108A,
	0xFFFD: 0x108B,
	0xFFFD: 0x108C,
	0xFFFD: 0x108D,
	0xFFFD: 0x108E,
	0xFFFD: 0x108F,
	0xFFFD: 0x1090,
	0xFFFD: 0x1091,
	0xFFFD: 0x1092,
	0xFFFD: 0x1093,
	0xFFFD: 0x1094,
	0xFFFD: 0x1095,
	0xFFFD: 0x1096,
	0xFFFD: 0x1097,
	0xFFFD: 0x1098,
	0xFFFD: 0x1099,
	0xFFFD: 0x109A,
	0xFFFD: 0x109B,
	0xFFFD: 0x109C,
	0xFFFD: 0x109D,
	0xFFFD: 0x109E,
	0xFFFD: 0x109F,
	0xFFFD: 0x10A0,
	0xFFFD: 0x10A1,
	0xFFFD: 0x10A2,
	0xFFFD: 0x10A3,
	0xFFFD: 0x10A4,
	0xFFFD: 0x10A5,
	0xFFFD: 0x10A6,
	0xFFFD: 0x10A7,
	0xFFFD: 0x10A8,
	0xFFFD: 0x10A9,
	0xFFFD: 0x10AA,
	0xFFFD: 0x10AB,
	0xFFFD: 0x10AC,
	0xFFFD: 0x10AD,
	0xFFFD: 0x10AE,
	0xFFFD: 0x10AF,
	0xFFFD: 0x10B0,
	0xFFFD: 0x10B1,
	0xFFFD: 0x10B2,
	0xFFFD: 0x10B3,
	0xFFFD: 0x10B4,
	0xFFFD: 0x10B5,
	0xFFFD: 0x10B6,
	0xFFFD: 0x10B7,
	0xFFFD: 0x10B8,
	0xFFFD: 0x10B9,
	0xFFFD: 0x10BA,
	0xFFFD: 0x10BB,
	0xFFFD: 0x10BC,
	0xFFFD: 0x10BD,
	0xFFFD: 0x10BE,
	0xFFFD: 0x10BF,
	0xFFFD: 0x10C0,
	0xFFFD: 0x10C1,
	0xFFFD: 0x10C2,
	0xFFFD: 0x10C3,
	0xFFFD: 0x10C4,
	0xFFFD: 0x10C5,
	0xFFFD: 0x10C6,
	0xFFFD: 0x10C7,
	0xFFFD: 0x10C8,
	0xFFFD: 0x10C9,
	0xFFFD: 0x10CA,
	0xFFFD: 0x10CB,
	0xFFFD: 0x10CC,
	0xFFFD: 0x10CD,
	0xFFFD: 0x10CE,
	0xFFFD: 0x10CF,
	0xFFFD: 0x10D0,
	0xFFFD: 0x10D1,
	0xFFFD: 0x10D2,
	0xFFFD: 0x10D3,
	0xFFFD: 0x10D4,
	0xFFFD: 0x10D5,
	0xFFFD: 0x10D6,
	0xFFFD: 0x10D7,
	0xFFFD: 0x10D8,
	0xFFFD: 0x10D9,
	0xFFFD: 0x10DA,
	0xFFFD: 0x10DB,
	0xFFFD: 0x10DC,
	0xFFFD: 0x10DD,
	0xFFFD: 0x10DE,
	0xFFFD: 0x10DF,
	0xFFFD: 0x10E0,
	0xFFFD: 0x10E1,
	0xFFFD: 0x10E2,
	0xFFFD: 0x10E3,
	0xFFFD: 0x10E4,
	0xFFFD: 0x10E5,
	0xFFFD: 0x10E6,
	0xFFFD: 0x10E7,
	0xFFFD: 0x10E8,
	0xFFFD: 0x10E9,
	0xFFFD: 0x10EA,
	0xFFFD: 0x10EB,
	0xFFFD: 0x10EC,
	0xFFFD: 0x10ED,
	0xFFFD: 0x10EE,
	0xFFFD: 0x10EF,
	0xFFFD: 0x10F0,
	0xFFFD: 0x10F1,
	0xFFFD: 0x10F2,
	0xFFFD: 0x10F3,
	0xFFFD: 0x10F4,
	0xFFFD: 0x10F5,
	0xFFFD: 0x10F6,
	0xFFFD: 0x10F7,
	0xFFFD: 0x10F8,
	0xFFFD: 0x10F9,
	0xFFFD: 0x10FA,
	0xFFFD: 0x10FB,
	0xFFFD: 0x10FC,
	0xFFFD: 0x10FD,
	0xFFFD: 0x10FE,
	0xFFFD: 0x10FF,
	0xFFFD: 0x1100,
	0xFFFD: 0x1101,
	0xFFFD: 0x1102,
	0xFFFD: 0x1103,
	0xFFFD: 0x1104,
	0xFFFD: 0x1105,
	0xFFFD: 0x1106,
	0xFFFD: 0x1107,
	0xFFFD: 0x1108,
	0xFFFD: 0x1109,
	0xFFFD: 0x110A,
	0xFFFD: 0x110B,
	0xFFFD: 0x110C,
	0xFFFD: 0x110D,
	0xFFFD: 0x110E,
	0xFFFD: 0x110F,
	0xFFFD: 0x1110,
	0xFFFD: 0x1111,
	0xFFFD: 0x1112,
	0xFFFD: 0x1113,
	0xFFFD: 0x1114,
	0xFFFD: 0x1115,
	0xFFFD: 0x1116,
	0xFFFD: 0x1117,
	0xFFFD: 0x1118,
	0xFFFD: 0x1119,
	0xFFFD: 0x111A,
	0xFFFD: 0x111B,
	0xFFFD: 0x111C,
	0xFFFD: 0x111D,
	0xFFFD: 0x111E,
	0xFFFD: 0x111F,
	0xFFFD: 0x1120,
	0xFFFD: 0x1121,
	0xFFFD: 0x1122,
	0xFFFD: 0x1123,
	0xFFFD: 0x1124,
	0xFFFD: 0x1125,
	0xFFFD: 0x1126,
	0xFFFD: 0x1127,
	0xFFFD: 0x1128,
	0xFFFD: 0x1129,
	0xFFFD: 0x112A,
	0xFFFD: 0x112B,
	0xFFFD: 0x112C,
	0xFFFD: 0x112D,
	0xFFFD: 0x112E,
	0xFFFD: 0x112F,
	0xFFFD: 0x1130,
	0xFFFD: 0x1131,
	0xFFFD: 0x1132,
	0xFFFD: 0x1133,
	0xFFFD: 0x1134,
	0xFFFD: 0x1135,
	0xFFFD: 0x1136,
	0xFFFD: 0x1137,
	0xFFFD: 0x1138,
	0xFFFD: 0x1139,
	0xFFFD: 0x113A,
	0xFFFD: 0x113B,
	0xFFFD: 0x113C,
	0xFFFD: 0x113D,
	0xFFFD: 0x113E,
	0xFFFD: 0x113F,
	0xFFFD: 0x1140,
	0xFFFD: 0x1141,
	0xFFFD: 0x1142,
	0xFFFD: 0x1143,
	0xFFFD: 0x1144,
	0xFFFD: 0x1145,
	0xFFFD: 0x1146,
	0xFFFD: 0x1147,
	0xFFFD: 0x1148,
	0xFFFD: 0x1149,
	0xFFFD: 0x114A,
	0xFFFD: 0x114B,
	0xFFFD: 0x114C,
	0xFFFD: 0x114D,
	0xFFFD: 0x114E,
	0xFFFD: 0x114F,
	0xFFFD: 0x1150,
	0xFFFD: 0x1151,
	0xFFFD: 0x1152,
	0xFFFD: 0x1153,
	0xFFFD: 0x1154,
	0xFFFD: 0x1155,
	0xFFFD: 0x1156,
	0xFFFD: 0x1157,
	0xFFFD: 0x1158,
	0xFFFD: 0x1159,
	0xFFFD: 0x115A,
	0xFFFD: 0x115B,
	0xFFFD: 0x115C,
	0xFFFD: 0x115D,
	0xFFFD: 0x115E,
	0xFFFD: 0x115F,
	0xFFFD: 0x1160,
	0xFFFD: 0x1161,
	0xFFFD: 0x1162,
	0xFFFD: 0x1163,
	0xFFFD: 0x1164,
	0xFFFD: 0x1165,
	0xFFFD: 0x1166,
	0xFFFD: 0x1167,
	0xFFFD: 0x1168,
	0xFFFD: 0x1169,
	0xFFFD: 0x116A,
	0xFFFD: 0x116B,
	0xFFFD: 0x116C,
	0xFFFD: 0x116D,
	0xFFFD: 0x116E,
	0xFFFD: 0x116F,
	0xFFFD: 0x1170,
	0xFFFD: 0x1171,
	0xFFFD: 0x1172,
	0xFFFD: 0x1173,
	0xFFFD: 0x1174,
	0xFFFD: 0x1175,
	0xFFFD: 0x1176,
	0xFFFD: 0x1177,
	0xFFFD: 0x1178,
	0xFFFD: 0x1179,
	0xFFFD: 0x117A,
	0xFFFD: 0x117B,
	0xFFFD: 0x117C,
	0xFFFD: 0x117D,
	0xFFFD: 0x117E,
	0xFFFD: 0x117F,
	0xFFFD: 0x1180,
	0xFFFD: 0x1181,
	0xFFFD: 0x1182,
	0xFFFD: 0x1183,
	0xFFFD: 0x1184,
	0xFFFD: 0x1185,
	0xFFFD: 0x1186,
	0xFFFD: 0x1187,
	0xFFFD: 0x1188,
	0xFFFD: 0x1189,
	0xFFFD: 0x118A,
	0xFFFD: 0x118B,
	0xFFFD: 0x118C,
	0xFFFD: 0x118D,
	0xFFFD: 0x118E,
	0xFFFD: 0x118F,
	0xFFFD: 0x1190,
	0xFFFD: 0x1191,
	0xFFFD: 0x1192,
	0xFFFD: 0x1193,
	0xFFFD: 0x1194,
	0xFFFD: 0x1195,
	0xFFFD: 0x1196,
	0xFFFD: 0x1197,
	0xFFFD: 0x1198,
	0xFFFD: 0x1199,
	0xFFFD: 0x119A,
	0xFFFD: 0x119B,
	0xFFFD: 0x119C,
	0xFFFD: 0x119D,
	0xFFFD: 0x119E,
	0xFFFD: 0x119F,
	0xFFFD: 0x11A0,
	0xFFFD: 0x11A1,
	0xFFFD: 0x11A2,
	0xFFFD: 0x11A3,
	0xFFFD: 0x11A4,
	0xFFFD: 0x11A5,
	0xFFFD: 0x11A6,
	0xFFFD: 0x11A7,
	0xFFFD: 0x11A8,
	0xFFFD: 0x11A9,
	0xFFFD: 0x11AA,
	0xFFFD: 0x11AB,
	0xFFFD: 0x11AC,
	0xFFFD: 0x11AD,
	0xFFFD: 0x11AE,
	0xFFFD: 0x11AF,
	0xFFFD: 0x11B0,
	0xFFFD: 0x11B1,
	0xFFFD: 0x11B2,
	0xFFFD: 0x11B3,
	0xFFFD: 0x11B4,
	0xFFFD: 0x11B5,
	0xFFFD: 0x11B6,
	0xFFFD: 0x11B7,
	0xFFFD: 0x11B8,
	0xFFFD: 0x11B9,
	0xFFFD: 0x11BA,
	0xFFFD: 0x11BB,
	0xFFFD: 0x11BC,
	0xFFFD: 0x11BD,
	0xFFFD: 0x11BE,
	0xFFFD: 0x11BF,
	0xFFFD: 0x11C0,
	0xFFFD: 0x11C1,
	0xFFFD: 0x11C2,
	0xFFFD: 0x11C3,
	0xFFFD: 0x11C4,
	0xFFFD: 0x11C5,
	0xFFFD: 0x11C6,
	0xFFFD: 0x11C7,
	0xFFFD: 0x11C8,
	0xFFFD: 0x11C9,
	0xFFFD: 0x11CA,
	0xFFFD: 0x11CB,
	0xFFFD: 0x11CC,
	0xFFFD: 0x11CD,
	0xFFFD: 0x11CE,
	0xFFFD: 0x11CF,
	0xFFFD: 0x11D0,
	0xFFFD: 0x11D1,
	0xFFFD: 0x11D2,
	0xFFFD: 0x11D3,
	0xFFFD: 0x11D4,
	0xFFFD: 0x11D5,
	0xFFFD: 0x11D6,
	0xFFFD: 0x11D7,
	0xFFFD: 0x11D8,
	0xFFFD: 0x11D9,
	0xFFFD: 0x11DA,
	0xFFFD: 0x11DB,
	0xFFFD: 0x11DC,
	0xFFFD: 0x11DD,
	0xFFFD: 0x11DE,
	0xFFFD: 0x11DF,
	0xFFFD: 0x11E0,
	0xFFFD: 0x11E1,
	0xFFFD: 0x11E2,
	0xFFFD: 0x11E3,
	0xFFFD: 0x11E4,
	0xFFFD: 0x11E5,
	0xFFFD: 0x11E6,
	0xFFFD: 0x11E7,
	0xFFFD: 0x11E8,
	0xFFFD: 0x11E9,
	0xFFFD: 0x11EA,
	0xFFFD: 0x11EB,
	0xFFFD: 0x11EC,
	0xFFFD: 0x11ED,
	0xFFFD: 0x11EE,
	0xFFFD: 0x11EF,
	0xFFFD: 0x11F0,
	0xFFFD: 0x11F1,
	0xFFFD: 0x11F2,
	0xFFFD: 0x11F3,
	0xFFFD: 0x11F4,
	0xFFFD: 0x11F5,
	0xFFFD: 0x11F6,
	0xFFFD: 0x11F7,
	0xFFFD: 0x11F8,
	0xFFFD: 0x11F9,
	0xFFFD: 0x11FA,
	0xFFFD: 0x11FB,
	0xFFFD: 0x11FC,
	0xFFFD: 0x11FD,
	0xFFFD: 0x11FE,
	0xFFFD: 0x11FF,
	0xFFFD: 0x1200,
	0xFFFD: 0x1201,
	0xFFFD: 0x1202,
	0xFFFD: 0x1203,
	0xFFFD: 0x1204,
	0xFFFD: 0x1205,
	0xFFFD: 0x1206,
	0xFFFD: 0x1207,
	0xFFFD: 0x1208,
	0xFFFD: 0x1209,
	0xFFFD: 0x120A,
	0xFFFD: 0x120B,
	0xFFFD: 0x120C,
	0xFFFD: 0x120D,
	0xFFFD: 0x120E,
	0xFFFD: 0x120F,
	0xFFFD: 0x1210,
	0xFFFD: 0x1211,
	0xFFFD: 0x1212,
	0xFFFD: 0x1213,
	0xFFFD: 0x1214,
	0xFFFD: 0x1215,
	0xFFFD: 0x1216,
	0xFFFD: 0x1217,
	0xFFFD: 0x1218,
	0xFFFD: 0x1219,
	0xFFFD: 0x121A,
	0xFFFD: 0x121B,
	0xFFFD: 0x121C,
	0xFFFD: 0x121D,
	0xFFFD: 0x121E,
	0xFFFD: 0x121F,
	0xFFFD: 0x1220,
	0xFFFD: 0x1221,
	0xFFFD: 0x1222,
	0xFFFD: 0x1223,
	0xFFFD: 0x1224,
	0xFFFD: 0x1225,
	0xFFFD: 0x1226,
	0xFFFD: 0x1227,
	0xFFFD: 0x1228,
	0xFFFD: 0x1229,
	0xFFFD: 0x122A,
	0xFFFD: 0x122B,
	0xFFFD: 0x122C,
	0xFFFD: 0x122D,
	0xFFFD: 0x122E,
	0xFFFD: 0x122F,
	0xFFFD: 0x1230,
	0xFFFD: 0x1231,
	0xFFFD: 0x1232,
	0xFFFD: 0x1233,
	0xFFFD: 0x1234,
	0xFFFD: 0x1235,
	0xFFFD: 0x1236,
	0xFFFD: 0x1237,
	0xFFFD: 0x1238,
	0xFFFD: 0x1239,
	0xFFFD: 0x123A,
	0xFFFD: 0x123B,
	0xFFFD: 0x123C,
	0xFFFD: 0x123D,
	0xFFFD: 0x123E,
	0xFFFD: 0x123F,
	0xFFFD: 0x1240,
	0xFFFD: 0x1241,
	0xFFFD: 0x1242,
	0xFFFD: 0x1243,
	0xFFFD: 0x1244,
	0xFFFD: 0x1245,
	0xFFFD: 0x1246,
	0xFFFD: 0x1247,
	0xFFFD: 0x1248,
	0xFFFD: 0x1249,
	0xFFFD: 0x124A,
	0xFFFD: 0x124B,
	0xFFFD: 0x124C,
	0xFFFD: 0x124D,
	0xFFFD: 0x124E,
	0xFFFD: 0x124F,
	0xFFFD: 0x1250,
	0xFFFD: 0x1251,
	0xFFFD: 0x1252,
	0xFFFD: 0x1253,
	0xFFFD: 0x1254,
	0xFFFD: 0x1255,
	0xFFFD: 0x1256,
	0xFFFD: 0x1257,
	0xFFFD: 0x1258,
	0xFFFD: 0x1259,
	0xFFFD: 0x125A,
	0xFFFD: 0x125B,
	0xFFFD: 0x125C,
	0xFFFD: 0x125D,
	0xFFFD: 0x125E,
	0xFFFD: 0x125F,
	0xFFFD: 0x1260,
	0xFFFD: 0x1261,
	0xFFFD: 0x1262,
	0xFFFD: 0x1263,
	0xFFFD: 0x1264,
	0xFFFD: 0x1265,
	0xFFFD: 0x1266,
	0xFFFD: 0x1267,
	0xFFFD: 0x1268,
	0xFFFD: 0x1269,
	0xFFFD: 0x126A,
	0xFFFD: 0x126B,
	0xFFFD: 0x126C,
	0xFFFD: 0x126D,
	0xFFFD: 0x126E,
	0xFFFD: 0x126F,
	0xFFFD: 0x1270,
	0xFFFD: 0x1271,
	0xFFFD: 0x1272,
	0xFFFD: 0x1273,
	0xFFFD: 0x1274,
	0xFFFD: 0x1275,
	0xFFFD: 0x1276,
	0xFFFD: 0x1277,
	0xFFFD: 0x1278,
	0xFFFD: 0x1279,
	0xFFFD: 0x127A,
	0xFFFD: 0x127B,
	0xFFFD: 0x127C,
	0xFFFD: 0x127D,
	0xFFFD: 0x127E,
	0xFFFD: 0x127F,
	0xFFFD: 0x1280,
	0xFFFD: 0x1281,
	0xFFFD: 0x1282,
	0xFFFD: 0x1283,
	0xFFFD: 0x1284,
	0xFFFD: 0x1285,
	0xFFFD: 0x1286,
	0xFFFD: 0x1287,
	0xFFFD: 0x1288,
	0xFFFD: 0x1289,
	0xFFFD: 0x128A,
	0xFFFD: 0x128B,
	0xFFFD: 0x128C,
	0xFFFD: 0x128D,
	0xFFFD: 0x128E,
	0xFFFD: 0x128F,
	0xFFFD: 0x1290,
	0xFFFD: 0x1291,
	0xFFFD: 0x1292,
	0xFFFD: 0x1293,
	0xFFFD: 0x1294,
	0xFFFD: 0x1295,
	0xFFFD: 0x1296,
	0xFFFD: 0x1297,
	0xFFFD: 0x1298,
	0xFFFD: 0x1299,
	0xFFFD: 0x129A,
	0xFFFD: 0x129B,
	0xFFFD: 0x129C,
	0xFFFD: 0x129D,
	0xFFFD: 0x129E,
	0xFFFD: 0x129F,
	0xFFFD: 0x12A0,
	0xFFFD: 0x12A1,
	0xFFFD: 0x12A2,
	0xFFFD: 0x12A3,
	0xFFFD: 0x12A4,
	0xFFFD: 0x12A5,
	0xFFFD: 0x12A6,
	0xFFFD: 0x12A7,
	0xFFFD: 0x12A8,
	0xFFFD: 0x12A9,
	0xFFFD: 0x12AA,
	0xFFFD: 0x12AB,
	0xFFFD: 0x12AC,
	0xFFFD: 0x12AD,
	0xFFFD: 0x12AE,
	0xFFFD: 0x12AF,
	0xFFFD: 0x12B0,
	0xFFFD: 0x12B1,
	0xFFFD: 0x12B2,
	0xFFFD: 0x12B3,
	0xFFFD: 0x12B4,
	0xFFFD: 0x12B5,
	0xFFFD: 0x12B6,
	0xFFFD: 0x12B7,
	0xFFFD: 0x12B8,
	0xFFFD: 0x12B9,
	0xFFFD: 0x12BA,
	0xFFFD: 0x12BB,
	0xFFFD: 0x12BC,
	0xFFFD: 0x12BD,
	0xFFFD: 0x12BE,
	0xFFFD: 0x12BF,
	0xFFFD: 0x12C0,
	0xFFFD: 0x12C1,
	0xFFFD: 0x12C2,
	0xFFFD: 0x12C3,
	0xFFFD: 0x12C4,
	0xFFFD: 0x12C5,
	0xFFFD: 0x12C6,
	0xFFFD: 0x12C7,
	0xFFFD: 0x12C8,
	0xFFFD: 0x12C9,
	0xFFFD: 0x12CA,
	0xFFFD: 0x12CB,
	0xFFFD: 0x12CC,
	0xFFFD: 0x12CD,
	0xFFFD: 0x12CE,
	0xFFFD: 0x12CF,
	0xFFFD: 0x12D0,
	0xFFFD: 0x12D1,
	0xFFFD: 0x12D2,
	0xFFFD: 0x12D3,
	0xFFFD: 0x12D4,
	0xFFFD: 0x12D5,
	0xFFFD: 0x12D6,
	0xFFFD: 0x12D7,
	0xFFFD: 0x12D8,
	0xFFFD: 0x12D9,
	0xFFFD: 0x12DA,
	0xFFFD: 0x12DB,
	0xFFFD: 0x12DC,
	0xFFFD: 0x12DD,
	0xFFFD: 0x12DE,
	0xFFFD: 0x12DF,
	0xFFFD: 0x12E0,
	0xFFFD: 0x12E1,
	0xFFFD: 0x12E2,
	0xFFFD: 0x12E3,
	0xFFFD: 0x12E4,
	0xFFFD: 0x12E5,
	0xFFFD: 0x12E6,
	0xFFFD: 0x12E7,
	0xFFFD: 0x12E8,
	0xFFFD: 0x12E9,
	0xFFFD: 0x12EA,
	0xFFFD: 0x12EB,
	0xFFFD: 0x12EC,
	0xFFFD: 0x12ED,
	0xFFFD: 0x12EE,
	0xFFFD: 0x12EF,
	0xFFFD: 0x12F0,
	0xFFFD: 0x12F1,
	0xFFFD: 0x12F2,
	0xFFFD: 0x12F3,
	0xFFFD: 0x12F4,
	0xFFFD: 0x12F5,
	0xFFFD: 0x12F6,
	0xFFFD: 0x12F7,
	0xFFFD: 0x12F8,
	0xFFFD: 0x12F9,
	0xFFFD: 0x12FA,
	0xFFFD: 0x12FB,
	0xFFFD: 0x12FC,
	0xFFFD: 0x12FD,
	0xFFFD: 0x12FE,
	0xFFFD: 0x12FF,
	0xFFFD: 0x1300,
	0xFFFD: 0x1301,
	0xFFFD: 0x1302,
	0xFFFD: 0x1303,
	0xFFFD: 0x1304,
	0xFFFD: 0x1305,
	0xFFFD: 0x1306,
	0xFFFD: 0x1307,
	0xFFFD: 0x1308,
	0xFFFD: 0x1309,
	0xFFFD: 0x130A,
	0xFFFD: 0x130B,
	0xFFFD: 0x130C,
	0xFFFD: 0x130D,
	0xFFFD: 0x130E,
	0xFFFD: 0x130F,
	0xFFFD: 0x1310,
	0xFFFD: 0x1311,
	0xFFFD: 0x1312,
	0xFFFD: 0x1313,
	0xFFFD: 0x1314,
	0xFFFD: 0x1315,
	0xFFFD: 0x1316,
	0xFFFD: 0x1317,
	0xFFFD: 0x1318,
	0xFFFD: 0x1319,
	0xFFFD: 0x131A,
	0xFFFD: 0x131B,
	0xFFFD: 0x131C,
	0xFFFD: 0x131D,
	0xFFFD: 0x131E,
	0xFFFD: 0x131F,
	0xFFFD: 0x1320,
	0xFFFD: 0x1321,
	0xFFFD: 0x1322,
	0xFFFD: 0x1323,
	0xFFFD: 0x1324,
	0xFFFD: 0x1325,
	0xFFFD: 0x1326,
	0xFFFD: 0x1327,
	0xFFFD: 0x1328,
	0xFFFD: 0x1329,
	0xFFFD: 0x132A,
	0xFFFD: 0x132B,
	0xFFFD: 0x132C,
	0xFFFD: 0x132D,
	0xFFFD: 0x132E,
	0xFFFD: 0x132F,
	0xFFFD: 0x1330,
	0xFFFD: 0x1331,
	0xFFFD: 0x1332,
	0xFFFD: 0x1333,
	0xFFFD: 0x1334,
	0xFFFD: 0x1335,
	0xFFFD: 0x1336,
	0xFFFD: 0x1337,
	0xFFFD: 0x1338,
	0xFFFD: 0x1339,
	0xFFFD: 0x133A,
	0xFFFD: 0x133B,
	0xFFFD: 0x133C,
	0xFFFD: 0x133D,
	0xFFFD: 0x133E,
	0xFFFD: 0x133F,
	0xFFFD: 0x1340,
	0xFFFD: 0x1341,
	0xFFFD: 0x1342,
	0xFFFD: 0x1343,
	0xFFFD: 0x1344,
	0xFFFD: 0x1345,
	0xFFFD: 0x1346,
	0xFFFD: 0x1347,
	0xFFFD: 0x1348,
	0xFFFD: 0x1349,
	0xFFFD: 0x134A,
	0xFFFD: 0x134B,
	0xFFFD: 0x134C,
	0xFFFD: 0x134D,
	0xFFFD: 0x134E,
	0xFFFD: 0x134F,
	0xFFFD: 0x1350,
	0xFFFD: 0x1351,
	0xFFFD: 0x1352,
	0xFFFD: 0x1353,
	0xFFFD: 0x1354,
	0xFFFD: 0x1355,
	0xFFFD: 0x1356,
	0xFFFD: 0x1357,
	0xFFFD: 0x1358,
	0xFFFD: 0x1359,
	0xFFFD: 0x135A,
	0xFFFD: 0x135B,
	0xFFFD: 0x135C,
	0xFFFD: 0x135D,
	0xFFFD: 0x135E,
	0xFFFD: 0x135F,
	0xFFFD: 0x1360,
	0xFFFD: 0x1361,
	0xFFFD: 0x1362,
	0xFFFD: 0x1363,
	0xFFFD: 0x1364,
	0xFFFD: 0x1365,
	0xFFFD: 0x1366,
	0xFFFD: 0x1367,
	0xFFFD: 0x1368,
	0xFFFD: 0x1369,
	0xFFFD: 0x136A,
	0xFFFD: 0x136B,
	0xFFFD: 0x136C,
	0xFFFD: 0x136D,
	0xFFFD: 0x136E,
	0xFFFD: 0x136F,
	0xFFFD: 0x1370,
	0xFFFD: 0x1371,
	0xFFFD: 0x1372,
	0xFFFD: 0x1373,
	0xFFFD: 0x1374,
	0xFFFD: 0x1375,
	0xFFFD: 0x1376,
	0xFFFD: 0x1377,
	0xFFFD: 0x1378,
	0xFFFD: 0x1379,
	0xFFFD: 0x137A,
	0xFFFD: 0x137B,
	0xFFFD: 0x137C,
	0xFFFD: 0x137D,
	0xFFFD: 0x137E,
	0xFFFD: 0x137F,
	0xFFFD: 0x1380,
	0xFFFD: 0x1381,
	0xFFFD: 0x1382,
	0xFFFD: 0x1383,
	0xFFFD: 0x1384,
	0xFFFD: 0x1385,
	0xFFFD: 0x1386,
	0xFFFD: 0x1387,
	0xFFFD: 0x1388,
	0xFFFD: 0x1389,
	0xFFFD: 0x138A,
	0xFFFD: 0x138B,
	0xFFFD: 0x138C,
	0xFFFD: 0x138D,
	0xFFFD: 0x138E,
	0xFFFD: 0x138F,
	0xFFFD: 0x1390,
	0xFFFD: 0x1391,
	0xFFFD: 0x1392,
	0xFFFD: 0x1393,
	0xFFFD: 0x1394,
	0xFFFD: 0x1395,
	0xFFFD: 0x1396,
	0xFFFD: 0x1397,
	0xFFFD: 0x1398,
	0xFFFD: 0x1399,
	0xFFFD: 0x139A,
	0xFFFD: 0x139B,
	0xFFFD: 0x139C,
	0xFFFD: 0x139D,
	0xFFFD: 0x139E,
	0xFFFD: 0x139F,
	0xFFFD: 0x13A0,
	0xFFFD: 0x13A1,
	0xFFFD: 0x13A2,
	0xFFFD: 0x13A3,
	0xFFFD: 0x13A4,
	0xFFFD: 0x13A5,
	0xFFFD: 0x13A6,
	0xFFFD: 0x13A7,
	0xFFFD: 0x13A8,
	0xFFFD: 0x13A9,
	0xFFFD: 0x13AA,
	0xFFFD: 0x13AB,
	0xFFFD: 0x13AC,
	0xFFFD: 0x13AD,
	0xFFFD: 0x13AE,
	0xFFFD: 0x13AF,
	0xFFFD: 0x13B0,
	0xFFFD: 0x13B1,
	0xFFFD: 0x13B2,
	0xFFFD: 0x13B3,
	0xFFFD: 0x13B4,
	0xFFFD: 0x13B5,
	0xFFFD: 0x13B6,
	0xFFFD: 0x13B7,
	0xFFFD: 0x13B8,
	0xFFFD: 0x13B9,
	0xFFFD: 0x13BA,
	0xFFFD: 0x13BB,
	0xFFFD: 0x13BC,
	0xFFFD: 0x13BD,
	0xFFFD: 0x13BE,
	0xFFFD: 0x13BF,
	0xFFFD: 0x13C0,
	0xFFFD: 0x13C1,
	0xFFFD: 0x13C2,
	0xFFFD: 0x13C3,
	0xFFFD: 0x13C4,
	0xFFFD: 0x13C5,
	0xFFFD: 0x13C6,
	0xFFFD: 0x13C7,
	0xFFFD: 0x13C8,
	0xFFFD: 0x13C9,
	0xFFFD: 0x13CA,
	0xFFFD: 0x13CB,
	0xFFFD: 0x13CC,
	0xFFFD: 0x13CD,
	0xFFFD: 0x13CE,
	0xFFFD: 0x13CF,
	0xFFFD: 0x13D0,
	0xFFFD: 0x13D1,
	0xFFFD: 0x13D2,
	0xFFFD: 0x13D3,
	0xFFFD: 0x13D4,
	0xFFFD: 0x13D5,
	0xFFFD: 0x13D6,
	0xFFFD: 0x13D7,
	0xFFFD: 0x13D8,
	0xFFFD: 0x13D9,
	0xFFFD: 0x13DA,
	0xFFFD: 0x13DB,
	0xFFFD: 0x13DC,
	0xFFFD: 0x13DD,
	0xFFFD: 0x13DE,
	0xFFFD: 0x13DF,
	0xFFFD: 0x13E0,
	0xFFFD: 0x13E1,
	0xFFFD: 0x13E2,
	0xFFFD: 0x13E3,
	0xFFFD: 0x13E4,
	0xFFFD: 0x13E5,
	0xFFFD: 0x13E6,
	0xFFFD: 0x13E7,
	0xFFFD: 0x13E8,
	0xFFFD: 0x13E9,
	0xFFFD: 0x13EA,
	0xFFFD: 0x13EB,
	0xFFFD: 0x13EC,
	0xFFFD: 0x13ED,
	0xFFFD: 0x13EE,
	0xFFFD: 0x13EF,
	0xFFFD: 0x13F0,
	0xFFFD: 0x13F1,
	0xFFFD: 0x13F2,
	0xFFFD: 0x13F3,
	0xFFFD: 0x13F4,
	0xFFFD: 0x13F5,
	0xFFFD: 0x13F6,
	0xFFFD: 0x13F7,
	0xFFFD: 0x13F8,
	0xFFFD: 0x13F9,
	0xFFFD: 0x13FA,
	0xFFFD: 0x13FB,
	0xFFFD: 0x13FC,
	0xFFFD: 0x13FD,
	0xFFFD: 0x13FE,
	0xFFFD: 0x13FF,
	0xFFFD: 0x1400,
	0xFFFD: 0x1401,
	0xFFFD: 0x1402,
	0xFFFD: 0x1403,
	0xFFFD: 0x1404,
	0xFFFD: 0x1405,
	0xFFFD: 0x1406,
	0xFFFD: 0x1407,
	0xFFFD: 0x1408,
	0xFFFD: 0x1409,
	0xFFFD: 0x140A,
	0xFFFD: 0x140B,
	0xFFFD: 0x140C,
	0xFFFD: 0x140D,
	0xFFFD: 0x140E,
	0xFFFD: 0x140F,
	0xFFFD: 0x1410,
	0xFFFD: 0x1411,
	0xFFFD: 0x1412,
	0xFFFD: 0x1413,
	0xFFFD: 0x1414,
	0xFFFD: 0x1415,
	0xFFFD: 0x1416,
	0xFFFD: 0x1417,
	0xFFFD: 0x1418,
	0xFFFD: 0x1419,
	0xFFFD: 0x141A,
	0xFFFD: 0x141B,
	0xFFFD: 0x141C,
	0xFFFD: 0x141D,
	0xFFFD: 0x141E,
	0xFFFD: 0x141F,
	0xFFFD: 0x1420,
	0xFFFD: 0x1421,
	0xFFFD: 0x1422,
	0xFFFD: 0x1423,
	0xFFFD: 0x1424,
	0xFFFD: 0x1425,
	0xFFFD: 0x1426,
	0xFFFD: 0x1427,
	0xFFFD: 0x1428,
	0xFFFD: 0x1429,
	0xFFFD: 0x142A,
	0xFFFD: 0x142B,
	0xFFFD: 0x142C,
	0xFFFD: 0x142D,
	0xFFFD: 0x142E,
	0xFFFD: 0x142F,
	0xFFFD: 0x1430,
	0xFFFD: 0x1431,
	0xFFFD: 0x1432,
	0xFFFD: 0x1433,
	0xFFFD: 0x1434,
	0xFFFD: 0x1435,
	0xFFFD: 0x1436,
	0xFFFD: 0x1437,
	0xFFFD: 0x1438,
	0xFFFD: 0x1439,
	0xFFFD: 0x143A,
	0xFFFD: 0x143B,
	0xFFFD: 0x143C,
	0xFFFD: 0x143D,
	0xFFFD: 0x143E,
	0xFFFD: 0x143F,
	0xFFFD: 0x1440,
	0xFFFD: 0x1441,
	0xFFFD: 0x1442,
	0xFFFD: 0x1443,
	0xFFFD: 0x1444,
	0xFFFD: 0x1445,
	0xFFFD: 0x1446,
	0xFFFD: 0x1447,
	0xFFFD: 0x1448,
	0xFFFD: 0x1449,
	0xFFFD: 0x144A,
	0xFFFD: 0x144B,
	0xFFFD: 0x144C,
	0xFFFD: 0x144D,
	0xFFFD: 0x144E,
	0xFFFD: 0x144F,
	0xFFFD: 0x1450,
	0xFFFD: 0x1451,
	0xFFFD: 0x1452,
	0xFFFD: 0x1453,
	0xFFFD: 0x1454,
	0xFFFD: 0x1455,
	0xFFFD: 0x1456,
	0xFFFD: 0x1457,
	0xFFFD: 0x1458,
	0xFFFD: 0x1459,
	0xFFFD: 0x145A,
	0xFFFD: 0x145B,
	0xFFFD: 0x145C,
	0xFFFD: 0x145D,
	0xFFFD: 0x145E,
	0xFFFD: 0x145F,
	0xFFFD: 0x1460,
	0xFFFD: 0x1461,
	0xFFFD: 0x1462,
	0xFFFD: 0x1463,
	0xFFFD: 0x1464,
	0xFFFD: 0x1465,
	0xFFFD: 0x1466,
	0xFFFD: 0x1467,
	0xFFFD: 0x1468,
	0xFFFD: 0x1469,
	0xFFFD: 0x146A,
	0xFFFD: 0x146B,
	0xFFFD: 0x146C,
	0xFFFD: 0x146D,
	0xFFFD: 0x146E,
	0xFFFD: 0x146F,
	0xFFFD: 0x1470,
	0xFFFD: 0x1471,
	0xFFFD: 0x1472,
	0xFFFD: 0x1473,
	0xFFFD: 0x1474,
	0xFFFD: 0x1475,
	0xFFFD: 0x1476,
	0xFFFD: 0x1477,
	0xFFFD: 0x1478,
	0xFFFD: 0x1479,
	0xFFFD: 0x147A,
	0xFFFD: 0x147B,
	0xFFFD: 0x147C,
	0xFFFD: 0x147D,
	0xFFFD: 0x147E,
	0xFFFD: 0x147F,
	0xFFFD: 0x1480,
	0xFFFD: 0x1481,
	0xFFFD: 0x1482,
	0xFFFD: 0x1483,
	0xFFFD: 0x1484,
	0xFFFD: 0x1485,
	0xFFFD: 0x1486,
	0xFFFD: 0x1487,
	0xFFFD: 0x1488,
	0xFFFD: 0x1489,
	0xFFFD: 0x148A,
	0xFFFD: 0x148B,
	0xFFFD: 0x148C,
	0xFFFD: 0x148D,
	0xFFFD: 0x148E,
	0xFFFD: 0x148F,
	0xFFFD: 0x1490,
	0xFFFD: 0x1491,
	0xFFFD: 0x1492,
	0xFFFD: 0x1493,
	0xFFFD: 0x1494,
	0xFFFD: 0x1495,
	0xFFFD: 0x1496,
	0xFFFD: 0x1497,
	0xFFFD: 0x1498,
	0xFFFD: 0x1499,
	0xFFFD: 0x149A,
	0xFFFD: 0x149B,
	0xFFFD: 0x149C,
	0xFFFD: 0x149D,
	0xFFFD: 0x149E,
	0xFFFD: 0x149F,
	0xFFFD: 0x14A0,
	0xFFFD: 0x14A1,
	0xFFFD: 0x14A2,
	0xFFFD: 0x14A3,
	0xFFFD: 0x14A4,
	0xFFFD: 0x14A5,
	0xFFFD: 0x14A6,
	0xFFFD: 0x14A7,
	0xFFFD: 0x14A8,
	0xFFFD: 0x14A9,
	0xFFFD: 0x14AA,
	0xFFFD: 0x14AB,
	0xFFFD: 0x14AC,
	0xFFFD: 0x14AD,
	0xFFFD: 0x14AE,
	0xFFFD: 0x14AF,
	0xFFFD: 0x14B0,
	0xFFFD: 0x14B1,
	0xFFFD: 0x14B2,
	0xFFFD: 0x14B3,
	0xFFFD: 0x14B4,
	0xFFFD: 0x14B5,
	0xFFFD: 0x14B6,
	0xFFFD: 0x14B7,
	0xFFFD: 0x14B8,
	0xFFFD: 0x14B9,
	0xFFFD: 0x14BA,
	0xFFFD: 0x14BB,
	0xFFFD: 0x14BC,
	0xFFFD: 0x14BD,
	0xFFFD: 0x14BE,
	0xFFFD: 0x14BF,
	0xFFFD: 0x14C0,
	0xFFFD: 0x14C1,
	0xFFFD: 0x14C2,
	0xFFFD: 0x14C3,
	0xFFFD: 0x14C4,
	0xFFFD: 0x14C5,
	0xFFFD: 0x14C6,
	0xFFFD: 0x14C7,
	0xFFFD: 0x14C8,
	0xFFFD: 0x14C9,
	0xFFFD: 0x14CA,
	0xFFFD: 0x14CB,
	0xFFFD: 0x14CC,
	0xFFFD: 0x14CD,
	0xFFFD: 0x14CE,
	0xFFFD: 0x14CF,
	0xFFFD: 0x14D0,
	0xFFFD: 0x14D1,
	0xFFFD: 0x14D2,
	0xFFFD: 0x14D3,
	0xFFFD: 0x14D4,
	0xFFFD: 0x14D5,
	0xFFFD: 0x14D6,
	0xFFFD: 0x14D7,
	0xFFFD: 0x14D8,
	0xFFFD: 0x14D9,
	0xFFFD: 0x14DA,
	0xFFFD: 0x14DB,
	0xFFFD: 0x14DC,
	0xFFFD: 0x14DD,
	0xFFFD: 0x14DE,
	0xFFFD: 0x14DF,
	0xFFFD: 0x14E0,
	0xFFFD: 0x14E1,
	0xFFFD: 0x14E2,
	0xFFFD: 0x14E3,
	0xFFFD: 0x14E4,
	0xFFFD: 0x14E5,
	0xFFFD: 0x14E6,
	0xFFFD: 0x14E7,
	0xFFFD: 0x14E8,
	0xFFFD: 0x14E9,
	0xFFFD: 0x14EA,
	0xFFFD: 0x14EB,
	0xFFFD: 0x14EC,
	0xFFFD: 0x14ED,
	0xFFFD: 0x14EE,
	0xFFFD: 0x14EF,
	0xFFFD: 0x14F0,
	0xFFFD: 0x14F1,
	0xFFFD: 0x14F2,
	0xFFFD: 0x14F3,
	0xFFFD: 0x14F4,
	0xFFFD: 0x14F5,
	0xFFFD: 0x14F6,
	0xFFFD: 0x14F7,
	0xFFFD: 0x14F8,
	0xFFFD: 0x14F9,
	0xFFFD: 0x14FA,
	0xFFFD: 0x14FB,
	0xFFFD: 0x14FC,
	0xFFFD: 0x14FD,
	0xFFFD: 0x14FE,
	0xFFFD: 0x14FF,
	0xFFFD: 0x1500,
	0xFFFD: 0x1501,
	0xFFFD: 0x1502,
	0xFFFD: 0x1503,
	0xFFFD: 0x1504,
	0xFFFD: 0x1505,
	0xFFFD: 0x1506,
	0xFFFD: 0x1507,
	0xFFFD: 0x1508,
	0xFFFD: 0x1509,
	0xFFFD: 0x150A,
	0xFFFD: 0x150B,
	0xFFFD: 0x150C,
	0xFFFD: 0x150D,
	0xFFFD: 0x150E,
	0xFFFD: 0x150F,
	0xFFFD: 0x1510,
	0xFFFD: 0x1511,
	0xFFFD: 0x1512,
	0xFFFD: 0x1513,
	0xFFFD: 0x1514,
	0xFFFD: 0x1515,
	0xFFFD: 0x1516,
	0xFFFD: 0x1517,
	0xFFFD: 0x1518,
	0xFFFD: 0x1519,
	0xFFFD: 0x151A,
	0xFFFD: 0x151B,
	0xFFFD: 0x151C,
	0xFFFD: 0x151D,
	0xFFFD: 0x151E,
	0xFFFD: 0x151F,
	0xFFFD: 0x1520,
	0xFFFD: 0x1521,
	0xFFFD: 0x1522,
	0xFFFD: 0x1523,
	0xFFFD: 0x1524,
	0xFFFD: 0x1525,
	0xFFFD: 0x1526,
	0xFFFD: 0x1527,
	0xFFFD: 0x1528,
	0xFFFD: 0x1529,
	0xFFFD: 0x152A,
	0xFFFD: 0x152B,
	0xFFFD: 0x152C,
	0xFFFD: 0x152D,
	0xFFFD: 0x152E,
	0xFFFD: 0x152F,
	0xFFFD: 0x1530,
	0xFFFD: 0x1531,
	0xFFFD: 0x1532,
	0xFFFD: 0x1533,
	0xFFFD: 0x1534,
	0xFFFD: 0x1535,
	0xFFFD: 0x1536,
	0xFFFD: 0x1537,
	0xFFFD: 0x1538,
	0xFFFD: 0x1539,
	0xFFFD: 0x153A,
	0xFFFD: 0x153B,
	0xFFFD: 0x153C,
	0xFFFD: 0x153D,
	0xFFFD: 0x153E,
	0xFFFD: 0x153F,
	0xFFFD: 0x1540,
	0xFFFD: 0x1541,
	0xFFFD: 0x1542,
	0xFFFD: 0x1543,
	0xFFFD: 0x1544,
	0xFFFD: 0x1545,
	0xFFFD: 0x1546,
	0xFFFD: 0x1547,
	0xFFFD: 0x1548,
	0xFFFD: 0x1549,
	0xFFFD: 0x154A,
	0xFFFD: 0x154B,
	0xFFFD: 0x154C,
	0xFFFD: 0x154D,
	0xFFFD: 0x154E,
	0xFFFD: 0x154F,
	0xFFFD: 0x1550,
	0xFFFD: 0x1551,
	0xFFFD: 0x1552,
	0xFFFD: 0x1553,
	0xFFFD: 0x1554,
	0xFFFD: 0x1555,
	0xFFFD: 0x1556,
	0xFFFD: 0x1557,
	0xFFFD: 0x1558,
	0xFFFD: 0x1559,
	0xFFFD: 0x155A,
	0xFFFD: 0x155B,
	0xFFFD: 0x155C,
	0xFFFD: 0x155D,
	0xFFFD: 0x155E,
	0xFFFD: 0x155F,
	0xFFFD: 0x1560,
	0xFFFD: 0x1561,
	0xFFFD: 0x1562,
	0xFFFD: 0x1563,
	0xFFFD: 0x1564,
	0xFFFD: 0x1565,
	0xFFFD: 0x1566,
	0xFFFD: 0x1567,
	0xFFFD: 0x1568,
	0xFFFD: 0x1569,
	0xFFFD: 0x156A,
	0xFFFD: 0x156B,
	0xFFFD: 0x156C,
	0xFFFD: 0x156D,
	0xFFFD: 0x156E,
	0xFFFD: 0x156F,
	0xFFFD: 0x1570,
	0xFFFD: 0x1571,
	0xFFFD: 0x1572,
	0xFFFD: 0x1573,
	0xFFFD: 0x1574,
	0xFFFD: 0x1575,
	0xFFFD: 0x1576,
	0xFFFD: 0x1577,
	0xFFFD: 0x1578,
	0xFFFD: 0x1579,
	0xFFFD: 0x157A,
	0xFFFD: 0x157B,
	0xFFFD: 0x157C,
	0xFFFD: 0x157D,
	0xFFFD: 0x157E,
	0xFFFD: 0x157F,
	0xFFFD: 0x1580,
	0xFFFD: 0x1581,
	0xFFFD: 0x1582,
	0xFFFD: 0x1583,
	0xFFFD: 0x1584,
	0xFFFD: 0x1585,
	0xFFFD: 0x1586,
	0xFFFD: 0x1587,
	0xFFFD: 0x1588,
	0xFFFD: 0x1589,
	0xFFFD: 0x158A,
	0xFFFD: 0x158B,
	0xFFFD: 0x158C,
	0xFFFD: 0x158D,
	0xFFFD: 0x158E,
	0xFFFD: 0x158F,
	0xFFFD: 0x1590,
	0xFFFD: 0x1591,
	0xFFFD: 0x1592,
	0xFFFD: 0x1593,
	0xFFFD: 0x1594,
	0xFFFD: 0x1595,
	0xFFFD: 0x1596,
	0xFFFD: 0x1597,
	0xFFFD: 0x1598,
	0xFFFD: 0x1599,
	0xFFFD: 0x159A,
	0xFFFD: 0x159B,
	0xFFFD: 0x159C,
	0xFFFD: 0x159D,
	0xFFFD: 0x159E,
	0xFFFD: 0x159F,
	0xFFFD: 0x15A0,
	0xFFFD: 0x15A1,
	0xFFFD: 0x15A2,
	0xFFFD: 0x15A3,
	0xFFFD: 0x15A4,
	0xFFFD: 0x15A5,
	0xFFFD: 0x15A6,
	0xFFFD: 0x15A7,
	0xFFFD: 0x15A8,
	0xFFFD: 0x15A9,
	0xFFFD: 0x15AA,
	0xFFFD: 0x15AB,
	0xFFFD: 0x15AC,
	0xFFFD: 0x15AD,
	0xFFFD: 0x15AE,
	0xFFFD: 0x15AF,
	0xFFFD: 0x15B0,
	0xFFFD: 0x15B1,
	0xFFFD: 0x15B2,
	0xFFFD: 0x15B3,
	0xFFFD: 0x15B4,
	0xFFFD: 0x15B5,
	0xFFFD: 0x15B6,
	0xFFFD: 0x15B7,
	0xFFFD: 0x15B8,
	0xFFFD: 0x15B9,
	0xFFFD: 0x15BA,
	0xFFFD: 0x15BB,
	0xFFFD: 0x15BC,
	0xFFFD: 0x15BD,
	0xFFFD: 0x15BE,
	0xFFFD: 0x15BF,
	0xFFFD: 0x15C0,
	0xFFFD: 0x15C1,
	0xFFFD: 0x15C2,
	0xFFFD: 0x15C3,
	0xFFFD: 0x15C4,
	0xFFFD: 0x15C5,
	0xFFFD: 0x15C6,
	0xFFFD: 0x15C7,
	0xFFFD: 0x15C8,
	0xFFFD: 0x15C9,
	0xFFFD: 0x15CA,
	0xFFFD: 0x15CB,
	0xFFFD: 0x15CC,
	0xFFFD: 0x15CD,
	0xFFFD: 0x15CE,
	0xFFFD: 0x15CF,
	0xFFFD: 0x15D0,
	0xFFFD: 0x15D1,
	0xFFFD: 0x15D2,
	0xFFFD: 0x15D3,
	0xFFFD: 0x15D4,
	0xFFFD: 0x15D5,
	0xFFFD: 0x15D6,
	0xFFFD: 0x15D7,
	0xFFFD: 0x15D8,
	0xFFFD: 0x15D9,
	0xFFFD: 0x15DA,
	0xFFFD: 0x15DB,
	0xFFFD: 0x15DC,
	0xFFFD: 0x15DD,
	0xFFFD: 0x15DE,
	0xFFFD: 0x15DF,
	0xFFFD: 0x15E0,
	0xFFFD: 0x15E1,
	0xFFFD: 0x15E2,
	0xFFFD: 0x15E3,
	0xFFFD: 0x15E4,
	0xFFFD: 0x15E5,
	0xFFFD: 0x15E6,
	0xFFFD: 0x15E7,
	0xFFFD: 0x15E8,
	0xFFFD: 0x15E9,
	0xFFFD: 0x15EA,
	0xFFFD: 0x15EB,
	0xFFFD: 0x15EC,
	0xFFFD: 0x15ED,
	0xFFFD: 0x15EE,
	0xFFFD: 0x15EF,
	0xFFFD: 0x15F0,
	0xFFFD: 0x15F1,
	0xFFFD: 0x15F2,
	0xFFFD: 0x15F3,
	0xFFFD: 0x15F4,
	0xFFFD: 0x15F5,
	0xFFFD: 0x15F6,
	0xFFFD: 0x15F7,
	0xFFFD: 0x15F8,
	0xFFFD: 0x15F9,
	0xFFFD: 0x15FA,
	0xFFFD: 0x15FB,
	0xFFFD: 0x15FC,
	0xFFFD: 0x15FD,
	0xFFFD: 0x15FE,
	0xFFFD: 0x15FF,
	0xFFFD: 0x1600,
	0xFFFD: 0x1601,
	0xFFFD: 0x1602,
	0xFFFD: 0x1603,
	0xFFFD: 0x1604,
	0xFFFD: 0x1605,
	0xFFFD: 0x1606,
	0xFFFD: 0x1607,
	0xFFFD: 0x1608,
	0xFFFD: 0x1609,
	0xFFFD: 0x160A,
	0xFFFD: 0x160B,
	0xFFFD: 0x160C,
	0xFFFD: 0x160D,
	0xFFFD: 0x160E,
	0xFFFD: 0x160F,
	0xFFFD: 0x1610,
	0xFFFD: 0x1611,
	0xFFFD: 0x1612,
	0xFFFD: 0x1613,
	0xFFFD: 0x1614,
	0xFFFD: 0x1615,
	0xFFFD: 0x1616,
	0xFFFD: 0x1617,
	0xFFFD: 0x1618,
	0xFFFD: 0x1619,
	0xFFFD: 0x161A,
	0xFFFD: 0x161B,
	0xFFFD: 0x161C,
	0xFFFD: 0x161D,
	0xFFFD: 0x161E,
	0xFFFD: 0x161F,
	0xFFFD: 0x1620,
	0xFFFD: 0x1621,
	0xFFFD: 0x1622,
	0xFFFD: 0x1623,
	0xFFFD: 0x1624,
	0xFFFD: 0x1625,
	0xFFFD: 0x1626,
	0xFFFD: 0x1627,
	0xFFFD: 0x1628,
	0xFFFD: 0x1629,
	0xFFFD: 0x162A,
	0xFFFD: 0x162B,
	0xFFFD: 0x162C,
	0xFFFD: 0x162D,
	0xFFFD: 0x162E,
	0xFFFD: 0x162F,
	0xFFFD: 0x1630,
	0xFFFD: 0x1631,
	0xFFFD: 0x1632,
	0xFFFD: 0x1633,
	0xFFFD: 0x1634,
	0xFFFD: 0x1635,
	0xFFFD: 0x1636,
	0xFFFD: 0x1637,
	0xFFFD: 0x1638,
	0xFFFD: 0x1639,
	0xFFFD: 0x163A,
	0xFFFD: 0x163B,
	0xFFFD: 0x163C,
	0xFFFD: 0x163D,
	0xFFFD: 0x163E,
	0xFFFD: 0x163F,
	0xFFFD: 0x1640,
	0xFFFD: 0x1641,
	0xFFFD: 0x1642,
	0xFFFD: 0x1643,
	0xFFFD: 0x1644,
	0xFFFD: 0x1645,
	0xFFFD: 0x1646,
	0xFFFD: 0x1647,
	0xFFFD: 0x1648,
	0xFFFD: 0x1649,
	0xFFFD: 0x164A,
	0xFFFD: 0x164B,
	0xFFFD: 0x164C,
	0xFFFD: 0x164D,
	0xFFFD: 0x164E,
	0xFFFD: 0x164F,
	0xFFFD: 0x1650,
	0xFFFD: 0x1651,
	0xFFFD: 0x1652,
	0xFFFD: 0x1653,
	0xFFFD: 0x1654,
	0xFFFD: 0x1655,
	0xFFFD: 0x1656,
	0xFFFD: 0x1657,
	0xFFFD: 0x1658,
	0xFFFD: 0x1659,
	0xFFFD: 0x165A,
	0xFFFD: 0x165B,
	0xFFFD: 0x165C,
	0xFFFD: 0x165D,
	0xFFFD: 0x165E,
	0xFFFD: 0x165F,
	0xFFFD: 0x1660,
	0xFFFD: 0x1661,
	0xFFFD: 0x1662,
	0xFFFD: 0x1663,
	0xFFFD: 0x1664,
	0xFFFD: 0x1665,
	0xFFFD: 0x1666,
	0xFFFD: 0x1667,
	0xFFFD: 0x1668,
	0xFFFD: 0x1669,
	0xFFFD: 0x166A,
	0xFFFD: 0x166B,
	0xFFFD: 0x166C,
	0xFFFD: 0x166D,
	0xFFFD: 0x166E,
	0xFFFD: 0x166F,
	0xFFFD: 0x1670,
	0xFFFD: 0x1671,
	0xFFFD: 0x1672,
	0xFFFD: 0x1673,
	0xFFFD: 0x1674,
	0xFFFD: 0x1675,
	0xFFFD: 0x1676,
	0xFFFD: 0x1677,
	0xFFFD: 0x1678,
	0xFFFD: 0x1679,
	0xFFFD: 0x167A,
	0xFFFD: 0x167B,
	0xFFFD: 0x167C,
	0xFFFD: 0x167D,
	0xFFFD: 0x167E,
	0xFFFD: 0x167F,
	0xFFFD: 0x1680,
	0xFFFD: 0x1681,
	0xFFFD: 0x1682,
	0xFFFD: 0x1683,
	0xFFFD: 0x1684,
	0xFFFD: 0x1685,
	0xFFFD: 0x1686,
	0xFFFD: 0x1687,
	0xFFFD: 0x1688,
	0xFFFD: 0x1689,
	0xFFFD: 0x168A,
	0xFFFD: 0x168B,
	0xFFFD: 0x168C,
	0xFFFD: 0x168D,
	0xFFFD: 0x168E,
	0xFFFD: 0x168F,
	0xFFFD: 0x1690,
	0xFFFD: 0x1691,
	0xFFFD: 0x1692,
	0xFFFD: 0x1693,
	0xFFFD: 0x1694,
	0xFFFD: 0x1695,
	0xFFFD: 0x1696,
	0xFFFD: 0x1697,
	0xFFFD: 0x1698,
	0xFFFD: 0x1699,
	0xFFFD: 0x169A,
	0xFFFD: 0x169B,
	0xFFFD: 0x169C,
	0xFFFD: 0x169D,
	0xFFFD: 0x169E,
	0xFFFD: 0x169F,
	0xFFFD: 0x16A0,
	0xFFFD: 0x16A1,
	0xFFFD: 0x16A2,
	0xFFFD: 0x16A3,
	0xFFFD: 0x16A4,
	0xFFFD: 0x16A5,
	0xFFFD: 0x16A6,
	0xFFFD: 0x16A7,
	0xFFFD: 0x16A8,
	0xFFFD: 0x16A9,
	0xFFFD: 0x16AA,
	0xFFFD: 0x16AB,
	0xFFFD: 0x16AC,
	0xFFFD: 0x16AD,
	0xFFFD: 0x16AE,
	0xFFFD: 0x16AF,
	0xFFFD: 0x16B0,
	0xFFFD: 0x16B1,
	0xFFFD: 0x16B2,
	0xFFFD: 0x16B3,
	0xFFFD: 0x16B4,
	0xFFFD: 0x16B5,
	0xFFFD: 0x16B6,
	0xFFFD: 0x16B7,
	0xFFFD: 0x16B8,
	0xFFFD: 0x16B9,
	0xFFFD: 0x16BA,
	0xFFFD: 0x16BB,
	0xFFFD: 0x16BC,
	0xFFFD: 0x16BD,
	0xFFFD: 0x16BE,
	0xFFFD: 0x16BF,
	0xFFFD: 0x16C0,
	0xFFFD: 0x16C1,
	0xFFFD: 0x16C2,
	0xFFFD: 0x16C3,
	0xFFFD: 0x16C4,
	0xFFFD: 0x16C5,
	0xFFFD: 0x16C6,
	0xFFFD: 0x16C7,
	0xFFFD: 0x16C8,
	0xFFFD: 0x16C9,
	0xFFFD: 0x16CA,
	0xFFFD: 0x16CB,
	0xFFFD: 0x16CC,
	0xFFFD: 0x16CD,
	0xFFFD: 0x16CE,
	0xFFFD: 0x16CF,
	0xFFFD: 0x16D0,
	0xFFFD: 0x16D1,
	0xFFFD: 0x16D2,
	0xFFFD: 0x16D3,
	0xFFFD: 0x16D4,
	0xFFFD: 0x16D5,
	0xFFFD: 0x16D6,
	0xFFFD: 0x16D7,
	0xFFFD: 0x16D8,
	0xFFFD: 0x16D9,
	0xFFFD: 0x16DA,
	0xFFFD: 0x16DB,
	0xFFFD: 0x16DC,
	0xFFFD: 0x16DD,
	0xFFFD: 0x16DE,
	0xFFFD: 0x16DF,
	0xFFFD: 0x16E0,
	0xFFFD: 0x16E1,
	0xFFFD: 0x16E2,
	0xFFFD: 0x16E3,
	0xFFFD: 0x16E4,
	0xFFFD: 0x16E5,
	0xFFFD: 0x16E6,
	0xFFFD: 0x16E7,
	0xFFFD: 0x16E8,
	0xFFFD: 0x16E9,
	0xFFFD: 0x16EA,
	0xFFFD: 0x16EB,
	0xFFFD: 0x16EC,
	0xFFFD: 0x16ED,
	0xFFFD: 0x16EE,
	0xFFFD: 0x16EF,
	0xFFFD: 0x16F0,
	0xFFFD: 0x16F1,
	0xFFFD: 0x16F2,
	0xFFFD: 0x16F3,
	0xFFFD: 0x16F4,
	0xFFFD: 0x16F5,
	0xFFFD: 0x16F6,
	0xFFFD: 0x16F7,
	0xFFFD: 0x16F8,
	0xFFFD: 0x16F9,
	0xFFFD: 0x16FA,
	0xFFFD: 0x16FB,
	0xFFFD: 0x16FC,
	0xFFFD: 0x16FD,
	0xFFFD: 0x16FE,
	0xFFFD: 0x16FF,
	0xFFFD: 0x1700,
	0xFFFD: 0x1701,
	0xFFFD: 0x1702,
	0xFFFD: 0x1703,
	0xFFFD: 0x1704,
	0xFFFD: 0x1705,
	0xFFFD: 0x1706,
	0xFFFD: 0x1707,
	0xFFFD: 0x1708,
	0xFFFD: 0x1709,
	0xFFFD: 0x170A,
	0xFFFD: 0x170B,
	0xFFFD: 0x170C,
	0xFFFD: 0x170D,
	0xFFFD: 0x170E,
	0xFFFD: 0x170F,
	0xFFFD: 0x1710,
	0xFFFD: 0x1711,
	0xFFFD: 0x1712,
	0xFFFD: 0x1713,
	0xFFFD: 0x1714,
	0xFFFD: 0x1715,
	0xFFFD: 0x1716,
	0xFFFD: 0x1717,
	0xFFFD: 0x1718,
	0xFFFD: 0x1719,
	0xFFFD: 0x171A,
	0xFFFD: 0x171B,
	0xFFFD: 0x171C,
	0xFFFD: 0x171D,
	0xFFFD: 0x171E,
	0xFFFD: 0x171F,
	0xFFFD: 0x1720,
	0xFFFD: 0x1721,
	0xFFFD: 0x1722,
	0xFFFD: 0x1723,
	0xFFFD: 0x1724,
	0xFFFD: 0x1725,
	0xFFFD: 0x1726,
	0xFFFD: 0x1727,
	0xFFFD: 0x1728,
	0xFFFD: 0x1729,
	0xFFFD: 0x172A,
	0xFFFD: 0x172B,
	0xFFFD: 0x172C,
	0xFFFD: 0x172D,
	0xFFFD: 0x172E,
	0xFFFD: 0x172F,
	0xFFFD: 0x1730,
	0xFFFD: 0x1731,
	0xFFFD: 0x1732,
	0xFFFD: 0x1733,
	0xFFFD: 0x1734,
	0xFFFD: 0x1735,
	0xFFFD: 0x1736,
	0xFFFD: 0x1737,
	0xFFFD: 0x1738,
	0xFFFD: 0x1739,
	0xFFFD: 0x173A,
	0xFFFD: 0x173B,
	0xFFFD: 0x173C,
	0xFFFD: 0x173D,
	0xFFFD: 0x173E,
	0xFFFD: 0x173F,
	0xFFFD: 0x1740,
	0xFFFD: 0x1741,
	0xFFFD: 0x1742,
	0xFFFD: 0x1743,
	0xFFFD: 0x1744,
	0xFFFD: 0x1745,
	0xFFFD: 0x1746,
	0xFFFD: 0x1747,
	0xFFFD: 0x1748,
	0xFFFD: 0x1749,
	0xFFFD: 0x174A,
	0xFFFD: 0x174B,
	0xFFFD: 0x174C,
	0xFFFD: 0x174D,
	0xFFFD: 0x174E,
	0xFFFD: 0x174F,
	0xFFFD: 0x1750,
	0xFFFD: 0x1751,
	0xFFFD: 0x1752,
	0xFFFD: 0x1753,
	0xFFFD: 0x1754,
	0xFFFD: 0x1755,
	0xFFFD: 0x1756,
	0xFFFD: 0x1757,
	0xFFFD: 0x1758,
	0xFFFD: 0x1759,
	0xFFFD: 0x175A,
	0xFFFD: 0x175B,
	0xFFFD: 0x175C,
	0xFFFD: 0x175D,
	0xFFFD: 0x175E,
	0xFFFD: 0x175F,
	0xFFFD: 0x1760,
	0xFFFD: 0x1761,
	0xFFFD: 0x1762,
	0xFFFD: 0x1763,
	0xFFFD: 0x1764,
	0xFFFD: 0x1765,
	0xFFFD: 0x1766,
	0xFFFD: 0x1767,
	0xFFFD: 0x1768,
	0xFFFD: 0x1769,
	0xFFFD: 0x176A,
	0xFFFD: 0x176B,
	0xFFFD: 0x176C,
	0xFFFD: 0x176D,
	0xFFFD: 0x176E,
	0xFFFD: 0x176F,
	0xFFFD: 0x1770,
	0xFFFD: 0x1771,
	0xFFFD: 0x1772,
	0xFFFD: 0x1773,
	0xFFFD: 0x1774,
	0xFFFD: 0x1775,
	0xFFFD: 0x1776,
	0xFFFD: 0x1777,
	0xFFFD: 0x1778,
	0xFFFD: 0x1779,
	0xFFFD: 0x177A,
	0xFFFD: 0x177B,
	0xFFFD: 0x177C,
	0xFFFD: 0x177D,
	0xFFFD: 0x177E,
	0xFFFD: 0x177F,
	0xFFFD: 0x1780,
	0xFFFD: 0x1781,
	0xFFFD: 0x1782,
	0xFFFD: 0x1783,
	0xFFFD: 0x1784,
	0xFFFD: 0x1785,
	0xFFFD: 0x1786,
	0xFFFD: 0x1787,
	0xFFFD: 0x1788,
	0xFFFD: 0x1789,
	0xFFFD: 0x178A,
	0xFFFD: 0x178B,
	0xFFFD: 0x178C,
	0xFFFD: 0x178D,
	0xFFFD: 0x178E,
	0xFFFD: 0x178F,
	0xFFFD: 0x1790,
	0xFFFD: 0x1791,
	0xFFFD: 0x1792,
	0xFFFD: 0x1793,
	0xFFFD: 0x1794,
	0xFFFD: 0x1795,
	0xFFFD: 0x1796,
	0xFFFD: 0x1797,
	0xFFFD: 0x1798,
	0xFFFD: 0x1799,
	0xFFFD: 0x179A,
	0xFFFD: 0x179B,
	0xFFFD: 0x179C,
	0xFFFD: 0x179D,
	0xFFFD: 0x179E,
	0xFFFD: 0x179F,
	0xFFFD: 0x17A0,
	0xFFFD: 0x17A1,
	0xFFFD: 0x17A2,
	0xFFFD: 0x17A3,
	0xFFFD: 0x17A4,
	0xFFFD: 0x17A5,
	0xFFFD: 0x17A6,
	0xFFFD: 0x17A7,
	0xFFFD: 0x17A8,
	0xFFFD: 0x17A9,
	0xFFFD: 0x17AA,
	0xFFFD: 0x17AB,
	0xFFFD: 0x17AC,
	0xFFFD: 0x17AD,
	0xFFFD: 0x17AE,
	0xFFFD: 0x17AF,
	0xFFFD: 0x17B0,
	0xFFFD: 0x17B1,
	0xFFFD: 0x17B2,
	0xFFFD: 0x17B3,
	0xFFFD: 0x17B4,
	0xFFFD: 0x17B5,
	0xFFFD: 0x17B6,
	0xFFFD: 0x17B7,
	0xFFFD: 0x17B8,
	0xFFFD: 0x17B9,
	0xFFFD: 0x17BA,
	0xFFFD: 0x17BB,
	0xFFFD: 0x17BC,
	0xFFFD: 0x17BD,
	0xFFFD: 0x17BE,
	0xFFFD: 0x17BF,
	0xFFFD: 0x17C0,
	0xFFFD: 0x17C1,
	0xFFFD: 0x17C2,
	0xFFFD: 0x17C3,
	0xFFFD: 0x17C4,
	0xFFFD: 0x17C5,
	0xFFFD: 0x17C6,
	0xFFFD: 0x17C7,
	0xFFFD: 0x17C8,
	0xFFFD: 0x17C9,
	0xFFFD: 0x17CA,
	0xFFFD: 0x17CB,
	0xFFFD: 0x17CC,
	0xFFFD: 0x17CD,
	0xFFFD: 0x17CE,
	0xFFFD: 0x17CF,
	0xFFFD: 0x17D0,
	0xFFFD: 0x17D1,
	0xFFFD: 0x17D2,
	0xFFFD: 0x17D3,
	0xFFFD: 0x17D4,
	0xFFFD: 0x17D5,
	0xFFFD: 0x17D6,
	0xFFFD: 0x17D7,
	0xFFFD: 0x17D8,
	0xFFFD: 0x17D9,
	0xFFFD: 0x17DA,
	0xFFFD: 0x17DB,
	0xFFFD: 0x17DC,
	0xFFFD: 0x17DD,
	0xFFFD: 0x17DE,
	0xFFFD: 0x17DF,
	0xFFFD: 0x17E0,
	0xFFFD: 0x17E1,
	0xFFFD: 0x17E2,
	0xFFFD: 0x17E3,
	0xFFFD: 0x17E4,
	0xFFFD: 0x17E5,
	0xFFFD: 0x17E6,
	0xFFFD: 0x17E7,
	0xFFFD: 0x17E8,
	0xFFFD: 0x17E9,
	0xFFFD: 0x17EA,
	0xFFFD: 0x17EB,
	0xFFFD: 0x17EC,
	0xFFFD: 0x17ED,
	0xFFFD: 0x17EE,
	0xFFFD: 0x17EF,
	0xFFFD: 0x17F0,
	0xFFFD: 0x17F1,
	0xFFFD: 0x17F2,
	0xFFFD: 0x17F3,
	0xFFFD: 0x17F4,
	0xFFFD: 0x17F5,
	0xFFFD: 0x17F6,
	0xFFFD: 0x17F7,
	0xFFFD: 0x17F8,
	0xFFFD: 0x17F9,
	0xFFFD: 0x17FA,
	0xFFFD: 0x17FB,
	0xFFFD: 0x17FC,
	0xFFFD: 0x17FD,
	0xFFFD: 0x17FE,
	0xFFFD: 0x17FF,
	0xFFFD: 0x1800,
	0xFFFD: 0x1801,
	0xFFFD: 0x1802,
	0xFFFD: 0x1803,
	0xFFFD: 0x1804,
	0xFFFD: 0x1805,
	0xFFFD: 0x1806,
	0xFFFD: 0x1807,
	0xFFFD: 0x1808,
	0xFFFD: 0x1809,
	0xFFFD: 0x180A,
	0xFFFD: 0x180B,
	0xFFFD: 0x180C,
	0xFFFD: 0x180D,
	0xFFFD: 0x180E,
	0xFFFD: 0x180F,
	0xFFFD: 0x1810,
	0xFFFD: 0x1811,
	0xFFFD: 0x1812,
	0xFFFD: 0x1813,
	0xFFFD: 0x1814,
	0xFFFD: 0x1815,
	0xFFFD: 0x1816,
	0xFFFD: 0x1817,
	0xFFFD: 0x1818,
	0xFFFD: 0x1819,
	0xFFFD: 0x181A,
	0xFFFD: 0x181B,
	0xFFFD: 0x181C,
	0xFFFD: 0x181D,
	0xFFFD: 0x181E,
	0xFFFD: 0x181F,
	0xFFFD: 0x1820,
	0xFFFD: 0x1821,
	0xFFFD: 0x1822,
	0xFFFD: 0x1823,
	0xFFFD: 0x1824,
	0xFFFD: 0x1825,
	0xFFFD: 0x1826,
	0xFFFD: 0x1827,
	0xFFFD: 0x1828,
	0xFFFD: 0x1829,
	0xFFFD: 0x182A,
	0xFFFD: 0x182B,
	0xFFFD: 0x182C,
	0xFFFD: 0x182D,
	0xFFFD: 0x182E,
	0xFFFD: 0x182F,
	0xFFFD: 0x1830,
	0xFFFD: 0x1831,
	0xFFFD: 0x1832,
	0xFFFD: 0x1833,
	0xFFFD: 0x1834,
	0xFFFD: 0x1835,
	0xFFFD: 0x1836,
	0xFFFD: 0x1837,
	0xFFFD: 0x1838,
	0xFFFD: 0x1839,
	0xFFFD: 0x183A,
	0xFFFD: 0x183B,
	0xFFFD: 0x183C,
	0xFFFD: 0x183D,
	0xFFFD: 0x183E,
	0xFFFD: 0x183F,
	0xFFFD: 0x1840,
	0xFFFD: 0x1841,
	0xFFFD: 0x1842,
	0xFFFD: 0x1843,
	0xFFFD: 0x1844,
	0xFFFD: 0x1845,
	0xFFFD: 0x1846,
	0xFFFD: 0x1847,
	0xFFFD: 0x1848,
	0xFFFD: 0x1849,
	0xFFFD: 0x184A,
	0xFFFD: 0x184B,
	0xFFFD: 0x184C,
	0xFFFD: 0x184D,
	0xFFFD: 0x184E,
	0xFFFD: 0x184F,
	0xFFFD: 0x1850,
	0xFFFD: 0x1851,
	0xFFFD: 0x1852,
	0xFFFD: 0x1853,
	0xFFFD: 0x1854,
	0xFFFD: 0x1855,
	0xFFFD: 0x1856,
	0xFFFD: 0x1857,
	0xFFFD: 0x1858,
	0xFFFD: 0x1859,
	0xFFFD: 0x185A,
	0xFFFD: 0x185B,
	0xFFFD: 0x185C,
	0xFFFD: 0x185D,
	0xFFFD: 0x185E,
	0xFFFD: 0x185F,
	0xFFFD: 0x1860,
	0xFFFD: 0x1861,
	0xFFFD: 0x1862,
	0xFFFD: 0x1863,
	0xFFFD: 0x1864,
	0xFFFD: 0x1865,
	0xFFFD: 0x1866,
	0xFFFD: 0x1867,
	0xFFFD: 0x1868,
	0xFFFD: 0x1869,
	0xFFFD: 0x186A,
	0xFFFD: 0x186B,
	0xFFFD: 0x186C,
	0xFFFD: 0x186D,
	0xFFFD: 0x186E,
	0xFFFD: 0x186F,
	0xFFFD: 0x1870,
	0xFFFD: 0x1871,
	0xFFFD: 0x1872,
	0xFFFD: 0x1873,
	0xFFFD: 0x1874,
	0xFFFD: 0x1875,
	0xFFFD: 0x1876,
	0xFFFD: 0x1877,
	0xFFFD: 0x1878,
	0xFFFD: 0x1879,
	0xFFFD: 0x187A,
	0xFFFD: 0x187B,
	0xFFFD: 0x187C,
	0xFFFD: 0x187D,
	0xFFFD: 0x187E,
	0xFFFD: 0x187F,
	0xFFFD: 0x1880,
	0xFFFD: 0x1881,
	0xFFFD: 0x1882,
	0xFFFD: 0x1883,
	0xFFFD: 0x1884,
	0xFFFD: 0x1885,
	0xFFFD: 0x1886,
	0xFFFD: 0x1887,
	0xFFFD: 0x1888,
	0xFFFD: 0x1889,
	0xFFFD: 0x188A,
	0xFFFD: 0x188B,
	0xFFFD: 0x188C,
	0xFFFD: 0x188D,
	0xFFFD: 0x188E,
	0xFFFD: 0x188F,
	0xFFFD: 0x1890,
	0xFFFD: 0x1891,
	0xFFFD: 0x1892,
	0xFFFD: 0x1893,
	0xFFFD: 0x1894,
	0xFFFD: 0x1895,
	0xFFFD: 0x1896,
	0xFFFD: 0x1897,
	0xFFFD: 0x1898,
	0xFFFD: 0x1899,
	0xFFFD: 0x189A,
	0xFFFD: 0x189B,
	0xFFFD: 0x189C,
	0xFFFD: 0x189D,
	0xFFFD: 0x189E,
	0xFFFD: 0x189F,
	0xFFFD: 0x18A0,
	0xFFFD: 0x18A1,
	0xFFFD: 0x18A2,
	0xFFFD: 0x18A3,
	0xFFFD: 0x18A4,
	0xFFFD: 0x18A5,
	0xFFFD: 0x18A6,
	0xFFFD: 0x18A7,
	0xFFFD: 0x18A8,
	0xFFFD: 0x18A9,
	0xFFFD: 0x18AA,
	0xFFFD: 0x18AB,
	0xFFFD: 0x18AC,
	0xFFFD: 0x18AD,
	0xFFFD: 0x18AE,
	0xFFFD: 0x18AF,
	0xFFFD: 0x18B0,
	0xFFFD: 0x18B1,
	0xFFFD: 0x18B2,
	0xFFFD: 0x18B3,
	0xFFFD: 0x18B4,
	0xFFFD: 0x18B5,
	0xFFFD: 0x18B6,
	0xFFFD: 0x18B7,
	0xFFFD: 0x18B8,
	0xFFFD: 0x18B9,
	0xFFFD: 0x18BA,
	0xFFFD: 0x18BB,
	0xFFFD: 0x18BC,
	0xFFFD: 0x18BD,
	0xFFFD: 0x18BE,
	0xFFFD: 0x18BF,
	0xFFFD: 0x18C0,
	0xFFFD: 0x18C1,
	0xFFFD: 0x18C2,
	0xFFFD: 0x18C3,
	0xFFFD: 0x18C4,
	0xFFFD: 0x18C5,
	0xFFFD: 0x18C6,
	0xFFFD: 0x18C7,
	0xFFFD: 0x18C8,
	0xFFFD: 0x18C9,
	0xFFFD: 0x18CA,
	0xFFFD: 0x18CB,
	0xFFFD: 0x18CC,
	0xFFFD: 0x18CD,
	0xFFFD: 0x18CE,
	0xFFFD: 0x18CF,
	0xFFFD: 0x18D0,
	0xFFFD: 0x18D1,
	0xFFFD: 0x18D2,
	0xFFFD: 0x18D3,
	0xFFFD: 0x18D4,
	0xFFFD: 0x18D5,
	0xFFFD: 0x18D6,
	0xFFFD: 0x18D7,
	0xFFFD: 0x18D8,
	0xFFFD: 0x18D9,
	0xFFFD: 0x18DA,
	0xFFFD: 0x18DB,
	0xFFFD: 0x18DC,
	0xFFFD: 0x18DD,
	0xFFFD: 0x18DE,
	0xFFFD: 0x18DF,
	0xFFFD: 0x18E0,
	0xFFFD: 0x18E1,
	0xFFFD: 0x18E2,
	0xFFFD: 0x18E3,
	0xFFFD: 0x18E4,
	0xFFFD: 0x18E5,
	0xFFFD: 0x18E6,
	0xFFFD: 0x18E7,
	0xFFFD: 0x18E8,
	0xFFFD: 0x18E9,
	0xFFFD: 0x18EA,
	0xFFFD: 0x18EB,
	0xFFFD: 0x18EC,
	0xFFFD: 0x18ED,
	0xFFFD: 0x18EE,
	0xFFFD: 0x18EF,
	0xFFFD: 0x18F0,
	0xFFFD: 0x18F1,
	0xFFFD: 0x18F2,
	0xFFFD: 0x18F3,
	0xFFFD: 0x18F4,
	0xFFFD: 0x18F5,
	0xFFFD: 0x18F6,
	0xFFFD: 0x18F7,
	0xFFFD: 0x18F8,
	0xFFFD: 0x18F9,
	0xFFFD: 0x18FA,
	0xFFFD: 0x18FB,
	0xFFFD: 0x18FC,
	0xFFFD: 0x18FD,
	0xFFFD: 0x18FE,
	0xFFFD: 0x18FF,
	0xFFFD: 0x1900,
	0xFFFD: 0x1901,
	0xFFFD: 0x1902,
	0xFFFD: 0x1903,
	0xFFFD: 0x1904,
	0xFFFD: 0x1905,
	0xFFFD: 0x1906,
	0xFFFD: 0x1907,
	0xFFFD: 0x1908,
	0xFFFD: 0x1909,
	0xFFFD: 0x190A,
	0xFFFD: 0x190B,
	0xFFFD: 0x190C,
	0xFFFD: 0x190D,
	0xFFFD: 0x190E,
	0xFFFD: 0x190F,
	0xFFFD: 0x1910,
	0xFFFD: 0x1911,
	0xFFFD: 0x1912,
	0xFFFD: 0x1913,
	0xFFFD: 0x1914,
	0xFFFD: 0x1915,
	0xFFFD: 0x1916,
	0xFFFD: 0x1917,
	0xFFFD: 0x1918,
	0xFFFD: 0x1919,
	0xFFFD: 0x191A,
	0xFFFD: 0x191B,
	0xFFFD: 0x191C,
	0xFFFD: 0x191D,
	0xFFFD: 0x191E,
	0xFFFD: 0x191F,
	0xFFFD: 0x1920,
	0xFFFD: 0x1921,
	0xFFFD: 0x1922,
	0xFFFD: 0x1923,
	0xFFFD: 0x1924,
	0xFFFD: 0x1925,
	0xFFFD: 0x1926,
	0xFFFD: 0x1927,
	0xFFFD: 0x1928,
	0xFFFD: 0x1929,
	0xFFFD: 0x192A,
	0xFFFD: 0x192B,
	0xFFFD: 0x192C,
	0xFFFD: 0x192D,
	0xFFFD: 0x192E,
	0xFFFD: 0x192F,
	0xFFFD: 0x1930,
	0xFFFD: 0x1931,
	0xFFFD: 0x1932,
	0xFFFD: 0x1933,
	0xFFFD: 0x1934,
	0xFFFD: 0x1935,
	0xFFFD: 0x1936,
	0xFFFD: 0x1937,
	0xFFFD: 0x1938,
	0xFFFD: 0x1939,
	0xFFFD: 0x193A,
	0xFFFD: 0x193B,
	0xFFFD: 0x193C,
	0xFFFD: 0x193D,
	0xFFFD: 0x193E,
	0xFFFD: 0x193F,
	0xFFFD: 0x1940,
	0xFFFD: 0x1941,
	0xFFFD: 0x1942,
	0xFFFD: 0x1943,
	0xFFFD: 0x1944,
	0xFFFD: 0x1945,
	0xFFFD: 0x1946,
	0xFFFD: 0x1947,
	0xFFFD: 0x1948,
	0xFFFD: 0x1949,
	0xFFFD: 0x194A,
	0xFFFD: 0x194B,
	0xFFFD: 0x194C,
	0xFFFD: 0x194D,
	0xFFFD: 0x194E,
	0xFFFD: 0x194F,
	0xFFFD: 0x1950,
	0xFFFD: 0x1951,
	0xFFFD: 0x1952,
	0xFFFD: 0x1953,
	0xFFFD: 0x1954,
	0xFFFD: 0x1955,
	0xFFFD: 0x1956,
	0xFFFD: 0x1957,
	0xFFFD: 0x1958,
	0xFFFD: 0x1959,
	0xFFFD: 0x195A,
	0xFFFD: 0x195B,
	0xFFFD: 0x195C,
	0xFFFD: 0x195D,
	0xFFFD: 0x195E,
	0xFFFD: 0x195F,
	0xFFFD: 0x1960,
	0xFFFD: 0x1961,
	0xFFFD: 0x1962,
	0xFFFD: 0x1963,
	0xFFFD: 0x1964,
	0xFFFD: 0x1965,
	0xFFFD: 0x1966,
	0xFFFD: 0x1967,
	0xFFFD: 0x1968,
	0xFFFD: 0x1969,
	0xFFFD: 0x196A,
	0xFFFD: 0x196B,
	0xFFFD: 0x196C,
	0xFFFD: 0x196D,
	0xFFFD: 0x196E,
	0xFFFD: 0x196F,
	0xFFFD: 0x1970,
	0xFFFD: 0x1971,
	0xFFFD: 0x1972,
	0xFFFD: 0x1973,
	0xFFFD: 0x1974,
	0xFFFD: 0x1975,
	0xFFFD: 0x1976,
	0xFFFD: 0x1977,
	0xFFFD: 0x1978,
	0xFFFD: 0x1979,
	0xFFFD: 0x197A,
	0xFFFD: 0x197B,
	0xFFFD: 0x197C,
	0xFFFD: 0x197D,
	0xFFFD: 0x197E,
	0xFFFD: 0x197F,
	0xFFFD: 0x1980,
	0xFFFD: 0x1981,
	0xFFFD: 0x1982,
	0xFFFD: 0x1983,
	0xFFFD: 0x1984,
	0xFFFD: 0x1985,
	0xFFFD: 0x1986,
	0xFFFD: 0x1987,
	0xFFFD: 0x1988,
	0xFFFD: 0x1989,
	0xFFFD: 0x198A,
	0xFFFD: 0x198B,
	0xFFFD: 0x198C,
	0xFFFD: 0x198D,
	0xFFFD: 0x198E,
	0xFFFD: 0x198F,
	0xFFFD: 0x1990,
	0xFFFD: 0x1991,
	0xFFFD: 0x1992,
	0xFFFD: 0x1993,
	0xFFFD: 0x1994,
	0xFFFD: 0x1995,
	0xFFFD: 0x1996,
	0xFFFD: 0x1997,
	0xFFFD: 0x1998,
	0xFFFD: 0x1999,
	0xFFFD: 0x199A,
	0xFFFD: 0x199B,
	0xFFFD: 0x199C,
	0xFFFD: 0x199D,
	0xFFFD: 0x199E,
	0xFFFD: 0x199F,
	0xFFFD: 0x19A0,
	0xFFFD: 0x19A1,
	0xFFFD: 0x19A2,
	0xFFFD: 0x19A3,
	0xFFFD: 0x19A4,
	0xFFFD: 0x19A5,
	0xFFFD: 0x19A6,
	0xFFFD: 0x19A7,
	0xFFFD: 0x19A8,
	0xFFFD: 0x19A9,
	0xFFFD: 0x19AA,
	0xFFFD: 0x19AB,
	0xFFFD: 0x19AC,
	0xFFFD: 0x19AD,
	0xFFFD: 0x19AE,
	0xFFFD: 0x19AF,
	0xFFFD: 0x19B0,
	0xFFFD: 0x19B1,
	0xFFFD: 0x19B2,
	0xFFFD: 0x19B3,
	0xFFFD: 0x19B4,
	0xFFFD: 0x19B5,
	0xFFFD: 0x19B6,
	0xFFFD: 0x19B7,
	0xFFFD: 0x19B8,
	0xFFFD: 0x19B9,
	0xFFFD: 0x19BA,
	0xFFFD: 0x19BB,
	0xFFFD: 0x19BC,
	0xFFFD: 0x19BD,
	0xFFFD: 0x19BE,
	0xFFFD: 0x19BF,
	0xFFFD: 0x19C0,
	0xFFFD: 0x19C1,
	0xFFFD: 0x19C2,
	0xFFFD: 0x19C3,
	0xFFFD: 0x19C4,
	0xFFFD: 0x19C5,
	0xFFFD: 0x19C6,
	0xFFFD: 0x19C7,
	0xFFFD: 0x19C8,
	0xFFFD: 0x19C9,
	0xFFFD: 0x19CA,
	0xFFFD: 0x19CB,
	0xFFFD: 0x19CC,
	0xFFFD: 0x19CD,
	0xFFFD: 0x19CE,
	0xFFFD: 0x19CF,
	0xFFFD: 0x19D0,
	0xFFFD: 0x19D1,
	0xFFFD: 0x19D2,
	0xFFFD: 0x19D3,
	0xFFFD: 0x19D4,
	0xFFFD: 0x19D5,
	0xFFFD: 0x19D6,
	0xFFFD: 0x19D7,
	0xFFFD: 0x19D8,
	0xFFFD: 0x19D9,
	0xFFFD: 0x19DA,
	0xFFFD: 0x19DB,
	0xFFFD: 0x19DC,
	0xFFFD: 0x19DD,
	0xFFFD: 0x19DE,
	0xFFFD: 0x19DF,
	0xFFFD: 0x19E0,
	0xFFFD: 0x19E1,
	0xFFFD: 0x19E2,
	0xFFFD: 0x19E3,
	0xFFFD: 0x19E4,
	0xFFFD: 0x19E5,
	0xFFFD: 0x19E6,
	0xFFFD: 0x19E7,
	0xFFFD: 0x19E8,
	0xFFFD: 0x19E9,
	0xFFFD: 0x19EA,
	0xFFFD: 0x19EB,
	0xFFFD: 0x19EC,
	0xFFFD: 0x19ED,
	0xFFFD: 0x19EE,
	0xFFFD: 0x19EF,
	0xFFFD: 0x19F0,
	0xFFFD: 0x19F1,
	0xFFFD: 0x19F2,
	0xFFFD: 0x19F3,
	0xFFFD: 0x19F4,
	0xFFFD: 0x19F5,
	0xFFFD: 0x19F6,
	0xFFFD: 0x19F7,
	0xFFFD: 0x19F8,
	0xFFFD: 0x19F9,
	0xFFFD: 0x19FA,
	0xFFFD: 0x19FB,
	0xFFFD: 0x19FC,
	0xFFFD: 0x19FD,
	0xFFFD: 0x19FE,
	0xFFFD: 0x19FF,
	0xFFFD: 0x1A00,
	0xFFFD: 0x1A01,
	0xFFFD: 0x1A02,
	0xFFFD: 0x1A03,
	0xFFFD: 0x1A04,
	0xFFFD: 0x1A05,
	0xFFFD: 0x1A06,
	0xFFFD: 0x1A07,
	0xFFFD: 0x1A08,
	0xFFFD: 0x1A09,
	0xFFFD: 0x1A0A,
	0xFFFD: 0x1A0B,
	0xFFFD: 0x1A0C,
	0xFFFD: 0x1A0D,
	0xFFFD: 0x1A0E,
	0xFFFD: 0x1A0F,
	0xFFFD: 0x1A10,
	0xFFFD: 0x1A11,
	0xFFFD: 0x1A12,
	0xFFFD: 0x1A13,
	0xFFFD: 0x1A14,
	0xFFFD: 0x1A15,
	0xFFFD: 0x1A16,
	0xFFFD: 0x1A17,
	0xFFFD: 0x1A18,
	0xFFFD: 0x1A19,
	0xFFFD: 0x1A1A,
	0xFFFD: 0x1A1B,
	0xFFFD: 0x1A1C,
	0xFFFD: 0x1A1D,
	0xFFFD: 0x1A1E,
	0xFFFD: 0x1A1F,
	0xFFFD: 0x1A20,
	0xFFFD: 0x1A21,
	0xFFFD: 0x1A22,
	0xFFFD: 0x1A23,
	0xFFFD: 0x1A24,
	0xFFFD: 0x1A25,
	0xFFFD: 0x1A26,
	0xFFFD: 0x1A27,
	0xFFFD: 0x1A28,
	0xFFFD: 0x1A29,
	0xFFFD: 0x1A2A,
	0xFFFD: 0x1A2B,
	0xFFFD: 0x1A2C,
	0xFFFD: 0x1A2D,
	0xFFFD: 0x1A2E,
	0xFFFD: 0x1A2F,
	0xFFFD: 0x1A30,
	0xFFFD: 0x1A31,
	0xFFFD: 0x1A32,
	0xFFFD: 0x1A33,
	0xFFFD: 0x1A34,
	0xFFFD: 0x1A35,
	0xFFFD: 0x1A36,
	0xFFFD: 0x1A37,
	0xFFFD: 0x1A38,
	0xFFFD: 0x1A39,
	0xFFFD: 0x1A3A,
	0xFFFD: 0x1A3B,
	0xFFFD: 0x1A3C,
	0xFFFD: 0x1A3D,
	0xFFFD: 0x1A3E,
	0xFFFD: 0x1A3F,
	0xFFFD: 0x1A40,
	0xFFFD: 0x1A41,
	0xFFFD: 0x1A42,
	0xFFFD: 0x1A43,
	0xFFFD: 0x1A44,
	0xFFFD: 0x1A45,
	0xFFFD: 0x1A46,
	0xFFFD: 0x1A47,
	0xFFFD: 0x1A48,
	0xFFFD: 0x1A49,
	0xFFFD: 0x1A4A,
	0xFFFD: 0x1A4B,
	0xFFFD: 0x1A4C,
	0xFFFD: 0x1A4D,
	0xFFFD: 0x1A4E,
	0xFFFD: 0x1A4F,
	0xFFFD: 0x1A50,
	0xFFFD: 0x1A51,
	0xFFFD: 0x1A52,
	0xFFFD: 0x1A53,
	0xFFFD: 0x1A54,
	0xFFFD: 0x1A55,
	0xFFFD: 0x1A56,
	0xFFFD: 0x1A57,
	0xFFFD: 0x1A58,
	0xFFFD: 0x1A59,
	0xFFFD: 0x1A5A,
	0xFFFD: 0x1A5B,
	0xFFFD: 0x1A5C,
	0xFFFD: 0x1A5D,
	0xFFFD: 0x1A5E,
	0xFFFD: 0x1A5F,
	0xFFFD: 0x1A60,
	0xFFFD: 0x1A61,
	0xFFFD: 0x1A62,
	0xFFFD: 0x1A63,
	0xFFFD: 0x1A64,
	0xFFFD: 0x1A65,
	0xFFFD: 0x1A66,
	0xFFFD: 0x1A67,
	0xFFFD: 0x1A68,
	0xFFFD: 0x1A69,
	0xFFFD: 0x1A6A,
	0xFFFD: 0x1A6B,
	0xFFFD: 0x1A6C,
	0xFFFD: 0x1A6D,
	0xFFFD: 0x1A6E,
	0xFFFD: 0x1A6F,
	0xFFFD: 0x1A70,
	0xFFFD: 0x1A71,
	0xFFFD: 0x1A72,
	0xFFFD: 0x1A73,
	0xFFFD: 0x1A74,
	0xFFFD: 0x1A75,
	0xFFFD: 0x1A76,
	0xFFFD: 0x1A77,
	0xFFFD: 0x1A78,
	0xFFFD: 0x1A79,
	0xFFFD: 0x1A7A,
	0xFFFD: 0x1A7B,
	0xFFFD: 0x1A7C,
	0xFFFD: 0x1A7D,
	0xFFFD: 0x1A7E,
	0xFFFD: 0x1A7F,
	0xFFFD: 0x1A80,
	0xFFFD: 0x1A81,
	0xFFFD: 0x1A82,
	0xFFFD: 0x1A83,
	0xFFFD: 0x1A84,
	0xFFFD: 0x1A85,
	0xFFFD: 0x1A86,
	0xFFFD: 0x1A87,
	0xFFFD: 0x1A88,
	0xFFFD: 0x1A89,
	0xFFFD: 0x1A8A,
	0xFFFD: 0x1A8B,
	0xFFFD: 0x1A8C,
	0xFFFD: 0x1A8D,
	0xFFFD: 0x1A8E,
	0xFFFD: 0x1A8F,
	0xFFFD: 0x1A90,
	0xFFFD: 0x1A91,
	0xFFFD: 0x1A92,
	0xFFFD: 0x1A93,
	0xFFFD: 0x1A94,
	0xFFFD: 0x1A95,
	0xFFFD: 0x1A96,
	0xFFFD: 0x1A97,
	0xFFFD: 0x1A98,
	0xFFFD: 0x1A99,
	0xFFFD: 0x1A9A,
	0xFFFD: 0x1A9B,
	0xFFFD: 0x1A9C,
	0xFFFD: 0x1A9D,
	0xFFFD: 0x1A9E,
	0xFFFD: 0x1A9F,
	0xFFFD: 0x1AA0,
	0xFFFD: 0x1AA1,
	0xFFFD: 0x1AA2,
	0xFFFD: 0x1AA3,
	0xFFFD: 0x1AA4,
	0xFFFD: 0x1AA5,
	0xFFFD: 0x1AA6,
	0xFFFD: 0x1AA7,
	0xFFFD: 0x1AA8,
	0xFFFD: 0x1AA9,
	0xFFFD: 0x1AAA,
	0xFFFD: 0x1AAB,
	0xFFFD: 0x1AAC,
	0xFFFD: 0x1AAD,
	0xFFFD: 0x1AAE,
	0xFFFD: 0x1AAF,
	0xFFFD: 0x1AB0,
	0xFFFD: 0x1AB1,
	0xFFFD: 0x1AB2,
	0xFFFD: 0x1AB3,
	0xFFFD: 0x1AB4,
	0xFFFD: 0x1AB5,
	0xFFFD: 0x1AB6,
	0xFFFD: 0x1AB7,
	0xFFFD: 0x1AB8,
	0xFFFD: 0x1AB9,
	0xFFFD: 0x1ABA,
	0xFFFD: 0x1ABB,
	0xFFFD: 0x1ABC,
	0xFFFD: 0x1ABD,
	0xFFFD: 0x1ABE,
	0xFFFD: 0x1ABF,
	0xFFFD: 0x1AC0,
	0xFFFD: 0x1AC1,
	0xFFFD: 0x1AC2,
	0xFFFD: 0x1AC3,
	0xFFFD: 0x1AC4,
	0xFFFD: 0x1AC5,
	0xFFFD: 0x1AC6,
	0xFFFD: 0x1AC7,
	0xFFFD: 0x1AC8,
	0xFFFD: 0x1AC9,
	0xFFFD: 0x1ACA,
	0xFFFD: 0x1ACB,
	0xFFFD: 0x1ACC,
	0xFFFD: 0x1ACD,
	0xFFFD: 0x1ACE,
	0xFFFD: 0x1ACF,
	0xFFFD: 0x1AD0,
	0xFFFD: 0x1AD1,
	0xFFFD: 0x1AD2,
	0xFFFD: 0x1AD3,
	0xFFFD: 0x1AD4,
	0xFFFD: 0x1AD5,
	0xFFFD: 0x1AD6,
	0xFFFD: 0x1AD7,
	0xFFFD: 0x1AD8,
	0xFFFD: 0x1AD9,
	0xFFFD: 0x1ADA,
	0xFFFD: 0x1ADB,
	0xFFFD: 0x1ADC,
	0xFFFD: 0x1ADD,
	0xFFFD: 0x1ADE,
	0xFFFD: 0x1ADF,
	0xFFFD: 0x1AE0,
	0xFFFD: 0x1AE1,
	0xFFFD: 0x1AE2,
	0xFFFD: 0x1AE3,
	0xFFFD: 0x1AE4,
	0xFFFD: 0x1AE5,
	0xFFFD: 0x1AE6,
	0xFFFD: 0x1AE7,
	0xFFFD: 0x1AE8,
	0xFFFD: 0x1AE9,
	0xFFFD: 0x1AEA,
	0xFFFD: 0x1AEB,
	0xFFFD: 0x1AEC,
	0xFFFD: 0x1AED,
	0xFFFD: 0x1AEE,
	0xFFFD: 0x1AEF,
	0xFFFD: 0x1AF0,
	0xFFFD: 0x1AF1,
	0xFFFD: 0x1AF2,
	0xFFFD: 0x1AF3,
	0xFFFD: 0x1AF4,
	0xFFFD: 0x1AF5,
	0xFFFD: 0x1AF6,
	0xFFFD: 0x1AF7,
	0xFFFD: 0x1AF8,
	0xFFFD: 0x1AF9,
	0xFFFD: 0x1AFA,
	0xFFFD: 0x1AFB,
	0xFFFD: 0x1AFC,
	0xFFFD: 0x1AFD,
	0xFFFD: 0x1AFE,
	0xFFFD: 0x1AFF,
	0xFFFD: 0x1B00,
	0xFFFD: 0x1B01,
	0xFFFD: 0x1B02,
	0xFFFD: 0x1B03,
	0xFFFD: 0x1B04,
	0xFFFD: 0x1B05,
	0xFFFD: 0x1B06,
	0xFFFD: 0x1B07,
	0xFFFD: 0x1B08,
	0xFFFD: 0x1B09,
	0xFFFD: 0x1B0A,
	0xFFFD: 0x1B0B,
	0xFFFD: 0x1B0C,
	0xFFFD: 0x1B0D,
	0xFFFD: 0x1B0E,
	0xFFFD: 0x1B0F,
	0xFFFD: 0x1B10,
	0xFFFD: 0x1B11,
	0xFFFD: 0x1B12,
	0xFFFD: 0x1B13,
	0xFFFD: 0x1B14,
	0xFFFD: 0x1B15,
	0xFFFD: 0x1B16,
	0xFFFD: 0x1B17,
	0xFFFD: 0x1B18,
	0xFFFD: 0x1B19,
	0xFFFD: 0x1B1A,
	0xFFFD: 0x1B1B,
	0xFFFD: 0x1B1C,
	0xFFFD: 0x1B1D,
	0xFFFD: 0x1B1E,
	0xFFFD: 0x1B1F,
	0xFFFD: 0x1B20,
	0xFFFD: 0x1B21,
	0xFFFD: 0x1B22,
	0xFFFD: 0x1B23,
	0xFFFD: 0x1B24,
	0xFFFD: 0x1B25,
	0xFFFD: 0x1B26,
	0xFFFD: 0x1B27,
	0xFFFD: 0x1B28,
	0xFFFD: 0x1B29,
	0xFFFD: 0x1B2A,
	0xFFFD: 0x1B2B,
	0xFFFD: 0x1B2C,
	0xFFFD: 0x1B2D,
	0xFFFD: 0x1B2E,
	0xFFFD: 0x1B2F,
	0xFFFD: 0x1B30,
	0xFFFD: 0x1B31,
	0xFFFD: 0x1B32,
	0xFFFD: 0x1B33,
	0xFFFD: 0x1B34,
	0xFFFD: 0x1B35,
	0xFFFD: 0x1B36,
	0xFFFD: 0x1B37,
	0xFFFD: 0x1B38,
	0xFFFD: 0x1B39,
	0xFFFD: 0x1B3A,
	0xFFFD: 0x1B3B,
	0xFFFD: 0x1B3C,
	0xFFFD: 0x1B3D,
	0xFFFD: 0x1B3E,
	0xFFFD: 0x1B3F,
	0xFFFD: 0x1B40,
	0xFFFD: 0x1B41,
	0xFFFD: 0x1B42,
	0xFFFD: 0x1B43,
	0xFFFD: 0x1B44,
	0xFFFD: 0x1B45,
	0xFFFD: 0x1B46,
	0xFFFD: 0x1B47,
	0xFFFD: 0x1B48,
	0xFFFD: 0x1B49,
	0xFFFD: 0x1B4A,
	0xFFFD: 0x1B4B,
	0xFFFD: 0x1B4C,
	0xFFFD: 0x1B4D,
	0xFFFD: 0x1B4E,
	0xFFFD: 0x1B4F,
	0xFFFD: 0x1B50,
	0xFFFD: 0x1B51,
	0xFFFD: 0x1B52,
	0xFFFD: 0x1B53,
	0xFFFD: 0x1B54,
	0xFFFD: 0x1B55,
	0xFFFD: 0x1B56,
	0xFFFD: 0x1B57,
	0xFFFD: 0x1B58,
	0xFFFD: 0x1B59,
	0xFFFD: 0x1B5A,
	0xFFFD: 0x1B5B,
	0xFFFD: 0x1B5C,
	0xFFFD: 0x1B5D,
	0xFFFD: 0x1B5E,
	0xFFFD: 0x1B5F,
	0xFFFD: 0x1B60,
	0xFFFD: 0x1B61,
	0xFFFD: 0x1B62,
	0xFFFD: 0x1B63,
	0xFFFD: 0x1B64,
	0xFFFD: 0x1B65,
	0xFFFD: 0x1B66,
	0xFFFD: 0x1B67,
	0xFFFD: 0x1B68,
	0xFFFD: 0x1B69,
	0xFFFD: 0x1B6A,
	0xFFFD: 0x1B6B,
	0xFFFD: 0x1B6C,
	0xFFFD: 0x1B6D,
	0xFFFD: 0x1B6E,
	0xFFFD: 0x1B6F,
	0xFFFD: 0x1B70,
	0xFFFD: 0x1B71,
	0xFFFD: 0x1B72,
	0xFFFD: 0x1B73,
	0xFFFD: 0x1B74,
	0xFFFD: 0x1B75,
	0xFFFD: 0x1B76,
	0xFFFD: 0x1B77,
	0xFFFD: 0x1B78,
	0xFFFD: 0x1B79,
	0xFFFD: 0x1B7A,
	0xFFFD: 0x1B7B,
	0xFFFD: 0x1B7C,
	0xFFFD: 0x1B7D,
	0xFFFD: 0x1B7E,
	0xFFFD: 0x1B7F,
	0xFFFD: 0x1B80,
	0xFFFD: 0x1B81,
	0xFFFD: 0x1B82,
	0xFFFD: 0x1B83,
	0xFFFD: 0x1B84,
	0xFFFD: 0x1B85,
	0xFFFD: 0x1B86,
	0xFFFD: 0x1B87,
	0xFFFD: 0x1B88,
	0xFFFD: 0x1B89,
	0xFFFD: 0x1B8A,
	0xFFFD: 0x1B8B,
	0xFFFD: 0x1B8C,
	0xFFFD: 0x1B8D,
	0xFFFD: 0x1B8E,
	0xFFFD: 0x1B8F,
	0xFFFD: 0x1B90,
	0xFFFD: 0x1B91,
	0xFFFD: 0x1B92,
	0xFFFD: 0x1B93,
	0xFFFD: 0x1B94,
	0xFFFD: 0x1B95,
	0xFFFD: 0x1B96,
	0xFFFD: 0x1B97,
	0xFFFD: 0x1B98,
	0xFFFD: 0x1B99,
	0xFFFD: 0x1B9A,
	0xFFFD: 0x1B9B,
	0xFFFD: 0x1B9C,
	0xFFFD: 0x1B9D,
	0xFFFD: 0x1B9E,
	0xFFFD: 0x1B9F,
	0xFFFD: 0x1BA0,
	0xFFFD: 0x1BA1,
	0xFFFD: 0x1BA2,
	0xFFFD: 0x1BA3,
	0xFFFD: 0x1BA4,
	0xFFFD: 0x1BA5,
	0xFFFD: 0x1BA6,
	0xFFFD: 0x1BA7,
	0xFFFD: 0x1BA8,
	0xFFFD: 0x1BA9,
	0xFFFD: 0x1BAA,
	0xFFFD: 0x1BAB,
	0xFFFD: 0x1BAC,
	0xFFFD: 0x1BAD,
	0xFFFD: 0x1BAE,
	0xFFFD: 0x1BAF,
	0xFFFD: 0x1BB0,
	0xFFFD: 0x1BB1,
	0xFFFD: 0x1BB2,
	0xFFFD: 0x1BB3,
	0xFFFD: 0x1BB4,
	0xFFFD: 0x1BB5,
	0xFFFD: 0x1BB6,
	0xFFFD: 0x1BB7,
	0xFFFD: 0x1BB8,
	0xFFFD: 0x1BB9,
	0xFFFD: 0x1BBA,
	0xFFFD: 0x1BBB,
	0xFFFD: 0x1BBC,
	0xFFFD: 0x1BBD,
	0xFFFD: 0x1BBE,
	0xFFFD: 0x1BBF,
	0xFFFD: 0x1BC0,
	0xFFFD: 0x1BC1,
	0xFFFD: 0x1BC2,
	0xFFFD: 0x1BC3,
	0xFFFD: 0x1BC4,
	0xFFFD: 0x1BC5,
	0xFFFD: 0x1BC6,
	0xFFFD: 0x1BC7,
	0xFFFD: 0x1BC8,
	0xFFFD: 0x1BC9,
	0xFFFD: 0x1BCA,
	0xFFFD: 0x1BCB,
	0xFFFD: 0x1BCC,
	0xFFFD: 0x1BCD,
	0xFFFD: 0x1BCE,
	0xFFFD: 0x1BCF,
	0xFFFD: 0x1BD0,
	0xFFFD: 0x1BD1,
	0xFFFD: 0x1BD2,
	0xFFFD: 0x1BD3,
	0xFFFD: 0x1BD4,
	0xFFFD: 0x1BD5,
	0xFFFD: 0x1BD6,
	0xFFFD: 0x1BD7,
	0xFFFD: 0x1BD8,
	0xFFFD: 0x1BD9,
	0xFFFD: 0x1BDA,
	0xFFFD: 0x1BDB,
	0xFFFD: 0x1BDC,
	0xFFFD: 0x1BDD,
	0xFFFD: 0x1BDE,
	0xFFFD: 0x1BDF,
	0xFFFD: 0x1BE0,
	0xFFFD: 0x1BE1,
	0xFFFD: 0x1BE2,
	0xFFFD: 0x1BE3,
	0xFFFD: 0x1BE4,
	0xFFFD: 0x1BE5,
	0xFFFD: 0x1BE6,
	0xFFFD: 0x1BE7,
	0xFFFD: 0x1BE8,
	0xFFFD: 0x1BE9,
	0xFFFD: 0x1BEA,
	0xFFFD: 0x1BEB,
	0xFFFD: 0x1BEC,
	0xFFFD: 0x1BED,
	0xFFFD: 0x1BEE,
	0xFFFD: 0x1BEF,
	0xFFFD: 0x1BF0,
	0xFFFD: 0x1BF1,
	0xFFFD: 0x1BF2,
	0xFFFD: 0x1BF3,
	0xFFFD: 0x1BF4,
	0xFFFD: 0x1BF5,
	0xFFFD: 0x1BF6,
	0xFFFD: 0x1BF7,
	0xFFFD: 0x1BF8,
	0xFFFD: 0x1BF9,
	0xFFFD: 0x1BFA,
	0xFFFD: 0x1BFB,
	0xFFFD: 0x1BFC,
	0xFFFD: 0x1BFD,
	0xFFFD: 0x1BFE,
	0xFFFD: 0x1BFF,
	0xFFFD: 0x1C00,
	0xFFFD: 0x1C01,
	0xFFFD: 0x1C02,
	0xFFFD: 0x1C03,
	0xFFFD: 0x1C04,
	0xFFFD: 0x1C05,
	0xFFFD: 0x1C06,
	0xFFFD: 0x1C07,
	0xFFFD: 0x1C08,
	0xFFFD: 0x1C09,
	0xFFFD: 0x1C0A,
	0xFFFD: 0x1C0B,
	0xFFFD: 0x1C0C,
	0xFFFD: 0x1C0D,
	0xFFFD: 0x1C0E,
	0xFFFD: 0x1C0F,
	0xFFFD: 0x1C10,
	0xFFFD: 0x1C11,
	0xFFFD: 0x1C12,
	0xFFFD: 0x1C13,
	0xFFFD: 0x1C14,
	0xFFFD: 0x1C15,
	0xFFFD: 0x1C16,
	0xFFFD: 0x1C17,
	0xFFFD: 0x1C18,
	0xFFFD: 0x1C19,
	0xFFFD: 0x1C1A,
	0xFFFD: 0x1C1B,
	0xFFFD: 0x1C1C,
	0xFFFD: 0x1C1D,
	0xFFFD: 0x1C1E,
	0xFFFD: 0x1C1F,
	0xFFFD: 0x1C20,
	0xFFFD: 0x1C21,
	0xFFFD: 0x1C22,
	0xFFFD: 0x1C23,
	0xFFFD: 0x1C24,
	0xFFFD: 0x1C25,
	0xFFFD: 0x1C26,
	0xFFFD: 0x1C27,
	0xFFFD: 0x1C28,
	0xFFFD: 0x1C29,
	0xFFFD: 0x1C2A,
	0xFFFD: 0x1C2B,
	0xFFFD: 0x1C2C,
	0xFFFD: 0x1C2D,
	0xFFFD: 0x1C2E,
	0xFFFD: 0x1C2F,
	0xFFFD: 0x1C30,
	0xFFFD: 0x1C31,
	0xFFFD: 0x1C32,
	0xFFFD: 0x1C33,
	0xFFFD: 0x1C34,
	0xFFFD: 0x1C35,
	0xFFFD: 0x1C36,
	0xFFFD: 0x1C37,
	0xFFFD: 0x1C38,
	0xFFFD: 0x1C39,
	0xFFFD: 0x1C3A,
	0xFFFD: 0x1C3B,
	0xFFFD: 0x1C3C,
	0xFFFD: 0x1C3D,
	0xFFFD: 0x1C3E,
	0xFFFD: 0x1C3F,
	0xFFFD: 0x1C40,
	0xFFFD: 0x1C41,
	0xFFFD: 0x1C42,
	0xFFFD: 0x1C43,
	0xFFFD: 0x1C44,
	0xFFFD: 0x1C45,
	0xFFFD: 0x1C46,
	0xFFFD: 0x1C47,
	0xFFFD: 0x1C48,
	0xFFFD: 0x1C49,
	0xFFFD: 0x1C4A,
	0xFFFD: 0x1C4B,
	0xFFFD: 0x1C4C,
	0xFFFD: 0x1C4D,
	0xFFFD: 0x1C4E,
	0xFFFD: 0x1C4F,
	0xFFFD: 0x1C50,
	0xFFFD: 0x1C51,
	0xFFFD: 0x1C52,
	0xFFFD: 0x1C53,
	0xFFFD: 0x1C54,
	0xFFFD: 0x1C55,
	0xFFFD: 0x1C56,
	0xFFFD: 0x1C57,
	0xFFFD: 0x1C58,
	0xFFFD: 0x1C59,
	0xFFFD: 0x1C5A,
	0xFFFD: 0x1C5B,
	0xFFFD: 0x1C5C,
	0xFFFD: 0x1C5D,
	0xFFFD: 0x1C5E,
	0xFFFD: 0x1C5F,
	0xFFFD: 0x1C60,
	0xFFFD: 0x1C61,
	0xFFFD: 0x1C62,
	0xFFFD: 0x1C63,
	0xFFFD: 0x1C64,
	0xFFFD: 0x1C65,
	0xFFFD: 0x1C66,
	0xFFFD: 0x1C67,
	0xFFFD: 0x1C68,
	0xFFFD: 0x1C69,
	0xFFFD: 0x1C6A,
	0xFFFD: 0x1C6B,
	0xFFFD: 0x1C6C,
	0xFFFD: 0x1C6D,
	0xFFFD: 0x1C6E,
	0xFFFD: 0x1C6F,
	0xFFFD: 0x1C70,
	0xFFFD: 0x1C71,
	0xFFFD: 0x1C72,
	0xFFFD: 0x1C73,
	0xFFFD: 0x1C74,
	0xFFFD: 0x1C75,
	0xFFFD: 0x1C76,
	0xFFFD: 0x1C77,
	0xFFFD: 0x1C78,
	0xFFFD: 0x1C79,
	0xFFFD: 0x1C7A,
	0xFFFD: 0x1C7B,
	0xFFFD: 0x1C7C,
	0xFFFD: 0x1C7D,
	0xFFFD: 0x1C7E,
	0xFFFD: 0x1C7F,
	0xFFFD: 0x1C80,
	0xFFFD: 0x1C81,
	0xFFFD: 0x1C82,
	0xFFFD: 0x1C83,
	0xFFFD: 0x1C84,
	0xFFFD: 0x1C85,
	0xFFFD: 0x1C86,
	0xFFFD: 0x1C87,
	0xFFFD: 0x1C88,
	0xFFFD: 0x1C89,
	0xFFFD: 0x1C8A,
	0xFFFD: 0x1C8B,
	0xFFFD: 0x1C8C,
	0xFFFD: 0x1C8D,
	0xFFFD: 0x1C8E,
	0xFFFD: 0x1C8F,
	0xFFFD: 0x1C90,
	0xFFFD: 0x1C91,
	0xFFFD: 0x1C92,
	0xFFFD: 0x1C93,
	0xFFFD: 0x1C94,
	0xFFFD: 0x1C95,
	0xFFFD: 0x1C96,
	0xFFFD: 0x1C97,
	0xFFFD: 0x1C98,
	0xFFFD: 0x1C99,
	0xFFFD: 0x1C9A,
	0xFFFD: 0x1C9B,
	0xFFFD: 0x1C9C,
	0xFFFD: 0x1C9D,
	0xFFFD: 0x1C9E,
	0xFFFD: 0x1C9F,
	0xFFFD: 0x1CA0,
	0xFFFD: 0x1CA1,
	0xFFFD: 0x1CA2,
	0xFFFD: 0x1CA3,
	0xFFFD: 0x1CA4,
	0xFFFD: 0x1CA5,
	0xFFFD: 0x1CA6,
	0xFFFD: 0x1CA7,
	0xFFFD: 0x1CA8,
	0xFFFD: 0x1CA9,
	0xFFFD: 0x1CAA,
	0xFFFD: 0x1CAB,
	0xFFFD: 0x1CAC,
	0xFFFD: 0x1CAD,
	0xFFFD: 0x1CAE,
	0xFFFD: 0x1CAF,
	0xFFFD: 0x1CB0,
	0xFFFD: 0x1CB1,
	0xFFFD: 0x1CB2,
	0xFFFD: 0x1CB3,
	0xFFFD: 0x1CB4,
	0xFFFD: 0x1CB5,
	0xFFFD: 0x1CB6,
	0xFFFD: 0x1CB7,
	0xFFFD: 0x1CB8,
	0xFFFD: 0x1CB9,
	0xFFFD: 0x1CBA,
	0xFFFD: 0x1CBB,
	0xFFFD: 0x1CBC,
	0xFFFD: 0x1CBD,
	0xFFFD: 0x1CBE,
	0xFFFD: 0x1CBF,
	0xFFFD: 0x1CC0,
	0xFFFD: 0x1CC1,
	0xFFFD: 0x1CC2,
	0xFFFD: 0x1CC3,
	0xFFFD: 0x1CC4,
	0xFFFD: 0x1CC5,
	0xFFFD: 0x1CC6,
	0xFFFD: 0x1CC7,
	0xFFFD: 0x1CC8,
	0xFFFD: 0x1CC9,
	0xFFFD: 0x1CCA,
	0xFFFD: 0x1CCB,
	0xFFFD: 0x1CCC,
	0xFFFD: 0x1CCD,
	0xFFFD: 0x1CCE,
	0xFFFD: 0x1CCF,
	0xFFFD: 0x1CD0,
	0xFFFD: 0x1CD1,
	0xFFFD: 0x1CD2,
	0xFFFD: 0x1CD3,
	0xFFFD: 0x1CD4,
	0xFFFD: 0x1CD5,
	0xFFFD: 0x1CD6,
	0xFFFD: 0x1CD7,
	0xFFFD: 0x1CD8,
	0xFFFD: 0x1CD9,
	0xFFFD: 0x1CDA,
	0xFFFD: 0x1CDB,
	0xFFFD: 0x1CDC,
	0xFFFD: 0x1CDD,
	0xFFFD: 0x1CDE,
	0xFFFD: 0x1CDF,
	0xFFFD: 0x1CE0,
	0xFFFD: 0x1CE1,
	0xFFFD: 0x1CE2,
	0xFFFD: 0x1CE3,
	0xFFFD: 0x1CE4,
	0xFFFD: 0x1CE5,
	0xFFFD: 0x1CE6,
	0xFFFD: 0x1CE7,
	0xFFFD: 0x1CE8,
	0xFFFD: 0x1CE9,
	0xFFFD: 0x1CEA,
	0xFFFD: 0x1CEB,
	0xFFFD: 0x1CEC,
	0xFFFD: 0x1CED,
	0xFFFD: 0x1CEE,
	0xFFFD: 0x1CEF,
	0xFFFD: 0x1CF0,
	0xFFFD: 0x1CF1,
	0xFFFD: 0x1CF2,
	0xFFFD: 0x1CF3,
	0xFFFD: 0x1CF4,
	0xFFFD: 0x1CF5,
	0xFFFD: 0x1CF6,
	0xFFFD: 0x1CF7,
	0xFFFD: 0x1CF8,
	0xFFFD: 0x1CF9,
	0xFFFD: 0x1CFA,
	0xFFFD: 0x1CFB,
	0xFFFD: 0x1CFC,
	0xFFFD: 0x1CFD,
	0xFFFD: 0x1CFE,
	0xFFFD: 0x1CFF,
	0xFFFD: 0x1D00,
	0xFFFD: 0x1D01,
	0xFFFD: 0x1D02,
	0xFFFD: 0x1D03,
	0xFFFD: 0x1D04,
	0xFFFD: 0x1D05,
	0xFFFD: 0x1D06,
	0xFFFD: 0x1D07,
	0xFFFD: 0x1D08,
	0xFFFD: 0x1D09,
	0xFFFD: 0x1D0A,
	0xFFFD: 0x1D0B,
	0xFFFD: 0x1D0C,
	0xFFFD: 0x1D0D,
	0xFFFD: 0x1D0E,
	0xFFFD: 0x1D0F,
	0xFFFD: 0x1D10,
	0xFFFD: 0x1D11,
	0xFFFD: 0x1D12,
	0xFFFD: 0x1D13,
	0xFFFD: 0x1D14,
	0xFFFD: 0x1D15,
	0xFFFD: 0x1D16,
	0xFFFD: 0x1D17,
	0xFFFD: 0x1D18,
	0xFFFD: 0x1D19,
	0xFFFD: 0x1D1A,
	0xFFFD: 0x1D1B,
	0xFFFD: 0x1D1C,
	0xFFFD: 0x1D1D,
	0xFFFD: 0x1D1E,
	0xFFFD: 0x1D1F,
	0xFFFD: 0x1D20,
	0xFFFD: 0x1D21,
	0xFFFD: 0x1D22,
	0xFFFD: 0x1D23,
	0xFFFD: 0x1D24,
	0xFFFD: 0x1D25,
	0xFFFD: 0x1D26,
	0xFFFD: 0x1D27,
	0xFFFD: 0x1D28,
	0xFFFD: 0x1D29,
	0xFFFD: 0x1D2A,
	0xFFFD: 0x1D2B,
	0xFFFD: 0x1D2C,
	0xFFFD: 0x1D2D,
	0xFFFD: 0x1D2E,
	0xFFFD: 0x1D2F,
	0xFFFD: 0x1D30,
	0xFFFD: 0x1D31,
	0xFFFD: 0x1D32,
	0xFFFD: 0x1D33,
	0xFFFD: 0x1D34,
	0xFFFD: 0x1D35,
	0xFFFD: 0x1D36,
	0xFFFD: 0x1D37,
	0xFFFD: 0x1D38,
	0xFFFD: 0x1D39,
	0xFFFD: 0x1D3A,
	0xFFFD: 0x1D3B,
	0xFFFD: 0x1D3C,
	0xFFFD: 0x1D3D,
	0xFFFD: 0x1D3E,
	0xFFFD: 0x1D3F,
	0xFFFD: 0x1D40,
	0xFFFD: 0x1D41,
	0xFFFD: 0x1D42,
	0xFFFD: 0x1D43,
	0xFFFD: 0x1D44,
	0xFFFD: 0x1D45,
	0xFFFD: 0x1D46,
	0xFFFD: 0x1D47,
	0xFFFD: 0x1D48,
	0xFFFD: 0x1D49,
	0xFFFD: 0x1D4A,
	0xFFFD: 0x1D4B,
	0xFFFD: 0x1D4C,
	0xFFFD: 0x1D4D,
	0xFFFD: 0x1D4E,
	0xFFFD: 0x1D4F,
	0xFFFD: 0x1D50,
	0xFFFD: 0x1D51,
	0xFFFD: 0x1D52,
	0xFFFD: 0x1D53,
	0xFFFD: 0x1D54,
	0xFFFD: 0x1D55,
	0xFFFD: 0x1D56,
	0xFFFD: 0x1D57,
	0xFFFD: 0x1D58,
	0xFFFD: 0x1D59,
	0xFFFD: 0x1D5A,
	0xFFFD: 0x1D5B,
	0xFFFD: 0x1D5C,
	0xFFFD: 0x1D5D,
	0xFFFD: 0x1D5E,
	0xFFFD: 0x1D5F,
	0xFFFD: 0x1D60,
	0xFFFD: 0x1D61,
	0xFFFD: 0x1D62,
	0xFFFD: 0x1D63,
	0xFFFD: 0x1D64,
	0xFFFD: 0x1D65,
	0xFFFD: 0x1D66,
	0xFFFD: 0x1D67,
	0xFFFD: 0x1D68,
	0xFFFD: 0x1D69,
	0xFFFD: 0x1D6A,
	0xFFFD: 0x1D6B,
	0xFFFD: 0x1D6C,
	0xFFFD: 0x1D6D,
	0xFFFD: 0x1D6E,
	0xFFFD: 0x1D6F,
	0xFFFD: 0x1D70,
	0xFFFD: 0x1D71,
	0xFFFD: 0x1D72,
	0xFFFD: 0x1D73,
	0xFFFD: 0x1D74,
	0xFFFD: 0x1D75,
	0xFFFD: 0x1D76,
	0xFFFD: 0x1D77,
	0xFFFD: 0x1D78,
	0xFFFD: 0x1D79,
	0xFFFD: 0x1D7A,
	0xFFFD: 0x1D7B,
	0xFFFD: 0x1D7C,
	0xFFFD: 0x1D7D,
	0xFFFD: 0x1D7E,
	0xFFFD: 0x1D7F,
	0xFFFD: 0x1D80,
	0xFFFD: 0x1D81,
	0xFFFD: 0x1D82,
	0xFFFD: 0x1D83,
	0xFFFD: 0x1D84,
	0xFFFD: 0x1D85,
	0xFFFD: 0x1D86,
	0xFFFD: 0x1D87,
	0xFFFD: 0x1D88,
	0xFFFD: 0x1D89,
	0xFFFD: 0x1D8A,
	0xFFFD: 0x1D8B,
	0xFFFD: 0x1D8C,
	0xFFFD: 0x1D8D,
	0xFFFD: 0x1D8E,
	0xFFFD: 0x1D8F,
	0xFFFD: 0x1D90,
	0xFFFD: 0x1D91,
	0xFFFD: 0x1D92,
	0xFFFD: 0x1D93,
	0xFFFD: 0x1D94,
	0xFFFD: 0x1D95,
	0xFFFD: 0x1D96,
	0xFFFD: 0x1D97,
	0xFFFD: 0x1D98,
	0xFFFD: 0x1D99,
	0xFFFD: 0x1D9A,
	0xFFFD: 0x1D9B,
	0xFFFD: 0x1D9C,
	0xFFFD: 0x1D9D,
	0xFFFD: 0x1D9E,
	0xFFFD: 0x1D9F,
	0xFFFD: 0x1DA0,
	0xFFFD: 0x1DA1,
	0xFFFD: 0x1DA2,
	0xFFFD: 0x1DA3,
	0xFFFD: 0x1DA4,
	0xFFFD: 0x1DA5,
	0xFFFD: 0x1DA6,
	0xFFFD: 0x1DA7,
	0xFFFD: 0x1DA8,
	0xFFFD: 0x1DA9,
	0xFFFD: 0x1DAA,
	0xFFFD: 0x1DAB,
	0xFFFD: 0x1DAC,
	0xFFFD: 0x1DAD,
	0xFFFD: 0x1DAE,
	0xFFFD: 0x1DAF,
	0xFFFD: 0x1DB0,
	0xFFFD: 0x1DB1,
	0xFFFD: 0x1DB2,
	0xFFFD: 0x1DB3,
	0xFFFD: 0x1DB4,
	0xFFFD: 0x1DB5,
	0xFFFD: 0x1DB6,
	0xFFFD: 0x1DB7,
	0xFFFD: 0x1DB8,
	0xFFFD: 0x1DB9,
	0xFFFD: 0x1DBA,
	0xFFFD: 0x1DBB,
	0xFFFD: 0x1DBC,
	0xFFFD: 0x1DBD,
	0xFFFD: 0x1DBE,
	0xFFFD: 0x1DBF,
	0xFFFD: 0x1DC0,
	0xFFFD: 0x1DC1,
	0xFFFD: 0x1DC2,
	0xFFFD: 0x1DC3,
	0xFFFD: 0x1DC4,
	0xFFFD: 0x1DC5,
	0xFFFD: 0x1DC6,
	0xFFFD: 0x1DC7,
	0xFFFD: 0x1DC8,
	0xFFFD: 0x1DC9,
	0xFFFD: 0x1DCA,
	0xFFFD: 0x1DCB,
	0xFFFD: 0x1DCC,
	0xFFFD: 0x1DCD,
	0xFFFD: 0x1DCE,
	0xFFFD: 0x1DCF,
	0xFFFD: 0x1DD0,
	0xFFFD: 0x1DD1,
	0xFFFD: 0x1DD2,
	0xFFFD: 0x1DD3,
	0xFFFD: 0x1DD4,
	0xFFFD: 0x1DD5,
	0xFFFD: 0x1DD6,
	0xFFFD: 0x1DD7,
	0xFFFD: 0x1DD8,
	0xFFFD: 0x1DD9,
	0xFFFD: 0x1DDA,
	0xFFFD: 0x1DDB,
	0xFFFD: 0x1DDC,
	0xFFFD: 0x1DDD,
	0xFFFD: 0x1DDE,
	0xFFFD: 0x1DDF,
	0xFFFD: 0x1DE0,
	0xFFFD: 0x1DE1,
	0xFFFD: 0x1DE2,
	0xFFFD: 0x1DE3,
	0xFFFD: 0x1DE4,
	0xFFFD: 0x1DE5,
	0xFFFD: 0x1DE6,
	0xFFFD: 0x1DE7,
	0xFFFD: 0x1DE8,
	0xFFFD: 0x1DE9,
	0xFFFD: 0x1DEA,
	0xFFFD: 0x1DEB,
	0xFFFD: 0x1DEC,
	0xFFFD: 0x1DED,
	0xFFFD: 0x1DEE,
	0xFFFD: 0x1DEF,
	0xFFFD: 0x1DF0,
	0xFFFD: 0x1DF1,
	0xFFFD: 0x1DF2,
	0xFFFD: 0x1DF3,
	0xFFFD: 0x1DF4,
	0xFFFD: 0x1DF5,
	0xFFFD: 0x1DF6,
	0xFFFD: 0x1DF7,
	0xFFFD: 0x1DF8,
	0xFFFD: 0x1DF9,
	0xFFFD: 0x1DFA,
	0xFFFD: 0x1DFB,
	0xFFFD: 0x1DFC,
	0xFFFD: 0x1DFD,
	0xFFFD: 0x1DFE,
	0xFFFD: 0x1DFF,
	0xFFFD: 0x1E00,
	0xFFFD: 0x1E01,
	0xFFFD: 0x1E02,
	0xFFFD: 0x1E03,
	0xFFFD: 0x1E04,
	0xFFFD: 0x1E05,
	0xFFFD: 0x1E06,
	0xFFFD: 0x1E07,
	0xFFFD: 0x1E08,
	0xFFFD: 0x1E09,
	0xFFFD: 0x1E0A,
	0xFFFD: 0x1E0B,
	0xFFFD: 0x1E0C,
	0xFFFD: 0x1E0D,
	0xFFFD: 0x1E0E,
	0xFFFD: 0x1E0F,
	0xFFFD: 0x1E10,
	0xFFFD: 0x1E11,
	0xFFFD: 0x1E12,
	0xFFFD: 0x1E13,
	0xFFFD: 0x1E14,
	0xFFFD: 0x1E15,
	0xFFFD: 0x1E16,
	0xFFFD: 0x1E17,
	0xFFFD: 0x1E18,
	0xFFFD: 0x1E19,
	0xFFFD: 0x1E1A,
	0xFFFD: 0x1E1B,
	0xFFFD: 0x1E1C,
	0xFFFD: 0x1E1D,
	0xFFFD: 0x1E1E,
	0xFFFD: 0x1E1F,
	0xFFFD: 0x1E20,
	0xFFFD: 0x1E21,
	0xFFFD: 0x1E22,
	0xFFFD: 0x1E23,
	0xFFFD: 0x1E24,
	0xFFFD: 0x1E25,
	0xFFFD: 0x1E26,
	0xFFFD: 0x1E27,
	0xFFFD: 0x1E28,
	0xFFFD: 0x1E29,
	0xFFFD: 0x1E2A,
	0xFFFD: 0x1E2B,
	0xFFFD: 0x1E2C,
	0xFFFD: 0x1E2D,
	0xFFFD: 0x1E2E,
	0xFFFD: 0x1E2F,
	0xFFFD: 0x1E30,
	0xFFFD: 0x1E31,
	0xFFFD: 0x1E32,
	0xFFFD: 0x1E33,
	0xFFFD: 0x1E34,
	0xFFFD: 0x1E35,
	0xFFFD: 0x1E36,
	0xFFFD: 0x1E37,
	0xFFFD: 0x1E38,
	0xFFFD: 0x1E39,
	0xFFFD: 0x1E3A,
	0x9BD6: 0x1E3B,
	0xFFFD: 0x1E3C,
	0xFFFD: 0x1E3D,
	0xFFFD: 0x1E3E,
	0xFFFD: 0x1E3F,
	0xFFFD: 0x1E40,
	0xFFFD: 0x1E41,
	0xFFFD: 0x1E42,
	0x9BD3: 0x1E43,
	0xFFFD: 0x1E44,
	0xFFFD: 0x1E45,
	0xFFFD: 0x1E46,
	0xFFFD: 0x1E47,
	0xFFFD: 0x1E48,
	0x9BD4: 0x1E49,
	0xFFFD: 0x1E4A,
	0xFFFD: 0x1E4B,
	0xFFFD: 0x1E4C,
	0xFFFD: 0x1E4D,
	0xFFFD: 0x1E4E,
	0xFFFD: 0x1E4F,
	0xFFFD: 0x1E50,
	0xFFFD: 0x1E51,
	0xFFFD: 0x1E52,
	0xFFFD: 0x1E53,
	0xFFFD: 0x1E54,
	0xFFFD: 0x1E55,
	0xFFFD: 0x1E56,
	0xFFFD: 0x1E57,
	0xFFFD: 0x1E58,
	0xFFFD: 0x1E59,
	0xFFFD: 0x1E5A,
	0xFFFD: 0x1E5B,
	0xFFFD: 0x1E5C,
	0xFFFD: 0x1E5D,
	0xFFFD: 0x1E5E,
	0xFFFD: 0x1E5F,
	0xFFFD: 0x1E60,
	0xFFFD: 0x1E61,
	0xFFFD: 0x1E62,
	0xFFFD: 0x1E63,
	0xFFFD: 0x1E64,
	0xFFFD: 0x1E65,
	0xFFFD: 0x1E66,
	0xFFFD: 0x1E67,
	0xFFFD: 0x1E68,
	0xFFFD: 0x1E69,
	0xFFFD: 0x1E6A,
	0xFFFD: 0x1E6B,
	0xFFFD: 0x1E6C,
	0xFFFD: 0x1E6D,
	0xFFFD: 0x1E6E,
	0xFFFD: 0x1E6F,
	0xFFFD: 0x1E70,
	0xFFFD: 0x1E71,
	0xFFFD: 0x1E72,
	0xFFFD: 0x1E73,
	0xFFFD: 0x1E74,
	0xFFFD: 0x1E75,
	0xFFFD: 0x1E76,
	0xFFFD: 0x1E77,
	0xFFFD: 0x1E78,
	0xFFFD: 0x1E79,
	0xFFFD: 0x1E7A,
	0xFFFD: 0x1E7B,
	0xFFFD: 0x1E7C,
	0xFFFD: 0x1E7D,
	0xFFFD: 0x1E7E,
	0xFFFD: 0x1E7F,
	0xFFFD: 0x1E80,
	0xFFFD: 0x1E81,
	0xFFFD: 0x1E82,
	0xFFFD: 0x1E83,
	0xFFFD: 0x1E84,
	0xFFFD: 0x1E85,
	0xFFFD: 0x1E86,
	0xFFFD: 0x1E87,
	0xFFFD: 0x1E88,
	0xFFFD: 0x1E89,
	0xFFFD: 0x1E8A,
	0xFFFD: 0x1E8B,
	0xFFFD: 0x1E8C,
	0xFFFD: 0x1E8D,
	0xFFFD: 0x1E8E,
	0xFFFD: 0x1E8F,
	0xFFFD: 0x1E90,
	0xFFFD: 0x1E91,
	0xFFFD: 0x1E92,
	0xFFFD: 0x1E93,
	0xFFFD: 0x1E94,
	0xFFFD: 0x1E95,
	0xFFFD: 0x1E96,
	0xFFFD: 0x1E97,
	0xFFFD: 0x1E98,
	0xFFFD: 0x1E99,
	0xFFFD: 0x1E9A,
	0xFFFD: 0x1E9B,
	0xFFFD: 0x1E9C,
	0xFFFD: 0x1E9D,
	0xFFFD: 0x1E9E,
	0xFFFD: 0x1E9F,
	0xFFFD: 0x1EA0,
	0xFFFD: 0x1EA1,
	0xFFFD: 0x1EA2,
	0xFFFD: 0x1EA3,
	0xFFFD: 0x1EA4,
	0xFFFD: 0x1EA5,
	0xFFFD: 0x1EA6,
	0xFFFD: 0x1EA7,
	0xFFFD: 0x1EA8,
	0xFFFD: 0x1EA9,
	0xFFFD: 0x1EAA,
	0xFFFD: 0x1EAB,
	0xFFFD: 0x1EAC,
	0xFFFD: 0x1EAD,
	0xFFFD: 0x1EAE,
	0xFFFD: 0x1EAF,
	0xFFFD: 0x1EB0,
	0xFFFD: 0x1EB1,
	0xFFFD: 0x1EB2,
	0xFFFD: 0x1EB3,
	0xFFFD: 0x1EB4,
	0xFFFD: 0x1EB5,
	0xFFFD: 0x1EB6,
	0xFFFD: 0x1EB7,
	0xFFFD: 0x1EB8,
	0xFFFD: 0x1EB9,
	0xFFFD: 0x1EBA,
	0xFFFD: 0x1EBB,
	0xFFFD: 0x1EBC,
	0xFFFD: 0x1EBD,
	0xFFFD: 0x1EBE,
	0xFFFD: 0x1EBF,
	0xFFFD: 0x1EC0,
	0xFFFD: 0x1EC1,
	0xFFFD: 0x1EC2,
	0xFFFD: 0x1EC3,
	0xFFFD: 0x1EC4,
	0xFFFD: 0x1EC5,
	0xFFFD: 0x1EC6,
	0xFFFD: 0x1EC7,
	0xFFFD: 0x1EC8,
	0xFFFD: 0x1EC9,
	0xFFFD: 0x1ECA,
	0xFFFD: 0x1ECB,
	0xFFFD: 0x1ECC,
	0xFFFD: 0x1ECD,
	0xFFFD: 0x1ECE,
	0xFFFD: 0x1ECF,
	0xFFFD: 0x1ED0,
	0xFFFD: 0x1ED1,
	0xFFFD: 0x1ED2,
	0xFFFD: 0x1ED3,
	0xFFFD: 0x1ED4,
	0xFFFD: 0x1ED5,
	0xFFFD: 0x1ED6,
	0xFFFD: 0x1ED7,
	0xFFFD: 0x1ED8,
	0xFFFD: 0x1ED9,
	0xFFFD: 0x1EDA,
	0xFFFD: 0x1EDB,
	0xFFFD: 0x1EDC,
	0xFFFD: 0x1EDD,
	0xFFFD: 0x1EDE,
	0xFFFD: 0x1EDF,
	0xFFFD: 0x1EE0,
	0xFFFD: 0x1EE1,
	0xFFFD: 0x1EE2,
	0xFFFD: 0x1EE3,
	0xFFFD: 0x1EE4,
	0xFFFD: 0x1EE5,
	0xFFFD: 0x1EE6,
	0xFFFD: 0x1EE7,
	0xFFFD: 0x1EE8,
	0xFFFD: 0x1EE9,
	0xFFFD: 0x1EEA,
	0xFFFD: 0x1EEB,
	0xFFFD: 0x1EEC,
	0xFFFD: 0x1EED,
	0xFFFD: 0x1EEE,
	0xFFFD: 0x1EEF,
	0xFFFD: 0x1EF0,
	0xFFFD: 0x1EF1,
	0xA0DB: 0x1EF2,
	0xA0EB: 0x1EF3,
	0xFFFD: 0x1EF4,
	0xFFFD: 0x1EF5,
	0xFFFD: 0x1EF6,
	0xFFFD: 0x1EF7,
	0xFFFD: 0x1EF8,
	0xFFFD: 0x1EF9,
	0xFFFD: 0x1EFA,
	0xFFFD: 0x1EFB,
	0xFFFD: 0x1EFC,
	0xFFFD: 0x1EFD,
	0xFFFD: 0x1EFE,
	0xFFFD: 0x1EFF,
	0xFFFD: 0x1F00,
	0xFFFD: 0x1F01,
	0xFFFD: 0x1F02,
	0xFFFD: 0x1F03,
	0xFFFD: 0x1F04,
	0xFFFD: 0x1F05,
	0xFFFD: 0x1F06,
	0xFFFD: 0x1F07,
	0xFFFD: 0x1F08,
	0xFFFD: 0x1F09,
	0xFFFD: 0x1F0A,
	0xFFFD: 0x1F0B,
	0xFFFD: 0x1F0C,
	0xFFFD: 0x1F0D,
	0xFFFD: 0x1F0E,
	0xFFFD: 0x1F0F,
	0xFFFD: 0x1F10,
	0xFFFD: 0x1F11,
	0xFFFD: 0x1F12,
	0xFFFD: 0x1F13,
	0xFFFD: 0x1F14,
	0xFFFD: 0x1F15,
	0xFFFD: 0x1F16,
	0xFFFD: 0x1F17,
	0xFFFD: 0x1F18,
	0xFFFD: 0x1F19,
	0xFFFD: 0x1F1A,
	0xFFFD: 0x1F1B,
	0xFFFD: 0x1F1C,
	0xFFFD: 0x1F1D,
	0xFFFD: 0x1F1E,
	0xFFFD: 0x1F1F,
	0xFFFD: 0x1F20,
	0xFFFD: 0x1F21,
	0xFFFD: 0x1F22,
	0xFFFD: 0x1F23,
	0xFFFD: 0x1F24,
	0xFFFD: 0x1F25,
	0xFFFD: 0x1F26,
	0xFFFD: 0x1F27,
	0xFFFD: 0x1F28,
	0xFFFD: 0x1F29,
	0xFFFD: 0x1F2A,
	0xFFFD: 0x1F2B,
	0xFFFD: 0x1F2C,
	0xFFFD: 0x1F2D,
	0xFFFD: 0x1F2E,
	0xFFFD: 0x1F2F,
	0xFFFD: 0x1F30,
	0xFFFD: 0x1F31,
	0xFFFD: 0x1F32,
	0xFFFD: 0x1F33,
	0xFFFD: 0x1F34,
	0xFFFD: 0x1F35,
	0xFFFD: 0x1F36,
	0xFFFD: 0x1F37,
	0xFFFD: 0x1F38,
	0xFFFD: 0x1F39,
	0xFFFD: 0x1F3A,
	0xFFFD: 0x1F3B,
	0xFFFD: 0x1F3C,
	0xFFFD: 0x1F3D,
	0xFFFD: 0x1F3E,
	0xFFFD: 0x1F3F,
	0xFFFD: 0x1F40,
	0xFFFD: 0x1F41,
	0xFFFD: 0x1F42,
	0xFFFD: 0x1F43,
	0xFFFD: 0x1F44,
	0xFFFD: 0x1F45,
	0xFFFD: 0x1F46,
	0xFFFD: 0x1F47,
	0xFFFD: 0x1F48,
	0xFFFD: 0x1F49,
	0xFFFD: 0x1F4A,
	0xFFFD: 0x1F4B,
	0xFFFD: 0x1F4C,
	0xFFFD: 0x1F4D,
	0xFFFD: 0x1F4E,
	0xFFFD: 0x1F4F,
	0xFFFD: 0x1F50,
	0xFFFD: 0x1F51,
	0xFFFD: 0x1F52,
	0xFFFD: 0x1F53,
	0xFFFD: 0x1F54,
	0xFFFD: 0x1F55,
	0xFFFD: 0x1F56,
	0xFFFD: 0x1F57,
	0xFFFD: 0x1F58,
	0xFFFD: 0x1F59,
	0xFFFD: 0x1F5A,
	0xFFFD: 0x1F5B,
	0xFFFD: 0x1F5C,
	0xFFFD: 0x1F5D,
	0xFFFD: 0x1F5E,
	0xFFFD: 0x1F5F,
	0xFFFD: 0x1F60,
	0xFFFD: 0x1F61,
	0xFFFD: 0x1F62,
	0xFFFD: 0x1F63,
	0xFFFD: 0x1F64,
	0xFFFD: 0x1F65,
	0xFFFD: 0x1F66,
	0xFFFD: 0x1F67,
	0xFFFD: 0x1F68,
	0xFFFD: 0x1F69,
	0xFFFD: 0x1F6A,
	0xFFFD: 0x1F6B,
	0xFFFD: 0x1F6C,
	0xFFFD: 0x1F6D,
	0xFFFD: 0x1F6E,
	0xFFFD: 0x1F6F,
	0xFFFD: 0x1F70,
	0xFFFD: 0x1F71,
	0xFFFD: 0x1F72,
	0xFFFD: 0x1F73,
	0xFFFD: 0x1F74,
	0xFFFD: 0x1F75,
	0xFFFD: 0x1F76,
	0xFFFD: 0x1F77,
	0xFFFD: 0x1F78,
	0xFFFD: 0x1F79,
	0xFFFD: 0x1F7A,
	0xFFFD: 0x1F7B,
	0xFFFD: 0x1F7C,
	0xFFFD: 0x1F7D,
	0xFFFD: 0x1F7E,
	0xFFFD: 0x1F7F,
	0xFFFD: 0x1F80,
	0xFFFD: 0x1F81,
	0xFFFD: 0x1F82,
	0xFFFD: 0x1F83,
	0xFFFD: 0x1F84,
	0xFFFD: 0x1F85,
	0xFFFD: 0x1F86,
	0xFFFD: 0x1F87,
	0xFFFD: 0x1F88,
	0xFFFD: 0x1F89,
	0xFFFD: 0x1F8A,
	0xFFFD: 0x1F8B,
	0xFFFD: 0x1F8C,
	0xFFFD: 0x1F8D,
	0xFFFD: 0x1F8E,
	0xFFFD: 0x1F8F,
	0xFFFD: 0x1F90,
	0xFFFD: 0x1F91,
	0xFFFD: 0x1F92,
	0xFFFD: 0x1F93,
	0xFFFD: 0x1F94,
	0xFFFD: 0x1F95,
	0xFFFD: 0x1F96,
	0xFFFD: 0x1F97,
	0xFFFD: 0x1F98,
	0xFFFD: 0x1F99,
	0xFFFD: 0x1F9A,
	0xFFFD: 0x1F9B,
	0xFFFD: 0x1F9C,
	0xFFFD: 0x1F9D,
	0xFFFD: 0x1F9E,
	0xFFFD: 0x1F9F,
	0xFFFD: 0x1FA0,
	0xFFFD: 0x1FA1,
	0xFFFD: 0x1FA2,
	0xFFFD: 0x1FA3,
	0xFFFD: 0x1FA4,
	0xFFFD: 0x1FA5,
	0xFFFD: 0x1FA6,
	0xFFFD: 0x1FA7,
	0xFFFD: 0x1FA8,
	0xFFFD: 0x1FA9,
	0xFFFD: 0x1FAA,
	0xFFFD: 0x1FAB,
	0xFFFD: 0x1FAC,
	0xFFFD: 0x1FAD,
	0xFFFD: 0x1FAE,
	0xFFFD: 0x1FAF,
	0xFFFD: 0x1FB0,
	0xFFFD: 0x1FB1,
	0xFFFD: 0x1FB2,
	0xFFFD: 0x1FB3,
	0xFFFD: 0x1FB4,
	0xFFFD: 0x1FB5,
	0xFFFD: 0x1FB6,
	0xFFFD: 0x1FB7,
	0xFFFD: 0x1FB8,
	0xFFFD: 0x1FB9,
	0xFFFD: 0x1FBA,
	0xFFFD: 0x1FBB,
	0xFFFD: 0x1FBC,
	0xFFFD: 0x1FBD,
	0xFFFD: 0x1FBE,
	0xFFFD: 0x1FBF,
	0xFFFD: 0x1FC0,
	0xFFFD: 0x1FC1,
	0xFFFD: 0x1FC2,
	0xFFFD: 0x1FC3,
	0xFFFD: 0x1FC4,
	0xFFFD: 0x1FC5,
	0xFFFD: 0x1FC6,
	0xFFFD: 0x1FC7,
	0xFFFD: 0x1FC8,
	0xFFFD: 0x1FC9,
	0xFFFD: 0x1FCA,
	0xFFFD: 0x1FCB,
	0xFFFD: 0x1FCC,
	0xFFFD: 0x1FCD,
	0xFFFD: 0x1FCE,
	0xFFFD: 0x1FCF,
	0xFFFD: 0x1FD0,
	0xFFFD: 0x1FD1,
	0xFFFD: 0x1FD2,
	0xFFFD: 0x1FD3,
	0xFFFD: 0x1FD4,
	0xFFFD: 0x1FD5,
	0xFFFD: 0x1FD6,
	0xFFFD: 0x1FD7,
	0xFFFD: 0x1FD8,
	0xFFFD: 0x1FD9,
	0xFFFD: 0x1FDA,
	0xFFFD: 0x1FDB,
	0xFFFD: 0x1FDC,
	0xFFFD: 0x1FDD,
	0xFFFD: 0x1FDE,
	0xFFFD: 0x1FDF,
	0xFFFD: 0x1FE0,
	0xFFFD: 0x1FE1,
	0xFFFD: 0x1FE2,
	0xFFFD: 0x1FE3,
	0xFFFD: 0x1FE4,
	0xFFFD: 0x1FE5,
	0xFFFD: 0x1FE6,
	0xFFFD: 0x1FE7,
	0xFFFD: 0x1FE8,
	0xFFFD: 0x1FE9,
	0xFFFD: 0x1FEA,
	0xFFFD: 0x1FEB,
	0xFFFD: 0x1FEC,
	0xFFFD: 0x1FED,
	0xFFFD: 0x1FEE,
	0xFFFD: 0x1FEF,
	0xFFFD: 0x1FF0,
	0xFFFD: 0x1FF1,
	0xFFFD: 0x1FF2,
	0xFFFD: 0x1FF3,
	0xFFFD: 0x1FF4,
	0xFFFD: 0x1FF5,
	0xFFFD: 0x1FF6,
	0xFFFD: 0x1FF7,
	0xFFFD: 0x1FF8,
	0xFFFD: 0x1FF9,
	0xFFFD: 0x1FFA,
	0xFFFD: 0x1FFB,
	0xFFFD: 0x1FFC,
	0xFFFD: 0x1FFD,
	0xFFFD: 0x1FFE,
	0xFFFD: 0x1FFF,
	0xFFFD: 0x2000,
	0xFFFD: 0x2001,
	0xFFFD: 0x2002,
	0xFFFD: 0x2003,
	0xFFFD: 0x2004,
	0xFFFD: 0x2005,
	0xFFFD: 0x2006,
	0xFFFD: 0x2007,
	0xFFFD: 0x2008,
	0xFFFD: 0x2009,
	0xFFFD: 0x200A,
	0xFFFD: 0x200B,
	0xFFFD: 0x200C,
	0xFFFD: 0x200D,
	0xFFFD: 0x200E,
	0xFFFD: 0x200F,
	0x9FEC: 0x2010,
	0xFFFD: 0x2011,
	0xFFFD: 0x2012,
	0xA156: 0x2013,
	0xA158: 0x2014,
	0xA277: 0x2015,
	0xA1FC: 0x2016,
	0xFFFD: 0x2017,
	0xA1A5: 0x2018,
	0xA1A6: 0x2019,
	0xFFFD: 0x201A,
	0xFFFD: 0x201B,
	0xA1A7: 0x201C,
	0xA1A8: 0x201D,
	0xFFFD: 0x201E,
	0xFFFD: 0x201F,
	0xA1CF: 0x2020,
	0x91DE: 0x2021,
	0xA145: 0x2022,
	0xFFFD: 0x2023,
	0xA3BB: 0x2024,
	0xA14C: 0x2025,
	0xA14B: 0x2026,
	0xA145: 0x2027,
	0xFFFD: 0x2028,
	0xFFFD: 0x2029,
	0xFFFD: 0x202A,
	0xFFFD: 0x202B,
	0xFFFD: 0x202C,
	0xFFFD: 0x202D,
	0xFFFD: 0x202E,
	0xFFFD: 0x202F,
	0xFEE2: 0x2030,
	0xFFFD: 0x2031,
	0xA1AC: 0x2032,
	0xA1B2: 0x2033,
	0xFFFD: 0x2034,
	0xA1AB: 0x2035,
	0xFFFD: 0x2036,
	0xFFFD: 0x2037,
	0xFFFD: 0x2038,
	0xFFFD: 0x2039,
	0xFFFD: 0x203A,
	0xA1B0: 0x203B,
	0x91F7: 0x203C,
	0xFFFD: 0x203D,
	0xA1C3: 0x203E,
	0xFFFD: 0x203F,
	0xFFFD: 0x2040,
	0xFFFD: 0x2041,
	0xFFFD: 0x2042,
	0xFFFD: 0x2043,
	0xFFFD: 0x2044,
	0xFFFD: 0x2045,
	0xFFFD: 0x2046,
	0xFFFD: 0x2047,
	0xFFFD: 0x2048,
	0xFFFD: 0x2049,
	0xFFFD: 0x204A,
	0xFFFD: 0x204B,
	0xFFFD: 0x204C,
	0xFFFD: 0x204D,
	0xFFFD: 0x204E,
	0xFFFD: 0x204F,
	0xFFFD: 0x2050,
	0xFFFD: 0x2051,
	0xFFFD: 0x2052,
	0xFFFD: 0x2053,
	0xFFFD: 0x2054,
	0xFFFD: 0x2055,
	0xFFFD: 0x2056,
	0xFFFD: 0x2057,
	0xFFFD: 0x2058,
	0xFFFD: 0x2059,
	0xFFFD: 0x205A,
	0xFFFD: 0x205B,
	0xFFFD: 0x205C,
	0xFFFD: 0x205D,
	0xFFFD: 0x205E,
	0xFFFD: 0x205F,
	0xFFFD: 0x2060,
	0xFFFD: 0x2061,
	0xFFFD: 0x2062,
	0xFFFD: 0x2063,
	0xFFFD: 0x2064,
	0xFFFD: 0x2065,
	0xFFFD: 0x2066,
	0xFFFD: 0x2067,
	0xFFFD: 0x2068,
	0xFFFD: 0x2069,
	0xFFFD: 0x206A,
	0xFFFD: 0x206B,
	0xFFFD: 0x206C,
	0xFFFD: 0x206D,
	0xFFFD: 0x206E,
	0xFFFD: 0x206F,
	0xFFFD: 0x2070,
	0xFFFD: 0x2071,
	0xFFFD: 0x2072,
	0xFFFD: 0x2073,
	0xFFFD: 0x2074,
	0xFFFD: 0x2075,
	0xFFFD: 0x2076,
	0xFFFD: 0x2077,
	0xFFFD: 0x2078,
	0xFFFD: 0x2079,
	0xFFFD: 0x207A,
	0xFFFD: 0x207B,
	0xFFFD: 0x207C,
	0xFFFD: 0x207D,
	0xFFFD: 0x207E,
	0xFFFD: 0x207F,
	0xFFFD: 0x2080,
	0xFFFD: 0x2081,
	0xFFFD: 0x2082,
	0xFFFD: 0x2083,
	0xFFFD: 0x2084,
	0xFFFD: 0x2085,
	0xFFFD: 0x2086,
	0xFFFD: 0x2087,
	0xFFFD: 0x2088,
	0xFFFD: 0x2089,
	0xFFFD: 0x208A,
	0xFFFD: 0x208B,
	0xFFFD: 0x208C,
	0xFFFD: 0x208D,
	0xFFFD: 0x208E,
	0xFFFD: 0x208F,
	0xFFFD: 0x2090,
	0xFFFD: 0x2091,
	0xFFFD: 0x2092,
	0xFFFD: 0x2093,
	0xFFFD: 0x2094,
	0xFFFD: 0x2095,
	0xFFFD: 0x2096,
	0xFFFD: 0x2097,
	0xFFFD: 0x2098,
	0xFFFD: 0x2099,
	0xFFFD: 0x209A,
	0xFFFD: 0x209B,
	0xFFFD: 0x209C,
	0xFFFD: 0x209D,
	0xFFFD: 0x209E,
	0xFFFD: 0x209F,
	0xFFFD: 0x20A0,
	0xFFFD: 0x20A1,
	0xFFFD: 0x20A2,
	0xFFFD: 0x20A3,
	0xFFFD: 0x20A4,
	0xFFFD: 0x20A5,
	0xFFFD: 0x20A6,
	0xFFFD: 0x20A7,
	0xFFFD: 0x20A8,
	0xFFFD: 0x20A9,
	0xFFFD: 0x20AA,
	0xFFFD: 0x20AB,
	0xA3E1: 0x20AC,
	0xFFFD: 0x20AD,
	0xFFFD: 0x20AE,
	0xFFFD: 0x20AF,
	0xFFFD: 0x20B0,
	0xFFFD: 0x20B1,
	0xFFFD: 0x20B2,
	0xFFFD: 0x20B3,
	0xFFFD: 0x20B4,
	0xFFFD: 0x20B5,
	0xFFFD: 0x20B6,
	0xFFFD: 0x20B7,
	0xFFFD: 0x20B8,
	0xFFFD: 0x20B9,
	0xFFFD: 0x20BA,
	0xFFFD: 0x20BB,
	0xFFFD: 0x20BC,
	0xFFFD: 0x20BD,
	0xFFFD: 0x20BE,
	0xFFFD: 0x20BF,
	0xFFFD: 0x20C0,
	0xFFFD: 0x20C1,
	0xFFFD: 0x20C2,
	0xFFFD: 0x20C3,
	0xFFFD: 0x20C4,
	0xFFFD: 0x20C5,
	0xFFFD: 0x20C6,
	0xFFFD: 0x20C7,
	0xFFFD: 0x20C8,
	0xFFFD: 0x20C9,
	0xFFFD: 0x20CA,
	0xFFFD: 0x20CB,
	0xFFFD: 0x20CC,
	0xFFFD: 0x20CD,
	0xFFFD: 0x20CE,
	0xFFFD: 0x20CF,
	0xFFFD: 0x20D0,
	0xFFFD: 0x20D1,
	0xFFFD: 0x20D2,
	0xFFFD: 0x20D3,
	0xFFFD: 0x20D4,
	0xFFFD: 0x20D5,
	0xFFFD: 0x20D6,
	0xFFFD: 0x20D7,
	0xFFFD: 0x20D8,
	0xFFFD: 0x20D9,
	0xFFFD: 0x20DA,
	0xFFFD: 0x20DB,
	0xFFFD: 0x20DC,
	0xFFFD: 0x20DD,
	0xFFFD: 0x20DE,
	0xFFFD: 0x20DF,
	0xFFFD: 0x20E0,
	0xFFFD: 0x20E1,
	0xFFFD: 0x20E2,
	0xFFFD: 0x20E3,
	0xFFFD: 0x20E4,
	0xFFFD: 0x20E5,
	0xFFFD: 0x20E6,
	0xFFFD: 0x20E7,
	0xFFFD: 0x20E8,
	0xFFFD: 0x20E9,
	0xFFFD: 0x20EA,
	0xFFFD: 0x20EB,
	0xFFFD: 0x20EC,
	0xFFFD: 0x20ED,
	0xFFFD: 0x20EE,
	0xFFFD: 0x20EF,
	0xFFFD: 0x20F0,
	0xFFFD: 0x20F1,
	0xFFFD: 0x20F2,
	0xFFFD: 0x20F3,
	0xFFFD: 0x20F4,
	0xFFFD: 0x20F5,
	0xFFFD: 0x20F6,
	0xFFFD: 0x20F7,
	0xFFFD: 0x20F8,
	0xFFFD: 0x20F9,
	0xFFFD: 0x20FA,
	0xFFFD: 0x20FB,
	0xFFFD: 0x20FC,
	0xFFFD: 0x20FD,
	0xFFFD: 0x20FE,
	0xFFFD: 0x20FF,
	0xFFFD: 0x2100,
	0xFFFD: 0x2101,
	0xFFFD: 0x2102,
	0xA24A: 0x2103,
	0xFFFD: 0x2104,
	0xA1C1: 0x2105,
	0xFFFD: 0x2106,
	0xFFFD: 0x2107,
	0xFFFD: 0x2108,
	0xA24B: 0x2109,
	0xFFFD: 0x210A,
	0xFFFD: 0x210B,
	0xFFFD: 0x210C,
	0xFFFD: 0x210D,
	0xFFFD: 0x210E,
	0xFFFD: 0x210F,
	0xFFFD: 0x2110,
	0xFFFD: 0x2111,
	0xFFFD: 0x2112,
	0xFFFD: 0x2113,
	0xFFFD: 0x2114,
	0xFFFD: 0x2115,
	0x9DCF: 0x2116,
	0xFFFD: 0x2117,
	0xFFFD: 0x2118,
	0xFFFD: 0x2119,
	0xFFFD: 0x211A,
	0xFFFD: 0x211B,
	0xFFFD: 0x211C,
	0xFFFD: 0x211D,
	0x9DE2: 0x211E,
	0xFFFD: 0x211F,
	0xFFFD: 0x2120,
	0x9DC9: 0x2121,
	0x97FC: 0x2122,
	0xFFFD: 0x2123,
	0xFFFD: 0x2124,
	0xFFFD: 0x2125,
	0xFFFD: 0x2126,
	0xFFFD: 0x2127,
	0xFFFD: 0x2128,
	0xFFFD: 0x2129,
	0xFFFD: 0x212A,
	0x9652: 0x212B,
	0xFFFD: 0x212C,
	0xFFFD: 0x212D,
	0xFFFD: 0x212E,
	0xFFFD: 0x212F,
	0xFFFD: 0x2130,
	0xFFFD: 0x2131,
	0xFFFD: 0x2132,
	0xFFFD: 0x2133,
	0xFFFD: 0x2134,
	0xFFFD: 0x2135,
	0xFFFD: 0x2136,
	0xFFFD: 0x2137,
	0xFFFD: 0x2138,
	0xFFFD: 0x2139,
	0xFFFD: 0x213A,
	0x9DC8: 0x213B,
	0xFFFD: 0x213C,
	0xFFFD: 0x213D,
	0xFFFD: 0x213E,
	0xFFFD: 0x213F,
	0xFFFD: 0x2140,
	0xFFFD: 0x2141,
	0xFFFD: 0x2142,
	0xFFFD: 0x2143,
	0xFFFD: 0x2144,
	0xFFFD: 0x2145,
	0xFFFD: 0x2146,
	0xFFFD: 0x2147,
	0xFFFD: 0x2148,
	0xFFFD: 0x2149,
	0xFFFD: 0x214A,
	0xFFFD: 0x214B,
	0xFFFD: 0x214C,
	0xFFFD: 0x214D,
	0xFFFD: 0x214E,
	0xFFFD: 0x214F,
	0xFFFD: 0x2150,
	0xFFFD: 0x2151,
	0xFFFD: 0x2152,
	0xFEB1: 0x2153,
	0xFEB2: 0x2154,
	0xFEB5: 0x2155,
	0xFEB6: 0x2156,
	0xFEB7: 0x2157,
	0xFEB8: 0x2158,
	0xFEB9: 0x2159,
	0xFEBA: 0x215A,
	0xFEC1: 0x215B,
	0xFEC2: 0x215C,
	0xFEC3: 0x215D,
	0xFEC4: 0x215E,
	0xFFFD: 0x215F,
	0xA2B9: 0x2160,
	0xA2BA: 0x2161,
	0xA2BB: 0x2162,
	0xA2BC: 0x2163,
	0xA2BD: 0x2164,
	0xA2BE: 0x2165,
	0xA2BF: 0x2166,
	0xA2C0: 0x2167,
	0xA2C1: 0x2168,
	0xA2C2: 0x2169,
	0xFFFD: 0x216A,
	0xFFFD: 0x216B,
	0xFFFD: 0x216C,
	0xFFFD: 0x216D,
	0xFFFD: 0x216E,
	0xFFFD: 0x216F,
	0xC6B5: 0x2170,
	0xC6B6: 0x2171,
	0xC6B7: 0x2172,
	0xC6B8: 0x2173,
	0xC6B9: 0x2174,
	0xC6BA: 0x2175,
	0xC6BB: 0x2176,
	0xC6BC: 0x2177,
	0xC6BD: 0x2178,
	0xC6BE: 0x2179,
	0xFFFD: 0x217A,
	0xFFFD: 0x217B,
	0xFFFD: 0x217C,
	0xFFFD: 0x217D,
	0xFFFD: 0x217E,
	0xFFFD: 0x217F,
	0xFFFD: 0x2180,
	0xFFFD: 0x2181,
	0xFFFD: 0x2182,
	0xFFFD: 0x2183,
	0xFFFD: 0x2184,
	0xFFFD: 0x2185,
	0xFFFD: 0x2186,
	0xFFFD: 0x2187,
	0xFFFD: 0x2188,
	0xFFFD: 0x2189,
	0xFFFD: 0x218A,
	0xFFFD: 0x218B,
	0xFFFD: 0x218C,
	0xFFFD: 0x218D,
	0xFFFD: 0x218E,
	0xFFFD: 0x218F,
	0xA1F6: 0x2190,
	0xA1F4: 0x2191,
	0xA1F7: 0x2192,
	0xA1F5: 0x2193,
	0x91FB: 0x2194,
	0x91F6: 0x2195,
	0xA1F8: 0x2196,
	0xA1F9: 0x2197,
	0xA1FB: 0x2198,
	0xA1FA: 0x2199,
	0xFFFD: 0x219A,
	0xFFFD: 0x219B,
	0xFFFD: 0x219C,
	0xFFFD: 0x219D,
	0xFFFD: 0x219E,
	0xFFFD: 0x219F,
	0xFFFD: 0x21A0,
	0xFFFD: 0x21A1,
	0xFFFD: 0x21A2,
	0xFFFD: 0x21A3,
	0xFFFD: 0x21A4,
	0xFFFD: 0x21A5,
	0xFFFD: 0x21A6,
	0xFFFD: 0x21A7,
	0x91FA: 0x21A8,
	0xFFFD: 0x21A9,
	0xFFFD: 0x21AA,
	0xFFFD: 0x21AB,
	0xFFFD: 0x21AC,
	0xFFFD: 0x21AD,
	0xFFFD: 0x21AE,
	0xFFFD: 0x21AF,
	0xFFFD: 0x21B0,
	0xFFFD: 0x21B1,
	0x9DFD: 0x21B2,
	0xFFFD: 0x21B3,
	0xFFFD: 0x21B4,
	0xFFFD: 0x21B5,
	0xFFFD: 0x21B6,
	0xFFFD: 0x21B7,
	0xC877: 0x21B8,
	0xC878: 0x21B9,
	0xFFFD: 0x21BA,
	0xFFFD: 0x21BB,
	0xFFFD: 0x21BC,
	0xFFFD: 0x21BD,
	0xFFFD: 0x21BE,
	0xFFFD: 0x21BF,
	0xFFFD: 0x21C0,
	0xFFFD: 0x21C1,
	0xFFFD: 0x21C2,
	0xFFFD: 0x21C3,
	0xFFFD: 0x21C4,
	0xFFFD: 0x21C5,
	0xFFFD: 0x21C6,
	0xFFFD: 0x21C7,
	0xFFFD: 0x21C8,
	0xFFFD: 0x21C9,
	0xFFFD: 0x21CA,
	0x9653: 0x21CB,
	0xFFFD: 0x21CC,
	0xFFFD: 0x21CD,
	0xFFFD: 0x21CE,
	0xFFFD: 0x21CF,
	0xFFFD: 0x21D0,
	0xFFFD: 0x21D1,
	0xFFFD: 0x21D2,
	0xFFFD: 0x21D3,
	0x9965: 0x21D4,
	0xFFFD: 0x21D5,
	0xFFFD: 0x21D6,
	0xFFFD: 0x21D7,
	0xFFFD: 0x21D8,
	0xFFFD: 0x21D9,
	0xFFFD: 0x21DA,
	0xFFFD: 0x21DB,
	0xFFFD: 0x21DC,
	0xFFFD: 0x21DD,
	0xFFFD: 0x21DE,
	0xFFFD: 0x21DF,
	0xFFFD: 0x21E0,
	0xFFFD: 0x21E1,
	0xFFFD: 0x21E2,
	0xFFFD: 0x21E3,
	0xFFFD: 0x21E4,
	0xFFFD: 0x21E5,
	0x9D4A: 0x21E6,
	0xC876: 0x21E7,
	0x9D49: 0x21E8,
	0x9D4C: 0x21E9,
	0xFFFD: 0x21EA,
	0xFFFD: 0x21EB,
	0xFFFD: 0x21EC,
	0xFFFD: 0x21ED,
	0xFFFD: 0x21EE,
	0xFFFD: 0x21EF,
	0xFFFD: 0x21F0,
	0xFFFD: 0x21F1,
	0xFFFD: 0x21F2,
	0xFFFD: 0x21F3,
	0xFFFD: 0x21F4,
	0xFFFD: 0x21F5,
	0xFFFD: 0x21F6,
	0xFFFD: 0x21F7,
	0xFFFD: 0x21F8,
	0xFFFD: 0x21F9,
	0xFFFD: 0x21FA,
	0xFFFD: 0x21FB,
	0xFFFD: 0x21FC,
	0xFFFD: 0x21FD,
	0xFFFD: 0x21FE,
	0xFFFD: 0x21FF,
	0x91F9: 0x2200,
	0xFFFD: 0x2201,
	0xA079: 0x2202,
	0x98F9: 0x2203,
	0xFFFD: 0x2204,
	0xFFFD: 0x2205,
	0xFFFD: 0x2206,
	0xA1BE: 0x2207,
	0x916B: 0x2208,
	0xFFFD: 0x2209,
	0xFFFD: 0x220A,
	0x915F: 0x220B,
	0xFFFD: 0x220C,
	0xFFFD: 0x220D,
	0xFFFD: 0x220E,
	0xA353: 0x220F,
	0xFFFD: 0x2210,
	0xA355: 0x2211,
	0xFFFD: 0x2212,
	0xFFFD: 0x2213,
	0xFFFD: 0x2214,
	0xA241: 0x2215,
	0xA242: 0x2216,
	0xFFFD: 0x2217,
	0xA258: 0x2218,
	0xFFFD: 0x2219,
	0xA1D4: 0x221A,
	0xFFFD: 0x221B,
	0xFFFD: 0x221C,
	0xFFFD: 0x221D,
	0xA1DB: 0x221E,
	0xA1E8: 0x221F,
	0xA1E7: 0x2220,
	0xFFFD: 0x2221,
	0xFFFD: 0x2222,
	0xA1FD: 0x2223,
	0xFFFD: 0x2224,
	0xA1FC: 0x2225,
	0xFFFD: 0x2226,
	0xA34E: 0x2227,
	0xA2E4: 0x2228,
	0xA1E4: 0x2229,
	0xA1E5: 0x222A,
	0xA1EC: 0x222B,
	0x9F4C: 0x222C,
	0xFFFD: 0x222D,
	0xA1ED: 0x222E,
	0xFFFD: 0x222F,
	0xFFFD: 0x2230,
	0xFFFD: 0x2231,
	0xFFFD: 0x2232,
	0xFFFD: 0x2233,
	0xA1EF: 0x2234,
	0xA1EE: 0x2235,
	0xA147: 0x2236,
	0x9F46: 0x2237,
	0xFFFD: 0x2238,
	0xFFFD: 0x2239,
	0xFFFD: 0x223A,
	0xFFFD: 0x223B,
	0xFFFD: 0x223C,
	0xFFFD: 0x223D,
	0xFFFD: 0x223E,
	0xFFFD: 0x223F,
	0xFFFD: 0x2240,
	0xFFFD: 0x2241,
	0xFFFD: 0x2242,
	0xFFFD: 0x2243,
	0xFFFD: 0x2244,
	0xFFFD: 0x2245,
	0xFFFD: 0x2246,
	0xFFFD: 0x2247,
	0xFFFD: 0x2248,
	0xFFFD: 0x2249,
	0xFFFD: 0x224A,
	0xFFFD: 0x224B,
	0xFFFD: 0x224C,
	0xFFFD: 0x224D,
	0xFFFD: 0x224E,
	0xFFFD: 0x224F,
	0xFFFD: 0x2250,
	0xFFFD: 0x2251,
	0xA1DC: 0x2252,
	0xFFFD: 0x2253,
	0xFFFD: 0x2254,
	0xFFFD: 0x2255,
	0xFFFD: 0x2256,
	0xFFFD: 0x2257,
	0xFFFD: 0x2258,
	0xFFFD: 0x2259,
	0xFFFD: 0x225A,
	0xFFFD: 0x225B,
	0xFFFD: 0x225C,
	0xFFFD: 0x225D,
	0xFFFD: 0x225E,
	0xFFFD: 0x225F,
	0xA1DA: 0x2260,
	0xA1DD: 0x2261,
	0xFFFD: 0x2262,
	0xA1DD: 0x2263,
	0xFFFD: 0x2264,
	0xFFFD: 0x2265,
	0xA1D8: 0x2266,
	0xA1D9: 0x2267,
	0xFFFD: 0x2268,
	0xFFFD: 0x2269,
	0xFFFD: 0x226A,
	0xFFFD: 0x226B,
	0xFFFD: 0x226C,
	0xFFFD: 0x226D,
	0xFFFD: 0x226E,
	0xFFFD: 0x226F,
	0xFFFD: 0x2270,
	0xFFFD: 0x2271,
	0xFFFD: 0x2272,
	0xFFFD: 0x2273,
	0xFFFD: 0x2274,
	0xFFFD: 0x2275,
	0xFFFD: 0x2276,
	0xFFFD: 0x2277,
	0xFFFD: 0x2278,
	0xFFFD: 0x2279,
	0xFFFD: 0x227A,
	0xFFFD: 0x227B,
	0xFFFD: 0x227C,
	0xFFFD: 0x227D,
	0xFFFD: 0x227E,
	0xFFFD: 0x227F,
	0xFFFD: 0x2280,
	0xFFFD: 0x2281,
	0x9AE0: 0x2282,
	0x9AA6: 0x2283,
	0xFFFD: 0x2284,
	0xFFFD: 0x2285,
	0x9C72: 0x2286,
	0x9CAA: 0x2287,
	0xFFFD: 0x2288,
	0xFFFD: 0x2289,
	0xFFFD: 0x228A,
	0xFFFD: 0x228B,
	0xFFFD: 0x228C,
	0xFFFD: 0x228D,
	0xFFFD: 0x228E,
	0xFFFD: 0x228F,
	0xFFFD: 0x2290,
	0xFFFD: 0x2291,
	0xFFFD: 0x2292,
	0xFFFD: 0x2293,
	0xFFFD: 0x2294,
	0xA1F2: 0x2295,
	0xFFFD: 0x2296,
	0xFFFD: 0x2297,
	0xFFFD: 0x2298,
	0xA1F3: 0x2299,
	0xFFFD: 0x229A,
	0xFFFD: 0x229B,
	0xFFFD: 0x229C,
	0xFFFD: 0x229D,
	0xFFFD: 0x229E,
	0xFFFD: 0x229F,
	0xFFFD: 0x22A0,
	0xFFFD: 0x22A1,
	0xFFFD: 0x22A2,
	0xFFFD: 0x22A3,
	0xFFFD: 0x22A4,
	0xA1E6: 0x22A5,
	0xFFFD: 0x22A6,
	0xFFFD: 0x22A7,
	0xFFFD: 0x22A8,
	0xFFFD: 0x22A9,
	0xFFFD: 0x22AA,
	0xFFFD: 0x22AB,
	0xFFFD: 0x22AC,
	0xFFFD: 0x22AD,
	0xFFFD: 0x22AE,
	0xFFFD: 0x22AF,
	0xFFFD: 0x22B0,
	0xFFFD: 0x22B1,
	0xFFFD: 0x22B2,
	0xFFFD: 0x22B3,
	0xFFFD: 0x22B4,
	0xFFFD: 0x22B5,
	0xFFFD: 0x22B6,
	0xFFFD: 0x22B7,
	0xFFFD: 0x22B8,
	0xFFFD: 0x22B9,
	0xFFFD: 0x22BA,
	0xFFFD: 0x22BB,
	0xFFFD: 0x22BC,
	0xFFFD: 0x22BD,
	0xFFFD: 0x22BE,
	0xA1E9: 0x22BF,
	0xFFFD: 0x22C0,
	0xFFFD: 0x22C1,
	0xFFFD: 0x22C2,
	0xFFFD: 0x22C3,
	0xFFFD: 0x22C4,
	0xFFFD: 0x22C5,
	0xFFFD: 0x22C6,
	0xFFFD: 0x22C7,
	0xFFFD: 0x22C8,
	0xFFFD: 0x22C9,
	0xFFFD: 0x22CA,
	0xFFFD: 0x22CB,
	0xFFFD: 0x22CC,
	0xFFFD: 0x22CD,
	0xFFFD: 0x22CE,
	0xFFFD: 0x22CF,
	0xFFFD: 0x22D0,
	0xFFFD: 0x22D1,
	0xFFFD: 0x22D2,
	0xFFFD: 0x22D3,
	0xFFFD: 0x22D4,
	0xFFFD: 0x22D5,
	0xFFFD: 0x22D6,
	0xFFFD: 0x22D7,
	0xFFFD: 0x22D8,
	0xFFFD: 0x22D9,
	0xFFFD: 0x22DA,
	0xFFFD: 0x22DB,
	0xFFFD: 0x22DC,
	0xFFFD: 0x22DD,
	0xFFFD: 0x22DE,
	0xFFFD: 0x22DF,
	0xFFFD: 0x22E0,
	0xFFFD: 0x22E1,
	0xFFFD: 0x22E2,
	0xFFFD: 0x22E3,
	0xFFFD: 0x22E4,
	0xFFFD: 0x22E5,
	0xFFFD: 0x22E6,
	0xFFFD: 0x22E7,
	0xFFFD: 0x22E8,
	0xFFFD: 0x22E9,
	0xFFFD: 0x22EA,
	0xFFFD: 0x22EB,
	0xFFFD: 0x22EC,
	0xFFFD: 0x22ED,
	0xFFFD: 0x22EE,
	0xFFFD: 0x22EF,
	0xFFFD: 0x22F0,
	0xFFFD: 0x22F1,
	0xFFFD: 0x22F2,
	0xFFFD: 0x22F3,
	0xFFFD: 0x22F4,
	0xFFFD: 0x22F5,
	0xFFFD: 0x22F6,
	0xFFFD: 0x22F7,
	0xFFFD: 0x22F8,
	0xFFFD: 0x22F9,
	0xFFFD: 0x22FA,
	0xFFFD: 0x22FB,
	0xFFFD: 0x22FC,
	0xFFFD: 0x22FD,
	0xFFFD: 0x22FE,
	0xFFFD: 0x22FF,
	0xFFFD: 0x2300,
	0xFFFD: 0x2301,
	0x91FC: 0x2302,
	0xFFFD: 0x2303,
	0xFFFD: 0x2304,
	0xFFFD: 0x2305,
	0xFFFD: 0x2306,
	0xA15B: 0x2307,
	0xFFFD: 0x2308,
	0xFFFD: 0x2309,
	0xFFFD: 0x230A,
	0xFFFD: 0x230B,
	0xFFFD: 0x230C,
	0xFFFD: 0x230D,
	0xFFFD: 0x230E,
	0xFFFD: 0x230F,
	0xFFFD: 0x2310,
	0xFFFD: 0x2311,
	0xFED9: 0x2312,
	0xFFFD: 0x2313,
	0xFFFD: 0x2314,
	0xFFFD: 0x2315,
	0xFFFD: 0x2316,
	0xFFFD: 0x2317,
	0xFFFD: 0x2318,
	0xFFFD: 0x2319,
	0xFFFD: 0x231A,
	0xFFFD: 0x231B,
	0xFFFD: 0x231C,
	0xFFFD: 0x231D,
	0xFFFD: 0x231E,
	0xFFFD: 0x231F,
	0xFFFD: 0x2320,
	0xFFFD: 0x2321,
	0xFFFD: 0x2322,
	0xFFFD: 0x2323,
	0xFFFD: 0x2324,
	0xFFFD: 0x2325,
	0xFFFD: 0x2326,
	0xFFFD: 0x2327,
	0xFFFD: 0x2328,
	0xFFFD: 0x2329,
	0xFFFD: 0x232A,
	0xFFFD: 0x232B,
	0xFFFD: 0x232C,
	0xFFFD: 0x232D,
	0xFFFD: 0x232E,
	0xFFFD: 0x232F,
	0xFFFD: 0x2330,
	0xFFFD: 0x2331,
	0xFFFD: 0x2332,
	0xFFFD: 0x2333,
	0xFFFD: 0x2334,
	0xFFFD: 0x2335,
	0xFFFD: 0x2336,
	0xFFFD: 0x2337,
	0xFFFD: 0x2338,
	0xFFFD: 0x2339,
	0xFFFD: 0x233A,
	0xFFFD: 0x233B,
	0xFFFD: 0x233C,
	0xFFFD: 0x233D,
	0xFFFD: 0x233E,
	0xFFFD: 0x233F,
	0xFFFD: 0x2340,
	0xFFFD: 0x2341,
	0xFFFD: 0x2342,
	0xFFFD: 0x2343,
	0xFFFD: 0x2344,
	0xFFFD: 0x2345,
	0xFFFD: 0x2346,
	0xFFFD: 0x2347,
	0xFFFD: 0x2348,
	0xFFFD: 0x2349,
	0xFFFD: 0x234A,
	0xFFFD: 0x234B,
	0xFFFD: 0x234C,
	0xFFFD: 0x234D,
	0xFFFD: 0x234E,
	0xFFFD: 0x234F,
	0xFFFD: 0x2350,
	0xFFFD: 0x2351,
	0xFFFD: 0x2352,
	0xFFFD: 0x2353,
	0xFFFD: 0x2354,
	0xFFFD: 0x2355,
	0xFFFD: 0x2356,
	0xFFFD: 0x2357,
	0xFFFD: 0x2358,
	0xFFFD: 0x2359,
	0xFFFD: 0x235A,
	0xFFFD: 0x235B,
	0xFFFD: 0x235C,
	0xFFFD: 0x235D,
	0xFFFD: 0x235E,
	0xFFFD: 0x235F,
	0xFFFD: 0x2360,
	0xFFFD: 0x2361,
	0xFFFD: 0x2362,
	0xFFFD: 0x2363,
	0xFFFD: 0x2364,
	0xFFFD: 0x2365,
	0xFFFD: 0x2366,
	0xFFFD: 0x2367,
	0xFFFD: 0x2368,
	0xFFFD: 0x2369,
	0xFFFD: 0x236A,
	0xFFFD: 0x236B,
	0xFFFD: 0x236C,
	0xFFFD: 0x236D,
	0xFFFD: 0x236E,
	0xFFFD: 0x236F,
	0xFFFD: 0x2370,
	0xFFFD: 0x2371,
	0xFFFD: 0x2372,
	0xFFFD: 0x2373,
	0xFFFD: 0x2374,
	0xFFFD: 0x2375,
	0xFFFD: 0x2376,
	0xFFFD: 0x2377,
	0xFFFD: 0x2378,
	0xFFFD: 0x2379,
	0xFFFD: 0x237A,
	0xFFFD: 0x237B,
	0xFFFD: 0x237C,
	0xFFFD: 0x237D,
	0xFFFD: 0x237E,
	0xFFFD: 0x237F,
	0xFFFD: 0x2380,
	0xFFFD: 0x2381,
	0xFFFD: 0x2382,
	0xFFFD: 0x2383,
	0xFFFD: 0x2384,
	0xFFFD: 0x2385,
	0xFFFD: 0x2386,
	0xFFFD: 0x2387,
	0xFFFD: 0x2388,
	0xFFFD: 0x2389,
	0xFFFD: 0x238A,
	0xFFFD: 0x238B,
	0xFFFD: 0x238C,
	0xFFFD: 0x238D,
	0xFFFD: 0x238E,
	0xFFFD: 0x238F,
	0xFFFD: 0x2390,
	0xFFFD: 0x2391,
	0xFFFD: 0x2392,
	0xFFFD: 0x2393,
	0xFFFD: 0x2394,
	0xFFFD: 0x2395,
	0xFFFD: 0x2396,
	0xFFFD: 0x2397,
	0xFFFD: 0x2398,
	0xFFFD: 0x2399,
	0xFFFD: 0x239A,
	0xFFFD: 0x239B,
	0xFFFD: 0x239C,
	0xFFFD: 0x239D,
	0xFFFD: 0x239E,
	0xFFFD: 0x239F,
	0xFFFD: 0x23A0,
	0xFFFD: 0x23A1,
	0xFFFD: 0x23A2,
	0xFFFD: 0x23A3,
	0xFFFD: 0x23A4,
	0xFFFD: 0x23A5,
	0xFFFD: 0x23A6,
	0xFFFD: 0x23A7,
	0xFFFD: 0x23A8,
	0xFFFD: 0x23A9,
	0xFFFD: 0x23AA,
	0xFFFD: 0x23AB,
	0xFFFD: 0x23AC,
	0xFFFD: 0x23AD,
	0xFFFD: 0x23AE,
	0xFFFD: 0x23AF,
	0xFFFD: 0x23B0,
	0xFFFD: 0x23B1,
	0xFFFD: 0x23B2,
	0xFFFD: 0x23B3,
	0xFFFD: 0x23B4,
	0xFFFD: 0x23B5,
	0xFFFD: 0x23B6,
	0xFFFD: 0x23B7,
	0xFFFD: 0x23B8,
	0xFFFD: 0x23B9,
	0xFFFD: 0x23BA,
	0xFFFD: 0x23BB,
	0xFFFD: 0x23BC,
	0xFFFD: 0x23BD,
	0xFFFD: 0x23BE,
	0xFFFD: 0x23BF,
	0xFFFD: 0x23C0,
	0xFFFD: 0x23C1,
	0xFFFD: 0x23C2,
	0xFFFD: 0x23C3,
	0xFFFD: 0x23C4,
	0xFFFD: 0x23C5,
	0xFFFD: 0x23C6,
	0xFFFD: 0x23C7,
	0xFFFD: 0x23C8,
	0xFFFD: 0x23C9,
	0xFFFD: 0x23CA,
	0xFFFD: 0x23CB,
	0xFFFD: 0x23CC,
	0xFFFD: 0x23CD,
	0xFFFD: 0x23CE,
	0xFFFD: 0x23CF,
	0xFFFD: 0x23D0,
	0xFFFD: 0x23D1,
	0xFFFD: 0x23D2,
	0xFFFD: 0x23D3,
	0xFFFD: 0x23D4,
	0xFFFD: 0x23D5,
	0xFFFD: 0x23D6,
	0xFFFD: 0x23D7,
	0xFFFD: 0x23D8,
	0xFFFD: 0x23D9,
	0xFFFD: 0x23DA,
	0xFFFD: 0x23DB,
	0xFFFD: 0x23DC,
	0xFFFD: 0x23DD,
	0xFFFD: 0x23DE,
	0xFFFD: 0x23DF,
	0xFFFD: 0x23E0,
	0xFFFD: 0x23E1,
	0xFFFD: 0x23E2,
	0xFFFD: 0x23E3,
	0xFFFD: 0x23E4,
	0xFFFD: 0x23E5,
	0xFFFD: 0x23E6,
	0xFFFD: 0x23E7,
	0xFFFD: 0x23E8,
	0xFFFD: 0x23E9,
	0xFFFD: 0x23EA,
	0xFFFD: 0x23EB,
	0xFFFD: 0x23EC,
	0xFFFD: 0x23ED,
	0xFFFD: 0x23EE,
	0xFFFD: 0x23EF,
	0xFFFD: 0x23F0,
	0xFFFD: 0x23F1,
	0xFFFD: 0x23F2,
	0xFFFD: 0x23F3,
	0xFFFD: 0x23F4,
	0xFFFD: 0x23F5,
	0xFFFD: 0x23F6,
	0xFFFD: 0x23F7,
	0xFFFD: 0x23F8,
	0xFFFD: 0x23F9,
	0xFFFD: 0x23FA,
	0xFFFD: 0x23FB,
	0xFFFD: 0x23FC,
	0xFFFD: 0x23FD,
	0xFFFD: 0x23FE,
	0xFFFD: 0x23FF,
	0xA3C0: 0x2400,
	0xA3C1: 0x2401,
	0xA3C2: 0x2402,
	0xA3C3: 0x2403,
	0xA3C4: 0x2404,
	0xA3C5: 0x2405,
	0xA3C6: 0x2406,
	0xA3C7: 0x2407,
	0xA3C8: 0x2408,
	0xA3C9: 0x2409,
	0xA3CA: 0x240A,
	0xA3CB: 0x240B,
	0xA3CC: 0x240C,
	0xA3CD: 0x240D,
	0xA3CE: 0x240E,
	0xA3CF: 0x240F,
	0xA3D0: 0x2410,
	0xA3D1: 0x2411,
	0xA3D2: 0x2412,
	0xA3D3: 0x2413,
	0xA3D4: 0x2414,
	0xA3D5: 0x2415,
	0xA3D6: 0x2416,
	0xA3D7: 0x2417,
	0xA3D8: 0x2418,
	0xA3D9: 0x2419,
	0xA3DA: 0x241A,
	0xA3DB: 0x241B,
	0xA3DC: 0x241C,
	0xA3DD: 0x241D,
	0xA3DE: 0x241E,
	0xA3DF: 0x241F,
	0xFFFD: 0x2420,
	0xA3E0: 0x2421,
	0xFFFD: 0x2422,
	0xFFFD: 0x2423,
	0xFFFD: 0x2424,
	0xFFFD: 0x2425,
	0xFFFD: 0x2426,
	0xFFFD: 0x2427,
	0xFFFD: 0x2428,
	0xFFFD: 0x2429,
	0xFFFD: 0x242A,
	0xFFFD: 0x242B,
	0xFFFD: 0x242C,
	0xFFFD: 0x242D,
	0xFFFD: 0x242E,
	0xFFFD: 0x242F,
	0xFFFD: 0x2430,
	0xFFFD: 0x2431,
	0xFFFD: 0x2432,
	0xFFFD: 0x2433,
	0xFFFD: 0x2434,
	0xFFFD: 0x2435,
	0xFFFD: 0x2436,
	0xFFFD: 0x2437,
	0xFFFD: 0x2438,
	0xFFFD: 0x2439,
	0xFFFD: 0x243A,
	0xFFFD: 0x243B,
	0xFFFD: 0x243C,
	0xFFFD: 0x243D,
	0xFFFD: 0x243E,
	0xFFFD: 0x243F,
	0xFFFD: 0x2440,
	0xFFFD: 0x2441,
	0xFFFD: 0x2442,
	0xFFFD: 0x2443,
	0xFFFD: 0x2444,
	0xFFFD: 0x2445,
	0xFFFD: 0x2446,
	0xFFFD: 0x2447,
	0xFFFD: 0x2448,
	0xFFFD: 0x2449,
	0xFFFD: 0x244A,
	0xFFFD: 0x244B,
	0xFFFD: 0x244C,
	0xFFFD: 0x244D,
	0xFFFD: 0x244E,
	0xFFFD: 0x244F,
	0xFFFD: 0x2450,
	0xFFFD: 0x2451,
	0xFFFD: 0x2452,
	0xFFFD: 0x2453,
	0xFFFD: 0x2454,
	0xFFFD: 0x2455,
	0xFFFD: 0x2456,
	0xFFFD: 0x2457,
	0xFFFD: 0x2458,
	0xFFFD: 0x2459,
	0xFFFD: 0x245A,
	0xFFFD: 0x245B,
	0xFFFD: 0x245C,
	0xFFFD: 0x245D,
	0xFFFD: 0x245E,
	0xFFFD: 0x245F,
	0xC6A1: 0x2460,
	0xC6A2: 0x2461,
	0xC6A3: 0x2462,
	0xC6A4: 0x2463,
	0xC6A5: 0x2464,
	0xC6A6: 0x2465,
	0xC6A7: 0x2466,
	0xC6A8: 0x2467,
	0xC6A9: 0x2468,
	0xC6AA: 0x2469,
	0x974B: 0x246A,
	0x974C: 0x246B,
	0x974D: 0x246C,
	0x974E: 0x246D,
	0x974F: 0x246E,
	0x9750: 0x246F,
	0x9751: 0x2470,
	0x9752: 0x2471,
	0x9753: 0x2472,
	0x9754: 0x2473,
	0xC6AB: 0x2474,
	0xC6AC: 0x2475,
	0xC6AD: 0x2476,
	0xC6AE: 0x2477,
	0xC6AF: 0x2478,
	0xC6B0: 0x2479,
	0xC6B1: 0x247A,
	0xC6B2: 0x247B,
	0xC6B3: 0x247C,
	0xC6B4: 0x247D,
	0x994B: 0x247E,
	0x994C: 0x247F,
	0x994D: 0x2480,
	0x994E: 0x2481,
	0x994F: 0x2482,
	0x9950: 0x2483,
	0x9951: 0x2484,
	0x9952: 0x2485,
	0x9953: 0x2486,
	0x9954: 0x2487,
	0x9A41: 0x2488,
	0x9A42: 0x2489,
	0x9A43: 0x248A,
	0x9A44: 0x248B,
	0x9A45: 0x248C,
	0x9A46: 0x248D,
	0x9A47: 0x248E,
	0x9A48: 0x248F,
	0x9A49: 0x2490,
	0x9A4A: 0x2491,
	0x9A4B: 0x2492,
	0x9A4C: 0x2493,
	0x9A4D: 0x2494,
	0x9A4E: 0x2495,
	0x9A4F: 0x2496,
	0x9A50: 0x2497,
	0x9A51: 0x2498,
	0x9A52: 0x2499,
	0x9A53: 0x249A,
	0x9A54: 0x249B,
	0x99E1: 0x249C,
	0x99E2: 0x249D,
	0x99E3: 0x249E,
	0x99E4: 0x249F,
	0x99E5: 0x24A0,
	0x99E6: 0x24A1,
	0x99E7: 0x24A2,
	0x99E8: 0x24A3,
	0x99E9: 0x24A4,
	0x99EA: 0x24A5,
	0x99EB: 0x24A6,
	0x99EC: 0x24A7,
	0x99ED: 0x24A8,
	0x99EE: 0x24A9,
	0x99EF: 0x24AA,
	0x99F0: 0x24AB,
	0x99F1: 0x24AC,
	0x99F2: 0x24AD,
	0x99F3: 0x24AE,
	0x99F4: 0x24AF,
	0x99F5: 0x24B0,
	0x99F6: 0x24B1,
	0x99F7: 0x24B2,
	0x99F8: 0x24B3,
	0x99F9: 0x24B4,
	0x99FA: 0x24B5,
	0x97C7: 0x24B6,
	0x97C8: 0x24B7,
	0x97C9: 0x24B8,
	0x97CA: 0x24B9,
	0x97CB: 0x24BA,
	0x97CC: 0x24BB,
	0x97CD: 0x24BC,
	0x97CE: 0x24BD,
	0x97CF: 0x24BE,
	0x97D0: 0x24BF,
	0x97D1: 0x24C0,
	0x97D2: 0x24C1,
	0x97D3: 0x24C2,
	0x97D4: 0x24C3,
	0x97D5: 0x24C4,
	0x97D6: 0x24C5,
	0x97D7: 0x24C6,
	0x97D8: 0x24C7,
	0x97D9: 0x24C8,
	0x97DA: 0x24C9,
	0x97DB: 0x24CA,
	0x97DC: 0x24CB,
	0x97DD: 0x24CC,
	0x97DE: 0x24CD,
	0x97DF: 0x24CE,
	0x97E0: 0x24CF,
	0x97E1: 0x24D0,
	0x97E2: 0x24D1,
	0x97E3: 0x24D2,
	0x97E4: 0x24D3,
	0x97E5: 0x24D4,
	0x97E6: 0x24D5,
	0x97E7: 0x24D6,
	0x97E8: 0x24D7,
	0x97E9: 0x24D8,
	0x97EA: 0x24D9,
	0x97EB: 0x24DA,
	0x97EC: 0x24DB,
	0x97ED: 0x24DC,
	0x97EE: 0x24DD,
	0x97EF: 0x24DE,
	0x97F0: 0x24DF,
	0x97F1: 0x24E0,
	0x97F2: 0x24E1,
	0x97F3: 0x24E2,
	0x97F4: 0x24E3,
	0x97F5: 0x24E4,
	0x97F6: 0x24E5,
	0x97F7: 0x24E6,
	0x97F8: 0x24E7,
	0x97F9: 0x24E8,
	0x97FA: 0x24E9,
	0x9740: 0x24EA,
	0xFFFD: 0x24EB,
	0xFFFD: 0x24EC,
	0xFFFD: 0x24ED,
	0xFFFD: 0x24EE,
	0xFFFD: 0x24EF,
	0xFFFD: 0x24F0,
	0xFFFD: 0x24F1,
	0xFFFD: 0x24F2,
	0xFFFD: 0x24F3,
	0xFFFD: 0x24F4,
	0xFFFD: 0x24F5,
	0xFFFD: 0x24F6,
	0xFFFD: 0x24F7,
	0xFFFD: 0x24F8,
	0xFFFD: 0x24F9,
	0xFFFD: 0x24FA,
	0xFFFD: 0x24FB,
	0xFFFD: 0x24FC,
	0xFFFD: 0x24FD,
	0xFFFD: 0x24FE,
	0xFFFD: 0x24FF,
	0xA277: 0x2500,
	0x9D7D: 0x2501,
	0xA278: 0x2502,
	0x9D7E: 0x2503,
	0xA14C: 0x2504,
	0xA14C: 0x2505,
	0xA14A: 0x2506,
	0xA14A: 0x2507,
	0xA14B: 0x2508,
	0xA14B: 0x2509,
	0xA155: 0x250A,
	0xA155: 0x250B,
	0xA27A: 0x250C,
	0xA27A: 0x250D,
	0xA27A: 0x250E,
	0xA27A: 0x250F,
	0xA27B: 0x2510,
	0xA27B: 0x2511,
	0xA27B: 0x2512,
	0xA27B: 0x2513,
	0xA27C: 0x2514,
	0xA27C: 0x2515,
	0xA27C: 0x2516,
	0xA27C: 0x2517,
	0xA27D: 0x2518,
	0xA27D: 0x2519,
	0xA27D: 0x251A,
	0xA27D: 0x251B,
	0xA275: 0x251C,
	0xA275: 0x251D,
	0xA275: 0x251E,
	0xA275: 0x251F,
	0xA275: 0x2520,
	0xA275: 0x2521,
	0xA275: 0x2522,
	0xA275: 0x2523,
	0xA274: 0x2524,
	0xA274: 0x2525,
	0xA274: 0x2526,
	0xA274: 0x2527,
	0xA274: 0x2528,
	0xA274: 0x2529,
	0xA274: 0x252A,
	0xA274: 0x252B,
	0xA273: 0x252C,
	0xA273: 0x252D,
	0xA273: 0x252E,
	0xA273: 0x252F,
	0xA273: 0x2530,
	0xA273: 0x2531,
	0xA273: 0x2532,
	0xA273: 0x2533,
	0xA272: 0x2534,
	0xA272: 0x2535,
	0xA272: 0x2536,
	0xA272: 0x2537,
	0xA272: 0x2538,
	0xA272: 0x2539,
	0xA272: 0x253A,
	0xA272: 0x253B,
	0xA271: 0x253C,
	0xA271: 0x253D,
	0xA271: 0x253E,
	0xA271: 0x253F,
	0xA271: 0x2540,
	0xA271: 0x2541,
	0xA271: 0x2542,
	0xA271: 0x2543,
	0xA271: 0x2544,
	0xA271: 0x2545,
	0xA271: 0x2546,
	0xA271: 0x2547,
	0xA271: 0x2548,
	0xA271: 0x2549,
	0xA271: 0x254A,
	0xA271: 0x254B,
	0xFFFD: 0x254C,
	0xFFFD: 0x254D,
	0x91F0: 0x254E,
	0xFFFD: 0x254F,
	0xF9F9: 0x2550,
	0xF9F8: 0x2551,
	0xF9E6: 0x2552,
	0xF9EF: 0x2553,
	0xF9DD: 0x2554,
	0xF9E8: 0x2555,
	0xF9F1: 0x2556,
	0xF9DF: 0x2557,
	0xF9EC: 0x2558,
	0xF9F5: 0x2559,
	0xF9E3: 0x255A,
	0xF9EE: 0x255B,
	0xF9F7: 0x255C,
	0xF9E5: 0x255D,
	0xF9E9: 0x255E,
	0xF9F2: 0x255F,
	0xF9E0: 0x2560,
	0xF9EB: 0x2561,
	0xF9F4: 0x2562,
	0xF9E2: 0x2563,
	0xF9E7: 0x2564,
	0xF9F0: 0x2565,
	0xF9DE: 0x2566,
	0xF9ED: 0x2567,
	0xF9F6: 0x2568,
	0xF9E4: 0x2569,
	0xF9EA: 0x256A,
	0xF9F3: 0x256B,
	0xF9E1: 0x256C,
	0xA27E: 0x256D,
	0xA2A1: 0x256E,
	0xA2A3: 0x256F,
	0xA2A2: 0x2570,
	0xA2AC: 0x2571,
	0xA2AD: 0x2572,
	0xA2AE: 0x2573,
	0xA15A: 0x2574,
	0xFFFD: 0x2575,
	0xFFFD: 0x2576,
	0xFFFD: 0x2577,
	0xFFFD: 0x2578,
	0xFFFD: 0x2579,
	0xFFFD: 0x257A,
	0xFFFD: 0x257B,
	0xFFFD: 0x257C,
	0xFFFD: 0x257D,
	0xFFFD: 0x257E,
	0xFFFD: 0x257F,
	0xFFFD: 0x2580,
	0xA262: 0x2581,
	0xA263: 0x2582,
	0xA264: 0x2583,
	0xA265: 0x2584,
	0xA266: 0x2585,
	0xA267: 0x2586,
	0xA268: 0x2587,
	0xA269: 0x2588,
	0xA270: 0x2589,
	0xA26F: 0x258A,
	0xA26E: 0x258B,
	0xA26D: 0x258C,
	0xA26C: 0x258D,
	0xA26B: 0x258E,
	0xA26A: 0x258F,
	0xFFFD: 0x2590,
	0xFFFD: 0x2591,
	0xFFFD: 0x2592,
	0xF9FE: 0x2593,
	0xA276: 0x2594,
	0xA279: 0x2595,
	0xFFFD: 0x2596,
	0xFFFD: 0x2597,
	0xFFFD: 0x2598,
	0xFFFD: 0x2599,
	0xFFFD: 0x259A,
	0xFFFD: 0x259B,
	0xFFFD: 0x259C,
	0xFFFD: 0x259D,
	0xFFFD: 0x259E,
	0xFFFD: 0x259F,
	0xA1BD: 0x25A0,
	0xA1BC: 0x25A1,
	0xFFFD: 0x25A2,
	0xFFFD: 0x25A3,
	0xFFFD: 0x25A4,
	0xFFFD: 0x25A5,
	0xFFFD: 0x25A6,
	0xFFFD: 0x25A7,
	0xFFFD: 0x25A8,
	0xFFFD: 0x25A9,
	0xFFFD: 0x25AA,
	0xFFFD: 0x25AB,
	0xFFFD: 0x25AC,
	0xFFFD: 0x25AD,
	0xFFFD: 0x25AE,
	0xFFFD: 0x25AF,
	0xFFFD: 0x25B0,
	0xFFFD: 0x25B1,
	0xA1B6: 0x25B2,
	0xA1B5: 0x25B3,
	0xFFFD: 0x25B4,
	0xFFFD: 0x25B5,
	0x91F4: 0x25B6,
	0xFFFD: 0x25B7,
	0xFFFD: 0x25B8,
	0xFFFD: 0x25B9,
	0xFFFD: 0x25BA,
	0xFFFD: 0x25BB,
	0xA1BF: 0x25BC,
	0xA1BE: 0x25BD,
	0xFFFD: 0x25BE,
	0xFFFD: 0x25BF,
	0xFFFD: 0x25C0,
	0xFFFD: 0x25C1,
	0xFFFD: 0x25C2,
	0xFFFD: 0x25C3,
	0x91F5: 0x25C4,
	0xFFFD: 0x25C5,
	0xA1BB: 0x25C6,
	0xA1BA: 0x25C7,
	0xFFFD: 0x25C8,
	0xFFFD: 0x25C9,
	0xFFFD: 0x25CA,
	0xA1B3: 0x25CB,
	0xFFFD: 0x25CC,
	0xFFFD: 0x25CD,
	0xA1B7: 0x25CE,
	0xA1B4: 0x25CF,
	0xFFFD: 0x25D0,
	0xFFFD: 0x25D1,
	0xFFFD: 0x25D2,
	0xFFFD: 0x25D3,
	0xFFFD: 0x25D4,
	0xFFFD: 0x25D5,
	0xFFFD: 0x25D6,
	0xFFFD: 0x25D7,
	0x91F1: 0x25D8,
	0x91F2: 0x25D9,
	0xFFFD: 0x25DA,
	0xFFFD: 0x25DB,
	0xFFFD: 0x25DC,
	0xFFFD: 0x25DD,
	0xFFFD: 0x25DE,
	0xFFFD: 0x25DF,
	0xFFFD: 0x25E0,
	0xFFFD: 0x25E1,
	0xA2A8: 0x25E2,
	0xA2A9: 0x25E3,
	0xA2AB: 0x25E4,
	0xA2AA: 0x25E5,
	0xFFFD: 0x25E6,
	0xFFFD: 0x25E7,
	0xFFFD: 0x25E8,
	0xFFFD: 0x25E9,
	0xFFFD: 0x25EA,
	0xFFFD: 0x25EB,
	0xFFFD: 0x25EC,
	0xFFFD: 0x25ED,
	0xFFFD: 0x25EE,
	0xA1B3: 0x25EF,
	0xFFFD: 0x25F0,
	0xFFFD: 0x25F1,
	0xFFFD: 0x25F2,
	0xFFFD: 0x25F3,
	0xFFFD: 0x25F4,
	0xFFFD: 0x25F5,
	0xFFFD: 0x25F6,
	0xFFFD: 0x25F7,
	0xFFFD: 0x25F8,
	0xFFFD: 0x25F9,
	0xFFFD: 0x25FA,
	0xFFFD: 0x25FB,
	0xFFFD: 0x25FC,
	0xFFFD: 0x25FD,
	0xFFFD: 0x25FE,
	0xFFFD: 0x25FF,
	0xFFFD: 0x2600,
	0x9DBA: 0x2601,
	0x9DBC: 0x2602,
	0xFFFD: 0x2603,
	0xFFFD: 0x2604,
	0xA1B9: 0x2605,
	0xA1B8: 0x2606,
	0xFFFD: 0x2607,
	0xFFFD: 0x2608,
	0xA1F3: 0x2609,
	0xFFFD: 0x260A,
	0xFFFD: 0x260B,
	0xFFFD: 0x260C,
	0xFFFD: 0x260D,
	0x9D40: 0x260E,
	0xFFFD: 0x260F,
	0xFFFD: 0x2610,
	0x9DED: 0x2611,
	0x9CD1: 0x2612,
	0xFFFD: 0x2613,
	0xFFFD: 0x2614,
	0xFFFD: 0x2615,
	0xFFFD: 0x2616,
	0xFFFD: 0x2617,
	0xFFFD: 0x2618,
	0xFFFD: 0x2619,
	0xFFFD: 0x261A,
	0x9D4F: 0x261B,
	0x9D4E: 0x261C,
	0xFFFD: 0x261D,
	0x9D4D: 0x261E,
	0x9D50: 0x261F,
	0x9DD5: 0x2620,
	0xFFFD: 0x2621,
	0xFFFD: 0x2622,
	0xFFFD: 0x2623,
	0xFFFD: 0x2624,
	0xFFFD: 0x2625,
	0xFFFD: 0x2626,
	0xFFFD: 0x2627,
	0xFFFD: 0x2628,
	0xFFFD: 0x2629,
	0xFFFD: 0x262A,
	0xFFFD: 0x262B,
	0xFFFD: 0x262C,
	0xFFFD: 0x262D,
	0xFFFD: 0x262E,
	0x9F55: 0x262F,
	0x9F56: 0x2630,
	0x9F5D: 0x2631,
	0x9F5B: 0x2632,
	0x9F58: 0x2633,
	0x9F59: 0x2634,
	0x9F5A: 0x2635,
	0x9F5C: 0x2636,
	0x9F57: 0x2637,
	0xFFFD: 0x2638,
	0x9D5E: 0x2639,
	0x9D5D: 0x263A,
	0x98FC: 0x263B,
	0x9DB8: 0x263C,
	0x9D57: 0x263D,
	0xFFFD: 0x263E,
	0xFFFD: 0x263F,
	0xA1F0: 0x2640,
	0xA1F2: 0x2641,
	0xA1F1: 0x2642,
	0xFFFD: 0x2643,
	0xFFFD: 0x2644,
	0xFFFD: 0x2645,
	0xFFFD: 0x2646,
	0xFFFD: 0x2647,
	0xFFFD: 0x2648,
	0xFFFD: 0x2649,
	0xFFFD: 0x264A,
	0xFFFD: 0x264B,
	0xFFFD: 0x264C,
	0xFFFD: 0x264D,
	0xFFFD: 0x264E,
	0xFFFD: 0x264F,
	0xFFFD: 0x2650,
	0xFFFD: 0x2651,
	0xFFFD: 0x2652,
	0xFFFD: 0x2653,
	0xFFFD: 0x2654,
	0xFFFD: 0x2655,
	0xFFFD: 0x2656,
	0xFFFD: 0x2657,
	0xFFFD: 0x2658,
	0xFFFD: 0x2659,
	0xFFFD: 0x265A,
	0xFFFD: 0x265B,
	0xFFFD: 0x265C,
	0xFFFD: 0x265D,
	0xFFFD: 0x265E,
	0xFFFD: 0x265F,
	0x9DD8: 0x2660,
	0x9DDD: 0x2661,
	0x9DDB: 0x2662,
	0x9DDA: 0x2663,
	0x9DD7: 0x2664,
	0x9DDE: 0x2665,
	0x9DDC: 0x2666,
	0x9DD9: 0x2667,
	0xFFFD: 0x2668,
	0xFFFD: 0x2669,
	0x9D66: 0x266A,
	0xFFFD: 0x266B,
	0x9D65: 0x266C,
	0xA2EA: 0x266D,
	0xFFFD: 0x266E,
	0xA1AD: 0x266F,
	0xFFFD: 0x2670,
	0xFFFD: 0x2671,
	0xFFFD: 0x2672,
	0xFFFD: 0x2673,
	0xFFFD: 0x2674,
	0xFFFD: 0x2675,
	0xFFFD: 0x2676,
	0xFFFD: 0x2677,
	0xFFFD: 0x2678,
	0xFFFD: 0x2679,
	0xFFFD: 0x267A,
	0xFFFD: 0x267B,
	0xFFFD: 0x267C,
	0xFFFD: 0x267D,
	0xFFFD: 0x267E,
	0xFFFD: 0x267F,
	0xFFFD: 0x2680,
	0xFFFD: 0x2681,
	0xFFFD: 0x2682,
	0xFFFD: 0x2683,
	0xFFFD: 0x2684,
	0xFFFD: 0x2685,
	0xFFFD: 0x2686,
	0xFFFD: 0x2687,
	0xFFFD: 0x2688,
	0xFFFD: 0x2689,
	0xFFFD: 0x268A,
	0xFFFD: 0x268B,
	0xFFFD: 0x268C,
	0xFFFD: 0x268D,
	0xFFFD: 0x268E,
	0xFFFD: 0x268F,
	0xFFFD: 0x2690,
	0xFFFD: 0x2691,
	0xFFFD: 0x2692,
	0xFFFD: 0x2693,
	0xFFFD: 0x2694,
	0xFFFD: 0x2695,
	0xFFFD: 0x2696,
	0xFFFD: 0x2697,
	0xFFFD: 0x2698,
	0xFFFD: 0x2699,
	0xFFFD: 0x269A,
	0xFFFD: 0x269B,
	0xFFFD: 0x269C,
	0xFFFD: 0x269D,
	0xFFFD: 0x269E,
	0xFFFD: 0x269F,
	0xFFFD: 0x26A0,
	0xFFFD: 0x26A1,
	0xFFFD: 0x26A2,
	0xFFFD: 0x26A3,
	0xFFFD: 0x26A4,
	0xFFFD: 0x26A5,
	0xFFFD: 0x26A6,
	0xFFFD: 0x26A7,
	0xFFFD: 0x26A8,
	0xFFFD: 0x26A9,
	0xFFFD: 0x26AA,
	0xFFFD: 0x26AB,
	0xFFFD: 0x26AC,
	0xFFFD: 0x26AD,
	0xFFFD: 0x26AE,
	0xFFFD: 0x26AF,
	0xFFFD: 0x26B0,
	0xFFFD: 0x26B1,
	0xFFFD: 0x26B2,
	0xFFFD: 0x26B3,
	0xFFFD: 0x26B4,
	0xFFFD: 0x26B5,
	0xFFFD: 0x26B6,
	0xFFFD: 0x26B7,
	0xFFFD: 0x26B8,
	0xFFFD: 0x26B9,
	0xFFFD: 0x26BA,
	0xFFFD: 0x26BB,
	0xFFFD: 0x26BC,
	0xFFFD: 0x26BD,
	0xFFFD: 0x26BE,
	0xFFFD: 0x26BF,
	0xFFFD: 0x26C0,
	0xFFFD: 0x26C1,
	0xFFFD: 0x26C2,
	0xFFFD: 0x26C3,
	0xFFFD: 0x26C4,
	0xFFFD: 0x26C5,
	0xFFFD: 0x26C6,
	0xFFFD: 0x26C7,
	0xFFFD: 0x26C8,
	0xFFFD: 0x26C9,
	0xFFFD: 0x26CA,
	0xFFFD: 0x26CB,
	0xFFFD: 0x26CC,
	0xFFFD: 0x26CD,
	0xFFFD: 0x26CE,
	0xFFFD: 0x26CF,
	0xFFFD: 0x26D0,
	0xFFFD: 0x26D1,
	0xFFFD: 0x26D2,
	0xFFFD: 0x26D3,
	0xFFFD: 0x26D4,
	0xFFFD: 0x26D5,
	0xFFFD: 0x26D6,
	0xFFFD: 0x26D7,
	0xFFFD: 0x26D8,
	0xFFFD: 0x26D9,
	0xFFFD: 0x26DA,
	0xFFFD: 0x26DB,
	0xFFFD: 0x26DC,
	0xFFFD: 0x26DD,
	0xFFFD: 0x26DE,
	0xFFFD: 0x26DF,
	0xFFFD: 0x26E0,
	0xFFFD: 0x26E1,
	0xFFFD: 0x26E2,
	0xFFFD: 0x26E3,
	0xFFFD: 0x26E4,
	0xFFFD: 0x26E5,
	0xFFFD: 0x26E6,
	0xFFFD: 0x26E7,
	0xFFFD: 0x26E8,
	0xFFFD: 0x26E9,
	0xFFFD: 0x26EA,
	0xFFFD: 0x26EB,
	0xFFFD: 0x26EC,
	0xFFFD: 0x26ED,
	0xFFFD: 0x26EE,
	0xFFFD: 0x26EF,
	0xFFFD: 0x26F0,
	0xFFFD: 0x26F1,
	0xFFFD: 0x26F2,
	0xFFFD: 0x26F3,
	0xFFFD: 0x26F4,
	0xFFFD: 0x26F5,
	0xFFFD: 0x26F6,
	0xFFFD: 0x26F7,
	0xFFFD: 0x26F8,
	0xFFFD: 0x26F9,
	0xFFFD: 0x26FA,
	0xFFFD: 0x26FB,
	0xFFFD: 0x26FC,
	0xFFFD: 0x26FD,
	0xFFFD: 0x26FE,
	0xFFFD: 0x26FF,
	0xFFFD: 0x2700,
	0xFFFD: 0x2701,
	0x9D6C: 0x2702,
	0xFFFD: 0x2703,
	0xFFFD: 0x2704,
	0xFFFD: 0x2705,
	0xFFFD: 0x2706,
	0xFFFD: 0x2707,
	0x9DC0: 0x2708,
	0x9D6B: 0x2709,
	0xFFFD: 0x270A,
	0xFFFD: 0x270B,
	0xFFFD: 0x270C,
	0xFFFD: 0x270D,
	0xFFFD: 0x270E,
	0xFFFD: 0x270F,
	0xFFFD: 0x2710,
	0xFFFD: 0x2711,
	0xFFFD: 0x2712,
	0x9D55: 0x2713,
	0xFFFD: 0x2714,
	0x9D54: 0x2715,
	0xFFFD: 0x2716,
	0xFFFD: 0x2717,
	0xFFFD: 0x2718,
	0xFFFD: 0x2719,
	0xFFFD: 0x271A,
	0xFFFD: 0x271B,
	0xFFFD: 0x271C,
	0xFFFD: 0x271D,
	0xFFFD: 0x271E,
	0xFFFD: 0x271F,
	0xFFFD: 0x2720,
	0x9D5C: 0x2721,
	0xFFFD: 0x2722,
	0xFFFD: 0x2723,
	0xFFFD: 0x2724,
	0xFFFD: 0x2725,
	0xFFFD: 0x2726,
	0xFFFD: 0x2727,
	0xFFFD: 0x2728,
	0x9D5B: 0x2729,
	0xFFFD: 0x272A,
	0xFFFD: 0x272B,
	0xFFFD: 0x272C,
	0xFFFD: 0x272D,
	0xFFFD: 0x272E,
	0xFFFD: 0x272F,
	0xFFFD: 0x2730,
	0xFFFD: 0x2731,
	0xFFFD: 0x2732,
	0xFFFD: 0x2733,
	0xFFFD: 0x2734,
	0xFFFD: 0x2735,
	0xFFFD: 0x2736,
	0xFFFD: 0x2737,
	0xFFFD: 0x2738,
	0xFFFD: 0x2739,
	0xFFFD: 0x273A,
	0xFFFD: 0x273B,
	0xFFFD: 0x273C,
	0xC6E6: 0x273D,
	0xFFFD: 0x273E,
	0xFFFD: 0x273F,
	0xFFFD: 0x2740,
	0xFFFD: 0x2741,
	0xFFFD: 0x2742,
	0xFFFD: 0x2743,
	0xFFFD: 0x2744,
	0xFFFD: 0x2745,
	0xFFFD: 0x2746,
	0xFFFD: 0x2747,
	0xFFFD: 0x2748,
	0xFFFD: 0x2749,
	0xFFFD: 0x274A,
	0xFFFD: 0x274B,
	0xFFFD: 0x274C,
	0xFFFD: 0x274D,
	0xFFFD: 0x274E,
	0x9D77: 0x274F,
	0xFFFD: 0x2750,
	0xFFFD: 0x2751,
	0xFFFD: 0x2752,
	0xFFFD: 0x2753,
	0xFFFD: 0x2754,
	0xFFFD: 0x2755,
	0xFFFD: 0x2756,
	0xFFFD: 0x2757,
	0xFFFD: 0x2758,
	0xFFFD: 0x2759,
	0xFFFD: 0x275A,
	0xFFFD: 0x275B,
	0xFFFD: 0x275C,
	0xFFFD: 0x275D,
	0xFFFD: 0x275E,
	0xFFFD: 0x275F,
	0xFFFD: 0x2760,
	0xFFFD: 0x2761,
	0xFFFD: 0x2762,
	0xFFFD: 0x2763,
	0xFFFD: 0x2764,
	0xFFFD: 0x2765,
	0xFFFD: 0x2766,
	0xFFFD: 0x2767,
	0xFFFD: 0x2768,
	0xFFFD: 0x2769,
	0xFFFD: 0x276A,
	0xFFFD: 0x276B,
	0xFFFD: 0x276C,
	0xFFFD: 0x276D,
	0xFFFD: 0x276E,
	0xFFFD: 0x276F,
	0xFFFD: 0x2770,
	0xFFFD: 0x2771,
	0xFFFD: 0x2772,
	0xFFFD: 0x2773,
	0xFFFD: 0x2774,
	0xFFFD: 0x2775,
	0x9841: 0x2776,
	0x9842: 0x2777,
	0x9843: 0x2778,
	0x9844: 0x2779,
	0x9845: 0x277A,
	0x9846: 0x277B,
	0x9847: 0x277C,
	0x9848: 0x277D,
	0x9849: 0x277E,
	0x984A: 0x277F,
	0xC6A1: 0x2780,
	0xC6A2: 0x2781,
	0xC6A3: 0x2782,
	0xC6A4: 0x2783,
	0xC6A5: 0x2784,
	0xC6A6: 0x2785,
	0xC6A7: 0x2786,
	0xC6A8: 0x2787,
	0xC6A9: 0x2788,
	0xC6AA: 0x2789,
	0x9841: 0x278A,
	0x9842: 0x278B,
	0x9843: 0x278C,
	0x9844: 0x278D,
	0x9845: 0x278E,
	0x9846: 0x278F,
	0x9847: 0x2790,
	0x9848: 0x2791,
	0x9849: 0x2792,
	0x984A: 0x2793,
	0xFFFD: 0x2794,
	0xFFFD: 0x2795,
	0xFFFD: 0x2796,
	0xFFFD: 0x2797,
	0xFFFD: 0x2798,
	0xFFFD: 0x2799,
	0xFFFD: 0x279A,
	0xFFFD: 0x279B,
	0xFFFD: 0x279C,
	0xFFFD: 0x279D,
	0xFFFD: 0x279E,
	0xFFFD: 0x279F,
	0xFFFD: 0x27A0,
	0xFFFD: 0x27A1,
	0xFFFD: 0x27A2,
	0xFFFD: 0x27A3,
	0xFFFD: 0x27A4,
	0xFFFD: 0x27A5,
	0xFFFD: 0x27A6,
	0xFFFD: 0x27A7,
	0xFFFD: 0x27A8,
	0xFFFD: 0x27A9,
	0xFFFD: 0x27AA,
	0xFFFD: 0x27AB,
	0xFFFD: 0x27AC,
	0xFFFD: 0x27AD,
	0xFFFD: 0x27AE,
	0xFFFD: 0x27AF,
	0xFFFD: 0x27B0,
	0xFFFD: 0x27B1,
	0xFFFD: 0x27B2,
	0xFFFD: 0x27B3,
	0xFFFD: 0x27B4,
	0xFFFD: 0x27B5,
	0xFFFD: 0x27B6,
	0xFFFD: 0x27B7,
	0xFFFD: 0x27B8,
	0xFFFD: 0x27B9,
	0xFFFD: 0x27BA,
	0xFFFD: 0x27BB,
	0xFFFD: 0x27BC,
	0xFFFD: 0x27BD,
	0xFFFD: 0x27BE,
	0xFFFD: 0x27BF,
	0xFFFD: 0x27C0,
	0xFFFD: 0x27C1,
	0xFFFD: 0x27C2,
	0xFFFD: 0x27C3,
	0xFFFD: 0x27C4,
	0xFFFD: 0x27C5,
	0xFFFD: 0x27C6,
	0xFFFD: 0x27C7,
	0xFFFD: 0x27C8,
	0xFFFD: 0x27C9,
	0xFFFD: 0x27CA,
	0xFFFD: 0x27CB,
	0xFFFD: 0x27CC,
	0xFFFD: 0x27CD,
	0xFFFD: 0x27CE,
	0xFFFD: 0x27CF,
	0xFFFD: 0x27D0,
	0xFFFD: 0x27D1,
	0xFFFD: 0x27D2,
	0xFFFD: 0x27D3,
	0xFFFD: 0x27D4,
	0xFFFD: 0x27D5,
	0xFFFD: 0x27D6,
	0xFFFD: 0x27D7,
	0xFFFD: 0x27D8,
	0xFFFD: 0x27D9,
	0xFFFD: 0x27DA,
	0xFFFD: 0x27DB,
	0xFFFD: 0x27DC,
	0xFFFD: 0x27DD,
	0xFFFD: 0x27DE,
	0xFFFD: 0x27DF,
	0xFFFD: 0x27E0,
	0xFFFD: 0x27E1,
	0xFFFD: 0x27E2,
	0xFFFD: 0x27E3,
	0xFFFD: 0x27E4,
	0xFFFD: 0x27E5,
	0xFFFD: 0x27E6,
	0xFFFD: 0x27E7,
	0xFFFD: 0x27E8,
	0xFFFD: 0x27E9,
	0xFFFD: 0x27EA,
	0xFFFD: 0x27EB,
	0xFFFD: 0x27EC,
	0xFFFD: 0x27ED,
	0xFFFD: 0x27EE,
	0xFFFD: 0x27EF,
	0xFFFD: 0x27F0,
	0xFFFD: 0x27F1,
	0xFFFD: 0x27F2,
	0xFFFD: 0x27F3,
	0xFFFD: 0x27F4,
	0xFFFD: 0x27F5,
	0xFFFD: 0x27F6,
	0xFFFD: 0x27F7,
	0xFFFD: 0x27F8,
	0xFFFD: 0x27F9,
	0xFFFD: 0x27FA,
	0xFFFD: 0x27FB,
	0xFFFD: 0x27FC,
	0xFFFD: 0x27FD,
	0xFFFD: 0x27FE,
	0xFFFD: 0x27FF,
	0xFFFD: 0x2800,
	0xFFFD: 0x2801,
	0xFFFD: 0x2802,
	0xFFFD: 0x2803,
	0xFFFD: 0x2804,
	0xFFFD: 0x2805,
	0xFFFD: 0x2806,
	0xFFFD: 0x2807,
	0xFFFD: 0x2808,
	0xFFFD: 0x2809,
	0xFFFD: 0x280A,
	0xFFFD: 0x280B,
	0xFFFD: 0x280C,
	0xFFFD: 0x280D,
	0xFFFD: 0x280E,
	0xFFFD: 0x280F,
	0xFFFD: 0x2810,
	0xFFFD: 0x2811,
	0xFFFD: 0x2812,
	0xFFFD: 0x2813,
	0xFFFD: 0x2814,
	0xFFFD: 0x2815,
	0xFFFD: 0x2816,
	0xFFFD: 0x2817,
	0xFFFD: 0x2818,
	0xFFFD: 0x2819,
	0xFFFD: 0x281A,
	0xFFFD: 0x281B,
	0xFFFD: 0x281C,
	0xFFFD: 0x281D,
	0xFFFD: 0x281E,
	0xFFFD: 0x281F,
	0xFFFD: 0x2820,
	0xFFFD: 0x2821,
	0xFFFD: 0x2822,
	0xFFFD: 0x2823,
	0xFFFD: 0x2824,
	0xFFFD: 0x2825,
	0xFFFD: 0x2826,
	0xFFFD: 0x2827,
	0xFFFD: 0x2828,
	0xFFFD: 0x2829,
	0xFFFD: 0x282A,
	0xFFFD: 0x282B,
	0xFFFD: 0x282C,
	0xFFFD: 0x282D,
	0xFFFD: 0x282E,
	0xFFFD: 0x282F,
	0xFFFD: 0x2830,
	0xFFFD: 0x2831,
	0xFFFD: 0x2832,
	0xFFFD: 0x2833,
	0xFFFD: 0x2834,
	0xFFFD: 0x2835,
	0xFFFD: 0x2836,
	0xFFFD: 0x2837,
	0xFFFD: 0x2838,
	0xFFFD: 0x2839,
	0xFFFD: 0x283A,
	0xFFFD: 0x283B,
	0xFFFD: 0x283C,
	0xFFFD: 0x283D,
	0xFFFD: 0x283E,
	0xFFFD: 0x283F,
	0xFFFD: 0x2840,
	0xFFFD: 0x2841,
	0xFFFD: 0x2842,
	0xFFFD: 0x2843,
	0xFFFD: 0x2844,
	0xFFFD: 0x2845,
	0xFFFD: 0x2846,
	0xFFFD: 0x2847,
	0xFFFD: 0x2848,
	0xFFFD: 0x2849,
	0xFFFD: 0x284A,
	0xFFFD: 0x284B,
	0xFFFD: 0x284C,
	0xFFFD: 0x284D,
	0xFFFD: 0x284E,
	0xFFFD: 0x284F,
	0xFFFD: 0x2850,
	0xFFFD: 0x2851,
	0xFFFD: 0x2852,
	0xFFFD: 0x2853,
	0xFFFD: 0x2854,
	0xFFFD: 0x2855,
	0xFFFD: 0x2856,
	0xFFFD: 0x2857,
	0xFFFD: 0x2858,
	0xFFFD: 0x2859,
	0xFFFD: 0x285A,
	0xFFFD: 0x285B,
	0xFFFD: 0x285C,
	0xFFFD: 0x285D,
	0xFFFD: 0x285E,
	0xFFFD: 0x285F,
	0xFFFD: 0x2860,
	0xFFFD: 0x2861,
	0xFFFD: 0x2862,
	0xFFFD: 0x2863,
	0xFFFD: 0x2864,
	0xFFFD: 0x2865,
	0xFFFD: 0x2866,
	0xFFFD: 0x2867,
	0xFFFD: 0x2868,
	0xFFFD: 0x2869,
	0xFFFD: 0x286A,
	0xFFFD: 0x286B,
	0xFFFD: 0x286C,
	0xFFFD: 0x286D,
	0xFFFD: 0x286E,
	0xFFFD: 0x286F,
	0xFFFD: 0x2870,
	0xFFFD: 0x2871,
	0xFFFD: 0x2872,
	0xFFFD: 0x2873,
	0xFFFD: 0x2874,
	0xFFFD: 0x2875,
	0xFFFD: 0x2876,
	0xFFFD: 0x2877,
	0xFFFD: 0x2878,
	0xFFFD: 0x2879,
	0xFFFD: 0x287A,
	0xFFFD: 0x287B,
	0xFFFD: 0x287C,
	0xFFFD: 0x287D,
	0xFFFD: 0x287E,
	0xFFFD: 0x287F,
	0xFFFD: 0x2880,
	0xFFFD: 0x2881,
	0xFFFD: 0x2882,
	0xFFFD: 0x2883,
	0xFFFD: 0x2884,
	0xFFFD: 0x2885,
	0xFFFD: 0x2886,
	0xFFFD: 0x2887,
	0xFFFD: 0x2888,
	0xFFFD: 0x2889,
	0xFFFD: 0x288A,
	0xFFFD: 0x288B,
	0xFFFD: 0x288C,
	0xFFFD: 0x288D,
	0xFFFD: 0x288E,
	0xFFFD: 0x288F,
	0xFFFD: 0x2890,
	0xFFFD: 0x2891,
	0xFFFD: 0x2892,
	0xFFFD: 0x2893,
	0xFFFD: 0x2894,
	0xFFFD: 0x2895,
	0xFFFD: 0x2896,
	0xFFFD: 0x2897,
	0xFFFD: 0x2898,
	0xFFFD: 0x2899,
	0xFFFD: 0x289A,
	0xFFFD: 0x289B,
	0xFFFD: 0x289C,
	0xFFFD: 0x289D,
	0xFFFD: 0x289E,
	0xFFFD: 0x289F,
	0xFFFD: 0x28A0,
	0xFFFD: 0x28A1,
	0xFFFD: 0x28A2,
	0xFFFD: 0x28A3,
	0xFFFD: 0x28A4,
	0xFFFD: 0x28A5,
	0xFFFD: 0x28A6,
	0xFFFD: 0x28A7,
	0xFFFD: 0x28A8,
	0xFFFD: 0x28A9,
	0xFFFD: 0x28AA,
	0xFFFD: 0x28AB,
	0xFFFD: 0x28AC,
	0xFFFD: 0x28AD,
	0xFFFD: 0x28AE,
	0xFFFD: 0x28AF,
	0xFFFD: 0x28B0,
	0xFFFD: 0x28B1,
	0xFFFD: 0x28B2,
	0xFFFD: 0x28B3,
	0xFFFD: 0x28B4,
	0xFFFD: 0x28B5,
	0xFFFD: 0x28B6,
	0xFFFD: 0x28B7,
	0xFFFD: 0x28B8,
	0xFFFD: 0x28B9,
	0xFFFD: 0x28BA,
	0xFFFD: 0x28BB,
	0xFFFD: 0x28BC,
	0xFFFD: 0x28BD,
	0xFFFD: 0x28BE,
	0xFFFD: 0x28BF,
	0xFFFD: 0x28C0,
	0xFFFD: 0x28C1,
	0xFFFD: 0x28C2,
	0xFFFD: 0x28C3,
	0xFFFD: 0x28C4,
	0xFFFD: 0x28C5,
	0xFFFD: 0x28C6,
	0xFFFD: 0x28C7,
	0xFFFD: 0x28C8,
	0xFFFD: 0x28C9,
	0xFFFD: 0x28CA,
	0xFFFD: 0x28CB,
	0xFFFD: 0x28CC,
	0xFFFD: 0x28CD,
	0xFFFD: 0x28CE,
	0xFFFD: 0x28CF,
	0xFFFD: 0x28D0,
	0xFFFD: 0x28D1,
	0xFFFD: 0x28D2,
	0xFFFD: 0x28D3,
	0xFFFD: 0x28D4,
	0xFFFD: 0x28D5,
	0xFFFD: 0x28D6,
	0xFFFD: 0x28D7,
	0xFFFD: 0x28D8,
	0xFFFD: 0x28D9,
	0xFFFD: 0x28DA,
	0xFFFD: 0x28DB,
	0xFFFD: 0x28DC,
	0xFFFD: 0x28DD,
	0xFFFD: 0x28DE,
	0xFFFD: 0x28DF,
	0xFFFD: 0x28E0,
	0xFFFD: 0x28E1,
	0xFFFD: 0x28E2,
	0xFFFD: 0x28E3,
	0xFFFD: 0x28E4,
	0xFFFD: 0x28E5,
	0xFFFD: 0x28E6,
	0xFFFD: 0x28E7,
	0xFFFD: 0x28E8,
	0xFFFD: 0x28E9,
	0xFFFD: 0x28EA,
	0xFFFD: 0x28EB,
	0xFFFD: 0x28EC,
	0xFFFD: 0x28ED,
	0xFFFD: 0x28EE,
	0xFFFD: 0x28EF,
	0xFFFD: 0x28F0,
	0xFFFD: 0x28F1,
	0xFFFD: 0x28F2,
	0xFFFD: 0x28F3,
	0xFFFD: 0x28F4,
	0xFFFD: 0x28F5,
	0xFFFD: 0x28F6,
	0xFFFD: 0x28F7,
	0xFFFD: 0x28F8,
	0xFFFD: 0x28F9,
	0xFFFD: 0x28FA,
	0xFFFD: 0x28FB,
	0xFFFD: 0x28FC,
	0xFFFD: 0x28FD,
	0xFFFD: 0x28FE,
	0xFFFD: 0x28FF,
	0xFFFD: 0x2900,
	0xFFFD: 0x2901,
	0xFFFD: 0x2902,
	0xFFFD: 0x2903,
	0xFFFD: 0x2904,
	0xFFFD: 0x2905,
	0xFFFD: 0x2906,
	0xFFFD: 0x2907,
	0xFFFD: 0x2908,
	0xFFFD: 0x2909,
	0xFFFD: 0x290A,
	0xFFFD: 0x290B,
	0xFFFD: 0x290C,
	0xFFFD: 0x290D,
	0xFFFD: 0x290E,
	0xFFFD: 0x290F,
	0xFFFD: 0x2910,
	0xFFFD: 0x2911,
	0xFFFD: 0x2912,
	0xFFFD: 0x2913,
	0xFFFD: 0x2914,
	0xFFFD: 0x2915,
	0xFFFD: 0x2916,
	0xFFFD: 0x2917,
	0xFFFD: 0x2918,
	0xFFFD: 0x2919,
	0xFFFD: 0x291A,
	0xFFFD: 0x291B,
	0xFFFD: 0x291C,
	0xFFFD: 0x291D,
	0xFFFD: 0x291E,
	0xFFFD: 0x291F,
	0xFFFD: 0x2920,
	0xFFFD: 0x2921,
	0xFFFD: 0x2922,
	0xFFFD: 0x2923,
	0xFFFD: 0x2924,
	0xFFFD: 0x2925,
	0xFFFD: 0x2926,
	0xFFFD: 0x2927,
	0xFFFD: 0x2928,
	0xFFFD: 0x2929,
	0xFFFD: 0x292A,
	0xFFFD: 0x292B,
	0xFFFD: 0x292C,
	0xFFFD: 0x292D,
	0xFFFD: 0x292E,
	0xFFFD: 0x292F,
	0xFFFD: 0x2930,
	0xFFFD: 0x2931,
	0xFFFD: 0x2932,
	0xFFFD: 0x2933,
	0xFFFD: 0x2934,
	0xFFFD: 0x2935,
	0xFFFD: 0x2936,
	0xFFFD: 0x2937,
	0xFFFD: 0x2938,
	0xFFFD: 0x2939,
	0xFFFD: 0x293A,
	0xFFFD: 0x293B,
	0xFFFD: 0x293C,
	0xFFFD: 0x293D,
	0xFFFD: 0x293E,
	0xFFFD: 0x293F,
	0xFFFD: 0x2940,
	0xFFFD: 0x2941,
	0xFFFD: 0x2942,
	0xFFFD: 0x2943,
	0xFFFD: 0x2944,
	0xFFFD: 0x2945,
	0xFFFD: 0x2946,
	0xFFFD: 0x2947,
	0xFFFD: 0x2948,
	0xFFFD: 0x2949,
	0xFFFD: 0x294A,
	0xFFFD: 0x294B,
	0xFFFD: 0x294C,
	0xFFFD: 0x294D,
	0xFFFD: 0x294E,
	0xFFFD: 0x294F,
	0xFFFD: 0x2950,
	0xFFFD: 0x2951,
	0xFFFD: 0x2952,
	0xFFFD: 0x2953,
	0xFFFD: 0x2954,
	0xFFFD: 0x2955,
	0xFFFD: 0x2956,
	0xFFFD: 0x2957,
	0xFFFD: 0x2958,
	0xFFFD: 0x2959,
	0xFFFD: 0x295A,
	0xFFFD: 0x295B,
	0xFFFD: 0x295C,
	0xFFFD: 0x295D,
	0xFFFD: 0x295E,
	0xFFFD: 0x295F,
	0xFFFD: 0x2960,
	0xFFFD: 0x2961,
	0xFFFD: 0x2962,
	0xFFFD: 0x2963,
	0xFFFD: 0x2964,
	0xFFFD: 0x2965,
	0xFFFD: 0x2966,
	0xFFFD: 0x2967,
	0xFFFD: 0x2968,
	0xFFFD: 0x2969,
	0xFFFD: 0x296A,
	0xFFFD: 0x296B,
	0xFFFD: 0x296C,
	0xFFFD: 0x296D,
	0xFFFD: 0x296E,
	0xFFFD: 0x296F,
	0xFFFD: 0x2970,
	0xFFFD: 0x2971,
	0xFFFD: 0x2972,
	0xFFFD: 0x2973,
	0xFFFD: 0x2974,
	0xFFFD: 0x2975,
	0xFFFD: 0x2976,
	0xFFFD: 0x2977,
	0xFFFD: 0x2978,
	0xFFFD: 0x2979,
	0xFFFD: 0x297A,
	0xFFFD: 0x297B,
	0xFFFD: 0x297C,
	0xFFFD: 0x297D,
	0xFFFD: 0x297E,
	0xFFFD: 0x297F,
	0xFFFD: 0x2980,
	0xFFFD: 0x2981,
	0xFFFD: 0x2982,
	0xFFFD: 0x2983,
	0xFFFD: 0x2984,
	0xFFFD: 0x2985,
	0xFFFD: 0x2986,
	0xFFFD: 0x2987,
	0xFFFD: 0x2988,
	0xFFFD: 0x2989,
	0xFFFD: 0x298A,
	0xFFFD: 0x298B,
	0xFFFD: 0x298C,
	0xFFFD: 0x298D,
	0xFFFD: 0x298E,
	0xFFFD: 0x298F,
	0xFFFD: 0x2990,
	0xFFFD: 0x2991,
	0xFFFD: 0x2992,
	0xFFFD: 0x2993,
	0xFFFD: 0x2994,
	0xFFFD: 0x2995,
	0xFFFD: 0x2996,
	0xFFFD: 0x2997,
	0xFFFD: 0x2998,
	0xFFFD: 0x2999,
	0xFFFD: 0x299A,
	0xFFFD: 0x299B,
	0xFFFD: 0x299C,
	0xFFFD: 0x299D,
	0xFFFD: 0x299E,
	0xFFFD: 0x299F,
	0xFFFD: 0x29A0,
	0xFFFD: 0x29A1,
	0xFFFD: 0x29A2,
	0xFFFD: 0x29A3,
	0xFFFD: 0x29A4,
	0xFFFD: 0x29A5,
	0xFFFD: 0x29A6,
	0xFFFD: 0x29A7,
	0xFFFD: 0x29A8,
	0xFFFD: 0x29A9,
	0xFFFD: 0x29AA,
	0xFFFD: 0x29AB,
	0xFFFD: 0x29AC,
	0xFFFD: 0x29AD,
	0xFFFD: 0x29AE,
	0xFFFD: 0x29AF,
	0xFFFD: 0x29B0,
	0xFFFD: 0x29B1,
	0xFFFD: 0x29B2,
	0xFFFD: 0x29B3,
	0xFFFD: 0x29B4,
	0xFFFD: 0x29B5,
	0xFFFD: 0x29B6,
	0xFFFD: 0x29B7,
	0xFFFD: 0x29B8,
	0xFFFD: 0x29B9,
	0xFFFD: 0x29BA,
	0xFFFD: 0x29BB,
	0xFFFD: 0x29BC,
	0xFFFD: 0x29BD,
	0xFFFD: 0x29BE,
	0xFFFD: 0x29BF,
	0xFFFD: 0x29C0,
	0xFFFD: 0x29C1,
	0xFFFD: 0x29C2,
	0xFFFD: 0x29C3,
	0xFFFD: 0x29C4,
	0xFFFD: 0x29C5,
	0xFFFD: 0x29C6,
	0xFFFD: 0x29C7,
	0xFFFD: 0x29C8,
	0xFFFD: 0x29C9,
	0xFFFD: 0x29CA,
	0xFFFD: 0x29CB,
	0xFFFD: 0x29CC,
	0xFFFD: 0x29CD,
	0xFFFD: 0x29CE,
	0xFFFD: 0x29CF,
	0xFFFD: 0x29D0,
	0xFFFD: 0x29D1,
	0xFFFD: 0x29D2,
	0xFFFD: 0x29D3,
	0xFFFD: 0x29D4,
	0xFFFD: 0x29D5,
	0xFFFD: 0x29D6,
	0xFFFD: 0x29D7,
	0xFFFD: 0x29D8,
	0xFFFD: 0x29D9,
	0xFFFD: 0x29DA,
	0xFFFD: 0x29DB,
	0xFFFD: 0x29DC,
	0xFFFD: 0x29DD,
	0xFFFD: 0x29DE,
	0xFFFD: 0x29DF,
	0xFFFD: 0x29E0,
	0xFFFD: 0x29E1,
	0xFFFD: 0x29E2,
	0xFFFD: 0x29E3,
	0xFFFD: 0x29E4,
	0xFFFD: 0x29E5,
	0xFFFD: 0x29E6,
	0xFFFD: 0x29E7,
	0xFFFD: 0x29E8,
	0xFFFD: 0x29E9,
	0xFFFD: 0x29EA,
	0xFFFD: 0x29EB,
	0xFFFD: 0x29EC,
	0xFFFD: 0x29ED,
	0xFFFD: 0x29EE,
	0xFFFD: 0x29EF,
	0xFFFD: 0x29F0,
	0xFFFD: 0x29F1,
	0xFFFD: 0x29F2,
	0xFFFD: 0x29F3,
	0xFFFD: 0x29F4,
	0xFFFD: 0x29F5,
	0xFFFD: 0x29F6,
	0xFFFD: 0x29F7,
	0xFFFD: 0x29F8,
	0xFFFD: 0x29F9,
	0xFFFD: 0x29FA,
	0xFFFD: 0x29FB,
	0xFFFD: 0x29FC,
	0xFFFD: 0x29FD,
	0xFFFD: 0x29FE,
	0xFFFD: 0x29FF,
	0xFFFD: 0x2A00,
	0xFFFD: 0x2A01,
	0xFFFD: 0x2A02,
	0xFFFD: 0x2A03,
	0xFFFD: 0x2A04,
	0xFFFD: 0x2A05,
	0xFFFD: 0x2A06,
	0xFFFD: 0x2A07,
	0xFFFD: 0x2A08,
	0xFFFD: 0x2A09,
	0xFFFD: 0x2A0A,
	0xFFFD: 0x2A0B,
	0xFFFD: 0x2A0C,
	0xFFFD: 0x2A0D,
	0xFFFD: 0x2A0E,
	0xFFFD: 0x2A0F,
	0xFFFD: 0x2A10,
	0xFFFD: 0x2A11,
	0xFFFD: 0x2A12,
	0xFFFD: 0x2A13,
	0xFFFD: 0x2A14,
	0xFFFD: 0x2A15,
	0xFFFD: 0x2A16,
	0xFFFD: 0x2A17,
	0xFFFD: 0x2A18,
	0xFFFD: 0x2A19,
	0xFFFD: 0x2A1A,
	0xFFFD: 0x2A1B,
	0xFFFD: 0x2A1C,
	0xFFFD: 0x2A1D,
	0xFFFD: 0x2A1E,
	0xFFFD: 0x2A1F,
	0xFFFD: 0x2A20,
	0xFFFD: 0x2A21,
	0xFFFD: 0x2A22,
	0xFFFD: 0x2A23,
	0xFFFD: 0x2A24,
	0xFFFD: 0x2A25,
	0xFFFD: 0x2A26,
	0xFFFD: 0x2A27,
	0xFFFD: 0x2A28,
	0xFFFD: 0x2A29,
	0xFFFD: 0x2A2A,
	0xFFFD: 0x2A2B,
	0xFFFD: 0x2A2C,
	0xFFFD: 0x2A2D,
	0xFFFD: 0x2A2E,
	0xFFFD: 0x2A2F,
	0xFFFD: 0x2A30,
	0xFFFD: 0x2A31,
	0xFFFD: 0x2A32,
	0xFFFD: 0x2A33,
	0xFFFD: 0x2A34,
	0xFFFD: 0x2A35,
	0xFFFD: 0x2A36,
	0xFFFD: 0x2A37,
	0xFFFD: 0x2A38,
	0xFFFD: 0x2A39,
	0xFFFD: 0x2A3A,
	0xFFFD: 0x2A3B,
	0xFFFD: 0x2A3C,
	0xFFFD: 0x2A3D,
	0xFFFD: 0x2A3E,
	0xFFFD: 0x2A3F,
	0xFFFD: 0x2A40,
	0xFFFD: 0x2A41,
	0xFFFD: 0x2A42,
	0xFFFD: 0x2A43,
	0xFFFD: 0x2A44,
	0xFFFD: 0x2A45,
	0xFFFD: 0x2A46,
	0xFFFD: 0x2A47,
	0xFFFD: 0x2A48,
	0xFFFD: 0x2A49,
	0xFFFD: 0x2A4A,
	0xFFFD: 0x2A4B,
	0xFFFD: 0x2A4C,
	0xFFFD: 0x2A4D,
	0xFFFD: 0x2A4E,
	0xFFFD: 0x2A4F,
	0xFFFD: 0x2A50,
	0xFFFD: 0x2A51,
	0xFFFD: 0x2A52,
	0xFFFD: 0x2A53,
	0xFFFD: 0x2A54,
	0xFFFD: 0x2A55,
	0xFFFD: 0x2A56,
	0xFFFD: 0x2A57,
	0xFFFD: 0x2A58,
	0xFFFD: 0x2A59,
	0xFFFD: 0x2A5A,
	0xFFFD: 0x2A5B,
	0xFFFD: 0x2A5C,
	0xFFFD: 0x2A5D,
	0xFFFD: 0x2A5E,
	0xFFFD: 0x2A5F,
	0xFFFD: 0x2A60,
	0xFFFD: 0x2A61,
	0xFFFD: 0x2A62,
	0xFFFD: 0x2A63,
	0xFFFD: 0x2A64,
	0xFFFD: 0x2A65,
	0xFFFD: 0x2A66,
	0xFFFD: 0x2A67,
	0xFFFD: 0x2A68,
	0xFFFD: 0x2A69,
	0xFFFD: 0x2A6A,
	0xFFFD: 0x2A6B,
	0xFFFD: 0x2A6C,
	0xFFFD: 0x2A6D,
	0xFFFD: 0x2A6E,
	0xFFFD: 0x2A6F,
	0xFFFD: 0x2A70,
	0xFFFD: 0x2A71,
	0xFFFD: 0x2A72,
	0xFFFD: 0x2A73,
	0xFFFD: 0x2A74,
	0xFFFD: 0x2A75,
	0xFFFD: 0x2A76,
	0xFFFD: 0x2A77,
	0xFFFD: 0x2A78,
	0xFFFD: 0x2A79,
	0xFFFD: 0x2A7A,
	0xFFFD: 0x2A7B,
	0xFFFD: 0x2A7C,
	0xFFFD: 0x2A7D,
	0xFFFD: 0x2A7E,
	0xFFFD: 0x2A7F,
	0xFFFD: 0x2A80,
	0xFFFD: 0x2A81,
	0xFFFD: 0x2A82,
	0xFFFD: 0x2A83,
	0xFFFD: 0x2A84,
	0xFFFD: 0x2A85,
	0xFFFD: 0x2A86,
	0xFFFD: 0x2A87,
	0xFFFD: 0x2A88,
	0xFFFD: 0x2A89,
	0xFFFD: 0x2A8A,
	0xFFFD: 0x2A8B,
	0xFFFD: 0x2A8C,
	0xFFFD: 0x2A8D,
	0xFFFD: 0x2A8E,
	0xFFFD: 0x2A8F,
	0xFFFD: 0x2A90,
	0xFFFD: 0x2A91,
	0xFFFD: 0x2A92,
	0xFFFD: 0x2A93,
	0xFFFD: 0x2A94,
	0xFFFD: 0x2A95,
	0xFFFD: 0x2A96,
	0xFFFD: 0x2A97,
	0xFFFD: 0x2A98,
	0xFFFD: 0x2A99,
	0xFFFD: 0x2A9A,
	0xFFFD: 0x2A9B,
	0xFFFD: 0x2A9C,
	0xFFFD: 0x2A9D,
	0xFFFD: 0x2A9E,
	0xFFFD: 0x2A9F,
	0xFFFD: 0x2AA0,
	0xFFFD: 0x2AA1,
	0xFFFD: 0x2AA2,
	0xFFFD: 0x2AA3,
	0xFFFD: 0x2AA4,
	0xFFFD: 0x2AA5,
	0xFFFD: 0x2AA6,
	0xFFFD: 0x2AA7,
	0xFFFD: 0x2AA8,
	0xFFFD: 0x2AA9,
	0xFFFD: 0x2AAA,
	0xFFFD: 0x2AAB,
	0xFFFD: 0x2AAC,
	0xFFFD: 0x2AAD,
	0xFFFD: 0x2AAE,
	0xFFFD: 0x2AAF,
	0xFFFD: 0x2AB0,
	0xFFFD: 0x2AB1,
	0xFFFD: 0x2AB2,
	0xFFFD: 0x2AB3,
	0xFFFD: 0x2AB4,
	0xFFFD: 0x2AB5,
	0xFFFD: 0x2AB6,
	0xFFFD: 0x2AB7,
	0xFFFD: 0x2AB8,
	0xFFFD: 0x2AB9,
	0xFFFD: 0x2ABA,
	0xFFFD: 0x2ABB,
	0xFFFD: 0x2ABC,
	0xFFFD: 0x2ABD,
	0xFFFD: 0x2ABE,
	0xFFFD: 0x2ABF,
	0xFFFD: 0x2AC0,
	0xFFFD: 0x2AC1,
	0xFFFD: 0x2AC2,
	0xFFFD: 0x2AC3,
	0xFFFD: 0x2AC4,
	0xFFFD: 0x2AC5,
	0xFFFD: 0x2AC6,
	0xFFFD: 0x2AC7,
	0xFFFD: 0x2AC8,
	0xFFFD: 0x2AC9,
	0xFFFD: 0x2ACA,
	0xFFFD: 0x2ACB,
	0xFFFD: 0x2ACC,
	0xFFFD: 0x2ACD,
	0xFFFD: 0x2ACE,
	0xFFFD: 0x2ACF,
	0xFFFD: 0x2AD0,
	0xFFFD: 0x2AD1,
	0xFFFD: 0x2AD2,
	0xFFFD: 0x2AD3,
	0xFFFD: 0x2AD4,
	0xFFFD: 0x2AD5,
	0xFFFD: 0x2AD6,
	0xFFFD: 0x2AD7,
	0xFFFD: 0x2AD8,
	0xFFFD: 0x2AD9,
	0xFFFD: 0x2ADA,
	0xFFFD: 0x2ADB,
	0xFFFD: 0x2ADC,
	0xFFFD: 0x2ADD,
	0xFFFD: 0x2ADE,
	0xFFFD: 0x2ADF,
	0xFFFD: 0x2AE0,
	0xFFFD: 0x2AE1,
	0xFFFD: 0x2AE2,
	0xFFFD: 0x2AE3,
	0xFFFD: 0x2AE4,
	0xFFFD: 0x2AE5,
	0xFFFD: 0x2AE6,
	0xFFFD: 0x2AE7,
	0xFFFD: 0x2AE8,
	0xFFFD: 0x2AE9,
	0xFFFD: 0x2AEA,
	0xFFFD: 0x2AEB,
	0xFFFD: 0x2AEC,
	0xFFFD: 0x2AED,
	0xFFFD: 0x2AEE,
	0xFFFD: 0x2AEF,
	0xFFFD: 0x2AF0,
	0xFFFD: 0x2AF1,
	0xFFFD: 0x2AF2,
	0xFFFD: 0x2AF3,
	0xFFFD: 0x2AF4,
	0xFFFD: 0x2AF5,
	0xFFFD: 0x2AF6,
	0xFFFD: 0x2AF7,
	0xFFFD: 0x2AF8,
	0xFFFD: 0x2AF9,
	0xFFFD: 0x2AFA,
	0xFFFD: 0x2AFB,
	0xFFFD: 0x2AFC,
	0xFFFD: 0x2AFD,
	0xFFFD: 0x2AFE,
	0xFFFD: 0x2AFF,
	0xFFFD: 0x2B00,
	0xFFFD: 0x2B01,
	0xFFFD: 0x2B02,
	0xFFFD: 0x2B03,
	0xFFFD: 0x2B04,
	0xFFFD: 0x2B05,
	0xFFFD: 0x2B06,
	0xFFFD: 0x2B07,
	0xFFFD: 0x2B08,
	0xFFFD: 0x2B09,
	0xFFFD: 0x2B0A,
	0xFFFD: 0x2B0B,
	0xFFFD: 0x2B0C,
	0xFFFD: 0x2B0D,
	0xFFFD: 0x2B0E,
	0xFFFD: 0x2B0F,
	0xFFFD: 0x2B10,
	0xFFFD: 0x2B11,
	0xFFFD: 0x2B12,
	0xFFFD: 0x2B13,
	0xFFFD: 0x2B14,
	0xFFFD: 0x2B15,
	0xFFFD: 0x2B16,
	0xFFFD: 0x2B17,
	0xFFFD: 0x2B18,
	0xFFFD: 0x2B19,
	0xFFFD: 0x2B1A,
	0xFFFD: 0x2B1B,
	0xFFFD: 0x2B1C,
	0xFFFD: 0x2B1D,
	0xFFFD: 0x2B1E,
	0xFFFD: 0x2B1F,
	0xFFFD: 0x2B20,
	0xFFFD: 0x2B21,
	0xFFFD: 0x2B22,
	0xFFFD: 0x2B23,
	0xFFFD: 0x2B24,
	0xFFFD: 0x2B25,
	0xFFFD: 0x2B26,
	0xFFFD: 0x2B27,
	0xFFFD: 0x2B28,
	0xFFFD: 0x2B29,
	0xFFFD: 0x2B2A,
	0xFFFD: 0x2B2B,
	0xFFFD: 0x2B2C,
	0xFFFD: 0x2B2D,
	0xFFFD: 0x2B2E,
	0xFFFD: 0x2B2F,
	0xFFFD: 0x2B30,
	0xFFFD: 0x2B31,
	0xFFFD: 0x2B32,
	0xFFFD: 0x2B33,
	0xFFFD: 0x2B34,
	0xFFFD: 0x2B35,
	0xFFFD: 0x2B36,
	0xFFFD: 0x2B37,
	0xFFFD: 0x2B38,
	0xFFFD: 0x2B39,
	0xFFFD: 0x2B3A,
	0xFFFD: 0x2B3B,
	0xFFFD: 0x2B3C,
	0xFFFD: 0x2B3D,
	0xFFFD: 0x2B3E,
	0xFFFD: 0x2B3F,
	0xFFFD: 0x2B40,
	0xFFFD: 0x2B41,
	0xFFFD: 0x2B42,
	0xFFFD: 0x2B43,
	0xFFFD: 0x2B44,
	0xFFFD: 0x2B45,
	0xFFFD: 0x2B46,
	0xFFFD: 0x2B47,
	0xFFFD: 0x2B48,
	0xFFFD: 0x2B49,
	0xFFFD: 0x2B4A,
	0xFFFD: 0x2B4B,
	0xFFFD: 0x2B4C,
	0xFFFD: 0x2B4D,
	0xFFFD: 0x2B4E,
	0xFFFD: 0x2B4F,
	0xFFFD: 0x2B50,
	0xFFFD: 0x2B51,
	0xFFFD: 0x2B52,
	0xFFFD: 0x2B53,
	0xFFFD: 0x2B54,
	0xFFFD: 0x2B55,
	0xFFFD: 0x2B56,
	0xFFFD: 0x2B57,
	0xFFFD: 0x2B58,
	0xFFFD: 0x2B59,
	0xFFFD: 0x2B5A,
	0xFFFD: 0x2B5B,
	0xFFFD: 0x2B5C,
	0xFFFD: 0x2B5D,
	0xFFFD: 0x2B5E,
	0xFFFD: 0x2B5F,
	0xFFFD: 0x2B60,
	0xFFFD: 0x2B61,
	0xFFFD: 0x2B62,
	0xFFFD: 0x2B63,
	0xFFFD: 0x2B64,
	0xFFFD: 0x2B65,
	0xFFFD: 0x2B66,
	0xFFFD: 0x2B67,
	0xFFFD: 0x2B68,
	0xFFFD: 0x2B69,
	0xFFFD: 0x2B6A,
	0xFFFD: 0x2B6B,
	0xFFFD: 0x2B6C,
	0xFFFD: 0x2B6D,
	0xFFFD: 0x2B6E,
	0xFFFD: 0x2B6F,
	0xFFFD: 0x2B70,
	0xFFFD: 0x2B71,
	0xFFFD: 0x2B72,
	0xFFFD: 0x2B73,
	0xFFFD: 0x2B74,
	0xFFFD: 0x2B75,
	0xFFFD: 0x2B76,
	0xFFFD: 0x2B77,
	0xFFFD: 0x2B78,
	0xFFFD: 0x2B79,
	0xFFFD: 0x2B7A,
	0xFFFD: 0x2B7B,
	0xFFFD: 0x2B7C,
	0xFFFD: 0x2B7D,
	0xFFFD: 0x2B7E,
	0xFFFD: 0x2B7F,
	0xFFFD: 0x2B80,
	0xFFFD: 0x2B81,
	0xFFFD: 0x2B82,
	0xFFFD: 0x2B83,
	0xFFFD: 0x2B84,
	0xFFFD: 0x2B85,
	0xFFFD: 0x2B86,
	0xFFFD: 0x2B87,
	0xFFFD: 0x2B88,
	0xFFFD: 0x2B89,
	0xFFFD: 0x2B8A,
	0xFFFD: 0x2B8B,
	0xFFFD: 0x2B8C,
	0xFFFD: 0x2B8D,
	0xFFFD: 0x2B8E,
	0xFFFD: 0x2B8F,
	0xFFFD: 0x2B90,
	0xFFFD: 0x2B91,
	0xFFFD: 0x2B92,
	0xFFFD: 0x2B93,
	0xFFFD: 0x2B94,
	0xFFFD: 0x2B95,
	0xFFFD: 0x2B96,
	0xFFFD: 0x2B97,
	0xFFFD: 0x2B98,
	0xFFFD: 0x2B99,
	0xFFFD: 0x2B9A,
	0xFFFD: 0x2B9B,
	0xFFFD: 0x2B9C,
	0xFFFD: 0x2B9D,
	0xFFFD: 0x2B9E,
	0xFFFD: 0x2B9F,
	0xFFFD: 0x2BA0,
	0xFFFD: 0x2BA1,
	0xFFFD: 0x2BA2,
	0xFFFD: 0x2BA3,
	0xFFFD: 0x2BA4,
	0xFFFD: 0x2BA5,
	0xFFFD: 0x2BA6,
	0xFFFD: 0x2BA7,
	0xFFFD: 0x2BA8,
	0xFFFD: 0x2BA9,
	0xFFFD: 0x2BAA,
	0xFFFD: 0x2BAB,
	0xFFFD: 0x2BAC,
	0xFFFD: 0x2BAD,
	0xFFFD: 0x2BAE,
	0xFFFD: 0x2BAF,
	0xFFFD: 0x2BB0,
	0xFFFD: 0x2BB1,
	0xFFFD: 0x2BB2,
	0xFFFD: 0x2BB3,
	0xFFFD: 0x2BB4,
	0xFFFD: 0x2BB5,
	0xFFFD: 0x2BB6,
	0xFFFD: 0x2BB7,
	0xFFFD: 0x2BB8,
	0xFFFD: 0x2BB9,
	0xFFFD: 0x2BBA,
	0xFFFD: 0x2BBB,
	0xFFFD: 0x2BBC,
	0xFFFD: 0x2BBD,
	0xFFFD: 0x2BBE,
	0xFFFD: 0x2BBF,
	0xFFFD: 0x2BC0,
	0xFFFD: 0x2BC1,
	0xFFFD: 0x2BC2,
	0xFFFD: 0x2BC3,
	0xFFFD: 0x2BC4,
	0xFFFD: 0x2BC5,
	0xFFFD: 0x2BC6,
	0xFFFD: 0x2BC7,
	0xFFFD: 0x2BC8,
	0xFFFD: 0x2BC9,
	0xFFFD: 0x2BCA,
	0xFFFD: 0x2BCB,
	0xFFFD: 0x2BCC,
	0xFFFD: 0x2BCD,
	0xFFFD: 0x2BCE,
	0xFFFD: 0x2BCF,
	0xFFFD: 0x2BD0,
	0xFFFD: 0x2BD1,
	0xFFFD: 0x2BD2,
	0xFFFD: 0x2BD3,
	0xFFFD: 0x2BD4,
	0xFFFD: 0x2BD5,
	0xFFFD: 0x2BD6,
	0xFFFD: 0x2BD7,
	0xFFFD: 0x2BD8,
	0xFFFD: 0x2BD9,
	0xFFFD: 0x2BDA,
	0xFFFD: 0x2BDB,
	0xFFFD: 0x2BDC,
	0xFFFD: 0x2BDD,
	0xFFFD: 0x2BDE,
	0xFFFD: 0x2BDF,
	0xFFFD: 0x2BE0,
	0xFFFD: 0x2BE1,
	0xFFFD: 0x2BE2,
	0xFFFD: 0x2BE3,
	0xFFFD: 0x2BE4,
	0xFFFD: 0x2BE5,
	0xFFFD: 0x2BE6,
	0xFFFD: 0x2BE7,
	0xFFFD: 0x2BE8,
	0xFFFD: 0x2BE9,
	0xFFFD: 0x2BEA,
	0xFFFD: 0x2BEB,
	0xFFFD: 0x2BEC,
	0xFFFD: 0x2BED,
	0xFFFD: 0x2BEE,
	0xFFFD: 0x2BEF,
	0xFFFD: 0x2BF0,
	0xFFFD: 0x2BF1,
	0xFFFD: 0x2BF2,
	0xFFFD: 0x2BF3,
	0xFFFD: 0x2BF4,
	0xFFFD: 0x2BF5,
	0xFFFD: 0x2BF6,
	0xFFFD: 0x2BF7,
	0xFFFD: 0x2BF8,
	0xFFFD: 0x2BF9,
	0xFFFD: 0x2BFA,
	0xFFFD: 0x2BFB,
	0xFFFD: 0x2BFC,
	0xFFFD: 0x2BFD,
	0xFFFD: 0x2BFE,
	0xFFFD: 0x2BFF,
	0xFFFD: 0x2C00,
	0xFFFD: 0x2C01,
	0xFFFD: 0x2C02,
	0xFFFD: 0x2C03,
	0xFFFD: 0x2C04,
	0xFFFD: 0x2C05,
	0xFFFD: 0x2C06,
	0xFFFD: 0x2C07,
	0xFFFD: 0x2C08,
	0xFFFD: 0x2C09,
	0xFFFD: 0x2C0A,
	0xFFFD: 0x2C0B,
	0xFFFD: 0x2C0C,
	0xFFFD: 0x2C0D,
	0xFFFD: 0x2C0E,
	0xFFFD: 0x2C0F,
	0xFFFD: 0x2C10,
	0xFFFD: 0x2C11,
	0xFFFD: 0x2C12,
	0xFFFD: 0x2C13,
	0xFFFD: 0x2C14,
	0xFFFD: 0x2C15,
	0xFFFD: 0x2C16,
	0xFFFD: 0x2C17,
	0xFFFD: 0x2C18,
	0xFFFD: 0x2C19,
	0xFFFD: 0x2C1A,
	0xFFFD: 0x2C1B,
	0xFFFD: 0x2C1C,
	0xFFFD: 0x2C1D,
	0xFFFD: 0x2C1E,
	0xFFFD: 0x2C1F,
	0xFFFD: 0x2C20,
	0xFFFD: 0x2C21,
	0xFFFD: 0x2C22,
	0xFFFD: 0x2C23,
	0xFFFD: 0x2C24,
	0xFFFD: 0x2C25,
	0xFFFD: 0x2C26,
	0xFFFD: 0x2C27,
	0xFFFD: 0x2C28,
	0xFFFD: 0x2C29,
	0xFFFD: 0x2C2A,
	0xFFFD: 0x2C2B,
	0xFFFD: 0x2C2C,
	0xFFFD: 0x2C2D,
	0xFFFD: 0x2C2E,
	0xFFFD: 0x2C2F,
	0xFFFD: 0x2C30,
	0xFFFD: 0x2C31,
	0xFFFD: 0x2C32,
	0xFFFD: 0x2C33,
	0xFFFD: 0x2C34,
	0xFFFD: 0x2C35,
	0xFFFD: 0x2C36,
	0xFFFD: 0x2C37,
	0xFFFD: 0x2C38,
	0xFFFD: 0x2C39,
	0xFFFD: 0x2C3A,
	0xFFFD: 0x2C3B,
	0xFFFD: 0x2C3C,
	0xFFFD: 0x2C3D,
	0xFFFD: 0x2C3E,
	0xFFFD: 0x2C3F,
	0xFFFD: 0x2C40,
	0xFFFD: 0x2C41,
	0xFFFD: 0x2C42,
	0xFFFD: 0x2C43,
	0xFFFD: 0x2C44,
	0xFFFD: 0x2C45,
	0xFFFD: 0x2C46,
	0xFFFD: 0x2C47,
	0xFFFD: 0x2C48,
	0xFFFD: 0x2C49,
	0xFFFD: 0x2C4A,
	0xFFFD: 0x2C4B,
	0xFFFD: 0x2C4C,
	0xFFFD: 0x2C4D,
	0xFFFD: 0x2C4E,
	0xFFFD: 0x2C4F,
	0xFFFD: 0x2C50,
	0xFFFD: 0x2C51,
	0xFFFD: 0x2C52,
	0xFFFD: 0x2C53,
	0xFFFD: 0x2C54,
	0xFFFD: 0x2C55,
	0xFFFD: 0x2C56,
	0xFFFD: 0x2C57,
	0xFFFD: 0x2C58,
	0xFFFD: 0x2C59,
	0xFFFD: 0x2C5A,
	0xFFFD: 0x2C5B,
	0xFFFD: 0x2C5C,
	0xFFFD: 0x2C5D,
	0xFFFD: 0x2C5E,
	0xFFFD: 0x2C5F,
	0xFFFD: 0x2C60,
	0xFFFD: 0x2C61,
	0xFFFD: 0x2C62,
	0xFFFD: 0x2C63,
	0xFFFD: 0x2C64,
	0xFFFD: 0x2C65,
	0xFFFD: 0x2C66,
	0xFFFD: 0x2C67,
	0xFFFD: 0x2C68,
	0xFFFD: 0x2C69,
	0xFFFD: 0x2C6A,
	0xFFFD: 0x2C6B,
	0xFFFD: 0x2C6C,
	0xFFFD: 0x2C6D,
	0xFFFD: 0x2C6E,
	0xFFFD: 0x2C6F,
	0xFFFD: 0x2C70,
	0xFFFD: 0x2C71,
	0xFFFD: 0x2C72,
	0xFFFD: 0x2C73,
	0xFFFD: 0x2C74,
	0xFFFD: 0x2C75,
	0xFFFD: 0x2C76,
	0xFFFD: 0x2C77,
	0xFFFD: 0x2C78,
	0xFFFD: 0x2C79,
	0xFFFD: 0x2C7A,
	0xFFFD: 0x2C7B,
	0xFFFD: 0x2C7C,
	0xFFFD: 0x2C7D,
	0xFFFD: 0x2C7E,
	0xFFFD: 0x2C7F,
	0xFFFD: 0x2C80,
	0xFFFD: 0x2C81,
	0xFFFD: 0x2C82,
	0xFFFD: 0x2C83,
	0xFFFD: 0x2C84,
	0xFFFD: 0x2C85,
	0xFFFD: 0x2C86,
	0xFFFD: 0x2C87,
	0xFFFD: 0x2C88,
	0xFFFD: 0x2C89,
	0xFFFD: 0x2C8A,
	0xFFFD: 0x2C8B,
	0xFFFD: 0x2C8C,
	0xFFFD: 0x2C8D,
	0xFFFD: 0x2C8E,
	0xFFFD: 0x2C8F,
	0xFFFD: 0x2C90,
	0xFFFD: 0x2C91,
	0xFFFD: 0x2C92,
	0xFFFD: 0x2C93,
	0xFFFD: 0x2C94,
	0xFFFD: 0x2C95,
	0xFFFD: 0x2C96,
	0xFFFD: 0x2C97,
	0xFFFD: 0x2C98,
	0xFFFD: 0x2C99,
	0xFFFD: 0x2C9A,
	0xFFFD: 0x2C9B,
	0xFFFD: 0x2C9C,
	0xFFFD: 0x2C9D,
	0xFFFD: 0x2C9E,
	0xFFFD: 0x2C9F,
	0xFFFD: 0x2CA0,
	0xFFFD: 0x2CA1,
	0xFFFD: 0x2CA2,
	0xFFFD: 0x2CA3,
	0xFFFD: 0x2CA4,
	0xFFFD: 0x2CA5,
	0xFFFD: 0x2CA6,
	0xFFFD: 0x2CA7,
	0xFFFD: 0x2CA8,
	0xFFFD: 0x2CA9,
	0xFFFD: 0x2CAA,
	0xFFFD: 0x2CAB,
	0xFFFD: 0x2CAC,
	0xFFFD: 0x2CAD,
	0xFFFD: 0x2CAE,
	0xFFFD: 0x2CAF,
	0xFFFD: 0x2CB0,
	0xFFFD: 0x2CB1,
	0xFFFD: 0x2CB2,
	0xFFFD: 0x2CB3,
	0xFFFD: 0x2CB4,
	0xFFFD: 0x2CB5,
	0xFFFD: 0x2CB6,
	0xFFFD: 0x2CB7,
	0xFFFD: 0x2CB8,
	0xFFFD: 0x2CB9,
	0xFFFD: 0x2CBA,
	0xFFFD: 0x2CBB,
	0xFFFD: 0x2CBC,
	0xFFFD: 0x2CBD,
	0xFFFD: 0x2CBE,
	0xFFFD: 0x2CBF,
	0xFFFD: 0x2CC0,
	0xFFFD: 0x2CC1,
	0xFFFD: 0x2CC2,
	0xFFFD: 0x2CC3,
	0xFFFD: 0x2CC4,
	0xFFFD: 0x2CC5,
	0xFFFD: 0x2CC6,
	0xFFFD: 0x2CC7,
	0xFFFD: 0x2CC8,
	0xFFFD: 0x2CC9,
	0xFFFD: 0x2CCA,
	0xFFFD: 0x2CCB,
	0xFFFD: 0x2CCC,
	0xFFFD: 0x2CCD,
	0xFFFD: 0x2CCE,
	0xFFFD: 0x2CCF,
	0xFFFD: 0x2CD0,
	0xFFFD: 0x2CD1,
	0xFFFD: 0x2CD2,
	0xFFFD: 0x2CD3,
	0xFFFD: 0x2CD4,
	0xFFFD: 0x2CD5,
	0xFFFD: 0x2CD6,
	0xFFFD: 0x2CD7,
	0xFFFD: 0x2CD8,
	0xFFFD: 0x2CD9,
	0xFFFD: 0x2CDA,
	0xFFFD: 0x2CDB,
	0xFFFD: 0x2CDC,
	0xFFFD: 0x2CDD,
	0xFFFD: 0x2CDE,
	0xFFFD: 0x2CDF,
	0xFFFD: 0x2CE0,
	0xFFFD: 0x2CE1,
	0xFFFD: 0x2CE2,
	0xFFFD: 0x2CE3,
	0xFFFD: 0x2CE4,
	0xFFFD: 0x2CE5,
	0xFFFD: 0x2CE6,
	0xFFFD: 0x2CE7,
	0xFFFD: 0x2CE8,
	0xFFFD: 0x2CE9,
	0xFFFD: 0x2CEA,
	0xFFFD: 0x2CEB,
	0xFFFD: 0x2CEC,
	0xFFFD: 0x2CED,
	0xFFFD: 0x2CEE,
	0xFFFD: 0x2CEF,
	0xFFFD: 0x2CF0,
	0xFFFD: 0x2CF1,
	0xFFFD: 0x2CF2,
	0xFFFD: 0x2CF3,
	0xFFFD: 0x2CF4,
	0xFFFD: 0x2CF5,
	0xFFFD: 0x2CF6,
	0xFFFD: 0x2CF7,
	0xFFFD: 0x2CF8,
	0xFFFD: 0x2CF9,
	0xFFFD: 0x2CFA,
	0xFFFD: 0x2CFB,
	0xFFFD: 0x2CFC,
	0xFFFD: 0x2CFD,
	0xFFFD: 0x2CFE,
	0xFFFD: 0x2CFF,
	0xFFFD: 0x2D00,
	0xFFFD: 0x2D01,
	0xFFFD: 0x2D02,
	0xFFFD: 0x2D03,
	0xFFFD: 0x2D04,
	0xFFFD: 0x2D05,
	0xFFFD: 0x2D06,
	0xFFFD: 0x2D07,
	0xFFFD: 0x2D08,
	0xFFFD: 0x2D09,
	0xFFFD: 0x2D0A,
	0xFFFD: 0x2D0B,
	0xFFFD: 0x2D0C,
	0xFFFD: 0x2D0D,
	0xFFFD: 0x2D0E,
	0xFFFD: 0x2D0F,
	0xFFFD: 0x2D10,
	0xFFFD: 0x2D11,
	0xFFFD: 0x2D12,
	0xFFFD: 0x2D13,
	0xFFFD: 0x2D14,
	0xFFFD: 0x2D15,
	0xFFFD: 0x2D16,
	0xFFFD: 0x2D17,
	0xFFFD: 0x2D18,
	0xFFFD: 0x2D19,
	0xFFFD: 0x2D1A,
	0xFFFD: 0x2D1B,
	0xFFFD: 0x2D1C,
	0xFFFD: 0x2D1D,
	0xFFFD: 0x2D1E,
	0xFFFD: 0x2D1F,
	0xFFFD: 0x2D20,
	0xFFFD: 0x2D21,
	0xFFFD: 0x2D22,
	0xFFFD: 0x2D23,
	0xFFFD: 0x2D24,
	0xFFFD: 0x2D25,
	0xFFFD: 0x2D26,
	0xFFFD: 0x2D27,
	0xFFFD: 0x2D28,
	0xFFFD: 0x2D29,
	0xFFFD: 0x2D2A,
	0xFFFD: 0x2D2B,
	0xFFFD: 0x2D2C,
	0xFFFD: 0x2D2D,
	0xFFFD: 0x2D2E,
	0xFFFD: 0x2D2F,
	0xFFFD: 0x2D30,
	0xFFFD: 0x2D31,
	0xFFFD: 0x2D32,
	0xFFFD: 0x2D33,
	0xFFFD: 0x2D34,
	0xFFFD: 0x2D35,
	0xFFFD: 0x2D36,
	0xFFFD: 0x2D37,
	0xFFFD: 0x2D38,
	0xFFFD: 0x2D39,
	0xFFFD: 0x2D3A,
	0xFFFD: 0x2D3B,
	0xFFFD: 0x2D3C,
	0xFFFD: 0x2D3D,
	0xFFFD: 0x2D3E,
	0xFFFD: 0x2D3F,
	0xFFFD: 0x2D40,
	0xFFFD: 0x2D41,
	0xFFFD: 0x2D42,
	0xFFFD: 0x2D43,
	0xFFFD: 0x2D44,
	0xFFFD: 0x2D45,
	0xFFFD: 0x2D46,
	0xFFFD: 0x2D47,
	0xFFFD: 0x2D48,
	0xFFFD: 0x2D49,
	0xFFFD: 0x2D4A,
	0xFFFD: 0x2D4B,
	0xFFFD: 0x2D4C,
	0xFFFD: 0x2D4D,
	0xFFFD: 0x2D4E,
	0xFFFD: 0x2D4F,
	0xFFFD: 0x2D50,
	0xFFFD: 0x2D51,
	0xFFFD: 0x2D52,
	0xFFFD: 0x2D53,
	0xFFFD: 0x2D54,
	0xFFFD: 0x2D55,
	0xFFFD: 0x2D56,
	0xFFFD: 0x2D57,
	0xFFFD: 0x2D58,
	0xFFFD: 0x2D59,
	0xFFFD: 0x2D5A,
	0xFFFD: 0x2D5B,
	0xFFFD: 0x2D5C,
	0xFFFD: 0x2D5D,
	0xFFFD: 0x2D5E,
	0xFFFD: 0x2D5F,
	0xFFFD: 0x2D60,
	0xFFFD: 0x2D61,
	0xFFFD: 0x2D62,
	0xFFFD: 0x2D63,
	0xFFFD: 0x2D64,
	0xFFFD: 0x2D65,
	0xFFFD: 0x2D66,
	0xFFFD: 0x2D67,
	0xFFFD: 0x2D68,
	0xFFFD: 0x2D69,
	0xFFFD: 0x2D6A,
	0xFFFD: 0x2D6B,
	0xFFFD: 0x2D6C,
	0xFFFD: 0x2D6D,
	0xFFFD: 0x2D6E,
	0xFFFD: 0x2D6F,
	0xFFFD: 0x2D70,
	0xFFFD: 0x2D71,
	0xFFFD: 0x2D72,
	0xFFFD: 0x2D73,
	0xFFFD: 0x2D74,
	0xFFFD: 0x2D75,
	0xFFFD: 0x2D76,
	0xFFFD: 0x2D77,
	0xFFFD: 0x2D78,
	0xFFFD: 0x2D79,
	0xFFFD: 0x2D7A,
	0xFFFD: 0x2D7B,
	0xFFFD: 0x2D7C,
	0xFFFD: 0x2D7D,
	0xFFFD: 0x2D7E,
	0xFFFD: 0x2D7F,
	0xFFFD: 0x2D80,
	0xFFFD: 0x2D81,
	0xFFFD: 0x2D82,
	0xFFFD: 0x2D83,
	0xFFFD: 0x2D84,
	0xFFFD: 0x2D85,
	0xFFFD: 0x2D86,
	0xFFFD: 0x2D87,
	0xFFFD: 0x2D88,
	0xFFFD: 0x2D89,
	0xFFFD: 0x2D8A,
	0xFFFD: 0x2D8B,
	0xFFFD: 0x2D8C,
	0xFFFD: 0x2D8D,
	0xFFFD: 0x2D8E,
	0xFFFD: 0x2D8F,
	0xFFFD: 0x2D90,
	0xFFFD: 0x2D91,
	0xFFFD: 0x2D92,
	0xFFFD: 0x2D93,
	0xFFFD: 0x2D94,
	0xFFFD: 0x2D95,
	0xFFFD: 0x2D96,
	0xFFFD: 0x2D97,
	0xFFFD: 0x2D98,
	0xFFFD: 0x2D99,
	0xFFFD: 0x2D9A,
	0xFFFD: 0x2D9B,
	0xFFFD: 0x2D9C,
	0xFFFD: 0x2D9D,
	0xFFFD: 0x2D9E,
	0xFFFD: 0x2D9F,
	0xFFFD: 0x2DA0,
	0xFFFD: 0x2DA1,
	0xFFFD: 0x2DA2,
	0xFFFD: 0x2DA3,
	0xFFFD: 0x2DA4,
	0xFFFD: 0x2DA5,
	0xFFFD: 0x2DA6,
	0xFFFD: 0x2DA7,
	0xFFFD: 0x2DA8,
	0xFFFD: 0x2DA9,
	0xFFFD: 0x2DAA,
	0xFFFD: 0x2DAB,
	0xFFFD: 0x2DAC,
	0xFFFD: 0x2DAD,
	0xFFFD: 0x2DAE,
	0xFFFD: 0x2DAF,
	0xFFFD: 0x2DB0,
	0xFFFD: 0x2DB1,
	0xFFFD: 0x2DB2,
	0xFFFD: 0x2DB3,
	0xFFFD: 0x2DB4,
	0xFFFD: 0x2DB5,
	0xFFFD: 0x2DB6,
	0xFFFD: 0x2DB7,
	0xFFFD: 0x2DB8,
	0xFFFD: 0x2DB9,
	0xFFFD: 0x2DBA,
	0xFFFD: 0x2DBB,
	0xFFFD: 0x2DBC,
	0xFFFD: 0x2DBD,
	0xFFFD: 0x2DBE,
	0xFFFD: 0x2DBF,
	0xFFFD: 0x2DC0,
	0xFFFD: 0x2DC1,
	0xFFFD: 0x2DC2,
	0xFFFD: 0x2DC3,
	0xFFFD: 0x2DC4,
	0xFFFD: 0x2DC5,
	0xFFFD: 0x2DC6,
	0xFFFD: 0x2DC7,
	0xFFFD: 0x2DC8,
	0xFFFD: 0x2DC9,
	0xFFFD: 0x2DCA,
	0xFFFD: 0x2DCB,
	0xFFFD: 0x2DCC,
	0xFFFD: 0x2DCD,
	0xFFFD: 0x2DCE,
	0xFFFD: 0x2DCF,
	0xFFFD: 0x2DD0,
	0xFFFD: 0x2DD1,
	0xFFFD: 0x2DD2,
	0xFFFD: 0x2DD3,
	0xFFFD: 0x2DD4,
	0xFFFD: 0x2DD5,
	0xFFFD: 0x2DD6,
	0xFFFD: 0x2DD7,
	0xFFFD: 0x2DD8,
	0xFFFD: 0x2DD9,
	0xFFFD: 0x2DDA,
	0xFFFD: 0x2DDB,
	0xFFFD: 0x2DDC,
	0xFFFD: 0x2DDD,
	0xFFFD: 0x2DDE,
	0xFFFD: 0x2DDF,
	0xFFFD: 0x2DE0,
	0xFFFD: 0x2DE1,
	0xFFFD: 0x2DE2,
	0xFFFD: 0x2DE3,
	0xFFFD: 0x2DE4,
	0xFFFD: 0x2DE5,
	0xFFFD: 0x2DE6,
	0xFFFD: 0x2DE7,
	0xFFFD: 0x2DE8,
	0xFFFD: 0x2DE9,
	0xFFFD: 0x2DEA,
	0xFFFD: 0x2DEB,
	0xFFFD: 0x2DEC,
	0xFFFD: 0x2DED,
	0xFFFD: 0x2DEE,
	0xFFFD: 0x2DEF,
	0xFFFD: 0x2DF0,
	0xFFFD: 0x2DF1,
	0xFFFD: 0x2DF2,
	0xFFFD: 0x2DF3,
	0xFFFD: 0x2DF4,
	0xFFFD: 0x2DF5,
	0xFFFD: 0x2DF6,
	0xFFFD: 0x2DF7,
	0xFFFD: 0x2DF8,
	0xFFFD: 0x2DF9,
	0xFFFD: 0x2DFA,
	0xFFFD: 0x2DFB,
	0xFFFD: 0x2DFC,
	0xFFFD: 0x2DFD,
	0xFFFD: 0x2DFE,
	0xFFFD: 0x2DFF,
	0xFFFD: 0x2E00,
	0xFFFD: 0x2E01,
	0xFFFD: 0x2E02,
	0xFFFD: 0x2E03,
	0xFFFD: 0x2E04,
	0xFFFD: 0x2E05,
	0xFFFD: 0x2E06,
	0xFFFD: 0x2E07,
	0xFFFD: 0x2E08,
	0xFFFD: 0x2E09,
	0xFFFD: 0x2E0A,
	0xFFFD: 0x2E0B,
	0xFFFD: 0x2E0C,
	0xFFFD: 0x2E0D,
	0xFFFD: 0x2E0E,
	0xFFFD: 0x2E0F,
	0xFFFD: 0x2E10,
	0xFFFD: 0x2E11,
	0xFFFD: 0x2E12,
	0xFFFD: 0x2E13,
	0xFFFD: 0x2E14,
	0xFFFD: 0x2E15,
	0xFFFD: 0x2E16,
	0xFFFD: 0x2E17,
	0xFFFD: 0x2E18,
	0xFFFD: 0x2E19,
	0xFFFD: 0x2E1A,
	0xFFFD: 0x2E1B,
	0xFFFD: 0x2E1C,
	0xFFFD: 0x2E1D,
	0xFFFD: 0x2E1E,
	0xFFFD: 0x2E1F,
	0xFFFD: 0x2E20,
	0xFFFD: 0x2E21,
	0xFFFD: 0x2E22,
	0xFFFD: 0x2E23,
	0xFFFD: 0x2E24,
	0xFFFD: 0x2E25,
	0xFFFD: 0x2E26,
	0xFFFD: 0x2E27,
	0xFFFD: 0x2E28,
	0xFFFD: 0x2E29,
	0xFFFD: 0x2E2A,
	0xFFFD: 0x2E2B,
	0xFFFD: 0x2E2C,
	0xFFFD: 0x2E2D,
	0xFFFD: 0x2E2E,
	0xFFFD: 0x2E2F,
	0xFFFD: 0x2E30,
	0xFFFD: 0x2E31,
	0xFFFD: 0x2E32,
	0xFFFD: 0x2E33,
	0xFFFD: 0x2E34,
	0xFFFD: 0x2E35,
	0xFFFD: 0x2E36,
	0xFFFD: 0x2E37,
	0xFFFD: 0x2E38,
	0xFFFD: 0x2E39,
	0xFFFD: 0x2E3A,
	0xFFFD: 0x2E3B,
	0xFFFD: 0x2E3C,
	0xFFFD: 0x2E3D,
	0xFFFD: 0x2E3E,
	0xFFFD: 0x2E3F,
	0xFFFD: 0x2E40,
	0xFFFD: 0x2E41,
	0xFFFD: 0x2E42,
	0xFFFD: 0x2E43,
	0xFFFD: 0x2E44,
	0xFFFD: 0x2E45,
	0xFFFD: 0x2E46,
	0xFFFD: 0x2E47,
	0xFFFD: 0x2E48,
	0xFFFD: 0x2E49,
	0xFFFD: 0x2E4A,
	0xFFFD: 0x2E4B,
	0xFFFD: 0x2E4C,
	0xFFFD: 0x2E4D,
	0xFFFD: 0x2E4E,
	0xFFFD: 0x2E4F,
	0xFFFD: 0x2E50,
	0xFFFD: 0x2E51,
	0xFFFD: 0x2E52,
	0xFFFD: 0x2E53,
	0xFFFD: 0x2E54,
	0xFFFD: 0x2E55,
	0xFFFD: 0x2E56,
	0xFFFD: 0x2E57,
	0xFFFD: 0x2E58,
	0xFFFD: 0x2E59,
	0xFFFD: 0x2E5A,
	0xFFFD: 0x2E5B,
	0xFFFD: 0x2E5C,
	0xFFFD: 0x2E5D,
	0xFFFD: 0x2E5E,
	0xFFFD: 0x2E5F,
	0xFFFD: 0x2E60,
	0xFFFD: 0x2E61,
	0xFFFD: 0x2E62,
	0xFFFD: 0x2E63,
	0xFFFD: 0x2E64,
	0xFFFD: 0x2E65,
	0xFFFD: 0x2E66,
	0xFFFD: 0x2E67,
	0xFFFD: 0x2E68,
	0xFFFD: 0x2E69,
	0xFFFD: 0x2E6A,
	0xFFFD: 0x2E6B,
	0xFFFD: 0x2E6C,
	0xFFFD: 0x2E6D,
	0xFFFD: 0x2E6E,
	0xFFFD: 0x2E6F,
	0xFFFD: 0x2E70,
	0xFFFD: 0x2E71,
	0xFFFD: 0x2E72,
	0xFFFD: 0x2E73,
	0xFFFD: 0x2E74,
	0xFFFD: 0x2E75,
	0xFFFD: 0x2E76,
	0xFFFD: 0x2E77,
	0xFFFD: 0x2E78,
	0xFFFD: 0x2E79,
	0xFFFD: 0x2E7A,
	0xFFFD: 0x2E7B,
	0xFFFD: 0x2E7C,
	0xFFFD: 0x2E7D,
	0xFFFD: 0x2E7E,
	0xFFFD: 0x2E7F,
	0x91ED: 0x2E80,
	0xFFFD: 0x2E81,
	0xFFFD: 0x2E82,
	0xFFFD: 0x2E83,
	0xFFFD: 0x2E84,
	0xFFFD: 0x2E85,
	0xFFFD: 0x2E86,
	0x9CCE: 0x2E87,
	0xFFFD: 0x2E88,
	0xFFFD: 0x2E89,
	0x9CD5: 0x2E8A,
	0xFFFD: 0x2E8B,
	0x9CD4: 0x2E8C,
	0xFFFD: 0x2E8D,
	0xFFFD: 0x2E8E,
	0xFFFD: 0x2E8F,
	0xFFFD: 0x2E90,
	0xFFFD: 0x2E91,
	0xFFFD: 0x2E92,
	0xFFFD: 0x2E93,
	0xFFFD: 0x2E94,
	0x9CDB: 0x2E95,
	0xFFFD: 0x2E96,
	0x91DB: 0x2E97,
	0xFFFD: 0x2E98,
	0xFFFD: 0x2E99,
	0xFFFD: 0x2E9A,
	0xFFFD: 0x2E9B,
	0xFFFD: 0x2E9C,
	0xFFFD: 0x2E9D,
	0xFFFD: 0x2E9E,
	0xFFFD: 0x2E9F,
	0xFFFD: 0x2EA0,
	0xFFFD: 0x2EA1,
	0xFFFD: 0x2EA2,
	0xFFFD: 0x2EA3,
	0x91C9: 0x2EA4,
	0xFFFD: 0x2EA5,
	0xFFFD: 0x2EA6,
	0xFFFD: 0x2EA7,
	0xFFFD: 0x2EA8,
	0xFFFD: 0x2EA9,
	0xFFFD: 0x2EAA,
	0xFFFD: 0x2EAB,
	0xFFFD: 0x2EAC,
	0xFFFD: 0x2EAD,
	0x9CF7: 0x2EAE,
	0xFFFD: 0x2EAF,
	0xFFFD: 0x2EB0,
	0xFFFD: 0x2EB1,
	0xFFFD: 0x2EB2,
	0xFFFD: 0x2EB3,
	0xFFFD: 0x2EB4,
	0xFFFD: 0x2EB5,
	0xFFFD: 0x2EB6,
	0xFFFD: 0x2EB7,
	0xFFFD: 0x2EB8,
	0xFFFD: 0x2EB9,
	0xFFFD: 0x2EBA,
	0xFFFD: 0x2EBB,
	0xFFFD: 0x2EBC,
	0xFFFD: 0x2EBD,
	0xFFFD: 0x2EBE,
	0xFFFD: 0x2EBF,
	0xFFFD: 0x2EC0,
	0xFFFD: 0x2EC1,
	0xFFFD: 0x2EC2,
	0xFFFD: 0x2EC3,
	0xFFFD: 0x2EC4,
	0xFFFD: 0x2EC5,
	0xFFFD: 0x2EC6,
	0xFFFD: 0x2EC7,
	0xFFFD: 0x2EC8,
	0xFFFD: 0x2EC9,
	0xFFFD: 0x2ECA,
	0xFFFD: 0x2ECB,
	0xFFFD: 0x2ECC,
	0xFFFD: 0x2ECD,
	0xFFFD: 0x2ECE,
	0xFFFD: 0x2ECF,
	0xFFFD: 0x2ED0,
	0xFFFD: 0x2ED1,
	0xFFFD: 0x2ED2,
	0xFFFD: 0x2ED3,
	0xFFFD: 0x2ED4,
	0xFFFD: 0x2ED5,
	0xFFFD: 0x2ED6,
	0xFFFD: 0x2ED7,
	0xFFFD: 0x2ED8,
	0xFFFD: 0x2ED9,
	0xFFFD: 0x2EDA,
	0xFFFD: 0x2EDB,
	0xFFFD: 0x2EDC,
	0xFFFD: 0x2EDD,
	0xFFFD: 0x2EDE,
	0xFFFD: 0x2EDF,
	0xFFFD: 0x2EE0,
	0xFFFD: 0x2EE1,
	0xFFFD: 0x2EE2,
	0xFFFD: 0x2EE3,
	0xFFFD: 0x2EE4,
	0xFFFD: 0x2EE5,
	0xFFFD: 0x2EE6,
	0xFFFD: 0x2EE7,
	0xFFFD: 0x2EE8,
	0xFFFD: 0x2EE9,
	0xFFFD: 0x2EEA,
	0xFFFD: 0x2EEB,
	0xFFFD: 0x2EEC,
	0xFFFD: 0x2EED,
	0xFFFD: 0x2EEE,
	0xFFFD: 0x2EEF,
	0xFFFD: 0x2EF0,
	0xFFFD: 0x2EF1,
	0xFFFD: 0x2EF2,
	0xFFFD: 0x2EF3,
	0xFFFD: 0x2EF4,
	0xFFFD: 0x2EF5,
	0xFFFD: 0x2EF6,
	0xFFFD: 0x2EF7,
	0xFFFD: 0x2EF8,
	0xFFFD: 0x2EF9,
	0xFFFD: 0x2EFA,
	0xFFFD: 0x2EFB,
	0xFFFD: 0x2EFC,
	0xFFFD: 0x2EFD,
	0xFFFD: 0x2EFE,
	0xFFFD: 0x2EFF,
	0xFFFD: 0x2F00,
	0xFFFD: 0x2F01,
	0xC6BF: 0x2F02,
	0xC6C0: 0x2F03,
	0xFFFD: 0x2F04,
	0xC6C1: 0x2F05,
	0xFFFD: 0x2F06,
	0xC6C2: 0x2F07,
	0xFFFD: 0x2F08,
	0xFFFD: 0x2F09,
	0xFFFD: 0x2F0A,
	0xFFFD: 0x2F0B,
	0xC6C3: 0x2F0C,
	0xC6C4: 0x2F0D,
	0xC6C5: 0x2F0E,
	0xFFFD: 0x2F0F,
	0xFFFD: 0x2F10,
	0xFFFD: 0x2F11,
	0xFFFD: 0x2F12,
	0xC6C6: 0x2F13,
	0xFFFD: 0x2F14,
	0xFFFD: 0x2F15,
	0xC6C7: 0x2F16,
	0xFFFD: 0x2F17,
	0xFFFD: 0x2F18,
	0xC6C8: 0x2F19,
	0xFFFD: 0x2F1A,
	0xC6C9: 0x2F1B,
	0xFFFD: 0x2F1C,
	0xFFFD: 0x2F1D,
	0xFFFD: 0x2F1E,
	0xFFFD: 0x2F1F,
	0xFFFD: 0x2F20,
	0xFFFD: 0x2F21,
	0xC6CA: 0x2F22,
	0xFFFD: 0x2F23,
	0xFFFD: 0x2F24,
	0xFFFD: 0x2F25,
	0xFFFD: 0x2F26,
	0xC6CB: 0x2F27,
	0xFFFD: 0x2F28,
	0xFFFD: 0x2F29,
	0xFFFD: 0x2F2A,
	0xFFFD: 0x2F2B,
	0xFFFD: 0x2F2C,
	0xFFFD: 0x2F2D,
	0xC6CC: 0x2F2E,
	0xFFFD: 0x2F2F,
	0xFFFD: 0x2F30,
	0xFFFD: 0x2F31,
	0xFFFD: 0x2F32,
	0xC6CD: 0x2F33,
	0xC6CE: 0x2F34,
	0xC6CF: 0x2F35,
	0xFFFD: 0x2F36,
	0xFFFD: 0x2F37,
	0xFFFD: 0x2F38,
	0xC6D0: 0x2F39,
	0xC6D1: 0x2F3A,
	0xFFFD: 0x2F3B,
	0xFFFD: 0x2F3C,
	0xFFFD: 0x2F3D,
	0xFFFD: 0x2F3E,
	0xFFFD: 0x2F3F,
	0xFFFD: 0x2F40,
	0xC6D2: 0x2F41,
	0xFFFD: 0x2F42,
	0xFFFD: 0x2F43,
	0xFFFD: 0x2F44,
	0xFFFD: 0x2F45,
	0xC6D3: 0x2F46,
	0xFFFD: 0x2F47,
	0xFFFD: 0x2F48,
	0xFFFD: 0x2F49,
	0xFFFD: 0x2F4A,
	0xFFFD: 0x2F4B,
	0xFFFD: 0x2F4C,
	0xFFFD: 0x2F4D,
	0xFFFD: 0x2F4E,
	0xFFFD: 0x2F4F,
	0xFFFD: 0x2F50,
	0xFFFD: 0x2F51,
	0xFFFD: 0x2F52,
	0xFFFD: 0x2F53,
	0xFFFD: 0x2F54,
	0xFFFD: 0x2F55,
	0xFFFD: 0x2F56,
	0xFFFD: 0x2F57,
	0xFFFD: 0x2F58,
	0xFFFD: 0x2F59,
	0xFFFD: 0x2F5A,
	0xFFFD: 0x2F5B,
	0xFFFD: 0x2F5C,
	0xFFFD: 0x2F5D,
	0xFFFD: 0x2F5E,
	0xFFFD: 0x2F5F,
	0xFFFD: 0x2F60,
	0xFFFD: 0x2F61,
	0xFFFD: 0x2F62,
	0xFFFD: 0x2F63,
	0xFFFD: 0x2F64,
	0xFFFD: 0x2F65,
	0xFFFD: 0x2F66,
	0xC6D4: 0x2F67,
	0xC6D5: 0x2F68,
	0xFFFD: 0x2F69,
	0xFFFD: 0x2F6A,
	0xFFFD: 0x2F6B,
	0xFFFD: 0x2F6C,
	0xFFFD: 0x2F6D,
	0xFFFD: 0x2F6E,
	0xFFFD: 0x2F6F,
	0xFFFD: 0x2F70,
	0xFFFD: 0x2F71,
	0xFFFD: 0x2F72,
	0xFFFD: 0x2F73,
	0xFFFD: 0x2F74,
	0xFFFD: 0x2F75,
	0xFFFD: 0x2F76,
	0xFFFD: 0x2F77,
	0xFFFD: 0x2F78,
	0xFFFD: 0x2F79,
	0xFFFD: 0x2F7A,
	0xFFFD: 0x2F7B,
	0xFFFD: 0x2F7C,
	0xFFFD: 0x2F7D,
	0xFFFD: 0x2F7E,
	0xFFFD: 0x2F7F,
	0xFFFD: 0x2F80,
	0xFFFD: 0x2F81,
	0xFFFD: 0x2F82,
	0xFFFD: 0x2F83,
	0xFFFD: 0x2F84,
	0xFFFD: 0x2F85,
	0xFFFD: 0x2F86,
	0xFFFD: 0x2F87,
	0xFFFD: 0x2F88,
	0xFFFD: 0x2F89,
	0xFFFD: 0x2F8A,
	0xFFFD: 0x2F8B,
	0xFFFD: 0x2F8C,
	0xFFFD: 0x2F8D,
	0xFFFD: 0x2F8E,
	0xFFFD: 0x2F8F,
	0xFFFD: 0x2F90,
	0xFFFD: 0x2F91,
	0xFFFD: 0x2F92,
	0xFFFD: 0x2F93,
	0xFFFD: 0x2F94,
	0xFFFD: 0x2F95,
	0xFFFD: 0x2F96,
	0xFFFD: 0x2F97,
	0xFFFD: 0x2F98,
	0xFFFD: 0x2F99,
	0xFFFD: 0x2F9A,
	0xFFFD: 0x2F9B,
	0xFFFD: 0x2F9C,
	0xFFFD: 0x2F9D,
	0xFFFD: 0x2F9E,
	0xFFFD: 0x2F9F,
	0xFFFD: 0x2FA0,
	0xC6D6: 0x2FA1,
	0xFFFD: 0x2FA2,
	0xFFFD: 0x2FA3,
	0xFFFD: 0x2FA4,
	0xFFFD: 0x2FA5,
	0xFFFD: 0x2FA6,
	0xFFFD: 0x2FA7,
	0xFFFD: 0x2FA8,
	0xFFFD: 0x2FA9,
	0xC6D7: 0x2FAA,
	0xFFFD: 0x2FAB,
	0xFFFD: 0x2FAC,
	0xFFFD: 0x2FAD,
	0xFFFD: 0x2FAE,
	0xFFFD: 0x2FAF,
	0xFFFD: 0x2FB0,
	0xFFFD: 0x2FB1,
	0xFFFD: 0x2FB2,
	0xFFFD: 0x2FB3,
	0xFFFD: 0x2FB4,
	0xFFFD: 0x2FB5,
	0xFFFD: 0x2FB6,
	0xFFFD: 0x2FB7,
	0xFFFD: 0x2FB8,
	0xFFFD: 0x2FB9,
	0xFFFD: 0x2FBA,
	0xFFFD: 0x2FBB,
	0xFFFD: 0x2FBC,
	0xFFFD: 0x2FBD,
	0xFFFD: 0x2FBE,
	0xFFFD: 0x2FBF,
	0xFFFD: 0x2FC0,
	0xFFFD: 0x2FC1,
	0xFFFD: 0x2FC2,
	0xFFFD: 0x2FC3,
	0xFFFD: 0x2FC4,
	0xFFFD: 0x2FC5,
	0xFFFD: 0x2FC6,
	0xFFFD: 0x2FC7,
	0xFFFD: 0x2FC8,
	0xFFFD: 0x2FC9,
	0xFFFD: 0x2FCA,
	0xFFFD: 0x2FCB,
	0xFFFD: 0x2FCC,
	0xFFFD: 0x2FCD,
	0xFFFD: 0x2FCE,
	0xFFFD: 0x2FCF,
	0xFFFD: 0x2FD0,
	0xFFFD: 0x2FD1,
	0xFFFD: 0x2FD2,
	0xFFFD: 0x2FD3,
	0xFFFD: 0x2FD4,
	0xFFFD: 0x2FD5,
	0xFFFD: 0x2FD6,
	0xFFFD: 0x2FD7,
	0xFFFD: 0x2FD8,
	0xFFFD: 0x2FD9,
	0xFFFD: 0x2FDA,
	0xFFFD: 0x2FDB,
	0xFFFD: 0x2FDC,
	0xFFFD: 0x2FDD,
	0xFFFD: 0x2FDE,
	0xFFFD: 0x2FDF,
	0xFFFD: 0x2FE0,
	0xFFFD: 0x2FE1,
	0xFFFD: 0x2FE2,
	0xFFFD: 0x2FE3,
	0xFFFD: 0x2FE4,
	0xFFFD: 0x2FE5,
	0xFFFD: 0x2FE6,
	0xFFFD: 0x2FE7,
	0xFFFD: 0x2FE8,
	0xFFFD: 0x2FE9,
	0xFFFD: 0x2FEA,
	0xFFFD: 0x2FEB,
	0xFFFD: 0x2FEC,
	0xFFFD: 0x2FED,
	0xFFFD: 0x2FEE,
	0xFFFD: 0x2FEF,
	0xFFFD: 0x2FF0,
	0xFFFD: 0x2FF1,
	0xFFFD: 0x2FF2,
	0xFFFD: 0x2FF3,
	0xFFFD: 0x2FF4,
	0xFFFD: 0x2FF5,
	0xFFFD: 0x2FF6,
	0xFFFD: 0x2FF7,
	0xFFFD: 0x2FF8,
	0xFFFD: 0x2FF9,
	0xFFFD: 0x2FFA,
	0xFFFD: 0x2FFB,
	0xFFFD: 0x2FFC,
	0xFFFD: 0x2FFD,
	0xFFFD: 0x2FFE,
	0xFFFD: 0x2FFF,
	0xA140: 0x3000,
	0xA142: 0x3001,
	0xA143: 0x3002,
	0xA1B2: 0x3003,
	0xFFFD: 0x3004,
	0xC6E0: 0x3005,
	0xC6E1: 0x3006,
	0xC6E2: 0x3007,
	0xA171: 0x3008,
	0xA172: 0x3009,
	0xA16D: 0x300A,
	0xA16E: 0x300B,
	0xA175: 0x300C,
	0xA176: 0x300D,
	0xA179: 0x300E,
	0xA17A: 0x300F,
	0xA169: 0x3010,
	0xA16A: 0x3011,
	0xA245: 0x3012,
	0x965D: 0x3013,
	0xA165: 0x3014,
	0xA166: 0x3015,
	0x9D51: 0x3016,
	0x9D52: 0x3017,
	0xFFFD: 0x3018,
	0xFFFD: 0x3019,
	0xFFFD: 0x301A,
	0xFFFD: 0x301B,
	0xA1E3: 0x301C,
	0xA1A9: 0x301D,
	0xA1AA: 0x301E,
	0xFFFD: 0x301F,
	0xFFFD: 0x3020,
	0xA2C3: 0x3021,
	0xA2C4: 0x3022,
	0xA2C5: 0x3023,
	0xA2C6: 0x3024,
	0xA2C7: 0x3025,
	0xA2C8: 0x3026,
	0xA2C9: 0x3027,
	0xA2CA: 0x3028,
	0xA2CB: 0x3029,
	0xFFFD: 0x302A,
	0xFFFD: 0x302B,
	0xFFFD: 0x302C,
	0xFFFD: 0x302D,
	0xFFFD: 0x302E,
	0xFFFD: 0x302F,
	0xA1CA: 0x3030,
	0xFFFD: 0x3031,
	0xFFFD: 0x3032,
	0xFFFD: 0x3033,
	0xFFFD: 0x3034,
	0xFFFD: 0x3035,
	0xFFFD: 0x3036,
	0xFFFD: 0x3037,
	0xA2CC: 0x3038,
	0xA2CD: 0x3039,
	0xA2CE: 0x303A,
	0xFFFD: 0x303B,
	0xFFFD: 0x303C,
	0xFFFD: 0x303D,
	0xFFFD: 0x303E,
	0xFFFD: 0x303F,
	0xFFFD: 0x3040,
	0xC6E7: 0x3041,
	0xC6E8: 0x3042,
	0xC6E9: 0x3043,
	0xC6EA: 0x3044,
	0xC6EB: 0x3045,
	0xC6EC: 0x3046,
	0xC6ED: 0x3047,
	0xC6EE: 0x3048,
	0xC6EF: 0x3049,
	0xC6F0: 0x304A,
	0xC6F1: 0x304B,
	0xC6F2: 0x304C,
	0xC6F3: 0x304D,
	0xC6F4: 0x304E,
	0xC6F5: 0x304F,
	0xC6F6: 0x3050,
	0xC6F7: 0x3051,
	0xC6F8: 0x3052,
	0xC6F9: 0x3053,
	0xC6FA: 0x3054,
	0xC6FB: 0x3055,
	0xC6FC: 0x3056,
	0xC6FD: 0x3057,
	0xC6FE: 0x3058,
	0xC740: 0x3059,
	0xC741: 0x305A,
	0xC742: 0x305B,
	0xC743: 0x305C,
	0xC744: 0x305D,
	0xC745: 0x305E,
	0xC746: 0x305F,
	0xC747: 0x3060,
	0xC748: 0x3061,
	0xC749: 0x3062,
	0xC74A: 0x3063,
	0xC74B: 0x3064,
	0xC74C: 0x3065,
	0xC74D: 0x3066,
	0xC74E: 0x3067,
	0xC74F: 0x3068,
	0xC750: 0x3069,
	0xC751: 0x306A,
	0xC752: 0x306B,
	0xC753: 0x306C,
	0xC754: 0x306D,
	0xC755: 0x306E,
	0xC756: 0x306F,
	0xC757: 0x3070,
	0xC758: 0x3071,
	0xC759: 0x3072,
	0xC75A: 0x3073,
	0xC75B: 0x3074,
	0xC75C: 0x3075,
	0xC75D: 0x3076,
	0xC75E: 0x3077,
	0xC75F: 0x3078,
	0xC760: 0x3079,
	0xC761: 0x307A,
	0xC762: 0x307B,
	0xC763: 0x307C,
	0xC764: 0x307D,
	0xC765: 0x307E,
	0xC766: 0x307F,
	0xC767: 0x3080,
	0xC768: 0x3081,
	0xC769: 0x3082,
	0xC76A: 0x3083,
	0xC76B: 0x3084,
	0xC76C: 0x3085,
	0xC76D: 0x3086,
	0xC76E: 0x3087,
	0xC76F: 0x3088,
	0xC770: 0x3089,
	0xC771: 0x308A,
	0xC772: 0x308B,
	0xC773: 0x308C,
	0xC774: 0x308D,
	0xC775: 0x308E,
	0xC776: 0x308F,
	0xC777: 0x3090,
	0xC778: 0x3091,
	0xC779: 0x3092,
	0xC77A: 0x3093,
	0xC8B3: 0x3094,
	0xFFFD: 0x3095,
	0xFFFD: 0x3096,
	0xFFFD: 0x3097,
	0xFFFD: 0x3098,
	0xFFFD: 0x3099,
	0xFFFD: 0x309A,
	0xC8B1: 0x309B,
	0xC8B2: 0x309C,
	0xC6DC: 0x309D,
	0xC6DD: 0x309E,
	0xFFFD: 0x309F,
	0xFFFD: 0x30A0,
	0xC77B: 0x30A1,
	0xC77C: 0x30A2,
	0xC77D: 0x30A3,
	0xC77E: 0x30A4,
	0xC7A1: 0x30A5,
	0xC7A2: 0x30A6,
	0xC7A3: 0x30A7,
	0xC7A4: 0x30A8,
	0xC7A5: 0x30A9,
	0xC7A6: 0x30AA,
	0xC7A7: 0x30AB,
	0xC7A8: 0x30AC,
	0xC7A9: 0x30AD,
	0xC7AA: 0x30AE,
	0xC7AB: 0x30AF,
	0xC7AC: 0x30B0,
	0xC7AD: 0x30B1,
	0xC7AE: 0x30B2,
	0xC7AF: 0x30B3,
	0xC7B0: 0x30B4,
	0xC7B1: 0x30B5,
	0xC7B2: 0x30B6,
	0xC7B3: 0x30B7,
	0xC7B4: 0x30B8,
	0xC7B5: 0x30B9,
	0xC7B6: 0x30BA,
	0xC7B7: 0x30BB,
	0xC7B8: 0x30BC,
	0xC7B9: 0x30BD,
	0xC7BA: 0x30BE,
	0xC7BB: 0x30BF,
	0xC7BC: 0x30C0,
	0xC7BD: 0x30C1,
	0xC7BE: 0x30C2,
	0xC7BF: 0x30C3,
	0xC7C0: 0x30C4,
	0xC7C1: 0x30C5,
	0xC7C2: 0x30C6,
	0xC7C3: 0x30C7,
	0xC7C4: 0x30C8,
	0xC7C5: 0x30C9,
	0xC7C6: 0x30CA,
	0xC7C7: 0x30CB,
	0xC7C8: 0x30CC,
	0xC7C9: 0x30CD,
	0xC7CA: 0x30CE,
	0xC7CB: 0x30CF,
	0xC7CC: 0x30D0,
	0xC7CD: 0x30D1,
	0xC7CE: 0x30D2,
	0xC7CF: 0x30D3,
	0xC7D0: 0x30D4,
	0xC7D1: 0x30D5,
	0xC7D2: 0x30D6,
	0xC7D3: 0x30D7,
	0xC7D4: 0x30D8,
	0xC7D5: 0x30D9,
	0xC7D6: 0x30DA,
	0xC7D7: 0x30DB,
	0xC7D8: 0x30DC,
	0xC7D9: 0x30DD,
	0xC7DA: 0x30DE,
	0xC7DB: 0x30DF,
	0xC7DC: 0x30E0,
	0xC7DD: 0x30E1,
	0xC7DE: 0x30E2,
	0xC7DF: 0x30E3,
	0xC7E0: 0x30E4,
	0xC7E1: 0x30E5,
	0xC7E2: 0x30E6,
	0xC7E3: 0x30E7,
	0xC7E4: 0x30E8,
	0xC7E5: 0x30E9,
	0xC7E6: 0x30EA,
	0xC7E7: 0x30EB,
	0xC7E8: 0x30EC,
	0xC7E9: 0x30ED,
	0xC7EA: 0x30EE,
	0xC7EB: 0x30EF,
	0xC7EC: 0x30F0,
	0xC7ED: 0x30F1,
	0xC7EE: 0x30F2,
	0xC7EF: 0x30F3,
	0xC7F0: 0x30F4,
	0xC7F1: 0x30F5,
	0xC7F2: 0x30F6,
	0xC8B4: 0x30F7,
	0xC8B5: 0x30F8,
	0xC8B6: 0x30F9,
	0xC8B7: 0x30FA,
	0xC8B8: 0x30FB,
	0xC6E3: 0x30FC,
	0xC6DA: 0x30FD,
	0xC6DB: 0x30FE,
	0xFFFD: 0x30FF,
	0xFFFD: 0x3100,
	0xFFFD: 0x3101,
	0xFFFD: 0x3102,
	0xFFFD: 0x3103,
	0xFFFD: 0x3104,
	0xA374: 0x3105,
	0xA375: 0x3106,
	0xA376: 0x3107,
	0xA377: 0x3108,
	0xA378: 0x3109,
	0xA379: 0x310A,
	0xA37A: 0x310B,
	0xA37B: 0x310C,
	0xA37C: 0x310D,
	0xA37D: 0x310E,
	0xA37E: 0x310F,
	0xA3A1: 0x3110,
	0xA3A2: 0x3111,
	0xA3A3: 0x3112,
	0xA3A4: 0x3113,
	0xA3A5: 0x3114,
	0xA3A6: 0x3115,
	0xA3A7: 0x3116,
	0xA3A8: 0x3117,
	0xA3A9: 0x3118,
	0xA3AA: 0x3119,
	0xA3AB: 0x311A,
	0xA3AC: 0x311B,
	0xA3AD: 0x311C,
	0xA3AE: 0x311D,
	0xA3AF: 0x311E,
	0xA3B0: 0x311F,
	0xA3B1: 0x3120,
	0xA3B2: 0x3121,
	0xA3B3: 0x3122,
	0xA3B4: 0x3123,
	0xA3B5: 0x3124,
	0xA3B6: 0x3125,
	0xA3B7: 0x3126,
	0xA3B8: 0x3127,
	0xA3B9: 0x3128,
	0xA3BA: 0x3129,
	0xFFFD: 0x312A,
	0xFFFD: 0x312B,
	0xFFFD: 0x312C,
	0xFFFD: 0x312D,
	0xFFFD: 0x312E,
	0xFFFD: 0x312F,
	0xFFFD: 0x3130,
	0xFFFD: 0x3131,
	0xFFFD: 0x3132,
	0xFFFD: 0x3133,
	0xFFFD: 0x3134,
	0xFFFD: 0x3135,
	0xFFFD: 0x3136,
	0xFFFD: 0x3137,
	0xFFFD: 0x3138,
	0xFFFD: 0x3139,
	0xFFFD: 0x313A,
	0xFFFD: 0x313B,
	0xFFFD: 0x313C,
	0xFFFD: 0x313D,
	0xFFFD: 0x313E,
	0xFFFD: 0x313F,
	0xFFFD: 0x3140,
	0xFFFD: 0x3141,
	0xFFFD: 0x3142,
	0xFFFD: 0x3143,
	0xFFFD: 0x3144,
	0xFFFD: 0x3145,
	0xFFFD: 0x3146,
	0xFFFD: 0x3147,
	0xFFFD: 0x3148,
	0xFFFD: 0x3149,
	0xFFFD: 0x314A,
	0xFFFD: 0x314B,
	0xFFFD: 0x314C,
	0xFFFD: 0x314D,
	0xFFFD: 0x314E,
	0xFFFD: 0x314F,
	0xFFFD: 0x3150,
	0xFFFD: 0x3151,
	0xFFFD: 0x3152,
	0xFFFD: 0x3153,
	0xFFFD: 0x3154,
	0xFFFD: 0x3155,
	0xFFFD: 0x3156,
	0xFFFD: 0x3157,
	0xFFFD: 0x3158,
	0xFFFD: 0x3159,
	0xFFFD: 0x315A,
	0xFFFD: 0x315B,
	0xFFFD: 0x315C,
	0xFFFD: 0x315D,
	0xFFFD: 0x315E,
	0xFFFD: 0x315F,
	0xFFFD: 0x3160,
	0xFFFD: 0x3161,
	0xFFFD: 0x3162,
	0xFFFD: 0x3163,
	0xFFFD: 0x3164,
	0xFFFD: 0x3165,
	0xFFFD: 0x3166,
	0xFFFD: 0x3167,
	0xFFFD: 0x3168,
	0xFFFD: 0x3169,
	0xFFFD: 0x316A,
	0xFFFD: 0x316B,
	0xFFFD: 0x316C,
	0xFFFD: 0x316D,
	0xFFFD: 0x316E,
	0xFFFD: 0x316F,
	0xFFFD: 0x3170,
	0xFFFD: 0x3171,
	0xFFFD: 0x3172,
	0xFFFD: 0x3173,
	0xFFFD: 0x3174,
	0xFFFD: 0x3175,
	0xFFFD: 0x3176,
	0xFFFD: 0x3177,
	0xFFFD: 0x3178,
	0xFFFD: 0x3179,
	0xFFFD: 0x317A,
	0xFFFD: 0x317B,
	0xFFFD: 0x317C,
	0xFFFD: 0x317D,
	0xFFFD: 0x317E,
	0xFFFD: 0x317F,
	0xFFFD: 0x3180,
	0xFFFD: 0x3181,
	0xFFFD: 0x3182,
	0xFFFD: 0x3183,
	0xFFFD: 0x3184,
	0xFFFD: 0x3185,
	0xFFFD: 0x3186,
	0xFFFD: 0x3187,
	0xFFFD: 0x3188,
	0xFFFD: 0x3189,
	0xFFFD: 0x318A,
	0xFFFD: 0x318B,
	0xFFFD: 0x318C,
	0xFFFD: 0x318D,
	0xFFFD: 0x318E,
	0xFFFD: 0x318F,
	0xFFFD: 0x3190,
	0xFFFD: 0x3191,
	0xA440: 0x3192,
	0xA447: 0x3193,
	0xA454: 0x3194,
	0xA57C: 0x3195,
	0xA457: 0x3196,
	0xA4A4: 0x3197,
	0xA455: 0x3198,
	0xA5D2: 0x3199,
	0xA441: 0x319A,
	0xA4FE: 0x319B,
	0xA442: 0x319C,
	0xA4D1: 0x319D,
	0xA661: 0x319E,
	0xA448: 0x319F,
	0xFFFD: 0x31A0,
	0xFFFD: 0x31A1,
	0xFFFD: 0x31A2,
	0xFFFD: 0x31A3,
	0xFFFD: 0x31A4,
	0xFFFD: 0x31A5,
	0xFFFD: 0x31A6,
	0xFFFD: 0x31A7,
	0xFFFD: 0x31A8,
	0xFFFD: 0x31A9,
	0xFFFD: 0x31AA,
	0xFFFD: 0x31AB,
	0xFFFD: 0x31AC,
	0xFFFD: 0x31AD,
	0xFFFD: 0x31AE,
	0xFFFD: 0x31AF,
	0xFFFD: 0x31B0,
	0xFFFD: 0x31B1,
	0xFFFD: 0x31B2,
	0xFFFD: 0x31B3,
	0xFFFD: 0x31B4,
	0xFFFD: 0x31B5,
	0xFFFD: 0x31B6,
	0xFFFD: 0x31B7,
	0xFFFD: 0x31B8,
	0xFFFD: 0x31B9,
	0xFFFD: 0x31BA,
	0xFFFD: 0x31BB,
	0xFFFD: 0x31BC,
	0xFFFD: 0x31BD,
	0xFFFD: 0x31BE,
	0xFFFD: 0x31BF,
	0xFFFD: 0x31C0,
	0xFFFD: 0x31C1,
	0xFFFD: 0x31C2,
	0xFFFD: 0x31C3,
	0xFFFD: 0x31C4,
	0xFFFD: 0x31C5,
	0xFFFD: 0x31C6,
	0xFFFD: 0x31C7,
	0xFFFD: 0x31C8,
	0xFFFD: 0x31C9,
	0xFFFD: 0x31CA,
	0xFFFD: 0x31CB,
	0xFFFD: 0x31CC,
	0xFFFD: 0x31CD,
	0xFFFD: 0x31CE,
	0xC879: 0x31CF,
	0xFFFD: 0x31D0,
	0xFFFD: 0x31D1,
	0xFFFD: 0x31D2,
	0xFFFD: 0x31D3,
	0xFFFD: 0x31D4,
	0xFFFD: 0x31D5,
	0xFFFD: 0x31D6,
	0xFFFD: 0x31D7,
	0xFFFD: 0x31D8,
	0xFFFD: 0x31D9,
	0xFFFD: 0x31DA,
	0xFFFD: 0x31DB,
	0xFFFD: 0x31DC,
	0xFFFD: 0x31DD,
	0xFFFD: 0x31DE,
	0xFFFD: 0x31DF,
	0xFFFD: 0x31E0,
	0xFFFD: 0x31E1,
	0xFFFD: 0x31E2,
	0xFFFD: 0x31E3,
	0xFFFD: 0x31E4,
	0xFFFD: 0x31E5,
	0xFFFD: 0x31E6,
	0xFFFD: 0x31E7,
	0xFFFD: 0x31E8,
	0xFFFD: 0x31E9,
	0xFFFD: 0x31EA,
	0xFFFD: 0x31EB,
	0xFFFD: 0x31EC,
	0xFFFD: 0x31ED,
	0xFFFD: 0x31EE,
	0xFFFD: 0x31EF,
	0xFFFD: 0x31F0,
	0xFFFD: 0x31F1,
	0xFFFD: 0x31F2,
	0xFFFD: 0x31F3,
	0xFFFD: 0x31F4,
	0xFFFD: 0x31F5,
	0xFFFD: 0x31F6,
	0xFFFD: 0x31F7,
	0xFFFD: 0x31F8,
	0xFFFD: 0x31F9,
	0xFFFD: 0x31FA,
	0xFFFD: 0x31FB,
	0xFFFD: 0x31FC,
	0xFFFD: 0x31FD,
	0xFFFD: 0x31FE,
	0xFFFD: 0x31FF,
	0xFFFD: 0x3200,
	0xFFFD: 0x3201,
	0xFFFD: 0x3202,
	0xFFFD: 0x3203,
	0xFFFD: 0x3204,
	0xFFFD: 0x3205,
	0xFFFD: 0x3206,
	0xFFFD: 0x3207,
	0xFFFD: 0x3208,
	0xFFFD: 0x3209,
	0xFFFD: 0x320A,
	0xFFFD: 0x320B,
	0xFFFD: 0x320C,
	0xFFFD: 0x320D,
	0xFFFD: 0x320E,
	0xFFFD: 0x320F,
	0xFFFD: 0x3210,
	0xFFFD: 0x3211,
	0xFFFD: 0x3212,
	0xFFFD: 0x3213,
	0xFFFD: 0x3214,
	0xFFFD: 0x3215,
	0xFFFD: 0x3216,
	0xFFFD: 0x3217,
	0xFFFD: 0x3218,
	0xFFFD: 0x3219,
	0xFFFD: 0x321A,
	0xFFFD: 0x321B,
	0xFFFD: 0x321C,
	0xFFFD: 0x321D,
	0xFFFD: 0x321E,
	0xFFFD: 0x321F,
	0x9C41: 0x3220,
	0x9C42: 0x3221,
	0x9C43: 0x3222,
	0x9C44: 0x3223,
	0x9C45: 0x3224,
	0x9C46: 0x3225,
	0x9C47: 0x3226,
	0x9C48: 0x3227,
	0x9C49: 0x3228,
	0x9C4A: 0x3229,
	0xA4EB: 0x322A,
	0xA4F5: 0x322B,
	0xA4F4: 0x322C,
	0xA4EC: 0x322D,
	0xAAF7: 0x322E,
	0xA467: 0x322F,
	0xA4E9: 0x3230,
	0x99FD: 0x3231,
	0x99FC: 0x3232,
	0xAAC0: 0x3233,
	0xA657: 0x3234,
	0xAF53: 0x3235,
	0xB05D: 0x3236,
	0xAFAC: 0x3237,
	0xB3D2: 0x3238,
	0xA54E: 0x3239,
	0xA949: 0x323A,
	0xBEC7: 0x323B,
	0xBACA: 0x323C,
	0xA5F8: 0x323D,
	0xB8EA: 0x323E,
	0xA8F3: 0x323F,
	0xB2BD: 0x3240,
	0xA5F0: 0x3241,
	0xA6DB: 0x3242,
	0xA6DC: 0x3243,
	0xFFFD: 0x3244,
	0xFFFD: 0x3245,
	0xFFFD: 0x3246,
	0xFFFD: 0x3247,
	0xFFFD: 0x3248,
	0xFFFD: 0x3249,
	0xFFFD: 0x324A,
	0xFFFD: 0x324B,
	0xFFFD: 0x324C,
	0xFFFD: 0x324D,
	0xFFFD: 0x324E,
	0xFFFD: 0x324F,
	0xFFFD: 0x3250,
	0xFFFD: 0x3251,
	0xFFFD: 0x3252,
	0xFFFD: 0x3253,
	0xFFFD: 0x3254,
	0xFFFD: 0x3255,
	0xFFFD: 0x3256,
	0xFFFD: 0x3257,
	0xFFFD: 0x3258,
	0xFFFD: 0x3259,
	0xFFFD: 0x325A,
	0xFFFD: 0x325B,
	0xFFFD: 0x325C,
	0xFFFD: 0x325D,
	0xFFFD: 0x325E,
	0xFFFD: 0x325F,
	0xFFFD: 0x3260,
	0xFFFD: 0x3261,
	0xFFFD: 0x3262,
	0xFFFD: 0x3263,
	0xFFFD: 0x3264,
	0xFFFD: 0x3265,
	0xFFFD: 0x3266,
	0xFFFD: 0x3267,
	0xFFFD: 0x3268,
	0xFFFD: 0x3269,
	0xFFFD: 0x326A,
	0xFFFD: 0x326B,
	0xFFFD: 0x326C,
	0xFFFD: 0x326D,
	0xFFFD: 0x326E,
	0xFFFD: 0x326F,
	0xFFFD: 0x3270,
	0xFFFD: 0x3271,
	0xFFFD: 0x3272,
	0xFFFD: 0x3273,
	0xFFFD: 0x3274,
	0xFFFD: 0x3275,
	0xFFFD: 0x3276,
	0xFFFD: 0x3277,
	0xFFFD: 0x3278,
	0xFFFD: 0x3279,
	0xFFFD: 0x327A,
	0xFFFD: 0x327B,
	0xFFFD: 0x327C,
	0xFFFD: 0x327D,
	0xFFFD: 0x327E,
	0xFFFD: 0x327F,
	0xA440: 0x3280,
	0xA447: 0x3281,
	0xA454: 0x3282,
	0xA57C: 0x3283,
	0xA4AD: 0x3284,
	0xA4BB: 0x3285,
	0xA443: 0x3286,
	0xA44B: 0x3287,
	0xA445: 0x3288,
	0xA451: 0x3289,
	0xA4EB: 0x328A,
	0xA4F5: 0x328B,
	0xA4F4: 0x328C,
	0xA4EC: 0x328D,
	0xAAF7: 0x328E,
	0xA467: 0x328F,
	0xA4E9: 0x3290,
	0xAEE8: 0x3291,
	0xA6B3: 0x3292,
	0xAAC0: 0x3293,
	0xA657: 0x3294,
	0xAF53: 0x3295,
	0xB05D: 0x3296,
	0xAFAC: 0x3297,
	0xB3D2: 0x3298,
	0xAFB5: 0x3299,
	0xA86B: 0x329A,
	0xA46B: 0x329B,
	0xBE41: 0x329C,
	0xC075: 0x329D,
	0xA64C: 0x329E,
	0xAA60: 0x329F,
	0xB6B5: 0x32A0,
	0xA5F0: 0x32A1,
	0xBC67: 0x32A2,
	0xA1C0: 0x32A3,
	0xA457: 0x32A4,
	0xA4A4: 0x32A5,
	0xA455: 0x32A6,
	0xA5AA: 0x32A7,
	0xA56B: 0x32A8,
	0xC2E5: 0x32A9,
	0xA976: 0x32AA,
	0xBEC7: 0x32AB,
	0xBACA: 0x32AC,
	0xA5F8: 0x32AD,
	0xB8EA: 0x32AE,
	0xA8F3: 0x32AF,
	0xA95D: 0x32B0,
	0xFFFD: 0x32B1,
	0xFFFD: 0x32B2,
	0xFFFD: 0x32B3,
	0xFFFD: 0x32B4,
	0xFFFD: 0x32B5,
	0xFFFD: 0x32B6,
	0xFFFD: 0x32B7,
	0xFFFD: 0x32B8,
	0xFFFD: 0x32B9,
	0xFFFD: 0x32BA,
	0xFFFD: 0x32BB,
	0xFFFD: 0x32BC,
	0xFFFD: 0x32BD,
	0xFFFD: 0x32BE,
	0xFFFD: 0x32BF,
	0xFFFD: 0x32C0,
	0xFFFD: 0x32C1,
	0xFFFD: 0x32C2,
	0xFFFD: 0x32C3,
	0xFFFD: 0x32C4,
	0xFFFD: 0x32C5,
	0xFFFD: 0x32C6,
	0xFFFD: 0x32C7,
	0xFFFD: 0x32C8,
	0xFFFD: 0x32C9,
	0xFFFD: 0x32CA,
	0xFFFD: 0x32CB,
	0x4867: 0x32CC,
	0xFFFD: 0x32CD,
	0x6556: 0x32CE,
	0xFFFD: 0x32CF,
	0xFFFD: 0x32D0,
	0xFFFD: 0x32D1,
	0xFFFD: 0x32D2,
	0xFFFD: 0x32D3,
	0xFFFD: 0x32D4,
	0xFFFD: 0x32D5,
	0xFFFD: 0x32D6,
	0xFFFD: 0x32D7,
	0xFFFD: 0x32D8,
	0xFFFD: 0x32D9,
	0xFFFD: 0x32DA,
	0xFFFD: 0x32DB,
	0xFFFD: 0x32DC,
	0xFFFD: 0x32DD,
	0xFFFD: 0x32DE,
	0xFFFD: 0x32DF,
	0xFFFD: 0x32E0,
	0xFFFD: 0x32E1,
	0xFFFD: 0x32E2,
	0xFFFD: 0x32E3,
	0xFFFD: 0x32E4,
	0xFFFD: 0x32E5,
	0xFFFD: 0x32E6,
	0xFFFD: 0x32E7,
	0xFFFD: 0x32E8,
	0xFFFD: 0x32E9,
	0xFFFD: 0x32EA,
	0xFFFD: 0x32EB,
	0xFFFD: 0x32EC,
	0xFFFD: 0x32ED,
	0xFFFD: 0x32EE,
	0xFFFD: 0x32EF,
	0xFFFD: 0x32F0,
	0xFFFD: 0x32F1,
	0xFFFD: 0x32F2,
	0xFFFD: 0x32F3,
	0xFFFD: 0x32F4,
	0xFFFD: 0x32F5,
	0xFFFD: 0x32F6,
	0xFFFD: 0x32F7,
	0xFFFD: 0x32F8,
	0xFFFD: 0x32F9,
	0xFFFD: 0x32FA,
	0xFFFD: 0x32FB,
	0xFFFD: 0x32FC,
	0xFFFD: 0x32FD,
	0xFFFD: 0x32FE,
	0xFFFD: 0x32FF,
	0xFFFD: 0x3300,
	0xFFFD: 0x3301,
	0xFFFD: 0x3302,
	0xFFFD: 0x3303,
	0xFFFD: 0x3304,
	0xFFFD: 0x3305,
	0xFFFD: 0x3306,
	0xFFFD: 0x3307,
	0xFFFD: 0x3308,
	0xFFFD: 0x3309,
	0xFFFD: 0x330A,
	0xFFFD: 0x330B,
	0xFFFD: 0x330C,
	0xFFFD: 0x330D,
	0xFFFD: 0x330E,
	0xFFFD: 0x330F,
	0xFFFD: 0x3310,
	0xFFFD: 0x3311,
	0xFFFD: 0x3312,
	0xFFFD: 0x3313,
	0xFFFD: 0x3314,
	0xFFFD: 0x3315,
	0xFFFD: 0x3316,
	0xFFFD: 0x3317,
	0xFFFD: 0x3318,
	0xFFFD: 0x3319,
	0xFFFD: 0x331A,
	0xFFFD: 0x331B,
	0xFFFD: 0x331C,
	0xFFFD: 0x331D,
	0xFFFD: 0x331E,
	0xFFFD: 0x331F,
	0xFFFD: 0x3320,
	0xFFFD: 0x3321,
	0xFFFD: 0x3322,
	0xFFFD: 0x3323,
	0xFFFD: 0x3324,
	0xFFFD: 0x3325,
	0xFFFD: 0x3326,
	0xFFFD: 0x3327,
	0xFFFD: 0x3328,
	0xFFFD: 0x3329,
	0xFFFD: 0x332A,
	0xFFFD: 0x332B,
	0xFFFD: 0x332C,
	0xFFFD: 0x332D,
	0xFFFD: 0x332E,
	0xFFFD: 0x332F,
	0xFFFD: 0x3330,
	0xFFFD: 0x3331,
	0xFFFD: 0x3332,
	0xFFFD: 0x3333,
	0xFFFD: 0x3334,
	0xFFFD: 0x3335,
	0xFFFD: 0x3336,
	0xFFFD: 0x3337,
	0xFFFD: 0x3338,
	0xFFFD: 0x3339,
	0xFFFD: 0x333A,
	0xFFFD: 0x333B,
	0xFFFD: 0x333C,
	0xFFFD: 0x333D,
	0xFFFD: 0x333E,
	0xFFFD: 0x333F,
	0xFFFD: 0x3340,
	0xFFFD: 0x3341,
	0xFFFD: 0x3342,
	0xFFFD: 0x3343,
	0xFFFD: 0x3344,
	0xFFFD: 0x3345,
	0xFFFD: 0x3346,
	0xFFFD: 0x3347,
	0xFFFD: 0x3348,
	0xFFFD: 0x3349,
	0xFFFD: 0x334A,
	0xFFFD: 0x334B,
	0xFFFD: 0x334C,
	0xFFFD: 0x334D,
	0xFFFD: 0x334E,
	0xFFFD: 0x334F,
	0xFFFD: 0x3350,
	0xFFFD: 0x3351,
	0xFFFD: 0x3352,
	0xFFFD: 0x3353,
	0xFFFD: 0x3354,
	0xFFFD: 0x3355,
	0xFFFD: 0x3356,
	0xFFFD: 0x3357,
	0xFFFD: 0x3358,
	0xFFFD: 0x3359,
	0xFFFD: 0x335A,
	0xFFFD: 0x335B,
	0xFFFD: 0x335C,
	0xFFFD: 0x335D,
	0xFFFD: 0x335E,
	0xFFFD: 0x335F,
	0xFFFD: 0x3360,
	0xFFFD: 0x3361,
	0xFFFD: 0x3362,
	0xFFFD: 0x3363,
	0xFFFD: 0x3364,
	0xFFFD: 0x3365,
	0xFFFD: 0x3366,
	0xFFFD: 0x3367,
	0xFFFD: 0x3368,
	0xFFFD: 0x3369,
	0xFFFD: 0x336A,
	0xFFFD: 0x336B,
	0xFFFD: 0x336C,
	0xFFFD: 0x336D,
	0xFFFD: 0x336E,
	0xFFFD: 0x336F,
	0xFFFD: 0x3370,
	0xFFFD: 0x3371,
	0x6461: 0x3372,
	0x4155: 0x3373,
	0xFFFD: 0x3374,
	0x6F56: 0x3375,
	0x7063: 0x3376,
	0x646D: 0x3377,
	0xFFFD: 0x3378,
	0xFFFD: 0x3379,
	0x4955: 0x337A,
	0xFFFD: 0x337B,
	0xFFFD: 0x337C,
	0xFFFD: 0x337D,
	0xFFFD: 0x337E,
	0xFFFD: 0x337F,
	0x7041: 0x3380,
	0x6E41: 0x3381,
	0xFFFD: 0x3382,
	0x6D41: 0x3383,
	0x6B41: 0x3384,
	0x4B42: 0x3385,
	0x4D42: 0x3386,
	0x4742: 0x3387,
	0xFFFD: 0x3388,
	0xFFFD: 0x3389,
	0x7046: 0x338A,
	0x6E46: 0x338B,
	0xFFFD: 0x338C,
	0xFFFD: 0x338D,
	0xA255: 0x338E,
	0xA256: 0x338F,
	0x487A: 0x3390,
	0xFFFD: 0x3391,
	0xFFFD: 0x3392,
	0xFFFD: 0x3393,
	0xFFFD: 0x3394,
	0xFFFD: 0x3395,
	0xFFFD: 0x3396,
	0xFFFD: 0x3397,
	0xFFFD: 0x3398,
	0x666D: 0x3399,
	0x6E6D: 0x339A,
	0xFFFD: 0x339B,
	0xA250: 0x339C,
	0xA251: 0x339D,
	0xA252: 0x339E,
	0xFFFD: 0x339F,
	0xFFFD: 0x33A0,
	0xA254: 0x33A1,
	0xFFFD: 0x33A2,
	0xFFFD: 0x33A3,
	0xFFFD: 0x33A4,
	0x9DE7: 0x33A5,
	0xFFFD: 0x33A6,
	0xFFFD: 0x33A7,
	0xFFFD: 0x33A8,
	0x5061: 0x33A9,
	0xFFFD: 0x33AA,
	0xFFFD: 0x33AB,
	0xFFFD: 0x33AC,
	0xFFFD: 0x33AD,
	0xFFFD: 0x33AE,
	0xFFFD: 0x33AF,
	0x7073: 0x33B0,
	0x6E73: 0x33B1,
	0xFFFD: 0x33B2,
	0x6D73: 0x33B3,
	0x7056: 0x33B4,
	0x6E56: 0x33B5,
	0xFFFD: 0x33B6,
	0x6D56: 0x33B7,
	0x6B56: 0x33B8,
	0x4D56: 0x33B9,
	0x7057: 0x33BA,
	0x6E57: 0x33BB,
	0xFFFD: 0x33BC,
	0x6D57: 0x33BD,
	0x6B57: 0x33BE,
	0x4D57: 0x33BF,
	0xFFFD: 0x33C0,
	0xFFFD: 0x33C1,
	0x9DE3: 0x33C2,
	0x4271: 0x33C3,
	0xA257: 0x33C4,
	0x6364: 0x33C5,
	0xFFFD: 0x33C6,
	0xFFFD: 0x33C7,
	0x6442: 0x33C8,
	0x4779: 0x33C9,
	0x6861: 0x33CA,
	0x4850: 0x33CB,
	0x696E: 0x33CC,
	0x4B4B: 0x33CD,
	0xA253: 0x33CE,
	0x6B74: 0x33CF,
	0x6C6D: 0x33D0,
	0xA1EB: 0x33D1,
	0xA1EA: 0x33D2,
	0x6C78: 0x33D3,
	0x6D62: 0x33D4,
	0xA24F: 0x33D5,
	0xFFFD: 0x33D6,
	0x5048: 0x33D7,
	0x9DE4: 0x33D8,
	0xFFFD: 0x33D9,
	0x5052: 0x33DA,
	0x7372: 0x33DB,
	0x5376: 0x33DC,
	0x5762: 0x33DD,
	0xFFFD: 0x33DE,
	0xFFFD: 0x33DF,
	0xFFFD: 0x33E0,
	0xFFFD: 0x33E1,
	0xFFFD: 0x33E2,
	0xFFFD: 0x33E3,
	0xFFFD: 0x33E4,
	0xFFFD: 0x33E5,
	0xFFFD: 0x33E6,
	0xFFFD: 0x33E7,
	0xFFFD: 0x33E8,
	0xFFFD: 0x33E9,
	0xFFFD: 0x33EA,
	0xFFFD: 0x33EB,
	0xFFFD: 0x33EC,
	0xFFFD: 0x33ED,
	0xFFFD: 0x33EE,
	0xFFFD: 0x33EF,
	0xFFFD: 0x33F0,
	0xFFFD: 0x33F1,
	0xFFFD: 0x33F2,
	0xFFFD: 0x33F3,
	0xFFFD: 0x33F4,
	0xFFFD: 0x33F5,
	0xFFFD: 0x33F6,
	0xFFFD: 0x33F7,
	0xFFFD: 0x33F8,
	0xFFFD: 0x33F9,
	0xFFFD: 0x33FA,
	0xFFFD: 0x33FB,
	0xFFFD: 0x33FC,
	0xFFFD: 0x33FD,
	0xFFFD: 0x33FE,
	0xFFFD: 0x33FF,
	0xFFFD: 0x3400,
	0xFFFD: 0x3401,
	0xFFFD: 0x3402,
	0xFFFD: 0x3403,
	0x91E0: 0x3404,
	0xFFFD: 0x3405,
	0xFFFD: 0x3406,
	0xFFFD: 0x3407,
	0xFFFD: 0x3408,
	0xFFFD: 0x3409,
	0xFFFD: 0x340A,
	0xFFFD: 0x340B,
	0xFFFD: 0x340C,
	0xFFFD: 0x340D,
	0xFFFD: 0x340E,
	0xFFFD: 0x340F,
	0xFFFD: 0x3410,
	0xFFFD: 0x3411,
	0xFFFD: 0x3412,
	0xFFFD: 0x3413,
	0xFFFD: 0x3414,
	0xFFFD: 0x3415,
	0xFFFD: 0x3416,
	0xFFFD: 0x3417,
	0xFFFD: 0x3418,
	0xFFFD: 0x3419,
	0xFFFD: 0x341A,
	0xFFFD: 0x341B,
	0xFFFD: 0x341C,
	0xFFFD: 0x341D,
	0xFFFD: 0x341E,
	0xFFFD: 0x341F,
	0xFFFD: 0x3420,
	0xFFFD: 0x3421,
	0xFFFD: 0x3422,
	0xFFFD: 0x3423,
	0xFFFD: 0x3424,
	0xFFFD: 0x3425,
	0xFFFD: 0x3426,
	0xFFFD: 0x3427,
	0xFFFD: 0x3428,
	0xFFFD: 0x3429,
	0xFFFD: 0x342A,
	0xFFFD: 0x342B,
	0xFFFD: 0x342C,
	0xFFFD: 0x342D,
	0xFFFD: 0x342E,
	0xFFFD: 0x342F,
	0xFFFD: 0x3430,
	0xFFFD: 0x3431,
	0xFFFD: 0x3432,
	0xFFFD: 0x3433,
	0xFFFD: 0x3434,
	0xFFFD: 0x3435,
	0xFFFD: 0x3436,
	0xFFFD: 0x3437,
	0xFFFD: 0x3438,
	0xFFFD: 0x3439,
	0xFFFD: 0x343A,
	0xFFFD: 0x343B,
	0xFFFD: 0x343C,
	0xFFFD: 0x343D,
	0xFFFD: 0x343E,
	0xFFFD: 0x343F,
	0xFFFD: 0x3440,
	0xFFFD: 0x3441,
	0xFFFD: 0x3442,
	0xFFFD: 0x3443,
	0xFFFD: 0x3444,
	0xFFFD: 0x3445,
	0xFFFD: 0x3446,
	0xFFFD: 0x3447,
	0xFFFD: 0x3448,
	0xFFFD: 0x3449,
	0xFFFD: 0x344A,
	0xFFFD: 0x344B,
	0xFFFD: 0x344C,
	0xFFFD: 0x344D,
	0xFFFD: 0x344E,
	0xFFFD: 0x344F,
	0xFFFD: 0x3450,
	0xA0A2: 0x3451,
	0xFFFD: 0x3452,
	0xFFFD: 0x3453,
	0xFFFD: 0x3454,
	0xFFFD: 0x3455,
	0xFFFD: 0x3456,
	0xFFFD: 0x3457,
	0xFFFD: 0x3458,
	0xFFFD: 0x3459,
	0xFFFD: 0x345A,
	0xFFFD: 0x345B,
	0xFFFD: 0x345C,
	0xFFFD: 0x345D,
	0xFFFD: 0x345E,
	0xFFFD: 0x345F,
	0xFFFD: 0x3460,
	0xFFFD: 0x3461,
	0xFFFD: 0x3462,
	0xFFFD: 0x3463,
	0xFFFD: 0x3464,
	0xFFFD: 0x3465,
	0xFFFD: 0x3466,
	0xFFFD: 0x3467,
	0xFFFD: 0x3468,
	0xFFFD: 0x3469,
	0xFFFD: 0x346A,
	0xFFFD: 0x346B,
	0xFFFD: 0x346C,
	0xFFFD: 0x346D,
	0xFFFD: 0x346E,
	0xFFFD: 0x346F,
	0xFFFD: 0x3470,
	0xFFFD: 0x3471,
	0xFFFD: 0x3472,
	0xFFFD: 0x3473,
	0xFFFD: 0x3474,
	0xFFFD: 0x3475,
	0xFFFD: 0x3476,
	0xFFFD: 0x3477,
	0xFFFD: 0x3478,
	0xFFFD: 0x3479,
	0xFFFD: 0x347A,
	0xFFFD: 0x347B,
	0xFFFD: 0x347C,
	0xFFFD: 0x347D,
	0xFFFD: 0x347E,
	0xFFFD: 0x347F,
	0xFFFD: 0x3480,
	0xFFFD: 0x3481,
	0xFFFD: 0x3482,
	0xFFFD: 0x3483,
	0xFFFD: 0x3484,
	0xFFFD: 0x3485,
	0xFFFD: 0x3486,
	0xFFFD: 0x3487,
	0xFFFD: 0x3488,
	0xFFFD: 0x3489,
	0xFFFD: 0x348A,
	0xFFFD: 0x348B,
	0xFFFD: 0x348C,
	0xFFFD: 0x348D,
	0xFFFD: 0x348E,
	0xFFFD: 0x348F,
	0xFFFD: 0x3490,
	0xFFFD: 0x3491,
	0xFFFD: 0x3492,
	0xFFFD: 0x3493,
	0xFFFD: 0x3494,
	0xFFFD: 0x3495,
	0xFFFD: 0x3496,
	0xFFFD: 0x3497,
	0xFFFD: 0x3498,
	0xFFFD: 0x3499,
	0xFFFD: 0x349A,
	0xFFFD: 0x349B,
	0xFFFD: 0x349C,
	0xFFFD: 0x349D,
	0xFFFD: 0x349E,
	0xFFFD: 0x349F,
	0xFFFD: 0x34A0,
	0xFFFD: 0x34A1,
	0xFFFD: 0x34A2,
	0xFFFD: 0x34A3,
	0xFFFD: 0x34A4,
	0xFFFD: 0x34A5,
	0xFFFD: 0x34A6,
	0xFFFD: 0x34A7,
	0xFFFD: 0x34A8,
	0xFFFD: 0x34A9,
	0xFFFD: 0x34AA,
	0xFFFD: 0x34AB,
	0xFFFD: 0x34AC,
	0xFFFD: 0x34AD,
	0xFFFD: 0x34AE,
	0xFFFD: 0x34AF,
	0xFFFD: 0x34B0,
	0xFFFD: 0x34B1,
	0xFFFD: 0x34B2,
	0xFFFD: 0x34B3,
	0xFFFD: 0x34B4,
	0xFFFD: 0x34B5,
	0xFFFD: 0x34B6,
	0xFFFD: 0x34B7,
	0xFFFD: 0x34B8,
	0xFFFD: 0x34B9,
	0xFFFD: 0x34BA,
	0xFFFD: 0x34BB,
	0xFFFD: 0x34BC,
	0xFFFD: 0x34BD,
	0xFFFD: 0x34BE,
	0xFFFD: 0x34BF,
	0xFFFD: 0x34C0,
	0xFFFD: 0x34C1,
	0xFFFD: 0x34C2,
	0xFFFD: 0x34C3,
	0xFFFD: 0x34C4,
	0xFFFD: 0x34C5,
	0xFFFD: 0x34C6,
	0xFFFD: 0x34C7,
	0xFFFD: 0x34C8,
	0xFFFD: 0x34C9,
	0xFFFD: 0x34CA,
	0xFFFD: 0x34CB,
	0xFFFD: 0x34CC,
	0xFFFD: 0x34CD,
	0xFFFD: 0x34CE,
	0xFFFD: 0x34CF,
	0xFFFD: 0x34D0,
	0xFFFD: 0x34D1,
	0xFFFD: 0x34D2,
	0xFFFD: 0x34D3,
	0xFFFD: 0x34D4,
	0xFFFD: 0x34D5,
	0xFFFD: 0x34D6,
	0xFFFD: 0x34D7,
	0xFFFD: 0x34D8,
	0xFFFD: 0x34D9,
	0xFFFD: 0x34DA,
	0xFFFD: 0x34DB,
	0xFFFD: 0x34DC,
	0xFFFD: 0x34DD,
	0xFFFD: 0x34DE,
	0xFB44: 0x34DF,
	0xFFFD: 0x34E0,
	0xFFFD: 0x34E1,
	0xFFFD: 0x34E2,
	0xFFFD: 0x34E3,
	0xFFFD: 0x34E4,
	0xFFFD: 0x34E5,
	0xFFFD: 0x34E6,
	0xFFFD: 0x34E7,
	0xFFFD: 0x34E8,
	0xFFFD: 0x34E9,
	0xFFFD: 0x34EA,
	0xFFFD: 0x34EB,
	0xFFFD: 0x34EC,
	0xFFFD: 0x34ED,
	0xFFFD: 0x34EE,
	0xFFFD: 0x34EF,
	0xFFFD: 0x34F0,
	0xFFFD: 0x34F1,
	0xFFFD: 0x34F2,
	0xFFFD: 0x34F3,
	0xFFFD: 0x34F4,
	0xFFFD: 0x34F5,
	0xFFFD: 0x34F6,
	0xFFFD: 0x34F7,
	0xFFFD: 0x34F8,
	0xFFFD: 0x34F9,
	0xFFFD: 0x34FA,
	0xFFFD: 0x34FB,
	0xFFFD: 0x34FC,
	0xFFFD: 0x34FD,
	0xFFFD: 0x34FE,
	0xFFFD: 0x34FF,
	0xFFFD: 0x3500,
	0xFFFD: 0x3501,
	0xFFFD: 0x3502,
	0xFFFD: 0x3503,
	0xFFFD: 0x3504,
	0xFFFD: 0x3505,
	0xFFFD: 0x3506,
	0xFFFD: 0x3507,
	0xFFFD: 0x3508,
	0xFFFD: 0x3509,
	0xFFFD: 0x350A,
	0xFFFD: 0x350B,
	0xFFFD: 0x350C,
	0xFFFD: 0x350D,
	0xFFFD: 0x350E,
	0xFFFD: 0x350F,
	0xFFFD: 0x3510,
	0xFFFD: 0x3511,
	0xFFFD: 0x3512,
	0xFFFD: 0x3513,
	0xFFFD: 0x3514,
	0xFFFD: 0x3515,
	0xFFFD: 0x3516,
	0xFFFD: 0x3517,
	0xFFFD: 0x3518,
	0xFFFD: 0x3519,
	0xFFFD: 0x351A,
	0xFFFD: 0x351B,
	0xFFFD: 0x351C,
	0xFFFD: 0x351D,
	0xFFFD: 0x351E,
	0xFFFD: 0x351F,
	0xFFFD: 0x3520,
	0xFFFD: 0x3521,
	0xFFFD: 0x3522,
	0xFFFD: 0x3523,
	0xFFFD: 0x3524,
	0xFFFD: 0x3525,
	0xFFFD: 0x3526,
	0xFFFD: 0x3527,
	0xFFFD: 0x3528,
	0xFFFD: 0x3529,
	0xFFFD: 0x352A,
	0xFFFD: 0x352B,
	0xFFFD: 0x352C,
	0xFFFD: 0x352D,
	0xFFFD: 0x352E,
	0xFFFD: 0x352F,
	0xFFFD: 0x3530,
	0xFFFD: 0x3531,
	0xFFFD: 0x3532,
	0xFFFD: 0x3533,
	0xFFFD: 0x3534,
	0xFFFD: 0x3535,
	0xFFFD: 0x3536,
	0xFFFD: 0x3537,
	0xFFFD: 0x3538,
	0xFFFD: 0x3539,
	0xFFFD: 0x353A,
	0xFFFD: 0x353B,
	0xFFFD: 0x353C,
	0xFFFD: 0x353D,
	0xFFFD: 0x353E,
	0xFFFD: 0x353F,
	0xFFFD: 0x3540,
	0xFFFD: 0x3541,
	0xFFFD: 0x3542,
	0xFFFD: 0x3543,
	0xFFFD: 0x3544,
	0xFFFD: 0x3545,
	0xFFFD: 0x3546,
	0xFFFD: 0x3547,
	0xFFFD: 0x3548,
	0xFFFD: 0x3549,
	0xFFFD: 0x354A,
	0xFFFD: 0x354B,
	0xFFFD: 0x354C,
	0xFFFD: 0x354D,
	0xFFFD: 0x354E,
	0xFFFD: 0x354F,
	0xFFFD: 0x3550,
	0x95B8: 0x3551,
	0xFFFD: 0x3552,
	0xFFFD: 0x3553,
	0xFFFD: 0x3554,
	0xFFFD: 0x3555,
	0xFFFD: 0x3556,
	0xFFFD: 0x3557,
	0xFFFD: 0x3558,
	0xFFFD: 0x3559,
	0xFFFD: 0x355A,
	0xFFFD: 0x355B,
	0xFFFD: 0x355C,
	0xFFFD: 0x355D,
	0xFFFD: 0x355E,
	0xFFFD: 0x355F,
	0xFFFD: 0x3560,
	0xFFFD: 0x3561,
	0xFFFD: 0x3562,
	0xFFFD: 0x3563,
	0xFFFD: 0x3564,
	0xFFFD: 0x3565,
	0xFFFD: 0x3566,
	0xFFFD: 0x3567,
	0xFFFD: 0x3568,
	0xFFFD: 0x3569,
	0xFFFD: 0x356A,
	0xFFFD: 0x356B,
	0xFFFD: 0x356C,
	0xFFFD: 0x356D,
	0xFFFD: 0x356E,
	0xFFFD: 0x356F,
	0xFFFD: 0x3570,
	0xFFFD: 0x3571,
	0xFFFD: 0x3572,
	0xFFFD: 0x3573,
	0xFFFD: 0x3574,
	0xFFFD: 0x3575,
	0xFFFD: 0x3576,
	0xFFFD: 0x3577,
	0xFFFD: 0x3578,
	0xFFFD: 0x3579,
	0xFFFD: 0x357A,
	0xFFFD: 0x357B,
	0xFFFD: 0x357C,
	0xFFFD: 0x357D,
	0xFFFD: 0x357E,
	0xFFFD: 0x357F,
	0xFFFD: 0x3580,
	0xFFFD: 0x3581,
	0xFFFD: 0x3582,
	0xFFFD: 0x3583,
	0xFFFD: 0x3584,
	0xFFFD: 0x3585,
	0xFFFD: 0x3586,
	0xFFFD: 0x3587,
	0xFFFD: 0x3588,
	0xFFFD: 0x3589,
	0xFFFD: 0x358A,
	0xFFFD: 0x358B,
	0xFFFD: 0x358C,
	0xFFFD: 0x358D,
	0xFFFD: 0x358E,
	0xFFFD: 0x358F,
	0xFFFD: 0x3590,
	0xFFFD: 0x3591,
	0xFFFD: 0x3592,
	0xFFFD: 0x3593,
	0xFFFD: 0x3594,
	0xFFFD: 0x3595,
	0xFFFD: 0x3596,
	0xFFFD: 0x3597,
	0xFFFD: 0x3598,
	0xFFFD: 0x3599,
	0xFFFD: 0x359A,
	0xFFFD: 0x359B,
	0xFFFD: 0x359C,
	0xFFFD: 0x359D,
	0xFFFD: 0x359E,
	0xFFFD: 0x359F,
	0xFFFD: 0x35A0,
	0xFFFD: 0x35A1,
	0xFFFD: 0x35A2,
	0xFFFD: 0x35A3,
	0xFFFD: 0x35A4,
	0xFFFD: 0x35A5,
	0xFFFD: 0x35A6,
	0xFFFD: 0x35A7,
	0xFFFD: 0x35A8,
	0xFFFD: 0x35A9,
	0xFFFD: 0x35AA,
	0xFFFD: 0x35AB,
	0xFFFD: 0x35AC,
	0xFFFD: 0x35AD,
	0xFFFD: 0x35AE,
	0xFFFD: 0x35AF,
	0xFFFD: 0x35B0,
	0xFFFD: 0x35B1,
	0xFFFD: 0x35B2,
	0xFFFD: 0x35B3,
	0xFFFD: 0x35B4,
	0xFFFD: 0x35B5,
	0xFFFD: 0x35B6,
	0xFFFD: 0x35B7,
	0xFFFD: 0x35B8,
	0xFFFD: 0x35B9,
	0xFFFD: 0x35BA,
	0xFFFD: 0x35BB,
	0xFFFD: 0x35BC,
	0xFFFD: 0x35BD,
	0xFFFD: 0x35BE,
	0xFFFD: 0x35BF,
	0xFFFD: 0x35C0,
	0xFFFD: 0x35C1,
	0xFFFD: 0x35C2,
	0xFFFD: 0x35C3,
	0xFFFD: 0x35C4,
	0xFFFD: 0x35C5,
	0xFFFD: 0x35C6,
	0xFFFD: 0x35C7,
	0xFFFD: 0x35C8,
	0xFFFD: 0x35C9,
	0xFFFD: 0x35CA,
	0xFFFD: 0x35CB,
	0xFFFD: 0x35CC,
	0xFFFD: 0x35CD,
	0xA048: 0x35CE,
	0xFFFD: 0x35CF,
	0xFFFD: 0x35D0,
	0xFFFD: 0x35D1,
	0xA04C: 0x35D2,
	0xFFFD: 0x35D3,
	0xFFFD: 0x35D4,
	0xFFFD: 0x35D5,
	0xFBDF: 0x35D6,
	0xFFFD: 0x35D7,
	0xFFFD: 0x35D8,
	0xFFFD: 0x35D9,
	0xFFFD: 0x35DA,
	0xFFFD: 0x35DB,
	0xFFFD: 0x35DC,
	0xFFFD: 0x35DD,
	0xFFFD: 0x35DE,
	0xFFFD: 0x35DF,
	0xFFFD: 0x35E0,
	0xFFFD: 0x35E1,
	0xFFFD: 0x35E2,
	0xFFFD: 0x35E3,
	0xFFFD: 0x35E4,
	0xFFFD: 0x35E5,
	0xFFFD: 0x35E6,
	0xFFFD: 0x35E7,
	0xFFFD: 0x35E8,
	0xFFFD: 0x35E9,
	0xFFFD: 0x35EA,
	0xFFFD: 0x35EB,
	0xFFFD: 0x35EC,
	0xFFFD: 0x35ED,
	0xFFFD: 0x35EE,
	0xFFFD: 0x35EF,
	0xFFFD: 0x35F0,
	0xFFFD: 0x35F1,
	0xFFFD: 0x35F2,
	0xFBE5: 0x35F3,
	0xFFFD: 0x35F4,
	0xFFFD: 0x35F5,
	0xFFFD: 0x35F6,
	0xFFFD: 0x35F7,
	0xFFFD: 0x35F8,
	0xFFFD: 0x35F9,
	0xFFFD: 0x35FA,
	0xFFFD: 0x35FB,
	0xFFFD: 0x35FC,
	0xFFFD: 0x35FD,
	0xFB6F: 0x35FE,
	0xFFFD: 0x35FF,
	0xFFFD: 0x3600,
	0xFFFD: 0x3601,
	0xFFFD: 0x3602,
	0xFFFD: 0x3603,
	0xFFFD: 0x3604,
	0xFFFD: 0x3605,
	0xFFFD: 0x3606,
	0xFFFD: 0x3607,
	0xFFFD: 0x3608,
	0xFFFD: 0x3609,
	0xFFFD: 0x360A,
	0xFFFD: 0x360B,
	0xFFFD: 0x360C,
	0xFFFD: 0x360D,
	0xFFFD: 0x360E,
	0xFFFD: 0x360F,
	0xFFFD: 0x3610,
	0xFFFD: 0x3611,
	0xFFFD: 0x3612,
	0xFFFD: 0x3613,
	0xFFFD: 0x3614,
	0xFFFD: 0x3615,
	0xFFFD: 0x3616,
	0xFFFD: 0x3617,
	0xFFFD: 0x3618,
	0xFFFD: 0x3619,
	0xFFFD: 0x361A,
	0xFFFD: 0x361B,
	0xFFFD: 0x361C,
	0xFFFD: 0x361D,
	0xFFFD: 0x361E,
	0xFFFD: 0x361F,
	0xFFFD: 0x3620,
	0xFFFD: 0x3621,
	0xFFFD: 0x3622,
	0xFFFD: 0x3623,
	0xFFFD: 0x3624,
	0xFFFD: 0x3625,
	0xFFFD: 0x3626,
	0xFFFD: 0x3627,
	0xFFFD: 0x3628,
	0xFFFD: 0x3629,
	0xFFFD: 0x362A,
	0xFFFD: 0x362B,
	0xFFFD: 0x362C,
	0x9542: 0x362D,
	0xFFFD: 0x362E,
	0xFFFD: 0x362F,
	0xFFFD: 0x3630,
	0xFFFD: 0x3631,
	0xFFFD: 0x3632,
	0xFFFD: 0x3633,
	0xFFFD: 0x3634,
	0xFFFD: 0x3635,
	0xFFFD: 0x3636,
	0xFFFD: 0x3637,
	0xFFFD: 0x3638,
	0xFFFD: 0x3639,
	0xFFFD: 0x363A,
	0xFFFD: 0x363B,
	0xFFFD: 0x363C,
	0xFFFD: 0x363D,
	0xFFFD: 0x363E,
	0xFFFD: 0x363F,
	0xFFFD: 0x3640,
	0xFFFD: 0x3641,
	0xFFFD: 0x3642,
	0xFFFD: 0x3643,
	0xFFFD: 0x3644,
	0xFFFD: 0x3645,
	0xFFFD: 0x3646,
	0xFFFD: 0x3647,
	0xFFFD: 0x3648,
	0xFFFD: 0x3649,
	0xFFFD: 0x364A,
	0xFFFD: 0x364B,
	0xFFFD: 0x364C,
	0xFFFD: 0x364D,
	0xFFFD: 0x364E,
	0xFFFD: 0x364F,
	0xFFFD: 0x3650,
	0xFFFD: 0x3651,
	0xFFFD: 0x3652,
	0xFFFD: 0x3653,
	0xFE7D: 0x3654,
	0xFFFD: 0x3655,
	0xFFFD: 0x3656,
	0xFFFD: 0x3657,
	0xFFFD: 0x3658,
	0xFFFD: 0x3659,
	0xFFFD: 0x365A,
	0xFFFD: 0x365B,
	0xFFFD: 0x365C,
	0xFFFD: 0x365D,
	0xFFFD: 0x365E,
	0xFFFD: 0x365F,
	0xFFFD: 0x3660,
	0xFFFD: 0x3661,
	0xFFFD: 0x3662,
	0xFFFD: 0x3663,
	0xFFFD: 0x3664,
	0xFFFD: 0x3665,
	0xFFFD: 0x3666,
	0xFFFD: 0x3667,
	0xFFFD: 0x3668,
	0xFFFD: 0x3669,
	0xFFFD: 0x366A,
	0xFFFD: 0x366B,
	0xFFFD: 0x366C,
	0xFFFD: 0x366D,
	0xFFFD: 0x366E,
	0xFFFD: 0x366F,
	0xFFFD: 0x3670,
	0xFFFD: 0x3671,
	0xFFFD: 0x3672,
	0xFFFD: 0x3673,
	0xFFFD: 0x3674,
	0xFFFD: 0x3675,
	0xFFFD: 0x3676,
	0xFFFD: 0x3677,
	0xFFFD: 0x3678,
	0xFFFD: 0x3679,
	0xFFFD: 0x367A,
	0xFFFD: 0x367B,
	0xFFFD: 0x367C,
	0xFFFD: 0x367D,
	0xFFFD: 0x367E,
	0xFFFD: 0x367F,
	0xFFFD: 0x3680,
	0xFFFD: 0x3681,
	0xFFFD: 0x3682,
	0xFFFD: 0x3683,
	0xFFFD: 0x3684,
	0xFFFD: 0x3685,
	0xFFFD: 0x3686,
	0xFFFD: 0x3687,
	0xFFFD: 0x3688,
	0xFFFD: 0x3689,
	0xFFFD: 0x368A,
	0xFFFD: 0x368B,
	0xFFFD: 0x368C,
	0xFFFD: 0x368D,
	0xFFFD: 0x368E,
	0xFFFD: 0x368F,
	0xFFFD: 0x3690,
	0xFFFD: 0x3691,
	0xFFFD: 0x3692,
	0xFFFD: 0x3693,
	0xFFFD: 0x3694,
	0xFFFD: 0x3695,
	0xFFFD: 0x3696,
	0xFFFD: 0x3697,
	0xFFFD: 0x3698,
	0xFFFD: 0x3699,
	0xFFFD: 0x369A,
	0xFFFD: 0x369B,
	0xFFFD: 0x369C,
	0xFFFD: 0x369D,
	0xFFFD: 0x369E,
	0xFFFD: 0x369F,
	0xFFFD: 0x36A0,
	0xFFFD: 0x36A1,
	0xFFFD: 0x36A2,
	0xFFFD: 0x36A3,
	0xFFFD: 0x36A4,
	0xFFFD: 0x36A5,
	0xFFFD: 0x36A6,
	0xFFFD: 0x36A7,
	0xFFFD: 0x36A8,
	0xFFFD: 0x36A9,
	0xFFFD: 0x36AA,
	0xFFFD: 0x36AB,
	0xFFFD: 0x36AC,
	0xFFFD: 0x36AD,
	0xFFFD: 0x36AE,
	0xFFFD: 0x36AF,
	0xFFFD: 0x36B0,
	0xFFFD: 0x36B1,
	0xFFFD: 0x36B2,
	0xFFFD: 0x36B3,
	0xFFFD: 0x36B4,
	0xFFFD: 0x36B5,
	0xFFFD: 0x36B6,
	0xFFFD: 0x36B7,
	0xFFFD: 0x36B8,
	0xFFFD: 0x36B9,
	0xFFFD: 0x36BA,
	0xFFFD: 0x36BB,
	0xFFFD: 0x36BC,
	0xFFFD: 0x36BD,
	0xFFFD: 0x36BE,
	0xFFFD: 0x36BF,
	0xFFFD: 0x36C0,
	0xFFFD: 0x36C1,
	0xFFFD: 0x36C2,
	0xFFFD: 0x36C3,
	0xFFFD: 0x36C4,
	0xFFFD: 0x36C5,
	0xFFFD: 0x36C6,
	0xFE67: 0x36C7,
	0xFFFD: 0x36C8,
	0xFFFD: 0x36C9,
	0xFFFD: 0x36CA,
	0xFFFD: 0x36CB,
	0xFFFD: 0x36CC,
	0xFFFD: 0x36CD,
	0xFFFD: 0x36CE,
	0xFFFD: 0x36CF,
	0xFFFD: 0x36D0,
	0xFFFD: 0x36D1,
	0xFFFD: 0x36D2,
	0xFFFD: 0x36D3,
	0xFFFD: 0x36D4,
	0xFFFD: 0x36D5,
	0xFFFD: 0x36D6,
	0xFFFD: 0x36D7,
	0xFFFD: 0x36D8,
	0xFFFD: 0x36D9,
	0xFFFD: 0x36DA,
	0xFFFD: 0x36DB,
	0xFFFD: 0x36DC,
	0xFFFD: 0x36DD,
	0xFFFD: 0x36DE,
	0xFFFD: 0x36DF,
	0xFFFD: 0x36E0,
	0xFFFD: 0x36E1,
	0xFFFD: 0x36E2,
	0xFFFD: 0x36E3,
	0xFFFD: 0x36E4,
	0xFFFD: 0x36E5,
	0xFFFD: 0x36E6,
	0xFFFD: 0x36E7,
	0xFFFD: 0x36E8,
	0xFFFD: 0x36E9,
	0xFFFD: 0x36EA,
	0xFFFD: 0x36EB,
	0xFFFD: 0x36EC,
	0xFFFD: 0x36ED,
	0xFFFD: 0x36EE,
	0xFFFD: 0x36EF,
	0xFFFD: 0x36F0,
	0xFFFD: 0x36F1,
	0xFFFD: 0x36F2,
	0xFFFD: 0x36F3,
	0xFFFD: 0x36F4,
	0xFFFD: 0x36F5,
	0xFFFD: 0x36F6,
	0xFFFD: 0x36F7,
	0xFFFD: 0x36F8,
	0xFFFD: 0x36F9,
	0xFFFD: 0x36FA,
	0xFFFD: 0x36FB,
	0xFFFD: 0x36FC,
	0xFFFD: 0x36FD,
	0xFFFD: 0x36FE,
	0xFFFD: 0x36FF,
	0xFFFD: 0x3700,
	0xFFFD: 0x3701,
	0xFFFD: 0x3702,
	0xFFFD: 0x3703,
	0xFFFD: 0x3704,
	0xFFFD: 0x3705,
	0xFFFD: 0x3706,
	0xFFFD: 0x3707,
	0xFFFD: 0x3708,
	0xFFFD: 0x3709,
	0xFFFD: 0x370A,
	0xFFFD: 0x370B,
	0xFFFD: 0x370C,
	0xFFFD: 0x370D,
	0xFFFD: 0x370E,
	0xFFFD: 0x370F,
	0xFFFD: 0x3710,
	0xFFFD: 0x3711,
	0xFFFD: 0x3712,
	0xFFFD: 0x3713,
	0xFFFD: 0x3714,
	0xFFFD: 0x3715,
	0xFFFD: 0x3716,
	0xFFFD: 0x3717,
	0xFFFD: 0x3718,
	0xFFFD: 0x3719,
	0xFFFD: 0x371A,
	0xFFFD: 0x371B,
	0xFFFD: 0x371C,
	0xFFFD: 0x371D,
	0xFFFD: 0x371E,
	0xFFFD: 0x371F,
	0xFFFD: 0x3720,
	0xFFFD: 0x3721,
	0xFFFD: 0x3722,
	0xFFFD: 0x3723,
	0xFFFD: 0x3724,
	0xFFFD: 0x3725,
	0xFFFD: 0x3726,
	0xFFFD: 0x3727,
	0xFFFD: 0x3728,
	0xFFFD: 0x3729,
	0xFFFD: 0x372A,
	0xFFFD: 0x372B,
	0xFFFD: 0x372C,
	0xFFFD: 0x372D,
	0xFFFD: 0x372E,
	0xFFFD: 0x372F,
	0xFFFD: 0x3730,
	0xFFFD: 0x3731,
	0xFFFD: 0x3732,
	0xFFFD: 0x3733,
	0xFFFD: 0x3734,
	0xFFFD: 0x3735,
	0xFFFD: 0x3736,
	0xFFFD: 0x3737,
	0xFFFD: 0x3738,
	0xFFFD: 0x3739,
	0xFFFD: 0x373A,
	0xFFFD: 0x373B,
	0xFFFD: 0x373C,
	0xFFFD: 0x373D,
	0xFFFD: 0x373E,
	0xFFFD: 0x373F,
	0xFFFD: 0x3740,
	0xFFFD: 0x3741,
	0xFFFD: 0x3742,
	0xFFFD: 0x3743,
	0xFFFD: 0x3744,
	0xFFFD: 0x3745,
	0xFFFD: 0x3746,
	0xFFFD: 0x3747,
	0xFFFD: 0x3748,
	0xFFFD: 0x3749,
	0xFFFD: 0x374A,
	0xFFFD: 0x374B,
	0xFFFD: 0x374C,
	0xFFFD: 0x374D,
	0xFFFD: 0x374E,
	0xFFFD: 0x374F,
	0xFFFD: 0x3750,
	0xFFFD: 0x3751,
	0xFFFD: 0x3752,
	0xFFFD: 0x3753,
	0xFFFD: 0x3754,
	0xFFFD: 0x3755,
	0xFFFD: 0x3756,
	0xFFFD: 0x3757,
	0xFFFD: 0x3758,
	0xFFFD: 0x3759,
	0xFFFD: 0x375A,
	0xFFFD: 0x375B,
	0xFFFD: 0x375C,
	0xFFFD: 0x375D,
	0xFFFD: 0x375E,
	0xFFFD: 0x375F,
	0xFFFD: 0x3760,
	0xFFFD: 0x3761,
	0xFFFD: 0x3762,
	0xFFFD: 0x3763,
	0xFFFD: 0x3764,
	0xFFFD: 0x3765,
	0xFFFD: 0x3766,
	0xFFFD: 0x3767,
	0xFFFD: 0x3768,
	0xFFFD: 0x3769,
	0xFFFD: 0x376A,
	0xFFFD: 0x376B,
	0xFFFD: 0x376C,
	0xFFFD: 0x376D,
	0xFFFD: 0x376E,
	0xFFFD: 0x376F,
	0xFFFD: 0x3770,
	0xFFFD: 0x3771,
	0xFFFD: 0x3772,
	0xFFFD: 0x3773,
	0xFFFD: 0x3774,
	0xFFFD: 0x3775,
	0xFFFD: 0x3776,
	0xFFFD: 0x3777,
	0xFFFD: 0x3778,
	0xFFFD: 0x3779,
	0xFFFD: 0x377A,
	0xFFFD: 0x377B,
	0xFFFD: 0x377C,
	0xFFFD: 0x377D,
	0xFFFD: 0x377E,
	0xFFFD: 0x377F,
	0xFFFD: 0x3780,
	0xFFFD: 0x3781,
	0xFFFD: 0x3782,
	0xFFFD: 0x3783,
	0xFFFD: 0x3784,
	0xFFFD: 0x3785,
	0xFFFD: 0x3786,
	0xFFFD: 0x3787,
	0xFFFD: 0x3788,
	0xFFFD: 0x3789,
	0xFFFD: 0x378A,
	0xFFFD: 0x378B,
	0xFFFD: 0x378C,
	0xFFFD: 0x378D,
	0xFFFD: 0x378E,
	0xFFFD: 0x378F,
	0xFFFD: 0x3790,
	0xFFFD: 0x3791,
	0xFFFD: 0x3792,
	0xFFFD: 0x3793,
	0xFFFD: 0x3794,
	0xFFFD: 0x3795,
	0xFFFD: 0x3796,
	0xFFFD: 0x3797,
	0xFFFD: 0x3798,
	0xFFFD: 0x3799,
	0xFFFD: 0x379A,
	0xFFFD: 0x379B,
	0xFFFD: 0x379C,
	0xFFFD: 0x379D,
	0xFFFD: 0x379E,
	0xFFFD: 0x379F,
	0xFFFD: 0x37A0,
	0xFFFD: 0x37A1,
	0xFFFD: 0x37A2,
	0xFFFD: 0x37A3,
	0xFFFD: 0x37A4,
	0xFFFD: 0x37A5,
	0xFFFD: 0x37A6,
	0xFFFD: 0x37A7,
	0xFFFD: 0x37A8,
	0xFFFD: 0x37A9,
	0xFFFD: 0x37AA,
	0xFFFD: 0x37AB,
	0xFFFD: 0x37AC,
	0xFFFD: 0x37AD,
	0xFFFD: 0x37AE,
	0xFFFD: 0x37AF,
	0xFFFD: 0x37B0,
	0xFFFD: 0x37B1,
	0xFFFD: 0x37B2,
	0xFFFD: 0x37B3,
	0xFFFD: 0x37B4,
	0xFFFD: 0x37B5,
	0xFFFD: 0x37B6,
	0xFFFD: 0x37B7,
	0xFFFD: 0x37B8,
	0xFFFD: 0x37B9,
	0xFFFD: 0x37BA,
	0xFFFD: 0x37BB,
	0xFFFD: 0x37BC,
	0xFFFD: 0x37BD,
	0xFFFD: 0x37BE,
	0xFFFD: 0x37BF,
	0xFFFD: 0x37C0,
	0xFFFD: 0x37C1,
	0xFFFD: 0x37C2,
	0xFFFD: 0x37C3,
	0xFFFD: 0x37C4,
	0xFFFD: 0x37C5,
	0xFFFD: 0x37C6,
	0xFFFD: 0x37C7,
	0xFFFD: 0x37C8,
	0xFFFD: 0x37C9,
	0xFFFD: 0x37CA,
	0xFFFD: 0x37CB,
	0xFFFD: 0x37CC,
	0xFFFD: 0x37CD,
	0xFFFD: 0x37CE,
	0xFFFD: 0x37CF,
	0xFFFD: 0x37D0,
	0xFFFD: 0x37D1,
	0xFFFD: 0x37D2,
	0xFFFD: 0x37D3,
	0xFFFD: 0x37D4,
	0xFFFD: 0x37D5,
	0xFFFD: 0x37D6,
	0xFFFD: 0x37D7,
	0xFFFD: 0x37D8,
	0xFFFD: 0x37D9,
	0xFFFD: 0x37DA,
	0xFFFD: 0x37DB,
	0xFFFD: 0x37DC,
	0xFFFD: 0x37DD,
	0xFFFD: 0x37DE,
	0xFFFD: 0x37DF,
	0xFFFD: 0x37E0,
	0xFFFD: 0x37E1,
	0xFFFD: 0x37E2,
	0xFFFD: 0x37E3,
	0xFFFD: 0x37E4,
	0xFFFD: 0x37E5,
	0xFFFD: 0x37E6,
	0xFFFD: 0x37E7,
	0xFFFD: 0x37E8,
	0xFFFD: 0x37E9,
	0xFFFD: 0x37EA,
	0xFFFD: 0x37EB,
	0xFFFD: 0x37EC,
	0xFFFD: 0x37ED,
	0xFFFD: 0x37EE,
	0xFFFD: 0x37EF,
	0xFFFD: 0x37F0,
	0xFFFD: 0x37F1,
	0xFFFD: 0x37F2,
	0xFFFD: 0x37F3,
	0xFFFD: 0x37F4,
	0xFFFD: 0x37F5,
	0xFFFD: 0x37F6,
	0xFFFD: 0x37F7,
	0xFFFD: 0x37F8,
	0xFFFD: 0x37F9,
	0xFFFD: 0x37FA,
	0xFFFD: 0x37FB,
	0xFFFD: 0x37FC,
	0xFFFD: 0x37FD,
	0xFFFD: 0x37FE,
	0xFFFD: 0x37FF,
	0xFFFD: 0x3800,
	0xFFFD: 0x3801,
	0xFFFD: 0x3802,
	0xFFFD: 0x3803,
	0xFFFD: 0x3804,
	0xFFFD: 0x3805,
	0xFFFD: 0x3806,
	0xFFFD: 0x3807,
	0xFFFD: 0x3808,
	0xFFFD: 0x3809,
	0xFFFD: 0x380A,
	0xFFFD: 0x380B,
	0xFFFD: 0x380C,
	0xFFFD: 0x380D,
	0xFFFD: 0x380E,
	0xFFFD: 0x380F,
	0xFFFD: 0x3810,
	0xFFFD: 0x3811,
	0xFFFD: 0x3812,
	0xFFFD: 0x3813,
	0xFFFD: 0x3814,
	0xFFFD: 0x3815,
	0xFFFD: 0x3816,
	0xFFFD: 0x3817,
	0xFFFD: 0x3818,
	0xFFFD: 0x3819,
	0xFFFD: 0x381A,
	0xFFFD: 0x381B,
	0xFFFD: 0x381C,
	0xFFFD: 0x381D,
	0xFFFD: 0x381E,
	0xFFFD: 0x381F,
	0xFFFD: 0x3820,
	0xFFFD: 0x3821,
	0xFFFD: 0x3822,
	0xFFFD: 0x3823,
	0xFFFD: 0x3824,
	0xFFFD: 0x3825,
	0xFFFD: 0x3826,
	0xFFFD: 0x3827,
	0xFFFD: 0x3828,
	0xFFFD: 0x3829,
	0xFFFD: 0x382A,
	0xFFFD: 0x382B,
	0xFFFD: 0x382C,
	0xFFFD: 0x382D,
	0xFFFD: 0x382E,
	0xFFFD: 0x382F,
	0xFFFD: 0x3830,
	0xFFFD: 0x3831,
	0xFFFD: 0x3832,
	0xFFFD: 0x3833,
	0xFFFD: 0x3834,
	0xFFFD: 0x3835,
	0xFFFD: 0x3836,
	0xFFFD: 0x3837,
	0xFFFD: 0x3838,
	0xFFFD: 0x3839,
	0xFFFD: 0x383A,
	0xFFFD: 0x383B,
	0xFFFD: 0x383C,
	0xFFFD: 0x383D,
	0xFFFD: 0x383E,
	0xFFFD: 0x383F,
	0xFFFD: 0x3840,
	0xFFFD: 0x3841,
	0xFFFD: 0x3842,
	0xFFFD: 0x3843,
	0xFFFD: 0x3844,
	0xFFFD: 0x3845,
	0xFFFD: 0x3846,
	0xFFFD: 0x3847,
	0xFFFD: 0x3848,
	0xFFFD: 0x3849,
	0xFFFD: 0x384A,
	0xFFFD: 0x384B,
	0xFFFD: 0x384C,
	0xFFFD: 0x384D,
	0xFFFD: 0x384E,
	0xFFFD: 0x384F,
	0xFFFD: 0x3850,
	0xFFFD: 0x3851,
	0xFFFD: 0x3852,
	0xFFFD: 0x3853,
	0xFFFD: 0x3854,
	0xFFFD: 0x3855,
	0xFFFD: 0x3856,
	0xFFFD: 0x3857,
	0xFFFD: 0x3858,
	0xFFFD: 0x3859,
	0xFFFD: 0x385A,
	0xFFFD: 0x385B,
	0xFFFD: 0x385C,
	0xFFFD: 0x385D,
	0xFFFD: 0x385E,
	0xFFFD: 0x385F,
	0xFFFD: 0x3860,
	0xFFFD: 0x3861,
	0xFFFD: 0x3862,
	0xFFFD: 0x3863,
	0xFFFD: 0x3864,
	0xFFFD: 0x3865,
	0xFFFD: 0x3866,
	0xFFFD: 0x3867,
	0xFFFD: 0x3868,
	0xFFFD: 0x3869,
	0xFFFD: 0x386A,
	0xFFFD: 0x386B,
	0xFFFD: 0x386C,
	0xFFFD: 0x386D,
	0xFFFD: 0x386E,
	0xFFFD: 0x386F,
	0xFFFD: 0x3870,
	0xFFFD: 0x3871,
	0xFFFD: 0x3872,
	0xFFFD: 0x3873,
	0xFFFD: 0x3874,
	0xFFFD: 0x3875,
	0xFFFD: 0x3876,
	0xFFFD: 0x3877,
	0xFFFD: 0x3878,
	0xFFFD: 0x3879,
	0xFFFD: 0x387A,
	0xFFFD: 0x387B,
	0xFFFD: 0x387C,
	0xFFFD: 0x387D,
	0xFFFD: 0x387E,
	0xFFFD: 0x387F,
	0xFFFD: 0x3880,
	0xFFFD: 0x3881,
	0xFFFD: 0x3882,
	0xFFFD: 0x3883,
	0xFFFD: 0x3884,
	0xFFFD: 0x3885,
	0xFFFD: 0x3886,
	0xFFFD: 0x3887,
	0xFFFD: 0x3888,
	0xFFFD: 0x3889,
	0xFFFD: 0x388A,
	0xFFFD: 0x388B,
	0xFFFD: 0x388C,
	0xFFFD: 0x388D,
	0xFFFD: 0x388E,
	0xFFFD: 0x388F,
	0xFFFD: 0x3890,
	0xFFFD: 0x3891,
	0xFFFD: 0x3892,
	0xFFFD: 0x3893,
	0xFFFD: 0x3894,
	0xFFFD: 0x3895,
	0xFFFD: 0x3896,
	0xFFFD: 0x3897,
	0xFFFD: 0x3898,
	0xFFFD: 0x3899,
	0xFFFD: 0x389A,
	0xFFFD: 0x389B,
	0xFFFD: 0x389C,
	0xFFFD: 0x389D,
	0xFFFD: 0x389E,
	0xFFFD: 0x389F,
	0xFFFD: 0x38A0,
	0xFFFD: 0x38A1,
	0xFFFD: 0x38A2,
	0xFFFD: 0x38A3,
	0xFFFD: 0x38A4,
	0xFFFD: 0x38A5,
	0xFFFD: 0x38A6,
	0xFFFD: 0x38A7,
	0xFFFD: 0x38A8,
	0xFFFD: 0x38A9,
	0xFFFD: 0x38AA,
	0xFFFD: 0x38AB,
	0xFFFD: 0x38AC,
	0xFFFD: 0x38AD,
	0xFFFD: 0x38AE,
	0xFFFD: 0x38AF,
	0xFFFD: 0x38B0,
	0xFFFD: 0x38B1,
	0xFFFD: 0x38B2,
	0xFFFD: 0x38B3,
	0xFFFD: 0x38B4,
	0xFFFD: 0x38B5,
	0xFFFD: 0x38B6,
	0xFFFD: 0x38B7,
	0xFFFD: 0x38B8,
	0xFFFD: 0x38B9,
	0xFFFD: 0x38BA,
	0xFFFD: 0x38BB,
	0xFFFD: 0x38BC,
	0xFFFD: 0x38BD,
	0xFFFD: 0x38BE,
	0xFFFD: 0x38BF,
	0xFFFD: 0x38C0,
	0xFFFD: 0x38C1,
	0xFFFD: 0x38C2,
	0xFFFD: 0x38C3,
	0xFFFD: 0x38C4,
	0xFFFD: 0x38C5,
	0xFFFD: 0x38C6,
	0xFFFD: 0x38C7,
	0xFFFD: 0x38C8,
	0xFFFD: 0x38C9,
	0xFFFD: 0x38CA,
	0xFFFD: 0x38CB,
	0xFFFD: 0x38CC,
	0xFFFD: 0x38CD,
	0xFFFD: 0x38CE,
	0xFFFD: 0x38CF,
	0xFFFD: 0x38D0,
	0xFFFD: 0x38D1,
	0xFFFD: 0x38D2,
	0xFFFD: 0x38D3,
	0xFFFD: 0x38D4,
	0xFFFD: 0x38D5,
	0xFFFD: 0x38D6,
	0xFFFD: 0x38D7,
	0xFFFD: 0x38D8,
	0xFFFD: 0x38D9,
	0xFFFD: 0x38DA,
	0xFFFD: 0x38DB,
	0xFFFD: 0x38DC,
	0xFFFD: 0x38DD,
	0xFFFD: 0x38DE,
	0xFFFD: 0x38DF,
	0xFFFD: 0x38E0,
	0xFFFD: 0x38E1,
	0xFFFD: 0x38E2,
	0xFFFD: 0x38E3,
	0xFFFD: 0x38E4,
	0xFFFD: 0x38E5,
	0xFFFD: 0x38E6,
	0xFFFD: 0x38E7,
	0xFFFD: 0x38E8,
	0xFFFD: 0x38E9,
	0xFFFD: 0x38EA,
	0xFFFD: 0x38EB,
	0xFFFD: 0x38EC,
	0xFFFD: 0x38ED,
	0xFFFD: 0x38EE,
	0xFFFD: 0x38EF,
	0xFFFD: 0x38F0,
	0xFFFD: 0x38F1,
	0xFFFD: 0x38F2,
	0xFFFD: 0x38F3,
	0xFFFD: 0x38F4,
	0xFFFD: 0x38F5,
	0xFFFD: 0x38F6,
	0xFFFD: 0x38F7,
	0xFFFD: 0x38F8,
	0xFFFD: 0x38F9,
	0xFFFD: 0x38FA,
	0xFFFD: 0x38FB,
	0xFFFD: 0x38FC,
	0xFFFD: 0x38FD,
	0xFFFD: 0x38FE,
	0xFFFD: 0x38FF,
	0xFFFD: 0x3900,
	0xFFFD: 0x3901,
	0xFFFD: 0x3902,
	0xFFFD: 0x3903,
	0xFFFD: 0x3904,
	0xFFFD: 0x3905,
	0xFFFD: 0x3906,
	0xFFFD: 0x3907,
	0xFFFD: 0x3908,
	0xFFFD: 0x3909,
	0xFFFD: 0x390A,
	0xFFFD: 0x390B,
	0xFFFD: 0x390C,
	0xFFFD: 0x390D,
	0xFFFD: 0x390E,
	0xFFFD: 0x390F,
	0xFFFD: 0x3910,
	0xFFFD: 0x3911,
	0xFFFD: 0x3912,
	0xFFFD: 0x3913,
	0xFFFD: 0x3914,
	0xFFFD: 0x3915,
	0xFFFD: 0x3916,
	0xFFFD: 0x3917,
	0xFFFD: 0x3918,
	0xFFFD: 0x3919,
	0xFFFD: 0x391A,
	0xFFFD: 0x391B,
	0xFFFD: 0x391C,
	0xFFFD: 0x391D,
	0xFFFD: 0x391E,
	0xFFFD: 0x391F,
	0xFFFD: 0x3920,
	0xFFFD: 0x3921,
	0xFFFD: 0x3922,
	0xFFFD: 0x3923,
	0xFFFD: 0x3924,
	0xFFFD: 0x3925,
	0xFFFD: 0x3926,
	0xFFFD: 0x3927,
	0xFFFD: 0x3928,
	0xFFFD: 0x3929,
	0xFFFD: 0x392A,
	0xFFFD: 0x392B,
	0xFFFD: 0x392C,
	0xFFFD: 0x392D,
	0xFFFD: 0x392E,
	0xFFFD: 0x392F,
	0xFFFD: 0x3930,
	0xFFFD: 0x3931,
	0xFFFD: 0x3932,
	0xFFFD: 0x3933,
	0xFFFD: 0x3934,
	0xFFFD: 0x3935,
	0xFFFD: 0x3936,
	0xFFFD: 0x3937,
	0xFFFD: 0x3938,
	0xFFFD: 0x3939,
	0xFFFD: 0x393A,
	0xFFFD: 0x393B,
	0xFFFD: 0x393C,
	0xFFFD: 0x393D,
	0xFFFD: 0x393E,
	0xFFFD: 0x393F,
	0xFFFD: 0x3940,
	0xFFFD: 0x3941,
	0xFFFD: 0x3942,
	0xFFFD: 0x3943,
	0xFFFD: 0x3944,
	0xFFFD: 0x3945,
	0xFFFD: 0x3946,
	0xFFFD: 0x3947,
	0xFFFD: 0x3948,
	0xFFFD: 0x3949,
	0xFFFD: 0x394A,
	0xFFFD: 0x394B,
	0xFFFD: 0x394C,
	0xFFFD: 0x394D,
	0xFFFD: 0x394E,
	0xFFFD: 0x394F,
	0xFFFD: 0x3950,
	0xFFFD: 0x3951,
	0xFFFD: 0x3952,
	0xFFFD: 0x3953,
	0xFFFD: 0x3954,
	0xFFFD: 0x3955,
	0xFFFD: 0x3956,
	0xFFFD: 0x3957,
	0xFFFD: 0x3958,
	0xFFFD: 0x3959,
	0xFFFD: 0x395A,
	0xFFFD: 0x395B,
	0xFFFD: 0x395C,
	0xFFFD: 0x395D,
	0xFFFD: 0x395E,
	0xFFFD: 0x395F,
	0xFFFD: 0x3960,
	0xFFFD: 0x3961,
	0xFFFD: 0x3962,
	0xFFFD: 0x3963,
	0xFFFD: 0x3964,
	0xFFFD: 0x3965,
	0xFFFD: 0x3966,
	0xFFFD: 0x3967,
	0xFFFD: 0x3968,
	0xFFFD: 0x3969,
	0xFFFD: 0x396A,
	0xFFFD: 0x396B,
	0xFFFD: 0x396C,
	0xFFFD: 0x396D,
	0xFFFD: 0x396E,
	0xFFFD: 0x396F,
	0xFFFD: 0x3970,
	0xFFFD: 0x3971,
	0xFFFD: 0x3972,
	0xFFFD: 0x3973,
	0xFFFD: 0x3974,
	0xFFFD: 0x3975,
	0xFFFD: 0x3976,
	0xFFFD: 0x3977,
	0xFFFD: 0x3978,
	0xFFFD: 0x3979,
	0xFFFD: 0x397A,
	0xFFFD: 0x397B,
	0xFFFD: 0x397C,
	0xFFFD: 0x397D,
	0xFFFD: 0x397E,
	0xFFFD: 0x397F,
	0xFFFD: 0x3980,
	0xFFFD: 0x3981,
	0xFFFD: 0x3982,
	0xFFFD: 0x3983,
	0xFFFD: 0x3984,
	0xFFFD: 0x3985,
	0xFFFD: 0x3986,
	0xFFFD: 0x3987,
	0xFFFD: 0x3988,
	0xFFFD: 0x3989,
	0xFFFD: 0x398A,
	0xFFFD: 0x398B,
	0xFFFD: 0x398C,
	0xFFFD: 0x398D,
	0xFFFD: 0x398E,
	0xFFFD: 0x398F,
	0xFFFD: 0x3990,
	0xFFFD: 0x3991,
	0xFFFD: 0x3992,
	0xFFFD: 0x3993,
	0xFFFD: 0x3994,
	0xFFFD: 0x3995,
	0xFFFD: 0x3996,
	0xFFFD: 0x3997,
	0xFFFD: 0x3998,
	0xFFFD: 0x3999,
	0xFFFD: 0x399A,
	0xFFFD: 0x399B,
	0xFFFD: 0x399C,
	0xFFFD: 0x399D,
	0xFFFD: 0x399E,
	0xFFFD: 0x399F,
	0xFFFD: 0x39A0,
	0xFFFD: 0x39A1,
	0xFFFD: 0x39A2,
	0xFFFD: 0x39A3,
	0xFFFD: 0x39A4,
	0xFFFD: 0x39A5,
	0xFFFD: 0x39A6,
	0xFFFD: 0x39A7,
	0xFFFD: 0x39A8,
	0xFFFD: 0x39A9,
	0xFFFD: 0x39AA,
	0xFFFD: 0x39AB,
	0xFFFD: 0x39AC,
	0xFFFD: 0x39AD,
	0xFFFD: 0x39AE,
	0xFFFD: 0x39AF,
	0xFFFD: 0x39B0,
	0xFFFD: 0x39B1,
	0xFFFD: 0x39B2,
	0xFFFD: 0x39B3,
	0xFFFD: 0x39B4,
	0xFFFD: 0x39B5,
	0xFFFD: 0x39B6,
	0xFFFD: 0x39B7,
	0x955E: 0x39B8,
	0xFFFD: 0x39B9,
	0xFFFD: 0x39BA,
	0xFFFD: 0x39BB,
	0xFFFD: 0x39BC,
	0xFFFD: 0x39BD,
	0xFFFD: 0x39BE,
	0xFFFD: 0x39BF,
	0xFFFD: 0x39C0,
	0xFFFD: 0x39C1,
	0xFFFD: 0x39C2,
	0xFFFD: 0x39C3,
	0xFFFD: 0x39C4,
	0xFFFD: 0x39C5,
	0xFFFD: 0x39C6,
	0xFFFD: 0x39C7,
	0xFFFD: 0x39C8,
	0xFFFD: 0x39C9,
	0xFFFD: 0x39CA,
	0xFFFD: 0x39CB,
	0xFFFD: 0x39CC,
	0xFFFD: 0x39CD,
	0xFFFD: 0x39CE,
	0xFFFD: 0x39CF,
	0xFFFD: 0x39D0,
	0xFFFD: 0x39D1,
	0xFFFD: 0x39D2,
	0xFFFD: 0x39D3,
	0xFFFD: 0x39D4,
	0xFFFD: 0x39D5,
	0xFFFD: 0x39D6,
	0xFFFD: 0x39D7,
	0xFFFD: 0x39D8,
	0xFFFD: 0x39D9,
	0xFFFD: 0x39DA,
	0xFFFD: 0x39DB,
	0xFFFD: 0x39DC,
	0xFFFD: 0x39DD,
	0xFFFD: 0x39DE,
	0xFFFD: 0x39DF,
	0xFFFD: 0x39E0,
	0xFFFD: 0x39E1,
	0xFFFD: 0x39E2,
	0xFFFD: 0x39E3,
	0xFFFD: 0x39E4,
	0xFFFD: 0x39E5,
	0xFFFD: 0x39E6,
	0xFFFD: 0x39E7,
	0xFFFD: 0x39E8,
	0xFFFD: 0x39E9,
	0xFFFD: 0x39EA,
	0xFFFD: 0x39EB,
	0xFFFD: 0x39EC,
	0xFFFD: 0x39ED,
	0xFFFD: 0x39EE,
	0xFFFD: 0x39EF,
	0xFFFD: 0x39F0,
	0xFFFD: 0x39F1,
	0xFFFD: 0x39F2,
	0xFFFD: 0x39F3,
	0xFFFD: 0x39F4,
	0xFFFD: 0x39F5,
	0xFFFD: 0x39F6,
	0xFFFD: 0x39F7,
	0xFFFD: 0x39F8,
	0xFFFD: 0x39F9,
	0xFFFD: 0x39FA,
	0xFFFD: 0x39FB,
	0xFFFD: 0x39FC,
	0xFFFD: 0x39FD,
	0xFFFD: 0x39FE,
	0xFFFD: 0x39FF,
	0xFFFD: 0x3A00,
	0xFFFD: 0x3A01,
	0xFFFD: 0x3A02,
	0xFFFD: 0x3A03,
	0xFFFD: 0x3A04,
	0xFFFD: 0x3A05,
	0xFFFD: 0x3A06,
	0xFFFD: 0x3A07,
	0xFFFD: 0x3A08,
	0xFFFD: 0x3A09,
	0xFFFD: 0x3A0A,
	0xFFFD: 0x3A0B,
	0xFFFD: 0x3A0C,
	0xFFFD: 0x3A0D,
	0xFFFD: 0x3A0E,
	0xFFFD: 0x3A0F,
	0xFFFD: 0x3A10,
	0xFFFD: 0x3A11,
	0xFFFD: 0x3A12,
	0xFFFD: 0x3A13,
	0xFFFD: 0x3A14,
	0xFFFD: 0x3A15,
	0xFFFD: 0x3A16,
	0xFFFD: 0x3A17,
	0xFFFD: 0x3A18,
	0xFFFD: 0x3A19,
	0xFFFD: 0x3A1A,
	0xFFFD: 0x3A1B,
	0xFFFD: 0x3A1C,
	0xFFFD: 0x3A1D,
	0xFFFD: 0x3A1E,
	0xFFFD: 0x3A1F,
	0xFFFD: 0x3A20,
	0xFFFD: 0x3A21,
	0xFFFD: 0x3A22,
	0xFFFD: 0x3A23,
	0xFFFD: 0x3A24,
	0xFFFD: 0x3A25,
	0xFFFD: 0x3A26,
	0xFFFD: 0x3A27,
	0xFFFD: 0x3A28,
	0xFFFD: 0x3A29,
	0x95DE: 0x3A2A,
	0xFFFD: 0x3A2B,
	0xFFFD: 0x3A2C,
	0xFFFD: 0x3A2D,
	0xFFFD: 0x3A2E,
	0xFFFD: 0x3A2F,
	0xFFFD: 0x3A30,
	0xFFFD: 0x3A31,
	0xFFFD: 0x3A32,
	0xFFFD: 0x3A33,
	0xFFFD: 0x3A34,
	0xFFFD: 0x3A35,
	0xFFFD: 0x3A36,
	0xFFFD: 0x3A37,
	0xFFFD: 0x3A38,
	0xFFFD: 0x3A39,
	0xFFFD: 0x3A3A,
	0xFFFD: 0x3A3B,
	0xFFFD: 0x3A3C,
	0xFFFD: 0x3A3D,
	0xFFFD: 0x3A3E,
	0xFFFD: 0x3A3F,
	0xFFFD: 0x3A40,
	0xFFFD: 0x3A41,
	0xFFFD: 0x3A42,
	0xFFFD: 0x3A43,
	0xFFFD: 0x3A44,
	0xFFFD: 0x3A45,
	0xFFFD: 0x3A46,
	0xFFFD: 0x3A47,
	0xFFFD: 0x3A48,
	0xFFFD: 0x3A49,
	0xFFFD: 0x3A4A,
	0xFFFD: 0x3A4B,
	0xFFFD: 0x3A4C,
	0xFFFD: 0x3A4D,
	0xFFFD: 0x3A4E,
	0xFFFD: 0x3A4F,
	0xFFFD: 0x3A50,
	0xFFFD: 0x3A51,
	0xFFFD: 0x3A52,
	0xFFFD: 0x3A53,
	0xFFFD: 0x3A54,
	0xFFFD: 0x3A55,
	0xFFFD: 0x3A56,
	0x95C7: 0x3A57,
	0xFFFD: 0x3A58,
	0xFFFD: 0x3A59,
	0xFFFD: 0x3A5A,
	0xFFFD: 0x3A5B,
	0xFC61: 0x3A5C,
	0xFFFD: 0x3A5D,
	0xFFFD: 0x3A5E,
	0xFFFD: 0x3A5F,
	0xFFFD: 0x3A60,
	0xFFFD: 0x3A61,
	0xFFFD: 0x3A62,
	0xFFFD: 0x3A63,
	0xFFFD: 0x3A64,
	0xFFFD: 0x3A65,
	0xFFFD: 0x3A66,
	0xFFFD: 0x3A67,
	0xFFFD: 0x3A68,
	0xFFFD: 0x3A69,
	0xFFFD: 0x3A6A,
	0xFFFD: 0x3A6B,
	0xFFFD: 0x3A6C,
	0xFFFD: 0x3A6D,
	0xFFFD: 0x3A6E,
	0xFFFD: 0x3A6F,
	0xFFFD: 0x3A70,
	0xFFFD: 0x3A71,
	0xFFFD: 0x3A72,
	0xFFFD: 0x3A73,
	0xFFFD: 0x3A74,
	0xFFFD: 0x3A75,
	0xFFFD: 0x3A76,
	0xFFFD: 0x3A77,
	0xFFFD: 0x3A78,
	0xFFFD: 0x3A79,
	0xFFFD: 0x3A7A,
	0xFFFD: 0x3A7B,
	0xFFFD: 0x3A7C,
	0xFFFD: 0x3A7D,
	0xFFFD: 0x3A7E,
	0xFFFD: 0x3A7F,
	0xFFFD: 0x3A80,
	0xFFFD: 0x3A81,
	0xFFFD: 0x3A82,
	0xFFFD: 0x3A83,
	0xFFFD: 0x3A84,
	0xFFFD: 0x3A85,
	0xFFFD: 0x3A86,
	0xFFFD: 0x3A87,
	0xFFFD: 0x3A88,
	0xFFFD: 0x3A89,
	0xFFFD: 0x3A8A,
	0xFFFD: 0x3A8B,
	0xFFFD: 0x3A8C,
	0xFFFD: 0x3A8D,
	0xFFFD: 0x3A8E,
	0xFFFD: 0x3A8F,
	0xFFFD: 0x3A90,
	0xFFFD: 0x3A91,
	0xFFFD: 0x3A92,
	0xFFFD: 0x3A93,
	0xFFFD: 0x3A94,
	0xFFFD: 0x3A95,
	0xFFFD: 0x3A96,
	0xFFFD: 0x3A97,
	0xFFFD: 0x3A98,
	0xFFFD: 0x3A99,
	0xFFFD: 0x3A9A,
	0xFFFD: 0x3A9B,
	0xFFFD: 0x3A9C,
	0xFFFD: 0x3A9D,
	0xFFFD: 0x3A9E,
	0xFFFD: 0x3A9F,
	0xFFFD: 0x3AA0,
	0xFFFD: 0x3AA1,
	0xFFFD: 0x3AA2,
	0xFFFD: 0x3AA3,
	0xFFFD: 0x3AA4,
	0xFFFD: 0x3AA5,
	0xFFFD: 0x3AA6,
	0xFFFD: 0x3AA7,
	0xFFFD: 0x3AA8,
	0xFFFD: 0x3AA9,
	0xFFFD: 0x3AAA,
	0xFFFD: 0x3AAB,
	0xFFFD: 0x3AAC,
	0xFFFD: 0x3AAD,
	0xFFFD: 0x3AAE,
	0xFFFD: 0x3AAF,
	0xFFFD: 0x3AB0,
	0xFFFD: 0x3AB1,
	0xFFFD: 0x3AB2,
	0xFFFD: 0x3AB3,
	0xFFFD: 0x3AB4,
	0xFFFD: 0x3AB5,
	0xFFFD: 0x3AB6,
	0xFFFD: 0x3AB7,
	0xFFFD: 0x3AB8,
	0xFFFD: 0x3AB9,
	0xFFFD: 0x3ABA,
	0xFFFD: 0x3ABB,
	0xFFFD: 0x3ABC,
	0xFFFD: 0x3ABD,
	0xFFFD: 0x3ABE,
	0xFFFD: 0x3ABF,
	0xFFFD: 0x3AC0,
	0xFFFD: 0x3AC1,
	0xFFFD: 0x3AC2,
	0xFFFD: 0x3AC3,
	0xFFFD: 0x3AC4,
	0xFFFD: 0x3AC5,
	0xFFFD: 0x3AC6,
	0xFFFD: 0x3AC7,
	0xFFFD: 0x3AC8,
	0xFFFD: 0x3AC9,
	0xFFFD: 0x3ACA,
	0xFFFD: 0x3ACB,
	0xFFFD: 0x3ACC,
	0xFFFD: 0x3ACD,
	0xFFFD: 0x3ACE,
	0xFFFD: 0x3ACF,
	0xFFFD: 0x3AD0,
	0xFFFD: 0x3AD1,
	0xFFFD: 0x3AD2,
	0xFFFD: 0x3AD3,
	0xFFFD: 0x3AD4,
	0xFFFD: 0x3AD5,
	0xFFFD: 0x3AD6,
	0xFFFD: 0x3AD7,
	0xFFFD: 0x3AD8,
	0xFFFD: 0x3AD9,
	0xFFFD: 0x3ADA,
	0xFFFD: 0x3ADB,
	0xFFFD: 0x3ADC,
	0xFFFD: 0x3ADD,
	0xFFFD: 0x3ADE,
	0xFFFD: 0x3ADF,
	0xFFFD: 0x3AE0,
	0xFFFD: 0x3AE1,
	0xFFFD: 0x3AE2,
	0xFFFD: 0x3AE3,
	0xFFFD: 0x3AE4,
	0xFFFD: 0x3AE5,
	0xFFFD: 0x3AE6,
	0xFFFD: 0x3AE7,
	0xFFFD: 0x3AE8,
	0xFFFD: 0x3AE9,
	0xFFFD: 0x3AEA,
	0xFFFD: 0x3AEB,
	0xFFFD: 0x3AEC,
	0xFFFD: 0x3AED,
	0xFFFD: 0x3AEE,
	0xFFFD: 0x3AEF,
	0xFFFD: 0x3AF0,
	0xFFFD: 0x3AF1,
	0xFFFD: 0x3AF2,
	0xFFFD: 0x3AF3,
	0xFFFD: 0x3AF4,
	0xFFFD: 0x3AF5,
	0xFFFD: 0x3AF6,
	0xFFFD: 0x3AF7,
	0xFFFD: 0x3AF8,
	0xFFFD: 0x3AF9,
	0xFFFD: 0x3AFA,
	0xFFFD: 0x3AFB,
	0xFFFD: 0x3AFC,
	0xFFFD: 0x3AFD,
	0xFFFD: 0x3AFE,
	0xFFFD: 0x3AFF,
	0xFFFD: 0x3B00,
	0xFFFD: 0x3B01,
	0xFFFD: 0x3B02,
	0xFFFD: 0x3B03,
	0xFFFD: 0x3B04,
	0xFFFD: 0x3B05,
	0xFFFD: 0x3B06,
	0xFFFD: 0x3B07,
	0xFFFD: 0x3B08,
	0xFFFD: 0x3B09,
	0xFFFD: 0x3B0A,
	0xFFFD: 0x3B0B,
	0xFFFD: 0x3B0C,
	0xFFFD: 0x3B0D,
	0xFFFD: 0x3B0E,
	0xFFFD: 0x3B0F,
	0xFFFD: 0x3B10,
	0xFFFD: 0x3B11,
	0xFFFD: 0x3B12,
	0xFFFD: 0x3B13,
	0xFFFD: 0x3B14,
	0xFFFD: 0x3B15,
	0xFFFD: 0x3B16,
	0xFFFD: 0x3B17,
	0xFFFD: 0x3B18,
	0xFFFD: 0x3B19,
	0xFFFD: 0x3B1A,
	0xFFFD: 0x3B1B,
	0xFFFD: 0x3B1C,
	0xFFFD: 0x3B1D,
	0xFFFD: 0x3B1E,
	0xFFFD: 0x3B1F,
	0xFFFD: 0x3B20,
	0xFFFD: 0x3B21,
	0xFFFD: 0x3B22,
	0xFFFD: 0x3B23,
	0xFFFD: 0x3B24,
	0xFFFD: 0x3B25,
	0xFFFD: 0x3B26,
	0xFFFD: 0x3B27,
	0xFFFD: 0x3B28,
	0xFFFD: 0x3B29,
	0xFFFD: 0x3B2A,
	0xFFFD: 0x3B2B,
	0xFFFD: 0x3B2C,
	0xFFFD: 0x3B2D,
	0xFFFD: 0x3B2E,
	0xFFFD: 0x3B2F,
	0xFFFD: 0x3B30,
	0xFFFD: 0x3B31,
	0xFFFD: 0x3B32,
	0xFFFD: 0x3B33,
	0xFFFD: 0x3B34,
	0xFFFD: 0x3B35,
	0xFFFD: 0x3B36,
	0xFFFD: 0x3B37,
	0xFFFD: 0x3B38,
	0xFFFD: 0x3B39,
	0xFFFD: 0x3B3A,
	0xFFFD: 0x3B3B,
	0xFFFD: 0x3B3C,
	0xFFFD: 0x3B3D,
	0xFFFD: 0x3B3E,
	0xFFFD: 0x3B3F,
	0xFFFD: 0x3B40,
	0xFFFD: 0x3B41,
	0xFFFD: 0x3B42,
	0xFFFD: 0x3B43,
	0xFFFD: 0x3B44,
	0xFFFD: 0x3B45,
	0xFFFD: 0x3B46,
	0xFFFD: 0x3B47,
	0xFFFD: 0x3B48,
	0xFFFD: 0x3B49,
	0xFFFD: 0x3B4A,
	0xFFFD: 0x3B4B,
	0xFFFD: 0x3B4C,
	0xFFFD: 0x3B4D,
	0xFFFD: 0x3B4E,
	0xFFFD: 0x3B4F,
	0xFFFD: 0x3B50,
	0xFFFD: 0x3B51,
	0xFFFD: 0x3B52,
	0xFFFD: 0x3B53,
	0xFFFD: 0x3B54,
	0xFFFD: 0x3B55,
	0xFFFD: 0x3B56,
	0xFFFD: 0x3B57,
	0xFFFD: 0x3B58,
	0xFFFD: 0x3B59,
	0xFFFD: 0x3B5A,
	0xFFFD: 0x3B5B,
	0xFFFD: 0x3B5C,
	0xFFFD: 0x3B5D,
	0xFFFD: 0x3B5E,
	0xFFFD: 0x3B5F,
	0xFFFD: 0x3B60,
	0xFFFD: 0x3B61,
	0xFFFD: 0x3B62,
	0xFFFD: 0x3B63,
	0xFFFD: 0x3B64,
	0xFFFD: 0x3B65,
	0xFFFD: 0x3B66,
	0xFFFD: 0x3B67,
	0xFFFD: 0x3B68,
	0xFFFD: 0x3B69,
	0xFFFD: 0x3B6A,
	0xFFFD: 0x3B6B,
	0xFFFD: 0x3B6C,
	0xFFFD: 0x3B6D,
	0xFFFD: 0x3B6E,
	0xFFFD: 0x3B6F,
	0xFFFD: 0x3B70,
	0xFFFD: 0x3B71,
	0xFFFD: 0x3B72,
	0xFFFD: 0x3B73,
	0xFFFD: 0x3B74,
	0xFFFD: 0x3B75,
	0xFFFD: 0x3B76,
	0xFFFD: 0x3B77,
	0xFFFD: 0x3B78,
	0xFFFD: 0x3B79,
	0xFFFD: 0x3B7A,
	0xFFFD: 0x3B7B,
	0xFFFD: 0x3B7C,
	0xFFFD: 0x3B7D,
	0xFFFD: 0x3B7E,
	0xFFFD: 0x3B7F,
	0xFFFD: 0x3B80,
	0xFFFD: 0x3B81,
	0xFFFD: 0x3B82,
	0xFFFD: 0x3B83,
	0xFFFD: 0x3B84,
	0xFFFD: 0x3B85,
	0xFFFD: 0x3B86,
	0xFFFD: 0x3B87,
	0xFFFD: 0x3B88,
	0xFFFD: 0x3B89,
	0xFFFD: 0x3B8A,
	0xFFFD: 0x3B8B,
	0xFFFD: 0x3B8C,
	0xFFFD: 0x3B8D,
	0xFFFD: 0x3B8E,
	0xFFFD: 0x3B8F,
	0xFFFD: 0x3B90,
	0xFFFD: 0x3B91,
	0xFFFD: 0x3B92,
	0xFFFD: 0x3B93,
	0xFFFD: 0x3B94,
	0xFFFD: 0x3B95,
	0xFFFD: 0x3B96,
	0xFFFD: 0x3B97,
	0xFFFD: 0x3B98,
	0xFFFD: 0x3B99,
	0xFFFD: 0x3B9A,
	0xFFFD: 0x3B9B,
	0xFFFD: 0x3B9C,
	0xFFFD: 0x3B9D,
	0xFFFD: 0x3B9E,
	0xFFFD: 0x3B9F,
	0xFFFD: 0x3BA0,
	0xFFFD: 0x3BA1,
	0xFFFD: 0x3BA2,
	0xFFFD: 0x3BA3,
	0xFFFD: 0x3BA4,
	0xFFFD: 0x3BA5,
	0xFFFD: 0x3BA6,
	0xFFFD: 0x3BA7,
	0xFFFD: 0x3BA8,
	0xFFFD: 0x3BA9,
	0xFFFD: 0x3BAA,
	0xFFFD: 0x3BAB,
	0xFFFD: 0x3BAC,
	0xFFFD: 0x3BAD,
	0xFFFD: 0x3BAE,
	0xFFFD: 0x3BAF,
	0xFFFD: 0x3BB0,
	0xFFFD: 0x3BB1,
	0xFFFD: 0x3BB2,
	0xFFFD: 0x3BB3,
	0xFFFD: 0x3BB4,
	0xFFFD: 0x3BB5,
	0xFFFD: 0x3BB6,
	0xFFFD: 0x3BB7,
	0xFFFD: 0x3BB8,
	0xFFFD: 0x3BB9,
	0xFFFD: 0x3BBA,
	0xFFFD: 0x3BBB,
	0xFFFD: 0x3BBC,
	0xFFFD: 0x3BBD,
	0xFFFD: 0x3BBE,
	0xFFFD: 0x3BBF,
	0xFFFD: 0x3BC0,
	0xFFFD: 0x3BC1,
	0xFFFD: 0x3BC2,
	0xFFFD: 0x3BC3,
	0xFFFD: 0x3BC4,
	0xFFFD: 0x3BC5,
	0xFFFD: 0x3BC6,
	0xFFFD: 0x3BC7,
	0xFFFD: 0x3BC8,
	0xFFFD: 0x3BC9,
	0xFFFD: 0x3BCA,
	0xFFFD: 0x3BCB,
	0xFFFD: 0x3BCC,
	0xFFFD: 0x3BCD,
	0xFFFD: 0x3BCE,
	0xFFFD: 0x3BCF,
	0xFFFD: 0x3BD0,
	0xFFFD: 0x3BD1,
	0xFFFD: 0x3BD2,
	0xFFFD: 0x3BD3,
	0xFFFD: 0x3BD4,
	0xFFFD: 0x3BD5,
	0xFFFD: 0x3BD6,
	0xFFFD: 0x3BD7,
	0xFFFD: 0x3BD8,
	0xFFFD: 0x3BD9,
	0xFFFD: 0x3BDA,
	0xFFFD: 0x3BDB,
	0xFFFD: 0x3BDC,
	0xFFFD: 0x3BDD,
	0xFFFD: 0x3BDE,
	0xFFFD: 0x3BDF,
	0xFFFD: 0x3BE0,
	0xFFFD: 0x3BE1,
	0xFFFD: 0x3BE2,
	0xFFFD: 0x3BE3,
	0xFFFD: 0x3BE4,
	0xFFFD: 0x3BE5,
	0xFFFD: 0x3BE6,
	0xFFFD: 0x3BE7,
	0xFFFD: 0x3BE8,
	0xFFFD: 0x3BE9,
	0xFFFD: 0x3BEA,
	0xFFFD: 0x3BEB,
	0xFFFD: 0x3BEC,
	0x95C9: 0x3BED,
	0xFFFD: 0x3BEE,
	0xFFFD: 0x3BEF,
	0xFFFD: 0x3BF0,
	0xFFFD: 0x3BF1,
	0xFFFD: 0x3BF2,
	0xFFFD: 0x3BF3,
	0xFFFD: 0x3BF4,
	0xFFFD: 0x3BF5,
	0xFFFD: 0x3BF6,
	0xFFFD: 0x3BF7,
	0xFFFD: 0x3BF8,
	0xFFFD: 0x3BF9,
	0xFFFD: 0x3BFA,
	0xFFFD: 0x3BFB,
	0xFFFD: 0x3BFC,
	0xFFFD: 0x3BFD,
	0xFFFD: 0x3BFE,
	0xFFFD: 0x3BFF,
	0xFFFD: 0x3C00,
	0xFFFD: 0x3C01,
	0xFFFD: 0x3C02,
	0xFFFD: 0x3C03,
	0xFFFD: 0x3C04,
	0xFFFD: 0x3C05,
	0xFFFD: 0x3C06,
	0xFFFD: 0x3C07,
	0xFFFD: 0x3C08,
	0xFFFD: 0x3C09,
	0xFFFD: 0x3C0A,
	0xFFFD: 0x3C0B,
	0xFFFD: 0x3C0C,
	0xFFFD: 0x3C0D,
	0xFFFD: 0x3C0E,
	0xFFFD: 0x3C0F,
	0xFFFD: 0x3C10,
	0xFFFD: 0x3C11,
	0xFFFD: 0x3C12,
	0xFFFD: 0x3C13,
	0xFFFD: 0x3C14,
	0xFFFD: 0x3C15,
	0xFFFD: 0x3C16,
	0xFFFD: 0x3C17,
	0xFFFD: 0x3C18,
	0xFFFD: 0x3C19,
	0xFFFD: 0x3C1A,
	0xFFFD: 0x3C1B,
	0xFFFD: 0x3C1C,
	0xFFFD: 0x3C1D,
	0xFFFD: 0x3C1E,
	0xFFFD: 0x3C1F,
	0xFFFD: 0x3C20,
	0xFFFD: 0x3C21,
	0xFFFD: 0x3C22,
	0xFFFD: 0x3C23,
	0xFFFD: 0x3C24,
	0xFFFD: 0x3C25,
	0xFFFD: 0x3C26,
	0xFFFD: 0x3C27,
	0xFFFD: 0x3C28,
	0xFFFD: 0x3C29,
	0xFFFD: 0x3C2A,
	0xFFFD: 0x3C2B,
	0xFFFD: 0x3C2C,
	0xFFFD: 0x3C2D,
	0xFFFD: 0x3C2E,
	0xFFFD: 0x3C2F,
	0xFFFD: 0x3C30,
	0xFFFD: 0x3C31,
	0xFFFD: 0x3C32,
	0xFFFD: 0x3C33,
	0xFFFD: 0x3C34,
	0xFFFD: 0x3C35,
	0xFFFD: 0x3C36,
	0xFFFD: 0x3C37,
	0xFFFD: 0x3C38,
	0xFFFD: 0x3C39,
	0xFFFD: 0x3C3A,
	0xFFFD: 0x3C3B,
	0xFFFD: 0x3C3C,
	0xFFFD: 0x3C3D,
	0xFFFD: 0x3C3E,
	0xFFFD: 0x3C3F,
	0xFFFD: 0x3C40,
	0xFFFD: 0x3C41,
	0xFFFD: 0x3C42,
	0xFFFD: 0x3C43,
	0xFFFD: 0x3C44,
	0xFFFD: 0x3C45,
	0xFFFD: 0x3C46,
	0xFFFD: 0x3C47,
	0xFFFD: 0x3C48,
	0xFFFD: 0x3C49,
	0xFFFD: 0x3C4A,
	0xFFFD: 0x3C4B,
	0xFFFD: 0x3C4C,
	0xFFFD: 0x3C4D,
	0xFFFD: 0x3C4E,
	0xFFFD: 0x3C4F,
	0xFFFD: 0x3C50,
	0xFFFD: 0x3C51,
	0xFFFD: 0x3C52,
	0xFFFD: 0x3C53,
	0xFFFD: 0x3C54,
	0xFFFD: 0x3C55,
	0xFFFD: 0x3C56,
	0xFFFD: 0x3C57,
	0xFFFD: 0x3C58,
	0xFFFD: 0x3C59,
	0xFFFD: 0x3C5A,
	0xFFFD: 0x3C5B,
	0xFFFD: 0x3C5C,
	0xFFFD: 0x3C5D,
	0xFFFD: 0x3C5E,
	0xFFFD: 0x3C5F,
	0xFFFD: 0x3C60,
	0xFFFD: 0x3C61,
	0xFFFD: 0x3C62,
	0xFFFD: 0x3C63,
	0xFFFD: 0x3C64,
	0xFFFD: 0x3C65,
	0xFFFD: 0x3C66,
	0xFFFD: 0x3C67,
	0xFFFD: 0x3C68,
	0xFFFD: 0x3C69,
	0xFFFD: 0x3C6A,
	0xFFFD: 0x3C6B,
	0xFFFD: 0x3C6C,
	0xFFFD: 0x3C6D,
	0xFFFD: 0x3C6E,
	0xFFFD: 0x3C6F,
	0xFFFD: 0x3C70,
	0xFFFD: 0x3C71,
	0xFFFD: 0x3C72,
	0xFFFD: 0x3C73,
	0xFFFD: 0x3C74,
	0xFFFD: 0x3C75,
	0xFFFD: 0x3C76,
	0xFFFD: 0x3C77,
	0xFFFD: 0x3C78,
	0xFFFD: 0x3C79,
	0xFFFD: 0x3C7A,
	0xFFFD: 0x3C7B,
	0xFFFD: 0x3C7C,
	0xFFFD: 0x3C7D,
	0xFFFD: 0x3C7E,
	0xFFFD: 0x3C7F,
	0xFFFD: 0x3C80,
	0xFFFD: 0x3C81,
	0xFFFD: 0x3C82,
	0xFFFD: 0x3C83,
	0xFFFD: 0x3C84,
	0xFFFD: 0x3C85,
	0xFFFD: 0x3C86,
	0xFFFD: 0x3C87,
	0xFFFD: 0x3C88,
	0xFFFD: 0x3C89,
	0xFFFD: 0x3C8A,
	0xFFFD: 0x3C8B,
	0xFFFD: 0x3C8C,
	0xFFFD: 0x3C8D,
	0xFFFD: 0x3C8E,
	0xFFFD: 0x3C8F,
	0xFFFD: 0x3C90,
	0xFFFD: 0x3C91,
	0xFFFD: 0x3C92,
	0xFFFD: 0x3C93,
	0xFFFD: 0x3C94,
	0xFFFD: 0x3C95,
	0xFFFD: 0x3C96,
	0xFFFD: 0x3C97,
	0xFFFD: 0x3C98,
	0xFFFD: 0x3C99,
	0xFFFD: 0x3C9A,
	0xFFFD: 0x3C9B,
	0xFFFD: 0x3C9C,
	0xFFFD: 0x3C9D,
	0xFFFD: 0x3C9E,
	0xFFFD: 0x3C9F,
	0xFFFD: 0x3CA0,
	0xFFFD: 0x3CA1,
	0xFFFD: 0x3CA2,
	0xFFFD: 0x3CA3,
	0xFFFD: 0x3CA4,
	0xFFFD: 0x3CA5,
	0xFFFD: 0x3CA6,
	0xFFFD: 0x3CA7,
	0xFFFD: 0x3CA8,
	0xFFFD: 0x3CA9,
	0xFFFD: 0x3CAA,
	0xFFFD: 0x3CAB,
	0xFFFD: 0x3CAC,
	0xFFFD: 0x3CAD,
	0xFFFD: 0x3CAE,
	0xFFFD: 0x3CAF,
	0xFFFD: 0x3CB0,
	0xFFFD: 0x3CB1,
	0xFFFD: 0x3CB2,
	0xFFFD: 0x3CB3,
	0xFFFD: 0x3CB4,
	0xFFFD: 0x3CB5,
	0xFFFD: 0x3CB6,
	0xFFFD: 0x3CB7,
	0xFFFD: 0x3CB8,
	0xFFFD: 0x3CB9,
	0xFFFD: 0x3CBA,
	0xFFFD: 0x3CBB,
	0xFFFD: 0x3CBC,
	0xFFFD: 0x3CBD,
	0xFFFD: 0x3CBE,
	0xFFFD: 0x3CBF,
	0xFFFD: 0x3CC0,
	0xFFFD: 0x3CC1,
	0xFFFD: 0x3CC2,
	0xFFFD: 0x3CC3,
	0xFFFD: 0x3CC4,
	0xFFFD: 0x3CC5,
	0xFFFD: 0x3CC6,
	0xFFFD: 0x3CC7,
	0xFFFD: 0x3CC8,
	0xFFFD: 0x3CC9,
	0xFFFD: 0x3CCA,
	0xFFFD: 0x3CCB,
	0xFFFD: 0x3CCC,
	0xFFFD: 0x3CCD,
	0xFFFD: 0x3CCE,
	0xFFFD: 0x3CCF,
	0xFFFD: 0x3CD0,
	0xFC7C: 0x3CD1,
	0xFFFD: 0x3CD2,
	0xFFFD: 0x3CD3,
	0xFFFD: 0x3CD4,
	0xFFFD: 0x3CD5,
	0xFFFD: 0x3CD6,
	0xFFFD: 0x3CD7,
	0xFFFD: 0x3CD8,
	0xFFFD: 0x3CD9,
	0xFFFD: 0x3CDA,
	0xFFFD: 0x3CDB,
	0xFFFD: 0x3CDC,
	0xFFFD: 0x3CDD,
	0xFFFD: 0x3CDE,
	0xFFFD: 0x3CDF,
	0xFFFD: 0x3CE0,
	0xFFFD: 0x3CE1,
	0xFFFD: 0x3CE2,
	0xFFFD: 0x3CE3,
	0xFFFD: 0x3CE4,
	0xFFFD: 0x3CE5,
	0xFFFD: 0x3CE6,
	0xFFFD: 0x3CE7,
	0xFFFD: 0x3CE8,
	0xFFFD: 0x3CE9,
	0xFFFD: 0x3CEA,
	0xFFFD: 0x3CEB,
	0xFFFD: 0x3CEC,
	0xFFFD: 0x3CED,
	0xFFFD: 0x3CEE,
	0xFFFD: 0x3CEF,
	0xFFFD: 0x3CF0,
	0xFFFD: 0x3CF1,
	0xFFFD: 0x3CF2,
	0xFFFD: 0x3CF3,
	0xFFFD: 0x3CF4,
	0xFFFD: 0x3CF5,
	0xFFFD: 0x3CF6,
	0xFFFD: 0x3CF7,
	0xFFFD: 0x3CF8,
	0xFFFD: 0x3CF9,
	0xFFFD: 0x3CFA,
	0xFFFD: 0x3CFB,
	0xFFFD: 0x3CFC,
	0xFFFD: 0x3CFD,
	0xFFFD: 0x3CFE,
	0xFFFD: 0x3CFF,
	0xFFFD: 0x3D00,
	0xFFFD: 0x3D01,
	0xFFFD: 0x3D02,
	0xFFFD: 0x3D03,
	0xFFFD: 0x3D04,
	0xFFFD: 0x3D05,
	0xFFFD: 0x3D06,
	0xFFFD: 0x3D07,
	0xFFFD: 0x3D08,
	0xFFFD: 0x3D09,
	0xFFFD: 0x3D0A,
	0xFFFD: 0x3D0B,
	0xFFFD: 0x3D0C,
	0xFFFD: 0x3D0D,
	0xFFFD: 0x3D0E,
	0xFFFD: 0x3D0F,
	0xFFFD: 0x3D10,
	0xFFFD: 0x3D11,
	0xFFFD: 0x3D12,
	0xFFFD: 0x3D13,
	0xFFFD: 0x3D14,
	0xFFFD: 0x3D15,
	0xFFFD: 0x3D16,
	0xFFFD: 0x3D17,
	0xFFFD: 0x3D18,
	0xFFFD: 0x3D19,
	0xFFFD: 0x3D1A,
	0xFFFD: 0x3D1B,
	0xFFFD: 0x3D1C,
	0xFFFD: 0x3D1D,
	0xFFFD: 0x3D1E,
	0xFFFD: 0x3D1F,
	0xFFFD: 0x3D20,
	0xFFFD: 0x3D21,
	0xFFFD: 0x3D22,
	0xFFFD: 0x3D23,
	0xFFFD: 0x3D24,
	0xFFFD: 0x3D25,
	0xFFFD: 0x3D26,
	0xFFFD: 0x3D27,
	0xFFFD: 0x3D28,
	0xFFFD: 0x3D29,
	0xFFFD: 0x3D2A,
	0xFFFD: 0x3D2B,
	0xFFFD: 0x3D2C,
	0xFFFD: 0x3D2D,
	0xFFFD: 0x3D2E,
	0xFFFD: 0x3D2F,
	0xFFFD: 0x3D30,
	0xFFFD: 0x3D31,
	0xFFFD: 0x3D32,
	0xFFFD: 0x3D33,
	0xFFFD: 0x3D34,
	0xFFFD: 0x3D35,
	0xFFFD: 0x3D36,
	0xFFFD: 0x3D37,
	0xFFFD: 0x3D38,
	0xFFFD: 0x3D39,
	0xFFFD: 0x3D3A,
	0xFFFD: 0x3D3B,
	0xFFFD: 0x3D3C,
	0xFFFD: 0x3D3D,
	0xFFFD: 0x3D3E,
	0xFFFD: 0x3D3F,
	0xFFFD: 0x3D40,
	0xFFFD: 0x3D41,
	0xFFFD: 0x3D42,
	0xFFFD: 0x3D43,
	0xFFFD: 0x3D44,
	0xFFFD: 0x3D45,
	0xFFFD: 0x3D46,
	0xFFFD: 0x3D47,
	0xFFFD: 0x3D48,
	0xFFFD: 0x3D49,
	0xFFFD: 0x3D4A,
	0xFFFD: 0x3D4B,
	0xFFFD: 0x3D4C,
	0xFFFD: 0x3D4D,
	0xFFFD: 0x3D4E,
	0xFFFD: 0x3D4F,
	0xFFFD: 0x3D50,
	0xFFFD: 0x3D51,
	0xFFFD: 0x3D52,
	0xFFFD: 0x3D53,
	0xFFFD: 0x3D54,
	0xFFFD: 0x3D55,
	0xFFFD: 0x3D56,
	0xFFFD: 0x3D57,
	0xFFFD: 0x3D58,
	0xFFFD: 0x3D59,
	0xFFFD: 0x3D5A,
	0xFFFD: 0x3D5B,
	0xFFFD: 0x3D5C,
	0xFFFD: 0x3D5D,
	0xFFFD: 0x3D5E,
	0xFFFD: 0x3D5F,
	0xFFFD: 0x3D60,
	0xFFFD: 0x3D61,
	0xFFFD: 0x3D62,
	0xFFFD: 0x3D63,
	0xFFFD: 0x3D64,
	0xFFFD: 0x3D65,
	0xFFFD: 0x3D66,
	0xFFFD: 0x3D67,
	0xFFFD: 0x3D68,
	0xFFFD: 0x3D69,
	0xFFFD: 0x3D6A,
	0xFFFD: 0x3D6B,
	0xFFFD: 0x3D6C,
	0xFFFD: 0x3D6D,
	0xFFFD: 0x3D6E,
	0xFFFD: 0x3D6F,
	0xFFFD: 0x3D70,
	0xFFFD: 0x3D71,
	0xFFFD: 0x3D72,
	0xFFFD: 0x3D73,
	0xFFFD: 0x3D74,
	0xFFFD: 0x3D75,
	0xFFFD: 0x3D76,
	0xFFFD: 0x3D77,
	0xFFFD: 0x3D78,
	0xFFFD: 0x3D79,
	0xFFFD: 0x3D7A,
	0xFFFD: 0x3D7B,
	0xFFFD: 0x3D7C,
	0xFFFD: 0x3D7D,
	0xFFFD: 0x3D7E,
	0xFFFD: 0x3D7F,
	0xFFFD: 0x3D80,
	0xFFFD: 0x3D81,
	0xFFFD: 0x3D82,
	0xFFFD: 0x3D83,
	0xFFFD: 0x3D84,
	0xFFFD: 0x3D85,
	0xFFFD: 0x3D86,
	0xFFFD: 0x3D87,
	0xFFFD: 0x3D88,
	0xFFFD: 0x3D89,
	0xFFFD: 0x3D8A,
	0xFFFD: 0x3D8B,
	0xFFFD: 0x3D8C,
	0xFFFD: 0x3D8D,
	0xFFFD: 0x3D8E,
	0xFFFD: 0x3D8F,
	0xFFFD: 0x3D90,
	0xFFFD: 0x3D91,
	0xFFFD: 0x3D92,
	0xFFFD: 0x3D93,
	0xFFFD: 0x3D94,
	0xFFFD: 0x3D95,
	0xFFFD: 0x3D96,
	0xFFFD: 0x3D97,
	0xFFFD: 0x3D98,
	0xFFFD: 0x3D99,
	0xFFFD: 0x3D9A,
	0xFFFD: 0x3D9B,
	0xFFFD: 0x3D9C,
	0xFFFD: 0x3D9D,
	0xFFFD: 0x3D9E,
	0xFFFD: 0x3D9F,
	0xFFFD: 0x3DA0,
	0xFFFD: 0x3DA1,
	0xFFFD: 0x3DA2,
	0xFFFD: 0x3DA3,
	0xFFFD: 0x3DA4,
	0xFFFD: 0x3DA5,
	0xFFFD: 0x3DA6,
	0xFFFD: 0x3DA7,
	0xFFFD: 0x3DA8,
	0xFFFD: 0x3DA9,
	0xFFFD: 0x3DAA,
	0xFFFD: 0x3DAB,
	0xFFFD: 0x3DAC,
	0xFFFD: 0x3DAD,
	0xFFFD: 0x3DAE,
	0xFFFD: 0x3DAF,
	0xFFFD: 0x3DB0,
	0xFFFD: 0x3DB1,
	0xFFFD: 0x3DB2,
	0xFFFD: 0x3DB3,
	0xFFFD: 0x3DB4,
	0xFFFD: 0x3DB5,
	0xFFFD: 0x3DB6,
	0xFFFD: 0x3DB7,
	0xFFFD: 0x3DB8,
	0xFFFD: 0x3DB9,
	0xFFFD: 0x3DBA,
	0xFFFD: 0x3DBB,
	0xFFFD: 0x3DBC,
	0xFFFD: 0x3DBD,
	0xFFFD: 0x3DBE,
	0xFFFD: 0x3DBF,
	0xFFFD: 0x3DC0,
	0xFFFD: 0x3DC1,
	0xFFFD: 0x3DC2,
	0xFFFD: 0x3DC3,
	0xFFFD: 0x3DC4,
	0xFFFD: 0x3DC5,
	0xFFFD: 0x3DC6,
	0xFFFD: 0x3DC7,
	0xFFFD: 0x3DC8,
	0xFFFD: 0x3DC9,
	0xFFFD: 0x3DCA,
	0xFFFD: 0x3DCB,
	0xFCA8: 0x3DCC,
	0xFFFD: 0x3DCD,
	0xFFFD: 0x3DCE,
	0xFFFD: 0x3DCF,
	0xFFFD: 0x3DD0,
	0xFFFD: 0x3DD1,
	0xFFFD: 0x3DD2,
	0xFFFD: 0x3DD3,
	0xFFFD: 0x3DD4,
	0xFFFD: 0x3DD5,
	0xFFFD: 0x3DD6,
	0xFFFD: 0x3DD7,
	0xFFFD: 0x3DD8,
	0xFFFD: 0x3DD9,
	0xFFFD: 0x3DDA,
	0xFFFD: 0x3DDB,
	0xFFFD: 0x3DDC,
	0xFFFD: 0x3DDD,
	0xFFFD: 0x3DDE,
	0xFFFD: 0x3DDF,
	0xFFFD: 0x3DE0,
	0xFFFD: 0x3DE1,
	0xFFFD: 0x3DE2,
	0xFFFD: 0x3DE3,
	0xFFFD: 0x3DE4,
	0xFFFD: 0x3DE5,
	0xFFFD: 0x3DE6,
	0xFFFD: 0x3DE7,
	0xFFFD: 0x3DE8,
	0xFFFD: 0x3DE9,
	0xFFFD: 0x3DEA,
	0xFFFD: 0x3DEB,
	0xFFFD: 0x3DEC,
	0xFFFD: 0x3DED,
	0xFFFD: 0x3DEE,
	0xFFFD: 0x3DEF,
	0xFFFD: 0x3DF0,
	0xFFFD: 0x3DF1,
	0xFFFD: 0x3DF2,
	0xFFFD: 0x3DF3,
	0xFFFD: 0x3DF4,
	0xFFFD: 0x3DF5,
	0xFFFD: 0x3DF6,
	0xFFFD: 0x3DF7,
	0xFFFD: 0x3DF8,
	0xFFFD: 0x3DF9,
	0xFFFD: 0x3DFA,
	0xFFFD: 0x3DFB,
	0xFFFD: 0x3DFC,
	0xFFFD: 0x3DFD,
	0xFFFD: 0x3DFE,
	0xFFFD: 0x3DFF,
	0xFFFD: 0x3E00,
	0xFFFD: 0x3E01,
	0xFFFD: 0x3E02,
	0xFFFD: 0x3E03,
	0xFFFD: 0x3E04,
	0xFFFD: 0x3E05,
	0xFFFD: 0x3E06,
	0xFFFD: 0x3E07,
	0xFFFD: 0x3E08,
	0xFFFD: 0x3E09,
	0xFFFD: 0x3E0A,
	0xFFFD: 0x3E0B,
	0xFFFD: 0x3E0C,
	0xFFFD: 0x3E0D,
	0xFFFD: 0x3E0E,
	0xFFFD: 0x3E0F,
	0xFFFD: 0x3E10,
	0xFFFD: 0x3E11,
	0xFFFD: 0x3E12,
	0xFFFD: 0x3E13,
	0xFFFD: 0x3E14,
	0xFFFD: 0x3E15,
	0xFFFD: 0x3E16,
	0xFFFD: 0x3E17,
	0xFFFD: 0x3E18,
	0xFFFD: 0x3E19,
	0xFFFD: 0x3E1A,
	0xFFFD: 0x3E1B,
	0xFFFD: 0x3E1C,
	0xFFFD: 0x3E1D,
	0xFFFD: 0x3E1E,
	0xFFFD: 0x3E1F,
	0xFFFD: 0x3E20,
	0xFFFD: 0x3E21,
	0xFFFD: 0x3E22,
	0xFFFD: 0x3E23,
	0xFFFD: 0x3E24,
	0xFFFD: 0x3E25,
	0xFFFD: 0x3E26,
	0xFFFD: 0x3E27,
	0xFFFD: 0x3E28,
	0xFFFD: 0x3E29,
	0xFFFD: 0x3E2A,
	0xFFFD: 0x3E2B,
	0xFFFD: 0x3E2C,
	0xFFFD: 0x3E2D,
	0xFFFD: 0x3E2E,
	0xFFFD: 0x3E2F,
	0xFFFD: 0x3E30,
	0xFFFD: 0x3E31,
	0xFFFD: 0x3E32,
	0xFFFD: 0x3E33,
	0xFFFD: 0x3E34,
	0xFFFD: 0x3E35,
	0xFFFD: 0x3E36,
	0xFFFD: 0x3E37,
	0xFFFD: 0x3E38,
	0xFFFD: 0x3E39,
	0xFFFD: 0x3E3A,
	0xFFFD: 0x3E3B,
	0xFFFD: 0x3E3C,
	0xFFFD: 0x3E3D,
	0xFFFD: 0x3E3E,
	0xFFFD: 0x3E3F,
	0xFFFD: 0x3E40,
	0xFFFD: 0x3E41,
	0xFFFD: 0x3E42,
	0xFFFD: 0x3E43,
	0xFFFD: 0x3E44,
	0xFFFD: 0x3E45,
	0xFFFD: 0x3E46,
	0xFFFD: 0x3E47,
	0xFFFD: 0x3E48,
	0xFFFD: 0x3E49,
	0xFFFD: 0x3E4A,
	0xFFFD: 0x3E4B,
	0xFFFD: 0x3E4C,
	0xFFFD: 0x3E4D,
	0xFFFD: 0x3E4E,
	0xFFFD: 0x3E4F,
	0xFFFD: 0x3E50,
	0xFFFD: 0x3E51,
	0xFFFD: 0x3E52,
	0xFFFD: 0x3E53,
	0xFFFD: 0x3E54,
	0xFFFD: 0x3E55,
	0xFFFD: 0x3E56,
	0xFFFD: 0x3E57,
	0xFFFD: 0x3E58,
	0xFFFD: 0x3E59,
	0xFFFD: 0x3E5A,
	0xFFFD: 0x3E5B,
	0xFFFD: 0x3E5C,
	0xFFFD: 0x3E5D,
	0xFFFD: 0x3E5E,
	0xFFFD: 0x3E5F,
	0xFFFD: 0x3E60,
	0xFFFD: 0x3E61,
	0xFFFD: 0x3E62,
	0xFFFD: 0x3E63,
	0xFFFD: 0x3E64,
	0xFFFD: 0x3E65,
	0xFFFD: 0x3E66,
	0xFFFD: 0x3E67,
	0xFFFD: 0x3E68,
	0xFFFD: 0x3E69,
	0xFFFD: 0x3E6A,
	0xFFFD: 0x3E6B,
	0xFFFD: 0x3E6C,
	0xFFFD: 0x3E6D,
	0xFFFD: 0x3E6E,
	0xFFFD: 0x3E6F,
	0xFFFD: 0x3E70,
	0xFFFD: 0x3E71,
	0xFFFD: 0x3E72,
	0xFFFD: 0x3E73,
	0xFFFD: 0x3E74,
	0xFFFD: 0x3E75,
	0xFFFD: 0x3E76,
	0xFFFD: 0x3E77,
	0xFFFD: 0x3E78,
	0xFFFD: 0x3E79,
	0xFFFD: 0x3E7A,
	0xFFFD: 0x3E7B,
	0xFFFD: 0x3E7C,
	0xFFFD: 0x3E7D,
	0xFFFD: 0x3E7E,
	0xFFFD: 0x3E7F,
	0xFFFD: 0x3E80,
	0xFFFD: 0x3E81,
	0xFFFD: 0x3E82,
	0xFFFD: 0x3E83,
	0xFFFD: 0x3E84,
	0xFFFD: 0x3E85,
	0xFFFD: 0x3E86,
	0xFFFD: 0x3E87,
	0xFFFD: 0x3E88,
	0xFFFD: 0x3E89,
	0xFFFD: 0x3E8A,
	0xFFFD: 0x3E8B,
	0xFFFD: 0x3E8C,
	0xFFFD: 0x3E8D,
	0xFFFD: 0x3E8E,
	0xFFFD: 0x3E8F,
	0xFFFD: 0x3E90,
	0xFFFD: 0x3E91,
	0xFFFD: 0x3E92,
	0xFFFD: 0x3E93,
	0xFFFD: 0x3E94,
	0xFFFD: 0x3E95,
	0xFFFD: 0x3E96,
	0xFFFD: 0x3E97,
	0xFFFD: 0x3E98,
	0xFFFD: 0x3E99,
	0xFFFD: 0x3E9A,
	0xFFFD: 0x3E9B,
	0xFFFD: 0x3E9C,
	0xFFFD: 0x3E9D,
	0xFFFD: 0x3E9E,
	0xFFFD: 0x3E9F,
	0xFFFD: 0x3EA0,
	0xFFFD: 0x3EA1,
	0xFFFD: 0x3EA2,
	0xFFFD: 0x3EA3,
	0xFFFD: 0x3EA4,
	0xFFFD: 0x3EA5,
	0xFFFD: 0x3EA6,
	0xFFFD: 0x3EA7,
	0xFFFD: 0x3EA8,
	0xFFFD: 0x3EA9,
	0xFFFD: 0x3EAA,
	0xFFFD: 0x3EAB,
	0xFFFD: 0x3EAC,
	0xFFFD: 0x3EAD,
	0xFFFD: 0x3EAE,
	0xFFFD: 0x3EAF,
	0xFFFD: 0x3EB0,
	0xFFFD: 0x3EB1,
	0xFFFD: 0x3EB2,
	0xFFFD: 0x3EB3,
	0xFFFD: 0x3EB4,
	0xFFFD: 0x3EB5,
	0xFFFD: 0x3EB6,
	0xFFFD: 0x3EB7,
	0xFFFD: 0x3EB8,
	0xFFFD: 0x3EB9,
	0xFFFD: 0x3EBA,
	0xFFFD: 0x3EBB,
	0xFFFD: 0x3EBC,
	0xFFFD: 0x3EBD,
	0xFFFD: 0x3EBE,
	0xFFFD: 0x3EBF,
	0xFFFD: 0x3EC0,
	0xFFFD: 0x3EC1,
	0xFFFD: 0x3EC2,
	0xFFFD: 0x3EC3,
	0xFFFD: 0x3EC4,
	0xFFFD: 0x3EC5,
	0xFFFD: 0x3EC6,
	0xFFFD: 0x3EC7,
	0xFFFD: 0x3EC8,
	0xFFFD: 0x3EC9,
	0xFFFD: 0x3ECA,
	0xFFFD: 0x3ECB,
	0xFFFD: 0x3ECC,
	0xFFFD: 0x3ECD,
	0xFFFD: 0x3ECE,
	0xFFFD: 0x3ECF,
	0xFFFD: 0x3ED0,
	0xFFFD: 0x3ED1,
	0xFFFD: 0x3ED2,
	0xFFFD: 0x3ED3,
	0xFFFD: 0x3ED4,
	0xFFFD: 0x3ED5,
	0xFFFD: 0x3ED6,
	0xFFFD: 0x3ED7,
	0xFFFD: 0x3ED8,
	0xFE71: 0x3ED9,
	0xFFFD: 0x3EDA,
	0xFFFD: 0x3EDB,
	0xFFFD: 0x3EDC,
	0xFFFD: 0x3EDD,
	0xFFFD: 0x3EDE,
	0xFFFD: 0x3EDF,
	0xFFFD: 0x3EE0,
	0xFFFD: 0x3EE1,
	0xFFFD: 0x3EE2,
	0xFFFD: 0x3EE3,
	0xFFFD: 0x3EE4,
	0xFFFD: 0x3EE5,
	0xFFFD: 0x3EE6,
	0xFFFD: 0x3EE7,
	0xFFFD: 0x3EE8,
	0xFFFD: 0x3EE9,
	0xFFFD: 0x3EEA,
	0xFFFD: 0x3EEB,
	0xFFFD: 0x3EEC,
	0xFFFD: 0x3EED,
	0xFFFD: 0x3EEE,
	0xFFFD: 0x3EEF,
	0xFFFD: 0x3EF0,
	0xFFFD: 0x3EF1,
	0xFFFD: 0x3EF2,
	0xFFFD: 0x3EF3,
	0xFFFD: 0x3EF4,
	0xFFFD: 0x3EF5,
	0xFFFD: 0x3EF6,
	0xFFFD: 0x3EF7,
	0xFFFD: 0x3EF8,
	0xFFFD: 0x3EF9,
	0xFFFD: 0x3EFA,
	0xFFFD: 0x3EFB,
	0xFFFD: 0x3EFC,
	0xFFFD: 0x3EFD,
	0xFFFD: 0x3EFE,
	0xFFFD: 0x3EFF,
	0xFFFD: 0x3F00,
	0xFFFD: 0x3F01,
	0xFFFD: 0x3F02,
	0xFFFD: 0x3F03,
	0xFFFD: 0x3F04,
	0xFFFD: 0x3F05,
	0xFFFD: 0x3F06,
	0xFFFD: 0x3F07,
	0xFFFD: 0x3F08,
	0xFFFD: 0x3F09,
	0xFFFD: 0x3F0A,
	0xFFFD: 0x3F0B,
	0xFFFD: 0x3F0C,
	0xFFFD: 0x3F0D,
	0xFFFD: 0x3F0E,
	0xFFFD: 0x3F0F,
	0xFFFD: 0x3F10,
	0xFFFD: 0x3F11,
	0xFFFD: 0x3F12,
	0xFFFD: 0x3F13,
	0xFFFD: 0x3F14,
	0xFFFD: 0x3F15,
	0xFFFD: 0x3F16,
	0xFFFD: 0x3F17,
	0xFFFD: 0x3F18,
	0xFFFD: 0x3F19,
	0xFFFD: 0x3F1A,
	0xFFFD: 0x3F1B,
	0xFFFD: 0x3F1C,
	0xFFFD: 0x3F1D,
	0xFFFD: 0x3F1E,
	0xFFFD: 0x3F1F,
	0xFFFD: 0x3F20,
	0xFFFD: 0x3F21,
	0xFFFD: 0x3F22,
	0xFFFD: 0x3F23,
	0xFFFD: 0x3F24,
	0xFFFD: 0x3F25,
	0xFFFD: 0x3F26,
	0xFFFD: 0x3F27,
	0xFFFD: 0x3F28,
	0xFFFD: 0x3F29,
	0xFFFD: 0x3F2A,
	0xFFFD: 0x3F2B,
	0xFFFD: 0x3F2C,
	0xFFFD: 0x3F2D,
	0xFFFD: 0x3F2E,
	0xFFFD: 0x3F2F,
	0xFFFD: 0x3F30,
	0xFFFD: 0x3F31,
	0xFFFD: 0x3F32,
	0xFFFD: 0x3F33,
	0xFFFD: 0x3F34,
	0xFFFD: 0x3F35,
	0xFFFD: 0x3F36,
	0xFFFD: 0x3F37,
	0xFFFD: 0x3F38,
	0xFFFD: 0x3F39,
	0xFFFD: 0x3F3A,
	0xFFFD: 0x3F3B,
	0xFFFD: 0x3F3C,
	0xFFFD: 0x3F3D,
	0xFFFD: 0x3F3E,
	0xFFFD: 0x3F3F,
	0xFFFD: 0x3F40,
	0xFFFD: 0x3F41,
	0xFFFD: 0x3F42,
	0xFFFD: 0x3F43,
	0xFFFD: 0x3F44,
	0xFFFD: 0x3F45,
	0xFFFD: 0x3F46,
	0xFFFD: 0x3F47,
	0xFFFD: 0x3F48,
	0xFFFD: 0x3F49,
	0xFFFD: 0x3F4A,
	0xFFFD: 0x3F4B,
	0xFFFD: 0x3F4C,
	0xFFFD: 0x3F4D,
	0xFFFD: 0x3F4E,
	0xFFFD: 0x3F4F,
	0xFFFD: 0x3F50,
	0xFFFD: 0x3F51,
	0xFFFD: 0x3F52,
	0xFFFD: 0x3F53,
	0xFFFD: 0x3F54,
	0xFFFD: 0x3F55,
	0xFFFD: 0x3F56,
	0xFFFD: 0x3F57,
	0xFFFD: 0x3F58,
	0xFFFD: 0x3F59,
	0xFFFD: 0x3F5A,
	0xFFFD: 0x3F5B,
	0xFFFD: 0x3F5C,
	0xFFFD: 0x3F5D,
	0xFFFD: 0x3F5E,
	0xFFFD: 0x3F5F,
	0xFFFD: 0x3F60,
	0xFFFD: 0x3F61,
	0xFFFD: 0x3F62,
	0xFFFD: 0x3F63,
	0xFFFD: 0x3F64,
	0xFFFD: 0x3F65,
	0xFFFD: 0x3F66,
	0xFFFD: 0x3F67,
	0xFFFD: 0x3F68,
	0xFFFD: 0x3F69,
	0xFFFD: 0x3F6A,
	0xFFFD: 0x3F6B,
	0xFFFD: 0x3F6C,
	0xFFFD: 0x3F6D,
	0xFFFD: 0x3F6E,
	0xFFFD: 0x3F6F,
	0xFFFD: 0x3F70,
	0xFFFD: 0x3F71,
	0xFFFD: 0x3F72,
	0xFFFD: 0x3F73,
	0xFFFD: 0x3F74,
	0xFFFD: 0x3F75,
	0xFFFD: 0x3F76,
	0xFFFD: 0x3F77,
	0xFFFD: 0x3F78,
	0xFFFD: 0x3F79,
	0xFFFD: 0x3F7A,
	0xFFFD: 0x3F7B,
	0xFFFD: 0x3F7C,
	0xFFFD: 0x3F7D,
	0xFFFD: 0x3F7E,
	0xFFFD: 0x3F7F,
	0xFFFD: 0x3F80,
	0xFFFD: 0x3F81,
	0xFFFD: 0x3F82,
	0xFFFD: 0x3F83,
	0xFFFD: 0x3F84,
	0xFFFD: 0x3F85,
	0xFFFD: 0x3F86,
	0xFFFD: 0x3F87,
	0xFFFD: 0x3F88,
	0xFFFD: 0x3F89,
	0xFFFD: 0x3F8A,
	0xFFFD: 0x3F8B,
	0xFFFD: 0x3F8C,
	0xFFFD: 0x3F8D,
	0xFFFD: 0x3F8E,
	0xFFFD: 0x3F8F,
	0xFFFD: 0x3F90,
	0xFFFD: 0x3F91,
	0xFFFD: 0x3F92,
	0xFFFD: 0x3F93,
	0xFFFD: 0x3F94,
	0xFFFD: 0x3F95,
	0xFFFD: 0x3F96,
	0xFFFD: 0x3F97,
	0xFFFD: 0x3F98,
	0xFFFD: 0x3F99,
	0xFFFD: 0x3F9A,
	0xFFFD: 0x3F9B,
	0xFFFD: 0x3F9C,
	0xFFFD: 0x3F9D,
	0xFFFD: 0x3F9E,
	0xFFFD: 0x3F9F,
	0xFFFD: 0x3FA0,
	0xFFFD: 0x3FA1,
	0xFFFD: 0x3FA2,
	0xFFFD: 0x3FA3,
	0xFFFD: 0x3FA4,
	0xFFFD: 0x3FA5,
	0xFFFD: 0x3FA6,
	0xFFFD: 0x3FA7,
	0xFFFD: 0x3FA8,
	0xFFFD: 0x3FA9,
	0xFFFD: 0x3FAA,
	0xFFFD: 0x3FAB,
	0xFFFD: 0x3FAC,
	0xFFFD: 0x3FAD,
	0xFFFD: 0x3FAE,
	0xFFFD: 0x3FAF,
	0xFFFD: 0x3FB0,
	0xFFFD: 0x3FB1,
	0xFFFD: 0x3FB2,
	0xFFFD: 0x3FB3,
	0xFFFD: 0x3FB4,
	0xFFFD: 0x3FB5,
	0xFFFD: 0x3FB6,
	0xFFFD: 0x3FB7,
	0xFFFD: 0x3FB8,
	0xFFFD: 0x3FB9,
	0xFFFD: 0x3FBA,
	0xFFFD: 0x3FBB,
	0xFFFD: 0x3FBC,
	0xFFFD: 0x3FBD,
	0xFFFD: 0x3FBE,
	0xFFFD: 0x3FBF,
	0xFFFD: 0x3FC0,
	0xFFFD: 0x3FC1,
	0xFFFD: 0x3FC2,
	0xFFFD: 0x3FC3,
	0xFFFD: 0x3FC4,
	0xFFFD: 0x3FC5,
	0xFFFD: 0x3FC6,
	0xFFFD: 0x3FC7,
	0xFFFD: 0x3FC8,
	0xFFFD: 0x3FC9,
	0xFFFD: 0x3FCA,
	0xFFFD: 0x3FCB,
	0xFFFD: 0x3FCC,
	0xFFFD: 0x3FCD,
	0xFFFD: 0x3FCE,
	0xFFFD: 0x3FCF,
	0xFFFD: 0x3FD0,
	0xFFFD: 0x3FD1,
	0xFFFD: 0x3FD2,
	0xFFFD: 0x3FD3,
	0xFFFD: 0x3FD4,
	0xFFFD: 0x3FD5,
	0xFFFD: 0x3FD6,
	0xFFFD: 0x3FD7,
	0xFFFD: 0x3FD8,
	0xFFFD: 0x3FD9,
	0xFFFD: 0x3FDA,
	0xFFFD: 0x3FDB,
	0xFFFD: 0x3FDC,
	0xFFFD: 0x3FDD,
	0xFFFD: 0x3FDE,
	0xFFFD: 0x3FDF,
	0xFFFD: 0x3FE0,
	0xFFFD: 0x3FE1,
	0xFFFD: 0x3FE2,
	0xFFFD: 0x3FE3,
	0xFFFD: 0x3FE4,
	0xFFFD: 0x3FE5,
	0xFFFD: 0x3FE6,
	0xFFFD: 0x3FE7,
	0xFFFD: 0x3FE8,
	0xFFFD: 0x3FE9,
	0xFFFD: 0x3FEA,
	0xFFFD: 0x3FEB,
	0xFFFD: 0x3FEC,
	0xFFFD: 0x3FED,
	0xFFFD: 0x3FEE,
	0xFFFD: 0x3FEF,
	0xFFFD: 0x3FF0,
	0xFFFD: 0x3FF1,
	0xFFFD: 0x3FF2,
	0xFFFD: 0x3FF3,
	0xFFFD: 0x3FF4,
	0xFFFD: 0x3FF5,
	0xFFFD: 0x3FF6,
	0xFFFD: 0x3FF7,
	0xFFFD: 0x3FF8,
	0xFFFD: 0x3FF9,
	0xFFFD: 0x3FFA,
	0xFFFD: 0x3FFB,
	0xFFFD: 0x3FFC,
	0xFFFD: 0x3FFD,
	0xFFFD: 0x3FFE,
	0xFFFD: 0x3FFF,
	0xFFFD: 0x4000,
	0xFFFD: 0x4001,
	0xFFFD: 0x4002,
	0xFFFD: 0x4003,
	0xFFFD: 0x4004,
	0xFFFD: 0x4005,
	0xFFFD: 0x4006,
	0xFFFD: 0x4007,
	0xFFFD: 0x4008,
	0xFFFD: 0x4009,
	0xFFFD: 0x400A,
	0xFFFD: 0x400B,
	0xFFFD: 0x400C,
	0xFFFD: 0x400D,
	0xFFFD: 0x400E,
	0xFFFD: 0x400F,
	0xFFFD: 0x4010,
	0xFFFD: 0x4011,
	0xFFFD: 0x4012,
	0xFFFD: 0x4013,
	0xFFFD: 0x4014,
	0xFFFD: 0x4015,
	0xFFFD: 0x4016,
	0xFFFD: 0x4017,
	0xFFFD: 0x4018,
	0xFFFD: 0x4019,
	0xFFFD: 0x401A,
	0xFFFD: 0x401B,
	0xFFFD: 0x401C,
	0xFFFD: 0x401D,
	0xFFFD: 0x401E,
	0xFFFD: 0x401F,
	0xFFFD: 0x4020,
	0xFFFD: 0x4021,
	0xFFFD: 0x4022,
	0xFFFD: 0x4023,
	0xFFFD: 0x4024,
	0xFFFD: 0x4025,
	0xFFFD: 0x4026,
	0xFFFD: 0x4027,
	0xFFFD: 0x4028,
	0xFFFD: 0x4029,
	0xFFFD: 0x402A,
	0xFFFD: 0x402B,
	0xFFFD: 0x402C,
	0xFFFD: 0x402D,
	0xFFFD: 0x402E,
	0xFFFD: 0x402F,
	0xFFFD: 0x4030,
	0xFFFD: 0x4031,
	0xFFFD: 0x4032,
	0xFFFD: 0x4033,
	0xFFFD: 0x4034,
	0xFFFD: 0x4035,
	0xFFFD: 0x4036,
	0xFFFD: 0x4037,
	0xFFFD: 0x4038,
	0xFFFD: 0x4039,
	0xFFFD: 0x403A,
	0xFFFD: 0x403B,
	0xFFFD: 0x403C,
	0xFFFD: 0x403D,
	0xFFFD: 0x403E,
	0xFFFD: 0x403F,
	0xFFFD: 0x4040,
	0xFFFD: 0x4041,
	0xFFFD: 0x4042,
	0xFFFD: 0x4043,
	0xFFFD: 0x4044,
	0xFFFD: 0x4045,
	0xFFFD: 0x4046,
	0xFFFD: 0x4047,
	0xFFFD: 0x4048,
	0xFFFD: 0x4049,
	0xFFFD: 0x404A,
	0xFFFD: 0x404B,
	0xFFFD: 0x404C,
	0xFFFD: 0x404D,
	0xFFFD: 0x404E,
	0xFFFD: 0x404F,
	0xFFFD: 0x4050,
	0xFFFD: 0x4051,
	0xFFFD: 0x4052,
	0xFFFD: 0x4053,
	0xFFFD: 0x4054,
	0xFFFD: 0x4055,
	0xFFFD: 0x4056,
	0xFFFD: 0x4057,
	0xFFFD: 0x4058,
	0xFFFD: 0x4059,
	0xFFFD: 0x405A,
	0xFFFD: 0x405B,
	0xFFFD: 0x405C,
	0xFFFD: 0x405D,
	0xFFFD: 0x405E,
	0xFFFD: 0x405F,
	0xFFFD: 0x4060,
	0xFFFD: 0x4061,
	0xFFFD: 0x4062,
	0xFFFD: 0x4063,
	0xFFFD: 0x4064,
	0xFCC2: 0x4065,
	0xFFFD: 0x4066,
	0xFFFD: 0x4067,
	0xFFFD: 0x4068,
	0xFFFD: 0x4069,
	0xFFFD: 0x406A,
	0xFFFD: 0x406B,
	0xFFFD: 0x406C,
	0xFFFD: 0x406D,
	0xFFFD: 0x406E,
	0xFFFD: 0x406F,
	0xFFFD: 0x4070,
	0xFFFD: 0x4071,
	0xFFFD: 0x4072,
	0xFFFD: 0x4073,
	0xFFFD: 0x4074,
	0xFFFD: 0x4075,
	0xFFFD: 0x4076,
	0xFFFD: 0x4077,
	0xFFFD: 0x4078,
	0xFFFD: 0x4079,
	0xFFFD: 0x407A,
	0xFFFD: 0x407B,
	0xFFFD: 0x407C,
	0xFFFD: 0x407D,
	0xFFFD: 0x407E,
	0xFFFD: 0x407F,
	0xFFFD: 0x4080,
	0xFFFD: 0x4081,
	0xFFFD: 0x4082,
	0xFFFD: 0x4083,
	0xFFFD: 0x4084,
	0xFFFD: 0x4085,
	0xFFFD: 0x4086,
	0xFFFD: 0x4087,
	0xFFFD: 0x4088,
	0xFFFD: 0x4089,
	0xFFFD: 0x408A,
	0xFFFD: 0x408B,
	0xFFFD: 0x408C,
	0xFFFD: 0x408D,
	0xFFFD: 0x408E,
	0xFFFD: 0x408F,
	0xFFFD: 0x4090,
	0xFFFD: 0x4091,
	0xFFFD: 0x4092,
	0xFFFD: 0x4093,
	0xFFFD: 0x4094,
	0xFFFD: 0x4095,
	0xFFFD: 0x4096,
	0xFFFD: 0x4097,
	0xFFFD: 0x4098,
	0xFFFD: 0x4099,
	0xFFFD: 0x409A,
	0xFFFD: 0x409B,
	0xFFFD: 0x409C,
	0xFFFD: 0x409D,
	0xFFFD: 0x409E,
	0xFFFD: 0x409F,
	0xFFFD: 0x40A0,
	0xFFFD: 0x40A1,
	0xFFFD: 0x40A2,
	0xFFFD: 0x40A3,
	0xFFFD: 0x40A4,
	0xFFFD: 0x40A5,
	0xFFFD: 0x40A6,
	0xFFFD: 0x40A7,
	0xFFFD: 0x40A8,
	0xFFFD: 0x40A9,
	0xFFFD: 0x40AA,
	0xFFFD: 0x40AB,
	0xFFFD: 0x40AC,
	0xFFFD: 0x40AD,
	0xFFFD: 0x40AE,
	0xFFFD: 0x40AF,
	0xFFFD: 0x40B0,
	0xFFFD: 0x40B1,
	0xFFFD: 0x40B2,
	0xFFFD: 0x40B3,
	0xFFFD: 0x40B4,
	0xFFFD: 0x40B5,
	0xFFFD: 0x40B6,
	0xFFFD: 0x40B7,
	0xFFFD: 0x40B8,
	0xFFFD: 0x40B9,
	0xFFFD: 0x40BA,
	0xFFFD: 0x40BB,
	0xFFFD: 0x40BC,
	0xFFFD: 0x40BD,
	0xFFFD: 0x40BE,
	0xFFFD: 0x40BF,
	0xFFFD: 0x40C0,
	0xFFFD: 0x40C1,
	0xFFFD: 0x40C2,
	0xFFFD: 0x40C3,
	0xFFFD: 0x40C4,
	0xFFFD: 0x40C5,
	0xFFFD: 0x40C6,
	0xFFFD: 0x40C7,
	0xFFFD: 0x40C8,
	0xFFFD: 0x40C9,
	0xFFFD: 0x40CA,
	0xFFFD: 0x40CB,
	0xFFFD: 0x40CC,
	0xFFFD: 0x40CD,
	0xFFFD: 0x40CE,
	0xFFFD: 0x40CF,
	0xFFFD: 0x40D0,
	0xFFFD: 0x40D1,
	0xFFFD: 0x40D2,
	0xFFFD: 0x40D3,
	0xFFFD: 0x40D4,
	0xFFFD: 0x40D5,
	0xFFFD: 0x40D6,
	0xFFFD: 0x40D7,
	0xFFFD: 0x40D8,
	0xFFFD: 0x40D9,
	0xFFFD: 0x40DA,
	0xFFFD: 0x40DB,
	0xFFFD: 0x40DC,
	0xFFFD: 0x40DD,
	0xFFFD: 0x40DE,
	0xFE4D: 0x40DF,
	0xFFFD: 0x40E0,
	0xFFFD: 0x40E1,
	0xFFFD: 0x40E2,
	0xFFFD: 0x40E3,
	0xFFFD: 0x40E4,
	0xFFFD: 0x40E5,
	0xFFFD: 0x40E6,
	0xFFFD: 0x40E7,
	0xFFFD: 0x40E8,
	0xFFFD: 0x40E9,
	0xFFFD: 0x40EA,
	0xFFFD: 0x40EB,
	0xFFFD: 0x40EC,
	0xFFFD: 0x40ED,
	0xFFFD: 0x40EE,
	0xFFFD: 0x40EF,
	0xFFFD: 0x40F0,
	0xFFFD: 0x40F1,
	0xFFFD: 0x40F2,
	0xFFFD: 0x40F3,
	0xFFFD: 0x40F4,
	0xFFFD: 0x40F5,
	0xFFFD: 0x40F6,
	0xFFFD: 0x40F7,
	0xFFFD: 0x40F8,
	0xFFFD: 0x40F9,
	0xFFFD: 0x40FA,
	0xFFFD: 0x40FB,
	0xFFFD: 0x40FC,
	0xFFFD: 0x40FD,
	0xFFFD: 0x40FE,
	0xFFFD: 0x40FF,
	0xFFFD: 0x4100,
	0xFFFD: 0x4101,
	0xFFFD: 0x4102,
	0xFFFD: 0x4103,
	0xFFFD: 0x4104,
	0xFFFD: 0x4105,
	0xFFFD: 0x4106,
	0xFFFD: 0x4107,
	0xFFFD: 0x4108,
	0xFFFD: 0x4109,
	0xFFFD: 0x410A,
	0xFFFD: 0x410B,
	0xFFFD: 0x410C,
	0xFFFD: 0x410D,
	0xFFFD: 0x410E,
	0xFFFD: 0x410F,
	0xFFFD: 0x4110,
	0xFFFD: 0x4111,
	0xFFFD: 0x4112,
	0xFFFD: 0x4113,
	0xFFFD: 0x4114,
	0xFFFD: 0x4115,
	0xFFFD: 0x4116,
	0xFFFD: 0x4117,
	0xFFFD: 0x4118,
	0xFFFD: 0x4119,
	0xFFFD: 0x411A,
	0xFFFD: 0x411B,
	0xFFFD: 0x411C,
	0xFFFD: 0x411D,
	0xFFFD: 0x411E,
	0xFFFD: 0x411F,
	0xFFFD: 0x4120,
	0xFFFD: 0x4121,
	0xFFFD: 0x4122,
	0xFFFD: 0x4123,
	0xFFFD: 0x4124,
	0xFFFD: 0x4125,
	0xFFFD: 0x4126,
	0xFFFD: 0x4127,
	0xFFFD: 0x4128,
	0xFFFD: 0x4129,
	0xFFFD: 0x412A,
	0xFFFD: 0x412B,
	0xFFFD: 0x412C,
	0xFFFD: 0x412D,
	0xFFFD: 0x412E,
	0xFFFD: 0x412F,
	0xFFFD: 0x4130,
	0xFFFD: 0x4131,
	0xFFFD: 0x4132,
	0xFFFD: 0x4133,
	0xFFFD: 0x4134,
	0xFFFD: 0x4135,
	0xFFFD: 0x4136,
	0xFFFD: 0x4137,
	0xFFFD: 0x4138,
	0xFFFD: 0x4139,
	0xFFFD: 0x413A,
	0xFFFD: 0x413B,
	0xFFFD: 0x413C,
	0xFFFD: 0x413D,
	0xFFFD: 0x413E,
	0xFFFD: 0x413F,
	0xFFFD: 0x4140,
	0xFFFD: 0x4141,
	0xFFFD: 0x4142,
	0xFFFD: 0x4143,
	0xFFFD: 0x4144,
	0xFFFD: 0x4145,
	0xFFFD: 0x4146,
	0xFFFD: 0x4147,
	0xFFFD: 0x4148,
	0xFFFD: 0x4149,
	0xFFFD: 0x414A,
	0xFFFD: 0x414B,
	0xFFFD: 0x414C,
	0xFFFD: 0x414D,
	0xFFFD: 0x414E,
	0xFFFD: 0x414F,
	0xFFFD: 0x4150,
	0xFFFD: 0x4151,
	0xFFFD: 0x4152,
	0xFFFD: 0x4153,
	0xFFFD: 0x4154,
	0xFFFD: 0x4155,
	0xFFFD: 0x4156,
	0xFFFD: 0x4157,
	0xFFFD: 0x4158,
	0xFFFD: 0x4159,
	0xFFFD: 0x415A,
	0xFFFD: 0x415B,
	0xFFFD: 0x415C,
	0xFFFD: 0x415D,
	0xFFFD: 0x415E,
	0xFFFD: 0x415F,
	0xFFFD: 0x4160,
	0xFFFD: 0x4161,
	0xFFFD: 0x4162,
	0xFFFD: 0x4163,
	0xFFFD: 0x4164,
	0xFFFD: 0x4165,
	0xFFFD: 0x4166,
	0xFFFD: 0x4167,
	0xFFFD: 0x4168,
	0xFFFD: 0x4169,
	0xFFFD: 0x416A,
	0xFFFD: 0x416B,
	0xFFFD: 0x416C,
	0xFFFD: 0x416D,
	0xFFFD: 0x416E,
	0xFFFD: 0x416F,
	0xFFFD: 0x4170,
	0xFFFD: 0x4171,
	0xFFFD: 0x4172,
	0xFFFD: 0x4173,
	0xFFFD: 0x4174,
	0xFFFD: 0x4175,
	0xFFFD: 0x4176,
	0xFFFD: 0x4177,
	0xFFFD: 0x4178,
	0xFFFD: 0x4179,
	0xFFFD: 0x417A,
	0xFFFD: 0x417B,
	0xFFFD: 0x417C,
	0xFFFD: 0x417D,
	0xFFFD: 0x417E,
	0xFFFD: 0x417F,
	0xFFFD: 0x4180,
	0xFFFD: 0x4181,
	0xFFFD: 0x4182,
	0xFFFD: 0x4183,
	0xFFFD: 0x4184,
	0xFFFD: 0x4185,
	0xFFFD: 0x4186,
	0xFFFD: 0x4187,
	0xFFFD: 0x4188,
	0xFFFD: 0x4189,
	0xFFFD: 0x418A,
	0xFFFD: 0x418B,
	0xFFFD: 0x418C,
	0xFFFD: 0x418D,
	0xFFFD: 0x418E,
	0xFFFD: 0x418F,
	0xFFFD: 0x4190,
	0xFFFD: 0x4191,
	0xFFFD: 0x4192,
	0xFFFD: 0x4193,
	0xFFFD: 0x4194,
	0xFFFD: 0x4195,
	0xFFFD: 0x4196,
	0xFFFD: 0x4197,
	0xFFFD: 0x4198,
	0xFFFD: 0x4199,
	0xFFFD: 0x419A,
	0xFFFD: 0x419B,
	0xFFFD: 0x419C,
	0xFFFD: 0x419D,
	0xFFFD: 0x419E,
	0xFFFD: 0x419F,
	0xFFFD: 0x41A0,
	0xFFFD: 0x41A1,
	0xFFFD: 0x41A2,
	0xFFFD: 0x41A3,
	0xFFFD: 0x41A4,
	0xFFFD: 0x41A5,
	0xFFFD: 0x41A6,
	0xFFFD: 0x41A7,
	0xFFFD: 0x41A8,
	0xFFFD: 0x41A9,
	0xFFFD: 0x41AA,
	0xFFFD: 0x41AB,
	0xFFFD: 0x41AC,
	0xFFFD: 0x41AD,
	0xFFFD: 0x41AE,
	0xFFFD: 0x41AF,
	0xFFFD: 0x41B0,
	0xFFFD: 0x41B1,
	0xFFFD: 0x41B2,
	0xFFFD: 0x41B3,
	0xFFFD: 0x41B4,
	0xFFFD: 0x41B5,
	0xFFFD: 0x41B6,
	0xFFFD: 0x41B7,
	0xFFFD: 0x41B8,
	0xFFFD: 0x41B9,
	0xFFFD: 0x41BA,
	0xFFFD: 0x41BB,
	0xFFFD: 0x41BC,
	0xFFFD: 0x41BD,
	0xFFFD: 0x41BE,
	0xFFFD: 0x41BF,
	0xFFFD: 0x41C0,
	0xFFFD: 0x41C1,
	0xFFFD: 0x41C2,
	0xFFFD: 0x41C3,
	0xFFFD: 0x41C4,
	0xFFFD: 0x41C5,
	0xFFFD: 0x41C6,
	0xFFFD: 0x41C7,
	0xFFFD: 0x41C8,
	0xFFFD: 0x41C9,
	0xFFFD: 0x41CA,
	0xFFFD: 0x41CB,
	0xFFFD: 0x41CC,
	0xFFFD: 0x41CD,
	0xFFFD: 0x41CE,
	0xFFFD: 0x41CF,
	0xFFFD: 0x41D0,
	0xFFFD: 0x41D1,
	0xFFFD: 0x41D2,
	0xFFFD: 0x41D3,
	0xFFFD: 0x41D4,
	0xFFFD: 0x41D5,
	0xFFFD: 0x41D6,
	0xFFFD: 0x41D7,
	0xFFFD: 0x41D8,
	0xFFFD: 0x41D9,
	0xFFFD: 0x41DA,
	0xFFFD: 0x41DB,
	0xFFFD: 0x41DC,
	0xFFFD: 0x41DD,
	0xFFFD: 0x41DE,
	0xFFFD: 0x41DF,
	0xFFFD: 0x41E0,
	0xFFFD: 0x41E1,
	0xFFFD: 0x41E2,
	0xFFFD: 0x41E3,
	0xFFFD: 0x41E4,
	0xFFFD: 0x41E5,
	0xFFFD: 0x41E6,
	0xFFFD: 0x41E7,
	0xFFFD: 0x41E8,
	0xFFFD: 0x41E9,
	0xFFFD: 0x41EA,
	0xFFFD: 0x41EB,
	0xFFFD: 0x41EC,
	0xFFFD: 0x41ED,
	0xFFFD: 0x41EE,
	0xFFFD: 0x41EF,
	0xFFFD: 0x41F0,
	0xFFFD: 0x41F1,
	0xFFFD: 0x41F2,
	0xFFFD: 0x41F3,
	0xFFFD: 0x41F4,
	0xFFFD: 0x41F5,
	0xFFFD: 0x41F6,
	0xFFFD: 0x41F7,
	0xFFFD: 0x41F8,
	0xFFFD: 0x41F9,
	0xFFFD: 0x41FA,
	0xFFFD: 0x41FB,
	0xFFFD: 0x41FC,
	0xFFFD: 0x41FD,
	0xFFFD: 0x41FE,
	0xFFFD: 0x41FF,
	0xFFFD: 0x4200,
	0xFFFD: 0x4201,
	0xFFFD: 0x4202,
	0xFFFD: 0x4203,
	0xFFFD: 0x4204,
	0xFFFD: 0x4205,
	0xFFFD: 0x4206,
	0xFFFD: 0x4207,
	0xFFFD: 0x4208,
	0xFFFD: 0x4209,
	0xFFFD: 0x420A,
	0xFFFD: 0x420B,
	0xFFFD: 0x420C,
	0xFFFD: 0x420D,
	0xFFFD: 0x420E,
	0xFFFD: 0x420F,
	0xFFFD: 0x4210,
	0xFFFD: 0x4211,
	0xFFFD: 0x4212,
	0xFFFD: 0x4213,
	0xFFFD: 0x4214,
	0xFFFD: 0x4215,
	0xFFFD: 0x4216,
	0xFFFD: 0x4217,
	0xFFFD: 0x4218,
	0xFFFD: 0x4219,
	0xFFFD: 0x421A,
	0xFFFD: 0x421B,
	0xFFFD: 0x421C,
	0xFFFD: 0x421D,
	0xFFFD: 0x421E,
	0xFFFD: 0x421F,
	0xFFFD: 0x4220,
	0xFFFD: 0x4221,
	0xFFFD: 0x4222,
	0xFFFD: 0x4223,
	0xFFFD: 0x4224,
	0xFFFD: 0x4225,
	0xFFFD: 0x4226,
	0xFFFD: 0x4227,
	0xFFFD: 0x4228,
	0xFFFD: 0x4229,
	0xFFFD: 0x422A,
	0xFFFD: 0x422B,
	0xFFFD: 0x422C,
	0xFFFD: 0x422D,
	0xFFFD: 0x422E,
	0xFFFD: 0x422F,
	0xFFFD: 0x4230,
	0xFFFD: 0x4231,
	0xFFFD: 0x4232,
	0xFFFD: 0x4233,
	0xFFFD: 0x4234,
	0xFFFD: 0x4235,
	0xFFFD: 0x4236,
	0xFFFD: 0x4237,
	0xFFFD: 0x4238,
	0xFFFD: 0x4239,
	0xFFFD: 0x423A,
	0xFFFD: 0x423B,
	0xFFFD: 0x423C,
	0xFFFD: 0x423D,
	0xFFFD: 0x423E,
	0xFFFD: 0x423F,
	0xFFFD: 0x4240,
	0xFFFD: 0x4241,
	0xFFFD: 0x4242,
	0xFFFD: 0x4243,
	0xFFFD: 0x4244,
	0xFFFD: 0x4245,
	0xFFFD: 0x4246,
	0xFFFD: 0x4247,
	0xFFFD: 0x4248,
	0xFFFD: 0x4249,
	0xFFFD: 0x424A,
	0xFFFD: 0x424B,
	0xFFFD: 0x424C,
	0xFFFD: 0x424D,
	0xFFFD: 0x424E,
	0xFFFD: 0x424F,
	0xFFFD: 0x4250,
	0xFFFD: 0x4251,
	0xFFFD: 0x4252,
	0xFFFD: 0x4253,
	0xFFFD: 0x4254,
	0xFFFD: 0x4255,
	0xFFFD: 0x4256,
	0xFFFD: 0x4257,
	0xFFFD: 0x4258,
	0xFFFD: 0x4259,
	0xFFFD: 0x425A,
	0xFFFD: 0x425B,
	0xFFFD: 0x425C,
	0xFFFD: 0x425D,
	0xFFFD: 0x425E,
	0xFFFD: 0x425F,
	0xFFFD: 0x4260,
	0xFFFD: 0x4261,
	0xFFFD: 0x4262,
	0xFFFD: 0x4263,
	0xFFFD: 0x4264,
	0xFFFD: 0x4265,
	0xFFFD: 0x4266,
	0xFFFD: 0x4267,
	0xFFFD: 0x4268,
	0xFFFD: 0x4269,
	0xFFFD: 0x426A,
	0xFFFD: 0x426B,
	0xFFFD: 0x426C,
	0xFFFD: 0x426D,
	0xFFFD: 0x426E,
	0xFFFD: 0x426F,
	0xFFFD: 0x4270,
	0xFFFD: 0x4271,
	0xFFFD: 0x4272,
	0xFFFD: 0x4273,
	0xFFFD: 0x4274,
	0xFFFD: 0x4275,
	0xFFFD: 0x4276,
	0xFFFD: 0x4277,
	0xFFFD: 0x4278,
	0xFFFD: 0x4279,
	0xFFFD: 0x427A,
	0xFFFD: 0x427B,
	0xFFFD: 0x427C,
	0xFFFD: 0x427D,
	0xFFFD: 0x427E,
	0xFFFD: 0x427F,
	0xFFFD: 0x4280,
	0xFFFD: 0x4281,
	0xFFFD: 0x4282,
	0xFFFD: 0x4283,
	0xFFFD: 0x4284,
	0xFFFD: 0x4285,
	0xFFFD: 0x4286,
	0xFFFD: 0x4287,
	0xFFFD: 0x4288,
	0xFFFD: 0x4289,
	0xFFFD: 0x428A,
	0xFFFD: 0x428B,
	0xFFFD: 0x428C,
	0xFFFD: 0x428D,
	0xFFFD: 0x428E,
	0xFFFD: 0x428F,
	0xFFFD: 0x4290,
	0xFFFD: 0x4291,
	0xFFFD: 0x4292,
	0xFFFD: 0x4293,
	0xFFFD: 0x4294,
	0xFFFD: 0x4295,
	0xFFFD: 0x4296,
	0xFFFD: 0x4297,
	0xFFFD: 0x4298,
	0xFFFD: 0x4299,
	0xFFFD: 0x429A,
	0xFFFD: 0x429B,
	0xFFFD: 0x429C,
	0xFFFD: 0x429D,
	0xFFFD: 0x429E,
	0xFFFD: 0x429F,
	0xFFFD: 0x42A0,
	0xFFFD: 0x42A1,
	0xFFFD: 0x42A2,
	0xFFFD: 0x42A3,
	0xFFFD: 0x42A4,
	0xFFFD: 0x42A5,
	0xFFFD: 0x42A6,
	0xFFFD: 0x42A7,
	0xFFFD: 0x42A8,
	0xFFFD: 0x42A9,
	0xFFFD: 0x42AA,
	0xFFFD: 0x42AB,
	0xFFFD: 0x42AC,
	0xFFFD: 0x42AD,
	0xFFFD: 0x42AE,
	0xFFFD: 0x42AF,
	0xFFFD: 0x42B0,
	0xFFFD: 0x42B1,
	0xFFFD: 0x42B2,
	0xFFFD: 0x42B3,
	0xFFFD: 0x42B4,
	0xFFFD: 0x42B5,
	0xFFFD: 0x42B6,
	0xFFFD: 0x42B7,
	0xFFFD: 0x42B8,
	0xFFFD: 0x42B9,
	0xFFFD: 0x42BA,
	0xFFFD: 0x42BB,
	0xFFFD: 0x42BC,
	0xFFFD: 0x42BD,
	0xFFFD: 0x42BE,
	0xFFFD: 0x42BF,
	0xFFFD: 0x42C0,
	0xFFFD: 0x42C1,
	0xFFFD: 0x42C2,
	0xFFFD: 0x42C3,
	0xFFFD: 0x42C4,
	0xFFFD: 0x42C5,
	0xFFFD: 0x42C6,
	0xFFFD: 0x42C7,
	0xFFFD: 0x42C8,
	0xFFFD: 0x42C9,
	0xFFFD: 0x42CA,
	0xFFFD: 0x42CB,
	0xFFFD: 0x42CC,
	0xFFFD: 0x42CD,
	0xFFFD: 0x42CE,
	0xFFFD: 0x42CF,
	0xFFFD: 0x42D0,
	0xFFFD: 0x42D1,
	0xFFFD: 0x42D2,
	0xFFFD: 0x42D3,
	0xFFFD: 0x42D4,
	0xFFFD: 0x42D5,
	0xFFFD: 0x42D6,
	0xFFFD: 0x42D7,
	0xFFFD: 0x42D8,
	0xFFFD: 0x42D9,
	0xFFFD: 0x42DA,
	0xFFFD: 0x42DB,
	0xFFFD: 0x42DC,
	0xFFFD: 0x42DD,
	0xFFFD: 0x42DE,
	0xFFFD: 0x42DF,
	0xFFFD: 0x42E0,
	0xFFFD: 0x42E1,
	0xFFFD: 0x42E2,
	0xFFFD: 0x42E3,
	0xFFFD: 0x42E4,
	0xFFFD: 0x42E5,
	0xFFFD: 0x42E6,
	0xFFFD: 0x42E7,
	0xFFFD: 0x42E8,
	0xFFFD: 0x42E9,
	0xFFFD: 0x42EA,
	0xFFFD: 0x42EB,
	0xFFFD: 0x42EC,
	0xFFFD: 0x42ED,
	0xFFFD: 0x42EE,
	0xFFFD: 0x42EF,
	0xFFFD: 0x42F0,
	0xFFFD: 0x42F1,
	0xFFFD: 0x42F2,
	0xFFFD: 0x42F3,
	0xFFFD: 0x42F4,
	0xFFFD: 0x42F5,
	0xFFFD: 0x42F6,
	0xFFFD: 0x42F7,
	0xFFFD: 0x42F8,
	0xFFFD: 0x42F9,
	0xFFFD: 0x42FA,
	0xFFFD: 0x42FB,
	0xFFFD: 0x42FC,
	0xFFFD: 0x42FD,
	0xFFFD: 0x42FE,
	0xFFFD: 0x42FF,
	0xFFFD: 0x4300,
	0xFFFD: 0x4301,
	0xFFFD: 0x4302,
	0xFFFD: 0x4303,
	0xFFFD: 0x4304,
	0xFFFD: 0x4305,
	0xFFFD: 0x4306,
	0xFFFD: 0x4307,
	0xFFFD: 0x4308,
	0xFFFD: 0x4309,
	0xFFFD: 0x430A,
	0xFFFD: 0x430B,
	0xFFFD: 0x430C,
	0xFFFD: 0x430D,
	0xFFFD: 0x430E,
	0xFFFD: 0x430F,
	0xFFFD: 0x4310,
	0xFFFD: 0x4311,
	0xFFFD: 0x4312,
	0xFFFD: 0x4313,
	0xFFFD: 0x4314,
	0xFFFD: 0x4315,
	0xFFFD: 0x4316,
	0xFFFD: 0x4317,
	0xFFFD: 0x4318,
	0xFFFD: 0x4319,
	0xFFFD: 0x431A,
	0xFFFD: 0x431B,
	0xFFFD: 0x431C,
	0xFFFD: 0x431D,
	0xFFFD: 0x431E,
	0xFFFD: 0x431F,
	0xFFFD: 0x4320,
	0xFFFD: 0x4321,
	0xFFFD: 0x4322,
	0xFFFD: 0x4323,
	0xFFFD: 0x4324,
	0xFFFD: 0x4325,
	0xFFFD: 0x4326,
	0xFFFD: 0x4327,
	0xFFFD: 0x4328,
	0xFFFD: 0x4329,
	0xFFFD: 0x432A,
	0xFFFD: 0x432B,
	0xFFFD: 0x432C,
	0xFFFD: 0x432D,
	0xFFFD: 0x432E,
	0xFFFD: 0x432F,
	0xFFFD: 0x4330,
	0xFFFD: 0x4331,
	0xFFFD: 0x4332,
	0xFFFD: 0x4333,
	0xFFFD: 0x4334,
	0xFFFD: 0x4335,
	0xFFFD: 0x4336,
	0xFFFD: 0x4337,
	0xFFFD: 0x4338,
	0xFFFD: 0x4339,
	0xFFFD: 0x433A,
	0xFFFD: 0x433B,
	0xFFFD: 0x433C,
	0xFFFD: 0x433D,
	0xFFFD: 0x433E,
	0xFFFD: 0x433F,
	0xFFFD: 0x4340,
	0xFFFD: 0x4341,
	0xFFFD: 0x4342,
	0xFFFD: 0x4343,
	0xFFFD: 0x4344,
	0xFFFD: 0x4345,
	0xFFFD: 0x4346,
	0xFFFD: 0x4347,
	0xFFFD: 0x4348,
	0xFFFD: 0x4349,
	0xFFFD: 0x434A,
	0xFFFD: 0x434B,
	0xFFFD: 0x434C,
	0xFFFD: 0x434D,
	0xFFFD: 0x434E,
	0xFFFD: 0x434F,
	0xFFFD: 0x4350,
	0xFFFD: 0x4351,
	0xFFFD: 0x4352,
	0xFFFD: 0x4353,
	0xFFFD: 0x4354,
	0xFFFD: 0x4355,
	0xFFFD: 0x4356,
	0xFFFD: 0x4357,
	0xFFFD: 0x4358,
	0xFFFD: 0x4359,
	0xFFFD: 0x435A,
	0xFFFD: 0x435B,
	0xFFFD: 0x435C,
	0xFFFD: 0x435D,
	0xFFFD: 0x435E,
	0xFFFD: 0x435F,
	0xFFFD: 0x4360,
	0xFFFD: 0x4361,
	0xFFFD: 0x4362,
	0xFFFD: 0x4363,
	0xFFFD: 0x4364,
	0xFFFD: 0x4365,
	0xFFFD: 0x4366,
	0xFFFD: 0x4367,
	0xFFFD: 0x4368,
	0xFFFD: 0x4369,
	0xFFFD: 0x436A,
	0xFFFD: 0x436B,
	0xFFFD: 0x436C,
	0xFFFD: 0x436D,
	0xFFFD: 0x436E,
	0xFFFD: 0x436F,
	0xFFFD: 0x4370,
	0xFFFD: 0x4371,
	0xFFFD: 0x4372,
	0xFFFD: 0x4373,
	0xFFFD: 0x4374,
	0xFFFD: 0x4375,
	0xFFFD: 0x4376,
	0xFFFD: 0x4377,
	0xFFFD: 0x4378,
	0xFFFD: 0x4379,
	0xFFFD: 0x437A,
	0xFFFD: 0x437B,
	0xFFFD: 0x437C,
	0xFFFD: 0x437D,
	0xFFFD: 0x437E,
	0xFFFD: 0x437F,
	0xFFFD: 0x4380,
	0xFFFD: 0x4381,
	0xFFFD: 0x4382,
	0xFFFD: 0x4383,
	0xFFFD: 0x4384,
	0xFFFD: 0x4385,
	0xFFFD: 0x4386,
	0xFFFD: 0x4387,
	0xFFFD: 0x4388,
	0xFFFD: 0x4389,
	0xFFFD: 0x438A,
	0xFFFD: 0x438B,
	0xFFFD: 0x438C,
	0xFFFD: 0x438D,
	0xFFFD: 0x438E,
	0xFFFD: 0x438F,
	0xFFFD: 0x4390,
	0xFFFD: 0x4391,
	0xFFFD: 0x4392,
	0xFFFD: 0x4393,
	0xFFFD: 0x4394,
	0xFFFD: 0x4395,
	0xFFFD: 0x4396,
	0xFFFD: 0x4397,
	0xFFFD: 0x4398,
	0xFFFD: 0x4399,
	0xFFFD: 0x439A,
	0xFFFD: 0x439B,
	0xFFFD: 0x439C,
	0xFFFD: 0x439D,
	0xFFFD: 0x439E,
	0xFFFD: 0x439F,
	0xFFFD: 0x43A0,
	0xFFFD: 0x43A1,
	0xFFFD: 0x43A2,
	0xFFFD: 0x43A3,
	0xFFFD: 0x43A4,
	0xFFFD: 0x43A5,
	0xFFFD: 0x43A6,
	0xFFFD: 0x43A7,
	0xFFFD: 0x43A8,
	0xFFFD: 0x43A9,
	0xFFFD: 0x43AA,
	0xFFFD: 0x43AB,
	0xFFFD: 0x43AC,
	0xFFFD: 0x43AD,
	0xFFFD: 0x43AE,
	0xFFFD: 0x43AF,
	0xFFFD: 0x43B0,
	0xFFFD: 0x43B1,
	0xFFFD: 0x43B2,
	0xFFFD: 0x43B3,
	0xFFFD: 0x43B4,
	0xFFFD: 0x43B5,
	0xFFFD: 0x43B6,
	0xFFFD: 0x43B7,
	0xFFFD: 0x43B8,
	0xFFFD: 0x43B9,
	0xFFFD: 0x43BA,
	0xFFFD: 0x43BB,
	0xFFFD: 0x43BC,
	0xFFFD: 0x43BD,
	0xFFFD: 0x43BE,
	0xFFFD: 0x43BF,
	0xFFFD: 0x43C0,
	0xFFFD: 0x43C1,
	0xFFFD: 0x43C2,
	0xFFFD: 0x43C3,
	0xFFFD: 0x43C4,
	0xFFFD: 0x43C5,
	0xFFFD: 0x43C6,
	0xFFFD: 0x43C7,
	0xFFFD: 0x43C8,
	0xFFFD: 0x43C9,
	0xFFFD: 0x43CA,
	0xFFFD: 0x43CB,
	0xFFFD: 0x43CC,
	0xFFFD: 0x43CD,
	0xFFFD: 0x43CE,
	0xFFFD: 0x43CF,
	0xFFFD: 0x43D0,
	0xFFFD: 0x43D1,
	0xFFFD: 0x43D2,
	0xFFFD: 0x43D3,
	0xFFFD: 0x43D4,
	0xFFFD: 0x43D5,
	0xFFFD: 0x43D6,
	0xFFFD: 0x43D7,
	0xFFFD: 0x43D8,
	0xFFFD: 0x43D9,
	0xFFFD: 0x43DA,
	0xFFFD: 0x43DB,
	0xFFFD: 0x43DC,
	0xFFFD: 0x43DD,
	0xFFFD: 0x43DE,
	0xFFFD: 0x43DF,
	0xFFFD: 0x43E0,
	0xFFFD: 0x43E1,
	0xFFFD: 0x43E2,
	0xFFFD: 0x43E3,
	0xFFFD: 0x43E4,
	0xFFFD: 0x43E5,
	0xFFFD: 0x43E6,
	0xFFFD: 0x43E7,
	0xFFFD: 0x43E8,
	0xFFFD: 0x43E9,
	0xFFFD: 0x43EA,
	0xFFFD: 0x43EB,
	0xFFFD: 0x43EC,
	0xFFFD: 0x43ED,
	0xFFFD: 0x43EE,
	0xFFFD: 0x43EF,
	0xFFFD: 0x43F0,
	0xFFFD: 0x43F1,
	0xFFFD: 0x43F2,
	0xFFFD: 0x43F3,
	0xFFFD: 0x43F4,
	0xFFFD: 0x43F5,
	0xFFFD: 0x43F6,
	0xFFFD: 0x43F7,
	0xFFFD: 0x43F8,
	0xFFFD: 0x43F9,
	0xFFFD: 0x43FA,
	0xFFFD: 0x43FB,
	0xFFFD: 0x43FC,
	0xFFFD: 0x43FD,
	0xFFFD: 0x43FE,
	0xFFFD: 0x43FF,
	0xFFFD: 0x4400,
	0xFFFD: 0x4401,
	0xFFFD: 0x4402,
	0xFFFD: 0x4403,
	0xFFFD: 0x4404,
	0xFFFD: 0x4405,
	0xFFFD: 0x4406,
	0xFFFD: 0x4407,
	0xFFFD: 0x4408,
	0xFFFD: 0x4409,
	0xFFFD: 0x440A,
	0xFFFD: 0x440B,
	0xFFFD: 0x440C,
	0xFFFD: 0x440D,
	0xFFFD: 0x440E,
	0xFFFD: 0x440F,
	0xFFFD: 0x4410,
	0xFFFD: 0x4411,
	0xFFFD: 0x4412,
	0xFFFD: 0x4413,
	0xFFFD: 0x4414,
	0xFFFD: 0x4415,
	0xFFFD: 0x4416,
	0xFFFD: 0x4417,
	0xFFFD: 0x4418,
	0xFFFD: 0x4419,
	0xFFFD: 0x441A,
	0xFFFD: 0x441B,
	0xFFFD: 0x441C,
	0xFFFD: 0x441D,
	0xFFFD: 0x441E,
	0xFFFD: 0x441F,
	0xFFFD: 0x4420,
	0xFFFD: 0x4421,
	0xFFFD: 0x4422,
	0xFFFD: 0x4423,
	0xFFFD: 0x4424,
	0xFFFD: 0x4425,
	0xFFFD: 0x4426,
	0xFFFD: 0x4427,
	0xFFFD: 0x4428,
	0xFFFD: 0x4429,
	0xFFFD: 0x442A,
	0xFFFD: 0x442B,
	0xFFFD: 0x442C,
	0xFFFD: 0x442D,
	0xFFFD: 0x442E,
	0xFFFD: 0x442F,
	0xFFFD: 0x4430,
	0xFFFD: 0x4431,
	0xFFFD: 0x4432,
	0xFFFD: 0x4433,
	0xFFFD: 0x4434,
	0xFFFD: 0x4435,
	0x96AD: 0x4436,
	0xFFFD: 0x4437,
	0xFFFD: 0x4438,
	0xFFFD: 0x4439,
	0xFFFD: 0x443A,
	0xFFFD: 0x443B,
	0xFFFD: 0x443C,
	0xFFFD: 0x443D,
	0xFFFD: 0x443E,
	0xFFFD: 0x443F,
	0xFFFD: 0x4440,
	0xFFFD: 0x4441,
	0xFFFD: 0x4442,
	0xFFFD: 0x4443,
	0xFFFD: 0x4444,
	0xFFFD: 0x4445,
	0xFFFD: 0x4446,
	0xFFFD: 0x4447,
	0xFFFD: 0x4448,
	0xFFFD: 0x4449,
	0xFFFD: 0x444A,
	0xFFFD: 0x444B,
	0xFFFD: 0x444C,
	0xFFFD: 0x444D,
	0xFFFD: 0x444E,
	0xFFFD: 0x444F,
	0xFFFD: 0x4450,
	0xFFFD: 0x4451,
	0xFFFD: 0x4452,
	0xFFFD: 0x4453,
	0xFFFD: 0x4454,
	0xFFFD: 0x4455,
	0xFFFD: 0x4456,
	0xFFFD: 0x4457,
	0xFFFD: 0x4458,
	0xFFFD: 0x4459,
	0xFFFD: 0x445A,
	0xFFFD: 0x445B,
	0xFFFD: 0x445C,
	0xFFFD: 0x445D,
	0xFFFD: 0x445E,
	0xFFFD: 0x445F,
	0xFFFD: 0x4460,
	0xFFFD: 0x4461,
	0xFFFD: 0x4462,
	0xFFFD: 0x4463,
	0xFFFD: 0x4464,
	0xFFFD: 0x4465,
	0xFFFD: 0x4466,
	0xFFFD: 0x4467,
	0xFFFD: 0x4468,
	0xFFFD: 0x4469,
	0xFFFD: 0x446A,
	0xFFFD: 0x446B,
	0xFFFD: 0x446C,
	0xFFFD: 0x446D,
	0xFFFD: 0x446E,
	0xFFFD: 0x446F,
	0xFFFD: 0x4470,
	0xFFFD: 0x4471,
	0xFFFD: 0x4472,
	0xFFFD: 0x4473,
	0xFFFD: 0x4474,
	0xFFFD: 0x4475,
	0xFFFD: 0x4476,
	0xFFFD: 0x4477,
	0xFFFD: 0x4478,
	0xFFFD: 0x4479,
	0xFFFD: 0x447A,
	0xFFFD: 0x447B,
	0xFFFD: 0x447C,
	0xFFFD: 0x447D,
	0xFFFD: 0x447E,
	0xFFFD: 0x447F,
	0xFFFD: 0x4480,
	0xFFFD: 0x4481,
	0xFFFD: 0x4482,
	0xFFFD: 0x4483,
	0xFFFD: 0x4484,
	0xFFFD: 0x4485,
	0xFFFD: 0x4486,
	0xFFFD: 0x4487,
	0xFFFD: 0x4488,
	0xFFFD: 0x4489,
	0xFFFD: 0x448A,
	0xFFFD: 0x448B,
	0xFFFD: 0x448C,
	0xFFFD: 0x448D,
	0xFFFD: 0x448E,
	0xFFFD: 0x448F,
	0xFFFD: 0x4490,
	0x9CD3: 0x4491,
	0xFFFD: 0x4492,
	0xFFFD: 0x4493,
	0xFFFD: 0x4494,
	0xFFFD: 0x4495,
	0xFFFD: 0x4496,
	0xFFFD: 0x4497,
	0xFFFD: 0x4498,
	0xFFFD: 0x4499,
	0xFFFD: 0x449A,
	0xFFFD: 0x449B,
	0xFFFD: 0x449C,
	0xFFFD: 0x449D,
	0xFFFD: 0x449E,
	0xFFFD: 0x449F,
	0xFFFD: 0x44A0,
	0xFFFD: 0x44A1,
	0xFFFD: 0x44A2,
	0xFFFD: 0x44A3,
	0xFFFD: 0x44A4,
	0xFFFD: 0x44A5,
	0xFFFD: 0x44A6,
	0xFFFD: 0x44A7,
	0xFFFD: 0x44A8,
	0xFFFD: 0x44A9,
	0xFFFD: 0x44AA,
	0xFFFD: 0x44AB,
	0xFFFD: 0x44AC,
	0xFFFD: 0x44AD,
	0xFFFD: 0x44AE,
	0xFFFD: 0x44AF,
	0xFFFD: 0x44B0,
	0xFFFD: 0x44B1,
	0xFFFD: 0x44B2,
	0xFFFD: 0x44B3,
	0xFFFD: 0x44B4,
	0xFFFD: 0x44B5,
	0xFFFD: 0x44B6,
	0xFD5E: 0x44B7,
	0xFFFD: 0x44B8,
	0xFFFD: 0x44B9,
	0xFFFD: 0x44BA,
	0xFFFD: 0x44BB,
	0xFFFD: 0x44BC,
	0xFFFD: 0x44BD,
	0xFFFD: 0x44BE,
	0xFFFD: 0x44BF,
	0xFFFD: 0x44C0,
	0xFFFD: 0x44C1,
	0xFFFD: 0x44C2,
	0xFFFD: 0x44C3,
	0xFFFD: 0x44C4,
	0xFFFD: 0x44C5,
	0xFFFD: 0x44C6,
	0xFFFD: 0x44C7,
	0xFFFD: 0x44C8,
	0xFFFD: 0x44C9,
	0xFFFD: 0x44CA,
	0xFFFD: 0x44CB,
	0xFFFD: 0x44CC,
	0xFFFD: 0x44CD,
	0xFFFD: 0x44CE,
	0xFFFD: 0x44CF,
	0xFFFD: 0x44D0,
	0xFFFD: 0x44D1,
	0xFFFD: 0x44D2,
	0xFFFD: 0x44D3,
	0xFFFD: 0x44D4,
	0xFFFD: 0x44D5,
	0xFFFD: 0x44D6,
	0xFFFD: 0x44D7,
	0xFFFD: 0x44D8,
	0xFFFD: 0x44D9,
	0xFFFD: 0x44DA,
	0xFFFD: 0x44DB,
	0xFFFD: 0x44DC,
	0xFFFD: 0x44DD,
	0xFFFD: 0x44DE,
	0xFFFD: 0x44DF,
	0xFFFD: 0x44E0,
	0xFFFD: 0x44E1,
	0xFFFD: 0x44E2,
	0xFFFD: 0x44E3,
	0xFFFD: 0x44E4,
	0xFFFD: 0x44E5,
	0xFFFD: 0x44E6,
	0xFFFD: 0x44E7,
	0xFFFD: 0x44E8,
	0xFFFD: 0x44E9,
	0xFE4A: 0x44EA,
	0xFFFD: 0x44EB,
	0xFFFD: 0x44EC,
	0xFFFD: 0x44ED,
	0xFFFD: 0x44EE,
	0xFFFD: 0x44EF,
	0xFFFD: 0x44F0,
	0xFFFD: 0x44F1,
	0xFFFD: 0x44F2,
	0xFFFD: 0x44F3,
	0xFFFD: 0x44F4,
	0xFFFD: 0x44F5,
	0xFFFD: 0x44F6,
	0xFFFD: 0x44F7,
	0xFFFD: 0x44F8,
	0xFFFD: 0x44F9,
	0xFFFD: 0x44FA,
	0xFD67: 0x44FB,
	0xFFFD: 0x44FC,
	0xFFFD: 0x44FD,
	0xFFFD: 0x44FE,
	0xFFFD: 0x44FF,
	0xFFFD: 0x4500,
	0xFFFD: 0x4501,
	0xFFFD: 0x4502,
	0xFFFD: 0x4503,
	0xFFFD: 0x4504,
	0xFFFD: 0x4505,
	0xFFFD: 0x4506,
	0xFFFD: 0x4507,
	0xFFFD: 0x4508,
	0xFFFD: 0x4509,
	0xFFFD: 0x450A,
	0xFFFD: 0x450B,
	0xFFFD: 0x450C,
	0xFFFD: 0x450D,
	0xFFFD: 0x450E,
	0xFFFD: 0x450F,
	0xFFFD: 0x4510,
	0xFFFD: 0x4511,
	0xFFFD: 0x4512,
	0xFFFD: 0x4513,
	0xFFFD: 0x4514,
	0xFFFD: 0x4515,
	0xFFFD: 0x4516,
	0xFFFD: 0x4517,
	0xFFFD: 0x4518,
	0xFFFD: 0x4519,
	0xFFFD: 0x451A,
	0xFFFD: 0x451B,
	0xFFFD: 0x451C,
	0xFFFD: 0x451D,
	0xFFFD: 0x451E,
	0xFFFD: 0x451F,
	0xFFFD: 0x4520,
	0xFFFD: 0x4521,
	0xFFFD: 0x4522,
	0xFFFD: 0x4523,
	0xFFFD: 0x4524,
	0xFFFD: 0x4525,
	0xFFFD: 0x4526,
	0xFFFD: 0x4527,
	0xFFFD: 0x4528,
	0xFFFD: 0x4529,
	0xFFFD: 0x452A,
	0xFFFD: 0x452B,
	0xFFFD: 0x452C,
	0xFFFD: 0x452D,
	0xFFFD: 0x452E,
	0xFFFD: 0x452F,
	0xFFFD: 0x4530,
	0xFFFD: 0x4531,
	0xFFFD: 0x4532,
	0xFFFD: 0x4533,
	0xFFFD: 0x4534,
	0xFFFD: 0x4535,
	0xFFFD: 0x4536,
	0xFFFD: 0x4537,
	0xFFFD: 0x4538,
	0xFFFD: 0x4539,
	0xFFFD: 0x453A,
	0xFFFD: 0x453B,
	0xFFFD: 0x453C,
	0xFFFD: 0x453D,
	0xFFFD: 0x453E,
	0xFFFD: 0x453F,
	0xFFFD: 0x4540,
	0xFFFD: 0x4541,
	0xFFFD: 0x4542,
	0xFFFD: 0x4543,
	0xFFFD: 0x4544,
	0xFFFD: 0x4545,
	0xFFFD: 0x4546,
	0xFFFD: 0x4547,
	0xFFFD: 0x4548,
	0xFFFD: 0x4549,
	0xFFFD: 0x454A,
	0xFFFD: 0x454B,
	0xFFFD: 0x454C,
	0xFFFD: 0x454D,
	0xFFFD: 0x454E,
	0xFFFD: 0x454F,
	0xFFFD: 0x4550,
	0xFFFD: 0x4551,
	0xFFFD: 0x4552,
	0xFFFD: 0x4553,
	0xFFFD: 0x4554,
	0xFFFD: 0x4555,
	0xFFFD: 0x4556,
	0xFFFD: 0x4557,
	0xFFFD: 0x4558,
	0xFFFD: 0x4559,
	0xFFFD: 0x455A,
	0xFFFD: 0x455B,
	0xFFFD: 0x455C,
	0xFFFD: 0x455D,
	0xFFFD: 0x455E,
	0xFFFD: 0x455F,
	0xFFFD: 0x4560,
	0xFFFD: 0x4561,
	0xFFFD: 0x4562,
	0xFFFD: 0x4563,
	0xFFFD: 0x4564,
	0xFFFD: 0x4565,
	0xFFFD: 0x4566,
	0xFFFD: 0x4567,
	0xFFFD: 0x4568,
	0xFFFD: 0x4569,
	0xFFFD: 0x456A,
	0xFFFD: 0x456B,
	0xFFFD: 0x456C,
	0xFFFD: 0x456D,
	0xFFFD: 0x456E,
	0xFFFD: 0x456F,
	0xFFFD: 0x4570,
	0xFFFD: 0x4571,
	0xFFFD: 0x4572,
	0xFFFD: 0x4573,
	0xFFFD: 0x4574,
	0xFFFD: 0x4575,
	0xFFFD: 0x4576,
	0xFFFD: 0x4577,
	0xFFFD: 0x4578,
	0xFFFD: 0x4579,
	0xFFFD: 0x457A,
	0xFFFD: 0x457B,
	0xFFFD: 0x457C,
	0xFFFD: 0x457D,
	0xFFFD: 0x457E,
	0xFFFD: 0x457F,
	0xFFFD: 0x4580,
	0xFFFD: 0x4581,
	0xFFFD: 0x4582,
	0xFFFD: 0x4583,
	0xFFFD: 0x4584,
	0xFFFD: 0x4585,
	0xFFFD: 0x4586,
	0xFFFD: 0x4587,
	0xFFFD: 0x4588,
	0xFFFD: 0x4589,
	0xFFFD: 0x458A,
	0xFFFD: 0x458B,
	0xFFFD: 0x458C,
	0xFFFD: 0x458D,
	0xFFFD: 0x458E,
	0xFFFD: 0x458F,
	0xFFFD: 0x4590,
	0xFFFD: 0x4591,
	0xFFFD: 0x4592,
	0xFFFD: 0x4593,
	0xFFFD: 0x4594,
	0xFFFD: 0x4595,
	0xFFFD: 0x4596,
	0xFFFD: 0x4597,
	0xFFFD: 0x4598,
	0xFFFD: 0x4599,
	0xFFFD: 0x459A,
	0xFFFD: 0x459B,
	0xFFFD: 0x459C,
	0xFFFD: 0x459D,
	0xFFFD: 0x459E,
	0xFFFD: 0x459F,
	0xFFFD: 0x45A0,
	0xFFFD: 0x45A1,
	0xFFFD: 0x45A2,
	0xFFFD: 0x45A3,
	0xFFFD: 0x45A4,
	0xFFFD: 0x45A5,
	0xFFFD: 0x45A6,
	0xFFFD: 0x45A7,
	0xFFFD: 0x45A8,
	0xFFFD: 0x45A9,
	0xFFFD: 0x45AA,
	0xFFFD: 0x45AB,
	0xFFFD: 0x45AC,
	0xFFFD: 0x45AD,
	0xFFFD: 0x45AE,
	0xFFFD: 0x45AF,
	0xFFFD: 0x45B0,
	0xFFFD: 0x45B1,
	0xFFFD: 0x45B2,
	0xFFFD: 0x45B3,
	0xFFFD: 0x45B4,
	0xFFFD: 0x45B5,
	0xFFFD: 0x45B6,
	0xFFFD: 0x45B7,
	0xFFFD: 0x45B8,
	0xFFFD: 0x45B9,
	0xFFFD: 0x45BA,
	0xFFFD: 0x45BB,
	0xFFFD: 0x45BC,
	0xFFFD: 0x45BD,
	0xFFFD: 0x45BE,
	0xFFFD: 0x45BF,
	0xFFFD: 0x45C0,
	0xFFFD: 0x45C1,
	0xFFFD: 0x45C2,
	0xFFFD: 0x45C3,
	0xFFFD: 0x45C4,
	0xFFFD: 0x45C5,
	0xFFFD: 0x45C6,
	0xFFFD: 0x45C7,
	0xFFFD: 0x45C8,
	0xFFFD: 0x45C9,
	0xFFFD: 0x45CA,
	0xFFFD: 0x45CB,
	0xFFFD: 0x45CC,
	0xFFFD: 0x45CD,
	0xFFFD: 0x45CE,
	0xFFFD: 0x45CF,
	0xFFFD: 0x45D0,
	0xFFFD: 0x45D1,
	0xFFFD: 0x45D2,
	0xFFFD: 0x45D3,
	0xFFFD: 0x45D4,
	0xFFFD: 0x45D5,
	0xFFFD: 0x45D6,
	0xFFFD: 0x45D7,
	0xFFFD: 0x45D8,
	0xFFFD: 0x45D9,
	0xFFFD: 0x45DA,
	0xFFFD: 0x45DB,
	0xFFFD: 0x45DC,
	0xFFFD: 0x45DD,
	0xFFFD: 0x45DE,
	0xFFFD: 0x45DF,
	0xFFFD: 0x45E0,
	0xFFFD: 0x45E1,
	0xFFFD: 0x45E2,
	0xFFFD: 0x45E3,
	0xFFFD: 0x45E4,
	0xFFFD: 0x45E5,
	0xFFFD: 0x45E6,
	0xFFFD: 0x45E7,
	0xFFFD: 0x45E8,
	0xFFFD: 0x45E9,
	0xFFFD: 0x45EA,
	0xFFFD: 0x45EB,
	0xFFFD: 0x45EC,
	0xFFFD: 0x45ED,
	0xFFFD: 0x45EE,
	0xFFFD: 0x45EF,
	0xFFFD: 0x45F0,
	0xFFFD: 0x45F1,
	0xFFFD: 0x45F2,
	0xFFFD: 0x45F3,
	0xFFFD: 0x45F4,
	0xFFFD: 0x45F5,
	0xFFFD: 0x45F6,
	0xFFFD: 0x45F7,
	0xFFFD: 0x45F8,
	0xFFFD: 0x45F9,
	0xFFFD: 0x45FA,
	0xFFFD: 0x45FB,
	0xFFFD: 0x45FC,
	0xFFFD: 0x45FD,
	0xFFFD: 0x45FE,
	0xFFFD: 0x45FF,
	0xFFFD: 0x4600,
	0xFFFD: 0x4601,
	0xFFFD: 0x4602,
	0xFFFD: 0x4603,
	0xFFFD: 0x4604,
	0xFFFD: 0x4605,
	0xFFFD: 0x4606,
	0xFFFD: 0x4607,
	0xFFFD: 0x4608,
	0xFFFD: 0x4609,
	0xFFFD: 0x460A,
	0xFFFD: 0x460B,
	0xFFFD: 0x460C,
	0xFFFD: 0x460D,
	0xFFFD: 0x460E,
	0xFBB0: 0x460F,
	0xFFFD: 0x4610,
	0xFFFD: 0x4611,
	0xFFFD: 0x4612,
	0xFFFD: 0x4613,
	0xFFFD: 0x4614,
	0xFFFD: 0x4615,
	0xFFFD: 0x4616,
	0xFFFD: 0x4617,
	0xFFFD: 0x4618,
	0xFFFD: 0x4619,
	0xFFFD: 0x461A,
	0xFFFD: 0x461B,
	0xFFFD: 0x461C,
	0xFFFD: 0x461D,
	0xFFFD: 0x461E,
	0xFFFD: 0x461F,
	0xFFFD: 0x4620,
	0xFFFD: 0x4621,
	0xFFFD: 0x4622,
	0xFFFD: 0x4623,
	0xFFFD: 0x4624,
	0xFFFD: 0x4625,
	0xFFFD: 0x4626,
	0xFFFD: 0x4627,
	0xFFFD: 0x4628,
	0xFFFD: 0x4629,
	0xFFFD: 0x462A,
	0xFFFD: 0x462B,
	0xFFFD: 0x462C,
	0xFFFD: 0x462D,
	0xFFFD: 0x462E,
	0xFFFD: 0x462F,
	0xFFFD: 0x4630,
	0xFFFD: 0x4631,
	0xFFFD: 0x4632,
	0xFFFD: 0x4633,
	0xFFFD: 0x4634,
	0xFFFD: 0x4635,
	0xFFFD: 0x4636,
	0xFFFD: 0x4637,
	0xFFFD: 0x4638,
	0xFFFD: 0x4639,
	0xFFFD: 0x463A,
	0xFFFD: 0x463B,
	0xFFFD: 0x463C,
	0xFFFD: 0x463D,
	0xFFFD: 0x463E,
	0xFFFD: 0x463F,
	0xFFFD: 0x4640,
	0xFFFD: 0x4641,
	0xFFFD: 0x4642,
	0xFFFD: 0x4643,
	0xFFFD: 0x4644,
	0xFFFD: 0x4645,
	0xFFFD: 0x4646,
	0xFFFD: 0x4647,
	0xFFFD: 0x4648,
	0xFFFD: 0x4649,
	0xFFFD: 0x464A,
	0xFFFD: 0x464B,
	0xFFFD: 0x464C,
	0xFFFD: 0x464D,
	0xFFFD: 0x464E,
	0xFFFD: 0x464F,
	0xFFFD: 0x4650,
	0xFFFD: 0x4651,
	0xFFFD: 0x4652,
	0xFFFD: 0x4653,
	0xFFFD: 0x4654,
	0xFFFD: 0x4655,
	0xFFFD: 0x4656,
	0xFFFD: 0x4657,
	0xFFFD: 0x4658,
	0xFFFD: 0x4659,
	0xFFFD: 0x465A,
	0xFFFD: 0x465B,
	0xFFFD: 0x465C,
	0xFFFD: 0x465D,
	0xFFFD: 0x465E,
	0xFFFD: 0x465F,
	0xFFFD: 0x4660,
	0xFFFD: 0x4661,
	0xFFFD: 0x4662,
	0xFFFD: 0x4663,
	0xFFFD: 0x4664,
	0xFFFD: 0x4665,
	0xFFFD: 0x4666,
	0xFFFD: 0x4667,
	0xFFFD: 0x4668,
	0xFFFD: 0x4669,
	0xFFFD: 0x466A,
	0xFFFD: 0x466B,
	0xFFFD: 0x466C,
	0xFFFD: 0x466D,
	0xFFFD: 0x466E,
	0xFFFD: 0x466F,
	0xFFFD: 0x4670,
	0xFFFD: 0x4671,
	0xFFFD: 0x4672,
	0xFFFD: 0x4673,
	0xFFFD: 0x4674,
	0xFFFD: 0x4675,
	0xFFFD: 0x4676,
	0xFFFD: 0x4677,
	0xFFFD: 0x4678,
	0xFFFD: 0x4679,
	0xFFFD: 0x467A,
	0xFFFD: 0x467B,
	0xFFFD: 0x467C,
	0xFFFD: 0x467D,
	0xFFFD: 0x467E,
	0xFFFD: 0x467F,
	0xFFFD: 0x4680,
	0xFFFD: 0x4681,
	0xFFFD: 0x4682,
	0xFFFD: 0x4683,
	0xFFFD: 0x4684,
	0xFFFD: 0x4685,
	0xFFFD: 0x4686,
	0xFFFD: 0x4687,
	0xFFFD: 0x4688,
	0xFFFD: 0x4689,
	0xFFFD: 0x468A,
	0xFFFD: 0x468B,
	0xFFFD: 0x468C,
	0xFFFD: 0x468D,
	0xFFFD: 0x468E,
	0xFFFD: 0x468F,
	0xFFFD: 0x4690,
	0xFFFD: 0x4691,
	0xFFFD: 0x4692,
	0xFFFD: 0x4693,
	0xFFFD: 0x4694,
	0xFFFD: 0x4695,
	0xFFFD: 0x4696,
	0xFFFD: 0x4697,
	0xFFFD: 0x4698,
	0xFFFD: 0x4699,
	0xFFFD: 0x469A,
	0xFFFD: 0x469B,
	0xFFFD: 0x469C,
	0xFFFD: 0x469D,
	0xFFFD: 0x469E,
	0xFFFD: 0x469F,
	0xFFFD: 0x46A0,
	0xFFFD: 0x46A1,
	0xFFFD: 0x46A2,
	0xFFFD: 0x46A3,
	0xFFFD: 0x46A4,
	0xFFFD: 0x46A5,
	0xFFFD: 0x46A6,
	0xFFFD: 0x46A7,
	0xFFFD: 0x46A8,
	0xFFFD: 0x46A9,
	0xFFFD: 0x46AA,
	0xFFFD: 0x46AB,
	0xFFFD: 0x46AC,
	0xFFFD: 0x46AD,
	0xFFFD: 0x46AE,
	0xFFFD: 0x46AF,
	0xFFFD: 0x46B0,
	0xFFFD: 0x46B1,
	0xFFFD: 0x46B2,
	0xFFFD: 0x46B3,
	0xFFFD: 0x46B4,
	0xFFFD: 0x46B5,
	0xFFFD: 0x46B6,
	0xFFFD: 0x46B7,
	0xFFFD: 0x46B8,
	0xFFFD: 0x46B9,
	0xFFFD: 0x46BA,
	0xFFFD: 0x46BB,
	0xFFFD: 0x46BC,
	0xFFFD: 0x46BD,
	0xFFFD: 0x46BE,
	0xFFFD: 0x46BF,
	0xFFFD: 0x46C0,
	0xFFFD: 0x46C1,
	0xFFFD: 0x46C2,
	0xFFFD: 0x46C3,
	0xFFFD: 0x46C4,
	0xFFFD: 0x46C5,
	0xFFFD: 0x46C6,
	0xFFFD: 0x46C7,
	0xFFFD: 0x46C8,
	0xFFFD: 0x46C9,
	0xFFFD: 0x46CA,
	0xFFFD: 0x46CB,
	0xFFFD: 0x46CC,
	0xFFFD: 0x46CD,
	0xFFFD: 0x46CE,
	0xFFFD: 0x46CF,
	0xFFFD: 0x46D0,
	0xFFFD: 0x46D1,
	0xFFFD: 0x46D2,
	0xFFFD: 0x46D3,
	0xFFFD: 0x46D4,
	0xFFFD: 0x46D5,
	0xFFFD: 0x46D6,
	0xFFFD: 0x46D7,
	0xFFFD: 0x46D8,
	0xFFFD: 0x46D9,
	0xFFFD: 0x46DA,
	0xFFFD: 0x46DB,
	0xFFFD: 0x46DC,
	0xFFFD: 0x46DD,
	0xFFFD: 0x46DE,
	0xFFFD: 0x46DF,
	0xFFFD: 0x46E0,
	0xFFFD: 0x46E1,
	0xFFFD: 0x46E2,
	0xFFFD: 0x46E3,
	0xFFFD: 0x46E4,
	0xFFFD: 0x46E5,
	0xFFFD: 0x46E6,
	0xFFFD: 0x46E7,
	0xFFFD: 0x46E8,
	0xFFFD: 0x46E9,
	0xFFFD: 0x46EA,
	0xFFFD: 0x46EB,
	0xFFFD: 0x46EC,
	0xFFFD: 0x46ED,
	0xFFFD: 0x46EE,
	0xFFFD: 0x46EF,
	0xFFFD: 0x46F0,
	0xFFFD: 0x46F1,
	0xFFFD: 0x46F2,
	0xFFFD: 0x46F3,
	0xFFFD: 0x46F4,
	0xFFFD: 0x46F5,
	0xFFFD: 0x46F6,
	0xFFFD: 0x46F7,
	0xFFFD: 0x46F8,
	0xFFFD: 0x46F9,
	0xFFFD: 0x46FA,
	0xFFFD: 0x46FB,
	0xFFFD: 0x46FC,
	0xFFFD: 0x46FD,
	0xFFFD: 0x46FE,
	0xFFFD: 0x46FF,
	0xFFFD: 0x4700,
	0xFFFD: 0x4701,
	0xFFFD: 0x4702,
	0xFFFD: 0x4703,
	0xFFFD: 0x4704,
	0xFFFD: 0x4705,
	0xFFFD: 0x4706,
	0xFFFD: 0x4707,
	0xFFFD: 0x4708,
	0xFFFD: 0x4709,
	0xFFFD: 0x470A,
	0xFFFD: 0x470B,
	0xFFFD: 0x470C,
	0xFFFD: 0x470D,
	0xFFFD: 0x470E,
	0xFFFD: 0x470F,
	0xFFFD: 0x4710,
	0xFFFD: 0x4711,
	0xFFFD: 0x4712,
	0xFFFD: 0x4713,
	0xFFFD: 0x4714,
	0xFFFD: 0x4715,
	0xFFFD: 0x4716,
	0xFFFD: 0x4717,
	0xFFFD: 0x4718,
	0xFFFD: 0x4719,
	0xFFFD: 0x471A,
	0xFFFD: 0x471B,
	0xFFFD: 0x471C,
	0xFFFD: 0x471D,
	0xFFFD: 0x471E,
	0xFFFD: 0x471F,
	0xFFFD: 0x4720,
	0xFFFD: 0x4721,
	0xFFFD: 0x4722,
	0xFFFD: 0x4723,
	0xFFFD: 0x4724,
	0xFFFD: 0x4725,
	0xFFFD: 0x4726,
	0xFFFD: 0x4727,
	0xFFFD: 0x4728,
	0xFFFD: 0x4729,
	0xFFFD: 0x472A,
	0xFFFD: 0x472B,
	0xFFFD: 0x472C,
	0xFFFD: 0x472D,
	0xFFFD: 0x472E,
	0xFFFD: 0x472F,
	0xFFFD: 0x4730,
	0xFFFD: 0x4731,
	0xFFFD: 0x4732,
	0xFFFD: 0x4733,
	0xFFFD: 0x4734,
	0xFFFD: 0x4735,
	0xFFFD: 0x4736,
	0xFFFD: 0x4737,
	0xFFFD: 0x4738,
	0xFFFD: 0x4739,
	0xFFFD: 0x473A,
	0xFFFD: 0x473B,
	0xFFFD: 0x473C,
	0xFFFD: 0x473D,
	0xFFFD: 0x473E,
	0xFFFD: 0x473F,
	0xFFFD: 0x4740,
	0xFFFD: 0x4741,
	0xFFFD: 0x4742,
	0xFFFD: 0x4743,
	0xFFFD: 0x4744,
	0xFFFD: 0x4745,
	0xFFFD: 0x4746,
	0xFFFD: 0x4747,
	0xFFFD: 0x4748,
	0xFFFD: 0x4749,
	0xFFFD: 0x474A,
	0xFFFD: 0x474B,
	0xFFFD: 0x474C,
	0xFFFD: 0x474D,
	0xFFFD: 0x474E,
	0xFFFD: 0x474F,
	0xFFFD: 0x4750,
	0xFFFD: 0x4751,
	0xFFFD: 0x4752,
	0xFFFD: 0x4753,
	0xFFFD: 0x4754,
	0xFFFD: 0x4755,
	0xFFFD: 0x4756,
	0xFFFD: 0x4757,
	0xFFFD: 0x4758,
	0xFFFD: 0x4759,
	0xFFFD: 0x475A,
	0xFFFD: 0x475B,
	0xFFFD: 0x475C,
	0xFFFD: 0x475D,
	0xFFFD: 0x475E,
	0xFFFD: 0x475F,
	0xFFFD: 0x4760,
	0xFFFD: 0x4761,
	0xFFFD: 0x4762,
	0xFFFD: 0x4763,
	0xFFFD: 0x4764,
	0xFFFD: 0x4765,
	0xFFFD: 0x4766,
	0xFFFD: 0x4767,
	0xFFFD: 0x4768,
	0xFFFD: 0x4769,
	0xFFFD: 0x476A,
	0xFFFD: 0x476B,
	0xFFFD: 0x476C,
	0xFFFD: 0x476D,
	0xFFFD: 0x476E,
	0xFFFD: 0x476F,
	0xFFFD: 0x4770,
	0xFFFD: 0x4771,
	0xFFFD: 0x4772,
	0xFFFD: 0x4773,
	0xFFFD: 0x4774,
	0xFFFD: 0x4775,
	0xFFFD: 0x4776,
	0xFFFD: 0x4777,
	0xFFFD: 0x4778,
	0xFFFD: 0x4779,
	0xFFFD: 0x477A,
	0xFFFD: 0x477B,
	0xFFFD: 0x477C,
	0xFFFD: 0x477D,
	0xFFFD: 0x477E,
	0xFFFD: 0x477F,
	0xFFFD: 0x4780,
	0xFFFD: 0x4781,
	0xFFFD: 0x4782,
	0xFFFD: 0x4783,
	0xFFFD: 0x4784,
	0xFFFD: 0x4785,
	0xFFFD: 0x4786,
	0xFFFD: 0x4787,
	0xFFFD: 0x4788,
	0xFFFD: 0x4789,
	0xFFFD: 0x478A,
	0xFFFD: 0x478B,
	0xFFFD: 0x478C,
	0xFFFD: 0x478D,
	0xFFFD: 0x478E,
	0xFFFD: 0x478F,
	0xFFFD: 0x4790,
	0xFFFD: 0x4791,
	0xFFFD: 0x4792,
	0xFFFD: 0x4793,
	0xFFFD: 0x4794,
	0xFFFD: 0x4795,
	0xFFFD: 0x4796,
	0xFFFD: 0x4797,
	0xFFFD: 0x4798,
	0xFFFD: 0x4799,
	0xFFFD: 0x479A,
	0xFFFD: 0x479B,
	0xFFFD: 0x479C,
	0xFFFD: 0x479D,
	0xFFFD: 0x479E,
	0xFFFD: 0x479F,
	0xFFFD: 0x47A0,
	0xFFFD: 0x47A1,
	0xFFFD: 0x47A2,
	0xFFFD: 0x47A3,
	0xFFFD: 0x47A4,
	0xFFFD: 0x47A5,
	0xFFFD: 0x47A6,
	0xFFFD: 0x47A7,
	0xFFFD: 0x47A8,
	0xFFFD: 0x47A9,
	0xFFFD: 0x47AA,
	0xFFFD: 0x47AB,
	0xFFFD: 0x47AC,
	0xFFFD: 0x47AD,
	0xFFFD: 0x47AE,
	0xFFFD: 0x47AF,
	0xFFFD: 0x47B0,
	0xFFFD: 0x47B1,
	0xFFFD: 0x47B2,
	0xFFFD: 0x47B3,
	0xFFFD: 0x47B4,
	0xFFFD: 0x47B5,
	0xFFFD: 0x47B6,
	0xFFFD: 0x47B7,
	0xFFFD: 0x47B8,
	0xFFFD: 0x47B9,
	0xFFFD: 0x47BA,
	0xFFFD: 0x47BB,
	0xFFFD: 0x47BC,
	0xFFFD: 0x47BD,
	0xFFFD: 0x47BE,
	0xFFFD: 0x47BF,
	0xFFFD: 0x47C0,
	0xFFFD: 0x47C1,
	0xFFFD: 0x47C2,
	0xFFFD: 0x47C3,
	0xFFFD: 0x47C4,
	0xFFFD: 0x47C5,
	0xFFFD: 0x47C6,
	0xFFFD: 0x47C7,
	0xFFFD: 0x47C8,
	0xFFFD: 0x47C9,
	0xFFFD: 0x47CA,
	0xFFFD: 0x47CB,
	0xFFFD: 0x47CC,
	0xFFFD: 0x47CD,
	0xFFFD: 0x47CE,
	0xFFFD: 0x47CF,
	0xFFFD: 0x47D0,
	0xFFFD: 0x47D1,
	0xFFFD: 0x47D2,
	0xFFFD: 0x47D3,
	0xFFFD: 0x47D4,
	0xFFFD: 0x47D5,
	0xFFFD: 0x47D6,
	0xFFFD: 0x47D7,
	0xFFFD: 0x47D8,
	0xFFFD: 0x47D9,
	0xFFFD: 0x47DA,
	0xFFFD: 0x47DB,
	0xFFFD: 0x47DC,
	0xFFFD: 0x47DD,
	0xFFFD: 0x47DE,
	0xFFFD: 0x47DF,
	0xFFFD: 0x47E0,
	0xFFFD: 0x47E1,
	0xFFFD: 0x47E2,
	0xFFFD: 0x47E3,
	0xFFFD: 0x47E4,
	0xFFFD: 0x47E5,
	0xFFFD: 0x47E6,
	0xFFFD: 0x47E7,
	0xFFFD: 0x47E8,
	0xFFFD: 0x47E9,
	0xFFFD: 0x47EA,
	0xFFFD: 0x47EB,
	0xFFFD: 0x47EC,
	0xFFFD: 0x47ED,
	0xFFFD: 0x47EE,
	0xFFFD: 0x47EF,
	0xFFFD: 0x47F0,
	0xFFFD: 0x47F1,
	0xFFFD: 0x47F2,
	0xFFFD: 0x47F3,
	0xFFFD: 0x47F4,
	0xFFFD: 0x47F5,
	0xFFFD: 0x47F6,
	0xFFFD: 0x47F7,
	0xFFFD: 0x47F8,
	0xFFFD: 0x47F9,
	0xFFFD: 0x47FA,
	0xFFFD: 0x47FB,
	0xFFFD: 0x47FC,
	0xFFFD: 0x47FD,
	0xFFFD: 0x47FE,
	0xFFFD: 0x47FF,
	0xFFFD: 0x4800,
	0xFFFD: 0x4801,
	0xFFFD: 0x4802,
	0xFFFD: 0x4803,
	0xFFFD: 0x4804,
	0xFFFD: 0x4805,
	0xFFFD: 0x4806,
	0xFFFD: 0x4807,
	0xFFFD: 0x4808,
	0xFFFD: 0x4809,
	0xFFFD: 0x480A,
	0xFFFD: 0x480B,
	0xFFFD: 0x480C,
	0xFFFD: 0x480D,
	0xFFFD: 0x480E,
	0xFFFD: 0x480F,
	0xFFFD: 0x4810,
	0xFFFD: 0x4811,
	0xFFFD: 0x4812,
	0xFFFD: 0x4813,
	0xFFFD: 0x4814,
	0xFFFD: 0x4815,
	0xFFFD: 0x4816,
	0xFFFD: 0x4817,
	0xFFFD: 0x4818,
	0xFFFD: 0x4819,
	0xFFFD: 0x481A,
	0xFFFD: 0x481B,
	0xFFFD: 0x481C,
	0xFFFD: 0x481D,
	0xFFFD: 0x481E,
	0xFFFD: 0x481F,
	0xFFFD: 0x4820,
	0xFFFD: 0x4821,
	0xFFFD: 0x4822,
	0xFFFD: 0x4823,
	0xFFFD: 0x4824,
	0xFFFD: 0x4825,
	0xFFFD: 0x4826,
	0xFFFD: 0x4827,
	0xFFFD: 0x4828,
	0xFFFD: 0x4829,
	0xFFFD: 0x482A,
	0xFFFD: 0x482B,
	0xFFFD: 0x482C,
	0xFFFD: 0x482D,
	0xFFFD: 0x482E,
	0xFFFD: 0x482F,
	0xFFFD: 0x4830,
	0xFFFD: 0x4831,
	0xFFFD: 0x4832,
	0xFFFD: 0x4833,
	0xFFFD: 0x4834,
	0xFFFD: 0x4835,
	0xFFFD: 0x4836,
	0xFFFD: 0x4837,
	0xFFFD: 0x4838,
	0xFFFD: 0x4839,
	0xFFFD: 0x483A,
	0xFFFD: 0x483B,
	0xFFFD: 0x483C,
	0xFFFD: 0x483D,
	0xFFFD: 0x483E,
	0xFFFD: 0x483F,
	0xFFFD: 0x4840,
	0xFFFD: 0x4841,
	0xFFFD: 0x4842,
	0xFFFD: 0x4843,
	0xFFFD: 0x4844,
	0xFFFD: 0x4845,
	0xFFFD: 0x4846,
	0xFFFD: 0x4847,
	0xFFFD: 0x4848,
	0xFFFD: 0x4849,
	0xFFFD: 0x484A,
	0xFFFD: 0x484B,
	0xFFFD: 0x484C,
	0xFFFD: 0x484D,
	0xFFFD: 0x484E,
	0xFFFD: 0x484F,
	0xFFFD: 0x4850,
	0xFFFD: 0x4851,
	0xFFFD: 0x4852,
	0xFFFD: 0x4853,
	0xFFFD: 0x4854,
	0xFFFD: 0x4855,
	0xFFFD: 0x4856,
	0xFFFD: 0x4857,
	0xFFFD: 0x4858,
	0xFFFD: 0x4859,
	0xFFFD: 0x485A,
	0xFFFD: 0x485B,
	0xFFFD: 0x485C,
	0xFFFD: 0x485D,
	0xFFFD: 0x485E,
	0xFFFD: 0x485F,
	0xFFFD: 0x4860,
	0xFFFD: 0x4861,
	0xFFFD: 0x4862,
	0xFFFD: 0x4863,
	0xFFFD: 0x4864,
	0xFFFD: 0x4865,
	0xFFFD: 0x4866,
	0xFFFD: 0x4867,
	0xFFFD: 0x4868,
	0xFFFD: 0x4869,
	0xFFFD: 0x486A,
	0xFFFD: 0x486B,
	0xFFFD: 0x486C,
	0xFFFD: 0x486D,
	0xFFFD: 0x486E,
	0xFFFD: 0x486F,
	0xFFFD: 0x4870,
	0xFFFD: 0x4871,
	0xFFFD: 0x4872,
	0xFFFD: 0x4873,
	0xFFFD: 0x4874,
	0xFFFD: 0x4875,
	0xFFFD: 0x4876,
	0xFFFD: 0x4877,
	0xFFFD: 0x4878,
	0xFFFD: 0x4879,
	0xFFFD: 0x487A,
	0xFFFD: 0x487B,
	0xFFFD: 0x487C,
	0xFFFD: 0x487D,
	0xFFFD: 0x487E,
	0xFFFD: 0x487F,
	0xFFFD: 0x4880,
	0xFFFD: 0x4881,
	0xFFFD: 0x4882,
	0xFFFD: 0x4883,
	0xFFFD: 0x4884,
	0xFFFD: 0x4885,
	0xFFFD: 0x4886,
	0xFFFD: 0x4887,
	0xFFFD: 0x4888,
	0xFFFD: 0x4889,
	0xFFFD: 0x488A,
	0xFFFD: 0x488B,
	0xFFFD: 0x488C,
	0xFFFD: 0x488D,
	0xFFFD: 0x488E,
	0xFFFD: 0x488F,
	0xFFFD: 0x4890,
	0xFFFD: 0x4891,
	0xFFFD: 0x4892,
	0xFFFD: 0x4893,
	0xFFFD: 0x4894,
	0xFFFD: 0x4895,
	0xFFFD: 0x4896,
	0xFFFD: 0x4897,
	0xFFFD: 0x4898,
	0xFFFD: 0x4899,
	0xFFFD: 0x489A,
	0xFFFD: 0x489B,
	0xFFFD: 0x489C,
	0xFFFD: 0x489D,
	0xFFFD: 0x489E,
	0xFFFD: 0x489F,
	0xFFFD: 0x48A0,
	0xFFFD: 0x48A1,
	0xFFFD: 0x48A2,
	0xFFFD: 0x48A3,
	0xFFFD: 0x48A4,
	0xFFFD: 0x48A5,
	0xFFFD: 0x48A6,
	0xFFFD: 0x48A7,
	0xFFFD: 0x48A8,
	0xFFFD: 0x48A9,
	0xFFFD: 0x48AA,
	0xFFFD: 0x48AB,
	0xFFFD: 0x48AC,
	0xFFFD: 0x48AD,
	0xFFFD: 0x48AE,
	0xFFFD: 0x48AF,
	0xFFFD: 0x48B0,
	0xFFFD: 0x48B1,
	0xFFFD: 0x48B2,
	0xFFFD: 0x48B3,
	0xFFFD: 0x48B4,
	0xFFFD: 0x48B5,
	0xFFFD: 0x48B6,
	0xFFFD: 0x48B7,
	0xFFFD: 0x48B8,
	0xFFFD: 0x48B9,
	0xFFFD: 0x48BA,
	0xFFFD: 0x48BB,
	0xFFFD: 0x48BC,
	0xFFFD: 0x48BD,
	0xFFFD: 0x48BE,
	0xFFFD: 0x48BF,
	0xFFFD: 0x48C0,
	0xFFFD: 0x48C1,
	0xFFFD: 0x48C2,
	0xFFFD: 0x48C3,
	0xFFFD: 0x48C4,
	0xFFFD: 0x48C5,
	0xFFFD: 0x48C6,
	0xFFFD: 0x48C7,
	0xFFFD: 0x48C8,
	0xFFFD: 0x48C9,
	0xFFFD: 0x48CA,
	0xFFFD: 0x48CB,
	0xFFFD: 0x48CC,
	0xFFFD: 0x48CD,
	0xFFFD: 0x48CE,
	0xFFFD: 0x48CF,
	0xFFFD: 0x48D0,
	0xFFFD: 0x48D1,
	0xFFFD: 0x48D2,
	0xFFFD: 0x48D3,
	0xFFFD: 0x48D4,
	0xFFFD: 0x48D5,
	0xFFFD: 0x48D6,
	0xFFFD: 0x48D7,
	0xFFFD: 0x48D8,
	0xFFFD: 0x48D9,
	0xFFFD: 0x48DA,
	0xFFFD: 0x48DB,
	0xFFFD: 0x48DC,
	0xFFFD: 0x48DD,
	0xFFFD: 0x48DE,
	0xFFFD: 0x48DF,
	0xFFFD: 0x48E0,
	0xFFFD: 0x48E1,
	0xFFFD: 0x48E2,
	0xFFFD: 0x48E3,
	0xFFFD: 0x48E4,
	0xFFFD: 0x48E5,
	0xFFFD: 0x48E6,
	0xFFFD: 0x48E7,
	0xFFFD: 0x48E8,
	0xFFFD: 0x48E9,
	0xFFFD: 0x48EA,
	0xFFFD: 0x48EB,
	0xFFFD: 0x48EC,
	0xFFFD: 0x48ED,
	0xFFFD: 0x48EE,
	0xFFFD: 0x48EF,
	0xFFFD: 0x48F0,
	0xFFFD: 0x48F1,
	0xFFFD: 0x48F2,
	0xFFFD: 0x48F3,
	0xFFFD: 0x48F4,
	0xFFFD: 0x48F5,
	0xFFFD: 0x48F6,
	0xFFFD: 0x48F7,
	0xFFFD: 0x48F8,
	0xFFFD: 0x48F9,
	0xFFFD: 0x48FA,
	0xFFFD: 0x48FB,
	0xFFFD: 0x48FC,
	0xFFFD: 0x48FD,
	0xFFFD: 0x48FE,
	0xFFFD: 0x48FF,
	0xFFFD: 0x4900,
	0xFFFD: 0x4901,
	0xFFFD: 0x4902,
	0xFFFD: 0x4903,
	0xFFFD: 0x4904,
	0xFFFD: 0x4905,
	0xFFFD: 0x4906,
	0xFFFD: 0x4907,
	0xFFFD: 0x4908,
	0xFFFD: 0x4909,
	0xFFFD: 0x490A,
	0xFFFD: 0x490B,
	0xFFFD: 0x490C,
	0xFFFD: 0x490D,
	0xFFFD: 0x490E,
	0xFFFD: 0x490F,
	0xFFFD: 0x4910,
	0xFFFD: 0x4911,
	0xFFFD: 0x4912,
	0xFFFD: 0x4913,
	0xFFFD: 0x4914,
	0xFFFD: 0x4915,
	0xFFFD: 0x4916,
	0xFFFD: 0x4917,
	0xFFFD: 0x4918,
	0xFFFD: 0x4919,
	0xFFFD: 0x491A,
	0xFFFD: 0x491B,
	0xFFFD: 0x491C,
	0xFFFD: 0x491D,
	0xFFFD: 0x491E,
	0xFFFD: 0x491F,
	0xFFFD: 0x4920,
	0xFFFD: 0x4921,
	0xFFFD: 0x4922,
	0xFFFD: 0x4923,
	0xFFFD: 0x4924,
	0xFFFD: 0x4925,
	0xFFFD: 0x4926,
	0xFFFD: 0x4927,
	0xFFFD: 0x4928,
	0xFFFD: 0x4929,
	0xFFFD: 0x492A,
	0xFFFD: 0x492B,
	0xFFFD: 0x492C,
	0xFFFD: 0x492D,
	0xFFFD: 0x492E,
	0xFFFD: 0x492F,
	0xFFFD: 0x4930,
	0xFFFD: 0x4931,
	0xFFFD: 0x4932,
	0xFFFD: 0x4933,
	0xFFFD: 0x4934,
	0xFFFD: 0x4935,
	0xFFFD: 0x4936,
	0xFFFD: 0x4937,
	0xFFFD: 0x4938,
	0xFFFD: 0x4939,
	0xFFFD: 0x493A,
	0xFFFD: 0x493B,
	0xFFFD: 0x493C,
	0xFFFD: 0x493D,
	0xFFFD: 0x493E,
	0xFFFD: 0x493F,
	0xFFFD: 0x4940,
	0xFFFD: 0x4941,
	0xFFFD: 0x4942,
	0xFFFD: 0x4943,
	0xFFFD: 0x4944,
	0xFFFD: 0x4945,
	0xFFFD: 0x4946,
	0xFFFD: 0x4947,
	0xFFFD: 0x4948,
	0xFFFD: 0x4949,
	0xFFFD: 0x494A,
	0xFFFD: 0x494B,
	0xFFFD: 0x494C,
	0xFFFD: 0x494D,
	0xFFFD: 0x494E,
	0xFFFD: 0x494F,
	0xFFFD: 0x4950,
	0xFFFD: 0x4951,
	0xFFFD: 0x4952,
	0xFFFD: 0x4953,
	0xFFFD: 0x4954,
	0xFFFD: 0x4955,
	0xFFFD: 0x4956,
	0xFFFD: 0x4957,
	0xFFFD: 0x4958,
	0xFFFD: 0x4959,
	0xFFFD: 0x495A,
	0xFFFD: 0x495B,
	0xFFFD: 0x495C,
	0xFFFD: 0x495D,
	0xFFFD: 0x495E,
	0xFFFD: 0x495F,
	0xFFFD: 0x4960,
	0xFFFD: 0x4961,
	0xFFFD: 0x4962,
	0xFFFD: 0x4963,
	0xFFFD: 0x4964,
	0xFFFD: 0x4965,
	0xFFFD: 0x4966,
	0xFFFD: 0x4967,
	0xFFFD: 0x4968,
	0xFFFD: 0x4969,
	0xFFFD: 0x496A,
	0xFFFD: 0x496B,
	0xFFFD: 0x496C,
	0xFFFD: 0x496D,
	0xFFFD: 0x496E,
	0xFFFD: 0x496F,
	0xFFFD: 0x4970,
	0xFFFD: 0x4971,
	0xFFFD: 0x4972,
	0xFFFD: 0x4973,
	0xFFFD: 0x4974,
	0xFFFD: 0x4975,
	0xFFFD: 0x4976,
	0xFFFD: 0x4977,
	0xFFFD: 0x4978,
	0xFFFD: 0x4979,
	0xFFFD: 0x497A,
	0xFFFD: 0x497B,
	0xFFFD: 0x497C,
	0xFFFD: 0x497D,
	0xFFFD: 0x497E,
	0xFFFD: 0x497F,
	0xFFFD: 0x4980,
	0xFFFD: 0x4981,
	0xFFFD: 0x4982,
	0xFFFD: 0x4983,
	0xFFFD: 0x4984,
	0xFFFD: 0x4985,
	0xFFFD: 0x4986,
	0xFFFD: 0x4987,
	0xFFFD: 0x4988,
	0xFB7D: 0x4989,
	0xFFFD: 0x498A,
	0xFFFD: 0x498B,
	0xFFFD: 0x498C,
	0xFFFD: 0x498D,
	0xFFFD: 0x498E,
	0xFFFD: 0x498F,
	0xFFFD: 0x4990,
	0xFFFD: 0x4991,
	0xFFFD: 0x4992,
	0xFFFD: 0x4993,
	0xFFFD: 0x4994,
	0xFFFD: 0x4995,
	0xFFFD: 0x4996,
	0xFFFD: 0x4997,
	0xFFFD: 0x4998,
	0xFFFD: 0x4999,
	0xFFFD: 0x499A,
	0xFFFD: 0x499B,
	0xFFFD: 0x499C,
	0xFFFD: 0x499D,
	0xFFFD: 0x499E,
	0xFFFD: 0x499F,
	0xFFFD: 0x49A0,
	0xFFFD: 0x49A1,
	0xFFFD: 0x49A2,
	0xFFFD: 0x49A3,
	0xFFFD: 0x49A4,
	0xFFFD: 0x49A5,
	0xFFFD: 0x49A6,
	0xFFFD: 0x49A7,
	0xFFFD: 0x49A8,
	0xFFFD: 0x49A9,
	0xFFFD: 0x49AA,
	0xFFFD: 0x49AB,
	0xFFFD: 0x49AC,
	0xFFFD: 0x49AD,
	0xFFFD: 0x49AE,
	0xFFFD: 0x49AF,
	0xFFFD: 0x49B0,
	0xFFFD: 0x49B1,
	0xFFFD: 0x49B2,
	0xFFFD: 0x49B3,
	0xFFFD: 0x49B4,
	0xFFFD: 0x49B5,
	0xFFFD: 0x49B6,
	0xFFFD: 0x49B7,
	0xFFFD: 0x49B8,
	0xFFFD: 0x49B9,
	0xFFFD: 0x49BA,
	0xFFFD: 0x49BB,
	0xFFFD: 0x49BC,
	0xFFFD: 0x49BD,
	0xFFFD: 0x49BE,
	0xFFFD: 0x49BF,
	0xFFFD: 0x49C0,
	0xFFFD: 0x49C1,
	0xFFFD: 0x49C2,
	0xFFFD: 0x49C3,
	0xFFFD: 0x49C4,
	0xFFFD: 0x49C5,
	0xFFFD: 0x49C6,
	0xFFFD: 0x49C7,
	0xFFFD: 0x49C8,
	0xFFFD: 0x49C9,
	0xFFFD: 0x49CA,
	0xFFFD: 0x49CB,
	0xFFFD: 0x49CC,
	0xFFFD: 0x49CD,
	0xFFFD: 0x49CE,
	0xFFFD: 0x49CF,
	0xFFFD: 0x49D0,
	0xFFFD: 0x49D1,
	0xFFFD: 0x49D2,
	0xFFFD: 0x49D3,
	0xFFFD: 0x49D4,
	0xFFFD: 0x49D5,
	0xFFFD: 0x49D6,
	0xFFFD: 0x49D7,
	0xFFFD: 0x49D8,
	0xFFFD: 0x49D9,
	0xFFFD: 0x49DA,
	0xFFFD: 0x49DB,
	0xFFFD: 0x49DC,
	0xFFFD: 0x49DD,
	0xFFFD: 0x49DE,
	0xFFFD: 0x49DF,
	0xFFFD: 0x49E0,
	0xFFFD: 0x49E1,
	0xFFFD: 0x49E2,
	0xFFFD: 0x49E3,
	0xFFFD: 0x49E4,
	0xFFFD: 0x49E5,
	0xFFFD: 0x49E6,
	0xFFFD: 0x49E7,
	0xFFFD: 0x49E8,
	0xFFFD: 0x49E9,
	0xFFFD: 0x49EA,
	0xFFFD: 0x49EB,
	0xFFFD: 0x49EC,
	0xFFFD: 0x49ED,
	0xFFFD: 0x49EE,
	0xFFFD: 0x49EF,
	0xFFFD: 0x49F0,
	0xFFFD: 0x49F1,
	0xFFFD: 0x49F2,
	0xFFFD: 0x49F3,
	0xFFFD: 0x49F4,
	0xFFFD: 0x49F5,
	0xFFFD: 0x49F6,
	0xFFFD: 0x49F7,
	0xFFFD: 0x49F8,
	0xFFFD: 0x49F9,
	0xFFFD: 0x49FA,
	0xFFFD: 0x49FB,
	0xFFFD: 0x49FC,
	0xFFFD: 0x49FD,
	0xFFFD: 0x49FE,
	0xFFFD: 0x49FF,
	0xFFFD: 0x4A00,
	0xFFFD: 0x4A01,
	0xFFFD: 0x4A02,
	0xFFFD: 0x4A03,
	0xFFFD: 0x4A04,
	0xFFFD: 0x4A05,
	0xFFFD: 0x4A06,
	0xFFFD: 0x4A07,
	0xFFFD: 0x4A08,
	0xFFFD: 0x4A09,
	0xFFFD: 0x4A0A,
	0xFFFD: 0x4A0B,
	0xFFFD: 0x4A0C,
	0xFFFD: 0x4A0D,
	0xFFFD: 0x4A0E,
	0xFFFD: 0x4A0F,
	0xFFFD: 0x4A10,
	0xFFFD: 0x4A11,
	0xFFFD: 0x4A12,
	0xFFFD: 0x4A13,
	0xFFFD: 0x4A14,
	0xFFFD: 0x4A15,
	0xFFFD: 0x4A16,
	0xFFFD: 0x4A17,
	0xFFFD: 0x4A18,
	0xFFFD: 0x4A19,
	0xFFFD: 0x4A1A,
	0xFFFD: 0x4A1B,
	0xFFFD: 0x4A1C,
	0xFFFD: 0x4A1D,
	0xFFFD: 0x4A1E,
	0xFFFD: 0x4A1F,
	0xFFFD: 0x4A20,
	0xFFFD: 0x4A21,
	0xFFFD: 0x4A22,
	0xFFFD: 0x4A23,
	0xFFFD: 0x4A24,
	0xFFFD: 0x4A25,
	0xFFFD: 0x4A26,
	0xFFFD: 0x4A27,
	0xFFFD: 0x4A28,
	0xFFFD: 0x4A29,
	0xFFFD: 0x4A2A,
	0xFFFD: 0x4A2B,
	0xFFFD: 0x4A2C,
	0xFFFD: 0x4A2D,
	0xFFFD: 0x4A2E,
	0xFFFD: 0x4A2F,
	0xFFFD: 0x4A30,
	0xFFFD: 0x4A31,
	0xFFFD: 0x4A32,
	0xFFFD: 0x4A33,
	0xFFFD: 0x4A34,
	0xFFFD: 0x4A35,
	0xFFFD: 0x4A36,
	0xFFFD: 0x4A37,
	0xFFFD: 0x4A38,
	0xFFFD: 0x4A39,
	0xFFFD: 0x4A3A,
	0xFFFD: 0x4A3B,
	0xFFFD: 0x4A3C,
	0xFFFD: 0x4A3D,
	0xFFFD: 0x4A3E,
	0xFFFD: 0x4A3F,
	0xFFFD: 0x4A40,
	0xFFFD: 0x4A41,
	0xFFFD: 0x4A42,
	0xFFFD: 0x4A43,
	0xFFFD: 0x4A44,
	0xFFFD: 0x4A45,
	0xFFFD: 0x4A46,
	0xFFFD: 0x4A47,
	0xFFFD: 0x4A48,
	0xFFFD: 0x4A49,
	0xFFFD: 0x4A4A,
	0xFFFD: 0x4A4B,
	0xFFFD: 0x4A4C,
	0xFFFD: 0x4A4D,
	0xFFFD: 0x4A4E,
	0xFFFD: 0x4A4F,
	0xFFFD: 0x4A50,
	0xFFFD: 0x4A51,
	0xFFFD: 0x4A52,
	0xFFFD: 0x4A53,
	0xFFFD: 0x4A54,
	0xFFFD: 0x4A55,
	0xFFFD: 0x4A56,
	0xFFFD: 0x4A57,
	0xFFFD: 0x4A58,
	0xFFFD: 0x4A59,
	0xFFFD: 0x4A5A,
	0xFFFD: 0x4A5B,
	0xFFFD: 0x4A5C,
	0xFFFD: 0x4A5D,
	0xFFFD: 0x4A5E,
	0xFFFD: 0x4A5F,
	0xFFFD: 0x4A60,
	0xFFFD: 0x4A61,
	0xFFFD: 0x4A62,
	0xFFFD: 0x4A63,
	0xFFFD: 0x4A64,
	0xFFFD: 0x4A65,
	0xFFFD: 0x4A66,
	0xFFFD: 0x4A67,
	0xFFFD: 0x4A68,
	0xFFFD: 0x4A69,
	0xFFFD: 0x4A6A,
	0xFFFD: 0x4A6B,
	0xFFFD: 0x4A6C,
	0xFFFD: 0x4A6D,
	0xFFFD: 0x4A6E,
	0xFFFD: 0x4A6F,
	0xFFFD: 0x4A70,
	0xFFFD: 0x4A71,
	0xFFFD: 0x4A72,
	0xFFFD: 0x4A73,
	0xFFFD: 0x4A74,
	0xFFFD: 0x4A75,
	0xFFFD: 0x4A76,
	0xFFFD: 0x4A77,
	0xFFFD: 0x4A78,
	0xFFFD: 0x4A79,
	0xFFFD: 0x4A7A,
	0xFFFD: 0x4A7B,
	0xFFFD: 0x4A7C,
	0xFFFD: 0x4A7D,
	0xFFFD: 0x4A7E,
	0xFFFD: 0x4A7F,
	0xFFFD: 0x4A80,
	0xFFFD: 0x4A81,
	0xFFFD: 0x4A82,
	0xFFFD: 0x4A83,
	0xFFFD: 0x4A84,
	0xFFFD: 0x4A85,
	0xFFFD: 0x4A86,
	0xFFFD: 0x4A87,
	0xFFFD: 0x4A88,
	0xFFFD: 0x4A89,
	0xFFFD: 0x4A8A,
	0xFFFD: 0x4A8B,
	0xFFFD: 0x4A8C,
	0xFFFD: 0x4A8D,
	0xFFFD: 0x4A8E,
	0xFFFD: 0x4A8F,
	0xFFFD: 0x4A90,
	0xFFFD: 0x4A91,
	0xFFFD: 0x4A92,
	0xFFFD: 0x4A93,
	0xFFFD: 0x4A94,
	0xFFFD: 0x4A95,
	0xFFFD: 0x4A96,
	0xFFFD: 0x4A97,
	0xFFFD: 0x4A98,
	0xFFFD: 0x4A99,
	0xFFFD: 0x4A9A,
	0xFFFD: 0x4A9B,
	0xFFFD: 0x4A9C,
	0xFFFD: 0x4A9D,
	0xFFFD: 0x4A9E,
	0xFFFD: 0x4A9F,
	0xFFFD: 0x4AA0,
	0xFFFD: 0x4AA1,
	0xFFFD: 0x4AA2,
	0xFFFD: 0x4AA3,
	0xFFFD: 0x4AA4,
	0xFFFD: 0x4AA5,
	0xFFFD: 0x4AA6,
	0xFFFD: 0x4AA7,
	0xFFFD: 0x4AA8,
	0xFFFD: 0x4AA9,
	0xFFFD: 0x4AAA,
	0xFFFD: 0x4AAB,
	0xFFFD: 0x4AAC,
	0xFFFD: 0x4AAD,
	0xFFFD: 0x4AAE,
	0xFFFD: 0x4AAF,
	0xFFFD: 0x4AB0,
	0xFFFD: 0x4AB1,
	0xFFFD: 0x4AB2,
	0xFFFD: 0x4AB3,
	0xFFFD: 0x4AB4,
	0xFFFD: 0x4AB5,
	0xFFFD: 0x4AB6,
	0xFFFD: 0x4AB7,
	0xFFFD: 0x4AB8,
	0xFFFD: 0x4AB9,
	0xFFFD: 0x4ABA,
	0xFFFD: 0x4ABB,
	0xFFFD: 0x4ABC,
	0xFFFD: 0x4ABD,
	0xFFFD: 0x4ABE,
	0xFFFD: 0x4ABF,
	0xFFFD: 0x4AC0,
	0xFFFD: 0x4AC1,
	0xFFFD: 0x4AC2,
	0xFFFD: 0x4AC3,
	0xFFFD: 0x4AC4,
	0xFFFD: 0x4AC5,
	0xFFFD: 0x4AC6,
	0xFFFD: 0x4AC7,
	0xFFFD: 0x4AC8,
	0xFFFD: 0x4AC9,
	0xFFFD: 0x4ACA,
	0xFFFD: 0x4ACB,
	0xFFFD: 0x4ACC,
	0xFFFD: 0x4ACD,
	0xFFFD: 0x4ACE,
	0xFFFD: 0x4ACF,
	0xFFFD: 0x4AD0,
	0xFFFD: 0x4AD1,
	0xFFFD: 0x4AD2,
	0xFFFD: 0x4AD3,
	0xFFFD: 0x4AD4,
	0xFFFD: 0x4AD5,
	0xFFFD: 0x4AD6,
	0xFFFD: 0x4AD7,
	0xFFFD: 0x4AD8,
	0xFFFD: 0x4AD9,
	0xFFFD: 0x4ADA,
	0xFFFD: 0x4ADB,
	0xFFFD: 0x4ADC,
	0xFFFD: 0x4ADD,
	0xFFFD: 0x4ADE,
	0xFFFD: 0x4ADF,
	0xFFFD: 0x4AE0,
	0xFFFD: 0x4AE1,
	0xFFFD: 0x4AE2,
	0xFFFD: 0x4AE3,
	0xFFFD: 0x4AE4,
	0xFFFD: 0x4AE5,
	0xFFFD: 0x4AE6,
	0xFFFD: 0x4AE7,
	0xFFFD: 0x4AE8,
	0xFFFD: 0x4AE9,
	0xFFFD: 0x4AEA,
	0xFFFD: 0x4AEB,
	0xFFFD: 0x4AEC,
	0xFFFD: 0x4AED,
	0xFFFD: 0x4AEE,
	0xFFFD: 0x4AEF,
	0xFFFD: 0x4AF0,
	0xFFFD: 0x4AF1,
	0xFFFD: 0x4AF2,
	0xFFFD: 0x4AF3,
	0xFFFD: 0x4AF4,
	0xFFFD: 0x4AF5,
	0xFFFD: 0x4AF6,
	0xFFFD: 0x4AF7,
	0xFFFD: 0x4AF8,
	0xFFFD: 0x4AF9,
	0xFFFD: 0x4AFA,
	0xFFFD: 0x4AFB,
	0xFFFD: 0x4AFC,
	0xFFFD: 0x4AFD,
	0xFFFD: 0x4AFE,
	0xFFFD: 0x4AFF,
	0xFFFD: 0x4B00,
	0xFFFD: 0x4B01,
	0xFFFD: 0x4B02,
	0xFFFD: 0x4B03,
	0xFFFD: 0x4B04,
	0xFFFD: 0x4B05,
	0xFFFD: 0x4B06,
	0xFFFD: 0x4B07,
	0xFFFD: 0x4B08,
	0xFFFD: 0x4B09,
	0xFFFD: 0x4B0A,
	0xFFFD: 0x4B0B,
	0xFFFD: 0x4B0C,
	0xFFFD: 0x4B0D,
	0xFFFD: 0x4B0E,
	0xFFFD: 0x4B0F,
	0xFFFD: 0x4B10,
	0xFFFD: 0x4B11,
	0xFFFD: 0x4B12,
	0xFFFD: 0x4B13,
	0xFFFD: 0x4B14,
	0xFFFD: 0x4B15,
	0xFFFD: 0x4B16,
	0xFFFD: 0x4B17,
	0xFFFD: 0x4B18,
	0xFFFD: 0x4B19,
	0xFFFD: 0x4B1A,
	0xFFFD: 0x4B1B,
	0xFFFD: 0x4B1C,
	0xFFFD: 0x4B1D,
	0xFFFD: 0x4B1E,
	0xFFFD: 0x4B1F,
	0xFFFD: 0x4B20,
	0xFFFD: 0x4B21,
	0xFFFD: 0x4B22,
	0xFFFD: 0x4B23,
	0xFFFD: 0x4B24,
	0xFFFD: 0x4B25,
	0xFFFD: 0x4B26,
	0xFFFD: 0x4B27,
	0xFFFD: 0x4B28,
	0xFFFD: 0x4B29,
	0xFFFD: 0x4B2A,
	0xFFFD: 0x4B2B,
	0xFFFD: 0x4B2C,
	0xFFFD: 0x4B2D,
	0xFFFD: 0x4B2E,
	0xFFFD: 0x4B2F,
	0xFFFD: 0x4B30,
	0xFFFD: 0x4B31,
	0xFFFD: 0x4B32,
	0xFFFD: 0x4B33,
	0xFFFD: 0x4B34,
	0xFFFD: 0x4B35,
	0xFFFD: 0x4B36,
	0xFFFD: 0x4B37,
	0xFFFD: 0x4B38,
	0xFFFD: 0x4B39,
	0xFFFD: 0x4B3A,
	0xFFFD: 0x4B3B,
	0xFFFD: 0x4B3C,
	0xFFFD: 0x4B3D,
	0xFFFD: 0x4B3E,
	0xFFFD: 0x4B3F,
	0xFFFD: 0x4B40,
	0xFFFD: 0x4B41,
	0xFFFD: 0x4B42,
	0xFFFD: 0x4B43,
	0xFFFD: 0x4B44,
	0xFFFD: 0x4B45,
	0xFFFD: 0x4B46,
	0xFFFD: 0x4B47,
	0xFFFD: 0x4B48,
	0xFFFD: 0x4B49,
	0xFFFD: 0x4B4A,
	0xFFFD: 0x4B4B,
	0xFFFD: 0x4B4C,
	0xFFFD: 0x4B4D,
	0xFFFD: 0x4B4E,
	0xFFFD: 0x4B4F,
	0xFFFD: 0x4B50,
	0xFFFD: 0x4B51,
	0xFFFD: 0x4B52,
	0xFFFD: 0x4B53,
	0xFFFD: 0x4B54,
	0xFFFD: 0x4B55,
	0xFFFD: 0x4B56,
	0xFFFD: 0x4B57,
	0xFFFD: 0x4B58,
	0xFFFD: 0x4B59,
	0xFFFD: 0x4B5A,
	0xFFFD: 0x4B5B,
	0xFFFD: 0x4B5C,
	0xFFFD: 0x4B5D,
	0xFFFD: 0x4B5E,
	0xFFFD: 0x4B5F,
	0xFFFD: 0x4B60,
	0xFFFD: 0x4B61,
	0xFFFD: 0x4B62,
	0xFFFD: 0x4B63,
	0xFFFD: 0x4B64,
	0xFFFD: 0x4B65,
	0xFFFD: 0x4B66,
	0xFFFD: 0x4B67,
	0xFFFD: 0x4B68,
	0xFFFD: 0x4B69,
	0xFFFD: 0x4B6A,
	0xFFFD: 0x4B6B,
	0xFFFD: 0x4B6C,
	0xFFFD: 0x4B6D,
	0xFFFD: 0x4B6E,
	0xFFFD: 0x4B6F,
	0xFFFD: 0x4B70,
	0xFFFD: 0x4B71,
	0xFFFD: 0x4B72,
	0xFFFD: 0x4B73,
	0xFFFD: 0x4B74,
	0xFFFD: 0x4B75,
	0xFFFD: 0x4B76,
	0xFFFD: 0x4B77,
	0xFFFD: 0x4B78,
	0xFFFD: 0x4B79,
	0xFFFD: 0x4B7A,
	0xFFFD: 0x4B7B,
	0xFFFD: 0x4B7C,
	0xFFFD: 0x4B7D,
	0xFDE3: 0x4B7E,
	0xFFFD: 0x4B7F,
	0xFFFD: 0x4B80,
	0xFFFD: 0x4B81,
	0xFFFD: 0x4B82,
	0xFFFD: 0x4B83,
	0xFFFD: 0x4B84,
	0xFFFD: 0x4B85,
	0xFFFD: 0x4B86,
	0xFFFD: 0x4B87,
	0xFFFD: 0x4B88,
	0xFFFD: 0x4B89,
	0xFFFD: 0x4B8A,
	0xFFFD: 0x4B8B,
	0xFFFD: 0x4B8C,
	0xFFFD: 0x4B8D,
	0xFFFD: 0x4B8E,
	0xFFFD: 0x4B8F,
	0xFFFD: 0x4B90,
	0xFFFD: 0x4B91,
	0xFFFD: 0x4B92,
	0xFFFD: 0x4B93,
	0xFFFD: 0x4B94,
	0xFFFD: 0x4B95,
	0xFFFD: 0x4B96,
	0xFFFD: 0x4B97,
	0xFFFD: 0x4B98,
	0xFFFD: 0x4B99,
	0xFFFD: 0x4B9A,
	0xFFFD: 0x4B9B,
	0xFFFD: 0x4B9C,
	0xFFFD: 0x4B9D,
	0xFFFD: 0x4B9E,
	0xFFFD: 0x4B9F,
	0xFFFD: 0x4BA0,
	0xFFFD: 0x4BA1,
	0xFFFD: 0x4BA2,
	0xFFFD: 0x4BA3,
	0xFFFD: 0x4BA4,
	0xFFFD: 0x4BA5,
	0xFFFD: 0x4BA6,
	0xFFFD: 0x4BA7,
	0xFFFD: 0x4BA8,
	0xFFFD: 0x4BA9,
	0xFFFD: 0x4BAA,
	0xFFFD: 0x4BAB,
	0xFFFD: 0x4BAC,
	0xFFFD: 0x4BAD,
	0xFFFD: 0x4BAE,
	0xFFFD: 0x4BAF,
	0xFFFD: 0x4BB0,
	0xFFFD: 0x4BB1,
	0xFFFD: 0x4BB2,
	0xFFFD: 0x4BB3,
	0xFFFD: 0x4BB4,
	0xFFFD: 0x4BB5,
	0xFFFD: 0x4BB6,
	0xFFFD: 0x4BB7,
	0xFFFD: 0x4BB8,
	0xFFFD: 0x4BB9,
	0xFFFD: 0x4BBA,
	0xFFFD: 0x4BBB,
	0xFFFD: 0x4BBC,
	0xFFFD: 0x4BBD,
	0xFFFD: 0x4BBE,
	0xFFFD: 0x4BBF,
	0xFFFD: 0x4BC0,
	0xFFFD: 0x4BC1,
	0xFFFD: 0x4BC2,
	0xFFFD: 0x4BC3,
	0xFFFD: 0x4BC4,
	0xFFFD: 0x4BC5,
	0xFFFD: 0x4BC6,
	0xFFFD: 0x4BC7,
	0xFFFD: 0x4BC8,
	0xFFFD: 0x4BC9,
	0xFFFD: 0x4BCA,
	0xFFFD: 0x4BCB,
	0xFFFD: 0x4BCC,
	0xFFFD: 0x4BCD,
	0xFFFD: 0x4BCE,
	0xFFFD: 0x4BCF,
	0xFFFD: 0x4BD0,
	0xFFFD: 0x4BD1,
	0xFFFD: 0x4BD2,
	0xFFFD: 0x4BD3,
	0xFFFD: 0x4BD4,
	0xFFFD: 0x4BD5,
	0xFFFD: 0x4BD6,
	0xFFFD: 0x4BD7,
	0xFFFD: 0x4BD8,
	0xFFFD: 0x4BD9,
	0xFFFD: 0x4BDA,
	0xFFFD: 0x4BDB,
	0xFFFD: 0x4BDC,
	0xFFFD: 0x4BDD,
	0xFFFD: 0x4BDE,
	0xFFFD: 0x4BDF,
	0xFFFD: 0x4BE0,
	0xFFFD: 0x4BE1,
	0xFFFD: 0x4BE2,
	0xFFFD: 0x4BE3,
	0xFFFD: 0x4BE4,
	0xFFFD: 0x4BE5,
	0xFFFD: 0x4BE6,
	0xFFFD: 0x4BE7,
	0xFFFD: 0x4BE8,
	0xFFFD: 0x4BE9,
	0xFFFD: 0x4BEA,
	0xFFFD: 0x4BEB,
	0xFFFD: 0x4BEC,
	0xFFFD: 0x4BED,
	0xFFFD: 0x4BEE,
	0xFFFD: 0x4BEF,
	0xFFFD: 0x4BF0,
	0xFFFD: 0x4BF1,
	0xFFFD: 0x4BF2,
	0xFFFD: 0x4BF3,
	0xFFFD: 0x4BF4,
	0xFFFD: 0x4BF5,
	0xFFFD: 0x4BF6,
	0xFFFD: 0x4BF7,
	0xFFFD: 0x4BF8,
	0xFFFD: 0x4BF9,
	0xFFFD: 0x4BFA,
	0xFFFD: 0x4BFB,
	0xFFFD: 0x4BFC,
	0xFFFD: 0x4BFD,
	0xFFFD: 0x4BFE,
	0xFFFD: 0x4BFF,
	0xFFFD: 0x4C00,
	0xFFFD: 0x4C01,
	0xFFFD: 0x4C02,
	0xFFFD: 0x4C03,
	0xFDF1: 0x4C04,
	0xFFFD: 0x4C05,
	0xFFFD: 0x4C06,
	0xFDEF: 0x4C07,
	0xFFFD: 0x4C08,
	0xFFFD: 0x4C09,
	0xFFFD: 0x4C0A,
	0xFFFD: 0x4C0B,
	0xFFFD: 0x4C0C,
	0xFFFD: 0x4C0D,
	0xFFFD: 0x4C0E,
	0xFFFD: 0x4C0F,
	0xFFFD: 0x4C10,
	0xFFFD: 0x4C11,
	0xFFFD: 0x4C12,
	0xFFFD: 0x4C13,
	0xFFFD: 0x4C14,
	0xFFFD: 0x4C15,
	0xFFFD: 0x4C16,
	0xFFFD: 0x4C17,
	0xFFFD: 0x4C18,
	0xFFFD: 0x4C19,
	0xFFFD: 0x4C1A,
	0xFFFD: 0x4C1B,
	0xFFFD: 0x4C1C,
	0xFFFD: 0x4C1D,
	0xFFFD: 0x4C1E,
	0xFFFD: 0x4C1F,
	0xFFFD: 0x4C20,
	0xFFFD: 0x4C21,
	0xFFFD: 0x4C22,
	0xFFFD: 0x4C23,
	0xFFFD: 0x4C24,
	0xFFFD: 0x4C25,
	0xFFFD: 0x4C26,
	0xFFFD: 0x4C27,
	0xFFFD: 0x4C28,
	0xFFFD: 0x4C29,
	0xFFFD: 0x4C2A,
	0xFFFD: 0x4C2B,
	0xFFFD: 0x4C2C,
	0xFFFD: 0x4C2D,
	0xFFFD: 0x4C2E,
	0xFFFD: 0x4C2F,
	0xFFFD: 0x4C30,
	0xFFFD: 0x4C31,
	0xFFFD: 0x4C32,
	0xFFFD: 0x4C33,
	0xFFFD: 0x4C34,
	0xFFFD: 0x4C35,
	0xFFFD: 0x4C36,
	0xFFFD: 0x4C37,
	0xFFFD: 0x4C38,
	0xFFFD: 0x4C39,
	0xFFFD: 0x4C3A,
	0xFDF2: 0x4C3B,
	0xFFFD: 0x4C3C,
	0xFFFD: 0x4C3D,
	0xFFFD: 0x4C3E,
	0xFFFD: 0x4C3F,
	0xFFFD: 0x4C40,
	0xFFFD: 0x4C41,
	0xFFFD: 0x4C42,
	0xFFFD: 0x4C43,
	0xFFFD: 0x4C44,
	0xFFFD: 0x4C45,
	0xFFFD: 0x4C46,
	0xFFFD: 0x4C47,
	0xFFFD: 0x4C48,
	0xFFFD: 0x4C49,
	0xFFFD: 0x4C4A,
	0xFFFD: 0x4C4B,
	0xFFFD: 0x4C4C,
	0xFFFD: 0x4C4D,
	0xFFFD: 0x4C4E,
	0xFFFD: 0x4C4F,
	0xFFFD: 0x4C50,
	0xFFFD: 0x4C51,
	0xFFFD: 0x4C52,
	0xFFFD: 0x4C53,
	0xFFFD: 0x4C54,
	0xFFFD: 0x4C55,
	0xFFFD: 0x4C56,
	0xFFFD: 0x4C57,
	0xFFFD: 0x4C58,
	0xFFFD: 0x4C59,
	0xFFFD: 0x4C5A,
	0xFFFD: 0x4C5B,
	0xFFFD: 0x4C5C,
	0xFFFD: 0x4C5D,
	0xFFFD: 0x4C5E,
	0xFFFD: 0x4C5F,
	0xFFFD: 0x4C60,
	0xFFFD: 0x4C61,
	0xFFFD: 0x4C62,
	0xFFFD: 0x4C63,
	0xFFFD: 0x4C64,
	0xFFFD: 0x4C65,
	0xFFFD: 0x4C66,
	0xFFFD: 0x4C67,
	0xFFFD: 0x4C68,
	0xFFFD: 0x4C69,
	0xFFFD: 0x4C6A,
	0xFFFD: 0x4C6B,
	0xFFFD: 0x4C6C,
	0xFFFD: 0x4C6D,
	0xFFFD: 0x4C6E,
	0xFFFD: 0x4C6F,
	0xFFFD: 0x4C70,
	0xFFFD: 0x4C71,
	0xFFFD: 0x4C72,
	0xFFFD: 0x4C73,
	0xFFFD: 0x4C74,
	0xFFFD: 0x4C75,
	0xFFFD: 0x4C76,
	0xFFFD: 0x4C77,
	0xFFFD: 0x4C78,
	0xFFFD: 0x4C79,
	0xFFFD: 0x4C7A,
	0xFFFD: 0x4C7B,
	0xFFFD: 0x4C7C,
	0xFB45: 0x4C7D,
	0xFFFD: 0x4C7E,
	0xFFFD: 0x4C7F,
	0xFFFD: 0x4C80,
	0xFFFD: 0x4C81,
	0xFFFD: 0x4C82,
	0xFFFD: 0x4C83,
	0xFFFD: 0x4C84,
	0xFFFD: 0x4C85,
	0xFFFD: 0x4C86,
	0xFFFD: 0x4C87,
	0xFFFD: 0x4C88,
	0xFFFD: 0x4C89,
	0xFFFD: 0x4C8A,
	0xFFFD: 0x4C8B,
	0xFFFD: 0x4C8C,
	0xFFFD: 0x4C8D,
	0xFFFD: 0x4C8E,
	0xFFFD: 0x4C8F,
	0xFFFD: 0x4C90,
	0xFFFD: 0x4C91,
	0xFFFD: 0x4C92,
	0xFFFD: 0x4C93,
	0xFFFD: 0x4C94,
	0xFFFD: 0x4C95,
	0xFFFD: 0x4C96,
	0xFFFD: 0x4C97,
	0xFFFD: 0x4C98,
	0xFFFD: 0x4C99,
	0xFFFD: 0x4C9A,
	0xFFFD: 0x4C9B,
	0xFFFD: 0x4C9C,
	0xFFFD: 0x4C9D,
	0xFFFD: 0x4C9E,
	0xFFFD: 0x4C9F,
	0xFFFD: 0x4CA0,
	0xFFFD: 0x4CA1,
	0xFFFD: 0x4CA2,
	0xFFFD: 0x4CA3,
	0xFFFD: 0x4CA4,
	0xFFFD: 0x4CA5,
	0xFFFD: 0x4CA6,
	0xFFFD: 0x4CA7,
	0xFFFD: 0x4CA8,
	0xFFFD: 0x4CA9,
	0xFFFD: 0x4CAA,
	0xFFFD: 0x4CAB,
	0xFFFD: 0x4CAC,
	0xFFFD: 0x4CAD,
	0xFFFD: 0x4CAE,
	0xFFFD: 0x4CAF,
	0xFFFD: 0x4CB0,
	0xFFFD: 0x4CB1,
	0xFFFD: 0x4CB2,
	0xFFFD: 0x4CB3,
	0xFFFD: 0x4CB4,
	0xFFFD: 0x4CB5,
	0xFFFD: 0x4CB6,
	0xFFFD: 0x4CB7,
	0xFFFD: 0x4CB8,
	0xFFFD: 0x4CB9,
	0xFFFD: 0x4CBA,
	0xFFFD: 0x4CBB,
	0xFFFD: 0x4CBC,
	0xFFFD: 0x4CBD,
	0xFFFD: 0x4CBE,
	0xFFFD: 0x4CBF,
	0xFFFD: 0x4CC0,
	0xFFFD: 0x4CC1,
	0xFFFD: 0x4CC2,
	0xFFFD: 0x4CC3,
	0xFFFD: 0x4CC4,
	0xFFFD: 0x4CC5,
	0xFFFD: 0x4CC6,
	0xFFFD: 0x4CC7,
	0xFFFD: 0x4CC8,
	0xFFFD: 0x4CC9,
	0xFFFD: 0x4CCA,
	0xFFFD: 0x4CCB,
	0xFFFD: 0x4CCC,
	0xFFFD: 0x4CCD,
	0xFFFD: 0x4CCE,
	0xFFFD: 0x4CCF,
	0xFFFD: 0x4CD0,
	0xFFFD: 0x4CD1,
	0xFFFD: 0x4CD2,
	0xFFFD: 0x4CD3,
	0xFFFD: 0x4CD4,
	0xFFFD: 0x4CD5,
	0xFFFD: 0x4CD6,
	0xFFFD: 0x4CD7,
	0xFFFD: 0x4CD8,
	0xFFFD: 0x4CD9,
	0xFFFD: 0x4CDA,
	0xFFFD: 0x4CDB,
	0xFFFD: 0x4CDC,
	0xFFFD: 0x4CDD,
	0xFFFD: 0x4CDE,
	0xFFFD: 0x4CDF,
	0xFFFD: 0x4CE0,
	0xFFFD: 0x4CE1,
	0xFFFD: 0x4CE2,
	0xFFFD: 0x4CE3,
	0xFFFD: 0x4CE4,
	0xFFFD: 0x4CE5,
	0xFFFD: 0x4CE6,
	0xFFFD: 0x4CE7,
	0xFFFD: 0x4CE8,
	0xFFFD: 0x4CE9,
	0xFFFD: 0x4CEA,
	0xFFFD: 0x4CEB,
	0xFFFD: 0x4CEC,
	0xFFFD: 0x4CED,
	0xFFFD: 0x4CEE,
	0xFFFD: 0x4CEF,
	0xFFFD: 0x4CF0,
	0xFFFD: 0x4CF1,
	0xFFFD: 0x4CF2,
	0xFFFD: 0x4CF3,
	0xFFFD: 0x4CF4,
	0xFFFD: 0x4CF5,
	0xFFFD: 0x4CF6,
	0xFFFD: 0x4CF7,
	0xFFFD: 0x4CF8,
	0xFFFD: 0x4CF9,
	0xFFFD: 0x4CFA,
	0xFFFD: 0x4CFB,
	0xFFFD: 0x4CFC,
	0xFFFD: 0x4CFD,
	0xFFFD: 0x4CFE,
	0xFFFD: 0x4CFF,
	0xFFFD: 0x4D00,
	0xFFFD: 0x4D01,
	0xFFFD: 0x4D02,
	0xFFFD: 0x4D03,
	0xFFFD: 0x4D04,
	0xFFFD: 0x4D05,
	0xFFFD: 0x4D06,
	0xFFFD: 0x4D07,
	0xFFFD: 0x4D08,
	0xFFFD: 0x4D09,
	0xFFFD: 0x4D0A,
	0xFFFD: 0x4D0B,
	0xFFFD: 0x4D0C,
	0xFFFD: 0x4D0D,
	0xFFFD: 0x4D0E,
	0xFFFD: 0x4D0F,
	0xFFFD: 0x4D10,
	0xFFFD: 0x4D11,
	0xFFFD: 0x4D12,
	0xFFFD: 0x4D13,
	0xFFFD: 0x4D14,
	0xFFFD: 0x4D15,
	0xFFFD: 0x4D16,
	0xFFFD: 0x4D17,
	0xFFFD: 0x4D18,
	0xFFFD: 0x4D19,
	0xFFFD: 0x4D1A,
	0xFFFD: 0x4D1B,
	0xFFFD: 0x4D1C,
	0xFFFD: 0x4D1D,
	0xFFFD: 0x4D1E,
	0xFFFD: 0x4D1F,
	0xFFFD: 0x4D20,
	0xFFFD: 0x4D21,
	0xFFFD: 0x4D22,
	0xFFFD: 0x4D23,
	0xFFFD: 0x4D24,
	0xFFFD: 0x4D25,
	0xFFFD: 0x4D26,
	0xFFFD: 0x4D27,
	0xFFFD: 0x4D28,
	0xFFFD: 0x4D29,
	0xFFFD: 0x4D2A,
	0xFFFD: 0x4D2B,
	0xFFFD: 0x4D2C,
	0xFFFD: 0x4D2D,
	0xFFFD: 0x4D2E,
	0xFFFD: 0x4D2F,
	0xFFFD: 0x4D30,
	0xFFFD: 0x4D31,
	0xFFFD: 0x4D32,
	0xFFFD: 0x4D33,
	0xFFFD: 0x4D34,
	0xFFFD: 0x4D35,
	0xFFFD: 0x4D36,
	0xFFFD: 0x4D37,
	0xFFFD: 0x4D38,
	0xFFFD: 0x4D39,
	0xFFFD: 0x4D3A,
	0xFFFD: 0x4D3B,
	0xFFFD: 0x4D3C,
	0xFFFD: 0x4D3D,
	0xFFFD: 0x4D3E,
	0xFFFD: 0x4D3F,
	0xFFFD: 0x4D40,
	0xFFFD: 0x4D41,
	0xFFFD: 0x4D42,
	0xFFFD: 0x4D43,
	0xFFFD: 0x4D44,
	0xFFFD: 0x4D45,
	0xFFFD: 0x4D46,
	0xFFFD: 0x4D47,
	0xFFFD: 0x4D48,
	0xFFFD: 0x4D49,
	0xFFFD: 0x4D4A,
	0xFFFD: 0x4D4B,
	0xFFFD: 0x4D4C,
	0xFFFD: 0x4D4D,
	0xFFFD: 0x4D4E,
	0xFFFD: 0x4D4F,
	0xFFFD: 0x4D50,
	0xFFFD: 0x4D51,
	0xFFFD: 0x4D52,
	0xFFFD: 0x4D53,
	0xFFFD: 0x4D54,
	0xFFFD: 0x4D55,
	0xFFFD: 0x4D56,
	0xFFFD: 0x4D57,
	0xFFFD: 0x4D58,
	0xFFFD: 0x4D59,
	0xFFFD: 0x4D5A,
	0xFFFD: 0x4D5B,
	0xFFFD: 0x4D5C,
	0xFFFD: 0x4D5D,
	0xFFFD: 0x4D5E,
	0xFFFD: 0x4D5F,
	0xFFFD: 0x4D60,
	0xFFFD: 0x4D61,
	0xFFFD: 0x4D62,
	0xFFFD: 0x4D63,
	0xFFFD: 0x4D64,
	0xFFFD: 0x4D65,
	0xFFFD: 0x4D66,
	0xFFFD: 0x4D67,
	0xFFFD: 0x4D68,
	0xFFFD: 0x4D69,
	0xFFFD: 0x4D6A,
	0xFFFD: 0x4D6B,
	0xFFFD: 0x4D6C,
	0xFFFD: 0x4D6D,
	0xFFFD: 0x4D6E,
	0xFFFD: 0x4D6F,
	0xFFFD: 0x4D70,
	0xFFFD: 0x4D71,
	0xFFFD: 0x4D72,
	0xFFFD: 0x4D73,
	0xFFFD: 0x4D74,
	0xFFFD: 0x4D75,
	0xFFFD: 0x4D76,
	0xFFFD: 0x4D77,
	0xFFFD: 0x4D78,
	0xFFFD: 0x4D79,
	0xFFFD: 0x4D7A,
	0xFFFD: 0x4D7B,
	0xFFFD: 0x4D7C,
	0xFFFD: 0x4D7D,
	0xFFFD: 0x4D7E,
	0xFFFD: 0x4D7F,
	0xFFFD: 0x4D80,
	0xFFFD: 0x4D81,
	0xFFFD: 0x4D82,
	0xFFFD: 0x4D83,
	0xFFFD: 0x4D84,
	0xFFFD: 0x4D85,
	0xFFFD: 0x4D86,
	0xFFFD: 0x4D87,
	0xFFFD: 0x4D88,
	0xFFFD: 0x4D89,
	0xFFFD: 0x4D8A,
	0xFFFD: 0x4D8B,
	0xFFFD: 0x4D8C,
	0xFFFD: 0x4D8D,
	0xFFFD: 0x4D8E,
	0xFFFD: 0x4D8F,
	0xFFFD: 0x4D90,
	0xFFFD: 0x4D91,
	0xFFFD: 0x4D92,
	0xFFFD: 0x4D93,
	0xFFFD: 0x4D94,
	0xFFFD: 0x4D95,
	0xFFFD: 0x4D96,
	0xFFFD: 0x4D97,
	0xFFFD: 0x4D98,
	0xFFFD: 0x4D99,
	0xFFFD: 0x4D9A,
	0xFFFD: 0x4D9B,
	0xFFFD: 0x4D9C,
	0xFFFD: 0x4D9D,
	0xFFFD: 0x4D9E,
	0xFFFD: 0x4D9F,
	0xFFFD: 0x4DA0,
	0xFFFD: 0x4DA1,
	0xFFFD: 0x4DA2,
	0xFFFD: 0x4DA3,
	0xFFFD: 0x4DA4,
	0xFFFD: 0x4DA5,
	0xFFFD: 0x4DA6,
	0xFFFD: 0x4DA7,
	0xFFFD: 0x4DA8,
	0xFFFD: 0x4DA9,
	0xFFFD: 0x4DAA,
	0xFFFD: 0x4DAB,
	0xFFFD: 0x4DAC,
	0xFFFD: 0x4DAD,
	0xFFFD: 0x4DAE,
	0xFFFD: 0x4DAF,
	0xFFFD: 0x4DB0,
	0xFFFD: 0x4DB1,
	0xFFFD: 0x4DB2,
	0xFFFD: 0x4DB3,
	0xFFFD: 0x4DB4,
	0xFFFD: 0x4DB5,
	0xFFFD: 0x4DB6,
	0xFFFD: 0x4DB7,
	0xFFFD: 0x4DB8,
	0xFFFD: 0x4DB9,
	0xFFFD: 0x4DBA,
	0xFFFD: 0x4DBB,
	0xFFFD: 0x4DBC,
	0xFFFD: 0x4DBD,
	0xFFFD: 0x4DBE,
	0xFFFD: 0x4DBF,
	0xFFFD: 0x4DC0,
	0xFFFD: 0x4DC1,
	0xFFFD: 0x4DC2,
	0xFFFD: 0x4DC3,
	0xFFFD: 0x4DC4,
	0xFFFD: 0x4DC5,
	0xFFFD: 0x4DC6,
	0xFFFD: 0x4DC7,
	0xFFFD: 0x4DC8,
	0xFFFD: 0x4DC9,
	0xFFFD: 0x4DCA,
	0xFFFD: 0x4DCB,
	0xFFFD: 0x4DCC,
	0xFFFD: 0x4DCD,
	0xFFFD: 0x4DCE,
	0xFFFD: 0x4DCF,
	0xFFFD: 0x4DD0,
	0xFFFD: 0x4DD1,
	0xFFFD: 0x4DD2,
	0xFFFD: 0x4DD3,
	0xFFFD: 0x4DD4,
	0xFFFD: 0x4DD5,
	0xFFFD: 0x4DD6,
	0xFFFD: 0x4DD7,
	0xFFFD: 0x4DD8,
	0xFFFD: 0x4DD9,
	0xFFFD: 0x4DDA,
	0xFFFD: 0x4DDB,
	0xFFFD: 0x4DDC,
	0xFFFD: 0x4DDD,
	0xFFFD: 0x4DDE,
	0xFFFD: 0x4DDF,
	0xFFFD: 0x4DE0,
	0xFFFD: 0x4DE1,
	0xFFFD: 0x4DE2,
	0xFFFD: 0x4DE3,
	0xFFFD: 0x4DE4,
	0xFFFD: 0x4DE5,
	0xFFFD: 0x4DE6,
	0xFFFD: 0x4DE7,
	0xFFFD: 0x4DE8,
	0xFFFD: 0x4DE9,
	0xFFFD: 0x4DEA,
	0xFFFD: 0x4DEB,
	0xFFFD: 0x4DEC,
	0xFFFD: 0x4DED,
	0xFFFD: 0x4DEE,
	0xFFFD: 0x4DEF,
	0xFFFD: 0x4DF0,
	0xFFFD: 0x4DF1,
	0xFFFD: 0x4DF2,
	0xFFFD: 0x4DF3,
	0xFFFD: 0x4DF4,
	0xFFFD: 0x4DF5,
	0xFFFD: 0x4DF6,
	0xFFFD: 0x4DF7,
	0xFFFD: 0x4DF8,
	0xFFFD: 0x4DF9,
	0xFFFD: 0x4DFA,
	0xFFFD: 0x4DFB,
	0xFFFD: 0x4DFC,
	0xFFFD: 0x4DFD,
	0xFFFD: 0x4DFE,
	0xFFFD: 0x4DFF,
	0xA440: 0x4E00,
	0xA442: 0x4E01,
	0xFFFD: 0x4E02,
	0xA443: 0x4E03,
	0x98A7: 0x4E04,
	0xFFFD: 0x4E05,
	0x91D7: 0x4E06,
	0xC945: 0x4E07,
	0xA456: 0x4E08,
	0xA454: 0x4E09,
	0xA457: 0x4E0A,
	0xA455: 0x4E0B,
	0xC946: 0x4E0C,
	0xA4A3: 0x4E0D,
	0xC94F: 0x4E0E,
	0xC94D: 0x4E0F,
	0xA4A2: 0x4E10,
	0xA4A1: 0x4E11,
	0xFFFD: 0x4E12,
	0x83FD: 0x4E13,
	0xA542: 0x4E14,
	0xA541: 0x4E15,
	0xA540: 0x4E16,
	0x8140: 0x4E17,
	0xA543: 0x4E18,
	0xA4FE: 0x4E19,
	0x85D2: 0x4E1A,
	0x8ABD: 0x4E1B,
	0x835B: 0x4E1C,
	0x8546: 0x4E1D,
	0xA5E0: 0x4E1E,
	0xA5E1: 0x4E1F,
	0xFFFD: 0x4E20,
	0x93E5: 0x4E21,
	0x8141: 0x4E22,
	0xFFFD: 0x4E23,
	0x8355: 0x4E24,
	0x8BF2: 0x4E25,
	0xA8C3: 0x4E26,
	0x84CA: 0x4E27,
	0x9CC9: 0x4E28,
	0xFFFD: 0x4E29,
	0x83AA: 0x4E2A,
	0xA458: 0x4E2B,
	0x8142: 0x4E2C,
	0xA4A4: 0x4E2D,
	0xC950: 0x4E2E,
	0x98A8: 0x4E2F,
	0xA4A5: 0x4E30,
	0xC963: 0x4E31,
	0xA6EA: 0x4E32,
	0xCBB1: 0x4E33,
	0x8A5A: 0x4E34,
	0xFFFD: 0x4E35,
	0xC6BF: 0x4E36,
	0x91CC: 0x4E37,
	0xA459: 0x4E38,
	0xA4A6: 0x4E39,
	0x836F: 0x4E3A,
	0xA544: 0x4E3B,
	0xC964: 0x4E3C,
	0x8BED: 0x4E3D,
	0x8A5B: 0x4E3E,
	0xC6C0: 0x4E3F,
	0xFFFD: 0x4E40,
	0xFFFD: 0x4E41,
	0xC940: 0x4E42,
	0xA444: 0x4E43,
	0x94F2: 0x4E44,
	0xA45B: 0x4E45,
	0xFFFD: 0x4E46,
	0xC947: 0x4E47,
	0xA45C: 0x4E48,
	0x85F3: 0x4E49,
	0xFFFD: 0x4E4A,
	0xA4A7: 0x4E4B,
	0x83BF: 0x4E4C,
	0xA545: 0x4E4D,
	0xA547: 0x4E4E,
	0xA546: 0x4E4F,
	0x87E4: 0x4E50,
	0xFFFD: 0x4E51,
	0xA5E2: 0x4E52,
	0xA5E3: 0x4E53,
	0x84CE: 0x4E54,
	0x8143: 0x4E55,
	0xA8C4: 0x4E56,
	0x92E9: 0x4E57,
	0xADBC: 0x4E58,
	0xA441: 0x4E59,
	0x9CDF: 0x4E5A,
	0x9CE8: 0x4E5B,
	0xC941: 0x4E5C,
	0xA445: 0x4E5D,
	0xA45E: 0x4E5E,
	0xA45D: 0x4E5F,
	0x8474: 0x4E60,
	0x8570: 0x4E61,
	0x8144: 0x4E62,
	0xFFFD: 0x4E63,
	0xFFFD: 0x4E64,
	0xFFFD: 0x4E65,
	0x83BC: 0x4E66,
	0xFFFD: 0x4E67,
	0xFFFD: 0x4E68,
	0xA5E4: 0x4E69,
	0xFE41: 0x4E6A,
	0xFFFD: 0x4E6B,
	0xFFFD: 0x4E6C,
	0xFFFD: 0x4E6D,
	0xFFFD: 0x4E6E,
	0xFFFD: 0x4E6F,
	0x8567: 0x4E70,
	0x85AF: 0x4E71,
	0xFFFD: 0x4E72,
	0xA8C5: 0x4E73,
	0xFFFD: 0x4E74,
	0xFFFD: 0x4E75,
	0xFFFD: 0x4E76,
	0xFFFD: 0x4E77,
	0xA061: 0x4E78,
	0xFFFD: 0x4E79,
	0xFFFD: 0x4E7A,
	0xFFFD: 0x4E7B,
	0xFFFD: 0x4E7C,
	0xFFFD: 0x4E7D,
	0xB0AE: 0x4E7E,
	0xD44B: 0x4E7F,
	0x93FA: 0x4E80,
	0x98A9: 0x4E81,
	0xB6C3: 0x4E82,
	0xDCB1: 0x4E83,
	0xDCB2: 0x4E84,
	0xC6C1: 0x4E85,
	0xA446: 0x4E86,
	0x98AA: 0x4E87,
	0xA4A9: 0x4E88,
	0x835C: 0x4E89,
	0x8145: 0x4E8A,
	0xA8C6: 0x4E8B,
	0xA447: 0x4E8C,
	0xC948: 0x4E8D,
	0xA45F: 0x4E8E,
	0x8A5F: 0x4E8F,
	0xFFFD: 0x4E90,
	0xA4AA: 0x4E91,
	0xA4AC: 0x4E92,
	0xC951: 0x4E93,
	0xA4AD: 0x4E94,
	0xA4AB: 0x4E95,
	0xFFFD: 0x4E96,
	0xFFFD: 0x4E97,
	0xFE62: 0x4E98,
	0xA5E5: 0x4E99,
	0x8352: 0x4E9A,
	0xA8C7: 0x4E9B,
	0x9240: 0x4E9C,
	0xFFFD: 0x4E9D,
	0xA8C8: 0x4E9E,
	0xAB45: 0x4E9F,
	0xC6C2: 0x4EA0,
	0xA460: 0x4EA1,
	0xA4AE: 0x4EA2,
	0x98AB: 0x4EA3,
	0xA5E6: 0x4EA4,
	0xA5E8: 0x4EA5,
	0xA5E7: 0x4EA6,
	0x8464: 0x4EA7,
	0xA6EB: 0x4EA8,
	0x83C2: 0x4EA9,
	0xFFFD: 0x4EAA,
	0xA8C9: 0x4EAB,
	0xA8CA: 0x4EAC,
	0xAB46: 0x4EAD,
	0xAB47: 0x4EAE,
	0xFFFD: 0x4EAF,
	0x8146: 0x4EB0,
	0xFFFD: 0x4EB1,
	0x895D: 0x4EB2,
	0xADBD: 0x4EB3,
	0xFFFD: 0x4EB4,
	0x8A62: 0x4EB5,
	0xDCB3: 0x4EB6,
	0x98AC: 0x4EB7,
	0xFFFD: 0x4EB8,
	0xF6D6: 0x4EB9,
	0xA448: 0x4EBA,
	0x9CF4: 0x4EBB,
	0x98AD: 0x4EBC,
	0xFFFD: 0x4EBD,
	0xFFFD: 0x4EBE,
	0x87A3: 0x4EBF,
	0xA4B0: 0x4EC0,
	0xA4AF: 0x4EC1,
	0xC952: 0x4EC2,
	0xA4B1: 0x4EC3,
	0xA4B7: 0x4EC4,
	0x85B2: 0x4EC5,
	0xA4B2: 0x4EC6,
	0xA4B3: 0x4EC7,
	0xC954: 0x4EC8,
	0xC953: 0x4EC9,
	0xA4B5: 0x4ECA,
	0xA4B6: 0x4ECB,
	0xFFFD: 0x4ECC,
	0xA4B4: 0x4ECD,
	0x8447: 0x4ECE,
	0x93C2: 0x4ECF,
	0xFFFD: 0x4ED0,
	0x8354: 0x4ED1,
	0xFFFD: 0x4ED2,
	0x83AC: 0x4ED3,
	0xA54A: 0x4ED4,
	0xA54B: 0x4ED5,
	0xA54C: 0x4ED6,
	0xA54D: 0x4ED7,
	0xA549: 0x4ED8,
	0xA550: 0x4ED9,
	0xC96A: 0x4EDA,
	0xFFFD: 0x4EDB,
	0xC966: 0x4EDC,
	0xC969: 0x4EDD,
	0xA551: 0x4EDE,
	0xA561: 0x4EDF,
	0xFFFD: 0x4EE0,
	0xC968: 0x4EE1,
	0xFFFD: 0x4EE2,
	0xA54E: 0x4EE3,
	0xA54F: 0x4EE4,
	0xA548: 0x4EE5,
	0xFFFD: 0x4EE6,
	0xFFFD: 0x4EE7,
	0xC965: 0x4EE8,
	0xC967: 0x4EE9,
	0x87A4: 0x4EEA,
	0x8147: 0x4EEB,
	0x83A8: 0x4EEC,
	0x8148: 0x4EED,
	0x9254: 0x4EEE,
	0xFFFD: 0x4EEF,
	0xA5F5: 0x4EF0,
	0xC9B0: 0x4EF1,
	0xA5F2: 0x4EF2,
	0xA5F6: 0x4EF3,
	0xC9BA: 0x4EF4,
	0xC9AE: 0x4EF5,
	0xA5F3: 0x4EF6,
	0xC9B2: 0x4EF7,
	0x98AE: 0x4EF8,
	0xFFFD: 0x4EF9,
	0xFFFD: 0x4EFA,
	0xA5F4: 0x4EFB,
	0x8149: 0x4EFC,
	0xA5F7: 0x4EFD,
	0xFFFD: 0x4EFE,
	0xA5E9: 0x4EFF,
	0xC9B1: 0x4F00,
	0xA5F8: 0x4F01,
	0xC9B5: 0x4F02,
	0xFBBA: 0x4F03,
	0xC9B9: 0x4F04,
	0xC9B6: 0x4F05,
	0xFFFD: 0x4F06,
	0xFFFD: 0x4F07,
	0xC9B3: 0x4F08,
	0xA5EA: 0x4F09,
	0xA5EC: 0x4F0A,
	0xA5F9: 0x4F0B,
	0xFFFD: 0x4F0C,
	0xA5EE: 0x4F0D,
	0xC9AB: 0x4F0E,
	0xA5F1: 0x4F0F,
	0xA5EF: 0x4F10,
	0xA5F0: 0x4F11,
	0xC9BB: 0x4F12,
	0xC9B8: 0x4F13,
	0xC9AF: 0x4F14,
	0xA5ED: 0x4F15,
	0xFFFD: 0x4F16,
	0x8467: 0x4F17,
	0xC9AC: 0x4F18,
	0xA5EB: 0x4F19,
	0x85D1: 0x4F1A,
	0x8DFD: 0x4F1B,
	0x814A: 0x4F1C,
	0xC9B4: 0x4F1D,
	0x84C4: 0x4F1E,
	0x83EC: 0x4F1F,
	0x85B1: 0x4F20,
	0xFFFD: 0x4F21,
	0xC9B7: 0x4F22,
	0xFFFD: 0x4F23,
	0x85B4: 0x4F24,
	0x83A9: 0x4F25,
	0x83AB: 0x4F26,
	0x84C3: 0x4F27,
	0x98AF: 0x4F28,
	0x98B0: 0x4F29,
	0x83EB: 0x4F2A,
	0x8343: 0x4F2B,
	0xC9AD: 0x4F2C,
	0xCA66: 0x4F2D,
	0xFFFD: 0x4F2E,
	0xA742: 0x4F2F,
	0xA6F4: 0x4F30,
	0xFFFD: 0x4F31,
	0xFBBD: 0x4F32,
	0xCA67: 0x4F33,
	0xA6F1: 0x4F34,
	0xFFFD: 0x4F35,
	0xA744: 0x4F36,
	0x98B1: 0x4F37,
	0xA6F9: 0x4F38,
	0xFBBC: 0x4F39,
	0xA6F8: 0x4F3A,
	0xCA5B: 0x4F3B,
	0xA6FC: 0x4F3C,
	0xA6F7: 0x4F3D,
	0xCA60: 0x4F3E,
	0xCA68: 0x4F3F,
	0xFFFD: 0x4F40,
	0xCA64: 0x4F41,
	0x98B2: 0x4F42,
	0xA6FA: 0x4F43,
	0xFFFD: 0x4F44,
	0x98B3: 0x4F45,
	0xA6FD: 0x4F46,
	0xA6EE: 0x4F47,
	0xA747: 0x4F48,
	0xCA5D: 0x4F49,
	0xFFFD: 0x4F4A,
	0x98B4: 0x4F4B,
	0xCBBD: 0x4F4C,
	0xA6EC: 0x4F4D,
	0xA743: 0x4F4E,
	0xA6ED: 0x4F4F,
	0xA6F5: 0x4F50,
	0xA6F6: 0x4F51,
	0xCA62: 0x4F52,
	0xCA5E: 0x4F53,
	0xA6FB: 0x4F54,
	0xA6F3: 0x4F55,
	0xCA5A: 0x4F56,
	0xA6EF: 0x4F57,
	0xCA65: 0x4F58,
	0xA745: 0x4F59,
	0xA748: 0x4F5A,
	0xA6F2: 0x4F5B,
	0xA740: 0x4F5C,
	0xA746: 0x4F5D,
	0xA6F0: 0x4F5E,
	0xCA63: 0x4F5F,
	0xA741: 0x4F60,
	0xCA69: 0x4F61,
	0xCA5C: 0x4F62,
	0xA6FE: 0x4F63,
	0xCA5F: 0x4F64,
	0x8E40: 0x4F65,
	0xFFFD: 0x4F66,
	0xCA61: 0x4F67,
	0xFFFD: 0x4F68,
	0xA8D8: 0x4F69,
	0xCBBF: 0x4F6A,
	0xCBCB: 0x4F6B,
	0xA8D0: 0x4F6C,
	0xFFFD: 0x4F6D,
	0xCBCC: 0x4F6E,
	0xA8CB: 0x4F6F,
	0xA8D5: 0x4F70,
	0xFFFD: 0x4F71,
	0x98B5: 0x4F72,
	0xA8CE: 0x4F73,
	0xCBB9: 0x4F74,
	0xA8D6: 0x4F75,
	0xCBB8: 0x4F76,
	0xCBBC: 0x4F77,
	0xCBC3: 0x4F78,
	0xCBC1: 0x4F79,
	0xA8DE: 0x4F7A,
	0xA8D9: 0x4F7B,
	0xCBB3: 0x4F7C,
	0xCBB5: 0x4F7D,
	0xA8DB: 0x4F7E,
	0xA8CF: 0x4F7F,
	0xCBB6: 0x4F80,
	0xCBC2: 0x4F81,
	0xCBC9: 0x4F82,
	0xA8D4: 0x4F83,
	0xCBBB: 0x4F84,
	0xCBB4: 0x4F85,
	0xA8D3: 0x4F86,
	0xCBB7: 0x4F87,
	0xA8D7: 0x4F88,
	0xCBBA: 0x4F89,
	0x814B: 0x4F8A,
	0xA8D2: 0x4F8B,
	0xFFFD: 0x4F8C,
	0xA8CD: 0x4F8D,
	0xFFFD: 0x4F8E,
	0xA8DC: 0x4F8F,
	0xCBC4: 0x4F90,
	0xA8DD: 0x4F91,
	0xCBC8: 0x4F92,
	0xFFFD: 0x4F93,
	0xCBC6: 0x4F94,
	0xCBCA: 0x4F95,
	0xA8DA: 0x4F96,
	0xCBBE: 0x4F97,
	0xCBB2: 0x4F98,
	0xFFFD: 0x4F99,
	0xCBC0: 0x4F9A,
	0xA8D1: 0x4F9B,
	0xCBC5: 0x4F9C,
	0xA8CC: 0x4F9D,
	0xCBC7: 0x4F9E,
	0xFFFD: 0x4F9F,
	0x8365: 0x4FA0,
	0x9255: 0x4FA1,
	0x98B6: 0x4FA2,
	0x8366: 0x4FA3,
	0xFFFD: 0x4FA4,
	0x86AB: 0x4FA5,
	0x83ED: 0x4FA6,
	0x83EE: 0x4FA7,
	0x86AC: 0x4FA8,
	0x87A7: 0x4FA9,
	0x88CA: 0x4FAA,
	0xFBBE: 0x4FAB,
	0x87A6: 0x4FAC,
	0x827D: 0x4FAD,
	0xAB56: 0x4FAE,
	0xAB4A: 0x4FAF,
	0x98B7: 0x4FB0,
	0xFFFD: 0x4FB1,
	0xCDE0: 0x4FB2,
	0xCDE8: 0x4FB3,
	0x98F7: 0x4FB4,
	0xAB49: 0x4FB5,
	0xAB51: 0x4FB6,
	0xAB5D: 0x4FB7,
	0xFFFD: 0x4FB8,
	0xCDEE: 0x4FB9,
	0xCDEC: 0x4FBA,
	0xCDE7: 0x4FBB,
	0xFFFD: 0x4FBC,
	0x98B8: 0x4FBD,
	0xFFFD: 0x4FBE,
	0xAB4B: 0x4FBF,
	0xCDED: 0x4FC0,
	0xCDE3: 0x4FC1,
	0xAB59: 0x4FC2,
	0xAB50: 0x4FC3,
	0xAB58: 0x4FC4,
	0xCDDE: 0x4FC5,
	0xFFFD: 0x4FC6,
	0xCDEA: 0x4FC7,
	0x98B9: 0x4FC8,
	0xCDE1: 0x4FC9,
	0xAB54: 0x4FCA,
	0xCDE2: 0x4FCB,
	0x98BA: 0x4FCC,
	0xCDDD: 0x4FCD,
	0xAB5B: 0x4FCE,
	0xAB4E: 0x4FCF,
	0xAB57: 0x4FD0,
	0xAB4D: 0x4FD1,
	0xFFFD: 0x4FD2,
	0xCDDF: 0x4FD3,
	0xCDE4: 0x4FD4,
	0xFFFD: 0x4FD5,
	0xCDEB: 0x4FD6,
	0xAB55: 0x4FD7,
	0xAB52: 0x4FD8,
	0xCDE6: 0x4FD9,
	0xAB5A: 0x4FDA,
	0xCDE9: 0x4FDB,
	0xCDE5: 0x4FDC,
	0xAB4F: 0x4FDD,
	0xAB5C: 0x4FDE,
	0xAB53: 0x4FDF,
	0xAB4C: 0x4FE0,
	0xAB48: 0x4FE1,
	0xFFFD: 0x4FE2,
	0x8DB9: 0x4FE3,
	0x945F: 0x4FE4,
	0x9460: 0x4FE5,
	0x88C8: 0x4FE6,
	0xFFFD: 0x4FE7,
	0x8CC8: 0x4FE8,
	0x83A7: 0x4FE9,
	0x8C6C: 0x4FEA,
	0xFFFD: 0x4FEB,
	0xCDEF: 0x4FEC,
	0x87A8: 0x4FED,
	0xADD7: 0x4FEE,
	0xADC1: 0x4FEF,
	0x98BB: 0x4FF0,
	0xADD1: 0x4FF1,
	0x98BC: 0x4FF2,
	0xADD6: 0x4FF3,
	0xD0D0: 0x4FF4,
	0xD0CF: 0x4FF5,
	0xD0D4: 0x4FF6,
	0xD0D5: 0x4FF7,
	0xADC4: 0x4FF8,
	0x98BD: 0x4FF9,
	0xADCD: 0x4FFA,
	0xFFFD: 0x4FFB,
	0xFFFD: 0x4FFC,
	0xFE7B: 0x4FFD,
	0xADDA: 0x4FFE,
	0x814C: 0x4FFF,
	0xADCE: 0x5000,
	0xFFFD: 0x5001,
	0xFFFD: 0x5002,
	0x98BE: 0x5003,
	0xFFFD: 0x5004,
	0xD0C9: 0x5005,
	0xADC7: 0x5006,
	0xD0CA: 0x5007,
	0x98BF: 0x5008,
	0xADDC: 0x5009,
	0xFFFD: 0x500A,
	0xADD3: 0x500B,
	0xADBE: 0x500C,
	0xADBF: 0x500D,
	0xD0DD: 0x500E,
	0xB0BF: 0x500F,
	0xFFFD: 0x5010,
	0xADCC: 0x5011,
	0xADCB: 0x5012,
	0xD0CB: 0x5013,
	0xADCF: 0x5014,
	0xD45B: 0x5015,
	0xADC6: 0x5016,
	0xD0D6: 0x5017,
	0xADD5: 0x5018,
	0xADD4: 0x5019,
	0xADCA: 0x501A,
	0xD0CE: 0x501B,
	0xD0D7: 0x501C,
	0xFFFD: 0x501D,
	0xD0C8: 0x501E,
	0xADC9: 0x501F,
	0xD0D8: 0x5020,
	0xADD2: 0x5021,
	0xD0CC: 0x5022,
	0xADC0: 0x5023,
	0x82A9: 0x5024,
	0xADC3: 0x5025,
	0xADC2: 0x5026,
	0xD0D9: 0x5027,
	0xADD0: 0x5028,
	0xADC5: 0x5029,
	0xADD9: 0x502A,
	0xADDB: 0x502B,
	0xD0D3: 0x502C,
	0xADD8: 0x502D,
	0xFBC1: 0x502E,
	0xD0DB: 0x502F,
	0xD0CD: 0x5030,
	0xD0DC: 0x5031,
	0xFFFD: 0x5032,
	0xD0D1: 0x5033,
	0x98C0: 0x5034,
	0xD0DA: 0x5035,
	0x82A3: 0x5036,
	0xD0D2: 0x5037,
	0xFFFD: 0x5038,
	0x92B2: 0x5039,
	0x85B0: 0x503A,
	0x98C1: 0x503B,
	0xADC8: 0x503C,
	0xFFFD: 0x503D,
	0x85B3: 0x503E,
	0xFFFD: 0x503F,
	0xD463: 0x5040,
	0xD457: 0x5041,
	0x814D: 0x5042,
	0xB0B3: 0x5043,
	0xFFFD: 0x5044,
	0xD45C: 0x5045,
	0xD462: 0x5046,
	0xB0B2: 0x5047,
	0xD455: 0x5048,
	0xB0B6: 0x5049,
	0xD459: 0x504A,
	0xD452: 0x504B,
	0xB0B4: 0x504C,
	0xD456: 0x504D,
	0xB0B9: 0x504E,
	0xB0BE: 0x504F,
	0x814E: 0x5050,
	0xD467: 0x5051,
	0xFFFD: 0x5052,
	0xD451: 0x5053,
	0xFFFD: 0x5054,
	0xB0BA: 0x5055,
	0xFBBF: 0x5056,
	0xD466: 0x5057,
	0x98C2: 0x5058,
	0xFFFD: 0x5059,
	0xB0B5: 0x505A,
	0xD458: 0x505B,
	0xB0B1: 0x505C,
	0xD453: 0x505D,
	0xD44F: 0x505E,
	0xD45D: 0x505F,
	0xD450: 0x5060,
	0xD44E: 0x5061,
	0xD45A: 0x5062,
	0xD460: 0x5063,
	0xD461: 0x5064,
	0xB0B7: 0x5065,
	0x98C3: 0x5066,
	0xFFFD: 0x5067,
	0xD85B: 0x5068,
	0xD45E: 0x5069,
	0xD44D: 0x506A,
	0xD45F: 0x506B,
	0x85B5: 0x506C,
	0xB0C1: 0x506D,
	0xD464: 0x506E,
	0xB0C0: 0x506F,
	0xD44C: 0x5070,
	0xFFFD: 0x5071,
	0xD454: 0x5072,
	0xD465: 0x5073,
	0xB0BC: 0x5074,
	0xB0BB: 0x5075,
	0xB0B8: 0x5076,
	0xB0BD: 0x5077,
	0x814F: 0x5078,
	0xFFFD: 0x5079,
	0xB0AF: 0x507A,
	0x8DFE: 0x507B,
	0xFFFD: 0x507C,
	0xB0B0: 0x507D,
	0x8E65: 0x507E,
	0x89C8: 0x507F,
	0xB3C8: 0x5080,
	0x98C4: 0x5081,
	0xD85E: 0x5082,
	0xD857: 0x5083,
	0xFFFD: 0x5084,
	0xB3C5: 0x5085,
	0xFFFD: 0x5086,
	0xD85F: 0x5087,
	0x90F0: 0x5088,
	0xFFFD: 0x5089,
	0xFFFD: 0x508A,
	0xD855: 0x508B,
	0xD858: 0x508C,
	0xB3C4: 0x508D,
	0xD859: 0x508E,
	0xFFFD: 0x508F,
	0x98C5: 0x5090,
	0xB3C7: 0x5091,
	0xD85D: 0x5092,
	0xFFFD: 0x5093,
	0xD853: 0x5094,
	0xD852: 0x5095,
	0xB3C9: 0x5096,
	0xFFFD: 0x5097,
	0xB3CA: 0x5098,
	0xB3C6: 0x5099,
	0xB3CB: 0x509A,
	0xD851: 0x509B,
	0xD85C: 0x509C,
	0xD85A: 0x509D,
	0xD854: 0x509E,
	0xFFFD: 0x509F,
	0xFFFD: 0x50A0,
	0xFFFD: 0x50A1,
	0xB3C3: 0x50A2,
	0xD856: 0x50A3,
	0xFFFD: 0x50A4,
	0x8CC9: 0x50A5,
	0xFBC2: 0x50A6,
	0x88C9: 0x50A7,
	0x89C9: 0x50A8,
	0x8FFB: 0x50A9,
	0xFFFD: 0x50AA,
	0xFFFD: 0x50AB,
	0xB6CA: 0x50AC,
	0xB6C4: 0x50AD,
	0xDCB7: 0x50AE,
	0xB6CD: 0x50AF,
	0xDCBD: 0x50B0,
	0xDCC0: 0x50B1,
	0xB6C6: 0x50B2,
	0xB6C7: 0x50B3,
	0xDCBA: 0x50B4,
	0xB6C5: 0x50B5,
	0xDCC3: 0x50B6,
	0xB6CB: 0x50B7,
	0xDCC4: 0x50B8,
	0xFFFD: 0x50B9,
	0xDCBF: 0x50BA,
	0xB6CC: 0x50BB,
	0x98C6: 0x50BC,
	0xDCB4: 0x50BD,
	0xB6C9: 0x50BE,
	0xDCB5: 0x50BF,
	0xFFFD: 0x50C0,
	0xDCBE: 0x50C1,
	0xDCBC: 0x50C2,
	0xFFFD: 0x50C3,
	0xDCB8: 0x50C4,
	0xB6C8: 0x50C5,
	0xDCB6: 0x50C6,
	0xB6CE: 0x50C7,
	0xDCBB: 0x50C8,
	0xDCC2: 0x50C9,
	0xDCB9: 0x50CA,
	0xDCC1: 0x50CB,
	0xFFFD: 0x50CC,
	0x944F: 0x50CD,
	0xB9B6: 0x50CE,
	0xB9B3: 0x50CF,
	0x98C7: 0x50D0,
	0xB9B4: 0x50D1,
	0xFFFD: 0x50D2,
	0xE0F9: 0x50D3,
	0xE0F1: 0x50D4,
	0xB9B2: 0x50D5,
	0xB9AF: 0x50D6,
	0xE0F2: 0x50D7,
	0x8150: 0x50D8,
	0xFBC3: 0x50D9,
	0xB9B1: 0x50DA,
	0xE0F5: 0x50DB,
	0xFFFD: 0x50DC,
	0xE0F7: 0x50DD,
	0x8151: 0x50DE,
	0x98C8: 0x50DF,
	0xE0FE: 0x50E0,
	0x98C9: 0x50E1,
	0xFFFD: 0x50E2,
	0xE0FD: 0x50E3,
	0xE0F8: 0x50E4,
	0xB9AE: 0x50E5,
	0xE0F0: 0x50E6,
	0xB9AC: 0x50E7,
	0xE0F3: 0x50E8,
	0xB9B7: 0x50E9,
	0xE0F6: 0x50EA,
	0xFFFD: 0x50EB,
	0xE0FA: 0x50EC,
	0xB9B0: 0x50ED,
	0xB9AD: 0x50EE,
	0xE0FC: 0x50EF,
	0xE0FB: 0x50F0,
	0xB9B5: 0x50F1,
	0xFFFD: 0x50F2,
	0xE0F4: 0x50F3,
	0x8152: 0x50F4,
	0xBBF8: 0x50F5,
	0xE4EC: 0x50F6,
	0xFFFD: 0x50F7,
	0xE4E9: 0x50F8,
	0xBBF9: 0x50F9,
	0xFFFD: 0x50FA,
	0xBBF7: 0x50FB,
	0x98CA: 0x50FC,
	0xE4F0: 0x50FD,
	0xE4ED: 0x50FE,
	0xE4E6: 0x50FF,
	0xBBF6: 0x5100,
	0xFBC6: 0x5101,
	0xBBFA: 0x5102,
	0xE4E7: 0x5103,
	0xBBF5: 0x5104,
	0xBBFD: 0x5105,
	0xE4EA: 0x5106,
	0xE4EB: 0x5107,
	0xBBFB: 0x5108,
	0xBBFC: 0x5109,
	0xE4F1: 0x510A,
	0xE4EE: 0x510B,
	0xE4EF: 0x510C,
	0x98CB: 0x510D,
	0xFBC4: 0x510E,
	0xFFFD: 0x510F,
	0xBEAA: 0x5110,
	0xE8F8: 0x5111,
	0xBEA7: 0x5112,
	0xE8F5: 0x5113,
	0xBEA9: 0x5114,
	0xBEAB: 0x5115,
	0x8153: 0x5116,
	0xE8F6: 0x5117,
	0xBEA8: 0x5118,
	0xFFFD: 0x5119,
	0xE8F7: 0x511A,
	0xFFFD: 0x511B,
	0xE8F4: 0x511C,
	0xFFFD: 0x511D,
	0xFFFD: 0x511E,
	0xC076: 0x511F,
	0xECBD: 0x5120,
	0xC077: 0x5121,
	0xECBB: 0x5122,
	0xFFFD: 0x5123,
	0xECBC: 0x5124,
	0xECBA: 0x5125,
	0xECB9: 0x5126,
	0xFFFD: 0x5127,
	0xFFFD: 0x5128,
	0xECBE: 0x5129,
	0xC075: 0x512A,
	0x98CC: 0x512B,
	0xFFFD: 0x512C,
	0xEFB8: 0x512D,
	0xEFB9: 0x512E,
	0xFFFD: 0x512F,
	0xE4E8: 0x5130,
	0xEFB7: 0x5131,
	0xC078: 0x5132,
	0xC35F: 0x5133,
	0xF1EB: 0x5134,
	0xF1EC: 0x5135,
	0xFFFD: 0x5136,
	0xC4D7: 0x5137,
	0xC4D8: 0x5138,
	0xF5C1: 0x5139,
	0xF5C0: 0x513A,
	0xC56C: 0x513B,
	0xC56B: 0x513C,
	0xF7D0: 0x513D,
	0xFFFD: 0x513E,
	0xA449: 0x513F,
	0xA461: 0x5140,
	0xA4B9: 0x5141,
	0xFFFD: 0x5142,
	0xA4B8: 0x5143,
	0xA553: 0x5144,
	0xA552: 0x5145,
	0xA5FC: 0x5146,
	0xA5FB: 0x5147,
	0xA5FD: 0x5148,
	0xA5FA: 0x5149,
	0x8154: 0x514A,
	0xA74A: 0x514B,
	0xA749: 0x514C,
	0xA74B: 0x514D,
	0x95FC: 0x514E,
	0xFFFD: 0x514F,
	0x92D1: 0x5150,
	0x8155: 0x5151,
	0xA8E0: 0x5152,
	0xFFFD: 0x5153,
	0xA8DF: 0x5154,
	0xA8E1: 0x5155,
	0x8367: 0x5156,
	0xAB5E: 0x5157,
	0xFFFD: 0x5158,
	0xA259: 0x5159,
	0xD0DE: 0x515A,
	0xA25A: 0x515B,
	0xB0C2: 0x515C,
	0xA25C: 0x515D,
	0xA25B: 0x515E,
	0xD860: 0x515F,
	0x98CD: 0x5160,
	0xA25D: 0x5161,
	0xB9B8: 0x5162,
	0xA25E: 0x5163,
	0x8156: 0x5164,
	0xA44A: 0x5165,
	0xFFFD: 0x5166,
	0xA4BA: 0x5167,
	0xA5FE: 0x5168,
	0xA8E2: 0x5169,
	0x8157: 0x516A,
	0xA44B: 0x516B,
	0xA4BD: 0x516C,
	0xA4BB: 0x516D,
	0xA4BC: 0x516E,
	0xFFFD: 0x516F,
	0x8CA3: 0x5170,
	0xA640: 0x5171,
	0xFFFD: 0x5172,
	0x8BD7: 0x5173,
	0x8955: 0x5174,
	0xA74C: 0x5175,
	0xA8E4: 0x5176,
	0xA8E3: 0x5177,
	0xA8E5: 0x5178,
	0x90BC: 0x5179,
	0xFFFD: 0x517A,
	0x88B5: 0x517B,
	0xADDD: 0x517C,
	0x8BA6: 0x517D,
	0xFFFD: 0x517E,
	0xFFFD: 0x517F,
	0xBEAC: 0x5180,
	0x9054: 0x5181,
	0xC6C3: 0x5182,
	0xFFFD: 0x5183,
	0xFFFD: 0x5184,
	0x8158: 0x5185,
	0x924C: 0x5186,
	0xC94E: 0x5187,
	0x8358: 0x5188,
	0xA554: 0x5189,
	0xA555: 0x518A,
	0xFFFD: 0x518B,
	0x95E4: 0x518C,
	0xA641: 0x518D,
	0xFFFD: 0x518E,
	0xCA6A: 0x518F,
	0x8159: 0x5190,
	0xAB60: 0x5191,
	0xAB5F: 0x5192,
	0xD0E0: 0x5193,
	0xD0DF: 0x5194,
	0xB0C3: 0x5195,
	0xC6C4: 0x5196,
	0xA4BE: 0x5197,
	0xC955: 0x5198,
	0x87C0: 0x5199,
	0xFB41: 0x519A,
	0x837E: 0x519B,
	0x8661: 0x519C,
	0x815A: 0x519D,
	0xCBCD: 0x519E,
	0xFFFD: 0x519F,
	0xAB61: 0x51A0,
	0xFFFD: 0x51A1,
	0xADE0: 0x51A2,
	0xFFFD: 0x51A3,
	0xADDE: 0x51A4,
	0xADDF: 0x51A5,
	0x815B: 0x51A6,
	0xFB4E: 0x51A7,
	0x815C: 0x51A8,
	0x815D: 0x51A9,
	0xBEAD: 0x51AA,
	0xC6C5: 0x51AB,
	0xA556: 0x51AC,
	0xFFFD: 0x51AD,
	0x98CE: 0x51AE,
	0x85AD: 0x51AF,
	0xA642: 0x51B0,
	0xC9BC: 0x51B1,
	0x834C: 0x51B2,
	0x834B: 0x51B3,
	0x94FB: 0x51B4,
	0x95D5: 0x51B5,
	0xA74D: 0x51B6,
	0xA74E: 0x51B7,
	0x98CF: 0x51B8,
	0xCA6B: 0x51B9,
	0xFFFD: 0x51BA,
	0x83AD: 0x51BB,
	0xCBCE: 0x51BC,
	0xA8E6: 0x51BD,
	0xCBCF: 0x51BE,
	0xFFFD: 0x51BF,
	0x8460: 0x51C0,
	0xFFFD: 0x51C1,
	0xFFFD: 0x51C2,
	0x95F3: 0x51C3,
	0xD0E2: 0x51C4,
	0xD0E3: 0x51C5,
	0xADE3: 0x51C6,
	0x815E: 0x51C7,
	0xD0E4: 0x51C8,
	0x845B: 0x51C9,
	0xD0E1: 0x51CA,
	0xADE4: 0x51CB,
	0xADE2: 0x51CC,
	0xADE1: 0x51CD,
	0xD0E5: 0x51CE,
	0x90B6: 0x51CF,
	0xD468: 0x51D0,
	0x84EE: 0x51D1,
	0x98D0: 0x51D2,
	0xFBCF: 0x51D3,
	0xD861: 0x51D4,
	0xFFFD: 0x51D5,
	0x815F: 0x51D6,
	0xDCC5: 0x51D7,
	0xE140: 0x51D8,
	0xFFFD: 0x51D9,
	0xFFFD: 0x51DA,
	0x8160: 0x51DB,
	0xBBFE: 0x51DC,
	0xBEAE: 0x51DD,
	0xE8F9: 0x51DE,
	0xFBD0: 0x51DF,
	0xA44C: 0x51E0,
	0xA45A: 0x51E1,
	0x98D1: 0x51E2,
	0xFFFD: 0x51E3,
	0x87A1: 0x51E4,
	0xFFFD: 0x51E5,
	0x92E1: 0x51E6,
	0x944C: 0x51E7,
	0xFFFD: 0x51E8,
	0x9461: 0x51E9,
	0x9452: 0x51EA,
	0x8E63: 0x51EB,
	0x8161: 0x51EC,
	0x88D7: 0x51ED,
	0xFFFD: 0x51EE,
	0x84C5: 0x51EF,
	0xB0C4: 0x51F0,
	0xB3CD: 0x51F1,
	0xFFFD: 0x51F2,
	0xB9B9: 0x51F3,
	0xFBC7: 0x51F4,
	0xC942: 0x51F5,
	0xA4BF: 0x51F6,
	0xFFFD: 0x51F7,
	0xA559: 0x51F8,
	0xA557: 0x51F9,
	0xA558: 0x51FA,
	0x89DB: 0x51FB,
	0x8162: 0x51FC,
	0xA8E7: 0x51FD,
	0xFBD2: 0x51FE,
	0x8DAD: 0x51FF,
	0xA44D: 0x5200,
	0xA44E: 0x5201,
	0xC87D: 0x5202,
	0xA462: 0x5203,
	0x95CF: 0x5204,
	0x98D2: 0x5205,
	0xA4C0: 0x5206,
	0xA4C1: 0x5207,
	0xA4C2: 0x5208,
	0xC9BE: 0x5209,
	0xA55A: 0x520A,
	0x8163: 0x520B,
	0xC96B: 0x520C,
	0x83D2: 0x520D,
	0xA646: 0x520E,
	0xFFFD: 0x520F,
	0xC9BF: 0x5210,
	0xA644: 0x5211,
	0xA645: 0x5212,
	0xC9BD: 0x5213,
	0x8164: 0x5214,
	0x8165: 0x5215,
	0xA647: 0x5216,
	0xA643: 0x5217,
	0x87AA: 0x5218,
	0x8368: 0x5219,
	0x83AE: 0x521A,
	0x84C7: 0x521B,
	0xCA6C: 0x521C,
	0xAAEC: 0x521D,
	0xCA6D: 0x521E,
	0xFBC8: 0x521F,
	0x8166: 0x5220,
	0xCA6E: 0x5221,
	0xFFFD: 0x5222,
	0xA07E: 0x5223,
	0xA750: 0x5224,
	0xA74F: 0x5225,
	0x957B: 0x5226,
	0x95E5: 0x5227,
	0xA753: 0x5228,
	0xA751: 0x5229,
	0xA752: 0x522A,
	0x8167: 0x522B,
	0xFFFD: 0x522C,
	0x8DBA: 0x522D,
	0xA8ED: 0x522E,
	0xFFFD: 0x522F,
	0xA8EC: 0x5230,
	0xCBD4: 0x5231,
	0xCBD1: 0x5232,
	0xCBD2: 0x5233,
	0x98D3: 0x5234,
	0xCBD0: 0x5235,
	0xA8EE: 0x5236,
	0xA8EA: 0x5237,
	0xA8E9: 0x5238,
	0x8168: 0x5239,
	0xA8EB: 0x523A,
	0xA8E8: 0x523B,
	0x98D4: 0x523C,
	0x87AC: 0x523D,
	0xFFFD: 0x523E,
	0x8EAF: 0x523F,
	0x84C6: 0x5240,
	0xA8EF: 0x5241,
	0x88CC: 0x5242,
	0xAB63: 0x5243,
	0xCDF0: 0x5244,
	0xFFFD: 0x5245,
	0xCBD3: 0x5246,
	0xAB68: 0x5247,
	0xFFFD: 0x5248,
	0xCDF1: 0x5249,
	0xAB64: 0x524A,
	0xAB67: 0x524B,
	0xAB66: 0x524C,
	0xAB65: 0x524D,
	0xAB62: 0x524E,
	0x8169: 0x524F,
	0x8DC8: 0x5250,
	0x87AB: 0x5251,
	0xD0E8: 0x5252,
	0xFFFD: 0x5253,
	0xADE7: 0x5254,
	0xD0EB: 0x5255,
	0xADE5: 0x5256,
	0xFBCA: 0x5257,
	0xFFFD: 0x5258,
	0x98D5: 0x5259,
	0xD0E7: 0x525A,
	0xADE8: 0x525B,
	0xADE6: 0x525C,
	0xADE9: 0x525D,
	0xD0E9: 0x525E,
	0xD0EA: 0x525F,
	0xFBC9: 0x5260,
	0xD0E6: 0x5261,
	0xD0EC: 0x5262,
	0x92B3: 0x5263,
	0x92C9: 0x5264,
	0x8276: 0x5265,
	0xFFFD: 0x5266,
	0x87A9: 0x5267,
	0x98D6: 0x5268,
	0xB3D1: 0x5269,
	0xB0C5: 0x526A,
	0xD469: 0x526B,
	0xD46B: 0x526C,
	0xD46A: 0x526D,
	0xD46C: 0x526E,
	0xB0C6: 0x526F,
	0x92EB: 0x5270,
	0x816A: 0x5271,
	0xB3CE: 0x5272,
	0xFCF5: 0x5273,
	0xB3CF: 0x5274,
	0xB3D0: 0x5275,
	0xFFFD: 0x5276,
	0xB6D0: 0x5277,
	0xDCC7: 0x5278,
	0x98D7: 0x5279,
	0xDCC6: 0x527A,
	0xDCC8: 0x527B,
	0xDCC9: 0x527C,
	0xB6D1: 0x527D,
	0xFFFD: 0x527E,
	0xB6CF: 0x527F,
	0xE141: 0x5280,
	0xE142: 0x5281,
	0xB9BB: 0x5282,
	0xB9BA: 0x5283,
	0xE35A: 0x5284,
	0xFFFD: 0x5285,
	0xFFFD: 0x5286,
	0xBC40: 0x5287,
	0xBC41: 0x5288,
	0xBC42: 0x5289,
	0xBC44: 0x528A,
	0xE4F2: 0x528B,
	0xE4F3: 0x528C,
	0xBC43: 0x528D,
	0xFFFD: 0x528E,
	0xFB69: 0x528F,
	0x816B: 0x5290,
	0xBEAF: 0x5291,
	0x816C: 0x5292,
	0xBEB0: 0x5293,
	0x816D: 0x5294,
	0xFFFD: 0x5295,
	0xF1ED: 0x5296,
	0xF5C3: 0x5297,
	0xF5C2: 0x5298,
	0xF7D1: 0x5299,
	0xFBCB: 0x529A,
	0xA44F: 0x529B,
	0x816E: 0x529C,
	0x8BEF: 0x529D,
	0x8974: 0x529E,
	0xA55C: 0x529F,
	0xA55B: 0x52A0,
	0x83EF: 0x52A1,
	0x8EB0: 0x52A2,
	0xA648: 0x52A3,
	0x98D8: 0x52A4,
	0xFFFD: 0x52A5,
	0xC9C0: 0x52A6,
	0xFFFD: 0x52A7,
	0x83F0: 0x52A8,
	0xA755: 0x52A9,
	0xA756: 0x52AA,
	0xA754: 0x52AB,
	0xA757: 0x52AC,
	0xCA6F: 0x52AD,
	0xCA70: 0x52AE,
	0x816F: 0x52AF,
	0xFFFD: 0x52B0,
	0x89CA: 0x52B1,
	0x8369: 0x52B2,
	0x84C8: 0x52B3,
	0x93F5: 0x52B4,
	0x8170: 0x52B5,
	0xFFFD: 0x52B6,
	0xFFFD: 0x52B7,
	0xFFFD: 0x52B8,
	0x95A2: 0x52B9,
	0xFFFD: 0x52BA,
	0xA8F1: 0x52BB,
	0xCBD5: 0x52BC,
	0xFFFD: 0x52BD,
	0xA8F0: 0x52BE,
	0x85B7: 0x52BF,
	0xCDF2: 0x52C0,
	0xAB6C: 0x52C1,
	0xCDF3: 0x52C2,
	0xAB6B: 0x52C3,
	0xFFFD: 0x52C4,
	0x9544: 0x52C5,
	0xFFFD: 0x52C6,
	0xAB69: 0x52C7,
	0xFFFD: 0x52C8,
	0xAB6A: 0x52C9,
	0xFFFD: 0x52CA,
	0x84C9: 0x52CB,
	0x98D9: 0x52CC,
	0xD0ED: 0x52CD,
	0xFFFD: 0x52CE,
	0xFFFD: 0x52CF,
	0x8171: 0x52D0,
	0xFBCC: 0x52D1,
	0xB0C7: 0x52D2,
	0xD46E: 0x52D3,
	0xFFFD: 0x52D4,
	0xB0CA: 0x52D5,
	0xD46D: 0x52D6,
	0xB1E5: 0x52D7,
	0xB0C9: 0x52D8,
	0xB0C8: 0x52D9,
	0xFFFD: 0x52DA,
	0xB3D4: 0x52DB,
	0xFFFD: 0x52DC,
	0xB3D3: 0x52DD,
	0xB3D2: 0x52DE,
	0xB6D2: 0x52DF,
	0xFBCD: 0x52E0,
	0xFBCE: 0x52E1,
	0xB6D5: 0x52E2,
	0xB6D6: 0x52E3,
	0xB6D4: 0x52E4,
	0xFFFD: 0x52E5,
	0xB6D3: 0x52E6,
	0x9268: 0x52E7,
	0xFFFD: 0x52E8,
	0xE143: 0x52E9,
	0xFFFD: 0x52EA,
	0xE144: 0x52EB,
	0xFFFD: 0x52EC,
	0xFFFD: 0x52ED,
	0xFFFD: 0x52EE,
	0xE4F5: 0x52EF,
	0xBC45: 0x52F0,
	0xE4F4: 0x52F1,
	0x92A4: 0x52F2,
	0xBEB1: 0x52F3,
	0xECBF: 0x52F4,
	0xC079: 0x52F5,
	0xFFFD: 0x52F6,
	0xF1EE: 0x52F7,
	0xC455: 0x52F8,
	0xC6C6: 0x52F9,
	0xA463: 0x52FA,
	0xA4C3: 0x52FB,
	0xC956: 0x52FC,
	0xFFFD: 0x52FD,
	0xA4C4: 0x52FE,
	0xA4C5: 0x52FF,
	0x8172: 0x5300,
	0x945E: 0x5301,
	0x9453: 0x5302,
	0x9CD0: 0x5303,
	0xFFFD: 0x5304,
	0xA55D: 0x5305,
	0xA55E: 0x5306,
	0x8173: 0x5307,
	0xA649: 0x5308,
	0xCA71: 0x5309,
	0xCBD6: 0x530A,
	0xCBD7: 0x530B,
	0xFFFD: 0x530C,
	0xAB6D: 0x530D,
	0xD0EE: 0x530E,
	0xB0CC: 0x530F,
	0xB0CB: 0x5310,
	0xD863: 0x5311,
	0xD862: 0x5312,
	0xFFFD: 0x5313,
	0xFFFD: 0x5314,
	0xA450: 0x5315,
	0xA4C6: 0x5316,
	0xA55F: 0x5317,
	0xFFFD: 0x5318,
	0xB0CD: 0x5319,
	0xC943: 0x531A,
	0xFFFD: 0x531B,
	0xC96C: 0x531C,
	0xA560: 0x531D,
	0xFFFD: 0x531E,
	0xC9C2: 0x531F,
	0xA64B: 0x5320,
	0xA64A: 0x5321,
	0xC9C1: 0x5322,
	0xA758: 0x5323,
	0x8174: 0x5324,
	0xFFFD: 0x5325,
	0x8DC9: 0x5326,
	0x98DA: 0x5327,
	0xFFFD: 0x5328,
	0xFFFD: 0x5329,
	0xADEA: 0x532A,
	0xFFFD: 0x532B,
	0xFBD4: 0x532C,
	0xD46F: 0x532D,
	0x86AD: 0x532E,
	0xB6D7: 0x532F,
	0xE145: 0x5330,
	0xB9BC: 0x5331,
	0xFBD3: 0x5332,
	0xFBD5: 0x5333,
	0xE8FA: 0x5334,
	0xFFFD: 0x5335,
	0xFFFD: 0x5336,
	0xF3FD: 0x5337,
	0xC6C7: 0x5338,
	0xA4C7: 0x5339,
	0x83F1: 0x533A,
	0x8B4B: 0x533B,
	0xCBD8: 0x533C,
	0xCDF4: 0x533D,
	0xB0D0: 0x533E,
	0xB0CE: 0x533F,
	0xB0CF: 0x5340,
	0xA451: 0x5341,
	0x98DB: 0x5342,
	0xA464: 0x5343,
	0xA2CD: 0x5344,
	0xA4CA: 0x5345,
	0x8175: 0x5346,
	0xA4C9: 0x5347,
	0xA4C8: 0x5348,
	0xA563: 0x5349,
	0xA562: 0x534A,
	0xFFFD: 0x534B,
	0xC96D: 0x534C,
	0xC9C3: 0x534D,
	0x854F: 0x534E,
	0x8356: 0x534F,
	0xFFFD: 0x5350,
	0xA8F5: 0x5351,
	0xA8F2: 0x5352,
	0xA8F4: 0x5353,
	0xA8F3: 0x5354,
	0x84CB: 0x5355,
	0x886F: 0x5356,
	0xAB6E: 0x5357,
	0x936D: 0x5358,
	0xFFFD: 0x5359,
	0xB3D5: 0x535A,
	0xFFFD: 0x535B,
	0xA452: 0x535C,
	0x98DC: 0x535D,
	0xA4CB: 0x535E,
	0x8176: 0x535F,
	0xA565: 0x5360,
	0xA564: 0x5361,
	0x8941: 0x5362,
	0xCA72: 0x5363,
	0x84C0: 0x5364,
	0xFFFD: 0x5365,
	0xA8F6: 0x5366,
	0x8360: 0x5367,
	0xFFFD: 0x5368,
	0xC6C8: 0x5369,
	0xFFFD: 0x536A,
	0x8855: 0x536B,
	0xC957: 0x536C,
	0x95F2: 0x536D,
	0xA567: 0x536E,
	0xA566: 0x536F,
	0xA64C: 0x5370,
	0xA64D: 0x5371,
	0xCA73: 0x5372,
	0xA759: 0x5373,
	0x836A: 0x5374,
	0xA75A: 0x5375,
	0xFFFD: 0x5376,
	0xA8F7: 0x5377,
	0xA8F8: 0x5378,
	0xA8F9: 0x5379,
	0x8DBD: 0x537A,
	0xAB6F: 0x537B,
	0xCDF5: 0x537C,
	0x98DD: 0x537D,
	0x98DE: 0x537E,
	0xADEB: 0x537F,
	0xFFFD: 0x5380,
	0xFFFD: 0x5381,
	0xC944: 0x5382,
	0xFFFD: 0x5383,
	0xA4CC: 0x5384,
	0x8D6D: 0x5385,
	0x88E5: 0x5386,
	0xFFFD: 0x5387,
	0xFFFD: 0x5388,
	0x87AD: 0x5389,
	0xC9C4: 0x538A,
	0x89CD: 0x538B,
	0x86AE: 0x538C,
	0x8DBB: 0x538D,
	0xCA74: 0x538E,
	0xCA75: 0x538F,
	0xFFFD: 0x5390,
	0xFFFD: 0x5391,
	0xCBD9: 0x5392,
	0x8177: 0x5393,
	0xCBDA: 0x5394,
	0x84DA: 0x5395,
	0xCDF7: 0x5396,
	0xCDF6: 0x5397,
	0xCDF9: 0x5398,
	0xCDF8: 0x5399,
	0xAB70: 0x539A,
	0xFFFD: 0x539B,
	0xD470: 0x539C,
	0xADED: 0x539D,
	0xD0EF: 0x539E,
	0xADEC: 0x539F,
	0x95E8: 0x53A0,
	0xFFFD: 0x53A1,
	0x95E9: 0x53A2,
	0x8FB6: 0x53A3,
	0xD864: 0x53A4,
	0xB3D6: 0x53A5,
	0x957A: 0x53A6,
	0xD865: 0x53A7,
	0x87C5: 0x53A8,
	0x84DB: 0x53A9,
	0xFBD7: 0x53AA,
	0xFBD6: 0x53AB,
	0xE146: 0x53AC,
	0xB9BD: 0x53AD,
	0x87C7: 0x53AE,
	0xFFFD: 0x53AF,
	0x8178: 0x53B0,
	0xFFFD: 0x53B1,
	0xBC46: 0x53B2,
	0x92BA: 0x53B3,
	0xF1EF: 0x53B4,
	0xFFFD: 0x53B5,
	0xC6C9: 0x53B6,
	0xFFFD: 0x53B7,
	0xFFFD: 0x53B8,
	0xC958: 0x53B9,
	0xFFFD: 0x53BA,
	0xA568: 0x53BB,
	0xFFFD: 0x53BC,
	0xFFFD: 0x53BD,
	0xFFFD: 0x53BE,
	0x894F: 0x53BF,
	0xFFFD: 0x53C0,
	0x9548: 0x53C1,
	0x83F2: 0x53C2,
	0xB0D1: 0x53C3,
	0xFFFD: 0x53C4,
	0x98DF: 0x53C5,
	0xFFFD: 0x53C6,
	0xFFFD: 0x53C7,
	0xA453: 0x53C8,
	0xA465: 0x53C9,
	0xA4CE: 0x53CA,
	0xA4CD: 0x53CB,
	0x8B5A: 0x53CC,
	0xA4CF: 0x53CD,
	0x8342: 0x53CE,
	0xFFFD: 0x53CF,
	0x98E0: 0x53D0,
	0x84FA: 0x53D1,
	0x98E1: 0x53D2,
	0xFFFD: 0x53D3,
	0xA8FB: 0x53D4,
	0xFFFD: 0x53D5,
	0xA8FA: 0x53D6,
	0xA8FC: 0x53D7,
	0x8D40: 0x53D8,
	0x95B3: 0x53D9,
	0xFBDB: 0x53DA,
	0xAB71: 0x53DB,
	0xFFFD: 0x53DC,
	0x8179: 0x53DD,
	0xFFFD: 0x53DE,
	0xADEE: 0x53DF,
	0x8CD4: 0x53E0,
	0xE8FB: 0x53E1,
	0xC24F: 0x53E2,
	0xA466: 0x53E3,
	0xA56A: 0x53E4,
	0xA579: 0x53E5,
	0xA574: 0x53E6,
	0xFFFD: 0x53E7,
	0xA56F: 0x53E8,
	0xA56E: 0x53E9,
	0xA575: 0x53EA,
	0xA573: 0x53EB,
	0xA56C: 0x53EC,
	0xA57A: 0x53ED,
	0xA56D: 0x53EE,
	0xA569: 0x53EF,
	0xA578: 0x53F0,
	0xA577: 0x53F1,
	0xA576: 0x53F2,
	0xA56B: 0x53F3,
	0xFFFD: 0x53F4,
	0xA572: 0x53F5,
	0x85FC: 0x53F6,
	0x8641: 0x53F7,
	0xA571: 0x53F8,
	0x86B1: 0x53F9,
	0x9462: 0x53FA,
	0xA57B: 0x53FB,
	0xA570: 0x53FC,
	0x87B4: 0x53FD,
	0x98E2: 0x53FE,
	0xFFFD: 0x53FF,
	0xFFFD: 0x5400,
	0xA653: 0x5401,
	0xFFFD: 0x5402,
	0xA659: 0x5403,
	0xA655: 0x5404,
	0xFFFD: 0x5405,
	0xA65B: 0x5406,
	0xC9C5: 0x5407,
	0xA658: 0x5408,
	0xA64E: 0x5409,
	0xA651: 0x540A,
	0xA654: 0x540B,
	0xA650: 0x540C,
	0xA657: 0x540D,
	0xA65A: 0x540E,
	0xA64F: 0x540F,
	0xA652: 0x5410,
	0xA656: 0x5411,
	0xA65C: 0x5412,
	0x89CC: 0x5413,
	0xFB43: 0x5414,
	0x90B8: 0x5415,
	0xFB42: 0x5416,
	0x85BA: 0x5417,
	0xCA7E: 0x5418,
	0xCA7B: 0x5419,
	0xA055: 0x541A,
	0xA767: 0x541B,
	0xCA7C: 0x541C,
	0xA75B: 0x541D,
	0xA75D: 0x541E,
	0xA775: 0x541F,
	0xA770: 0x5420,
	0x96B2: 0x5421,
	0xFFFD: 0x5422,
	0x817A: 0x5423,
	0xCAA5: 0x5424,
	0xCA7D: 0x5425,
	0xA75F: 0x5426,
	0xA761: 0x5427,
	0xCAA4: 0x5428,
	0xA768: 0x5429,
	0xCA78: 0x542A,
	0xA774: 0x542B,
	0xA776: 0x542C,
	0xA75C: 0x542D,
	0xA76D: 0x542E,
	0x8451: 0x542F,
	0xCA76: 0x5430,
	0xA773: 0x5431,
	0x96B4: 0x5432,
	0xA764: 0x5433,
	0x8345: 0x5434,
	0xA76E: 0x5435,
	0xA76F: 0x5436,
	0xCA77: 0x5437,
	0xA76C: 0x5438,
	0xA76A: 0x5439,
	0xFFFD: 0x543A,
	0xA76B: 0x543B,
	0xA771: 0x543C,
	0xCAA1: 0x543D,
	0xA75E: 0x543E,
	0xFFFD: 0x543F,
	0xA772: 0x5440,
	0xCAA3: 0x5441,
	0xA766: 0x5442,
	0xA763: 0x5443,
	0xFFFD: 0x5444,
	0xCA7A: 0x5445,
	0xA762: 0x5446,
	0xCAA6: 0x5447,
	0xA765: 0x5448,
	0x92BB: 0x5449,
	0xA769: 0x544A,
	0x96A4: 0x544B,
	0xFFFD: 0x544C,
	0xA05A: 0x544D,
	0xA760: 0x544E,
	0xCAA2: 0x544F,
	0x817B: 0x5450,
	0x817C: 0x5451,
	0x8EB2: 0x5452,
	0x8CCA: 0x5453,
	0xCA79: 0x5454,
	0x86B0: 0x5455,
	0x8FB7: 0x5456,
	0x8DC2: 0x5457,
	0x83B0: 0x5458,
	0x8DBC: 0x5459,
	0xFFFD: 0x545A,
	0x85BC: 0x545B,
	0x85BB: 0x545C,
	0xFFFD: 0x545D,
	0xFFFD: 0x545E,
	0x82AF: 0x545F,
	0xCBEB: 0x5460,
	0xCBEA: 0x5461,
	0xA94F: 0x5462,
	0xCBED: 0x5463,
	0xCBEF: 0x5464,
	0xCBE4: 0x5465,
	0xCBE7: 0x5466,
	0xCBEE: 0x5467,
	0xA950: 0x5468,
	0xFBD9: 0x5469,
	0x94FC: 0x546A,
	0xCBE1: 0x546B,
	0xCBE5: 0x546C,
	0x98E3: 0x546D,
	0xFFFD: 0x546E,
	0xCBE9: 0x546F,
	0xCE49: 0x5470,
	0xA94B: 0x5471,
	0xCE4D: 0x5472,
	0xA8FD: 0x5473,
	0xCBE6: 0x5474,
	0xA8FE: 0x5475,
	0xA94C: 0x5476,
	0xA945: 0x5477,
	0xA941: 0x5478,
	0xFFFD: 0x5479,
	0xCBE2: 0x547A,
	0xA944: 0x547B,
	0xA949: 0x547C,
	0xA952: 0x547D,
	0xCBE3: 0x547E,
	0xCBDC: 0x547F,
	0xA943: 0x5480,
	0xCBDD: 0x5481,
	0xCBDF: 0x5482,
	0xFFFD: 0x5483,
	0xA946: 0x5484,
	0x98E4: 0x5485,
	0xA948: 0x5486,
	0xCBDB: 0x5487,
	0xCBE0: 0x5488,
	0xFFFD: 0x5489,
	0x817D: 0x548A,
	0xA951: 0x548B,
	0xA94D: 0x548C,
	0xCBE8: 0x548D,
	0xA953: 0x548E,
	0x95A3: 0x548F,
	0xA94A: 0x5490,
	0xCBDE: 0x5491,
	0xA947: 0x5492,
	0x98E5: 0x5493,
	0x96B6: 0x5494,
	0xA942: 0x5495,
	0xA940: 0x5496,
	0xA057: 0x5497,
	0xCBEC: 0x5498,
	0x8BF0: 0x5499,
	0xA94E: 0x549A,
	0x89CB: 0x549B,
	0xFBDA: 0x549C,
	0x817E: 0x549D,
	0x98E6: 0x549E,
	0xFFFD: 0x549F,
	0xCE48: 0x54A0,
	0xCDFB: 0x54A1,
	0xCE4B: 0x54A2,
	0x81A1: 0x54A3,
	0x9579: 0x54A4,
	0xCDFD: 0x54A5,
	0xAB78: 0x54A6,
	0xABA8: 0x54A7,
	0xAB74: 0x54A8,
	0xABA7: 0x54A9,
	0xAB7D: 0x54AA,
	0xABA4: 0x54AB,
	0xAB72: 0x54AC,
	0xCDFC: 0x54AD,
	0xCE43: 0x54AE,
	0xABA3: 0x54AF,
	0xCE4F: 0x54B0,
	0xABA5: 0x54B1,
	0x9446: 0x54B2,
	0xAB79: 0x54B3,
	0x81A2: 0x54B4,
	0xFFFD: 0x54B5,
	0xCE45: 0x54B6,
	0xCE42: 0x54B7,
	0xAB77: 0x54B8,
	0x98E7: 0x54B9,
	0xCDFA: 0x54BA,
	0xABA6: 0x54BB,
	0xCE4A: 0x54BC,
	0xAB7C: 0x54BD,
	0xCE4C: 0x54BE,
	0xABA9: 0x54BF,
	0xAB73: 0x54C0,
	0xAB7E: 0x54C1,
	0xAB7B: 0x54C2,
	0xCE40: 0x54C3,
	0xABA1: 0x54C4,
	0xCE46: 0x54C5,
	0xCE47: 0x54C6,
	0xAB7A: 0x54C7,
	0xABA2: 0x54C8,
	0xAB76: 0x54C9,
	0xFFFD: 0x54CA,
	0xFB4A: 0x54CB,
	0x96CF: 0x54CC,
	0x8CB7: 0x54CD,
	0xAB75: 0x54CE,
	0xCDFE: 0x54CF,
	0x81A3: 0x54D0,
	0x83F3: 0x54D1,
	0x8EE2: 0x54D2,
	0x8EB1: 0x54D3,
	0x86B4: 0x54D4,
	0x8EE3: 0x54D5,
	0xCE44: 0x54D6,
	0x87B0: 0x54D7,
	0x9463: 0x54D8,
	0x8EE4: 0x54D9,
	0x96B3: 0x54DA,
	0xFFFD: 0x54DB,
	0x8F4F: 0x54DC,
	0x88CE: 0x54DD,
	0xCE4E: 0x54DE,
	0x84CC: 0x54DF,
	0xD144: 0x54E0,
	0xADFB: 0x54E1,
	0xD0F1: 0x54E2,
	0x98E8: 0x54E3,
	0xD0F6: 0x54E4,
	0xADF4: 0x54E5,
	0xAE40: 0x54E6,
	0xD0F4: 0x54E7,
	0xADEF: 0x54E8,
	0xADF9: 0x54E9,
	0xADFE: 0x54EA,
	0xD0FB: 0x54EB,
	0xFFFD: 0x54EC,
	0xADFA: 0x54ED,
	0xADFD: 0x54EE,
	0x98E9: 0x54EF,
	0xFFFD: 0x54F0,
	0xD0FE: 0x54F1,
	0xADF5: 0x54F2,
	0xD0F5: 0x54F3,
	0xFFFD: 0x54F4,
	0xFFFD: 0x54F5,
	0xFFFD: 0x54F6,
	0xD142: 0x54F7,
	0xD143: 0x54F8,
	0xFFFD: 0x54F9,
	0xADF7: 0x54FA,
	0xD141: 0x54FB,
	0xADF3: 0x54FC,
	0xAE43: 0x54FD,
	0xFFFD: 0x54FE,
	0xD0F8: 0x54FF,
	0xFFFD: 0x5500,
	0xADF1: 0x5501,
	0xFB5A: 0x5502,
	0xD146: 0x5503,
	0xD0F9: 0x5504,
	0xD0FD: 0x5505,
	0xADF6: 0x5506,
	0xAE42: 0x5507,
	0xD0FA: 0x5508,
	0xADFC: 0x5509,
	0xD140: 0x550A,
	0xD147: 0x550B,
	0xD4A1: 0x550C,
	0x98EA: 0x550D,
	0xD145: 0x550E,
	0xAE44: 0x550F,
	0xADF0: 0x5510,
	0xD0FC: 0x5511,
	0xD0F3: 0x5512,
	0xFB52: 0x5513,
	0xADF8: 0x5514,
	0xFFFD: 0x5515,
	0x8240: 0x5516,
	0xD0F2: 0x5517,
	0x98EB: 0x5518,
	0xFFFD: 0x5519,
	0xD0F7: 0x551A,
	0x8E66: 0x551B,
	0xFFFD: 0x551C,
	0xFFFD: 0x551D,
	0xFB55: 0x551E,
	0xFFFD: 0x551F,
	0x87AE: 0x5520,
	0xFFFD: 0x5521,
	0x8E41: 0x5522,
	0x81A4: 0x5523,
	0x84CD: 0x5524,
	0x98EC: 0x5525,
	0xD0F0: 0x5526,
	0xAE41: 0x5527,
	0x98ED: 0x5528,
	0xFFFD: 0x5529,
	0xD477: 0x552A,
	0x98EE: 0x552B,
	0xB0E4: 0x552C,
	0xD4A7: 0x552D,
	0xB0E2: 0x552E,
	0xB0DF: 0x552F,
	0xD47C: 0x5530,
	0xB0DB: 0x5531,
	0xD4A2: 0x5532,
	0xB0E6: 0x5533,
	0xD476: 0x5534,
	0xD47B: 0x5535,
	0xD47A: 0x5536,
	0xADF2: 0x5537,
	0xB0E1: 0x5538,
	0xD4A5: 0x5539,
	0xFFFD: 0x553A,
	0xD4A8: 0x553B,
	0xD473: 0x553C,
	0xFFFD: 0x553D,
	0xB3E8: 0x553E,
	0x81A5: 0x553F,
	0xD4A9: 0x5540,
	0xB0E7: 0x5541,
	0xFFFD: 0x5542,
	0xB0D9: 0x5543,
	0xB0D6: 0x5544,
	0xD47E: 0x5545,
	0xB0D3: 0x5546,
	0x98EF: 0x5547,
	0xD4A6: 0x5548,
	0x96B1: 0x5549,
	0xB0DA: 0x554A,
	0xD4AA: 0x554B,
	0x81A6: 0x554C,
	0xD474: 0x554D,
	0xD4A4: 0x554E,
	0xB0DD: 0x554F,
	0xD475: 0x5550,
	0xD478: 0x5551,
	0xD47D: 0x5552,
	0x81A7: 0x5553,
	0xFFFD: 0x5554,
	0xB0DE: 0x5555,
	0xB0DC: 0x5556,
	0xB0E8: 0x5557,
	0xFFFD: 0x5558,
	0xFFFD: 0x5559,
	0xFFFD: 0x555A,
	0xFFFD: 0x555B,
	0xB0E3: 0x555C,
	0x81A8: 0x555D,
	0xB0D7: 0x555E,
	0xB1D2: 0x555F,
	0xFFFD: 0x5560,
	0xB0D8: 0x5561,
	0xD479: 0x5562,
	0xB0E5: 0x5563,
	0xB0E0: 0x5564,
	0xD4A3: 0x5565,
	0xB0D5: 0x5566,
	0x86B3: 0x5567,
	0xFFFD: 0x5568,
	0xFB5B: 0x5569,
	0xB0D4: 0x556A,
	0xA046: 0x556B,
	0x81A9: 0x556C,
	0x8C6E: 0x556D,
	0x8CC7: 0x556E,
	0xFFFD: 0x556F,
	0xFFFD: 0x5570,
	0xA049: 0x5571,
	0xA045: 0x5572,
	0xFBDD: 0x5573,
	0xFFFD: 0x5574,
	0xD471: 0x5575,
	0xD472: 0x5576,
	0xD86A: 0x5577,
	0x87B3: 0x5578,
	0x98F0: 0x5579,
	0xFFFD: 0x557A,
	0xB3D7: 0x557B,
	0xB3DA: 0x557C,
	0xD875: 0x557D,
	0xB3EE: 0x557E,
	0xD878: 0x557F,
	0xB3D8: 0x5580,
	0xD871: 0x5581,
	0xB3DE: 0x5582,
	0xB3E4: 0x5583,
	0xB5BD: 0x5584,
	0xFFFD: 0x5585,
	0x95ED: 0x5586,
	0xB3E2: 0x5587,
	0xD86E: 0x5588,
	0xB3EF: 0x5589,
	0xB3DB: 0x558A,
	0xB3E3: 0x558B,
	0xD876: 0x558C,
	0xDCD7: 0x558D,
	0xD87B: 0x558E,
	0xD86F: 0x558F,
	0x98F1: 0x5590,
	0xD866: 0x5591,
	0xD873: 0x5592,
	0xD86D: 0x5593,
	0xB3E1: 0x5594,
	0xD879: 0x5595,
	0xFFFD: 0x5596,
	0xFFFD: 0x5597,
	0xB3DD: 0x5598,
	0xB3F1: 0x5599,
	0xB3EA: 0x559A,
	0xFFFD: 0x559B,
	0xB3DF: 0x559C,
	0xB3DC: 0x559D,
	0x81AA: 0x559E,
	0xB3E7: 0x559F,
	0xFFFD: 0x55A0,
	0xD87A: 0x55A1,
	0xD86C: 0x55A2,
	0xD872: 0x55A3,
	0xD874: 0x55A4,
	0xD868: 0x55A5,
	0xD877: 0x55A6,
	0xB3D9: 0x55A7,
	0xD867: 0x55A8,
	0x81AB: 0x55A9,
	0xB3E0: 0x55AA,
	0xB3F0: 0x55AB,
	0xB3EC: 0x55AC,
	0xD869: 0x55AD,
	0xB3E6: 0x55AE,
	0xFFFD: 0x55AF,
	0x9442: 0x55B0,
	0xB3ED: 0x55B1,
	0xB3E9: 0x55B2,
	0xB3E5: 0x55B3,
	0x98F2: 0x55B4,
	0xD870: 0x55B5,
	0x9249: 0x55B6,
	0x87B2: 0x55B7,
	0xFFFD: 0x55B8,
	0x96B5: 0x55B9,
	0xA04A: 0x55BA,
	0xB3EB: 0x55BB,
	0xFB4C: 0x55BC,
	0x86B2: 0x55BD,
	0x8FD9: 0x55BE,
	0xDCD5: 0x55BF,
	0xDCD1: 0x55C0,
	0x98F3: 0x55C1,
	0xDCE0: 0x55C2,
	0xDCCA: 0x55C3,
	0xDCD3: 0x55C4,
	0xB6E5: 0x55C5,
	0xB6E6: 0x55C6,
	0xB6DE: 0x55C7,
	0xDCDC: 0x55C8,
	0xB6E8: 0x55C9,
	0xDCCF: 0x55CA,
	0xDCCE: 0x55CB,
	0xDCCC: 0x55CC,
	0xDCDE: 0x55CD,
	0xB6DC: 0x55CE,
	0xDCD8: 0x55CF,
	0xDCCD: 0x55D0,
	0xB6DF: 0x55D1,
	0xDCD6: 0x55D2,
	0xB6DA: 0x55D3,
	0xDCD2: 0x55D4,
	0xDCD9: 0x55D5,
	0xDCDB: 0x55D6,
	0x98F4: 0x55D7,
	0x98F5: 0x55D8,
	0xDCDF: 0x55D9,
	0xB6E3: 0x55DA,
	0xDCCB: 0x55DB,
	0xB6DD: 0x55DC,
	0xDCD0: 0x55DD,
	0xFB56: 0x55DE,
	0xB6D8: 0x55DF,
	0xFFFD: 0x55E0,
	0xB6E4: 0x55E1,
	0xDCDA: 0x55E2,
	0xB6E0: 0x55E3,
	0xB6E1: 0x55E4,
	0xB6E7: 0x55E5,
	0xB6DB: 0x55E6,
	0xA25F: 0x55E7,
	0xB6D9: 0x55E8,
	0xDCD4: 0x55E9,
	0x96C9: 0x55EA,
	0x8C6D: 0x55EB,
	0x81AC: 0x55EC,
	0xFFFD: 0x55ED,
	0xFFFD: 0x55EE,
	0xB6E2: 0x55EF,
	0xA04D: 0x55F0,
	0xA04B: 0x55F1,
	0xDCDD: 0x55F2,
	0x88CF: 0x55F3,
	0xFFFD: 0x55F4,
	0x81AD: 0x55F5,
	0xB9CD: 0x55F6,
	0xB9C8: 0x55F7,
	0xFFFD: 0x55F8,
	0xE155: 0x55F9,
	0xE151: 0x55FA,
	0x98F6: 0x55FB,
	0xE14B: 0x55FC,
	0xB9C2: 0x55FD,
	0xB9BE: 0x55FE,
	0xE154: 0x55FF,
	0xB9BF: 0x5600,
	0xE14E: 0x5601,
	0xE150: 0x5602,
	0xFFFD: 0x5603,
	0xE153: 0x5604,
	0xA04E: 0x5605,
	0xB9C4: 0x5606,
	0xFFFD: 0x5607,
	0xB9CB: 0x5608,
	0xB9C5: 0x5609,
	0xFFFD: 0x560A,
	0xFFFD: 0x560B,
	0xE149: 0x560C,
	0xB9C6: 0x560D,
	0xB9C7: 0x560E,
	0xE14C: 0x560F,
	0xB9CC: 0x5610,
	0xFBE1: 0x5611,
	0xE14A: 0x5612,
	0xE14F: 0x5613,
	0xB9C3: 0x5614,
	0xE148: 0x5615,
	0xB9C9: 0x5616,
	0xB9C1: 0x5617,
	0x82B3: 0x5618,
	0xFFFD: 0x5619,
	0xFFFD: 0x561A,
	0xB9C0: 0x561B,
	0xE14D: 0x561C,
	0xE152: 0x561D,
	0xA052: 0x561E,
	0xB9CA: 0x561F,
	0xFCD9: 0x5620,
	0x98F8: 0x5621,
	0xA04F: 0x5622,
	0x81AE: 0x5623,
	0x8BF1: 0x5624,
	0xFB65: 0x5625,
	0xFFFD: 0x5626,
	0xE147: 0x5627,
	0xFFFD: 0x5628,
	0xBC4D: 0x5629,
	0xE547: 0x562A,
	0xFFFD: 0x562B,
	0xE544: 0x562C,
	0xA050: 0x562D,
	0xBC47: 0x562E,
	0xBC53: 0x562F,
	0xBC54: 0x5630,
	0x8D51: 0x5631,
	0xBC4A: 0x5632,
	0xE542: 0x5633,
	0xBC4C: 0x5634,
	0xE4F9: 0x5635,
	0xBC52: 0x5636,
	0xFE5D: 0x5637,
	0xE546: 0x5638,
	0xBC49: 0x5639,
	0xE548: 0x563A,
	0xBC48: 0x563B,
	0xFFFD: 0x563C,
	0xE543: 0x563D,
	0xE545: 0x563E,
	0xBC4B: 0x563F,
	0xE541: 0x5640,
	0xE4FA: 0x5641,
	0xE4F7: 0x5642,
	0xA051: 0x5643,
	0xFFFD: 0x5644,
	0xD86B: 0x5645,
	0xE4FD: 0x5646,
	0xFFFD: 0x5647,
	0xE4F6: 0x5648,
	0xE4FC: 0x5649,
	0xE4FB: 0x564A,
	0xFFFD: 0x564B,
	0xE4F8: 0x564C,
	0xFBE2: 0x564D,
	0xBC4F: 0x564E,
	0xFB6A: 0x564F,
	0x81AF: 0x5650,
	0xFFFD: 0x5651,
	0x98FA: 0x5652,
	0xBC4E: 0x5653,
	0xFBE4: 0x5654,
	0xFFFD: 0x5655,
	0xFFFD: 0x5656,
	0xBC50: 0x5657,
	0xE4FE: 0x5658,
	0xBEB2: 0x5659,
	0xE540: 0x565A,
	0x824F: 0x565B,
	0x8ABE: 0x565C,
	0x9940: 0x565D,
	0xE945: 0x565E,
	0xFFFD: 0x565F,
	0xE8FD: 0x5660,
	0x9955: 0x5661,
	0xBEBE: 0x5662,
	0xE942: 0x5663,
	0xBEB6: 0x5664,
	0xBEBA: 0x5665,
	0xE941: 0x5666,
	0xFFFD: 0x5667,
	0xBEB9: 0x5668,
	0xBEB5: 0x5669,
	0xBEB8: 0x566A,
	0xBEB3: 0x566B,
	0xBEBD: 0x566C,
	0xE943: 0x566D,
	0xE8FE: 0x566E,
	0xBEBC: 0x566F,
	0xE8FC: 0x5670,
	0xBEBB: 0x5671,
	0xE944: 0x5672,
	0xE940: 0x5673,
	0xBC51: 0x5674,
	0xFFFD: 0x5675,
	0xBEBF: 0x5676,
	0xE946: 0x5677,
	0xBEB7: 0x5678,
	0xBEB4: 0x5679,
	0x9457: 0x567A,
	0x96CA: 0x567B,
	0x81B0: 0x567C,
	0xFFFD: 0x567D,
	0xECC6: 0x567E,
	0xECC8: 0x567F,
	0xC07B: 0x5680,
	0xECC9: 0x5681,
	0xECC7: 0x5682,
	0xECC5: 0x5683,
	0xECC4: 0x5684,
	0xC07D: 0x5685,
	0xECC3: 0x5686,
	0xC07E: 0x5687,
	0xFFFD: 0x5688,
	0x9956: 0x5689,
	0x81B1: 0x568A,
	0x9957: 0x568B,
	0xECC1: 0x568C,
	0xECC2: 0x568D,
	0xC07A: 0x568E,
	0xC0A1: 0x568F,
	0xC07C: 0x5690,
	0xFFFD: 0x5691,
	0xA053: 0x5692,
	0xECC0: 0x5693,
	0x81B2: 0x5694,
	0xC250: 0x5695,
	0xFFFD: 0x5696,
	0xEFBC: 0x5697,
	0xEFBA: 0x5698,
	0xEFBF: 0x5699,
	0xEFBD: 0x569A,
	0xFFFD: 0x569B,
	0xEFBB: 0x569C,
	0xEFBE: 0x569D,
	0x9958: 0x569E,
	0xA05C: 0x569F,
	0x81B3: 0x56A0,
	0x9959: 0x56A1,
	0x8274: 0x56A2,
	0x8C6F: 0x56A3,
	0xA05B: 0x56A4,
	0xC360: 0x56A5,
	0xF1F2: 0x56A6,
	0xF1F3: 0x56A7,
	0xC456: 0x56A8,
	0xFFFD: 0x56A9,
	0xF1F4: 0x56AA,
	0xF1F0: 0x56AB,
	0xF1F5: 0x56AC,
	0xF1F1: 0x56AD,
	0xC251: 0x56AE,
	0x81B4: 0x56AF,
	0xFFFD: 0x56B0,
	0x995A: 0x56B1,
	0xF3FE: 0x56B2,
	0xF441: 0x56B3,
	0xC459: 0x56B4,
	0xF440: 0x56B5,
	0xC458: 0x56B6,
	0xC457: 0x56B7,
	0xFFFD: 0x56B8,
	0x995B: 0x56B9,
	0xFFFD: 0x56BA,
	0xFFFD: 0x56BB,
	0xC45A: 0x56BC,
	0xF5C5: 0x56BD,
	0xF5C6: 0x56BE,
	0x995C: 0x56BF,
	0xC4DA: 0x56C0,
	0xC4D9: 0x56C1,
	0xC4DB: 0x56C2,
	0xF5C4: 0x56C3,
	0xFFFD: 0x56C4,
	0xF6D8: 0x56C5,
	0xF6D7: 0x56C6,
	0xFFFD: 0x56C7,
	0xC56D: 0x56C8,
	0xC56F: 0x56C9,
	0xC56E: 0x56CA,
	0xF6D9: 0x56CB,
	0xC5C8: 0x56CC,
	0xF8A6: 0x56CD,
	0x9464: 0x56CE,
	0xFFFD: 0x56CF,
	0xFFFD: 0x56D0,
	0xC5F1: 0x56D1,
	0xFFFD: 0x56D2,
	0xF8A5: 0x56D3,
	0xF8EE: 0x56D4,
	0xFFFD: 0x56D5,
	0x995D: 0x56D6,
	0xC949: 0x56D7,
	0x81B5: 0x56D8,
	0xFFFD: 0x56D9,
	0xA57D: 0x56DA,
	0xA57C: 0x56DB,
	0xFFFD: 0x56DC,
	0xA65F: 0x56DD,
	0xA65E: 0x56DE,
	0xC9C7: 0x56DF,
	0xA65D: 0x56E0,
	0xC9C6: 0x56E1,
	0x86B5: 0x56E2,
	0x936F: 0x56E3,
	0xA779: 0x56E4,
	0xCAA9: 0x56E5,
	0xFFFD: 0x56E6,
	0xCAA8: 0x56E7,
	0xFFFD: 0x56E8,
	0xFFFD: 0x56E9,
	0xA777: 0x56EA,
	0xA77A: 0x56EB,
	0xFFFD: 0x56EC,
	0x85BD: 0x56ED,
	0xCAA7: 0x56EE,
	0x995E: 0x56EF,
	0xA778: 0x56F0,
	0x8346: 0x56F1,
	0x9243: 0x56F2,
	0x92F6: 0x56F3,
	0x84CF: 0x56F4,
	0x8DCA: 0x56F5,
	0xFFFD: 0x56F6,
	0xCBF0: 0x56F7,
	0xFFFD: 0x56F8,
	0xCBF1: 0x56F9,
	0xA954: 0x56FA,
	0x9D56: 0x56FB,
	0xFFFD: 0x56FC,
	0x83F6: 0x56FD,
	0x86B6: 0x56FE,
	0xABAA: 0x56FF,
	0x81B6: 0x5700,
	0xD148: 0x5701,
	0xD149: 0x5702,
	0xAE45: 0x5703,
	0xAE46: 0x5704,
	0xFFFD: 0x5705,
	0x85BE: 0x5706,
	0xD4AC: 0x5707,
	0xB0E9: 0x5708,
	0xB0EB: 0x5709,
	0xD4AB: 0x570A,
	0xB0EA: 0x570B,
	0xD87C: 0x570C,
	0xB3F2: 0x570D,
	0xFFFD: 0x570E,
	0x92B5: 0x570F,
	0xFFFD: 0x5710,
	0xFFFD: 0x5711,
	0xB6E9: 0x5712,
	0xB6EA: 0x5713,
	0xDCE1: 0x5714,
	0x995F: 0x5715,
	0xB9CF: 0x5716,
	0xFFFD: 0x5717,
	0xB9CE: 0x5718,
	0xFFFD: 0x5719,
	0xE549: 0x571A,
	0xE948: 0x571B,
	0xE947: 0x571C,
	0x9960: 0x571D,
	0xF96B: 0x571E,
	0xA467: 0x571F,
	0xC959: 0x5720,
	0xFFFD: 0x5721,
	0xC96E: 0x5722,
	0xC96F: 0x5723,
	0xFFFD: 0x5724,
	0xFFFD: 0x5725,
	0x9465: 0x5726,
	0x9242: 0x5727,
	0xA662: 0x5728,
	0xA666: 0x5729,
	0xC9C9: 0x572A,
	0xFFFD: 0x572B,
	0xA664: 0x572C,
	0xA663: 0x572D,
	0xC9C8: 0x572E,
	0xA665: 0x572F,
	0xA661: 0x5730,
	0xFFFD: 0x5731,
	0x9961: 0x5732,
	0xA660: 0x5733,
	0xC9CA: 0x5734,
	0xFFFD: 0x5735,
	0xFFFD: 0x5736,
	0x9466: 0x5737,
	0x9467: 0x5738,
	0x8ABF: 0x5739,
	0x84D1: 0x573A,
	0xA7A6: 0x573B,
	0xFFFD: 0x573C,
	0x9962: 0x573D,
	0xA7A3: 0x573E,
	0x9963: 0x573F,
	0xA77D: 0x5740,
	0xCAAA: 0x5741,
	0x95B5: 0x5742,
	0x9964: 0x5743,
	0xFFFD: 0x5744,
	0xCAAB: 0x5745,
	0xFBE7: 0x5746,
	0xA7A1: 0x5747,
	0xFFFD: 0x5748,
	0xCAAD: 0x5749,
	0xA77B: 0x574A,
	0xCAAE: 0x574B,
	0xCAAC: 0x574C,
	0xA77E: 0x574D,
	0xA7A2: 0x574E,
	0xA7A5: 0x574F,
	0xA7A4: 0x5750,
	0xA77C: 0x5751,
	0xCAAF: 0x5752,
	0xFFFD: 0x5753,
	0xFE6F: 0x5754,
	0xFFFD: 0x5755,
	0xFFFD: 0x5756,
	0x85C0: 0x5757,
	0xFFFD: 0x5758,
	0x81B7: 0x5759,
	0x83F7: 0x575A,
	0x88D1: 0x575B,
	0x8B6F: 0x575C,
	0x8D52: 0x575D,
	0x85C1: 0x575E,
	0x87B6: 0x575F,
	0x87B7: 0x5760,
	0xA959: 0x5761,
	0xCBFE: 0x5762,
	0xFFFD: 0x5763,
	0xA95B: 0x5764,
	0x81B8: 0x5765,
	0xA95A: 0x5766,
	0xFBE9: 0x5767,
	0xCC40: 0x5768,
	0xA958: 0x5769,
	0xA957: 0x576A,
	0xCBF5: 0x576B,
	0xFFFD: 0x576C,
	0xCBF4: 0x576D,
	0xFFFD: 0x576E,
	0xCBF2: 0x576F,
	0xCBF7: 0x5770,
	0xCBF6: 0x5771,
	0xCBF3: 0x5772,
	0xCBFC: 0x5773,
	0xCBFD: 0x5774,
	0xCBFA: 0x5775,
	0xCBF8: 0x5776,
	0xA956: 0x5777,
	0xFFFD: 0x5778,
	0xFFFD: 0x5779,
	0xFBE8: 0x577A,
	0xCBFB: 0x577B,
	0xA95C: 0x577C,
	0xCC41: 0x577D,
	0x9966: 0x577E,
	0x81B9: 0x577F,
	0xCBF9: 0x5780,
	0xFFFD: 0x5781,
	0xABAB: 0x5782,
	0xA955: 0x5783,
	0x8B6E: 0x5784,
	0x81BA: 0x5785,
	0x8FB8: 0x5786,
	0xFFFD: 0x5787,
	0x9468: 0x5788,
	0x81BB: 0x5789,
	0x9967: 0x578A,
	0xABAC: 0x578B,
	0xCE54: 0x578C,
	0x9968: 0x578D,
	0xFFFD: 0x578E,
	0xCE5A: 0x578F,
	0x9969: 0x5790,
	0xFFFD: 0x5791,
	0x8AC0: 0x5792,
	0xABB2: 0x5793,
	0xCE58: 0x5794,
	0xCE5E: 0x5795,
	0xFFFD: 0x5796,
	0xCE55: 0x5797,
	0xCE59: 0x5798,
	0xCE5B: 0x5799,
	0xCE5D: 0x579A,
	0xCE57: 0x579B,
	0x996A: 0x579C,
	0xCE56: 0x579D,
	0xCE51: 0x579E,
	0xCE52: 0x579F,
	0xABAD: 0x57A0,
	0x81BC: 0x57A1,
	0xABAF: 0x57A2,
	0xABAE: 0x57A3,
	0xCE53: 0x57A4,
	0xCE5C: 0x57A5,
	0x88D0: 0x57A6,
	0x8DB6: 0x57A7,
	0xFFFD: 0x57A8,
	0x83F8: 0x57A9,
	0x946A: 0x57AA,
	0x86B8: 0x57AB,
	0x81BD: 0x57AC,
	0x8DCB: 0x57AD,
	0xABB1: 0x57AE,
	0xFFFD: 0x57AF,
	0x946B: 0x57B0,
	0xFFFD: 0x57B1,
	0x8E42: 0x57B2,
	0x9469: 0x57B3,
	0x81BE: 0x57B4,
	0xCE50: 0x57B5,
	0xD153: 0x57B6,
	0xFFFD: 0x57B7,
	0xD152: 0x57B8,
	0xD157: 0x57B9,
	0xD14E: 0x57BA,
	0x996B: 0x57BB,
	0xD151: 0x57BC,
	0xD150: 0x57BD,
	0x996C: 0x57BE,
	0xD154: 0x57BF,
	0x81BF: 0x57C0,
	0xD158: 0x57C1,
	0xAE47: 0x57C2,
	0xAE4A: 0x57C3,
	0x996D: 0x57C4,
	0xFFFD: 0x57C5,
	0xD14F: 0x57C6,
	0xD155: 0x57C7,
	0x81C0: 0x57C8,
	0xFFFD: 0x57C9,
	0xFFFD: 0x57CA,
	0xAE49: 0x57CB,
	0xD14A: 0x57CC,
	0xFFFD: 0x57CD,
	0xABB0: 0x57CE,
	0xD4BA: 0x57CF,
	0xD156: 0x57D0,
	0xFFFD: 0x57D1,
	0xD14D: 0x57D2,
	0x81C1: 0x57D3,
	0xAE48: 0x57D4,
	0xD14C: 0x57D5,
	0x946C: 0x57D6,
	0xFE49: 0x57D7,
	0x85C2: 0x57D8,
	0x89CE: 0x57D9,
	0x84D3: 0x57DA,
	0xFFFD: 0x57DB,
	0xD4B1: 0x57DC,
	0xFBEC: 0x57DD,
	0x996E: 0x57DE,
	0xB0EC: 0x57DF,
	0xB0F0: 0x57E0,
	0xD4C1: 0x57E1,
	0xD4AF: 0x57E2,
	0xD4BD: 0x57E3,
	0xB0F1: 0x57E4,
	0xD4BF: 0x57E5,
	0xFBEB: 0x57E6,
	0xD4C5: 0x57E7,
	0xFFFD: 0x57E8,
	0xD4C9: 0x57E9,
	0xFFFD: 0x57EA,
	0xFFFD: 0x57EB,
	0xD4C0: 0x57EC,
	0xD4B4: 0x57ED,
	0xD4BC: 0x57EE,
	0x81C2: 0x57EF,
	0xD4CA: 0x57F0,
	0xD4C8: 0x57F1,
	0xD4BE: 0x57F2,
	0xD4B9: 0x57F3,
	0xD4B2: 0x57F4,
	0xD8A6: 0x57F5,
	0xD4B0: 0x57F6,
	0xB0F5: 0x57F7,
	0xD4B7: 0x57F8,
	0xB0F6: 0x57F9,
	0xB0F2: 0x57FA,
	0xD4AD: 0x57FB,
	0xD4C3: 0x57FC,
	0xD4B5: 0x57FD,
	0x996F: 0x57FE,
	0xFFFD: 0x57FF,
	0xD4B3: 0x5800,
	0xD4C6: 0x5801,
	0xB0F3: 0x5802,
	0x954A: 0x5803,
	0xD4CC: 0x5804,
	0xB0ED: 0x5805,
	0xB0EF: 0x5806,
	0xD4BB: 0x5807,
	0xD4B6: 0x5808,
	0xAE4B: 0x5809,
	0xB0EE: 0x580A,
	0xD4B8: 0x580B,
	0xD4C7: 0x580C,
	0xD4CB: 0x580D,
	0xD4C2: 0x580E,
	0xFFFD: 0x580F,
	0xD4C4: 0x5810,
	0x86B9: 0x5811,
	0x9970: 0x5812,
	0xFFFD: 0x5813,
	0xD4AE: 0x5814,
	0x87B8: 0x5815,
	0xFFFD: 0x5816,
	0xFFFD: 0x5817,
	0xFFFD: 0x5818,
	0xD8A1: 0x5819,
	0xFFFD: 0x581A,
	0xD8AA: 0x581B,
	0xD8A9: 0x581C,
	0xB3FA: 0x581D,
	0xD8A2: 0x581E,
	0xFFFD: 0x581F,
	0xB3FB: 0x5820,
	0xB3F9: 0x5821,
	0x9971: 0x5822,
	0xD8A4: 0x5823,
	0xB3F6: 0x5824,
	0xD8A8: 0x5825,
	0xFBEF: 0x5826,
	0xD8A3: 0x5827,
	0xD8A5: 0x5828,
	0xD87D: 0x5829,
	0xB3F4: 0x582A,
	0xFFFD: 0x582B,
	0xD8B2: 0x582C,
	0xD8B1: 0x582D,
	0xD8AE: 0x582E,
	0xB3F3: 0x582F,
	0xB3F7: 0x5830,
	0xB3F8: 0x5831,
	0xD14B: 0x5832,
	0xD8AB: 0x5833,
	0xB3F5: 0x5834,
	0xB0F4: 0x5835,
	0xD8AD: 0x5836,
	0xD87E: 0x5837,
	0xD8B0: 0x5838,
	0xD8AF: 0x5839,
	0xFBEA: 0x583A,
	0xD8B3: 0x583B,
	0xFFFD: 0x583C,
	0xDCEF: 0x583D,
	0xFFFD: 0x583E,
	0xD8AC: 0x583F,
	0x9459: 0x5840,
	0x93E9: 0x5841,
	0xFFFD: 0x5842,
	0xFFFD: 0x5843,
	0x81C3: 0x5844,
	0xFFFD: 0x5845,
	0xFFFD: 0x5846,
	0x9972: 0x5847,
	0xD8A7: 0x5848,
	0xDCE7: 0x5849,
	0xB6F4: 0x584A,
	0xB6F7: 0x584B,
	0xB6F2: 0x584C,
	0xDCE6: 0x584D,
	0xDCEA: 0x584E,
	0xDCE5: 0x584F,
	0xFFFD: 0x5850,
	0xB6EC: 0x5851,
	0xB6F6: 0x5852,
	0xDCE2: 0x5853,
	0xB6F0: 0x5854,
	0xDCE9: 0x5855,
	0xFFFD: 0x5856,
	0xB6EE: 0x5857,
	0xB6ED: 0x5858,
	0xDCEC: 0x5859,
	0xB6EF: 0x585A,
	0xDCEE: 0x585B,
	0x9973: 0x585C,
	0xDCEB: 0x585D,
	0xB6EB: 0x585E,
	0x9974: 0x585F,
	0xFFFD: 0x5860,
	0xFFFD: 0x5861,
	0xB6F5: 0x5862,
	0xDCF0: 0x5863,
	0xDCE4: 0x5864,
	0xDCED: 0x5865,
	0xFFFD: 0x5866,
	0xFFFD: 0x5867,
	0xDCE3: 0x5868,
	0x95CD: 0x5869,
	0xFFFD: 0x586A,
	0xB6F1: 0x586B,
	0x81C4: 0x586C,
	0xB6F3: 0x586D,
	0xFFFD: 0x586E,
	0xDCE8: 0x586F,
	0x946D: 0x5870,
	0xDCF1: 0x5871,
	0x9562: 0x5872,
	0x9975: 0x5873,
	0xE15D: 0x5874,
	0xB9D0: 0x5875,
	0xE163: 0x5876,
	0xFFFD: 0x5877,
	0xFFFD: 0x5878,
	0xB9D5: 0x5879,
	0xE15F: 0x587A,
	0xE166: 0x587B,
	0xE157: 0x587C,
	0xB9D7: 0x587D,
	0xB9D1: 0x587E,
	0xE15C: 0x587F,
	0xBC55: 0x5880,
	0xE15B: 0x5881,
	0xE164: 0x5882,
	0xB9D2: 0x5883,
	0xFFFD: 0x5884,
	0xB9D6: 0x5885,
	0xE15A: 0x5886,
	0xE160: 0x5887,
	0xE165: 0x5888,
	0xE156: 0x5889,
	0xB9D4: 0x588A,
	0xE15E: 0x588B,
	0xFFFD: 0x588C,
	0xFFFD: 0x588D,
	0xE162: 0x588E,
	0xE168: 0x588F,
	0xE158: 0x5890,
	0xE161: 0x5891,
	0x81C5: 0x5892,
	0xB9D3: 0x5893,
	0xE167: 0x5894,
	0xFFFD: 0x5895,
	0xFFFD: 0x5896,
	0x935E: 0x5897,
	0xE159: 0x5898,
	0x89F5: 0x5899,
	0x81C6: 0x589A,
	0xFFFD: 0x589B,
	0xBC59: 0x589C,
	0xE54B: 0x589D,
	0xBC57: 0x589E,
	0xBC56: 0x589F,
	0xE54D: 0x58A0,
	0xE552: 0x58A1,
	0xFFFD: 0x58A2,
	0xE54E: 0x58A3,
	0xFFFD: 0x58A4,
	0xE551: 0x58A5,
	0xBC5C: 0x58A6,
	0x9976: 0x58A7,
	0xBEA5: 0x58A8,
	0xBC5B: 0x58A9,
	0x9977: 0x58AA,
	0xE54A: 0x58AB,
	0xE550: 0x58AC,
	0xFFFD: 0x58AD,
	0xBC5A: 0x58AE,
	0xE54F: 0x58AF,
	0x9978: 0x58B0,
	0xE54C: 0x58B1,
	0x81C7: 0x58B2,
	0xBC58: 0x58B3,
	0xFFFD: 0x58B4,
	0x9979: 0x58B5,
	0x997A: 0x58B6,
	0xFFFD: 0x58B7,
	0x81C8: 0x58B8,
	0x946E: 0x58B9,
	0xE94D: 0x58BA,
	0xF9D9: 0x58BB,
	0xE94F: 0x58BC,
	0xE94A: 0x58BD,
	0xBEC1: 0x58BE,
	0xE94C: 0x58BF,
	0xFFFD: 0x58C0,
	0xBEC0: 0x58C1,
	0xE94E: 0x58C2,
	0xFFFD: 0x58C3,
	0xFFFD: 0x58C4,
	0xBEC3: 0x58C5,
	0xE950: 0x58C6,
	0xBEC2: 0x58C7,
	0xE949: 0x58C8,
	0xE94B: 0x58C9,
	0x925C: 0x58CA,
	0x997B: 0x58CB,
	0x92EE: 0x58CC,
	0xFFFD: 0x58CD,
	0xC0A5: 0x58CE,
	0xECCC: 0x58CF,
	0x997C: 0x58D0,
	0xC0A4: 0x58D1,
	0xECCD: 0x58D2,
	0xC0A3: 0x58D3,
	0xECCB: 0x58D4,
	0xC0A2: 0x58D5,
	0xECCA: 0x58D6,
	0x946F: 0x58D7,
	0xC253: 0x58D8,
	0xC252: 0x58D9,
	0xF1F6: 0x58DA,
	0xF1F8: 0x58DB,
	0xFBF0: 0x58DC,
	0xF1F7: 0x58DD,
	0xC361: 0x58DE,
	0xC362: 0x58DF,
	0x997D: 0x58E0,
	0xFFFD: 0x58E1,
	0xC363: 0x58E2,
	0xF442: 0x58E3,
	0xC45B: 0x58E4,
	0x81C9: 0x58E5,
	0xFFFD: 0x58E6,
	0xF7D3: 0x58E7,
	0xF7D2: 0x58E8,
	0xC5F2: 0x58E9,
	0xFFFD: 0x58EA,
	0xA468: 0x58EB,
	0xA4D0: 0x58EC,
	0xFFFD: 0x58ED,
	0x8347: 0x58EE,
	0xA7A7: 0x58EF,
	0x8A52: 0x58F0,
	0x9245: 0x58F1,
	0x93B3: 0x58F2,
	0x84EA: 0x58F3,
	0xCE5F: 0x58F4,
	0xFFFD: 0x58F5,
	0x84D4: 0x58F6,
	0x8241: 0x58F7,
	0xFFFD: 0x58F8,
	0xB3FC: 0x58F9,
	0xB3FD: 0x58FA,
	0x81CA: 0x58FB,
	0xDCF2: 0x58FC,
	0xB9D8: 0x58FD,
	0xE169: 0x58FE,
	0xE553: 0x58FF,
	0xFFFD: 0x5900,
	0xFFFD: 0x5901,
	0x81CB: 0x5902,
	0xC95A: 0x5903,
	0x847A: 0x5904,
	0x997E: 0x5905,
	0xCAB0: 0x5906,
	0x84C2: 0x5907,
	0xFFFD: 0x5908,
	0x93C4: 0x5909,
	0xC6CA: 0x590A,
	0x81CC: 0x590B,
	0xCC42: 0x590C,
	0xCE60: 0x590D,
	0xD159: 0x590E,
	0xAE4C: 0x590F,
	0x81CD: 0x5910,
	0x99A1: 0x5911,
	0xF1F9: 0x5912,
	0xFFFD: 0x5913,
	0xC4DC: 0x5914,
	0xA469: 0x5915,
	0xA57E: 0x5916,
	0xC970: 0x5917,
	0x81CE: 0x5918,
	0xA667: 0x5919,
	0xA668: 0x591A,
	0x81CF: 0x591B,
	0xA95D: 0x591C,
	0x9D58: 0x591D,
	0xFFFD: 0x591E,
	0x83FA: 0x591F,
	0xB0F7: 0x5920,
	0xFFFD: 0x5921,
	0xB9DA: 0x5922,
	0xFFFD: 0x5923,
	0xB9DB: 0x5924,
	0xB9D9: 0x5925,
	0xFFFD: 0x5926,
	0xA46A: 0x5927,
	0xFFFD: 0x5928,
	0xA4D1: 0x5929,
	0xA4D3: 0x592A,
	0xA4D2: 0x592B,
	0xC95B: 0x592C,
	0xA4D4: 0x592D,
	0xA5A1: 0x592E,
	0xC971: 0x592F,
	0xFFFD: 0x5930,
	0xA5A2: 0x5931,
	0x82B5: 0x5932,
	0xFFFD: 0x5933,
	0x89B3: 0x5934,
	0xFFFD: 0x5935,
	0xFFFD: 0x5936,
	0xA669: 0x5937,
	0xA66A: 0x5938,
	0x8348: 0x5939,
	0x86BC: 0x593A,
	0xFFFD: 0x593B,
	0xC9CB: 0x593C,
	0xFFFD: 0x593D,
	0xA7A8: 0x593E,
	0xFFFD: 0x593F,
	0xCAB1: 0x5940,
	0x86BD: 0x5941,
	0x836B: 0x5942,
	0xFFFD: 0x5943,
	0xA961: 0x5944,
	0xCC43: 0x5945,
	0xFFFD: 0x5946,
	0xA95F: 0x5947,
	0xA960: 0x5948,
	0xA95E: 0x5949,
	0xD15A: 0x594A,
	0x88D2: 0x594B,
	0xFFFD: 0x594C,
	0xFFFD: 0x594D,
	0xABB6: 0x594E,
	0xABB5: 0x594F,
	0xABB7: 0x5950,
	0xABB4: 0x5951,
	0xFFFD: 0x5952,
	0xCE61: 0x5953,
	0xA962: 0x5954,
	0xABB3: 0x5955,
	0x87F2: 0x5956,
	0xAE4D: 0x5957,
	0xAE4E: 0x5958,
	0xFFFD: 0x5959,
	0xAE4F: 0x595A,
	0x82B6: 0x595B,
	0xD4CD: 0x595C,
	0x82B7: 0x595D,
	0xFFFD: 0x595E,
	0xFFFD: 0x595F,
	0xB3FE: 0x5960,
	0xD8B4: 0x5961,
	0xB0F8: 0x5962,
	0x82B8: 0x5963,
	0xFFFD: 0x5964,
	0x85C4: 0x5965,
	0xFFFD: 0x5966,
	0xB6F8: 0x5967,
	0x92E6: 0x5968,
	0xB9DD: 0x5969,
	0xB9DC: 0x596A,
	0xE16A: 0x596B,
	0x82B9: 0x596C,
	0xBC5D: 0x596D,
	0xBEC4: 0x596E,
	0xFFFD: 0x596F,
	0xEFC0: 0x5970,
	0xF6DA: 0x5971,
	0xF7D4: 0x5972,
	0xA46B: 0x5973,
	0xA5A3: 0x5974,
	0xFE66: 0x5975,
	0xA5A4: 0x5976,
	0xC9D1: 0x5977,
	0xA66C: 0x5978,
	0xA66F: 0x5979,
	0xFFFD: 0x597A,
	0xC9CF: 0x597B,
	0xC9CD: 0x597C,
	0xA66E: 0x597D,
	0xC9D0: 0x597E,
	0xC9D2: 0x597F,
	0xC9CC: 0x5980,
	0xA671: 0x5981,
	0xA670: 0x5982,
	0xA66D: 0x5983,
	0xA66B: 0x5984,
	0xC9CE: 0x5985,
	0x8349: 0x5986,
	0x83FC: 0x5987,
	0x85C5: 0x5988,
	0x99A2: 0x5989,
	0xA7B3: 0x598A,
	0xFFFD: 0x598B,
	0xFFFD: 0x598C,
	0xA7B0: 0x598D,
	0xCAB6: 0x598E,
	0xCAB9: 0x598F,
	0xCAB8: 0x5990,
	0xFFFD: 0x5991,
	0xA7AA: 0x5992,
	0xA7B2: 0x5993,
	0x99A3: 0x5994,
	0xFFFD: 0x5995,
	0xA7AF: 0x5996,
	0xCAB5: 0x5997,
	0xCAB3: 0x5998,
	0xA7AE: 0x5999,
	0x99A4: 0x599A,
	0x82BA: 0x599B,
	0xFFFD: 0x599C,
	0xA7A9: 0x599D,
	0xA7AC: 0x599E,
	0x99A5: 0x599F,
	0xCAB4: 0x59A0,
	0xCABB: 0x59A1,
	0xCAB7: 0x59A2,
	0xA7AD: 0x59A3,
	0xA7B1: 0x59A4,
	0xA7B4: 0x59A5,
	0xCAB2: 0x59A6,
	0xCABA: 0x59A7,
	0xA7AB: 0x59A8,
	0x87BB: 0x59A9,
	0x86BE: 0x59AA,
	0x8DDB: 0x59AB,
	0x95A5: 0x59AC,
	0xFFFD: 0x59AD,
	0xA967: 0x59AE,
	0xA96F: 0x59AF,
	0x99A6: 0x59B0,
	0xCC4F: 0x59B1,
	0xCC48: 0x59B2,
	0xA970: 0x59B3,
	0xCC53: 0x59B4,
	0xCC44: 0x59B5,
	0xCC4B: 0x59B6,
	0xFBF1: 0x59B7,
	0x99A7: 0x59B8,
	0xA966: 0x59B9,
	0xCC45: 0x59BA,
	0xA964: 0x59BB,
	0xCC4C: 0x59BC,
	0xCC50: 0x59BD,
	0xA963: 0x59BE,
	0x9B40: 0x59BF,
	0xCC51: 0x59C0,
	0xCC4A: 0x59C1,
	0xFFFD: 0x59C2,
	0xCC4D: 0x59C3,
	0x99A8: 0x59C4,
	0xA972: 0x59C5,
	0xA969: 0x59C6,
	0xCC54: 0x59C7,
	0xCC52: 0x59C8,
	0x93FC: 0x59C9,
	0xA96E: 0x59CA,
	0xA96C: 0x59CB,
	0xCC49: 0x59CC,
	0xA96B: 0x59CD,
	0xCC47: 0x59CE,
	0xCC46: 0x59CF,
	0xA96A: 0x59D0,
	0xA968: 0x59D1,
	0xA971: 0x59D2,
	0xA96D: 0x59D3,
	0xA965: 0x59D4,
	0xFFFD: 0x59D5,
	0xCC4E: 0x59D6,
	0x82BB: 0x59D7,
	0xABB9: 0x59D8,
	0xFBF2: 0x59D9,
	0xABC0: 0x59DA,
	0xCE6F: 0x59DB,
	0xABB8: 0x59DC,
	0xCE67: 0x59DD,
	0xCE63: 0x59DE,
	0xFFFD: 0x59DF,
	0xCE73: 0x59E0,
	0xCE62: 0x59E1,
	0xFFFD: 0x59E2,
	0xABBB: 0x59E3,
	0xCE6C: 0x59E4,
	0xABBE: 0x59E5,
	0xABC1: 0x59E6,
	0xFFFD: 0x59E7,
	0xABBC: 0x59E8,
	0xCE70: 0x59E9,
	0xABBF: 0x59EA,
	0x82BC: 0x59EB,
	0xAE56: 0x59EC,
	0xCE76: 0x59ED,
	0xCE64: 0x59EE,
	0x99A9: 0x59EF,
	0x99AA: 0x59F0,
	0xCE66: 0x59F1,
	0xCE6D: 0x59F2,
	0xCE71: 0x59F3,
	0xCE75: 0x59F4,
	0xCE72: 0x59F5,
	0xCE6B: 0x59F6,
	0xCE6E: 0x59F7,
	0x99AB: 0x59F8,
	0x95C0: 0x59F9,
	0xCE68: 0x59FA,
	0xABC3: 0x59FB,
	0xCE6A: 0x59FC,
	0xCE69: 0x59FD,
	0xCE74: 0x59FE,
	0xABBA: 0x59FF,
	0xCE65: 0x5A00,
	0xABC2: 0x5A01,
	0x99AC: 0x5A02,
	0xABBD: 0x5A03,
	0x83FB: 0x5A04,
	0x8DCC: 0x5A05,
	0x87BD: 0x5A06,
	0x87BC: 0x5A07,
	0x9055: 0x5A08,
	0xAE5C: 0x5A09,
	0xD162: 0x5A0A,
	0x99AD: 0x5A0B,
	0xAE5B: 0x5A0C,
	0x99AE: 0x5A0D,
	0xFFFD: 0x5A0E,
	0xD160: 0x5A0F,
	0xFFFD: 0x5A10,
	0xAE50: 0x5A11,
	0x99AF: 0x5A12,
	0xAE55: 0x5A13,
	0xFFFD: 0x5A14,
	0xD15F: 0x5A15,
	0xD15C: 0x5A16,
	0xD161: 0x5A17,
	0xAE51: 0x5A18,
	0xD15B: 0x5A19,
	0x82BD: 0x5A1A,
	0xAE54: 0x5A1B,
	0xAE52: 0x5A1C,
	0xFFFD: 0x5A1D,
	0xD163: 0x5A1E,
	0xAE53: 0x5A1F,
	0xAE57: 0x5A20,
	0x99B0: 0x5A21,
	0xFFFD: 0x5A22,
	0xAE58: 0x5A23,
	0x99B1: 0x5A24,
	0xAE5A: 0x5A25,
	0xFFFD: 0x5A26,
	0x99B2: 0x5A27,
	0xFFFD: 0x5A28,
	0xAE59: 0x5A29,
	0x99B3: 0x5A2A,
	0x99B4: 0x5A2B,
	0x99B5: 0x5A2C,
	0xD15D: 0x5A2D,
	0xD15E: 0x5A2E,
	0x92BC: 0x5A2F,
	0xFFFD: 0x5A30,
	0x83B1: 0x5A31,
	0x84D5: 0x5A32,
	0xD164: 0x5A33,
	0x87B9: 0x5A34,
	0xD4D4: 0x5A35,
	0xB0F9: 0x5A36,
	0xD8C2: 0x5A37,
	0xD4D3: 0x5A38,
	0xD4E6: 0x5A39,
	0xFFFD: 0x5A3A,
	0xFFFD: 0x5A3B,
	0xB140: 0x5A3C,
	0x99B6: 0x5A3D,
	0xD4E4: 0x5A3E,
	0xFFFD: 0x5A3F,
	0xB0FE: 0x5A40,
	0xB0FA: 0x5A41,
	0xD4ED: 0x5A42,
	0xD4DD: 0x5A43,
	0xD4E0: 0x5A44,
	0x99B7: 0x5A45,
	0xB143: 0x5A46,
	0xD4EA: 0x5A47,
	0xD4E2: 0x5A48,
	0xB0FB: 0x5A49,
	0xB144: 0x5A4A,
	0xFFFD: 0x5A4B,
	0xD4E7: 0x5A4C,
	0xD4E5: 0x5A4D,
	0xFFFD: 0x5A4E,
	0xFFFD: 0x5A4F,
	0xD4D6: 0x5A50,
	0xD4EB: 0x5A51,
	0xD4DF: 0x5A52,
	0xD4DA: 0x5A53,
	0x99B8: 0x5A54,
	0xD4D0: 0x5A55,
	0xD4EC: 0x5A56,
	0xD4DC: 0x5A57,
	0xD4CF: 0x5A58,
	0x99B9: 0x5A59,
	0xB142: 0x5A5A,
	0xD4E1: 0x5A5B,
	0xD4EE: 0x5A5C,
	0xD4DE: 0x5A5D,
	0xD4D2: 0x5A5E,
	0xD4D7: 0x5A5F,
	0xD4CE: 0x5A60,
	0x99BA: 0x5A61,
	0xB141: 0x5A62,
	0x9563: 0x5A63,
	0xD4DB: 0x5A64,
	0xD4D8: 0x5A65,
	0xB0FC: 0x5A66,
	0xD4D1: 0x5A67,
	0x99BB: 0x5A68,
	0xD4E9: 0x5A69,
	0xB0FD: 0x5A6A,
	0x99BC: 0x5A6B,
	0xD4D9: 0x5A6C,
	0xD4D5: 0x5A6D,
	0x99BD: 0x5A6E,
	0xFFFD: 0x5A6F,
	0xD4E8: 0x5A70,
	0x99BE: 0x5A71,
	0xFFFD: 0x5A72,
	0xFFFD: 0x5A73,
	0x89CF: 0x5A74,
	0x87BA: 0x5A75,
	0x8AC1: 0x5A76,
	0xB440: 0x5A77,
	0xD8BB: 0x5A78,
	0x99BF: 0x5A79,
	0xD8B8: 0x5A7A,
	0xD8C9: 0x5A7B,
	0xD8BD: 0x5A7C,
	0xD8CA: 0x5A7D,
	0x99C0: 0x5A7E,
	0xB442: 0x5A7F,
	0xFFFD: 0x5A80,
	0x99C1: 0x5A81,
	0x99C2: 0x5A82,
	0xD8C6: 0x5A83,
	0xD8C3: 0x5A84,
	0xFFFD: 0x5A85,
	0x99C3: 0x5A86,
	0xFFFD: 0x5A87,
	0x99C4: 0x5A88,
	0xFFFD: 0x5A89,
	0xD8C4: 0x5A8A,
	0xD8C7: 0x5A8B,
	0xD8CB: 0x5A8C,
	0xFFFD: 0x5A8D,
	0xD4E3: 0x5A8E,
	0xD8CD: 0x5A8F,
	0xDD47: 0x5A90,
	0x99C5: 0x5A91,
	0xB443: 0x5A92,
	0xD8CE: 0x5A93,
	0xD8B6: 0x5A94,
	0xD8C0: 0x5A95,
	0xFE78: 0x5A96,
	0xD8C5: 0x5A97,
	0xFFFD: 0x5A98,
	0x99C6: 0x5A99,
	0xB441: 0x5A9A,
	0xB444: 0x5A9B,
	0xD8CC: 0x5A9C,
	0xD8CF: 0x5A9D,
	0xD8BA: 0x5A9E,
	0xD8B7: 0x5A9F,
	0x99C7: 0x5AA0,
	0x99C8: 0x5AA1,
	0xD8B9: 0x5AA2,
	0xFFFD: 0x5AA3,
	0x9C70: 0x5AA4,
	0xD8BE: 0x5AA5,
	0xD8BC: 0x5AA6,
	0xB445: 0x5AA7,
	0xFFFD: 0x5AA8,
	0xD8C8: 0x5AA9,
	0x82BE: 0x5AAA,
	0x99C9: 0x5AAB,
	0xD8BF: 0x5AAC,
	0xFFFD: 0x5AAD,
	0xD8C1: 0x5AAE,
	0xD8B5: 0x5AAF,
	0xDCFA: 0x5AB0,
	0xDCF8: 0x5AB1,
	0xB742: 0x5AB2,
	0xB740: 0x5AB3,
	0xDD43: 0x5AB4,
	0xDCF9: 0x5AB5,
	0xDD44: 0x5AB6,
	0xDD40: 0x5AB7,
	0xDCF7: 0x5AB8,
	0xDD46: 0x5AB9,
	0xDCF6: 0x5ABA,
	0xDCFD: 0x5ABB,
	0xB6FE: 0x5ABC,
	0xB6FD: 0x5ABD,
	0xB6FC: 0x5ABE,
	0xDCFB: 0x5ABF,
	0xDD41: 0x5AC0,
	0xB6F9: 0x5AC1,
	0xB741: 0x5AC2,
	0x99CA: 0x5AC3,
	0xDCF4: 0x5AC4,
	0xFFFD: 0x5AC5,
	0xDCFE: 0x5AC6,
	0xDCF3: 0x5AC7,
	0xDCFC: 0x5AC8,
	0xB6FA: 0x5AC9,
	0xDD42: 0x5ACA,
	0xDCF5: 0x5ACB,
	0xB6FB: 0x5ACC,
	0xDD45: 0x5ACD,
	0x99CB: 0x5ACE,
	0x99CC: 0x5ACF,
	0x82BF: 0x5AD0,
	0x9D67: 0x5AD1,
	0x8EE5: 0x5AD2,
	0x99CD: 0x5AD3,
	0x89D0: 0x5AD4,
	0xE16E: 0x5AD5,
	0xB9E2: 0x5AD6,
	0xB9E1: 0x5AD7,
	0xB9E3: 0x5AD8,
	0xE17A: 0x5AD9,
	0xE170: 0x5ADA,
	0xE176: 0x5ADB,
	0xE16B: 0x5ADC,
	0xE179: 0x5ADD,
	0xE178: 0x5ADE,
	0xE17C: 0x5ADF,
	0xE175: 0x5AE0,
	0xB9DE: 0x5AE1,
	0xE174: 0x5AE2,
	0xB9E4: 0x5AE3,
	0x99CE: 0x5AE4,
	0xE16D: 0x5AE5,
	0xB9DF: 0x5AE6,
	0xFFFD: 0x5AE7,
	0xE17B: 0x5AE8,
	0xB9E0: 0x5AE9,
	0xE16F: 0x5AEA,
	0xE172: 0x5AEB,
	0xE177: 0x5AEC,
	0xE171: 0x5AED,
	0xE16C: 0x5AEE,
	0xFFFD: 0x5AEF,
	0x99CF: 0x5AF0,
	0x82C0: 0x5AF1,
	0xFB67: 0x5AF2,
	0xE173: 0x5AF3,
	0xE555: 0x5AF4,
	0xBC61: 0x5AF5,
	0xE558: 0x5AF6,
	0xE557: 0x5AF7,
	0xE55A: 0x5AF8,
	0xE55C: 0x5AF9,
	0xF9DC: 0x5AFA,
	0xBC5F: 0x5AFB,
	0xFFFD: 0x5AFC,
	0xE556: 0x5AFD,
	0x99D0: 0x5AFE,
	0xE554: 0x5AFF,
	0xFFFD: 0x5B00,
	0xE55D: 0x5B01,
	0xE55B: 0x5B02,
	0xE559: 0x5B03,
	0xFFFD: 0x5B04,
	0xE55F: 0x5B05,
	0xFFFD: 0x5B06,
	0xE55E: 0x5B07,
	0xBC63: 0x5B08,
	0xBC5E: 0x5B09,
	0xFFFD: 0x5B0A,
	0xBC60: 0x5B0B,
	0xBC62: 0x5B0C,
	0x99D1: 0x5B0D,
	0xFFFD: 0x5B0E,
	0xE560: 0x5B0F,
	0xE957: 0x5B10,
	0x99D2: 0x5B11,
	0xFFFD: 0x5B12,
	0xE956: 0x5B13,
	0xE955: 0x5B14,
	0x99D3: 0x5B15,
	0xE958: 0x5B16,
	0xE951: 0x5B17,
	0xFFFD: 0x5B18,
	0xE952: 0x5B19,
	0xE95A: 0x5B1A,
	0xE953: 0x5B1B,
	0xFFFD: 0x5B1C,
	0xBEC5: 0x5B1D,
	0xE95C: 0x5B1E,
	0x99D4: 0x5B1F,
	0xE95B: 0x5B20,
	0xE954: 0x5B21,
	0x92EF: 0x5B22,
	0xECD1: 0x5B23,
	0xC0A8: 0x5B24,
	0xECCF: 0x5B25,
	0xECD4: 0x5B26,
	0xECD3: 0x5B27,
	0xE959: 0x5B28,
	0xFFFD: 0x5B29,
	0xC0A7: 0x5B2A,
	0x99D5: 0x5B2B,
	0xECD2: 0x5B2C,
	0xECCE: 0x5B2D,
	0xECD6: 0x5B2E,
	0xECD5: 0x5B2F,
	0xC0A6: 0x5B30,
	0xFFFD: 0x5B31,
	0xECD0: 0x5B32,
	0xFFFD: 0x5B33,
	0xBEC6: 0x5B34,
	0xFFFD: 0x5B35,
	0x82C1: 0x5B36,
	0x89D1: 0x5B37,
	0xC254: 0x5B38,
	0xFFFD: 0x5B39,
	0xFFFD: 0x5B3A,
	0xFFFD: 0x5B3B,
	0xEFC1: 0x5B3C,
	0xF1FA: 0x5B3D,
	0xF1FB: 0x5B3E,
	0xF1FC: 0x5B3F,
	0xC45C: 0x5B40,
	0x99D6: 0x5B41,
	0xFFFD: 0x5B42,
	0xC45D: 0x5B43,
	0x99D7: 0x5B44,
	0xF443: 0x5B45,
	0x99D8: 0x5B46,
	0xF5C8: 0x5B47,
	0xF5C7: 0x5B48,
	0xFFFD: 0x5B49,
	0x99D9: 0x5B4A,
	0xF6DB: 0x5B4B,
	0xF6DC: 0x5B4C,
	0xF7D5: 0x5B4D,
	0xF8A7: 0x5B4E,
	0x99DA: 0x5B4F,
	0xA46C: 0x5B50,
	0xA46D: 0x5B51,
	0xFFFD: 0x5B52,
	0xA46E: 0x5B53,
	0xA4D5: 0x5B54,
	0xA5A5: 0x5B55,
	0xC9D3: 0x5B56,
	0xA672: 0x5B57,
	0xA673: 0x5B58,
	0x83B2: 0x5B59,
	0xA7B7: 0x5B5A,
	0xA7B8: 0x5B5B,
	0xA7B6: 0x5B5C,
	0xA7B5: 0x5B5D,
	0xFFFD: 0x5B5E,
	0xA973: 0x5B5F,
	0xFFFD: 0x5B60,
	0xFFFD: 0x5B61,
	0xCC55: 0x5B62,
	0xA975: 0x5B63,
	0xA974: 0x5B64,
	0xCC56: 0x5B65,
	0x88D4: 0x5B66,
	0xFFFD: 0x5B67,
	0x99DB: 0x5B68,
	0xABC4: 0x5B69,
	0x8CCB: 0x5B6A,
	0xAE5D: 0x5B6B,
	0xD165: 0x5B6C,
	0xA041: 0x5B6D,
	0xD4F0: 0x5B6E,
	0xFFFD: 0x5B6F,
	0xB145: 0x5B70,
	0xB447: 0x5B71,
	0xD4EF: 0x5B72,
	0xB446: 0x5B73,
	0x99DC: 0x5B74,
	0xB9E5: 0x5B75,
	0x99DD: 0x5B76,
	0xE17D: 0x5B77,
	0xBEC7: 0x5B78,
	0xFFFD: 0x5B79,
	0xC0A9: 0x5B7A,
	0xECD7: 0x5B7B,
	0x99DE: 0x5B7C,
	0xC45E: 0x5B7D,
	0xFFFD: 0x5B7E,
	0xC570: 0x5B7F,
	0xC6CB: 0x5B80,
	0xC972: 0x5B81,
	0x99DF: 0x5B82,
	0xA5A6: 0x5B83,
	0xC973: 0x5B84,
	0xA676: 0x5B85,
	0xFFFD: 0x5B86,
	0xA674: 0x5B87,
	0xA675: 0x5B88,
	0xA677: 0x5B89,
	0xFFFD: 0x5B8A,
	0xA7BA: 0x5B8B,
	0xA7B9: 0x5B8C,
	0x93FD: 0x5B8D,
	0xCABC: 0x5B8E,
	0xA7BB: 0x5B8F,
	0x99E0: 0x5B90,
	0xFFFD: 0x5B91,
	0xCABD: 0x5B92,
	0xCC57: 0x5B93,
	0xFFFD: 0x5B94,
	0xCC58: 0x5B95,
	0x9A40: 0x5B96,
	0xA976: 0x5B97,
	0xA978: 0x5B98,
	0xA97A: 0x5B99,
	0xA977: 0x5B9A,
	0xA97B: 0x5B9B,
	0xA979: 0x5B9C,
	0x8BF3: 0x5B9D,
	0x86BF: 0x5B9E,
	0x92D4: 0x5B9F,
	0x8B70: 0x5BA0,
	0x87BF: 0x5BA1,
	0xABC8: 0x5BA2,
	0xABC5: 0x5BA3,
	0xABC7: 0x5BA4,
	0xABC9: 0x5BA5,
	0xABC6: 0x5BA6,
	0xD166: 0x5BA7,
	0xCE77: 0x5BA8,
	0xFFFD: 0x5BA9,
	0x88D6: 0x5BAA,
	0x90B3: 0x5BAB,
	0xD168: 0x5BAC,
	0xD167: 0x5BAD,
	0xAE63: 0x5BAE,
	0xFFFD: 0x5BAF,
	0xAE5F: 0x5BB0,
	0xFFFD: 0x5BB1,
	0xFFFD: 0x5BB2,
	0xAE60: 0x5BB3,
	0xAE62: 0x5BB4,
	0xAE64: 0x5BB5,
	0xAE61: 0x5BB6,
	0x9D68: 0x5BB7,
	0xAE66: 0x5BB8,
	0xAE65: 0x5BB9,
	0xFFFD: 0x5BBA,
	0xFFFD: 0x5BBB,
	0xFFFD: 0x5BBC,
	0x87BE: 0x5BBD,
	0x8759: 0x5BBE,
	0xB14A: 0x5BBF,
	0xD4F2: 0x5BC0,
	0xD4F1: 0x5BC1,
	0xB149: 0x5BC2,
	0xFC43: 0x5BC3,
	0xB148: 0x5BC4,
	0xB147: 0x5BC5,
	0xB14B: 0x5BC6,
	0xB146: 0x5BC7,
	0xFFFD: 0x5BC8,
	0x82C2: 0x5BC9,
	0xD8D5: 0x5BCA,
	0xD8D2: 0x5BCB,
	0xB449: 0x5BCC,
	0xD8D1: 0x5BCD,
	0xD8D6: 0x5BCE,
	0xFFFD: 0x5BCF,
	0xB44B: 0x5BD0,
	0xD8D4: 0x5BD1,
	0xB448: 0x5BD2,
	0xB44A: 0x5BD3,
	0xD8D3: 0x5BD4,
	0x9A55: 0x5BD5,
	0xDD48: 0x5BD6,
	0x9A56: 0x5BD7,
	0xDD49: 0x5BD8,
	0xDD4A: 0x5BD9,
	0xFFFD: 0x5BDA,
	0x9269: 0x5BDB,
	0xFFFD: 0x5BDC,
	0x86C0: 0x5BDD,
	0xB9E6: 0x5BDE,
	0xB9EE: 0x5BDF,
	0xE17E: 0x5BE0,
	0xB9E8: 0x5BE1,
	0xB9EC: 0x5BE2,
	0xE1A1: 0x5BE3,
	0xB9ED: 0x5BE4,
	0xB9E9: 0x5BE5,
	0xB9EA: 0x5BE6,
	0xB9E7: 0x5BE7,
	0xB9EB: 0x5BE8,
	0xBC66: 0x5BE9,
	0xD8D0: 0x5BEA,
	0xBC67: 0x5BEB,
	0xBC65: 0x5BEC,
	0xFFFD: 0x5BED,
	0xBC64: 0x5BEE,
	0xE95D: 0x5BEF,
	0xBEC8: 0x5BF0,
	0xECD8: 0x5BF1,
	0xECD9: 0x5BF2,
	0x82C3: 0x5BF3,
	0xFFFD: 0x5BF4,
	0xC364: 0x5BF5,
	0xC45F: 0x5BF6,
	0xFFFD: 0x5BF7,
	0xA46F: 0x5BF8,
	0x86C1: 0x5BF9,
	0xA678: 0x5BFA,
	0x84D6: 0x5BFB,
	0x88D5: 0x5BFC,
	0xFFFD: 0x5BFD,
	0x9366: 0x5BFE,
	0x86BA: 0x5BFF,
	0xFFFD: 0x5C00,
	0xABCA: 0x5C01,
	0x9347: 0x5C02,
	0xD169: 0x5C03,
	0xAE67: 0x5C04,
	0x955B: 0x5C05,
	0x92E2: 0x5C06,
	0xB14E: 0x5C07,
	0xB14D: 0x5C08,
	0xB14C: 0x5C09,
	0xB44C: 0x5C0A,
	0xB44D: 0x5C0B,
	0xD8D7: 0x5C0C,
	0xB9EF: 0x5C0D,
	0xBEC9: 0x5C0E,
	0xA470: 0x5C0F,
	0xC95C: 0x5C10,
	0xA4D6: 0x5C11,
	0xC974: 0x5C12,
	0x82C4: 0x5C13,
	0x86E0: 0x5C14,
	0xC9D4: 0x5C15,
	0xA679: 0x5C16,
	0xFFFD: 0x5C17,
	0x86B7: 0x5C18,
	0xFFFD: 0x5C19,
	0xA97C: 0x5C1A,
	0xFFFD: 0x5C1B,
	0x82C5: 0x5C1C,
	0x86AF: 0x5C1D,
	0x82C6: 0x5C1E,
	0xDD4B: 0x5C1F,
	0xFBF3: 0x5C20,
	0xFFFD: 0x5C21,
	0xA471: 0x5C22,
	0x9A57: 0x5C23,
	0xA4D7: 0x5C24,
	0xC9D5: 0x5C25,
	0xFFFD: 0x5C26,
	0x84D0: 0x5C27,
	0xCABE: 0x5C28,
	0xFFFD: 0x5C29,
	0xCABF: 0x5C2A,
	0xFFFD: 0x5C2B,
	0xA7BC: 0x5C2C,
	0x8259: 0x5C2D,
	0xFFFD: 0x5C2E,
	0xFFFD: 0x5C2F,
	0xD8D8: 0x5C30,
	0xB44E: 0x5C31,
	0xFFFD: 0x5C32,
	0xDD4C: 0x5C33,
	0x89D2: 0x5C34,
	0xFFFD: 0x5C35,
	0xFFFD: 0x5C36,
	0xC0AA: 0x5C37,
	0xA472: 0x5C38,
	0xA4A8: 0x5C39,
	0xA4D8: 0x5C3A,
	0xC975: 0x5C3B,
	0xA5A7: 0x5C3C,
	0x86E9: 0x5C3D,
	0xA7C0: 0x5C3E,
	0xA7BF: 0x5C3F,
	0xA7BD: 0x5C40,
	0xA7BE: 0x5C41,
	0x87C1: 0x5C42,
	0xFFFD: 0x5C43,
	0xCC59: 0x5C44,
	0xA97E: 0x5C45,
	0xA9A1: 0x5C46,
	0xCC5A: 0x5C47,
	0xA97D: 0x5C48,
	0x8440: 0x5C49,
	0x8357: 0x5C4A,
	0xABCE: 0x5C4B,
	0xCE78: 0x5C4C,
	0xABCD: 0x5C4D,
	0xABCB: 0x5C4E,
	0xABCC: 0x5C4F,
	0xAE6A: 0x5C50,
	0xAE68: 0x5C51,
	0xFFFD: 0x5C52,
	0x82C7: 0x5C53,
	0xD16B: 0x5C54,
	0xAE69: 0x5C55,
	0xD16A: 0x5C56,
	0xFFFD: 0x5C57,
	0xAE5E: 0x5C58,
	0xD4F3: 0x5C59,
	0xFFFD: 0x5C5A,
	0xFFFD: 0x5C5B,
	0xB150: 0x5C5C,
	0xB151: 0x5C5D,
	0x8C70: 0x5C5E,
	0xFFFD: 0x5C5F,
	0xB14F: 0x5C60,
	0x86C2: 0x5C61,
	0xB9F0: 0x5C62,
	0xE1A2: 0x5C63,
	0xBC68: 0x5C64,
	0xBC69: 0x5C65,
	0x89D3: 0x5C66,
	0xE561: 0x5C67,
	0xC0AB: 0x5C68,
	0xEFC2: 0x5C69,
	0xEFC3: 0x5C6A,
	0xFFFD: 0x5C6B,
	0xC4DD: 0x5C6C,
	0xF8A8: 0x5C6D,
	0xC94B: 0x5C6E,
	0xA4D9: 0x5C6F,
	0xFFFD: 0x5C70,
	0xA473: 0x5C71,
	0xFFFD: 0x5C72,
	0xC977: 0x5C73,
	0xC976: 0x5C74,
	0xFFFD: 0x5C75,
	0x9470: 0x5C76,
	0xFFFD: 0x5C77,
	0x9D64: 0x5C78,
	0xA67A: 0x5C79,
	0xC9D7: 0x5C7A,
	0xC9D8: 0x5C7B,
	0xC9D6: 0x5C7C,
	0xFFFD: 0x5C7D,
	0xC9D9: 0x5C7E,
	0x89D4: 0x5C7F,
	0xFFFD: 0x5C80,
	0x85D7: 0x5C81,
	0x83DB: 0x5C82,
	0xFFFD: 0x5C83,
	0xFFFD: 0x5C84,
	0x9A58: 0x5C85,
	0xCAC7: 0x5C86,
	0xFFFD: 0x5C87,
	0xCAC2: 0x5C88,
	0xCAC4: 0x5C89,
	0xCAC6: 0x5C8A,
	0xCAC3: 0x5C8B,
	0xA7C4: 0x5C8C,
	0xCAC0: 0x5C8D,
	0xFFFD: 0x5C8E,
	0xCAC1: 0x5C8F,
	0xA7C1: 0x5C90,
	0xA7C2: 0x5C91,
	0xCAC5: 0x5C92,
	0xCAC8: 0x5C93,
	0xA7C3: 0x5C94,
	0xCAC9: 0x5C95,
	0x86C4: 0x5C96,
	0x8442: 0x5C97,
	0x83B5: 0x5C98,
	0x82C8: 0x5C99,
	0x84D7: 0x5C9A,
	0x83B4: 0x5C9B,
	0x82C9: 0x5C9C,
	0xCC68: 0x5C9D,
	0x9A59: 0x5C9E,
	0xCC62: 0x5C9F,
	0xCC5D: 0x5CA0,
	0xA9A3: 0x5CA1,
	0xCC65: 0x5CA2,
	0xCC63: 0x5CA3,
	0xCC5C: 0x5CA4,
	0xCC69: 0x5CA5,
	0xCC6C: 0x5CA6,
	0xCC67: 0x5CA7,
	0xCC60: 0x5CA8,
	0xA9A5: 0x5CA9,
	0xCC66: 0x5CAA,
	0xA9A6: 0x5CAB,
	0xCC61: 0x5CAC,
	0xCC64: 0x5CAD,
	0xCC5B: 0x5CAE,
	0xCC5F: 0x5CAF,
	0xCC6B: 0x5CB0,
	0xA9A7: 0x5CB1,
	0xFFFD: 0x5CB2,
	0xA9A8: 0x5CB3,
	0xFFFD: 0x5CB4,
	0xCC5E: 0x5CB5,
	0xCC6A: 0x5CB6,
	0xA9A2: 0x5CB7,
	0xA9A4: 0x5CB8,
	0xFFFD: 0x5CB9,
	0x82CA: 0x5CBA,
	0x82CB: 0x5CBB,
	0x9471: 0x5CBC,
	0x8DCD: 0x5CBD,
	0x9473: 0x5CBE,
	0x8FFC: 0x5CBF,
	0xFFFD: 0x5CC0,
	0x82CC: 0x5CC1,
	0x9A5A: 0x5CC2,
	0xFFFD: 0x5CC3,
	0x8EE6: 0x5CC4,
	0x9472: 0x5CC5,
	0xCEAB: 0x5CC6,
	0xCEA4: 0x5CC7,
	0xCEAA: 0x5CC8,
	0xCEA3: 0x5CC9,
	0xCEA5: 0x5CCA,
	0xCE7D: 0x5CCB,
	0xCE7B: 0x5CCC,
	0xFFFD: 0x5CCD,
	0xCEAC: 0x5CCE,
	0xCEA9: 0x5CCF,
	0xCE79: 0x5CD0,
	0xFBF5: 0x5CD1,
	0xABD0: 0x5CD2,
	0xCEA7: 0x5CD3,
	0xCEA8: 0x5CD4,
	0x9D71: 0x5CD5,
	0xCEA6: 0x5CD6,
	0xCE7C: 0x5CD7,
	0xCE7A: 0x5CD8,
	0xABCF: 0x5CD9,
	0xCEA2: 0x5CDA,
	0xCE7E: 0x5CDB,
	0xFFFD: 0x5CDC,
	0xFFFD: 0x5CDD,
	0xCEA1: 0x5CDE,
	0xCEAD: 0x5CDF,
	0x9450: 0x5CE0,
	0x83B3: 0x5CE1,
	0xFFFD: 0x5CE2,
	0xFFFD: 0x5CE3,
	0x8EB4: 0x5CE4,
	0x8441: 0x5CE5,
	0x8CCD: 0x5CE6,
	0xFFFD: 0x5CE7,
	0xAE6F: 0x5CE8,
	0xFBF6: 0x5CE9,
	0xAE6E: 0x5CEA,
	0xFFFD: 0x5CEB,
	0xD16C: 0x5CEC,
	0xAE6B: 0x5CED,
	0xD16E: 0x5CEE,
	0x955D: 0x5CEF,
	0xAE70: 0x5CF0,
	0xD16F: 0x5CF1,
	0xFFFD: 0x5CF2,
	0xFFFD: 0x5CF3,
	0xAE73: 0x5CF4,
	0x82CD: 0x5CF5,
	0xAE71: 0x5CF6,
	0xD170: 0x5CF7,
	0xCEAE: 0x5CF8,
	0xD172: 0x5CF9,
	0x82CE: 0x5CFA,
	0xAE6D: 0x5CFB,
	0x9D69: 0x5CFC,
	0xAE6C: 0x5CFD,
	0xFFFD: 0x5CFE,
	0xD16D: 0x5CFF,
	0xD171: 0x5D00,
	0xAE72: 0x5D01,
	0x8EB3: 0x5D02,
	0x8DCE: 0x5D03,
	0xFFFD: 0x5D04,
	0xFFFD: 0x5D05,
	0xB153: 0x5D06,
	0xB152: 0x5D07,
	0xFFFD: 0x5D08,
	0xFFFD: 0x5D09,
	0xFFFD: 0x5D0A,
	0xD4F5: 0x5D0B,
	0xD4F9: 0x5D0C,
	0xD4FB: 0x5D0D,
	0xB154: 0x5D0E,
	0xD4FE: 0x5D0F,
	0x9A5B: 0x5D10,
	0xB158: 0x5D11,
	0xD541: 0x5D12,
	0xFFFD: 0x5D13,
	0xB15A: 0x5D14,
	0x82CF: 0x5D15,
	0xB156: 0x5D16,
	0xB15E: 0x5D17,
	0x82D0: 0x5D18,
	0xB15B: 0x5D19,
	0xD4F7: 0x5D1A,
	0xB155: 0x5D1B,
	0xFFFD: 0x5D1C,
	0xD4F6: 0x5D1D,
	0xD4F4: 0x5D1E,
	0xD543: 0x5D1F,
	0xD4F8: 0x5D20,
	0xFFFD: 0x5D21,
	0xB157: 0x5D22,
	0xD542: 0x5D23,
	0xB15C: 0x5D24,
	0xD4FD: 0x5D25,
	0xD4FC: 0x5D26,
	0xB15D: 0x5D27,
	0xD4FA: 0x5D28,
	0xB159: 0x5D29,
	0xFFFD: 0x5D2A,
	0xFFFD: 0x5D2B,
	0x9A5C: 0x5D2C,
	0x86C3: 0x5D2D,
	0xD544: 0x5D2E,
	0x9A5D: 0x5D2F,
	0xD540: 0x5D30,
	0xD8E7: 0x5D31,
	0xD8EE: 0x5D32,
	0xD8E3: 0x5D33,
	0xB451: 0x5D34,
	0xD8DF: 0x5D35,
	0xD8EF: 0x5D36,
	0xD8D9: 0x5D37,
	0xD8EC: 0x5D38,
	0xD8EA: 0x5D39,
	0xD8E4: 0x5D3A,
	0xFFFD: 0x5D3B,
	0xD8ED: 0x5D3C,
	0xD8E6: 0x5D3D,
	0x82D1: 0x5D3E,
	0xD8DE: 0x5D3F,
	0xD8F0: 0x5D40,
	0xD8DC: 0x5D41,
	0xD8E9: 0x5D42,
	0xD8DA: 0x5D43,
	0xFFFD: 0x5D44,
	0xD8F1: 0x5D45,
	0xFBF7: 0x5D46,
	0xB452: 0x5D47,
	0x9A5E: 0x5D48,
	0xD8EB: 0x5D49,
	0xDD4F: 0x5D4A,
	0xD8DD: 0x5D4B,
	0xB44F: 0x5D4C,
	0xFFFD: 0x5D4D,
	0xD8E1: 0x5D4E,
	0xFFFD: 0x5D4F,
	0xB450: 0x5D50,
	0xD8E0: 0x5D51,
	0xD8E5: 0x5D52,
	0x82D2: 0x5D53,
	0xFFFD: 0x5D54,
	0xD8E2: 0x5D55,
	0x9A5F: 0x5D56,
	0x9565: 0x5D57,
	0x89D5: 0x5D58,
	0xD8E8: 0x5D59,
	0xFFFD: 0x5D5A,
	0x8DDC: 0x5D5B,
	0x82D3: 0x5D5C,
	0x8E67: 0x5D5D,
	0xDD53: 0x5D5E,
	0xFFFD: 0x5D5F,
	0xFFFD: 0x5D60,
	0xFFFD: 0x5D61,
	0xDD56: 0x5D62,
	0xDD4E: 0x5D63,
	0xFFFD: 0x5D64,
	0xDD50: 0x5D65,
	0xFFFD: 0x5D66,
	0xDD55: 0x5D67,
	0xDD54: 0x5D68,
	0xB743: 0x5D69,
	0xFFFD: 0x5D6A,
	0xD8DB: 0x5D6B,
	0xDD52: 0x5D6C,
	0x82D4: 0x5D6D,
	0xFFFD: 0x5D6E,
	0xB744: 0x5D6F,
	0x9A60: 0x5D70,
	0xDD4D: 0x5D71,
	0xDD51: 0x5D72,
	0x82D5: 0x5D73,
	0x82D6: 0x5D74,
	0xFE7E: 0x5D75,
	0x9474: 0x5D76,
	0xE1A9: 0x5D77,
	0x9D7A: 0x5D78,
	0xE1B0: 0x5D79,
	0xE1A7: 0x5D7A,
	0x9A61: 0x5D7B,
	0xE1AE: 0x5D7C,
	0xE1A5: 0x5D7D,
	0xE1AD: 0x5D7E,
	0xE1B1: 0x5D7F,
	0xE1A4: 0x5D80,
	0xE1A8: 0x5D81,
	0xE1A3: 0x5D82,
	0xFFFD: 0x5D83,
	0xB9F1: 0x5D84,
	0x9A62: 0x5D85,
	0xE1A6: 0x5D86,
	0xB9F2: 0x5D87,
	0xE1AC: 0x5D88,
	0xE1AB: 0x5D89,
	0xE1AA: 0x5D8A,
	0x93FE: 0x5D8B,
	0x82D7: 0x5D8C,
	0xE1AF: 0x5D8D,
	0xFBF8: 0x5D8E,
	0xFFFD: 0x5D8F,
	0x82D8: 0x5D90,
	0xFFFD: 0x5D91,
	0xE565: 0x5D92,
	0xE567: 0x5D93,
	0xBC6B: 0x5D94,
	0xE568: 0x5D95,
	0xFFFD: 0x5D96,
	0xE563: 0x5D97,
	0xFFFD: 0x5D98,
	0xE562: 0x5D99,
	0xE56C: 0x5D9A,
	0xFFFD: 0x5D9B,
	0xE56A: 0x5D9C,
	0xBC6A: 0x5D9D,
	0xE56D: 0x5D9E,
	0xE564: 0x5D9F,
	0xE569: 0x5DA0,
	0xE56B: 0x5DA1,
	0xE566: 0x5DA2,
	0xFFFD: 0x5DA3,
	0x9A63: 0x5DA4,
	0xFFFD: 0x5DA5,
	0xFFFD: 0x5DA6,
	0xE961: 0x5DA7,
	0xE966: 0x5DA8,
	0xE960: 0x5DA9,
	0xE965: 0x5DAA,
	0x9A64: 0x5DAB,
	0xE95E: 0x5DAC,
	0xE968: 0x5DAD,
	0xE964: 0x5DAE,
	0xE969: 0x5DAF,
	0xE963: 0x5DB0,
	0xE95F: 0x5DB1,
	0xE967: 0x5DB2,
	0xFFFD: 0x5DB3,
	0xE96A: 0x5DB4,
	0xE962: 0x5DB5,
	0x9A65: 0x5DB6,
	0xECDA: 0x5DB7,
	0xC0AF: 0x5DB8,
	0x82D9: 0x5DB9,
	0xC0AD: 0x5DBA,
	0xFFFD: 0x5DBB,
	0xC0AC: 0x5DBC,
	0xC0AE: 0x5DBD,
	0xFFFD: 0x5DBE,
	0xFFFD: 0x5DBF,
	0xEFC4: 0x5DC0,
	0x9A66: 0x5DC1,
	0xF172: 0x5DC2,
	0xF1FD: 0x5DC3,
	0xFFFD: 0x5DC4,
	0x8CCC: 0x5DC5,
	0xF444: 0x5DC6,
	0xF445: 0x5DC7,
	0xFFFD: 0x5DC8,
	0xC460: 0x5DC9,
	0xFFFD: 0x5DCA,
	0xF5C9: 0x5DCB,
	0x8253: 0x5DCC,
	0xC4DE: 0x5DCD,
	0xFFFD: 0x5DCE,
	0xF5CA: 0x5DCF,
	0x82DA: 0x5DD0,
	0xF6DE: 0x5DD1,
	0xC572: 0x5DD2,
	0x82DB: 0x5DD3,
	0xC571: 0x5DD4,
	0xF6DD: 0x5DD5,
	0xC5C9: 0x5DD6,
	0x9A67: 0x5DD7,
	0xF7D6: 0x5DD8,
	0xFFFD: 0x5DD9,
	0xFFFD: 0x5DDA,
	0xC6CC: 0x5DDB,
	0xFFFD: 0x5DDC,
	0xA474: 0x5DDD,
	0xA67B: 0x5DDE,
	0xC9DA: 0x5DDF,
	0xCACA: 0x5DE0,
	0xA8B5: 0x5DE1,
	0xB15F: 0x5DE2,
	0x9357: 0x5DE3,
	0xFFFD: 0x5DE4,
	0xA475: 0x5DE5,
	0xA5AA: 0x5DE6,
	0xA5A9: 0x5DE7,
	0xA5A8: 0x5DE8,
	0x88B2: 0x5DE9,
	0xFFFD: 0x5DEA,
	0xA7C5: 0x5DEB,
	0xFFFD: 0x5DEC,
	0xFFFD: 0x5DED,
	0xAE74: 0x5DEE,
	0x8E43: 0x5DEF,
	0xDD57: 0x5DF0,
	0xA476: 0x5DF1,
	0xA477: 0x5DF2,
	0xA478: 0x5DF3,
	0xA4DA: 0x5DF4,
	0xFBFA: 0x5DF5,
	0xFFFD: 0x5DF6,
	0xABD1: 0x5DF7,
	0xFFFD: 0x5DF8,
	0xCEAF: 0x5DF9,
	0xFFFD: 0x5DFA,
	0x9266: 0x5DFB,
	0xFFFD: 0x5DFC,
	0xB453: 0x5DFD,
	0xA479: 0x5DFE,
	0xC95D: 0x5DFF,
	0xFFFD: 0x5E00,
	0x86C5: 0x5E01,
	0xA5AB: 0x5E02,
	0xA5AC: 0x5E03,
	0xC978: 0x5E04,
	0x836C: 0x5E05,
	0xA67C: 0x5E06,
	0xFFFD: 0x5E07,
	0x83B6: 0x5E08,
	0x9A68: 0x5E09,
	0xCACB: 0x5E0A,
	0xFBFB: 0x5E0B,
	0xA7C6: 0x5E0C,
	0xFFFD: 0x5E0D,
	0xCACC: 0x5E0E,
	0x84D9: 0x5E0F,
	0x8444: 0x5E10,
	0xA9AE: 0x5E11,
	0xFBFC: 0x5E12,
	0xFFFD: 0x5E13,
	0xCC6E: 0x5E14,
	0xA9AC: 0x5E15,
	0xA9AB: 0x5E16,
	0xCC6D: 0x5E17,
	0xA9A9: 0x5E18,
	0xCC6F: 0x5E19,
	0xA9AA: 0x5E1A,
	0xA9AD: 0x5E1B,
	0x87C3: 0x5E1C,
	0xABD2: 0x5E1D,
	0xFFFD: 0x5E1E,
	0xABD4: 0x5E1F,
	0xCEB3: 0x5E20,
	0xCEB0: 0x5E21,
	0xCEB1: 0x5E22,
	0xCEB2: 0x5E23,
	0xCEB4: 0x5E24,
	0xABD3: 0x5E25,
	0x8443: 0x5E26,
	0x84D8: 0x5E27,
	0xD174: 0x5E28,
	0xD173: 0x5E29,
	0xFFFD: 0x5E2A,
	0xAE76: 0x5E2B,
	0xFFFD: 0x5E2C,
	0xAE75: 0x5E2D,
	0x89D6: 0x5E2E,
	0x9367: 0x5E2F,
	0x926F: 0x5E30,
	0x8F50: 0x5E31,
	0xFFFD: 0x5E32,
	0xB162: 0x5E33,
	0xD546: 0x5E34,
	0xFFFD: 0x5E35,
	0xB161: 0x5E36,
	0xB163: 0x5E37,
	0xB160: 0x5E38,
	0xFFFD: 0x5E39,
	0xFFFD: 0x5E3A,
	0x8E68: 0x5E3B,
	0x86C6: 0x5E3C,
	0xB455: 0x5E3D,
	0xD545: 0x5E3E,
	0xFFFD: 0x5E3F,
	0xB456: 0x5E40,
	0xD8F3: 0x5E41,
	0x88CB: 0x5E42,
	0xB457: 0x5E43,
	0xD8F2: 0x5E44,
	0xB454: 0x5E45,
	0xFFFD: 0x5E46,
	0x82DC: 0x5E47,
	0x9A69: 0x5E48,
	0xFFFD: 0x5E49,
	0xDD5A: 0x5E4A,
	0xDD5C: 0x5E4B,
	0xB745: 0x5E4C,
	0xDD5B: 0x5E4D,
	0xDD59: 0x5E4E,
	0xDD58: 0x5E4F,
	0xFFFD: 0x5E50,
	0xFFFD: 0x5E51,
	0xFFFD: 0x5E52,
	0xE1B4: 0x5E53,
	0xB9F7: 0x5E54,
	0xB9F5: 0x5E55,
	0xFFFD: 0x5E56,
	0xB9F6: 0x5E57,
	0xE1B2: 0x5E58,
	0xE1B3: 0x5E59,
	0xFFFD: 0x5E5A,
	0xB9F3: 0x5E5B,
	0xE571: 0x5E5C,
	0xE56F: 0x5E5D,
	0xFBFE: 0x5E5E,
	0xBC6D: 0x5E5F,
	0xE570: 0x5E60,
	0xBC6E: 0x5E61,
	0xBC6C: 0x5E62,
	0xB9F4: 0x5E63,
	0x82DD: 0x5E64,
	0xFFFD: 0x5E65,
	0xE96D: 0x5E66,
	0xE96B: 0x5E67,
	0xE96C: 0x5E68,
	0xE56E: 0x5E69,
	0xECDC: 0x5E6A,
	0xC0B0: 0x5E6B,
	0xECDB: 0x5E6C,
	0xEFC5: 0x5E6D,
	0xEFC6: 0x5E6E,
	0xE96E: 0x5E6F,
	0xF1FE: 0x5E70,
	0xFFFD: 0x5E71,
	0xA47A: 0x5E72,
	0xA5AD: 0x5E73,
	0xA67E: 0x5E74,
	0xC9DB: 0x5E75,
	0xA67D: 0x5E76,
	0xFFFD: 0x5E77,
	0xA9AF: 0x5E78,
	0xB746: 0x5E79,
	0xC6CD: 0x5E7A,
	0xA4DB: 0x5E7B,
	0xA5AE: 0x5E7C,
	0xABD5: 0x5E7D,
	0xB458: 0x5E7E,
	0xC6CE: 0x5E7F,
	0xC979: 0x5E80,
	0x9375: 0x5E81,
	0xC97A: 0x5E82,
	0x92BE: 0x5E83,
	0xC9DC: 0x5E84,
	0xFFFD: 0x5E85,
	0x87CA: 0x5E86,
	0xA7C8: 0x5E87,
	0xCAD0: 0x5E88,
	0xCACE: 0x5E89,
	0xA7C9: 0x5E8A,
	0xCACD: 0x5E8B,
	0xCACF: 0x5E8C,
	0xCAD1: 0x5E8D,
	0xFFFD: 0x5E8E,
	0xA7C7: 0x5E8F,
	0x8B72: 0x5E90,
	0x8EB5: 0x5E91,
	0x9A6A: 0x5E92,
	0x83B7: 0x5E93,
	0x89D8: 0x5E94,
	0xA9B3: 0x5E95,
	0xA9B4: 0x5E96,
	0xA9B1: 0x5E97,
	0xFFFD: 0x5E98,
	0x87C6: 0x5E99,
	0xA9B0: 0x5E9A,
	0xCEB8: 0x5E9B,
	0xA9B2: 0x5E9C,
	0xFFFD: 0x5E9D,
	0x8B71: 0x5E9E,
	0x87C4: 0x5E9F,
	0xABD6: 0x5EA0,
	0xFFFD: 0x5EA1,
	0xCEB7: 0x5EA2,
	0xCEB9: 0x5EA3,
	0xCEB6: 0x5EA4,
	0xCEBA: 0x5EA5,
	0xABD7: 0x5EA6,
	0xAE79: 0x5EA7,
	0xD175: 0x5EA8,
	0xFFFD: 0x5EA9,
	0xD177: 0x5EAA,
	0xAE77: 0x5EAB,
	0xD178: 0x5EAC,
	0xAE78: 0x5EAD,
	0xD176: 0x5EAE,
	0xFFFD: 0x5EAF,
	0xCEB5: 0x5EB0,
	0xD547: 0x5EB1,
	0xD54A: 0x5EB2,
	0xD54B: 0x5EB3,
	0xD548: 0x5EB4,
	0xB167: 0x5EB5,
	0xB166: 0x5EB6,
	0xB164: 0x5EB7,
	0xB165: 0x5EB8,
	0xD549: 0x5EB9,
	0xFFFD: 0x5EBA,
	0xFFFD: 0x5EBB,
	0xFFFD: 0x5EBC,
	0x9A6B: 0x5EBD,
	0xB168: 0x5EBE,
	0xFFFD: 0x5EBF,
	0xFFFD: 0x5EC0,
	0xB45A: 0x5EC1,
	0xB45B: 0x5EC2,
	0x93B2: 0x5EC3,
	0xB45C: 0x5EC4,
	0xDD5D: 0x5EC5,
	0xDD5F: 0x5EC6,
	0xDD61: 0x5EC7,
	0xB748: 0x5EC8,
	0xB747: 0x5EC9,
	0xB459: 0x5ECA,
	0xDD60: 0x5ECB,
	0xDD5E: 0x5ECC,
	0xFEA4: 0x5ECD,
	0xE1B8: 0x5ECE,
	0x82DE: 0x5ECF,
	0x82DF: 0x5ED0,
	0xE1B6: 0x5ED1,
	0xE1BC: 0x5ED2,
	0xB9F8: 0x5ED3,
	0xE1BD: 0x5ED4,
	0xE1BA: 0x5ED5,
	0xB9F9: 0x5ED6,
	0xE1B7: 0x5ED7,
	0xE1B5: 0x5ED8,
	0xE1BB: 0x5ED9,
	0xBC70: 0x5EDA,
	0xE573: 0x5EDB,
	0xE1B9: 0x5EDC,
	0xBC72: 0x5EDD,
	0xE574: 0x5EDE,
	0xBC71: 0x5EDF,
	0xBC74: 0x5EE0,
	0xE575: 0x5EE1,
	0xBC6F: 0x5EE2,
	0xBC73: 0x5EE3,
	0xFFFD: 0x5EE4,
	0xE973: 0x5EE5,
	0xE971: 0x5EE6,
	0xE970: 0x5EE7,
	0xE972: 0x5EE8,
	0xE96F: 0x5EE9,
	0x82E0: 0x5EEA,
	0xFFFD: 0x5EEB,
	0xC366: 0x5EEC,
	0xFFFD: 0x5EED,
	0xF446: 0x5EEE,
	0xF447: 0x5EEF,
	0x82E1: 0x5EF0,
	0xF5CB: 0x5EF1,
	0xF6DF: 0x5EF2,
	0xC655: 0x5EF3,
	0xC6CF: 0x5EF4,
	0xFFFD: 0x5EF5,
	0xA9B5: 0x5EF6,
	0xA7CA: 0x5EF7,
	0x95A4: 0x5EF8,
	0x95A1: 0x5EF9,
	0xABD8: 0x5EFA,
	0x95EE: 0x5EFB,
	0x95FA: 0x5EFC,
	0xFFFD: 0x5EFD,
	0xA47B: 0x5EFE,
	0xA4DC: 0x5EFF,
	0x857B: 0x5F00,
	0xA5AF: 0x5F01,
	0xC9DD: 0x5F02,
	0x8456: 0x5F03,
	0xA7CB: 0x5F04,
	0xCAD2: 0x5F05,
	0xFFFD: 0x5F06,
	0xCEBB: 0x5F07,
	0xABD9: 0x5F08,
	0x82E2: 0x5F09,
	0xB9FA: 0x5F0A,
	0xA47C: 0x5F0B,
	0x82E3: 0x5F0C,
	0x95AA: 0x5F0D,
	0x9A6C: 0x5F0E,
	0xA6A1: 0x5F0F,
	0x93AE: 0x5F10,
	0x82E4: 0x5F11,
	0xB749: 0x5F12,
	0xA47D: 0x5F13,
	0xA4DD: 0x5F14,
	0xA4DE: 0x5F15,
	0x9475: 0x5F16,
	0xA5B1: 0x5F17,
	0xA5B0: 0x5F18,
	0xFFFD: 0x5F19,
	0xC9DE: 0x5F1A,
	0xA6A2: 0x5F1B,
	0xFFFD: 0x5F1C,
	0xCAD3: 0x5F1D,
	0xFFFD: 0x5F1E,
	0xA7CC: 0x5F1F,
	0x8445: 0x5F20,
	0x82E5: 0x5F21,
	0xCC71: 0x5F22,
	0xCC72: 0x5F23,
	0xCC73: 0x5F24,
	0x93F9: 0x5F25,
	0xA9B6: 0x5F26,
	0xA9B7: 0x5F27,
	0xCC70: 0x5F28,
	0xA9B8: 0x5F29,
	0x8DC3: 0x5F2A,
	0xFFFD: 0x5F2B,
	0xFFFD: 0x5F2C,
	0xABDA: 0x5F2D,
	0xCEBC: 0x5F2E,
	0x8CCE: 0x5F2F,
	0xD17A: 0x5F30,
	0xAE7A: 0x5F31,
	0xFFFD: 0x5F32,
	0xD179: 0x5F33,
	0x82E6: 0x5F34,
	0xB169: 0x5F35,
	0xD54C: 0x5F36,
	0xB16A: 0x5F37,
	0xD54D: 0x5F38,
	0x87C9: 0x5F39,
	0x8446: 0x5F3A,
	0x9D7B: 0x5F3B,
	0xB45D: 0x5F3C,
	0xFFFD: 0x5F3D,
	0x9371: 0x5F3E,
	0xFFFD: 0x5F3F,
	0xDD62: 0x5F40,
	0x82E7: 0x5F41,
	0xFFFD: 0x5F42,
	0xE1BF: 0x5F43,
	0xE1BE: 0x5F44,
	0x82E8: 0x5F45,
	0xB9FB: 0x5F46,
	0xFFFD: 0x5F47,
	0xBC75: 0x5F48,
	0xE576: 0x5F49,
	0xBECA: 0x5F4A,
	0xE974: 0x5F4B,
	0xC0B1: 0x5F4C,
	0xFC41: 0x5F4D,
	0xC573: 0x5F4E,
	0xF7D8: 0x5F4F,
	0xC6D0: 0x5F50,
	0x82E9: 0x5F51,
	0x8AD0: 0x5F52,
	0x85E5: 0x5F53,
	0xCC74: 0x5F54,
	0x89A3: 0x5F55,
	0xCEBD: 0x5F56,
	0xB16B: 0x5F57,
	0xD8F4: 0x5F58,
	0xB74A: 0x5F59,
	0xFFFD: 0x5F5A,
	0xFFFD: 0x5F5B,
	0x82EA: 0x5F5C,
	0xC255: 0x5F5D,
	0xC255: 0x5F5E,
	0xFFFD: 0x5F5F,
	0xFFFD: 0x5F60,
	0xC6D1: 0x5F61,
	0xA7CE: 0x5F62,
	0xFEA8: 0x5F63,
	0xA7CD: 0x5F64,
	0xABDB: 0x5F65,
	0x82EB: 0x5F66,
	0xD17B: 0x5F67,
	0xFFFD: 0x5F68,
	0xB16D: 0x5F69,
	0xB343: 0x5F6A,
	0xB16E: 0x5F6B,
	0xB16C: 0x5F6C,
	0xB45E: 0x5F6D,
	0xFFFD: 0x5F6E,
	0xE1C0: 0x5F6F,
	0xB9FC: 0x5F70,
	0xBC76: 0x5F71,
	0x9A6D: 0x5F72,
	0xC94C: 0x5F73,
	0xC9DF: 0x5F74,
	0xFFFD: 0x5F75,
	0xCAD5: 0x5F76,
	0xA7CF: 0x5F77,
	0xCAD4: 0x5F78,
	0xA7D0: 0x5F79,
	0xFFFD: 0x5F7A,
	0x86C7: 0x5F7B,
	0xA9BC: 0x5F7C,
	0xCC77: 0x5F7D,
	0xCC76: 0x5F7E,
	0xA9BB: 0x5F7F,
	0xA9B9: 0x5F80,
	0xA9BA: 0x5F81,
	0xCC75: 0x5F82,
	0x82EC: 0x5F83,
	0x92A6: 0x5F84,
	0xABDD: 0x5F85,
	0xCEBE: 0x5F86,
	0xABE0: 0x5F87,
	0xABDC: 0x5F88,
	0xABE2: 0x5F89,
	0xABDE: 0x5F8A,
	0xABDF: 0x5F8B,
	0xABE1: 0x5F8C,
	0xFFFD: 0x5F8D,
	0xFFFD: 0x5F8E,
	0xFFFD: 0x5F8F,
	0xAE7D: 0x5F90,
	0xAE7C: 0x5F91,
	0xAE7B: 0x5F92,
	0x92DC: 0x5F93,
	0xFFFD: 0x5F94,
	0x8448: 0x5F95,
	0xD54F: 0x5F96,
	0xB16F: 0x5F97,
	0xB172: 0x5F98,
	0xB170: 0x5F99,
	0xFFFD: 0x5F9A,
	0xD54E: 0x5F9B,
	0xB175: 0x5F9C,
	0xFFFD: 0x5F9D,
	0xB171: 0x5F9E,
	0xD550: 0x5F9F,
	0xB174: 0x5FA0,
	0xB173: 0x5FA1,
	0xFFFD: 0x5FA2,
	0xFFFD: 0x5FA3,
	0xFC47: 0x5FA4,
	0xD8F6: 0x5FA5,
	0xD8F5: 0x5FA6,
	0x955A: 0x5FA7,
	0xB461: 0x5FA8,
	0xB45F: 0x5FA9,
	0xB460: 0x5FAA,
	0xD8F7: 0x5FAB,
	0xB74B: 0x5FAC,
	0xDD64: 0x5FAD,
	0xB74C: 0x5FAE,
	0xDD63: 0x5FAF,
	0xFFFD: 0x5FB0,
	0x9A6E: 0x5FB1,
	0xE577: 0x5FB2,
	0x93A8: 0x5FB3,
	0x9376: 0x5FB4,
	0xBC78: 0x5FB5,
	0xE1C1: 0x5FB6,
	0xBC77: 0x5FB7,
	0xFFFD: 0x5FB8,
	0xB9FD: 0x5FB9,
	0xFC48: 0x5FBA,
	0xECDE: 0x5FBB,
	0xE975: 0x5FBC,
	0xC0B2: 0x5FBD,
	0xECDD: 0x5FBE,
	0xF240: 0x5FBF,
	0xF448: 0x5FC0,
	0xF449: 0x5FC1,
	0x9A6F: 0x5FC2,
	0xA4DF: 0x5FC3,
	0x9CF5: 0x5FC4,
	0xA5B2: 0x5FC5,
	0x88DA: 0x5FC6,
	0xFFFD: 0x5FC7,
	0xFFFD: 0x5FC8,
	0xC97B: 0x5FC9,
	0xFFFD: 0x5FCA,
	0xFFFD: 0x5FCB,
	0xA7D2: 0x5FCC,
	0xA7D4: 0x5FCD,
	0xFFFD: 0x5FCE,
	0xC9E2: 0x5FCF,
	0xCAD8: 0x5FD0,
	0xCAD7: 0x5FD1,
	0xCAD6: 0x5FD2,
	0xFFFD: 0x5FD3,
	0xC9E1: 0x5FD4,
	0xC9E0: 0x5FD5,
	0xA6A4: 0x5FD6,
	0xA7D3: 0x5FD7,
	0xA7D1: 0x5FD8,
	0xA6A3: 0x5FD9,
	0xFFFD: 0x5FDA,
	0x9A70: 0x5FDB,
	0x924E: 0x5FDC,
	0xA9BD: 0x5FDD,
	0xCC78: 0x5FDE,
	0x9A71: 0x5FDF,
	0xA9BE: 0x5FE0,
	0xCADD: 0x5FE1,
	0xFFFD: 0x5FE2,
	0xCADF: 0x5FE3,
	0xCADE: 0x5FE4,
	0xCC79: 0x5FE5,
	0xFFFD: 0x5FE6,
	0x87CC: 0x5FE7,
	0xCADA: 0x5FE8,
	0xFFFD: 0x5FE9,
	0xA7D8: 0x5FEA,
	0xA7D6: 0x5FEB,
	0xFFFD: 0x5FEC,
	0xCAD9: 0x5FED,
	0xCADB: 0x5FEE,
	0xCAE1: 0x5FEF,
	0x82ED: 0x5FF0,
	0xA7D5: 0x5FF1,
	0xFFFD: 0x5FF2,
	0xCADC: 0x5FF3,
	0xCAE5: 0x5FF4,
	0xA9C0: 0x5FF5,
	0xFFFD: 0x5FF6,
	0xCAE2: 0x5FF7,
	0xA7D7: 0x5FF8,
	0xFFFD: 0x5FF9,
	0xCAE0: 0x5FFA,
	0xCAE3: 0x5FFB,
	0xFFFD: 0x5FFC,
	0xA9BF: 0x5FFD,
	0x85C7: 0x5FFE,
	0xA9C1: 0x5FFF,
	0xCAE4: 0x6000,
	0x86C8: 0x6001,
	0x87CD: 0x6002,
	0x87D1: 0x6003,
	0x8E6B: 0x6004,
	0x844A: 0x6005,
	0x85C8: 0x6006,
	0xFFFD: 0x6007,
	0xFFFD: 0x6008,
	0xCCAF: 0x6009,
	0xCCA2: 0x600A,
	0xCC7E: 0x600B,
	0xCCAE: 0x600C,
	0xCCA9: 0x600D,
	0xABE7: 0x600E,
	0xA9C2: 0x600F,
	0xCCAA: 0x6010,
	0xCCAD: 0x6011,
	0xABE3: 0x6012,
	0xCCAC: 0x6013,
	0xA9C3: 0x6014,
	0xA9C8: 0x6015,
	0xA9C6: 0x6016,
	0xCCA3: 0x6017,
	0xFFFD: 0x6018,
	0xCC7C: 0x6019,
	0xCCA5: 0x601A,
	0xA9CD: 0x601B,
	0xCCB0: 0x601C,
	0xABE4: 0x601D,
	0xCCA6: 0x601E,
	0xFFFD: 0x601F,
	0xABE5: 0x6020,
	0xA9C9: 0x6021,
	0xCCA8: 0x6022,
	0x9A72: 0x6023,
	0xCECD: 0x6024,
	0xABE6: 0x6025,
	0xCC7B: 0x6026,
	0xA9CA: 0x6027,
	0xABE8: 0x6028,
	0xA9CB: 0x6029,
	0xA9C7: 0x602A,
	0xA9CC: 0x602B,
	0xCCA7: 0x602C,
	0xCC7A: 0x602D,
	0xCCAB: 0x602E,
	0xA9C4: 0x602F,
	0xFFFD: 0x6030,
	0x95A6: 0x6031,
	0xCC7D: 0x6032,
	0xCCA4: 0x6033,
	0xCCA1: 0x6034,
	0xA9C5: 0x6035,
	0xFFFD: 0x6036,
	0xCEBF: 0x6037,
	0xFFFD: 0x6038,
	0xCEC0: 0x6039,
	0x9476: 0x603A,
	0x8A4B: 0x603B,
	0x8F74: 0x603C,
	0xFFFD: 0x603D,
	0xFFFD: 0x603E,
	0x8EE7: 0x603F,
	0xCECA: 0x6040,
	0xD1A1: 0x6041,
	0xCECB: 0x6042,
	0xABEE: 0x6043,
	0xCECE: 0x6044,
	0xCEC4: 0x6045,
	0xABED: 0x6046,
	0xCEC6: 0x6047,
	0xFFFD: 0x6048,
	0xCEC7: 0x6049,
	0x82EE: 0x604A,
	0x8CF6: 0x604B,
	0xCEC9: 0x604C,
	0xABE9: 0x604D,
	0xFFFD: 0x604E,
	0xFFFD: 0x604F,
	0xAEA3: 0x6050,
	0xFFFD: 0x6051,
	0xF9DA: 0x6052,
	0xCEC5: 0x6053,
	0xCEC1: 0x6054,
	0xAEA4: 0x6055,
	0xFFFD: 0x6056,
	0xFFFD: 0x6057,
	0xCECF: 0x6058,
	0xAE7E: 0x6059,
	0xD17D: 0x605A,
	0xCEC8: 0x605B,
	0xFFFD: 0x605C,
	0xD17C: 0x605D,
	0xCEC3: 0x605E,
	0xCECC: 0x605F,
	0x82EF: 0x6060,
	0xFFFD: 0x6061,
	0xABEC: 0x6062,
	0xAEA1: 0x6063,
	0xABF2: 0x6064,
	0xAEA2: 0x6065,
	0xCED0: 0x6066,
	0xD17E: 0x6067,
	0xABEB: 0x6068,
	0xAEA6: 0x6069,
	0xABF1: 0x606A,
	0xABF0: 0x606B,
	0xABEF: 0x606C,
	0xAEA5: 0x606D,
	0xCED1: 0x606E,
	0xAEA7: 0x606F,
	0xABEA: 0x6070,
	0xFFFD: 0x6071,
	0xCEC2: 0x6072,
	0x89D9: 0x6073,
	0xFFFD: 0x6074,
	0x92A8: 0x6075,
	0x84DC: 0x6076,
	0xFC4B: 0x6077,
	0x86CA: 0x6078,
	0x8F51: 0x6079,
	0x85C9: 0x607A,
	0x84DF: 0x607B,
	0x84E0: 0x607C,
	0x8DDD: 0x607D,
	0x9A73: 0x607E,
	0xB176: 0x607F,
	0xD1A4: 0x6080,
	0xD1A6: 0x6081,
	0xFFFD: 0x6082,
	0xD1A8: 0x6083,
	0xAEA8: 0x6084,
	0xAEAE: 0x6085,
	0xD553: 0x6086,
	0xD1AC: 0x6087,
	0xD1A3: 0x6088,
	0xB178: 0x6089,
	0xD551: 0x608A,
	0x82F0: 0x608B,
	0xAEAD: 0x608C,
	0xAEAB: 0x608D,
	0xD1AE: 0x608E,
	0xFFFD: 0x608F,
	0xD552: 0x6090,
	0xFFFD: 0x6091,
	0xD1A5: 0x6092,
	0xFFFD: 0x6093,
	0xAEAC: 0x6094,
	0xD1A9: 0x6095,
	0xAEAF: 0x6096,
	0xD1AB: 0x6097,
	0xFFFD: 0x6098,
	0xFFFD: 0x6099,
	0xAEAA: 0x609A,
	0xD1AA: 0x609B,
	0xD1AD: 0x609C,
	0xD1A7: 0x609D,
	0xFB64: 0x609E,
	0xAEA9: 0x609F,
	0xB179: 0x60A0,
	0xFFFD: 0x60A1,
	0xD1A2: 0x60A2,
	0xB177: 0x60A3,
	0xFC4C: 0x60A4,
	0xFFFD: 0x60A5,
	0x82F1: 0x60A6,
	0xFEA6: 0x60A7,
	0xB17A: 0x60A8,
	0x93AF: 0x60A9,
	0x9241: 0x60AA,
	0x8E69: 0x60AB,
	0x8BF4: 0x60AC,
	0x8E6A: 0x60AD,
	0xFFFD: 0x60AE,
	0x87CE: 0x60AF,
	0xD555: 0x60B0,
	0xD55E: 0x60B1,
	0xB464: 0x60B2,
	0xFC4D: 0x60B3,
	0xB17C: 0x60B4,
	0xB1A3: 0x60B5,
	0xB465: 0x60B6,
	0xD560: 0x60B7,
	0xB1AA: 0x60B8,
	0xD8F9: 0x60B9,
	0xD556: 0x60BA,
	0xB1A2: 0x60BB,
	0xB1A5: 0x60BC,
	0xB17E: 0x60BD,
	0xD554: 0x60BE,
	0xD562: 0x60BF,
	0xD565: 0x60C0,
	0xD949: 0x60C1,
	0xFFFD: 0x60C2,
	0xD563: 0x60C3,
	0xD8FD: 0x60C4,
	0xB1A1: 0x60C5,
	0xB1A8: 0x60C6,
	0xB1AC: 0x60C7,
	0xD55D: 0x60C8,
	0xD8F8: 0x60C9,
	0xD561: 0x60CA,
	0xB17B: 0x60CB,
	0xD8FA: 0x60CC,
	0xD564: 0x60CD,
	0xD8FC: 0x60CE,
	0xD559: 0x60CF,
	0xFFFD: 0x60D0,
	0xB462: 0x60D1,
	0xFFFD: 0x60D2,
	0xD557: 0x60D3,
	0xD558: 0x60D4,
	0xB1A7: 0x60D5,
	0xFFFD: 0x60D6,
	0x9A74: 0x60D7,
	0xB1A6: 0x60D8,
	0xD55B: 0x60D9,
	0xB1AB: 0x60DA,
	0xD55F: 0x60DB,
	0xB1A4: 0x60DC,
	0xD55C: 0x60DD,
	0x82F2: 0x60DE,
	0xB1A9: 0x60DF,
	0xB466: 0x60E0,
	0xB463: 0x60E1,
	0xD8FB: 0x60E2,
	0x82AD: 0x60E3,
	0xD55A: 0x60E4,
	0xFFFD: 0x60E5,
	0xB17D: 0x60E6,
	0x8C71: 0x60E7,
	0x86CC: 0x60E8,
	0x8B73: 0x60E9,
	0xFFFD: 0x60EA,
	0x88D8: 0x60EB,
	0x84DE: 0x60EC,
	0x86CB: 0x60ED,
	0x87CF: 0x60EE,
	0x86C9: 0x60EF,
	0xB46B: 0x60F0,
	0xB46F: 0x60F1,
	0xD940: 0x60F2,
	0xB751: 0x60F3,
	0xB46D: 0x60F4,
	0xD944: 0x60F5,
	0xB471: 0x60F6,
	0xDD65: 0x60F7,
	0xD946: 0x60F8,
	0xB753: 0x60F9,
	0xB469: 0x60FA,
	0xB46C: 0x60FB,
	0xD947: 0x60FC,
	0xFC4E: 0x60FD,
	0xD948: 0x60FE,
	0xD94E: 0x60FF,
	0xB473: 0x6100,
	0xB754: 0x6101,
	0xFFFD: 0x6102,
	0xD94A: 0x6103,
	0xD94F: 0x6104,
	0xD943: 0x6105,
	0xB75E: 0x6106,
	0x9A75: 0x6107,
	0xB755: 0x6108,
	0xB472: 0x6109,
	0xD941: 0x610A,
	0xD950: 0x610B,
	0x9A76: 0x610C,
	0xB75D: 0x610D,
	0xB470: 0x610E,
	0xB74E: 0x610F,
	0xD94D: 0x6110,
	0x82F3: 0x6111,
	0xB474: 0x6112,
	0xD945: 0x6113,
	0xD8FE: 0x6114,
	0xB46A: 0x6115,
	0xD942: 0x6116,
	0xFFFD: 0x6117,
	0xD94B: 0x6118,
	0x9A77: 0x6119,
	0xB74D: 0x611A,
	0xB752: 0x611B,
	0xB467: 0x611C,
	0xD94C: 0x611D,
	0xFFFD: 0x611E,
	0xB750: 0x611F,
	0x82F4: 0x6120,
	0x82F5: 0x6121,
	0x9A78: 0x6122,
	0xB468: 0x6123,
	0x87D0: 0x6124,
	0xFFFD: 0x6125,
	0x8EB6: 0x6126,
	0xB75C: 0x6127,
	0xE1C3: 0x6128,
	0xDD70: 0x6129,
	0xFFFD: 0x612A,
	0xDD68: 0x612B,
	0xE1C2: 0x612C,
	0xFFFD: 0x612D,
	0xDD6C: 0x612E,
	0xDD6E: 0x612F,
	0xFC4F: 0x6130,
	0xFFFD: 0x6131,
	0xDD6B: 0x6132,
	0xFFFD: 0x6133,
	0xB75B: 0x6134,
	0xFFFD: 0x6135,
	0xDD6A: 0x6136,
	0xB75F: 0x6137,
	0xFFFD: 0x6138,
	0xFFFD: 0x6139,
	0xFFFD: 0x613A,
	0xE1D2: 0x613B,
	0x82F6: 0x613C,
	0x82F7: 0x613D,
	0xB75A: 0x613E,
	0xBA40: 0x613F,
	0xDD71: 0x6140,
	0xE1C4: 0x6141,
	0xFCC9: 0x6142,
	0xFFFD: 0x6143,
	0xB758: 0x6144,
	0xDD69: 0x6145,
	0xDD6D: 0x6146,
	0xB9FE: 0x6147,
	0xB74F: 0x6148,
	0xDD66: 0x6149,
	0xDD67: 0x614A,
	0xBA41: 0x614B,
	0xB757: 0x614C,
	0xB759: 0x614D,
	0xB756: 0x614E,
	0xDD6F: 0x614F,
	0x9A79: 0x6150,
	0x8C72: 0x6151,
	0xE1C8: 0x6152,
	0xE1C9: 0x6153,
	0xE1CE: 0x6154,
	0xBC7D: 0x6155,
	0xE1D5: 0x6156,
	0xFFFD: 0x6157,
	0xBA47: 0x6158,
	0xFC52: 0x6159,
	0xBA46: 0x615A,
	0xE1D0: 0x615B,
	0xFC54: 0x615C,
	0xBC7C: 0x615D,
	0xE1C5: 0x615E,
	0xBA45: 0x615F,
	0x9A7A: 0x6160,
	0xE1D4: 0x6161,
	0xBA43: 0x6162,
	0xBA44: 0x6163,
	0x95AD: 0x6164,
	0xE1D1: 0x6165,
	0xE5AA: 0x6166,
	0xBC7A: 0x6167,
	0xB46E: 0x6168,
	0xFFFD: 0x6169,
	0xE1D3: 0x616A,
	0xBCA3: 0x616B,
	0xE1CB: 0x616C,
	0xFFFD: 0x616D,
	0xBC7B: 0x616E,
	0x9566: 0x616F,
	0xBCA2: 0x6170,
	0xE1C6: 0x6171,
	0xE1CA: 0x6172,
	0xE1C7: 0x6173,
	0xE1CD: 0x6174,
	0xBA48: 0x6175,
	0xBC79: 0x6176,
	0xBA42: 0x6177,
	0xFFFD: 0x6178,
	0xE57A: 0x6179,
	0xE1CF: 0x617A,
	0xFFFD: 0x617B,
	0xBCA1: 0x617C,
	0xFC53: 0x617D,
	0xBCA4: 0x617E,
	0xFFFD: 0x617F,
	0xE1CC: 0x6180,
	0x9A7B: 0x6181,
	0xBC7E: 0x6182,
	0xE579: 0x6183,
	0xFFFD: 0x6184,
	0xFFFD: 0x6185,
	0xFFFD: 0x6186,
	0x95D1: 0x6187,
	0xFFFD: 0x6188,
	0xE57E: 0x6189,
	0xBECE: 0x618A,
	0xE578: 0x618B,
	0xE9A3: 0x618C,
	0xE5A9: 0x618D,
	0xBCA8: 0x618E,
	0xFFFD: 0x618F,
	0xBCA6: 0x6190,
	0xBECC: 0x6191,
	0xE5A6: 0x6192,
	0xE5A2: 0x6193,
	0xBCAC: 0x6194,
	0x9A7C: 0x6195,
	0xE978: 0x6196,
	0xFFFD: 0x6197,
	0x82F8: 0x6198,
	0xFE74: 0x6199,
	0xBCAA: 0x619A,
	0xE5A1: 0x619B,
	0xFC51: 0x619C,
	0xE976: 0x619D,
	0xFFFD: 0x619E,
	0xE5A5: 0x619F,
	0xFFFD: 0x61A0,
	0xE5A8: 0x61A1,
	0xE57D: 0x61A2,
	0xFFFD: 0x61A3,
	0xBCAB: 0x61A4,
	0xFFFD: 0x61A5,
	0xFFFD: 0x61A6,
	0xBCA5: 0x61A7,
	0xE977: 0x61A8,
	0xBECD: 0x61A9,
	0xE5A7: 0x61AA,
	0xBCA7: 0x61AB,
	0xBCA9: 0x61AC,
	0xE5A4: 0x61AD,
	0xBCAD: 0x61AE,
	0xE5A3: 0x61AF,
	0xE57C: 0x61B0,
	0xE57B: 0x61B1,
	0xBECB: 0x61B2,
	0xE5AB: 0x61B3,
	0xE97A: 0x61B4,
	0xECE0: 0x61B5,
	0xBED0: 0x61B6,
	0x82F9: 0x61B7,
	0xE9A2: 0x61B8,
	0x9A7D: 0x61B9,
	0xE97E: 0x61BA,
	0xFFFD: 0x61BB,
	0xECE1: 0x61BC,
	0xFFFD: 0x61BD,
	0xBED1: 0x61BE,
	0xE9A1: 0x61BF,
	0x9A7E: 0x61C0,
	0xE97C: 0x61C1,
	0xC0B4: 0x61C2,
	0xECDF: 0x61C3,
	0xFFFD: 0x61C4,
	0xE979: 0x61C5,
	0xE97B: 0x61C6,
	0xC0B5: 0x61C7,
	0xBED3: 0x61C8,
	0xC0B3: 0x61C9,
	0xBED2: 0x61CA,
	0xC0B7: 0x61CB,
	0xE97D: 0x61CC,
	0xBECF: 0x61CD,
	0xFFFD: 0x61CE,
	0x9AA1: 0x61CF,
	0x925D: 0x61D0,
	0x8AC2: 0x61D1,
	0x8B75: 0x61D2,
	0x9AA2: 0x61D3,
	0x88D9: 0x61D4,
	0xFFFD: 0x61D5,
	0xEFCF: 0x61D6,
	0xFFFD: 0x61D7,
	0xEFC7: 0x61D8,
	0xFFFD: 0x61D9,
	0x9AA3: 0x61DA,
	0xFFFD: 0x61DB,
	0xFFFD: 0x61DC,
	0xFFFD: 0x61DD,
	0xECE7: 0x61DE,
	0xEFC8: 0x61DF,
	0xECE3: 0x61E0,
	0xFFFD: 0x61E1,
	0xFC56: 0x61E2,
	0xC256: 0x61E3,
	0xECE5: 0x61E4,
	0xECE4: 0x61E5,
	0xC0B6: 0x61E6,
	0xECE2: 0x61E7,
	0xECE6: 0x61E8,
	0xEFD0: 0x61E9,
	0xEFCC: 0x61EA,
	0xEFCE: 0x61EB,
	0xFFFD: 0x61EC,
	0xEFC9: 0x61ED,
	0xEFCA: 0x61EE,
	0xFFFD: 0x61EF,
	0xEFCD: 0x61F0,
	0xEFCB: 0x61F1,
	0xC367: 0x61F2,
	0xFFFD: 0x61F3,
	0x82FA: 0x61F4,
	0xC36A: 0x61F5,
	0xC369: 0x61F6,
	0xC368: 0x61F7,
	0xC461: 0x61F8,
	0xF44A: 0x61F9,
	0xC462: 0x61FA,
	0xF241: 0x61FB,
	0xC4DF: 0x61FC,
	0xF5CC: 0x61FD,
	0xC4E0: 0x61FE,
	0xC574: 0x61FF,
	0xC5CA: 0x6200,
	0xF7D9: 0x6201,
	0xFFFD: 0x6202,
	0xF7DA: 0x6203,
	0xF7DB: 0x6204,
	0xFFFD: 0x6205,
	0x90AB: 0x6206,
	0xF9BA: 0x6207,
	0xA4E0: 0x6208,
	0xC97C: 0x6209,
	0xA5B3: 0x620A,
	0x8DB8: 0x620B,
	0xA6A6: 0x620C,
	0xA6A7: 0x620D,
	0xA6A5: 0x620E,
	0x89DA: 0x620F,
	0xA6A8: 0x6210,
	0xA7DA: 0x6211,
	0xA7D9: 0x6212,
	0x82FB: 0x6213,
	0xCCB1: 0x6214,
	0xA9CF: 0x6215,
	0xA9CE: 0x6216,
	0x8E6D: 0x6217,
	0x88DB: 0x6218,
	0xD1AF: 0x6219,
	0xB1AD: 0x621A,
	0xB1AE: 0x621B,
	0xFFFD: 0x621C,
	0x82FC: 0x621D,
	0x82FD: 0x621E,
	0xB475: 0x621F,
	0xDD72: 0x6220,
	0xB760: 0x6221,
	0xB761: 0x6222,
	0xDD74: 0x6223,
	0xDD76: 0x6224,
	0xDD75: 0x6225,
	0x9349: 0x6226,
	0xE1D7: 0x6227,
	0xFFFD: 0x6228,
	0xE1D6: 0x6229,
	0xBA49: 0x622A,
	0xE1D8: 0x622B,
	0x8E6C: 0x622C,
	0xE5AC: 0x622D,
	0xBCAE: 0x622E,
	0x9270: 0x622F,
	0xBED4: 0x6230,
	0xFFFD: 0x6231,
	0xC0B8: 0x6232,
	0xC257: 0x6233,
	0xC0B9: 0x6234,
	0xFFFD: 0x6235,
	0xA4E1: 0x6236,
	0x82FE: 0x6237,
	0x90BD: 0x6238,
	0xFC58: 0x6239,
	0xCAE6: 0x623A,
	0x93EC: 0x623B,
	0xFFFD: 0x623C,
	0xCCB2: 0x623D,
	0xA9D1: 0x623E,
	0xA9D0: 0x623F,
	0xA9D2: 0x6240,
	0xABF3: 0x6241,
	0xCED2: 0x6242,
	0xCED3: 0x6243,
	0xFFFD: 0x6244,
	0xFFFD: 0x6245,
	0xD1B0: 0x6246,
	0xAEB0: 0x6247,
	0xB1AF: 0x6248,
	0xB476: 0x6249,
	0xD951: 0x624A,
	0xA4E2: 0x624B,
	0x9CF2: 0x624C,
	0xA47E: 0x624D,
	0xA4E3: 0x624E,
	0xFFFD: 0x624F,
	0xC97D: 0x6250,
	0xA5B7: 0x6251,
	0xA5B6: 0x6252,
	0xA5B4: 0x6253,
	0xA5B5: 0x6254,
	0x93C1: 0x6255,
	0xFFFD: 0x6256,
	0xFFFD: 0x6257,
	0xA6AB: 0x6258,
	0xC9E9: 0x6259,
	0xC9EB: 0x625A,
	0xA6AA: 0x625B,
	0xC9E3: 0x625C,
	0xFFFD: 0x625D,
	0xC9E4: 0x625E,
	0xFFFD: 0x625F,
	0xC9EA: 0x6260,
	0xC9E6: 0x6261,
	0xC9E8: 0x6262,
	0xA6A9: 0x6263,
	0xC9E5: 0x6264,
	0xC9EC: 0x6265,
	0xC9E7: 0x6266,
	0x83F9: 0x6267,
	0xFC59: 0x6268,
	0x8AC3: 0x6269,
	0x844D: 0x626A,
	0x844B: 0x626B,
	0x84E4: 0x626C,
	0xA7E1: 0x626D,
	0xA7EA: 0x626E,
	0xA7E8: 0x626F,
	0xCAF0: 0x6270,
	0xCAED: 0x6271,
	0xCAF5: 0x6272,
	0xA7E6: 0x6273,
	0xCAF6: 0x6274,
	0xFFFD: 0x6275,
	0xA7DF: 0x6276,
	0xCAF3: 0x6277,
	0xFFFD: 0x6278,
	0xA7E5: 0x6279,
	0xCAEF: 0x627A,
	0xCAEE: 0x627B,
	0xA7E3: 0x627C,
	0xCAF4: 0x627D,
	0xA7E4: 0x627E,
	0xA9D3: 0x627F,
	0xA7DE: 0x6280,
	0xCAF1: 0x6281,
	0xFC5B: 0x6282,
	0xCAE7: 0x6283,
	0xA7DB: 0x6284,
	0xFC5A: 0x6285,
	0xA7EE: 0x6286,
	0xCAEC: 0x6287,
	0xCAF2: 0x6288,
	0xA7E0: 0x6289,
	0xA7E2: 0x628A,
	0xFFFD: 0x628B,
	0xCAE8: 0x628C,
	0xFFFD: 0x628D,
	0xCAE9: 0x628E,
	0xCAEA: 0x628F,
	0x9AA4: 0x6290,
	0xA7ED: 0x6291,
	0xA7E7: 0x6292,
	0xA7EC: 0x6293,
	0xCAEB: 0x6294,
	0xA7EB: 0x6295,
	0xA7DD: 0x6296,
	0xA7DC: 0x6297,
	0xA7E9: 0x6298,
	0xFFFD: 0x6299,
	0x87D7: 0x629A,
	0x90BE: 0x629B,
	0x93BB: 0x629C,
	0xFD57: 0x629D,
	0x936A: 0x629E,
	0x8E6E: 0x629F,
	0x8E6F: 0x62A0,
	0x844E: 0x62A1,
	0x85CB: 0x62A2,
	0xFFFD: 0x62A3,
	0x8CA8: 0x62A4,
	0x84D2: 0x62A5,
	0xFC5C: 0x62A6,
	0xFFFD: 0x62A7,
	0xA9E1: 0x62A8,
	0xCCBE: 0x62A9,
	0xCCB7: 0x62AA,
	0xA9DC: 0x62AB,
	0xA9EF: 0x62AC,
	0xCCB3: 0x62AD,
	0xCCBA: 0x62AE,
	0xCCBC: 0x62AF,
	0xCCBF: 0x62B0,
	0xA9EA: 0x62B1,
	0xFFFD: 0x62B2,
	0xCCBB: 0x62B3,
	0xCCB4: 0x62B4,
	0xA9E8: 0x62B5,
	0xCCB8: 0x62B6,
	0xFFFD: 0x62B7,
	0xCCC0: 0x62B8,
	0xA9D9: 0x62B9,
	0xFFFD: 0x62BA,
	0xCCBD: 0x62BB,
	0xA9E3: 0x62BC,
	0xA9E2: 0x62BD,
	0xCCB6: 0x62BE,
	0xA9D7: 0x62BF,
	0xFFFD: 0x62C0,
	0xFFFD: 0x62C1,
	0xA9D8: 0x62C2,
	0xFB46: 0x62C3,
	0xA9D6: 0x62C4,
	0x88E3: 0x62C5,
	0xA9EE: 0x62C6,
	0xA9E6: 0x62C7,
	0xA9E0: 0x62C8,
	0xA9D4: 0x62C9,
	0xCCB9: 0x62CA,
	0xA9DF: 0x62CB,
	0xA9D5: 0x62CC,
	0xA9E7: 0x62CD,
	0xA9F0: 0x62CE,
	0xCED4: 0x62CF,
	0xA9E4: 0x62D0,
	0xCCB5: 0x62D1,
	0xA9DA: 0x62D2,
	0xA9DD: 0x62D3,
	0xA9DE: 0x62D4,
	0xFC5D: 0x62D5,
	0xA9EC: 0x62D6,
	0xA9ED: 0x62D7,
	0xA9EB: 0x62D8,
	0xA9E5: 0x62D9,
	0xA9E9: 0x62DA,
	0xA9DB: 0x62DB,
	0xABF4: 0x62DC,
	0x93B1: 0x62DD,
	0xFFFD: 0x62DE,
	0x89DE: 0x62DF,
	0x9275: 0x62E0,
	0x925E: 0x62E1,
	0x8B76: 0x62E2,
	0x84E1: 0x62E3,
	0xFFFD: 0x62E4,
	0x88DC: 0x62E5,
	0x8BF6: 0x62E6,
	0x89DD: 0x62E7,
	0x87D5: 0x62E8,
	0x88E1: 0x62E9,
	0xFFFD: 0x62EA,
	0xCEDA: 0x62EB,
	0xAC41: 0x62EC,
	0xABF8: 0x62ED,
	0xABFA: 0x62EE,
	0xAC40: 0x62EF,
	0xCEE6: 0x62F0,
	0xABFD: 0x62F1,
	0xD1B1: 0x62F2,
	0xAEB1: 0x62F3,
	0xAC43: 0x62F4,
	0xCED7: 0x62F5,
	0xCEDF: 0x62F6,
	0xABFE: 0x62F7,
	0xCEDE: 0x62F8,
	0xCEDB: 0x62F9,
	0xCEE3: 0x62FA,
	0xCEE5: 0x62FB,
	0xABF7: 0x62FC,
	0xABFB: 0x62FD,
	0xAC42: 0x62FE,
	0xAEB3: 0x62FF,
	0xCEE0: 0x6300,
	0xABF9: 0x6301,
	0xAC45: 0x6302,
	0xCED9: 0x6303,
	0xFFFD: 0x6304,
	0xFFFD: 0x6305,
	0xFFFD: 0x6306,
	0xABFC: 0x6307,
	0xAEB2: 0x6308,
	0xABF6: 0x6309,
	0xFFFD: 0x630A,
	0xCED6: 0x630B,
	0xCEDD: 0x630C,
	0xCED5: 0x630D,
	0xCED8: 0x630E,
	0xCEDC: 0x630F,
	0xD1B2: 0x6310,
	0xAC44: 0x6311,
	0xFFFD: 0x6312,
	0xCEE1: 0x6313,
	0xCEE2: 0x6314,
	0xCEE4: 0x6315,
	0xABF5: 0x6316,
	0xFFFD: 0x6317,
	0x94F4: 0x6318,
	0x9276: 0x6319,
	0x87D2: 0x631A,
	0x8CF7: 0x631B,
	0xFFFD: 0x631C,
	0x88E4: 0x631D,
	0x88DE: 0x631E,
	0x83B9: 0x631F,
	0x87D6: 0x6320,
	0x88DD: 0x6321,
	0x8EB7: 0x6322,
	0x844F: 0x6323,
	0x89DC: 0x6324,
	0x84E2: 0x6325,
	0xFFFD: 0x6326,
	0x90BF: 0x6327,
	0xAEC1: 0x6328,
	0xD1BE: 0x6329,
	0xAEBF: 0x632A,
	0xAEC0: 0x632B,
	0xD1B4: 0x632C,
	0xD1C4: 0x632D,
	0xA05E: 0x632E,
	0xAEB6: 0x632F,
	0xFFFD: 0x6330,
	0x9AA5: 0x6331,
	0xD566: 0x6332,
	0xD1C6: 0x6333,
	0xD1C0: 0x6334,
	0xFC5F: 0x6335,
	0xD1B7: 0x6336,
	0x9AA7: 0x6337,
	0xD1C9: 0x6338,
	0xD1BA: 0x6339,
	0xAEBC: 0x633A,
	0xD57D: 0x633B,
	0xD1BD: 0x633C,
	0xAEBE: 0x633D,
	0xAEB5: 0x633E,
	0x9356: 0x633F,
	0xD1CB: 0x6340,
	0xD1BF: 0x6341,
	0xAEB8: 0x6342,
	0xD1B8: 0x6343,
	0xD1B5: 0x6344,
	0xD1B6: 0x6345,
	0xAEB9: 0x6346,
	0xD1C5: 0x6347,
	0xD1CC: 0x6348,
	0xAEBB: 0x6349,
	0xD1BC: 0x634A,
	0xD1BB: 0x634B,
	0xAEC3: 0x634C,
	0xAEC2: 0x634D,
	0xAEB4: 0x634E,
	0xAEBA: 0x634F,
	0xAEBD: 0x6350,
	0xD1C8: 0x6351,
	0xFFFD: 0x6352,
	0xFFFD: 0x6353,
	0xD1C2: 0x6354,
	0xAEB7: 0x6355,
	0xD1B3: 0x6356,
	0xD1CA: 0x6357,
	0xD1C1: 0x6358,
	0xD1C3: 0x6359,
	0xD1C7: 0x635A,
	0xFFFD: 0x635B,
	0x9355: 0x635C,
	0xFFFD: 0x635D,
	0x87D4: 0x635E,
	0x85CA: 0x635F,
	0xFFFD: 0x6360,
	0x88E2: 0x6361,
	0x84E3: 0x6362,
	0x85CC: 0x6363,
	0xFC5E: 0x6364,
	0xD567: 0x6365,
	0xFFFD: 0x6366,
	0xB1B7: 0x6367,
	0xB1CB: 0x6368,
	0xB1CA: 0x6369,
	0xFFFD: 0x636A,
	0xB1BF: 0x636B,
	0x9559: 0x636C,
	0xD579: 0x636D,
	0xD575: 0x636E,
	0xD572: 0x636F,
	0xD5A6: 0x6370,
	0xB1BA: 0x6371,
	0xB1B2: 0x6372,
	0xFFFD: 0x6373,
	0xFFFD: 0x6374,
	0xD577: 0x6375,
	0xB4A8: 0x6376,
	0xB1B6: 0x6377,
	0xD5A1: 0x6378,
	0x9AA8: 0x6379,
	0xB1CC: 0x637A,
	0xB1C9: 0x637B,
	0xD57B: 0x637C,
	0xD56A: 0x637D,
	0xFFFD: 0x637E,
	0xFC55: 0x637F,
	0xB1C8: 0x6380,
	0xD5A3: 0x6381,
	0xD569: 0x6382,
	0xB1BD: 0x6383,
	0xB1C1: 0x6384,
	0xD5A2: 0x6385,
	0xFFFD: 0x6386,
	0xD573: 0x6387,
	0xB1C2: 0x6388,
	0xB1BC: 0x6389,
	0xD568: 0x638A,
	0x9AA9: 0x638B,
	0xB478: 0x638C,
	0xD5A5: 0x638D,
	0xD571: 0x638E,
	0xB1C7: 0x638F,
	0xD574: 0x6390,
	0xD5A4: 0x6391,
	0xB1C6: 0x6392,
	0xFFFD: 0x6393,
	0xD952: 0x6394,
	0xFFFD: 0x6395,
	0xB1B3: 0x6396,
	0xD56F: 0x6397,
	0xB1B8: 0x6398,
	0xB1C3: 0x6399,
	0xFFFD: 0x639A,
	0xB1BE: 0x639B,
	0xD578: 0x639C,
	0xD56E: 0x639D,
	0xD56C: 0x639E,
	0xD57E: 0x639F,
	0xB1B0: 0x63A0,
	0xB1C4: 0x63A1,
	0xB1B4: 0x63A2,
	0xB477: 0x63A3,
	0xD57C: 0x63A4,
	0xB1B5: 0x63A5,
	0xFFFD: 0x63A6,
	0xB1B1: 0x63A7,
	0xB1C0: 0x63A8,
	0xB1BB: 0x63A9,
	0xB1B9: 0x63AA,
	0xD570: 0x63AB,
	0xB1C5: 0x63AC,
	0xD56D: 0x63AD,
	0xD57A: 0x63AE,
	0xD576: 0x63AF,
	0xD954: 0x63B0,
	0xD953: 0x63B1,
	0x92A9: 0x63B2,
	0x88E0: 0x63B3,
	0x86CE: 0x63B4,
	0x9477: 0x63B5,
	0xFFFD: 0x63B6,
	0x8AC4: 0x63B7,
	0x87D8: 0x63B8,
	0xFB57: 0x63B9,
	0x86CF: 0x63BA,
	0x90C0: 0x63BB,
	0x8E70: 0x63BC,
	0xD56B: 0x63BD,
	0xD964: 0x63BE,
	0xFFFD: 0x63BF,
	0xB47A: 0x63C0,
	0x9AAA: 0x63C1,
	0xD96A: 0x63C2,
	0xD959: 0x63C3,
	0xD967: 0x63C4,
	0xDD77: 0x63C5,
	0xB47D: 0x63C6,
	0xD96B: 0x63C7,
	0xD96E: 0x63C8,
	0xB47C: 0x63C9,
	0xD95C: 0x63CA,
	0xD96D: 0x63CB,
	0xD96C: 0x63CC,
	0xB47E: 0x63CD,
	0xD955: 0x63CE,
	0xB479: 0x63CF,
	0xB4A3: 0x63D0,
	0xFD6C: 0x63D1,
	0xB4A1: 0x63D2,
	0xD969: 0x63D3,
	0xFFFD: 0x63D4,
	0xD95F: 0x63D5,
	0xB4A5: 0x63D6,
	0xD970: 0x63D7,
	0xD968: 0x63D8,
	0xD971: 0x63D9,
	0xB4AD: 0x63DA,
	0xB4AB: 0x63DB,
	0xD966: 0x63DC,
	0xD965: 0x63DD,
	0x90C1: 0x63DE,
	0xD963: 0x63DF,
	0xD95D: 0x63E0,
	0xB4A4: 0x63E1,
	0x9AAB: 0x63E2,
	0xB4A2: 0x63E3,
	0xD1B9: 0x63E4,
	0xD956: 0x63E5,
	0x9AAC: 0x63E6,
	0xDDB7: 0x63E7,
	0xD957: 0x63E8,
	0xB47B: 0x63E9,
	0xB4AA: 0x63EA,
	0xDD79: 0x63EB,
	0xFFFD: 0x63EC,
	0xB4A6: 0x63ED,
	0xB4A7: 0x63EE,
	0xD958: 0x63EF,
	0xD96F: 0x63F0,
	0xDD78: 0x63F1,
	0xD960: 0x63F2,
	0xD95B: 0x63F3,
	0xB4A9: 0x63F4,
	0xD961: 0x63F5,
	0xD95E: 0x63F6,
	0xFFFD: 0x63F7,
	0xA05F: 0x63F8,
	0xB4AE: 0x63F9,
	0x90C2: 0x63FA,
	0x9AAD: 0x63FB,
	0xFB5D: 0x63FC,
	0x8D53: 0x63FD,
	0x9AAE: 0x63FE,
	0x87D9: 0x63FF,
	0x8BF7: 0x6400,
	0x89DF: 0x6401,
	0x86CD: 0x6402,
	0xFFFD: 0x6403,
	0xFFFD: 0x6404,
	0x8CF8: 0x6405,
	0xB770: 0x6406,
	0x9AAF: 0x6407,
	0xFFFD: 0x6408,
	0xDD7C: 0x6409,
	0xDDB1: 0x640A,
	0xDDB6: 0x640B,
	0xDDAA: 0x640C,
	0xB76C: 0x640D,
	0xDDBB: 0x640E,
	0xB769: 0x640F,
	0xDD7A: 0x6410,
	0xFFFD: 0x6411,
	0xDD7B: 0x6412,
	0xB762: 0x6413,
	0xB76B: 0x6414,
	0xDDA4: 0x6415,
	0xB76E: 0x6416,
	0xB76F: 0x6417,
	0xDDA5: 0x6418,
	0xFFFD: 0x6419,
	0xDDB2: 0x641A,
	0xDDB8: 0x641B,
	0xB76A: 0x641C,
	0xFFFD: 0x641D,
	0xB764: 0x641E,
	0xDDA3: 0x641F,
	0xDD7D: 0x6420,
	0xDDBA: 0x6421,
	0xDDA8: 0x6422,
	0xDDA9: 0x6423,
	0xDD7E: 0x6424,
	0xDDB4: 0x6425,
	0xDDAB: 0x6426,
	0xDDB5: 0x6427,
	0xDDAD: 0x6428,
	0xFFFD: 0x6429,
	0xB765: 0x642A,
	0xE1D9: 0x642B,
	0xB768: 0x642C,
	0xB766: 0x642D,
	0xDDB9: 0x642E,
	0xDDB0: 0x642F,
	0xDDAC: 0x6430,
	0xFFFD: 0x6431,
	0x9AB0: 0x6432,
	0xDDA1: 0x6433,
	0xBA53: 0x6434,
	0xDDAF: 0x6435,
	0xB76D: 0x6436,
	0xDDA7: 0x6437,
	0x9AB1: 0x6438,
	0xDDA6: 0x6439,
	0x8C74: 0x643A,
	0x9AB2: 0x643B,
	0xFFFD: 0x643C,
	0xB767: 0x643D,
	0xB763: 0x643E,
	0xE1EE: 0x643F,
	0xDDB3: 0x6440,
	0xDDAE: 0x6441,
	0x9345: 0x6442,
	0xDDA2: 0x6443,
	0x8C73: 0x6444,
	0x8F75: 0x6445,
	0x8AC7: 0x6446,
	0x93DA: 0x6447,
	0x8F52: 0x6448,
	0xFFFD: 0x6449,
	0x8CCF: 0x644A,
	0xE1E9: 0x644B,
	0xFFFD: 0x644C,
	0xE1DA: 0x644D,
	0xE1E5: 0x644E,
	0xFFFD: 0x644F,
	0xE1EC: 0x6450,
	0xBA51: 0x6451,
	0xB4AC: 0x6452,
	0xE1EA: 0x6453,
	0xBA4C: 0x6454,
	0xFFFD: 0x6455,
	0xFFFD: 0x6456,
	0xFFFD: 0x6457,
	0xBA4B: 0x6458,
	0xE1F1: 0x6459,
	0x9AB3: 0x645A,
	0xE1DB: 0x645B,
	0xE1E8: 0x645C,
	0xE1DC: 0x645D,
	0xE1E7: 0x645E,
	0xBA4F: 0x645F,
	0xE1EB: 0x6460,
	0xD962: 0x6461,
	0xFFFD: 0x6462,
	0xFFFD: 0x6463,
	0xFFFD: 0x6464,
	0xE1F2: 0x6465,
	0xE1E3: 0x6466,
	0xBA52: 0x6467,
	0xE5BA: 0x6468,
	0xBCAF: 0x6469,
	0xFFFD: 0x646A,
	0xE1F0: 0x646B,
	0xE1EF: 0x646C,
	0xBA54: 0x646D,
	0xE5AD: 0x646E,
	0xBCB0: 0x646F,
	0xE5AE: 0x6470,
	0x9AB4: 0x6471,
	0xE1DF: 0x6472,
	0xE1E0: 0x6473,
	0xE1DD: 0x6474,
	0xE1E2: 0x6475,
	0xE1DE: 0x6476,
	0xE1F3: 0x6477,
	0xBA4E: 0x6478,
	0xBCB1: 0x6479,
	0xBA50: 0x647A,
	0xBA55: 0x647B,
	0x9AB5: 0x647C,
	0xE1E1: 0x647D,
	0xFFFD: 0x647E,
	0xE1ED: 0x647F,
	0xFFFD: 0x6480,
	0xFFFD: 0x6481,
	0xE1E6: 0x6482,
	0x92B0: 0x6483,
	0x8FDA: 0x6484,
	0xE5B1: 0x6485,
	0xFFFD: 0x6486,
	0xBA4A: 0x6487,
	0xBCB4: 0x6488,
	0xE9AA: 0x6489,
	0xE5B6: 0x648A,
	0xE5B5: 0x648B,
	0xE5B7: 0x648C,
	0x9AB6: 0x648D,
	0xFFFD: 0x648E,
	0xE5B4: 0x648F,
	0xBCB5: 0x6490,
	0x90C3: 0x6491,
	0xBCBB: 0x6492,
	0xBCB8: 0x6493,
	0xFFFD: 0x6494,
	0xBCB9: 0x6495,
	0xE5AF: 0x6496,
	0xE5B2: 0x6497,
	0xE5BC: 0x6498,
	0xBCC1: 0x6499,
	0xBCBF: 0x649A,
	0xFFFD: 0x649B,
	0xE5B3: 0x649C,
	0xD95A: 0x649D,
	0xBCB2: 0x649E,
	0xE5B9: 0x649F,
	0xE5B0: 0x64A0,
	0xFFFD: 0x64A1,
	0xBCC2: 0x64A2,
	0xE5B8: 0x64A3,
	0xBA4D: 0x64A4,
	0xBCB7: 0x64A5,
	0xE1E4: 0x64A6,
	0xFFFD: 0x64A7,
	0xFFFD: 0x64A8,
	0xBCBA: 0x64A9,
	0xFFFD: 0x64AA,
	0xBCBE: 0x64AB,
	0xBCC0: 0x64AC,
	0xBCBD: 0x64AD,
	0xBCBC: 0x64AE,
	0x9AB7: 0x64AF,
	0xBCB6: 0x64B0,
	0xE5BB: 0x64B1,
	0xBCB3: 0x64B2,
	0xBCC3: 0x64B3,
	0x9AB8: 0x64B4,
	0x8AC6: 0x64B5,
	0x9AB9: 0x64B6,
	0x8AC9: 0x64B7,
	0x8F76: 0x64B8,
	0x824D: 0x64B9,
	0x8FFE: 0x64BA,
	0xBED8: 0x64BB,
	0xBED9: 0x64BC,
	0xE9A9: 0x64BD,
	0xBEE2: 0x64BE,
	0xBEDF: 0x64BF,
	0x90C4: 0x64C0,
	0xBED6: 0x64C1,
	0xBEDD: 0x64C2,
	0xE9AB: 0x64C3,
	0xBEDB: 0x64C4,
	0xBED5: 0x64C5,
	0xFFFD: 0x64C6,
	0xBEDC: 0x64C7,
	0xFFFD: 0x64C8,
	0xE9A8: 0x64C9,
	0xC0BB: 0x64CA,
	0xBED7: 0x64CB,
	0xFFFD: 0x64CC,
	0xBEDE: 0x64CD,
	0xC0BA: 0x64CE,
	0xE9A7: 0x64CF,
	0xE9A6: 0x64D0,
	0xFFFD: 0x64D1,
	0xBEE0: 0x64D2,
	0xA05D: 0x64D3,
	0xBEE1: 0x64D4,
	0xFFFD: 0x64D5,
	0xE9A5: 0x64D6,
	0xE9A4: 0x64D7,
	0xC0BC: 0x64D8,
	0xE9AE: 0x64D9,
	0xBEDA: 0x64DA,
	0xE9AC: 0x64DB,
	0xFFFD: 0x64DC,
	0x9ABA: 0x64DD,
	0x8AC8: 0x64DE,
	0xFFFD: 0x64DF,
	0xC0BD: 0x64E0,
	0x90C5: 0x64E1,
	0xC0C2: 0x64E2,
	0xECEA: 0x64E3,
	0xECEC: 0x64E4,
	0x9ABB: 0x64E5,
	0xC0BF: 0x64E6,
	0xFBA3: 0x64E7,
	0xECED: 0x64E8,
	0xECE9: 0x64E9,
	0x95C8: 0x64EA,
	0xECEB: 0x64EB,
	0xC0C0: 0x64EC,
	0xC0C3: 0x64ED,
	0xFFFD: 0x64EE,
	0xECE8: 0x64EF,
	0xC0BE: 0x64F0,
	0xC0C1: 0x64F1,
	0xC259: 0x64F2,
	0xE9AD: 0x64F3,
	0xC258: 0x64F4,
	0xFFFD: 0x64F5,
	0x90C6: 0x64F6,
	0xC25E: 0x64F7,
	0xEFD4: 0x64F8,
	0xFFFD: 0x64F9,
	0xC25C: 0x64FA,
	0xC25D: 0x64FB,
	0xEFD7: 0x64FC,
	0xEFD3: 0x64FD,
	0xC25A: 0x64FE,
	0xEFD1: 0x64FF,
	0xC36B: 0x6500,
	0xEFD5: 0x6501,
	0xFFFD: 0x6502,
	0xEFD6: 0x6503,
	0xEFD2: 0x6504,
	0x90C7: 0x6505,
	0xC25B: 0x6506,
	0xF242: 0x6507,
	0xFFFD: 0x6508,
	0xF245: 0x6509,
	0x9ABC: 0x650A,
	0xFFFD: 0x650B,
	0xF246: 0x650C,
	0xF244: 0x650D,
	0xF247: 0x650E,
	0xC36C: 0x650F,
	0xF243: 0x6510,
	0x9ABD: 0x6511,
	0x9057: 0x6512,
	0xF44E: 0x6513,
	0xC464: 0x6514,
	0xF44D: 0x6515,
	0xF44C: 0x6516,
	0xF44B: 0x6517,
	0xC463: 0x6518,
	0xC465: 0x6519,
	0xFFFD: 0x651A,
	0xF5CD: 0x651B,
	0xC4E2: 0x651C,
	0xC4E1: 0x651D,
	0xA060: 0x651E,
	0x9ABE: 0x651F,
	0xF6E1: 0x6520,
	0xF6E0: 0x6521,
	0xF6E3: 0x6522,
	0xC5CB: 0x6523,
	0xC575: 0x6524,
	0xF7DD: 0x6525,
	0xF6E2: 0x6526,
	0xFFFD: 0x6527,
	0xFFFD: 0x6528,
	0xF7DC: 0x6529,
	0xC5CD: 0x652A,
	0xC5CC: 0x652B,
	0xC5F3: 0x652C,
	0xF8A9: 0x652D,
	0xF8EF: 0x652E,
	0xA4E4: 0x652F,
	0xFE5B: 0x6530,
	0xFFFD: 0x6531,
	0xD972: 0x6532,
	0xE9AF: 0x6533,
	0xC6D2: 0x6534,
	0x90C8: 0x6535,
	0xA6AC: 0x6536,
	0xCAF7: 0x6537,
	0xA7F1: 0x6538,
	0xA7EF: 0x6539,
	0xFFFD: 0x653A,
	0xA7F0: 0x653B,
	0xFFFD: 0x653C,
	0xCCC1: 0x653D,
	0xA9F1: 0x653E,
	0xAC46: 0x653F,
	0xFFFD: 0x6540,
	0xCEE7: 0x6541,
	0xFFFD: 0x6542,
	0xCEE8: 0x6543,
	0xFFFD: 0x6544,
	0xAC47: 0x6545,
	0xD1CE: 0x6546,
	0xFFFD: 0x6547,
	0xAEC4: 0x6548,
	0xAEC5: 0x6549,
	0xD1CD: 0x654A,
	0xFFFD: 0x654B,
	0x87DA: 0x654C,
	0x95B4: 0x654D,
	0x90C9: 0x654E,
	0xB1D3: 0x654F,
	0xFFFD: 0x6550,
	0xB1CF: 0x6551,
	0xFFFD: 0x6552,
	0xD5A7: 0x6553,
	0xB1D6: 0x6554,
	0xB1D5: 0x6555,
	0xB1CE: 0x6556,
	0xB1D1: 0x6557,
	0xB1D4: 0x6558,
	0xB1D0: 0x6559,
	0xFFFD: 0x655A,
	0x89E0: 0x655B,
	0xD976: 0x655C,
	0xB1CD: 0x655D,
	0xB4AF: 0x655E,
	0x9ABF: 0x655F,
	0xFFFD: 0x6560,
	0xFFFD: 0x6561,
	0xB4B1: 0x6562,
	0xB4B2: 0x6563,
	0xD975: 0x6564,
	0xD978: 0x6565,
	0xB4B0: 0x6566,
	0xD973: 0x6567,
	0xD977: 0x6568,
	0xFFFD: 0x6569,
	0xD974: 0x656A,
	0x90CA: 0x656B,
	0xB771: 0x656C,
	0x9AC0: 0x656D,
	0xFFFD: 0x656E,
	0xDDBC: 0x656F,
	0x87DB: 0x6570,
	0xFFFD: 0x6571,
	0xBA56: 0x6572,
	0xE1F4: 0x6573,
	0xBEE3: 0x6574,
	0xBCC4: 0x6575,
	0xE5BD: 0x6576,
	0xBCC5: 0x6577,
	0xBCC6: 0x6578,
	0xE5BF: 0x6579,
	0xE5BE: 0x657A,
	0xE5C0: 0x657B,
	0xE9B1: 0x657C,
	0xFFFD: 0x657D,
	0xFFFD: 0x657E,
	0xE9B0: 0x657F,
	0xECEF: 0x6580,
	0xECEE: 0x6581,
	0xC0C4: 0x6582,
	0xC0C5: 0x6583,
	0xF248: 0x6584,
	0xFCB7: 0x6585,
	0x9AC1: 0x6586,
	0xA4E5: 0x6587,
	0x90CB: 0x6588,
	0x9342: 0x6589,
	0xFFFD: 0x658A,
	0x8ABC: 0x658B,
	0xD979: 0x658C,
	0xFFFD: 0x658D,
	0x92C7: 0x658E,
	0xFFFD: 0x658F,
	0xB4B4: 0x6590,
	0xB4B3: 0x6591,
	0xDDBD: 0x6592,
	0x8C75: 0x6593,
	0xEFD8: 0x6594,
	0xC4E3: 0x6595,
	0xF7DE: 0x6596,
	0xA4E6: 0x6597,
	0xFFFD: 0x6598,
	0xAEC6: 0x6599,
	0xFFFD: 0x659A,
	0xB1D8: 0x659B,
	0xB1D7: 0x659C,
	0xD97A: 0x659D,
	0xD97B: 0x659E,
	0xB772: 0x659F,
	0xE1F5: 0x65A0,
	0xBA57: 0x65A1,
	0xE9B2: 0x65A2,
	0xFFFD: 0x65A3,
	0xA4E7: 0x65A4,
	0xA5B8: 0x65A5,
	0xFFFD: 0x65A6,
	0xA9F2: 0x65A7,
	0xCCC2: 0x65A8,
	0x8453: 0x65A9,
	0xCEE9: 0x65AA,
	0xAC48: 0x65AB,
	0xB1D9: 0x65AC,
	0x8ACA: 0x65AD,
	0xD97C: 0x65AE,
	0xB4B5: 0x65AF,
	0xB773: 0x65B0,
	0xFFFD: 0x65B1,
	0xE5C1: 0x65B2,
	0xE5C2: 0x65B3,
	0xFFFD: 0x65B4,
	0x9AC2: 0x65B5,
	0xECF0: 0x65B6,
	0xC25F: 0x65B7,
	0xF8F0: 0x65B8,
	0xA4E8: 0x65B9,
	0xFFFD: 0x65BA,
	0xCCC3: 0x65BB,
	0xA9F3: 0x65BC,
	0xAC49: 0x65BD,
	0x9AC3: 0x65BE,
	0xCEEA: 0x65BF,
	0xFFFD: 0x65C0,
	0xAEC7: 0x65C1,
	0xD1D2: 0x65C2,
	0xD1D0: 0x65C3,
	0xD1D1: 0x65C4,
	0xAEC8: 0x65C5,
	0xD1CF: 0x65C6,
	0xFFFD: 0x65C7,
	0xFFFD: 0x65C8,
	0xFFFD: 0x65C9,
	0xFFFD: 0x65CA,
	0xB1DB: 0x65CB,
	0xB1DC: 0x65CC,
	0xD5A8: 0x65CD,
	0xB1DD: 0x65CE,
	0xB1DA: 0x65CF,
	0xD97D: 0x65D0,
	0x9AC4: 0x65D1,
	0xD97E: 0x65D2,
	0xDDBE: 0x65D3,
	0x9AC5: 0x65D4,
	0xFFFD: 0x65D5,
	0xBA59: 0x65D6,
	0xBA58: 0x65D7,
	0xFFFD: 0x65D8,
	0x90CC: 0x65D9,
	0xECF1: 0x65DA,
	0xEFD9: 0x65DB,
	0xFFFD: 0x65DC,
	0xF24A: 0x65DD,
	0xF249: 0x65DE,
	0xF44F: 0x65DF,
	0xC6D3: 0x65E0,
	0xC95E: 0x65E1,
	0xAC4A: 0x65E2,
	0x9AC6: 0x65E3,
	0xFFFD: 0x65E4,
	0xA4E9: 0x65E5,
	0xA5B9: 0x65E6,
	0x8AF6: 0x65E7,
	0xA6AE: 0x65E8,
	0xA6AD: 0x65E9,
	0xFFFD: 0x65EA,
	0xFFFD: 0x65EB,
	0xA6AF: 0x65EC,
	0xA6B0: 0x65ED,
	0xC9EE: 0x65EE,
	0xC9ED: 0x65EF,
	0xCAF8: 0x65F0,
	0xA7F2: 0x65F1,
	0xCAFB: 0x65F2,
	0xCAFA: 0x65F3,
	0xCAF9: 0x65F4,
	0xCAFC: 0x65F5,
	0x83BA: 0x65F6,
	0x8B77: 0x65F7,
	0x85D0: 0x65F8,
	0xFFFD: 0x65F9,
	0xA9F4: 0x65FA,
	0xCCC9: 0x65FB,
	0xCCC5: 0x65FC,
	0xCCCE: 0x65FD,
	0xFFFD: 0x65FE,
	0x9AC7: 0x65FF,
	0xA9FB: 0x6600,
	0xFFFD: 0x6601,
	0xA9F9: 0x6602,
	0xCCCA: 0x6603,
	0xCCC6: 0x6604,
	0xCCCD: 0x6605,
	0xA9F8: 0x6606,
	0xAA40: 0x6607,
	0xCCC8: 0x6608,
	0xCCC4: 0x6609,
	0xA9FE: 0x660A,
	0xCCCB: 0x660B,
	0xA9F7: 0x660C,
	0xCCCC: 0x660D,
	0xA9FA: 0x660E,
	0xA9FC: 0x660F,
	0xCCD0: 0x6610,
	0xCCCF: 0x6611,
	0xCCC7: 0x6612,
	0xA9F6: 0x6613,
	0xA9F5: 0x6614,
	0xA9FD: 0x6615,
	0xFFFD: 0x6616,
	0xFFFD: 0x6617,
	0x9AC8: 0x6618,
	0x88E8: 0x6619,
	0xFFFD: 0x661A,
	0xFFFD: 0x661B,
	0xCEEF: 0x661C,
	0xCEF5: 0x661D,
	0x90CD: 0x661E,
	0xAC50: 0x661F,
	0xAC4D: 0x6620,
	0xCEEC: 0x6621,
	0xCEF1: 0x6622,
	0x9AC9: 0x6623,
	0xAC53: 0x6624,
	0xAC4B: 0x6625,
	0xCEF0: 0x6626,
	0xAC4E: 0x6627,
	0xAC51: 0x6628,
	0xFFFD: 0x6629,
	0xFFFD: 0x662A,
	0xCEF3: 0x662B,
	0xFFFD: 0x662C,
	0xAC4C: 0x662D,
	0xCEF8: 0x662E,
	0xAC4F: 0x662F,
	0x95FE: 0x6630,
	0xAC52: 0x6631,
	0xCEED: 0x6632,
	0xCEF2: 0x6633,
	0xCEF6: 0x6634,
	0xCEEE: 0x6635,
	0xCEEB: 0x6636,
	0xFFFD: 0x6637,
	0xFFFD: 0x6638,
	0xCEF7: 0x6639,
	0xCEF4: 0x663A,
	0x90CE: 0x663B,
	0x8454: 0x663C,
	0xFFFD: 0x663D,
	0x8D46: 0x663E,
	0x90CF: 0x663F,
	0xFFFD: 0x6640,
	0xAED0: 0x6641,
	0xAEC9: 0x6642,
	0xAECC: 0x6643,
	0x90D0: 0x6644,
	0xAECF: 0x6645,
	0xFFFD: 0x6646,
	0xD1D5: 0x6647,
	0xFC62: 0x6648,
	0xAECA: 0x6649,
	0xD1D3: 0x664A,
	0x83BB: 0x664B,
	0xAECE: 0x664C,
	0x9D59: 0x664D,
	0xFFFD: 0x664E,
	0xAECB: 0x664F,
	0xFFFD: 0x6650,
	0xD1D6: 0x6651,
	0xAECD: 0x6652,
	0x88E6: 0x6653,
	0x88E7: 0x6654,
	0x85CF: 0x6655,
	0x85CE: 0x6656,
	0x90D1: 0x6657,
	0xFFFD: 0x6658,
	0xD5AC: 0x6659,
	0xB1DF: 0x665A,
	0xD5AB: 0x665B,
	0xD5AD: 0x665C,
	0xB1DE: 0x665D,
	0xB1E3: 0x665E,
	0xD1D4: 0x665F,
	0xFFFD: 0x6660,
	0xD5AA: 0x6661,
	0xD5AE: 0x6662,
	0x9ACA: 0x6663,
	0xB1E0: 0x6664,
	0xD5A9: 0x6665,
	0xB1E2: 0x6666,
	0xFC63: 0x6667,
	0xB1E1: 0x6668,
	0x90D2: 0x6669,
	0xD9A7: 0x666A,
	0x9ACB: 0x666B,
	0xD9A2: 0x666C,
	0xFFFD: 0x666D,
	0xB4B6: 0x666E,
	0xB4BA: 0x666F,
	0xB4B7: 0x6670,
	0xD9A5: 0x6671,
	0xD9A8: 0x6672,
	0x90D3: 0x6673,
	0xB4B8: 0x6674,
	0xFFFD: 0x6675,
	0xB4B9: 0x6676,
	0xB4BE: 0x6677,
	0xDDC7: 0x6678,
	0xD9A6: 0x6679,
	0xB4BC: 0x667A,
	0xD9A3: 0x667B,
	0xD9A1: 0x667C,
	0x9ACC: 0x667D,
	0xB4BD: 0x667E,
	0xFFFD: 0x667F,
	0xD9A4: 0x6680,
	0x927D: 0x6681,
	0x87DC: 0x6682,
	0x90D4: 0x6683,
	0xB779: 0x6684,
	0x9ACD: 0x6685,
	0xDDBF: 0x6686,
	0xB776: 0x6687,
	0xB777: 0x6688,
	0xB775: 0x6689,
	0xDDC4: 0x668A,
	0xDDC3: 0x668B,
	0xDDC0: 0x668C,
	0xB77B: 0x668D,
	0xFE7A: 0x668E,
	0xFFFD: 0x668F,
	0xDDC2: 0x6690,
	0xB4BB: 0x6691,
	0x9ACE: 0x6692,
	0xFFFD: 0x6693,
	0xDDC6: 0x6694,
	0xDDC1: 0x6695,
	0xB778: 0x6696,
	0xB774: 0x6697,
	0xB77A: 0x6698,
	0xDDC5: 0x6699,
	0x9ACF: 0x669A,
	0xFFFD: 0x669B,
	0xFFFD: 0x669C,
	0xBA5C: 0x669D,
	0xFFFD: 0x669E,
	0xE1F8: 0x669F,
	0xE1F7: 0x66A0,
	0xE1F6: 0x66A1,
	0xBA5A: 0x66A2,
	0xFFFD: 0x66A3,
	0x9AD0: 0x66A4,
	0xFFFD: 0x66A5,
	0x93EF: 0x66A6,
	0x89E2: 0x66A7,
	0xBA5B: 0x66A8,
	0xE5C5: 0x66A9,
	0xE5C8: 0x66AA,
	0xBCC8: 0x66AB,
	0xFFFD: 0x66AC,
	0x9AD1: 0x66AD,
	0xBCC7: 0x66AE,
	0xE5C9: 0x66AF,
	0xE5C4: 0x66B0,
	0xBCCA: 0x66B1,
	0xE5C6: 0x66B2,
	0x9AD2: 0x66B3,
	0xBCC9: 0x66B4,
	0xE5C3: 0x66B5,
	0x9AD3: 0x66B6,
	0xE5C7: 0x66B7,
	0xBEE9: 0x66B8,
	0xBEE6: 0x66B9,
	0xE9BB: 0x66BA,
	0xE9BA: 0x66BB,
	0x90D5: 0x66BC,
	0xE9B9: 0x66BD,
	0xE9B4: 0x66BE,
	0x90D6: 0x66BF,
	0xE9B5: 0x66C0,
	0x90D7: 0x66C1,
	0xFFFD: 0x66C2,
	0xFFFD: 0x66C3,
	0xBEE7: 0x66C4,
	0xFFFD: 0x66C5,
	0xBEE4: 0x66C6,
	0xBEE8: 0x66C7,
	0xE9B3: 0x66C8,
	0xBEE5: 0x66C9,
	0xE9B6: 0x66CA,
	0xE9B7: 0x66CB,
	0xE9BC: 0x66CC,
	0x9AD4: 0x66CD,
	0x9AD5: 0x66CE,
	0xE9B8: 0x66CF,
	0xFFFD: 0x66D0,
	0xFFFD: 0x66D1,
	0xECF2: 0x66D2,
	0xFFFD: 0x66D3,
	0xFFFD: 0x66D4,
	0xFFFD: 0x66D5,
	0xC0C7: 0x66D6,
	0xFFFD: 0x66D7,
	0xEFDC: 0x66D8,
	0xC0C6: 0x66D9,
	0xEFDA: 0x66DA,
	0xEFDB: 0x66DB,
	0xC260: 0x66DC,
	0xC36E: 0x66DD,
	0xF24B: 0x66DE,
	0xFFFD: 0x66DF,
	0xC36D: 0x66E0,
	0xFFFD: 0x66E1,
	0xFFFD: 0x66E2,
	0xF451: 0x66E3,
	0xF452: 0x66E4,
	0xFFFD: 0x66E5,
	0xC466: 0x66E6,
	0x9DCA: 0x66E7,
	0xF450: 0x66E8,
	0xC4E4: 0x66E9,
	0xFFFD: 0x66EA,
	0xF7DF: 0x66EB,
	0xC5CE: 0x66EC,
	0xF8AA: 0x66ED,
	0xF8AB: 0x66EE,
	0xFFFD: 0x66EF,
	0xA4EA: 0x66F0,
	0xA058: 0x66F1,
	0xA6B1: 0x66F2,
	0xA6B2: 0x66F3,
	0xA7F3: 0x66F4,
	0x90D8: 0x66F5,
	0xCCD1: 0x66F6,
	0xAC54: 0x66F7,
	0xAED1: 0x66F8,
	0xB1E4: 0x66F9,
	0x90D9: 0x66FA,
	0x90DA: 0x66FB,
	0xB0D2: 0x66FC,
	0x93FB: 0x66FD,
	0xB4BF: 0x66FE,
	0xB4C0: 0x66FF,
	0xB3CC: 0x6700,
	0xD9A9: 0x6701,
	0x9AD6: 0x6702,
	0xB77C: 0x6703,
	0xE1FA: 0x6704,
	0xE1F9: 0x6705,
	0xFFFD: 0x6706,
	0xFFFD: 0x6707,
	0xA4EB: 0x6708,
	0xA6B3: 0x6709,
	0xCCD2: 0x670A,
	0xAA42: 0x670B,
	0x9AD7: 0x670C,
	0xAA41: 0x670D,
	0x90DB: 0x670E,
	0xCEF9: 0x670F,
	0xCEFA: 0x6710,
	0xFFFD: 0x6711,
	0xD1D7: 0x6712,
	0xD1D8: 0x6713,
	0xAED2: 0x6714,
	0xAED3: 0x6715,
	0x90DC: 0x6716,
	0xAED4: 0x6717,
	0xD5AF: 0x6718,
	0x9AD8: 0x6719,
	0xFFFD: 0x671A,
	0xB1E6: 0x671B,
	0xFFFD: 0x671C,
	0xB4C2: 0x671D,
	0xFC64: 0x671E,
	0xB4C1: 0x671F,
	0xDDC8: 0x6720,
	0xDF7A: 0x6721,
	0xE1FB: 0x6722,
	0xE9BD: 0x6723,
	0xFFFD: 0x6724,
	0xFE5E: 0x6725,
	0xC261: 0x6726,
	0xC467: 0x6727,
	0xA4EC: 0x6728,
	0x91D1: 0x6729,
	0xA5BC: 0x672A,
	0xA5BD: 0x672B,
	0xA5BB: 0x672C,
	0xA5BE: 0x672D,
	0xA5BA: 0x672E,
	0x847B: 0x672F,
	0xFFFD: 0x6730,
	0xA6B6: 0x6731,
	0xFFFD: 0x6732,
	0xC9F6: 0x6733,
	0xA6B5: 0x6734,
	0xA6B7: 0x6735,
	0x957C: 0x6736,
	0x90DD: 0x6737,
	0xC9F1: 0x6738,
	0xC9F0: 0x6739,
	0xC9F3: 0x673A,
	0xC9F2: 0x673B,
	0xC9F5: 0x673C,
	0xA6B4: 0x673D,
	0xC9EF: 0x673E,
	0xC9F4: 0x673F,
	0x8459: 0x6740,
	0x9478: 0x6741,
	0x8B59: 0x6742,
	0x8CD0: 0x6743,
	0x9AD9: 0x6744,
	0xCAFD: 0x6745,
	0xA7FD: 0x6746,
	0xCAFE: 0x6747,
	0xCB43: 0x6748,
	0xA7FC: 0x6749,
	0xFFFD: 0x674A,
	0xCB47: 0x674B,
	0xCB42: 0x674C,
	0xCB45: 0x674D,
	0xA7F5: 0x674E,
	0xA7F6: 0x674F,
	0xA7F7: 0x6750,
	0xA7F8: 0x6751,
	0xFFFD: 0x6752,
	0xA840: 0x6753,
	0xFFFD: 0x6754,
	0xCB41: 0x6755,
	0xA7FA: 0x6756,
	0xA841: 0x6757,
	0xFFFD: 0x6758,
	0xCB40: 0x6759,
	0xCB46: 0x675A,
	0xFFFD: 0x675B,
	0xA7F9: 0x675C,
	0xCB44: 0x675D,
	0xA7FB: 0x675E,
	0xA7F4: 0x675F,
	0xA7FE: 0x6760,
	0x8457: 0x6761,
	0x945C: 0x6762,
	0x9479: 0x6763,
	0x90DE: 0x6764,
	0x8353: 0x6765,
	0x90DF: 0x6766,
	0xFBA6: 0x6767,
	0x85D4: 0x6768,
	0x8E72: 0x6769,
	0xAA57: 0x676A,
	0x9ADA: 0x676B,
	0xCCD4: 0x676C,
	0xAA43: 0x676D,
	0x9D72: 0x676E,
	0xAA4D: 0x676F,
	0xAA4E: 0x6770,
	0xAA46: 0x6771,
	0xAA58: 0x6772,
	0xAA48: 0x6773,
	0xCCDC: 0x6774,
	0xAA53: 0x6775,
	0xCCD7: 0x6776,
	0xAA49: 0x6777,
	0xCCE6: 0x6778,
	0xCCE7: 0x6779,
	0xCCDF: 0x677A,
	0xCCD8: 0x677B,
	0xAA56: 0x677C,
	0xCCE4: 0x677D,
	0xAA51: 0x677E,
	0xAA4F: 0x677F,
	0xFFFD: 0x6780,
	0xCCE5: 0x6781,
	0xFFFD: 0x6782,
	0xCCE3: 0x6783,
	0xCCDB: 0x6784,
	0xCCD3: 0x6785,
	0xCCDA: 0x6786,
	0xAA4A: 0x6787,
	0xFFFD: 0x6788,
	0xAA50: 0x6789,
	0xFFFD: 0x678A,
	0xAA44: 0x678B,
	0xCCDE: 0x678C,
	0xCCDD: 0x678D,
	0xCCD5: 0x678E,
	0x9ADB: 0x678F,
	0xAA52: 0x6790,
	0xCCE1: 0x6791,
	0xCCD6: 0x6792,
	0xAA55: 0x6793,
	0xCCE8: 0x6794,
	0xAA45: 0x6795,
	0xFFFD: 0x6796,
	0xAA4C: 0x6797,
	0xCCD9: 0x6798,
	0xCCE2: 0x6799,
	0xAA54: 0x679A,
	0xFFFD: 0x679B,
	0xAA47: 0x679C,
	0xAA4B: 0x679D,
	0x87E5: 0x679E,
	0xCCE0: 0x679F,
	0x94FD: 0x67A0,
	0x947A: 0x67A1,
	0x87E0: 0x67A2,
	0x84E5: 0x67A3,
	0x9ADC: 0x67A4,
	0x8FDC: 0x67A5,
	0x90E0: 0x67A6,
	0x90E1: 0x67A7,
	0x8DDF: 0x67A8,
	0x90E2: 0x67A9,
	0x86D2: 0x67AA,
	0x85D6: 0x67AB,
	0xFC66: 0x67AC,
	0x8458: 0x67AD,
	0xCF5B: 0x67AE,
	0xAC5C: 0x67AF,
	0xAC69: 0x67B0,
	0x9545: 0x67B1,
	0xCF56: 0x67B2,
	0xCF4C: 0x67B3,
	0xAC62: 0x67B4,
	0xCF4A: 0x67B5,
	0xAC5B: 0x67B6,
	0xCF45: 0x67B7,
	0xAC65: 0x67B8,
	0xCF52: 0x67B9,
	0xCEFE: 0x67BA,
	0xCF41: 0x67BB,
	0xFFFD: 0x67BC,
	0xFFFD: 0x67BD,
	0xFFFD: 0x67BE,
	0x9ADD: 0x67BF,
	0xCF44: 0x67C0,
	0xCEFB: 0x67C1,
	0xCF51: 0x67C2,
	0xCF61: 0x67C3,
	0xAC60: 0x67C4,
	0xCF46: 0x67C5,
	0xCF58: 0x67C6,
	0xFFFD: 0x67C7,
	0xCEFD: 0x67C8,
	0xCF5F: 0x67C9,
	0xCF60: 0x67CA,
	0xCF63: 0x67CB,
	0xCF5A: 0x67CC,
	0xCF4B: 0x67CD,
	0xCF53: 0x67CE,
	0xAC66: 0x67CF,
	0xAC59: 0x67D0,
	0xAC61: 0x67D1,
	0xAC6D: 0x67D2,
	0xAC56: 0x67D3,
	0xAC58: 0x67D4,
	0xFFFD: 0x67D5,
	0x9ADE: 0x67D6,
	0x9ADF: 0x67D7,
	0xCF43: 0x67D8,
	0xAC6A: 0x67D9,
	0xAC63: 0x67DA,
	0xCF5D: 0x67DB,
	0xCF40: 0x67DC,
	0xAC6C: 0x67DD,
	0xAC67: 0x67DE,
	0xCF49: 0x67DF,
	0x8ACE: 0x67E0,
	0xFFFD: 0x67E1,
	0xAC6B: 0x67E2,
	0xCF50: 0x67E3,
	0xCF48: 0x67E4,
	0xAC64: 0x67E5,
	0xCF5C: 0x67E6,
	0xCF54: 0x67E7,
	0xFFFD: 0x67E8,
	0xAC5E: 0x67E9,
	0xCF62: 0x67EA,
	0xCF47: 0x67EB,
	0xAC5A: 0x67EC,
	0xCF59: 0x67ED,
	0xCF4F: 0x67EE,
	0xAC5F: 0x67EF,
	0xCF55: 0x67F0,
	0xAC57: 0x67F1,
	0xCEFC: 0x67F2,
	0xAC68: 0x67F3,
	0xAEE3: 0x67F4,
	0xAC5D: 0x67F5,
	0xCF4E: 0x67F6,
	0xCF4D: 0x67F7,
	0xCF42: 0x67F8,
	0xFC67: 0x67F9,
	0xCF5E: 0x67FA,
	0x90E3: 0x67FB,
	0xCF57: 0x67FC,
	0x90E4: 0x67FD,
	0x945A: 0x67FE,
	0xAC55: 0x67FF,
	0x90E5: 0x6800,
	0x90E6: 0x6801,
	0x944D: 0x6802,
	0x9451: 0x6803,
	0x9248: 0x6804,
	0x90E7: 0x6805,
	0xFFFD: 0x6806,
	0x87E1: 0x6807,
	0x84E7: 0x6808,
	0x89E6: 0x6809,
	0x8FDB: 0x680A,
	0x84E6: 0x680B,
	0x8FDD: 0x680C,
	0x9AE1: 0x680D,
	0x8FBA: 0x680E,
	0x8C77: 0x680F,
	0x9AE2: 0x6810,
	0x88EB: 0x6811,
	0xD1EC: 0x6812,
	0xAEEA: 0x6813,
	0xD1ED: 0x6814,
	0xFFFD: 0x6815,
	0xD1E1: 0x6816,
	0xAEDF: 0x6817,
	0xAEEB: 0x6818,
	0xFFFD: 0x6819,
	0xD1DA: 0x681A,
	0x9AE3: 0x681B,
	0xD1E3: 0x681C,
	0xD1EB: 0x681D,
	0x90E8: 0x681E,
	0xD1D9: 0x681F,
	0xD1F4: 0x6820,
	0xAED5: 0x6821,
	0xFE45: 0x6822,
	0xFFFD: 0x6823,
	0xFFFD: 0x6824,
	0xD1F3: 0x6825,
	0xD1EE: 0x6826,
	0xFFFD: 0x6827,
	0xD1EF: 0x6828,
	0xAEDD: 0x6829,
	0xAEE8: 0x682A,
	0xD1E5: 0x682B,
	0xFFFD: 0x682C,
	0xD1E6: 0x682D,
	0xD1F0: 0x682E,
	0xD1E7: 0x682F,
	0xFFFD: 0x6830,
	0xD1E2: 0x6831,
	0xD1DC: 0x6832,
	0xD1DD: 0x6833,
	0xD1EA: 0x6834,
	0xD1E4: 0x6835,
	0x9AE4: 0x6836,
	0x87DE: 0x6837,
	0xAED6: 0x6838,
	0xAEDA: 0x6839,
	0xD1F2: 0x683A,
	0xD1DE: 0x683B,
	0xAEE6: 0x683C,
	0xAEE2: 0x683D,
	0x906A: 0x683E,
	0xFFFD: 0x683F,
	0xAEE5: 0x6840,
	0xAEEC: 0x6841,
	0xAEDB: 0x6842,
	0xAEE7: 0x6843,
	0xD1E9: 0x6844,
	0xAEE9: 0x6845,
	0xAED8: 0x6846,
	0x9AE5: 0x6847,
	0xAED7: 0x6848,
	0xD1DB: 0x6849,
	0x90E9: 0x684A,
	0xD1DF: 0x684B,
	0xAEE0: 0x684C,
	0xD1F1: 0x684D,
	0xD1E8: 0x684E,
	0xD1E0: 0x684F,
	0xAEE4: 0x6850,
	0xAEE1: 0x6851,
	0x90EA: 0x6852,
	0xAED9: 0x6853,
	0xAEDC: 0x6854,
	0x90EB: 0x6855,
	0x9AE6: 0x6856,
	0xFFFD: 0x6857,
	0xFFFD: 0x6858,
	0x90EC: 0x6859,
	0xFFFD: 0x685A,
	0xFFFD: 0x685B,
	0x9251: 0x685C,
	0x827C: 0x685D,
	0xFFFD: 0x685E,
	0x92CC: 0x685F,
	0x8DDE: 0x6860,
	0x88EF: 0x6861,
	0x85D5: 0x6862,
	0x89E3: 0x6863,
	0x8E71: 0x6864,
	0x88ED: 0x6865,
	0x88E9: 0x6866,
	0x89E5: 0x6867,
	0x87E3: 0x6868,
	0x87DF: 0x6869,
	0xFFFD: 0x686A,
	0xD5C4: 0x686B,
	0xFFFD: 0x686C,
	0xD5B4: 0x686D,
	0xD5B5: 0x686E,
	0xD5B9: 0x686F,
	0xFFFD: 0x6870,
	0xD5C8: 0x6871,
	0xD5C5: 0x6872,
	0xFFFD: 0x6873,
	0xD5BE: 0x6874,
	0xD5BD: 0x6875,
	0xB1ED: 0x6876,
	0xD5C1: 0x6877,
	0xD5D0: 0x6878,
	0xD5B0: 0x6879,
	0xFFFD: 0x687A,
	0xD5D1: 0x687B,
	0xD5C3: 0x687C,
	0xD5D5: 0x687D,
	0xD5C9: 0x687E,
	0xB1EC: 0x687F,
	0xD5C7: 0x6880,
	0xB1E7: 0x6881,
	0xB1FC: 0x6882,
	0xB1F2: 0x6883,
	0x9AE7: 0x6884,
	0xB1F6: 0x6885,
	0xB1F5: 0x6886,
	0xD5B1: 0x6887,
	0x9AE8: 0x6888,
	0xD5CE: 0x6889,
	0xD5D4: 0x688A,
	0xD5CC: 0x688B,
	0xD5D3: 0x688C,
	0x90ED: 0x688D,
	0xFFFD: 0x688E,
	0xD5C0: 0x688F,
	0xD5B2: 0x6890,
	0xD5D2: 0x6891,
	0xD5C2: 0x6892,
	0xB1EA: 0x6893,
	0xB1F7: 0x6894,
	0xFFFD: 0x6895,
	0xD5CB: 0x6896,
	0xB1F0: 0x6897,
	0xFB58: 0x6898,
	0xFFFD: 0x6899,
	0xFFFD: 0x689A,
	0xD5CA: 0x689B,
	0xD5B3: 0x689C,
	0xB1F8: 0x689D,
	0xFFFD: 0x689E,
	0xB1FA: 0x689F,
	0xD5CD: 0x68A0,
	0xB1FB: 0x68A1,
	0xB1E9: 0x68A2,
	0xD5BA: 0x68A3,
	0xD5CF: 0x68A4,
	0xFFFD: 0x68A5,
	0x86BB: 0x68A6,
	0xB1EF: 0x68A7,
	0xB1F9: 0x68A8,
	0xD5BC: 0x68A9,
	0xD5C6: 0x68AA,
	0xD5B7: 0x68AB,
	0xD5BB: 0x68AC,
	0xB1F4: 0x68AD,
	0xD5B6: 0x68AE,
	0xB1E8: 0x68AF,
	0xB1F1: 0x68B0,
	0xB1EE: 0x68B1,
	0xD5BF: 0x68B2,
	0xAEDE: 0x68B3,
	0xD9C0: 0x68B4,
	0xB1EB: 0x68B5,
	0xFC68: 0x68B6,
	0xFFFD: 0x68B7,
	0xFFFD: 0x68B8,
	0x90EE: 0x68B9,
	0x947B: 0x68BA,
	0xFFFD: 0x68BB,
	0x826F: 0x68BC,
	0x9AE9: 0x68BD,
	0xFFFD: 0x68BE,
	0xFFFD: 0x68BF,
	0x89E4: 0x68C0,
	0xFFFD: 0x68C1,
	0x8C78: 0x68C2,
	0x9AEA: 0x68C3,
	0xB1F3: 0x68C4,
	0x9AEB: 0x68C5,
	0xD9C3: 0x68C6,
	0xD9D9: 0x68C7,
	0xD9CE: 0x68C8,
	0xB4D6: 0x68C9,
	0xFC6C: 0x68CA,
	0xB4D1: 0x68CB,
	0xD9BD: 0x68CC,
	0xB4D2: 0x68CD,
	0xD9CD: 0x68CE,
	0x90EF: 0x68CF,
	0xD9C6: 0x68D0,
	0xD9D3: 0x68D1,
	0xB4CE: 0x68D2,
	0xD9AB: 0x68D3,
	0xD9D5: 0x68D4,
	0xB4C4: 0x68D5,
	0xD9B3: 0x68D6,
	0xB4C7: 0x68D7,
	0xB4C6: 0x68D8,
	0xFFFD: 0x68D9,
	0xB4D7: 0x68DA,
	0xFFFD: 0x68DB,
	0xD9AD: 0x68DC,
	0xD9CF: 0x68DD,
	0xD9D0: 0x68DE,
	0xB4C9: 0x68DF,
	0xB4C5: 0x68E0,
	0xD9BB: 0x68E1,
	0xFFFD: 0x68E2,
	0xB4D0: 0x68E3,
	0xD9B6: 0x68E4,
	0xFFFD: 0x68E5,
	0xD9D1: 0x68E6,
	0xB4CC: 0x68E7,
	0xD9C9: 0x68E8,
	0xD9D6: 0x68E9,
	0xD9B0: 0x68EA,
	0xD9B5: 0x68EB,
	0xD9AF: 0x68EC,
	0xFFFD: 0x68ED,
	0xB4CB: 0x68EE,
	0xD9C2: 0x68EF,
	0xDDDE: 0x68F0,
	0xD9B1: 0x68F1,
	0xB4CF: 0x68F2,
	0xD9BA: 0x68F3,
	0xD9D2: 0x68F4,
	0xB4CA: 0x68F5,
	0xD9B7: 0x68F6,
	0xD9B4: 0x68F7,
	0xD9C5: 0x68F8,
	0xB4CD: 0x68F9,
	0xB4C3: 0x68FA,
	0xB4D9: 0x68FB,
	0xD9C8: 0x68FC,
	0xD9C7: 0x68FD,
	0xFFFD: 0x68FE,
	0xFFFD: 0x68FF,
	0xFC6B: 0x6900,
	0xFC6A: 0x6901,
	0x9AEC: 0x6902,
	0x9AED: 0x6903,
	0xD9AC: 0x6904,
	0xB4C8: 0x6905,
	0xD9D4: 0x6906,
	0xD9BC: 0x6907,
	0xD9BE: 0x6908,
	0x9AEE: 0x6909,
	0xD9CB: 0x690A,
	0xD9CA: 0x690B,
	0xD9AA: 0x690C,
	0xB4D3: 0x690D,
	0xB4D5: 0x690E,
	0xD9B2: 0x690F,
	0xD9B9: 0x6910,
	0xD9C1: 0x6911,
	0xB4D4: 0x6912,
	0xD9B8: 0x6913,
	0xD9C4: 0x6914,
	0xD9D7: 0x6915,
	0xFFFD: 0x6916,
	0xD9CC: 0x6917,
	0x9AEF: 0x6918,
	0x9449: 0x6919,
	0xFE4F: 0x691A,
	0x9441: 0x691B,
	0x92B6: 0x691C,
	0xFFFD: 0x691D,
	0xFFFD: 0x691E,
	0x8B79: 0x691F,
	0x8EB8: 0x6920,
	0x94A2: 0x6921,
	0x90F3: 0x6922,
	0x94A1: 0x6923,
	0x906B: 0x6924,
	0xD9D8: 0x6925,
	0x90F4: 0x6926,
	0xFFFD: 0x6927,
	0x947D: 0x6928,
	0xFFFD: 0x6929,
	0xD9AE: 0x692A,
	0xFFFD: 0x692B,
	0xFC69: 0x692C,
	0x88EC: 0x692D,
	0xFFFD: 0x692E,
	0xDDF2: 0x692F,
	0xB7A6: 0x6930,
	0xFFFD: 0x6931,
	0xDDF0: 0x6932,
	0xDDDB: 0x6933,
	0xDDE0: 0x6934,
	0xDDD9: 0x6935,
	0x90FD: 0x6936,
	0xDDEC: 0x6937,
	0xDDCB: 0x6938,
	0xDDD2: 0x6939,
	0xFFFD: 0x693A,
	0xDDEA: 0x693B,
	0xDDF4: 0x693C,
	0xDDDC: 0x693D,
	0xFC6F: 0x693E,
	0xDDCF: 0x693F,
	0xDDE2: 0x6940,
	0xDDE7: 0x6941,
	0xDDD3: 0x6942,
	0x9AF0: 0x6943,
	0xDDE4: 0x6944,
	0xDDD0: 0x6945,
	0x9AF1: 0x6946,
	0xFFFD: 0x6947,
	0xDDD7: 0x6948,
	0xDDD8: 0x6949,
	0xB7A8: 0x694A,
	0xDDEB: 0x694B,
	0xDDE9: 0x694C,
	0xFFFD: 0x694D,
	0xDDCC: 0x694E,
	0xDDEE: 0x694F,
	0xFFFD: 0x6950,
	0xDDEF: 0x6951,
	0xDDF1: 0x6952,
	0xB7AC: 0x6953,
	0xB7A4: 0x6954,
	0x826C: 0x6955,
	0xD5B8: 0x6956,
	0xDDD4: 0x6957,
	0xDDE6: 0x6958,
	0xDDD5: 0x6959,
	0xB7A1: 0x695A,
	0xB7B1: 0x695B,
	0xDDED: 0x695C,
	0xB7AF: 0x695D,
	0xB7AB: 0x695E,
	0xDDCA: 0x695F,
	0xB7A3: 0x6960,
	0x90FE: 0x6961,
	0xDDCD: 0x6962,
	0xB7B0: 0x6963,
	0x9AF2: 0x6964,
	0xDDDD: 0x6965,
	0xDDC9: 0x6966,
	0x9AF3: 0x6967,
	0xB7A9: 0x6968,
	0xDDE1: 0x6969,
	0xDDD1: 0x696A,
	0xB7AA: 0x696B,
	0xDDDA: 0x696C,
	0xB77E: 0x696D,
	0xB4D8: 0x696E,
	0xDDE3: 0x696F,
	0xD9BF: 0x6970,
	0xDDCE: 0x6971,
	0x9AF4: 0x6972,
	0xFC6D: 0x6973,
	0xDDE8: 0x6974,
	0xB7A5: 0x6975,
	0xDDE5: 0x6976,
	0xB7A2: 0x6977,
	0xDDDF: 0x6978,
	0xB7AD: 0x6979,
	0xDDD6: 0x697A,
	0xDDF3: 0x697B,
	0x87E2: 0x697C,
	0x9262: 0x697D,
	0x94A3: 0x697E,
	0xFFFD: 0x697F,
	0xFC6E: 0x6980,
	0x94A4: 0x6981,
	0xB7A7: 0x6982,
	0xDEC6: 0x6983,
	0x8D6E: 0x6984,
	0x9AF5: 0x6985,
	0xB7AE: 0x6986,
	0x8BF9: 0x6987,
	0x8B7A: 0x6988,
	0x9040: 0x6989,
	0x9445: 0x698A,
	0xFFFD: 0x698B,
	0xFFFD: 0x698C,
	0xE24A: 0x698D,
	0xE248: 0x698E,
	0xFFFD: 0x698F,
	0xE25E: 0x6990,
	0xE246: 0x6991,
	0xFFFD: 0x6992,
	0xE258: 0x6993,
	0xB77D: 0x6994,
	0xBA5F: 0x6995,
	0xE242: 0x6996,
	0xE25D: 0x6997,
	0x9567: 0x6998,
	0xE247: 0x6999,
	0xE255: 0x699A,
	0xBA64: 0x699B,
	0xBA5D: 0x699C,
	0xFFFD: 0x699D,
	0xE25B: 0x699E,
	0x9AF6: 0x699F,
	0xE240: 0x69A0,
	0xE25A: 0x69A1,
	0x9AF7: 0x69A2,
	0xBA6F: 0x69A3,
	0xE251: 0x69A4,
	0xE261: 0x69A5,
	0xBA6D: 0x69A6,
	0xE249: 0x69A7,
	0xBA5E: 0x69A8,
	0xE24B: 0x69A9,
	0xE259: 0x69AA,
	0xBA67: 0x69AB,
	0xE244: 0x69AC,
	0xBA6B: 0x69AD,
	0xBA61: 0x69AE,
	0xE24D: 0x69AF,
	0xE243: 0x69B0,
	0xE1FC: 0x69B1,
	0xFC71: 0x69B2,
	0xE257: 0x69B3,
	0xBA68: 0x69B4,
	0xE260: 0x69B5,
	0xE1FD: 0x69B6,
	0xBA65: 0x69B7,
	0xFFFD: 0x69B8,
	0xE253: 0x69B9,
	0xFFFD: 0x69BA,
	0xBA66: 0x69BB,
	0xE245: 0x69BC,
	0xE250: 0x69BD,
	0xE24C: 0x69BE,
	0xE24E: 0x69BF,
	0xFC72: 0x69C0,
	0xBA60: 0x69C1,
	0xE25F: 0x69C2,
	0xBA6E: 0x69C3,
	0xE24F: 0x69C4,
	0xFFFD: 0x69C5,
	0xE262: 0x69C6,
	0x91EE: 0x69C7,
	0xFFFD: 0x69C8,
	0xE1FE: 0x69C9,
	0xE254: 0x69CA,
	0xBA63: 0x69CB,
	0xBA6C: 0x69CC,
	0xBA6A: 0x69CD,
	0xE241: 0x69CE,
	0xE256: 0x69CF,
	0xBA69: 0x69D0,
	0x9AF8: 0x69D1,
	0xFFFD: 0x69D2,
	0xBA62: 0x69D3,
	0xE252: 0x69D4,
	0x9AF9: 0x69D5,
	0x9AFA: 0x69D6,
	0xFFFD: 0x69D7,
	0x93DB: 0x69D8,
	0xE25C: 0x69D9,
	0xFFFD: 0x69DA,
	0x8ACD: 0x69DB,
	0xFFFD: 0x69DC,
	0x94A5: 0x69DD,
	0x967D: 0x69DE,
	0x8ACB: 0x69DF,
	0x8FB9: 0x69E0,
	0x9B41: 0x69E1,
	0xE5D5: 0x69E2,
	0xFFFD: 0x69E3,
	0xE5D1: 0x69E4,
	0xE5CD: 0x69E5,
	0xE5E1: 0x69E6,
	0xE5DE: 0x69E7,
	0xBCCD: 0x69E8,
	0xFC75: 0x69E9,
	0xFFFD: 0x69EA,
	0xE5E5: 0x69EB,
	0xE5D4: 0x69EC,
	0xBCD8: 0x69ED,
	0xE5DB: 0x69EE,
	0xFFFD: 0x69EF,
	0xFFFD: 0x69F0,
	0xE5D0: 0x69F1,
	0xE5DA: 0x69F2,
	0xBCD5: 0x69F3,
	0xE5EE: 0x69F4,
	0xFFFD: 0x69F5,
	0xE5EB: 0x69F6,
	0xE5DD: 0x69F7,
	0xE5CE: 0x69F8,
	0x967E: 0x69F9,
	0xFC74: 0x69FA,
	0xE5E2: 0x69FB,
	0xE5E4: 0x69FC,
	0xBCD1: 0x69FD,
	0xE5D8: 0x69FE,
	0xE5D3: 0x69FF,
	0xE5CA: 0x6A00,
	0xBCCE: 0x6A01,
	0xBCD6: 0x6A02,
	0x9B42: 0x6A03,
	0xE5E7: 0x6A04,
	0xBCD7: 0x6A05,
	0xE5CB: 0x6A06,
	0xE5ED: 0x6A07,
	0xE5E0: 0x6A08,
	0xE5E6: 0x6A09,
	0xBCD4: 0x6A0A,
	0xFE54: 0x6A0B,
	0x96CE: 0x6A0C,
	0xE5E3: 0x6A0D,
	0xFFFD: 0x6A0E,
	0xE5EA: 0x6A0F,
	0xFFFD: 0x6A10,
	0xBCD9: 0x6A11,
	0x96EB: 0x6A12,
	0xBCD3: 0x6A13,
	0xE5DC: 0x6A14,
	0xE5CF: 0x6A15,
	0xE5EF: 0x6A16,
	0xE5CC: 0x6A17,
	0xE5E8: 0x6A18,
	0xBCD0: 0x6A19,
	0x9B43: 0x6A1A,
	0xE5D6: 0x6A1B,
	0x9B44: 0x6A1C,
	0xE5D7: 0x6A1D,
	0xBCCF: 0x6A1E,
	0xBCCC: 0x6A1F,
	0xE5D2: 0x6A20,
	0xBCD2: 0x6A21,
	0x96EC: 0x6A22,
	0xBCCB: 0x6A23,
	0xFFFD: 0x6A24,
	0xE5E9: 0x6A25,
	0xE5EC: 0x6A26,
	0xE5D9: 0x6A27,
	0xE9CA: 0x6A28,
	0x92B7: 0x6A29,
	0x88EA: 0x6A2A,
	0x9440: 0x6A2B,
	0x9B45: 0x6A2C,
	0x9B46: 0x6A2D,
	0x94A6: 0x6A2E,
	0x89E7: 0x6A2F,
	0x96ED: 0x6A30,
	0x8C76: 0x6A31,
	0xE9C2: 0x6A32,
	0x9B47: 0x6A33,
	0xE9BE: 0x6A34,
	0xBEF6: 0x6A35,
	0x96EE: 0x6A36,
	0xFFFD: 0x6A37,
	0xBEEB: 0x6A38,
	0xBEF0: 0x6A39,
	0xBEEC: 0x6A3A,
	0xE9CC: 0x6A3B,
	0xE9D7: 0x6A3C,
	0xBEEA: 0x6A3D,
	0xE9C4: 0x6A3E,
	0xE9CD: 0x6A3F,
	0xE5DF: 0x6A40,
	0xE9CE: 0x6A41,
	0xFFFD: 0x6A42,
	0x9B48: 0x6A43,
	0xBEF1: 0x6A44,
	0x9B49: 0x6A45,
	0xE9DD: 0x6A46,
	0xBEF5: 0x6A47,
	0xBEF8: 0x6A48,
	0xE9C0: 0x6A49,
	0xFFFD: 0x6A4A,
	0xBEF4: 0x6A4B,
	0x9B4A: 0x6A4C,
	0xE9DB: 0x6A4D,
	0xE9DC: 0x6A4E,
	0xE9D2: 0x6A4F,
	0xE9D1: 0x6A50,
	0xE9C9: 0x6A51,
	0xFC77: 0x6A52,
	0x9B4B: 0x6A53,
	0xE9D3: 0x6A54,
	0xE9DA: 0x6A55,
	0xE9D9: 0x6A56,
	0x9B4C: 0x6A57,
	0xBEEF: 0x6A58,
	0xBEED: 0x6A59,
	0xE9CB: 0x6A5A,
	0xE9C8: 0x6A5B,
	0xFFFD: 0x6A5C,
	0xE9C5: 0x6A5D,
	0xE9D8: 0x6A5E,
	0xBEF7: 0x6A5F,
	0xE9D6: 0x6A60,
	0xBEF3: 0x6A61,
	0xBEF2: 0x6A62,
	0x9B4D: 0x6A63,
	0xE9D0: 0x6A64,
	0x96EF: 0x6A65,
	0xE9BF: 0x6A66,
	0xE9C1: 0x6A67,
	0xE9C3: 0x6A68,
	0xE9D5: 0x6A69,
	0xE9CF: 0x6A6A,
	0xBEEE: 0x6A6B,
	0xFFFD: 0x6A6C,
	0xE9C6: 0x6A6D,
	0xFFFD: 0x6A6E,
	0xE9D4: 0x6A6F,
	0xFFFD: 0x6A70,
	0x8B78: 0x6A71,
	0x94A7: 0x6A72,
	0x96F8: 0x6A73,
	0x9B4E: 0x6A74,
	0xFFFD: 0x6A75,
	0xE9C7: 0x6A76,
	0xFFFD: 0x6A77,
	0x96F9: 0x6A78,
	0x8B7B: 0x6A79,
	0x947E: 0x6A7A,
	0xFFFD: 0x6A7B,
	0x96FC: 0x6A7C,
	0xFFFD: 0x6A7D,
	0xC0CF: 0x6A7E,
	0xED45: 0x6A7F,
	0xC0C8: 0x6A80,
	0xECF5: 0x6A81,
	0x9B4F: 0x6A82,
	0xED41: 0x6A83,
	0xC0CA: 0x6A84,
	0xED48: 0x6A85,
	0xFFFD: 0x6A86,
	0xECFC: 0x6A87,
	0xFFFD: 0x6A88,
	0xECF7: 0x6A89,
	0x9B50: 0x6A8A,
	0xFFFD: 0x6A8B,
	0xED49: 0x6A8C,
	0xECF3: 0x6A8D,
	0xECFE: 0x6A8E,
	0x9B51: 0x6A8F,
	0xC0D1: 0x6A90,
	0xED44: 0x6A91,
	0xED4A: 0x6A92,
	0xECFD: 0x6A93,
	0xC0C9: 0x6A94,
	0xED40: 0x6A95,
	0xECF4: 0x6A96,
	0xC0D0: 0x6A97,
	0xFFFD: 0x6A98,
	0x9B52: 0x6A99,
	0xED47: 0x6A9A,
	0xECF9: 0x6A9B,
	0xC0CC: 0x6A9C,
	0xFC78: 0x6A9D,
	0xECFB: 0x6A9E,
	0xECF8: 0x6A9F,
	0xC0D2: 0x6AA0,
	0xECFA: 0x6AA1,
	0xC0CB: 0x6AA2,
	0xC0CE: 0x6AA3,
	0xED43: 0x6AA4,
	0xECF6: 0x6AA5,
	0xED46: 0x6AA6,
	0x9B53: 0x6AA7,
	0xED42: 0x6AA8,
	0x96FD: 0x6AA9,
	0x96FE: 0x6AAA,
	0x99FE: 0x6AAB,
	0xC263: 0x6AAC,
	0xEFE7: 0x6AAD,
	0xC268: 0x6AAE,
	0xC269: 0x6AAF,
	0xFFFD: 0x6AB0,
	0x9B54: 0x6AB1,
	0xFC76: 0x6AB2,
	0xC262: 0x6AB3,
	0xEFE6: 0x6AB4,
	0x9B55: 0x6AB5,
	0xEFE3: 0x6AB6,
	0xEFE4: 0x6AB7,
	0xC266: 0x6AB8,
	0xEFDE: 0x6AB9,
	0xEFE2: 0x6ABA,
	0xC265: 0x6ABB,
	0xFFFD: 0x6ABC,
	0xEFDF: 0x6ABD,
	0x9B56: 0x6ABE,
	0xFFFD: 0x6ABF,
	0xFFFD: 0x6AC0,
	0x9AFE: 0x6AC1,
	0xC267: 0x6AC2,
	0xC264: 0x6AC3,
	0xFFFD: 0x6AC4,
	0xEFDD: 0x6AC5,
	0xEFE1: 0x6AC6,
	0xEFE5: 0x6AC7,
	0x95E3: 0x6AC8,
	0x9B57: 0x6AC9,
	0xFBDC: 0x6ACA,
	0xF251: 0x6ACB,
	0xF24E: 0x6ACC,
	0xF257: 0x6ACD,
	0xFFFD: 0x6ACE,
	0xF256: 0x6ACF,
	0xF254: 0x6AD0,
	0xF24F: 0x6AD1,
	0xFFFD: 0x6AD2,
	0xC372: 0x6AD3,
	0x9B58: 0x6AD4,
	0xFFFD: 0x6AD5,
	0xFFFD: 0x6AD6,
	0xFFFD: 0x6AD7,
	0x9B59: 0x6AD8,
	0xF250: 0x6AD9,
	0xC371: 0x6ADA,
	0xC0CD: 0x6ADB,
	0xF253: 0x6ADC,
	0xC370: 0x6ADD,
	0xF258: 0x6ADE,
	0xF252: 0x6ADF,
	0xF24D: 0x6AE0,
	0xEFE0: 0x6AE1,
	0x9CF9: 0x6AE2,
	0xFFFD: 0x6AE3,
	0x9DE1: 0x6AE4,
	0xC36F: 0x6AE5,
	0xFFFD: 0x6AE6,
	0xF24C: 0x6AE7,
	0xF456: 0x6AE8,
	0xFFFD: 0x6AE9,
	0xF455: 0x6AEA,
	0xF255: 0x6AEB,
	0xC468: 0x6AEC,
	0xFFFD: 0x6AED,
	0xF459: 0x6AEE,
	0xF45A: 0x6AEF,
	0xF454: 0x6AF0,
	0xF458: 0x6AF1,
	0xFFFD: 0x6AF2,
	0xF453: 0x6AF3,
	0xFFFD: 0x6AF4,
	0xFFFD: 0x6AF5,
	0x9B5A: 0x6AF6,
	0xFFFD: 0x6AF7,
	0xF5D1: 0x6AF8,
	0xF457: 0x6AF9,
	0xC4E7: 0x6AFA,
	0xC4E5: 0x6AFB,
	0xF5CF: 0x6AFC,
	0xFFFD: 0x6AFD,
	0xFFFD: 0x6AFE,
	0xFFFD: 0x6AFF,
	0xF5D2: 0x6B00,
	0xFFFD: 0x6B01,
	0xF5CE: 0x6B02,
	0xF5D0: 0x6B03,
	0xC4E6: 0x6B04,
	0x9DFE: 0x6B05,
	0xFFFD: 0x6B06,
	0xFFFD: 0x6B07,
	0xF6E5: 0x6B08,
	0xF6E6: 0x6B09,
	0xC576: 0x6B0A,
	0xF6E4: 0x6B0B,
	0xFFFD: 0x6B0C,
	0xFFFD: 0x6B0D,
	0xFFFD: 0x6B0E,
	0xF7E2: 0x6B0F,
	0xC5CF: 0x6B10,
	0xF7E0: 0x6B11,
	0xF7E1: 0x6B12,
	0xF8AC: 0x6B13,
	0xFFFD: 0x6B14,
	0xFFFD: 0x6B15,
	0xC656: 0x6B16,
	0xF8F3: 0x6B17,
	0xF8F1: 0x6B18,
	0xF8F2: 0x6B19,
	0xF8F4: 0x6B1A,
	0xFFFD: 0x6B1B,
	0xFFFD: 0x6B1C,
	0xFC79: 0x6B1D,
	0xF9BB: 0x6B1E,
	0x94A8: 0x6B1F,
	0xA4ED: 0x6B20,
	0xA6B8: 0x6B21,
	0x8CD1: 0x6B22,
	0xAA59: 0x6B23,
	0x8ACF: 0x6B24,
	0xCCE9: 0x6B25,
	0xFFFD: 0x6B26,
	0x87E6: 0x6B27,
	0xCF64: 0x6B28,
	0xFFFD: 0x6B29,
	0xFFFD: 0x6B2A,
	0xFFFD: 0x6B2B,
	0xD1F5: 0x6B2C,
	0xD1F7: 0x6B2D,
	0xFFFD: 0x6B2E,
	0xD1F6: 0x6B2F,
	0xFFFD: 0x6B30,
	0xD1F8: 0x6B31,
	0xB1FD: 0x6B32,
	0xD5D7: 0x6B33,
	0xD1F9: 0x6B34,
	0x95B9: 0x6B35,
	0xD5D6: 0x6B36,
	0xD5D8: 0x6B37,
	0xD5D9: 0x6B38,
	0xD9DA: 0x6B39,
	0xB4DB: 0x6B3A,
	0xD9DB: 0x6B3B,
	0xD9DD: 0x6B3C,
	0xB4DC: 0x6B3D,
	0xB4DA: 0x6B3E,
	0xD9DC: 0x6B3F,
	0xFFFD: 0x6B40,
	0xDDFA: 0x6B41,
	0xDDF8: 0x6B42,
	0xDDF7: 0x6B43,
	0xFFFD: 0x6B44,
	0xDDF6: 0x6B45,
	0xDDF5: 0x6B46,
	0xB7B2: 0x6B47,
	0xDDF9: 0x6B48,
	0xBA70: 0x6B49,
	0xE263: 0x6B4A,
	0xE265: 0x6B4B,
	0xBA71: 0x6B4C,
	0xE264: 0x6B4D,
	0xBCDB: 0x6B4E,
	0xFFFD: 0x6B4F,
	0xBCDA: 0x6B50,
	0xE5F0: 0x6B51,
	0xFC7A: 0x6B52,
	0x926C: 0x6B53,
	0xE9DF: 0x6B54,
	0xE9DE: 0x6B55,
	0xE9E0: 0x6B56,
	0x9B5B: 0x6B57,
	0xFFFD: 0x6B58,
	0xBEF9: 0x6B59,
	0xFFFD: 0x6B5A,
	0xED4B: 0x6B5B,
	0xC0D3: 0x6B5C,
	0xFFFD: 0x6B5D,
	0xEFE8: 0x6B5E,
	0xC26A: 0x6B5F,
	0xF259: 0x6B60,
	0xC577: 0x6B61,
	0xA4EE: 0x6B62,
	0xA5BF: 0x6B63,
	0xA6B9: 0x6B64,
	0xA842: 0x6B65,
	0xAA5A: 0x6B66,
	0xAA5B: 0x6B67,
	0xFFFD: 0x6B68,
	0x93C5: 0x6B69,
	0xAC6E: 0x6B6A,
	0xFFFD: 0x6B6B,
	0xFFFD: 0x6B6C,
	0xD1FA: 0x6B6D,
	0xFFFD: 0x6B6E,
	0x92D0: 0x6B6F,
	0xFFFD: 0x6B70,
	0xFFFD: 0x6B71,
	0xB7B3: 0x6B72,
	0x92C8: 0x6B73,
	0x93F0: 0x6B74,
	0xFFFD: 0x6B75,
	0xE6D1: 0x6B76,
	0xBEFA: 0x6B77,
	0xC26B: 0x6B78,
	0xA4EF: 0x6B79,
	0x9B5C: 0x6B7A,
	0xA6BA: 0x6B7B,
	0x8C79: 0x6B7C,
	0xFFFD: 0x6B7D,
	0xCCEB: 0x6B7E,
	0xAA5C: 0x6B7F,
	0xCCEA: 0x6B80,
	0x9F4E: 0x6B81,
	0xCF65: 0x6B82,
	0xAC6F: 0x6B83,
	0xCF66: 0x6B84,
	0xFFFD: 0x6B85,
	0xAC70: 0x6B86,
	0x87E7: 0x6B87,
	0xD1FC: 0x6B88,
	0xAEEE: 0x6B89,
	0xAEED: 0x6B8A,
	0x92CF: 0x6B8B,
	0xD5DE: 0x6B8C,
	0xD5DC: 0x6B8D,
	0xD5DD: 0x6B8E,
	0xD5DB: 0x6B8F,
	0xFFFD: 0x6B90,
	0xD5DA: 0x6B91,
	0x8DB5: 0x6B92,
	0x89E8: 0x6B93,
	0xD9DE: 0x6B94,
	0xD9E1: 0x6B95,
	0xB4DE: 0x6B96,
	0xD9DF: 0x6B97,
	0xB4DD: 0x6B98,
	0xD9E0: 0x6B99,
	0x8EE8: 0x6B9A,
	0xDDFB: 0x6B9B,
	0xFFFD: 0x6B9C,
	0xFFFD: 0x6B9D,
	0xE266: 0x6B9E,
	0xE267: 0x6B9F,
	0xE268: 0x6BA0,
	0x8AD1: 0x6BA1,
	0xE5F3: 0x6BA2,
	0xE5F2: 0x6BA3,
	0xBCDC: 0x6BA4,
	0xE5F1: 0x6BA5,
	0xE5F4: 0x6BA6,
	0xE9E1: 0x6BA7,
	0xFFFD: 0x6BA8,
	0xFFFD: 0x6BA9,
	0xE9E2: 0x6BAA,
	0xE9E3: 0x6BAB,
	0xFFFD: 0x6BAC,
	0xED4C: 0x6BAD,
	0xC0D4: 0x6BAE,
	0xC26C: 0x6BAF,
	0xF25A: 0x6BB0,
	0x9F4F: 0x6BB1,
	0xC4E8: 0x6BB2,
	0xC95F: 0x6BB3,
	0x87E8: 0x6BB4,
	0xAC71: 0x6BB5,
	0xCF67: 0x6BB6,
	0xAEEF: 0x6BB7,
	0xFFFD: 0x6BB8,
	0xFFFD: 0x6BB9,
	0xB1FE: 0x6BBA,
	0x925F: 0x6BBB,
	0xB4DF: 0x6BBC,
	0xD9E2: 0x6BBD,
	0xFFFD: 0x6BBE,
	0xB7B5: 0x6BBF,
	0xB7B4: 0x6BC0,
	0x90B5: 0x6BC1,
	0x8A75: 0x6BC2,
	0xE269: 0x6BC3,
	0xE26A: 0x6BC4,
	0xBCDD: 0x6BC5,
	0xBCDE: 0x6BC6,
	0xE9E5: 0x6BC7,
	0xE9E4: 0x6BC8,
	0xEFE9: 0x6BC9,
	0xF7E3: 0x6BCA,
	0xA4F0: 0x6BCB,
	0xC960: 0x6BCC,
	0xA5C0: 0x6BCD,
	0x93D1: 0x6BCE,
	0xA843: 0x6BCF,
	0xCB48: 0x6BD0,
	0xFFFD: 0x6BD1,
	0xAC72: 0x6BD2,
	0xB7B6: 0x6BD3,
	0xA4F1: 0x6BD4,
	0x8465: 0x6BD5,
	0xCF68: 0x6BD6,
	0xAC73: 0x6BD7,
	0xCF69: 0x6BD8,
	0x89E1: 0x6BD9,
	0xC0D5: 0x6BDA,
	0xA4F2: 0x6BDB,
	0x9B5D: 0x6BDC,
	0xFFFD: 0x6BDD,
	0xCCEC: 0x6BDE,
	0x94A9: 0x6BDF,
	0xCF6A: 0x6BE0,
	0x89E9: 0x6BE1,
	0xD242: 0x6BE2,
	0xD241: 0x6BE3,
	0xD1FE: 0x6BE4,
	0xFFFD: 0x6BE5,
	0xD1FD: 0x6BE6,
	0xD243: 0x6BE7,
	0xD240: 0x6BE8,
	0xFFFD: 0x6BE9,
	0xA062: 0x6BEA,
	0xB240: 0x6BEB,
	0xB241: 0x6BEC,
	0xFFFD: 0x6BED,
	0xFFFD: 0x6BEE,
	0xB4E0: 0x6BEF,
	0xD9E3: 0x6BF0,
	0xFFFD: 0x6BF1,
	0xD9E4: 0x6BF2,
	0xD9E5: 0x6BF3,
	0xFFFD: 0x6BF4,
	0x8EB9: 0x6BF5,
	0xFFFD: 0x6BF6,
	0xDE41: 0x6BF7,
	0xDE42: 0x6BF8,
	0xDE40: 0x6BF9,
	0xFC7B: 0x6BFA,
	0xDDFD: 0x6BFB,
	0xDDFE: 0x6BFC,
	0xB7B7: 0x6BFD,
	0xE26B: 0x6BFE,
	0xE5F7: 0x6BFF,
	0xE5F6: 0x6C00,
	0xE5F5: 0x6C01,
	0xE5F8: 0x6C02,
	0xE9E7: 0x6C03,
	0xE9E6: 0x6C04,
	0xBEFB: 0x6C05,
	0xE9E8: 0x6C06,
	0x8FBB: 0x6C07,
	0xC0D6: 0x6C08,
	0xED4D: 0x6C09,
	0xFFFD: 0x6C0A,
	0xEFEA: 0x6C0B,
	0xF25B: 0x6C0C,
	0xF6E7: 0x6C0D,
	0xFFFD: 0x6C0E,
	0xA4F3: 0x6C0F,
	0xA5C2: 0x6C10,
	0xA5C1: 0x6C11,
	0xFFFD: 0x6C12,
	0xAA5D: 0x6C13,
	0xC961: 0x6C14,
	0xC97E: 0x6C15,
	0xA6BB: 0x6C16,
	0x926E: 0x6C17,
	0xC9F7: 0x6C18,
	0xCB49: 0x6C19,
	0xCB4A: 0x6C1A,
	0xAA5E: 0x6C1B,
	0x9B5E: 0x6C1C,
	0xCCED: 0x6C1D,
	0xFFFD: 0x6C1E,
	0xAC74: 0x6C1F,
	0xCF6B: 0x6C20,
	0xCF6C: 0x6C21,
	0x845A: 0x6C22,
	0xAEF0: 0x6C23,
	0xAEF4: 0x6C24,
	0xD244: 0x6C25,
	0xAEF3: 0x6C26,
	0xAEF1: 0x6C27,
	0xAEF2: 0x6C28,
	0x84EC: 0x6C29,
	0xD5DF: 0x6C2A,
	0xB242: 0x6C2B,
	0xB4E3: 0x6C2C,
	0xFFFD: 0x6C2D,
	0xB4E1: 0x6C2E,
	0xB4E2: 0x6C2F,
	0xD9E6: 0x6C30,
	0x9B5F: 0x6C31,
	0xA063: 0x6C32,
	0xBA72: 0x6C33,
	0xA4F4: 0x6C34,
	0x9CF3: 0x6C35,
	0xC9A1: 0x6C36,
	0x95EB: 0x6C37,
	0xA5C3: 0x6C38,
	0xFE40: 0x6C39,
	0x91D2: 0x6C3A,
	0xC9A4: 0x6C3B,
	0xFFFD: 0x6C3C,
	0xA064: 0x6C3D,
	0xA5C6: 0x6C3E,
	0xC9A3: 0x6C3F,
	0xA5C5: 0x6C40,
	0xA5C4: 0x6C41,
	0xA844: 0x6C42,
	0xC9A2: 0x6C43,
	0xFFFD: 0x6C44,
	0xFFFD: 0x6C45,
	0xC9F8: 0x6C46,
	0x85B9: 0x6C47,
	0xFFFD: 0x6C48,
	0x86D5: 0x6C49,
	0xC9FC: 0x6C4A,
	0xC9FE: 0x6C4B,
	0xCA40: 0x6C4C,
	0xA6C5: 0x6C4D,
	0xA6C6: 0x6C4E,
	0xC9FB: 0x6C4F,
	0xA6C1: 0x6C50,
	0xFFFD: 0x6C51,
	0xC9F9: 0x6C52,
	0xFFFD: 0x6C53,
	0xC9FD: 0x6C54,
	0xA6C2: 0x6C55,
	0xFFFD: 0x6C56,
	0xA6BD: 0x6C57,
	0x9B60: 0x6C58,
	0xA6BE: 0x6C59,
	0x95EA: 0x6C5A,
	0xA6C4: 0x6C5B,
	0xC9FA: 0x6C5C,
	0xA6BC: 0x6C5D,
	0xA845: 0x6C5E,
	0xA6BF: 0x6C5F,
	0xA6C0: 0x6C60,
	0xA6C3: 0x6C61,
	0xA065: 0x6C62,
	0xFFFD: 0x6C63,
	0x84F1: 0x6C64,
	0xCB5B: 0x6C65,
	0xCB59: 0x6C66,
	0xCB4C: 0x6C67,
	0xA851: 0x6C68,
	0xCB53: 0x6C69,
	0xA84C: 0x6C6A,
	0xCB4D: 0x6C6B,
	0xFFFD: 0x6C6C,
	0xCB55: 0x6C6D,
	0x9B61: 0x6C6E,
	0xCB52: 0x6C6F,
	0xA84F: 0x6C70,
	0xCB51: 0x6C71,
	0xA856: 0x6C72,
	0xCB5A: 0x6C73,
	0xA858: 0x6C74,
	0x9B62: 0x6C75,
	0xA85A: 0x6C76,
	0xFFFD: 0x6C77,
	0xCB4B: 0x6C78,
	0x836E: 0x6C79,
	0xA84D: 0x6C7A,
	0xCB5C: 0x6C7B,
	0xFFFD: 0x6C7C,
	0xA854: 0x6C7D,
	0xA857: 0x6C7E,
	0x9B63: 0x6C7F,
	0xCD45: 0x6C80,
	0xA847: 0x6C81,
	0xA85E: 0x6C82,
	0xA855: 0x6C83,
	0xCB4E: 0x6C84,
	0xA84A: 0x6C85,
	0xA859: 0x6C86,
	0xCB56: 0x6C87,
	0xA848: 0x6C88,
	0xA849: 0x6C89,
	0xCD43: 0x6C8A,
	0xCB4F: 0x6C8B,
	0xA850: 0x6C8C,
	0xA85B: 0x6C8D,
	0xCB5D: 0x6C8E,
	0xCB50: 0x6C8F,
	0xA84E: 0x6C90,
	0xFFFD: 0x6C91,
	0xA853: 0x6C92,
	0xCCEE: 0x6C93,
	0xA85C: 0x6C94,
	0xCB57: 0x6C95,
	0xA852: 0x6C96,
	0xFFFD: 0x6C97,
	0xA85D: 0x6C98,
	0xA846: 0x6C99,
	0xCB54: 0x6C9A,
	0xA84B: 0x6C9B,
	0xCB58: 0x6C9C,
	0xCD44: 0x6C9D,
	0xFFFD: 0x6C9E,
	0x85D8: 0x6C9F,
	0xFFFD: 0x6CA0,
	0x95CA: 0x6CA1,
	0x936B: 0x6CA2,
	0x88F4: 0x6CA3,
	0x8E75: 0x6CA4,
	0x8B7E: 0x6CA5,
	0x845F: 0x6CA6,
	0x85DC: 0x6CA7,
	0xFFFD: 0x6CA8,
	0x8DE0: 0x6CA9,
	0x86DB: 0x6CAA,
	0xAA6A: 0x6CAB,
	0xAA7A: 0x6CAC,
	0xCCF5: 0x6CAD,
	0xAA71: 0x6CAE,
	0x9B64: 0x6CAF,
	0xCD4B: 0x6CB0,
	0xAA62: 0x6CB1,
	0xA066: 0x6CB2,
	0xAA65: 0x6CB3,
	0xCD42: 0x6CB4,
	0xFFFD: 0x6CB5,
	0xCCF3: 0x6CB6,
	0xCCF7: 0x6CB7,
	0xAA6D: 0x6CB8,
	0xAA6F: 0x6CB9,
	0xCCFA: 0x6CBA,
	0xAA76: 0x6CBB,
	0xAA68: 0x6CBC,
	0xAA66: 0x6CBD,
	0xAA67: 0x6CBE,
	0xAA75: 0x6CBF,
	0xCD47: 0x6CC0,
	0xAA70: 0x6CC1,
	0xCCF9: 0x6CC2,
	0xCCFB: 0x6CC3,
	0xAA6E: 0x6CC4,
	0xAA73: 0x6CC5,
	0xCCFC: 0x6CC6,
	0xCD4A: 0x6CC7,
	0xFFFD: 0x6CC8,
	0xAC75: 0x6CC9,
	0xAA79: 0x6CCA,
	0x9B65: 0x6CCB,
	0xAA63: 0x6CCC,
	0xCD49: 0x6CCD,
	0xFC7D: 0x6CCE,
	0xCD4D: 0x6CCF,
	0xCCF8: 0x6CD0,
	0xCD4F: 0x6CD1,
	0xCD40: 0x6CD2,
	0xAA6C: 0x6CD3,
	0xCCF4: 0x6CD4,
	0xAA6B: 0x6CD5,
	0xAA7D: 0x6CD6,
	0xAA72: 0x6CD7,
	0xFFFD: 0x6CD8,
	0xCCF2: 0x6CD9,
	0xCF75: 0x6CDA,
	0xAA78: 0x6CDB,
	0xAA7C: 0x6CDC,
	0xCD41: 0x6CDD,
	0xCD46: 0x6CDE,
	0x9B66: 0x6CDF,
	0xAA7E: 0x6CE0,
	0xAA77: 0x6CE1,
	0xAA69: 0x6CE2,
	0xAA5F: 0x6CE3,
	0xFFFD: 0x6CE4,
	0xAA64: 0x6CE5,
	0xFFFD: 0x6CE6,
	0xCCF6: 0x6CE7,
	0xAA60: 0x6CE8,
	0xCD4E: 0x6CE9,
	0x845E: 0x6CEA,
	0xCCF0: 0x6CEB,
	0xCCEF: 0x6CEC,
	0xCCFD: 0x6CED,
	0xCCF1: 0x6CEE,
	0xAA7B: 0x6CEF,
	0xAEF5: 0x6CF0,
	0xAA74: 0x6CF1,
	0xCCFE: 0x6CF2,
	0xAA61: 0x6CF3,
	0xFFFD: 0x6CF4,
	0xACA6: 0x6CF5,
	0x8F54: 0x6CF6,
	0x8FBC: 0x6CF7,
	0x8BA2: 0x6CF8,
	0xCD4C: 0x6CF9,
	0x8F77: 0x6CFA,
	0x8AD2: 0x6CFB,
	0x87EA: 0x6CFC,
	0x88F2: 0x6CFD,
	0x83BD: 0x6CFE,
	0x9B67: 0x6CFF,
	0xCF7C: 0x6D00,
	0xCFA1: 0x6D01,
	0x9B68: 0x6D02,
	0xCFA4: 0x6D03,
	0xCF77: 0x6D04,
	0x9B69: 0x6D05,
	0x9B6A: 0x6D06,
	0xCFA7: 0x6D07,
	0xCFAA: 0x6D08,
	0xCFAC: 0x6D09,
	0xCF74: 0x6D0A,
	0xAC76: 0x6D0B,
	0xAC7B: 0x6D0C,
	0xD249: 0x6D0D,
	0xACAD: 0x6D0E,
	0xCFA5: 0x6D0F,
	0xCFAD: 0x6D10,
	0xCF7B: 0x6D11,
	0xCF73: 0x6D12,
	0xFFFD: 0x6D13,
	0xFFFD: 0x6D14,
	0xFFFD: 0x6D15,
	0xD264: 0x6D16,
	0xAC7E: 0x6D17,
	0xCFA2: 0x6D18,
	0xCF78: 0x6D19,
	0xCF7A: 0x6D1A,
	0xACA5: 0x6D1B,
	0xFFFD: 0x6D1C,
	0xCF7D: 0x6D1D,
	0xAC7D: 0x6D1E,
	0xCF70: 0x6D1F,
	0xCFA8: 0x6D20,
	0xFFFD: 0x6D21,
	0xCFAB: 0x6D22,
	0xFFFD: 0x6D23,
	0x95B0: 0x6D24,
	0xAC7A: 0x6D25,
	0x9B6B: 0x6D26,
	0xACA8: 0x6D27,
	0xCF6D: 0x6D28,
	0xACAA: 0x6D29,
	0xAC78: 0x6D2A,
	0xACAE: 0x6D2B,
	0xCFA9: 0x6D2C,
	0xCF6F: 0x6D2D,
	0xACAB: 0x6D2E,
	0xD25E: 0x6D2F,
	0xCD48: 0x6D30,
	0xAC7C: 0x6D31,
	0xAC77: 0x6D32,
	0xCF76: 0x6D33,
	0xCF6E: 0x6D34,
	0xACAC: 0x6D35,
	0xACA4: 0x6D36,
	0xCFA3: 0x6D37,
	0xACA9: 0x6D38,
	0xACA7: 0x6D39,
	0xCF79: 0x6D3A,
	0xACA1: 0x6D3B,
	0xCF71: 0x6D3C,
	0xACA2: 0x6D3D,
	0xACA3: 0x6D3E,
	0xCF72: 0x6D3F,
	0xCFA6: 0x6D40,
	0xAC79: 0x6D41,
	0xCF7E: 0x6D42,
	0x83BE: 0x6D43,
	0x92EA: 0x6D44,
	0x9348: 0x6D45,
	0x87E9: 0x6D46,
	0x87EC: 0x6D47,
	0x8DE1: 0x6D48,
	0xFFFD: 0x6D49,
	0x88F3: 0x6D4A,
	0x84F2: 0x6D4B,
	0xFFFD: 0x6D4C,
	0x8EE9: 0x6D4D,
	0x89EC: 0x6D4E,
	0x8AD7: 0x6D4F,
	0xFFFD: 0x6D50,
	0x84F3: 0x6D51,
	0x8E74: 0x6D52,
	0x88F1: 0x6D53,
	0x87F0: 0x6D54,
	0xFFFD: 0x6D55,
	0xFFFD: 0x6D56,
	0x9B6C: 0x6D57,
	0xD24C: 0x6D58,
	0xAEFD: 0x6D59,
	0xAF43: 0x6D5A,
	0x9B6D: 0x6D5B,
	0x93BD: 0x6D5C,
	0xFFFD: 0x6D5D,
	0xD255: 0x6D5E,
	0xD25B: 0x6D5F,
	0xD257: 0x6D60,
	0xD24A: 0x6D61,
	0xD24D: 0x6D62,
	0xD246: 0x6D63,
	0xD247: 0x6D64,
	0xAF4A: 0x6D65,
	0xAEFA: 0x6D66,
	0xD256: 0x6D67,
	0xD25F: 0x6D68,
	0xAF45: 0x6D69,
	0xAEF6: 0x6D6A,
	0xFFFD: 0x6D6B,
	0xAF40: 0x6D6C,
	0xD24E: 0x6D6D,
	0xAF42: 0x6D6E,
	0xD24F: 0x6D6F,
	0xD259: 0x6D70,
	0x9B6E: 0x6D71,
	0xFBA7: 0x6D72,
	0xFFFD: 0x6D73,
	0xAF44: 0x6D74,
	0xD268: 0x6D75,
	0xD248: 0x6D76,
	0xAEFC: 0x6D77,
	0xAEFB: 0x6D78,
	0xAF48: 0x6D79,
	0xD245: 0x6D7A,
	0xD266: 0x6D7B,
	0xD25A: 0x6D7C,
	0xD267: 0x6D7D,
	0xD261: 0x6D7E,
	0xD253: 0x6D7F,
	0xD262: 0x6D80,
	0x9B6F: 0x6D81,
	0xD25C: 0x6D82,
	0xD265: 0x6D83,
	0xD263: 0x6D84,
	0xAF49: 0x6D85,
	0xD254: 0x6D86,
	0xAEF9: 0x6D87,
	0xAEF8: 0x6D88,
	0xAF41: 0x6D89,
	0xAF47: 0x6D8A,
	0xD260: 0x6D8B,
	0xAF46: 0x6D8C,
	0xD251: 0x6D8D,
	0xB243: 0x6D8E,
	0x9B70: 0x6D8F,
	0xD269: 0x6D90,
	0xD250: 0x6D91,
	0xD24B: 0x6D92,
	0xAEFE: 0x6D93,
	0xAF4B: 0x6D94,
	0xAEF7: 0x6D95,
	0xFE5C: 0x6D96,
	0xD258: 0x6D97,
	0xD25D: 0x6D98,
	0x93E8: 0x6D99,
	0xFFFD: 0x6D9A,
	0x89ED: 0x6D9B,
	0x8271: 0x6D9C,
	0x8EBB: 0x6D9D,
	0x8DCF: 0x6D9E,
	0x86DA: 0x6D9F,
	0x8EBD: 0x6DA0,
	0x84F0: 0x6DA1,
	0xFFFD: 0x6DA2,
	0x84F4: 0x6DA3,
	0x86DE: 0x6DA4,
	0x9B71: 0x6DA5,
	0x87EE: 0x6DA6,
	0x87EF: 0x6DA7,
	0x86D9: 0x6DA8,
	0x89EF: 0x6DA9,
	0xB265: 0x6DAA,
	0xD5E1: 0x6DAB,
	0xD5E5: 0x6DAC,
	0xFFFD: 0x6DAD,
	0xB252: 0x6DAE,
	0xB250: 0x6DAF,
	0xFFFD: 0x6DB0,
	0x9B72: 0x6DB1,
	0xB247: 0x6DB2,
	0xD5E3: 0x6DB3,
	0xD5E2: 0x6DB4,
	0xB25B: 0x6DB5,
	0xFFFD: 0x6DB6,
	0xD5E8: 0x6DB7,
	0xB255: 0x6DB8,
	0xFCA1: 0x6DB9,
	0xD5FA: 0x6DBA,
	0xD647: 0x6DBB,
	0xB244: 0x6DBC,
	0xD5F7: 0x6DBD,
	0xD5F0: 0x6DBE,
	0xB267: 0x6DBF,
	0xD5E0: 0x6DC0,
	0xFFFD: 0x6DC1,
	0xD5FC: 0x6DC2,
	0xFFFD: 0x6DC3,
	0xB264: 0x6DC4,
	0xB258: 0x6DC5,
	0xB263: 0x6DC6,
	0xB24E: 0x6DC7,
	0xD5EC: 0x6DC8,
	0xD5FE: 0x6DC9,
	0xD5F6: 0x6DCA,
	0xB24F: 0x6DCB,
	0xB249: 0x6DCC,
	0xD645: 0x6DCD,
	0xFFFD: 0x6DCE,
	0xD5FD: 0x6DCF,
	0xD640: 0x6DD0,
	0xB251: 0x6DD1,
	0xB259: 0x6DD2,
	0xD642: 0x6DD3,
	0xD5EA: 0x6DD4,
	0xD5FB: 0x6DD5,
	0xD5EF: 0x6DD6,
	0xD644: 0x6DD7,
	0xB25E: 0x6DD8,
	0xB246: 0x6DD9,
	0xB25C: 0x6DDA,
	0xD5F4: 0x6DDB,
	0xD5F2: 0x6DDC,
	0xD5F3: 0x6DDD,
	0xB253: 0x6DDE,
	0xD5EE: 0x6DDF,
	0xD5ED: 0x6DE0,
	0xB248: 0x6DE1,
	0xD5E7: 0x6DE2,
	0xD646: 0x6DE3,
	0xB24A: 0x6DE4,
	0xD5F1: 0x6DE5,
	0xB268: 0x6DE6,
	0xFFFD: 0x6DE7,
	0xB262: 0x6DE8,
	0xD5E6: 0x6DE9,
	0xB25F: 0x6DEA,
	0xB25D: 0x6DEB,
	0xB266: 0x6DEC,
	0xD5F8: 0x6DED,
	0xB261: 0x6DEE,
	0xD252: 0x6DEF,
	0xD5F9: 0x6DF0,
	0xB260: 0x6DF1,
	0xD641: 0x6DF2,
	0xB245: 0x6DF3,
	0xD5F5: 0x6DF4,
	0xB257: 0x6DF5,
	0xD5E9: 0x6DF6,
	0xB256: 0x6DF7,
	0xA067: 0x6DF8,
	0xB254: 0x6DF9,
	0xB24C: 0x6DFA,
	0xB24B: 0x6DFB,
	0xD9E7: 0x6DFC,
	0xD643: 0x6DFD,
	0x9B73: 0x6DFE,
	0xFFFD: 0x6DFF,
	0xD5EB: 0x6E00,
	0xFFFD: 0x6E01,
	0x9B74: 0x6E02,
	0xD9FC: 0x6E03,
	0x9B75: 0x6E04,
	0xB24D: 0x6E05,
	0xFFFD: 0x6E06,
	0x9264: 0x6E07,
	0x92C6: 0x6E08,
	0x92E4: 0x6E09,
	0x845D: 0x6E0A,
	0x92DD: 0x6E0B,
	0x8DD0: 0x6E0C,
	0x86D4: 0x6E0D,
	0x8AD5: 0x6E0E,
	0x9B76: 0x6E0F,
	0x86D8: 0x6E10,
	0x88F6: 0x6E11,
	0xFFFD: 0x6E12,
	0x92AA: 0x6E13,
	0x86DC: 0x6E14,
	0x94AA: 0x6E15,
	0x8AD3: 0x6E16,
	0x86DD: 0x6E17,
	0x9B77: 0x6E18,
	0xB541: 0x6E19,
	0xB25A: 0x6E1A,
	0xB4EE: 0x6E1B,
	0xD9F6: 0x6E1C,
	0xB4FC: 0x6E1D,
	0xFFFD: 0x6E1E,
	0xD9EA: 0x6E1F,
	0xB4EB: 0x6E20,
	0xB4E7: 0x6E21,
	0xDA49: 0x6E22,
	0xB4ED: 0x6E23,
	0xB4F1: 0x6E24,
	0xB4EC: 0x6E25,
	0xB4F5: 0x6E26,
	0xDA4D: 0x6E27,
	0xDA44: 0x6E28,
	0xA068: 0x6E29,
	0x9B78: 0x6E2A,
	0xD9F1: 0x6E2B,
	0xB4FA: 0x6E2C,
	0xB4F4: 0x6E2D,
	0xD9FD: 0x6E2E,
	0xB4E4: 0x6E2F,
	0xDA4A: 0x6E30,
	0xDA43: 0x6E31,
	0xB4E8: 0x6E32,
	0xD9F7: 0x6E33,
	0xB4F7: 0x6E34,
	0xDA55: 0x6E35,
	0xDA56: 0x6E36,
	0xFFFD: 0x6E37,
	0xB4E5: 0x6E38,
	0xDA48: 0x6E39,
	0xB4F9: 0x6E3A,
	0xD9FB: 0x6E3B,
	0xD9ED: 0x6E3C,
	0xD9EE: 0x6E3D,
	0xB4FD: 0x6E3E,
	0xD9F2: 0x6E3F,
	0xD9F9: 0x6E40,
	0xD9F3: 0x6E41,
	0xFFFD: 0x6E42,
	0xB4FB: 0x6E43,
	0xB544: 0x6E44,
	0xD9EF: 0x6E45,
	0xD9E8: 0x6E46,
	0xD9E9: 0x6E47,
	0xFFFD: 0x6E48,
	0xD9EB: 0x6E49,
	0xB4EA: 0x6E4A,
	0xD9F8: 0x6E4B,
	0xFFFD: 0x6E4C,
	0xB4F8: 0x6E4D,
	0xB542: 0x6E4E,
	0xFC7E: 0x6E4F,
	0x9B79: 0x6E50,
	0xD9FA: 0x6E51,
	0xDA53: 0x6E52,
	0xDA4B: 0x6E53,
	0xB4E6: 0x6E54,
	0xDA51: 0x6E55,
	0xB4F2: 0x6E56,
	0x9DCB: 0x6E57,
	0xB4F0: 0x6E58,
	0x9B7A: 0x6E59,
	0xDA57: 0x6E5A,
	0xB4EF: 0x6E5B,
	0xDA41: 0x6E5C,
	0xD9F4: 0x6E5D,
	0xD9FE: 0x6E5E,
	0xB547: 0x6E5F,
	0xDA45: 0x6E60,
	0xDA42: 0x6E61,
	0xD9F0: 0x6E62,
	0xB543: 0x6E63,
	0xDA4F: 0x6E64,
	0xDA4C: 0x6E65,
	0xDA54: 0x6E66,
	0xB4E9: 0x6E67,
	0xDA40: 0x6E68,
	0xB546: 0x6E69,
	0xFFFD: 0x6E6A,
	0xDA47: 0x6E6B,
	0xFFFD: 0x6E6C,
	0xFFFD: 0x6E6D,
	0xB4F3: 0x6E6E,
	0xB4F6: 0x6E6F,
	0xFFFD: 0x6E70,
	0xDA46: 0x6E71,
	0xB545: 0x6E72,
	0xD9F5: 0x6E73,
	0xD5E4: 0x6E74,
	0xFFFD: 0x6E75,
	0xA069: 0x6E76,
	0xDA50: 0x6E77,
	0xDA4E: 0x6E78,
	0xDA52: 0x6E79,
	0xFFFD: 0x6E7A,
	0xFFFD: 0x6E7B,
	0x95CB: 0x6E7C,
	0xFFFD: 0x6E7D,
	0x8D6F: 0x6E7E,
	0x85DA: 0x6E7F,
	0x93D2: 0x6E80,
	0xFFFD: 0x6E81,
	0xA06A: 0x6E82,
	0x87ED: 0x6E83,
	0xFFFD: 0x6E84,
	0x8AD6: 0x6E85,
	0xA06B: 0x6E86,
	0xFFFD: 0x6E87,
	0xD9EC: 0x6E88,
	0xB540: 0x6E89,
	0xFFFD: 0x6E8A,
	0xFE6A: 0x6E8B,
	0x8278: 0x6E8C,
	0xDE61: 0x6E8D,
	0xDE60: 0x6E8E,
	0xDE46: 0x6E8F,
	0xB7BD: 0x6E90,
	0xFFFD: 0x6E91,
	0xDE5F: 0x6E92,
	0xDE49: 0x6E93,
	0xDE4A: 0x6E94,
	0xFFFD: 0x6E95,
	0xB7C7: 0x6E96,
	0xDE68: 0x6E97,
	0xB7C2: 0x6E98,
	0xDE5E: 0x6E99,
	0x9B7B: 0x6E9A,
	0xDE43: 0x6E9B,
	0xB7C8: 0x6E9C,
	0xB7BE: 0x6E9D,
	0xDE52: 0x6E9E,
	0xDE48: 0x6E9F,
	0xDE4B: 0x6EA0,
	0xDE63: 0x6EA1,
	0xB7B8: 0x6EA2,
	0xDE6A: 0x6EA3,
	0xDE62: 0x6EA4,
	0xB7C1: 0x6EA5,
	0xDE57: 0x6EA6,
	0xB7CC: 0x6EA7,
	0xFFFD: 0x6EA8,
	0xFFFD: 0x6EA9,
	0xB7CB: 0x6EAA,
	0xB7C5: 0x6EAB,
	0xFFFD: 0x6EAC,
	0xFFFD: 0x6EAD,
	0xDE69: 0x6EAE,
	0xB7B9: 0x6EAF,
	0xDE55: 0x6EB0,
	0xDE4C: 0x6EB1,
	0xDE59: 0x6EB2,
	0xDE65: 0x6EB3,
	0xB7CD: 0x6EB4,
	0x9B7C: 0x6EB5,
	0xB7BB: 0x6EB6,
	0xDE54: 0x6EB7,
	0x9B7D: 0x6EB8,
	0xDE4D: 0x6EB9,
	0xB7C4: 0x6EBA,
	0xA06C: 0x6EBB,
	0xB7C3: 0x6EBC,
	0xDE50: 0x6EBD,
	0xDE5A: 0x6EBE,
	0xDE64: 0x6EBF,
	0xDE47: 0x6EC0,
	0xDE51: 0x6EC1,
	0xB7BC: 0x6EC2,
	0xDE5B: 0x6EC3,
	0xB7C9: 0x6EC4,
	0xB7C0: 0x6EC5,
	0xDE4E: 0x6EC6,
	0xB7BF: 0x6EC7,
	0xDE45: 0x6EC8,
	0xDE53: 0x6EC9,
	0xDE67: 0x6ECA,
	0xB4FE: 0x6ECB,
	0xBAB0: 0x6ECC,
	0xDE56: 0x6ECD,
	0xE26C: 0x6ECE,
	0xDE58: 0x6ECF,
	0xDE66: 0x6ED0,
	0xB7C6: 0x6ED1,
	0xDE4F: 0x6ED2,
	0xB7BA: 0x6ED3,
	0xB7CA: 0x6ED4,
	0xBCF0: 0x6ED5,
	0xDE44: 0x6ED6,
	0x8EBE: 0x6ED7,
	0xDE5D: 0x6ED8,
	0x9550: 0x6ED9,
	0x86D3: 0x6EDA,
	0x9B7E: 0x6EDB,
	0xDE5C: 0x6EDC,
	0x9369: 0x6EDD,
	0x86D7: 0x6EDE,
	0xA06D: 0x6EDF,
	0x9041: 0x6EE0,
	0x86D6: 0x6EE1,
	0xA06E: 0x6EE2,
	0xFFFD: 0x6EE3,
	0x8AD4: 0x6EE4,
	0x89EE: 0x6EE5,
	0x8D7B: 0x6EE6,
	0xFFFD: 0x6EE7,
	0x89EB: 0x6EE8,
	0x8CD2: 0x6EE9,
	0xFFFD: 0x6EEA,
	0xE2AA: 0x6EEB,
	0xBAAD: 0x6EEC,
	0xE27D: 0x6EED,
	0xE2A4: 0x6EEE,
	0xBAA2: 0x6EEF,
	0xFFFD: 0x6EF0,
	0xE26E: 0x6EF1,
	0xBAAF: 0x6EF2,
	0xFFFD: 0x6EF3,
	0xBA77: 0x6EF4,
	0xE26D: 0x6EF5,
	0xE2B0: 0x6EF6,
	0xBAB1: 0x6EF7,
	0xE271: 0x6EF8,
	0xE2A3: 0x6EF9,
	0x9BA1: 0x6EFA,
	0xE273: 0x6EFB,
	0xE2B3: 0x6EFC,
	0xE2AF: 0x6EFD,
	0xBA75: 0x6EFE,
	0xBAA1: 0x6EFF,
	0xE653: 0x6F00,
	0xBAAE: 0x6F01,
	0xBA7D: 0x6F02,
	0xE26F: 0x6F03,
	0x9BA2: 0x6F04,
	0xE2AE: 0x6F05,
	0xBAA3: 0x6F06,
	0xE2AB: 0x6F07,
	0xE2B8: 0x6F08,
	0xE275: 0x6F09,
	0xE27E: 0x6F0A,
	0x9BA3: 0x6F0B,
	0x9BA4: 0x6F0C,
	0xE2B6: 0x6F0D,
	0xE2AC: 0x6F0E,
	0xBA7C: 0x6F0F,
	0xFFFD: 0x6F10,
	0xA06F: 0x6F11,
	0xE27C: 0x6F12,
	0xBA76: 0x6F13,
	0xBA74: 0x6F14,
	0xBAA8: 0x6F15,
	0x9BA5: 0x6F16,
	0x9BA6: 0x6F17,
	0xE27A: 0x6F18,
	0xE277: 0x6F19,
	0xE278: 0x6F1A,
	0xFFFD: 0x6F1B,
	0xE2B2: 0x6F1C,
	0xFFFD: 0x6F1D,
	0xE2B7: 0x6F1E,
	0xE2B5: 0x6F1F,
	0xBA7A: 0x6F20,
	0xE2B9: 0x6F21,
	0xBA7E: 0x6F22,
	0xBAA7: 0x6F23,
	0xA070: 0x6F24,
	0xE270: 0x6F25,
	0xE5FA: 0x6F26,
	0xE279: 0x6F27,
	0xFFFD: 0x6F28,
	0xBA78: 0x6F29,
	0xBAAC: 0x6F2A,
	0xBAA9: 0x6F2B,
	0xBA7B: 0x6F2C,
	0xE2A5: 0x6F2D,
	0xE274: 0x6F2E,
	0xBAAA: 0x6F2F,
	0xE2A7: 0x6F30,
	0xBAA4: 0x6F31,
	0xBAA6: 0x6F32,
	0xBA73: 0x6F33,
	0x9BA7: 0x6F34,
	0xE2A9: 0x6F35,
	0xE2A1: 0x6F36,
	0xE272: 0x6F37,
	0xBAA5: 0x6F38,
	0xE2B1: 0x6F39,
	0xE2B4: 0x6F3A,
	0xE27B: 0x6F3B,
	0xE2A8: 0x6F3C,
	0x9BA8: 0x6F3D,
	0xBA79: 0x6F3E,
	0xBCDF: 0x6F3F,
	0xE2A6: 0x6F40,
	0xE5F9: 0x6F41,
	0xFFFD: 0x6F42,
	0xE2AD: 0x6F43,
	0xFCA2: 0x6F44,
	0x8250: 0x6F45,
	0x8FBD: 0x6F46,
	0x8B7C: 0x6F47,
	0xFFFD: 0x6F48,
	0xFFFD: 0x6F49,
	0xFFFD: 0x6F4A,
	0x8BFB: 0x6F4B,
	0xFFFD: 0x6F4C,
	0x89F0: 0x6F4D,
	0xE276: 0x6F4E,
	0xE644: 0x6F4F,
	0xE64E: 0x6F50,
	0xBCE2: 0x6F51,
	0xE64D: 0x6F52,
	0xE659: 0x6F53,
	0xBCE4: 0x6F54,
	0xE64B: 0x6F55,
	0x9BA9: 0x6F56,
	0xE64F: 0x6F57,
	0xBCEF: 0x6F58,
	0xFFFD: 0x6F59,
	0xE646: 0x6F5A,
	0xBCE7: 0x6F5B,
	0x90B9: 0x6F5C,
	0xE652: 0x6F5D,
	0xE9F0: 0x6F5E,
	0xBCF3: 0x6F5F,
	0xBCF2: 0x6F60,
	0xE654: 0x6F61,
	0xE643: 0x6F62,
	0xE65E: 0x6F63,
	0xBCED: 0x6F64,
	0xFFFD: 0x6F65,
	0xBCE3: 0x6F66,
	0xE657: 0x6F67,
	0xFFFD: 0x6F68,
	0xE65B: 0x6F69,
	0xE660: 0x6F6A,
	0xE655: 0x6F6B,
	0xE649: 0x6F6C,
	0xBCE6: 0x6F6D,
	0xBCE9: 0x6F6E,
	0xBCF1: 0x6F6F,
	0xBCEC: 0x6F70,
	0xFFFD: 0x6F71,
	0xE64C: 0x6F72,
	0xE2A2: 0x6F73,
	0xA071: 0x6F74,
	0xFFFD: 0x6F75,
	0xE648: 0x6F76,
	0xE65F: 0x6F77,
	0xBCE8: 0x6F78,
	0x9BAA: 0x6F79,
	0xBCEB: 0x6F7A,
	0xE661: 0x6F7B,
	0xBCE0: 0x6F7C,
	0xE656: 0x6F7D,
	0xE5FB: 0x6F7E,
	0xE65C: 0x6F7F,
	0xC0DF: 0x6F80,
	0x956B: 0x6F81,
	0xE64A: 0x6F82,
	0xFFFD: 0x6F83,
	0xBCE1: 0x6F84,
	0xE645: 0x6F85,
	0xBCE5: 0x6F86,
	0xE5FC: 0x6F87,
	0xBAAB: 0x6F88,
	0xE641: 0x6F89,
	0x9BAB: 0x6F8A,
	0xE65A: 0x6F8B,
	0xE642: 0x6F8C,
	0xE640: 0x6F8D,
	0xBCEA: 0x6F8E,
	0xFFFD: 0x6F8F,
	0xE658: 0x6F90,
	0xA072: 0x6F91,
	0xE5FE: 0x6F92,
	0xE651: 0x6F93,
	0xE650: 0x6F94,
	0xE65D: 0x6F95,
	0xE647: 0x6F96,
	0xBCEE: 0x6F97,
	0xFFFD: 0x6F98,
	0xFFFD: 0x6F99,
	0xFFFD: 0x6F9A,
	0xFFFD: 0x6F9B,
	0x8BFA: 0x6F9C,
	0x9BAC: 0x6F9D,
	0xE9F3: 0x6F9E,
	0x9BAD: 0x6F9F,
	0xBF49: 0x6FA0,
	0xBEFE: 0x6FA1,
	0xEA40: 0x6FA2,
	0xE9EB: 0x6FA3,
	0xBF41: 0x6FA4,
	0xE9F7: 0x6FA5,
	0xBF48: 0x6FA6,
	0xBF43: 0x6FA7,
	0xE9F5: 0x6FA8,
	0xED4F: 0x6FA9,
	0xE9FB: 0x6FAA,
	0xEA42: 0x6FAB,
	0xE9FA: 0x6FAC,
	0xE9E9: 0x6FAD,
	0xE9F8: 0x6FAE,
	0xEA44: 0x6FAF,
	0xEA46: 0x6FB0,
	0xBEFD: 0x6FB1,
	0xEA45: 0x6FB2,
	0xBF44: 0x6FB3,
	0xBF4A: 0x6FB4,
	0xA073: 0x6FB5,
	0xBF47: 0x6FB6,
	0xFFFD: 0x6FB7,
	0xE9FE: 0x6FB8,
	0xBF46: 0x6FB9,
	0xE9F9: 0x6FBA,
	0x9BAE: 0x6FBB,
	0xE9ED: 0x6FBC,
	0xE9F2: 0x6FBD,
	0x9BAF: 0x6FBE,
	0xE9FD: 0x6FBF,
	0xBF45: 0x6FC0,
	0xBF42: 0x6FC1,
	0xBEFC: 0x6FC2,
	0xBF40: 0x6FC3,
	0xE9F1: 0x6FC4,
	0xFFFD: 0x6FC5,
	0xE5FD: 0x6FC6,
	0xE9EC: 0x6FC7,
	0xE9EF: 0x6FC8,
	0xEA41: 0x6FC9,
	0xE9F4: 0x6FCA,
	0xE9EA: 0x6FCB,
	0xED4E: 0x6FCC,
	0xEA43: 0x6FCD,
	0xE9EE: 0x6FCE,
	0xE9FC: 0x6FCF,
	0xFFFD: 0x6FD0,
	0x8B7D: 0x6FD1,
	0x8BA1: 0x6FD2,
	0x9BB0: 0x6FD3,
	0xED51: 0x6FD4,
	0xC0E3: 0x6FD5,
	0xFFFD: 0x6FD6,
	0xFFFD: 0x6FD7,
	0xC0D7: 0x6FD8,
	0x9BB1: 0x6FD9,
	0xFCA4: 0x6FDA,
	0xC0DB: 0x6FDB,
	0xED53: 0x6FDC,
	0xED59: 0x6FDD,
	0xED57: 0x6FDE,
	0xC0D9: 0x6FDF,
	0xC0DA: 0x6FE0,
	0xC0E1: 0x6FE1,
	0xED5A: 0x6FE2,
	0xED52: 0x6FE3,
	0xC0DC: 0x6FE4,
	0xFFFD: 0x6FE5,
	0xED56: 0x6FE6,
	0xED55: 0x6FE7,
	0xED5B: 0x6FE8,
	0xC0E2: 0x6FE9,
	0xFFFD: 0x6FEA,
	0xC0DD: 0x6FEB,
	0xC0E0: 0x6FEC,
	0xED54: 0x6FED,
	0xC0E4: 0x6FEE,
	0xC0DE: 0x6FEF,
	0xC0E5: 0x6FF0,
	0xC0D8: 0x6FF1,
	0xED58: 0x6FF2,
	0xA074: 0x6FF3,
	0xED50: 0x6FF4,
	0xA075: 0x6FF5,
	0x95C6: 0x6FF6,
	0xEFF7: 0x6FF7,
	0x9BB2: 0x6FF8,
	0xFFFD: 0x6FF9,
	0xC271: 0x6FFA,
	0xEFF4: 0x6FFB,
	0xEFF6: 0x6FFC,
	0xFFFD: 0x6FFD,
	0xC26F: 0x6FFE,
	0xEFF2: 0x6FFF,
	0xEFF3: 0x7000,
	0xEFEE: 0x7001,
	0xFFFD: 0x7002,
	0x9BB3: 0x7003,
	0xE9F6: 0x7004,
	0xEFEF: 0x7005,
	0xC270: 0x7006,
	0xEFEB: 0x7007,
	0xFFFD: 0x7008,
	0xC26D: 0x7009,
	0xEFF8: 0x700A,
	0xC26E: 0x700B,
	0xEFEC: 0x700C,
	0xEFED: 0x700D,
	0xEFF1: 0x700E,
	0xC273: 0x700F,
	0xFFFD: 0x7010,
	0xC272: 0x7011,
	0xFFFD: 0x7012,
	0xFFFD: 0x7013,
	0xEFF0: 0x7014,
	0xC378: 0x7015,
	0xF25F: 0x7016,
	0xF265: 0x7017,
	0xC379: 0x7018,
	0xF25C: 0x7019,
	0xC376: 0x701A,
	0xC373: 0x701B,
	0xF267: 0x701C,
	0xC377: 0x701D,
	0xFEA1: 0x701E,
	0xC374: 0x701F,
	0xF25E: 0x7020,
	0xF261: 0x7021,
	0xF262: 0x7022,
	0xF263: 0x7023,
	0xF266: 0x7024,
	0xFFFD: 0x7025,
	0xEFF5: 0x7026,
	0xF25D: 0x7027,
	0xC375: 0x7028,
	0xF264: 0x7029,
	0xF268: 0x702A,
	0xF260: 0x702B,
	0x9340: 0x702C,
	0xFFFD: 0x702D,
	0xFFFD: 0x702E,
	0xF45D: 0x702F,
	0xC46A: 0x7030,
	0xF460: 0x7031,
	0xC46B: 0x7032,
	0xF468: 0x7033,
	0xF45F: 0x7034,
	0xF45C: 0x7035,
	0xFFFD: 0x7036,
	0xF45E: 0x7037,
	0xF462: 0x7038,
	0xF465: 0x7039,
	0xF464: 0x703A,
	0xF467: 0x703B,
	0xF45B: 0x703C,
	0xFFFD: 0x703D,
	0xC469: 0x703E,
	0xF463: 0x703F,
	0xF466: 0x7040,
	0xF469: 0x7041,
	0xF461: 0x7042,
	0xF5D3: 0x7043,
	0xF5D4: 0x7044,
	0xF5D8: 0x7045,
	0xF5D9: 0x7046,
	0xFFFD: 0x7047,
	0xF5D6: 0x7048,
	0xF5D7: 0x7049,
	0xF5D5: 0x704A,
	0x9BB4: 0x704B,
	0xC4E9: 0x704C,
	0x9BB5: 0x704D,
	0xFFFD: 0x704E,
	0x9076: 0x704F,
	0x9BB6: 0x7050,
	0xC578: 0x7051,
	0xF6EB: 0x7052,
	0xFFFD: 0x7053,
	0x9BB7: 0x7054,
	0xF6E8: 0x7055,
	0xF6E9: 0x7056,
	0xF6EA: 0x7057,
	0xC579: 0x7058,
	0xFFFD: 0x7059,
	0xF7E5: 0x705A,
	0xF7E4: 0x705B,
	0x9BB8: 0x705C,
	0xF8AF: 0x705D,
	0xC5F4: 0x705E,
	0xF8AD: 0x705F,
	0xF8B0: 0x7060,
	0xF8AE: 0x7061,
	0xF8F5: 0x7062,
	0xC657: 0x7063,
	0xC665: 0x7064,
	0xF9A3: 0x7065,
	0xF96C: 0x7066,
	0x9BB9: 0x7067,
	0xF9A2: 0x7068,
	0xF9D0: 0x7069,
	0xF9D1: 0x706A,
	0xA4F5: 0x706B,
	0x9CF6: 0x706C,
	0x85D9: 0x706D,
	0xFFFD: 0x706E,
	0x88F9: 0x706F,
	0xA6C7: 0x7070,
	0xCA41: 0x7071,
	0xFFFD: 0x7072,
	0xFFFD: 0x7073,
	0xCB5E: 0x7074,
	0x8D5F: 0x7075,
	0xA85F: 0x7076,
	0x9BBA: 0x7077,
	0xA862: 0x7078,
	0x9BBB: 0x7079,
	0xCB5F: 0x707A,
	0xFFFD: 0x707B,
	0xA860: 0x707C,
	0xA861: 0x707D,
	0x834D: 0x707E,
	0x89F2: 0x707F,
	0x85DF: 0x7080,
	0xFCA5: 0x7081,
	0xCD58: 0x7082,
	0xCD5A: 0x7083,
	0xCD55: 0x7084,
	0xCD52: 0x7085,
	0xCD54: 0x7086,
	0xFFFD: 0x7087,
	0xFFFD: 0x7088,
	0x93F4: 0x7089,
	0xAAA4: 0x708A,
	0x9BBC: 0x708B,
	0xFFFD: 0x708C,
	0xFEA3: 0x708D,
	0xAAA2: 0x708E,
	0x9BBD: 0x708F,
	0xFFFD: 0x7090,
	0xCD56: 0x7091,
	0xAAA3: 0x7092,
	0xCD53: 0x7093,
	0xCD50: 0x7094,
	0xAAA1: 0x7095,
	0xCD57: 0x7096,
	0xFFFD: 0x7097,
	0xCD51: 0x7098,
	0xAAA5: 0x7099,
	0xCD59: 0x709A,
	0xFFFD: 0x709B,
	0x8E45: 0x709C,
	0x8E76: 0x709D,
	0xFFFD: 0x709E,
	0xCFAF: 0x709F,
	0x9BBE: 0x70A0,
	0xCFB3: 0x70A1,
	0xFFFD: 0x70A2,
	0x9BBF: 0x70A3,
	0xACB7: 0x70A4,
	0x9BC0: 0x70A5,
	0x9BC1: 0x70A6,
	0x9BC2: 0x70A7,
	0xFFFD: 0x70A8,
	0xCFB6: 0x70A9,
	0xFFFD: 0x70AA,
	0xACAF: 0x70AB,
	0xACB2: 0x70AC,
	0xACB4: 0x70AD,
	0xACB6: 0x70AE,
	0xACB3: 0x70AF,
	0xCFB2: 0x70B0,
	0xCFB1: 0x70B1,
	0xFFFD: 0x70B2,
	0xACB1: 0x70B3,
	0xCFB4: 0x70B4,
	0xCFB5: 0x70B5,
	0xFFFD: 0x70B6,
	0xCFAE: 0x70B7,
	0xACB5: 0x70B8,
	0x8ABB: 0x70B9,
	0xACB0: 0x70BA,
	0xA076: 0x70BB,
	0x85DE: 0x70BC,
	0x88F7: 0x70BD,
	0xCFB0: 0x70BE,
	0xFFFD: 0x70BF,
	0xA077: 0x70C0,
	0x8BA3: 0x70C1,
	0x8C7A: 0x70C2,
	0x8DD1: 0x70C3,
	0x9BC3: 0x70C4,
	0xD277: 0x70C5,
	0xD278: 0x70C6,
	0xD279: 0x70C7,
	0xAF50: 0x70C8,
	0xFFFD: 0x70C9,
	0xAF4C: 0x70CA,
	0xD26E: 0x70CB,
	0x9BC4: 0x70CC,
	0xD276: 0x70CD,
	0xD27B: 0x70CE,
	0xAF51: 0x70CF,
	0x9BC5: 0x70D0,
	0xD26C: 0x70D1,
	0xD272: 0x70D2,
	0xD26B: 0x70D3,
	0xD275: 0x70D4,
	0xFC57: 0x70D5,
	0x9BC6: 0x70D6,
	0xD271: 0x70D7,
	0xAF4D: 0x70D8,
	0xAF4F: 0x70D9,
	0xD27A: 0x70DA,
	0x89F3: 0x70DB,
	0xD26A: 0x70DC,
	0xD26D: 0x70DD,
	0xD273: 0x70DE,
	0x95AF: 0x70DF,
	0xD274: 0x70E0,
	0xD27C: 0x70E1,
	0xD270: 0x70E2,
	0xFFFD: 0x70E3,
	0xAF4E: 0x70E4,
	0xFFFD: 0x70E5,
	0x85DD: 0x70E6,
	0x88F8: 0x70E7,
	0x8EEA: 0x70E8,
	0x89F4: 0x70E9,
	0xFFFD: 0x70EA,
	0x88FA: 0x70EB,
	0x8AD8: 0x70EC,
	0x87F1: 0x70ED,
	0xFFFD: 0x70EE,
	0xB26D: 0x70EF,
	0xD64E: 0x70F0,
	0x9549: 0x70F1,
	0xFFFD: 0x70F2,
	0xD650: 0x70F3,
	0xD64C: 0x70F4,
	0x9C40: 0x70F5,
	0xD658: 0x70F6,
	0xD64A: 0x70F7,
	0xD657: 0x70F8,
	0xB269: 0x70F9,
	0xD648: 0x70FA,
	0xDA5B: 0x70FB,
	0xD652: 0x70FC,
	0xB26C: 0x70FD,
	0x9C4B: 0x70FE,
	0xD653: 0x70FF,
	0xD656: 0x7100,
	0xFFFD: 0x7101,
	0xD65A: 0x7102,
	0xFFFD: 0x7103,
	0xD64F: 0x7104,
	0x9C4C: 0x7105,
	0xD654: 0x7106,
	0xFFFD: 0x7107,
	0xFFFD: 0x7108,
	0xB26A: 0x7109,
	0xB26B: 0x710A,
	0xD659: 0x710B,
	0xD64D: 0x710C,
	0xD649: 0x710D,
	0xD65B: 0x710E,
	0xA078: 0x710F,
	0xD651: 0x7110,
	0xFFFD: 0x7111,
	0xFFFD: 0x7112,
	0xD655: 0x7113,
	0x8244: 0x7114,
	0x85E0: 0x7115,
	0x88FB: 0x7116,
	0xD64B: 0x7117,
	0x8AD9: 0x7118,
	0xB548: 0x7119,
	0xB549: 0x711A,
	0xDA65: 0x711B,
	0xB54F: 0x711C,
	0x9C4D: 0x711D,
	0xDA59: 0x711E,
	0xDA62: 0x711F,
	0xDA58: 0x7120,
	0xB54C: 0x7121,
	0xDA60: 0x7122,
	0xDA5E: 0x7123,
	0xFFFD: 0x7124,
	0xDA5F: 0x7125,
	0xB54A: 0x7126,
	0xFFFD: 0x7127,
	0xDA63: 0x7128,
	0x9C4E: 0x7129,
	0xFFFD: 0x712A,
	0x9C4F: 0x712B,
	0x9C50: 0x712C,
	0xFFFD: 0x712D,
	0xDA5C: 0x712E,
	0xDA5A: 0x712F,
	0xB54B: 0x7130,
	0xDA5D: 0x7131,
	0xDA61: 0x7132,
	0x9C51: 0x7133,
	0xFCA7: 0x7134,
	0x9C52: 0x7135,
	0xB54D: 0x7136,
	0xFFFD: 0x7137,
	0xFFFD: 0x7138,
	0xFFFD: 0x7139,
	0xDA64: 0x713A,
	0x9C53: 0x713B,
	0x92E5: 0x713C,
	0xFFFD: 0x713D,
	0x9C54: 0x713E,
	0xFE76: 0x713F,
	0x9C55: 0x7140,
	0xDE70: 0x7141,
	0xDE77: 0x7142,
	0xDE79: 0x7143,
	0xDEA1: 0x7144,
	0xFB66: 0x7145,
	0xB7DA: 0x7146,
	0xDE6B: 0x7147,
	0xFFFD: 0x7148,
	0xB7D2: 0x7149,
	0x954F: 0x714A,
	0xDE7A: 0x714B,
	0xB7D7: 0x714C,
	0xDEA2: 0x714D,
	0xB7CE: 0x714E,
	0x9C56: 0x714F,
	0xDE7D: 0x7150,
	0x955F: 0x7151,
	0xDE6D: 0x7152,
	0xDE7E: 0x7153,
	0xDE6C: 0x7154,
	0xA07A: 0x7155,
	0xB7DC: 0x7156,
	0x9DCD: 0x7157,
	0xDE78: 0x7158,
	0xB7CF: 0x7159,
	0xDEA3: 0x715A,
	0xFFFD: 0x715B,
	0xB7D4: 0x715C,
	0xDE71: 0x715D,
	0xB7D9: 0x715E,
	0xDE7C: 0x715F,
	0xDE6F: 0x7160,
	0xDE76: 0x7161,
	0xDE72: 0x7162,
	0xDE6E: 0x7163,
	0xB7D1: 0x7164,
	0xB7D8: 0x7165,
	0xB7D6: 0x7166,
	0xB7D3: 0x7167,
	0xB7DB: 0x7168,
	0xB7D0: 0x7169,
	0xDE75: 0x716A,
	0x9C57: 0x716B,
	0xB7D5: 0x716C,
	0xFFFD: 0x716D,
	0xB54E: 0x716E,
	0xFFFD: 0x716F,
	0xDE7B: 0x7170,
	0xFE53: 0x7171,
	0xDE73: 0x7172,
	0xA07B: 0x7173,
	0xFFFD: 0x7174,
	0x9C58: 0x7175,
	0xFCA9: 0x7176,
	0x9C59: 0x7177,
	0xDE74: 0x7178,
	0xFFFD: 0x7179,
	0xA07C: 0x717A,
	0xE2C1: 0x717B,
	0x9C5A: 0x717C,
	0xBAB4: 0x717D,
	0x9C5B: 0x717E,
	0xFFFD: 0x717F,
	0xE2BD: 0x7180,
	0xE2C3: 0x7181,
	0xE2BF: 0x7182,
	0xFFFD: 0x7183,
	0xBAB6: 0x7184,
	0xE2BE: 0x7185,
	0xE2C2: 0x7186,
	0xE2BA: 0x7187,
	0xA0D8: 0x7188,
	0xE2BC: 0x7189,
	0xBAB5: 0x718A,
	0xFFFD: 0x718B,
	0x9C5C: 0x718C,
	0xFFFD: 0x718D,
	0x9C5D: 0x718E,
	0xE2C0: 0x718F,
	0xE2BB: 0x7190,
	0x9C5E: 0x7191,
	0xBAB7: 0x7192,
	0xFFFD: 0x7193,
	0xBAB2: 0x7194,
	0x94AB: 0x7195,
	0x9C5F: 0x7196,
	0xE2C4: 0x7197,
	0xA0E7: 0x7198,
	0xBAB3: 0x7199,
	0xE667: 0x719A,
	0xE664: 0x719B,
	0xE670: 0x719C,
	0xE66A: 0x719D,
	0xE66C: 0x719E,
	0xBCF4: 0x719F,
	0xE666: 0x71A0,
	0xE66E: 0x71A1,
	0x9C60: 0x71A2,
	0x9C61: 0x71A3,
	0xE66D: 0x71A4,
	0xE66B: 0x71A5,
	0xFFFD: 0x71A6,
	0xE671: 0x71A7,
	0xBCF7: 0x71A8,
	0xE668: 0x71A9,
	0xE66F: 0x71AA,
	0xFFFD: 0x71AB,
	0xBCF5: 0x71AC,
	0x9C62: 0x71AD,
	0xFFFD: 0x71AE,
	0xE663: 0x71AF,
	0xE665: 0x71B0,
	0xBCF6: 0x71B1,
	0xE662: 0x71B2,
	0xE672: 0x71B3,
	0x9C63: 0x71B4,
	0xE669: 0x71B5,
	0xFFFD: 0x71B6,
	0x9C64: 0x71B7,
	0xEA4A: 0x71B8,
	0xBF51: 0x71B9,
	0x9C65: 0x71BA,
	0xFFFD: 0x71BB,
	0xEA55: 0x71BC,
	0xEA53: 0x71BD,
	0xBF4B: 0x71BE,
	0xEA49: 0x71BF,
	0xEA4C: 0x71C0,
	0xEA4D: 0x71C1,
	0xEA48: 0x71C2,
	0xBF55: 0x71C3,
	0xBF56: 0x71C4,
	0xEA47: 0x71C5,
	0xEA56: 0x71C6,
	0xEA51: 0x71C7,
	0xBF4F: 0x71C8,
	0xBF4C: 0x71C9,
	0xEA50: 0x71CA,
	0xEA4E: 0x71CB,
	0xFFFD: 0x71CC,
	0xFFFD: 0x71CD,
	0xBF52: 0x71CE,
	0xEA52: 0x71CF,
	0xBF4D: 0x71D0,
	0x9C66: 0x71D1,
	0xBF4E: 0x71D2,
	0xFFFD: 0x71D3,
	0xEA4F: 0x71D4,
	0xBF50: 0x71D5,
	0xEA4B: 0x71D6,
	0xA0E8: 0x71D7,
	0xEA54: 0x71D8,
	0xBF53: 0x71D9,
	0xEA57: 0x71DA,
	0xEA58: 0x71DB,
	0xBF54: 0x71DC,
	0x9C67: 0x71DD,
	0xFFFD: 0x71DE,
	0xC0E7: 0x71DF,
	0xC0EE: 0x71E0,
	0xED5C: 0x71E1,
	0xED62: 0x71E2,
	0xFFFD: 0x71E3,
	0xED60: 0x71E4,
	0xC0EA: 0x71E5,
	0xC0E9: 0x71E6,
	0xC0E6: 0x71E7,
	0xED5E: 0x71E8,
	0xFFFD: 0x71E9,
	0xFFFD: 0x71EA,
	0x9C68: 0x71EB,
	0xC0EC: 0x71EC,
	0xC0EB: 0x71ED,
	0xC0E8: 0x71EE,
	0xFFFD: 0x71EF,
	0xED61: 0x71F0,
	0xED5D: 0x71F1,
	0xED5F: 0x71F2,
	0xFFFD: 0x71F3,
	0xC0ED: 0x71F4,
	0xA0F5: 0x71F5,
	0xFB70: 0x71F6,
	0xFFFD: 0x71F7,
	0xC277: 0x71F8,
	0xEFFB: 0x71F9,
	0xFFFD: 0x71FA,
	0xC274: 0x71FB,
	0xC275: 0x71FC,
	0xEFFD: 0x71FD,
	0xC276: 0x71FE,
	0xEFFA: 0x71FF,
	0x9C69: 0x7200,
	0xEFF9: 0x7201,
	0xF26C: 0x7202,
	0xEFFC: 0x7203,
	0xFFFD: 0x7204,
	0xF26D: 0x7205,
	0xC37A: 0x7206,
	0xF26B: 0x7207,
	0xFFFD: 0x7208,
	0x9C6A: 0x7209,
	0xF26A: 0x720A,
	0xFFFD: 0x720B,
	0xF269: 0x720C,
	0xC37B: 0x720D,
	0x9C6B: 0x720E,
	0x9C6C: 0x720F,
	0xC46C: 0x7210,
	0xFFFD: 0x7211,
	0xFFFD: 0x7212,
	0xF46A: 0x7213,
	0xF46B: 0x7214,
	0xFCAC: 0x7215,
	0x9C6D: 0x7216,
	0x9C6E: 0x7217,
	0xFFFD: 0x7218,
	0xF5DC: 0x7219,
	0xF5DB: 0x721A,
	0xC4EA: 0x721B,
	0xFFFD: 0x721C,
	0xF5DA: 0x721D,
	0xF6EC: 0x721E,
	0xF6ED: 0x721F,
	0xFFFD: 0x7220,
	0xFFFD: 0x7221,
	0xF7E6: 0x7222,
	0xF8B1: 0x7223,
	0x9C6F: 0x7224,
	0x9D5A: 0x7225,
	0xF8F6: 0x7226,
	0xF9BC: 0x7227,
	0xC679: 0x7228,
	0xF9C6: 0x7229,
	0xA4F6: 0x722A,
	0x91C9: 0x722B,
	0xAAA6: 0x722C,
	0xAAA7: 0x722D,
	0x9C71: 0x722E,
	0xFFFD: 0x722F,
	0xACB8: 0x7230,
	0x85C6: 0x7231,
	0xFA64: 0x7232,
	0xFFFD: 0x7233,
	0xFFFD: 0x7234,
	0xC0EF: 0x7235,
	0xA4F7: 0x7236,
	0x85E1: 0x7237,
	0xAAA8: 0x7238,
	0xAF52: 0x7239,
	0xB7DD: 0x723A,
	0xA4F8: 0x723B,
	0xFA65: 0x723C,
	0xB26E: 0x723D,
	0xBAB8: 0x723E,
	0xC962: 0x723F,
	0x95A7: 0x7240,
	0xCFB7: 0x7241,
	0xD27D: 0x7242,
	0xFFFD: 0x7243,
	0xE2C5: 0x7244,
	0xFFFD: 0x7245,
	0xC0F0: 0x7246,
	0xA4F9: 0x7247,
	0xAAA9: 0x7248,
	0xCFB8: 0x7249,
	0xCFB9: 0x724A,
	0xDA66: 0x724B,
	0xB550: 0x724C,
	0x8BA4: 0x724D,
	0xFFFD: 0x724E,
	0xDEA4: 0x724F,
	0xFCAD: 0x7250,
	0xFFFD: 0x7251,
	0xB7DE: 0x7252,
	0xE2C6: 0x7253,
	0xFFFD: 0x7254,
	0x956E: 0x7255,
	0xBCF8: 0x7256,
	0x9C73: 0x7257,
	0xC37C: 0x7258,
	0xA4FA: 0x7259,
	0xDA67: 0x725A,
	0xA4FB: 0x725B,
	0x9C74: 0x725C,
	0xA6C9: 0x725D,
	0xCA42: 0x725E,
	0xA6C8: 0x725F,
	0xA865: 0x7260,
	0xA864: 0x7261,
	0xA863: 0x7262,
	0xCB60: 0x7263,
	0xFFFD: 0x7264,
	0xFFFD: 0x7265,
	0xFA66: 0x7266,
	0xAAAA: 0x7267,
	0xFFFD: 0x7268,
	0xAAAB: 0x7269,
	0xCD5B: 0x726A,
	0xFFFD: 0x726B,
	0xCFBA: 0x726C,
	0xFFFD: 0x726D,
	0xCFBD: 0x726E,
	0xACBA: 0x726F,
	0xCFBB: 0x7270,
	0xFFFD: 0x7271,
	0xACB9: 0x7272,
	0xCFBC: 0x7273,
	0xACBB: 0x7274,
	0x8461: 0x7275,
	0xD2A2: 0x7276,
	0xD2A1: 0x7277,
	0xD27E: 0x7278,
	0xAF53: 0x7279,
	0x8C7B: 0x727A,
	0xD65D: 0x727B,
	0xD65E: 0x727C,
	0xB26F: 0x727D,
	0xD65C: 0x727E,
	0xD65F: 0x727F,
	0xB552: 0x7280,
	0xB270: 0x7281,
	0xFA67: 0x7282,
	0xFFFD: 0x7283,
	0xB551: 0x7284,
	0xDA6B: 0x7285,
	0xDA6A: 0x7286,
	0xFCAE: 0x7287,
	0xDA68: 0x7288,
	0xDA69: 0x7289,
	0x8BA5: 0x728A,
	0xDA6C: 0x728B,
	0xDEA6: 0x728C,
	0xDEA5: 0x728D,
	0xDEA9: 0x728E,
	0xFA68: 0x728F,
	0xDEA8: 0x7290,
	0xDEA7: 0x7291,
	0xBAB9: 0x7292,
	0xE2C9: 0x7293,
	0x9C75: 0x7294,
	0xE2C8: 0x7295,
	0xBABA: 0x7296,
	0xE2C7: 0x7297,
	0xE673: 0x7298,
	0xFFFD: 0x7299,
	0xE674: 0x729A,
	0xBCF9: 0x729B,
	0xFFFD: 0x729C,
	0xEA59: 0x729D,
	0xEA5A: 0x729E,
	0xFA69: 0x729F,
	0x9271: 0x72A0,
	0xF272: 0x72A1,
	0xC37D: 0x72A2,
	0xF271: 0x72A3,
	0xF270: 0x72A4,
	0xF26E: 0x72A5,
	0xF26F: 0x72A6,
	0xC4EB: 0x72A7,
	0xF46C: 0x72A8,
	0xF6EE: 0x72A9,
	0xF8F7: 0x72AA,
	0xFFFD: 0x72AB,
	0xA4FC: 0x72AC,
	0xFA6A: 0x72AD,
	0xC9A5: 0x72AE,
	0xA5C7: 0x72AF,
	0xC9A6: 0x72B0,
	0xFA6B: 0x72B1,
	0xFCB0: 0x72B2,
	0xFFFD: 0x72B3,
	0xCA43: 0x72B4,
	0xCA44: 0x72B5,
	0x835D: 0x72B6,
	0x8ADA: 0x72B7,
	0xFA6C: 0x72B8,
	0x84F6: 0x72B9,
	0xCB66: 0x72BA,
	0xFFFD: 0x72BB,
	0xFFFD: 0x72BC,
	0xCB62: 0x72BD,
	0xFA6D: 0x72BE,
	0xCB61: 0x72BF,
	0xAAAC: 0x72C0,
	0xCB65: 0x72C1,
	0xA867: 0x72C2,
	0xCB63: 0x72C3,
	0xA866: 0x72C4,
	0xCB67: 0x72C5,
	0xCB64: 0x72C6,
	0xFFFD: 0x72C7,
	0x83C1: 0x72C8,
	0xCD5F: 0x72C9,
	0xCFBE: 0x72CA,
	0xCD5D: 0x72CB,
	0xCD64: 0x72CC,
	0xFA6E: 0x72CD,
	0xAAAD: 0x72CE,
	0xFFFD: 0x72CF,
	0xAAB0: 0x72D0,
	0xCD65: 0x72D1,
	0xCD61: 0x72D2,
	0xFFFD: 0x72D3,
	0xCD62: 0x72D4,
	0xFFFD: 0x72D5,
	0xCD5C: 0x72D6,
	0xAAAF: 0x72D7,
	0xCD5E: 0x72D8,
	0xAAAE: 0x72D9,
	0xCD63: 0x72DA,
	0xFA6F: 0x72DB,
	0xCD60: 0x72DC,
	0xFFFD: 0x72DD,
	0x89F6: 0x72DE,
	0xCFC2: 0x72DF,
	0xACBD: 0x72E0,
	0xACBE: 0x72E1,
	0xFCB1: 0x72E2,
	0xCFC5: 0x72E3,
	0xCFBF: 0x72E4,
	0xFFFD: 0x72E5,
	0xCFC4: 0x72E6,
	0xFFFD: 0x72E7,
	0xCFC0: 0x72E8,
	0xACBC: 0x72E9,
	0xCFC3: 0x72EA,
	0xCFC1: 0x72EB,
	0x88FC: 0x72EC,
	0x83C0: 0x72ED,
	0x85E2: 0x72EE,
	0x8EEC: 0x72EF,
	0x8462: 0x72F0,
	0x86E2: 0x72F1,
	0x8E47: 0x72F2,
	0xD2A8: 0x72F3,
	0xD2A5: 0x72F4,
	0xFFFD: 0x72F5,
	0xD2A7: 0x72F6,
	0xAF58: 0x72F7,
	0xAF57: 0x72F8,
	0xAF55: 0x72F9,
	0xD2A4: 0x72FA,
	0xD2A9: 0x72FB,
	0xAF54: 0x72FC,
	0xAF56: 0x72FD,
	0xD2A6: 0x72FE,
	0xD667: 0x72FF,
	0xD2A3: 0x7300,
	0xD2AA: 0x7301,
	0xFCB2: 0x7302,
	0x8EEB: 0x7303,
	0x9C76: 0x7304,
	0xFFFD: 0x7305,
	0xFFFD: 0x7306,
	0xD662: 0x7307,
	0xD666: 0x7308,
	0xFFFD: 0x7309,
	0xD665: 0x730A,
	0xDA6E: 0x730B,
	0xDA79: 0x730C,
	0xFFFD: 0x730D,
	0x8ADB: 0x730E,
	0xD668: 0x730F,
	0x9C77: 0x7310,
	0xD663: 0x7311,
	0xDA6D: 0x7312,
	0xB274: 0x7313,
	0xFFFD: 0x7314,
	0x8F55: 0x7315,
	0xB273: 0x7316,
	0xD661: 0x7317,
	0xD664: 0x7318,
	0xB275: 0x7319,
	0xFFFD: 0x731A,
	0xB272: 0x731B,
	0xB271: 0x731C,
	0xD660: 0x731D,
	0xD669: 0x731E,
	0x93E6: 0x731F,
	0xFFFD: 0x7320,
	0x8CD3: 0x7321,
	0xDA70: 0x7322,
	0xDA77: 0x7323,
	0xFA70: 0x7324,
	0xB554: 0x7325,
	0xDA76: 0x7326,
	0xDA73: 0x7327,
	0xFCB4: 0x7328,
	0xB556: 0x7329,
	0x95BD: 0x732A,
	0x95BC: 0x732B,
	0xFCAF: 0x732C,
	0xDA75: 0x732D,
	0x9552: 0x732E,
	0xFA71: 0x732F,
	0xDA6F: 0x7330,
	0xDA71: 0x7331,
	0xDA74: 0x7332,
	0xDA72: 0x7333,
	0xB555: 0x7334,
	0xDA78: 0x7335,
	0xB553: 0x7336,
	0xB7DF: 0x7337,
	0xFA72: 0x7338,
	0xFA73: 0x7339,
	0xDEAD: 0x733A,
	0xDEAC: 0x733B,
	0xDEAA: 0x733C,
	0xFFFD: 0x733D,
	0xB7E2: 0x733E,
	0xB7E1: 0x733F,
	0xDEAE: 0x7340,
	0x9C78: 0x7341,
	0xDEAB: 0x7342,
	0xE2CA: 0x7343,
	0xBABB: 0x7344,
	0xB7E0: 0x7345,
	0xFFFD: 0x7346,
	0xFFFD: 0x7347,
	0xFCB3: 0x7348,
	0xDEB0: 0x7349,
	0xDEAF: 0x734A,
	0xFFFD: 0x734B,
	0xE2CD: 0x734C,
	0xE2CB: 0x734D,
	0xBCFA: 0x734E,
	0xFCB5: 0x734F,
	0xBABC: 0x7350,
	0xE2CC: 0x7351,
	0xE676: 0x7352,
	0xFFFD: 0x7353,
	0xFFFD: 0x7354,
	0xFFFD: 0x7355,
	0xFFFD: 0x7356,
	0xBCFB: 0x7357,
	0xE675: 0x7358,
	0xE67E: 0x7359,
	0xE67D: 0x735A,
	0xE67B: 0x735B,
	0xFFFD: 0x735C,
	0xE67A: 0x735D,
	0xE677: 0x735E,
	0xE678: 0x735F,
	0xE679: 0x7360,
	0xE67C: 0x7361,
	0xE6A1: 0x7362,
	0x92DE: 0x7363,
	0xFFFD: 0x7364,
	0xEA5F: 0x7365,
	0xEA5C: 0x7366,
	0xEA5D: 0x7367,
	0xBF57: 0x7368,
	0xEA5B: 0x7369,
	0xEA61: 0x736A,
	0xEA60: 0x736B,
	0xEA5E: 0x736C,
	0x8BA7: 0x736D,
	0xED64: 0x736E,
	0xED65: 0x736F,
	0xC0F1: 0x7370,
	0xFCB6: 0x7371,
	0xC0F2: 0x7372,
	0xED63: 0x7373,
	0x9C79: 0x7374,
	0xC279: 0x7375,
	0xEFFE: 0x7376,
	0xC278: 0x7377,
	0xC37E: 0x7378,
	0xFFFD: 0x7379,
	0xC3A1: 0x737A,
	0xC46D: 0x737B,
	0xF46E: 0x737C,
	0xF46D: 0x737D,
	0xF5DD: 0x737E,
	0xF6EF: 0x737F,
	0xC57A: 0x7380,
	0xF7E8: 0x7381,
	0xF7E7: 0x7382,
	0xF7E9: 0x7383,
	0xA5C8: 0x7384,
	0xCFC6: 0x7385,
	0xAF59: 0x7386,
	0xB276: 0x7387,
	0xD66A: 0x7388,
	0xA5C9: 0x7389,
	0xC9A7: 0x738A,
	0xA4FD: 0x738B,
	0x9C7A: 0x738C,
	0xFFFD: 0x738D,
	0xCA45: 0x738E,
	0x9C7B: 0x738F,
	0xFFFD: 0x7390,
	0x88FD: 0x7391,
	0xCB6C: 0x7392,
	0xCB6A: 0x7393,
	0xCB6B: 0x7394,
	0xCB68: 0x7395,
	0xA868: 0x7396,
	0xCB69: 0x7397,
	0x9C7C: 0x7398,
	0xFFFD: 0x7399,
	0xFFFD: 0x739A,
	0x86E4: 0x739B,
	0x9C7D: 0x739C,
	0xCD6D: 0x739D,
	0x9C7E: 0x739E,
	0xAAB3: 0x739F,
	0xCD6B: 0x73A0,
	0xCD67: 0x73A1,
	0xCD6A: 0x73A2,
	0xFFFD: 0x73A3,
	0xCD66: 0x73A4,
	0xAAB5: 0x73A5,
	0xCD69: 0x73A6,
	0x9CA1: 0x73A7,
	0xAAB2: 0x73A8,
	0xAAB1: 0x73A9,
	0x9CA2: 0x73AA,
	0xAAB4: 0x73AB,
	0xCD6C: 0x73AC,
	0xCD68: 0x73AD,
	0x8E48: 0x73AE,
	0x89F8: 0x73AF,
	0x8463: 0x73B0,
	0xFFFD: 0x73B1,
	0xACC2: 0x73B2,
	0xACC5: 0x73B3,
	0xCFCE: 0x73B4,
	0xCFCD: 0x73B5,
	0xCFCC: 0x73B6,
	0xACBF: 0x73B7,
	0xCFD5: 0x73B8,
	0xCFCB: 0x73B9,
	0x8BA8: 0x73BA,
	0xACC1: 0x73BB,
	0xD2AF: 0x73BC,
	0xFA74: 0x73BD,
	0xCFD2: 0x73BE,
	0xCFD0: 0x73BF,
	0xACC4: 0x73C0,
	0xFFFD: 0x73C1,
	0xCFC8: 0x73C2,
	0xCFD3: 0x73C3,
	0xFFFD: 0x73C4,
	0xCFCA: 0x73C5,
	0xCFD4: 0x73C6,
	0xCFD1: 0x73C7,
	0xCFC9: 0x73C8,
	0x95BE: 0x73C9,
	0xACC0: 0x73CA,
	0xCFD6: 0x73CB,
	0xCFC7: 0x73CC,
	0xACC3: 0x73CD,
	0xFA75: 0x73CE,
	0x95B6: 0x73CF,
	0x90B2: 0x73D0,
	0x8BFD: 0x73D1,
	0xD2B4: 0x73D2,
	0xD2AB: 0x73D3,
	0xD2B6: 0x73D4,
	0x9CA3: 0x73D5,
	0xD2AE: 0x73D6,
	0xD2B9: 0x73D7,
	0xD2BA: 0x73D8,
	0xD2AC: 0x73D9,
	0xD2B8: 0x73DA,
	0xD2B5: 0x73DB,
	0xD2B3: 0x73DC,
	0xD2B7: 0x73DD,
	0xAF5F: 0x73DE,
	0xFFFD: 0x73DF,
	0xAF5D: 0x73E0,
	0x9CA4: 0x73E1,
	0x9CA5: 0x73E2,
	0xD2B1: 0x73E3,
	0x9CA6: 0x73E4,
	0xD2AD: 0x73E5,
	0x9CA7: 0x73E6,
	0xD2B0: 0x73E7,
	0xD2BB: 0x73E8,
	0xD2B2: 0x73E9,
	0xAF5E: 0x73EA,
	0xCFCF: 0x73EB,
	0xFFFD: 0x73EC,
	0xAF5A: 0x73ED,
	0xAF5C: 0x73EE,
	0x9CA8: 0x73EF,
	0xFFFD: 0x73F0,
	0xFA76: 0x73F1,
	0x85E4: 0x73F2,
	0x9CA9: 0x73F3,
	0xD678: 0x73F4,
	0xD66D: 0x73F5,
	0xD66B: 0x73F6,
	0xFEAA: 0x73F7,
	0xD66C: 0x73F8,
	0x9CAB: 0x73F9,
	0xD673: 0x73FA,
	0x9CAC: 0x73FB,
	0xD674: 0x73FC,
	0xD670: 0x73FD,
	0xB27B: 0x73FE,
	0xD675: 0x73FF,
	0xD672: 0x7400,
	0xD66F: 0x7401,
	0x9CAD: 0x7402,
	0xB279: 0x7403,
	0xD66E: 0x7404,
	0xB277: 0x7405,
	0xB27A: 0x7406,
	0xD671: 0x7407,
	0xD679: 0x7408,
	0xAF5B: 0x7409,
	0xB278: 0x740A,
	0xD677: 0x740B,
	0xD676: 0x740C,
	0xB27C: 0x740D,
	0xFFFD: 0x740E,
	0x8EBF: 0x740F,
	0x86E3: 0x7410,
	0x9CAE: 0x7411,
	0x9CAF: 0x7412,
	0xFFFD: 0x7413,
	0x9CB0: 0x7414,
	0x9CB1: 0x7415,
	0xDA7E: 0x7416,
	0x9CB2: 0x7417,
	0xFFFD: 0x7418,
	0x9CB3: 0x7419,
	0xDAA1: 0x741A,
	0xB560: 0x741B,
	0x9CB4: 0x741C,
	0xDAA7: 0x741D,
	0x9CB5: 0x741E,
	0x9CB6: 0x741F,
	0xDAA9: 0x7420,
	0xDAA2: 0x7421,
	0xB55A: 0x7422,
	0xDAA6: 0x7423,
	0xDAA5: 0x7424,
	0xB55B: 0x7425,
	0xB561: 0x7426,
	0xFFFD: 0x7427,
	0xB562: 0x7428,
	0xDAA8: 0x7429,
	0xB558: 0x742A,
	0xDA7D: 0x742B,
	0xDA7B: 0x742C,
	0xDAA3: 0x742D,
	0xDA7A: 0x742E,
	0xB55F: 0x742F,
	0xDA7C: 0x7430,
	0xDAA4: 0x7431,
	0xDAAA: 0x7432,
	0xB559: 0x7433,
	0xB55E: 0x7434,
	0xB55C: 0x7435,
	0xB55D: 0x7436,
	0x9CB7: 0x7437,
	0x9CB8: 0x7438,
	0x9CB9: 0x7439,
	0xB557: 0x743A,
	0xFFFD: 0x743B,
	0x8BA9: 0x743C,
	0xFFFD: 0x743D,
	0xFFFD: 0x743E,
	0xB7E9: 0x743F,
	0xDEB7: 0x7440,
	0xB7E8: 0x7441,
	0xDEBB: 0x7442,
	0x9CBA: 0x7443,
	0xDEB1: 0x7444,
	0x9CBB: 0x7445,
	0xDEBC: 0x7446,
	0x9CBC: 0x7447,
	0x9CBD: 0x7448,
	0x9CBE: 0x7449,
	0xDEB2: 0x744A,
	0xDEB3: 0x744B,
	0xFFFD: 0x744C,
	0xDEBD: 0x744D,
	0xDEBA: 0x744E,
	0xDEB8: 0x744F,
	0xDEB9: 0x7450,
	0xDEB5: 0x7451,
	0xDEB4: 0x7452,
	0x9CBF: 0x7453,
	0xDEBE: 0x7454,
	0xB7E5: 0x7455,
	0x9CC0: 0x7456,
	0xDEB6: 0x7457,
	0xFFFD: 0x7458,
	0xB7EA: 0x7459,
	0xB7E4: 0x745A,
	0xB7EB: 0x745B,
	0xB7EC: 0x745C,
	0xFCB9: 0x745D,
	0xB7E7: 0x745E,
	0xB7E6: 0x745F,
	0xFE75: 0x7460,
	0x9D73: 0x7461,
	0xE2CE: 0x7462,
	0xBABE: 0x7463,
	0xBABD: 0x7464,
	0x9CC1: 0x7465,
	0xFFFD: 0x7466,
	0xE2D3: 0x7467,
	0xFEAC: 0x7468,
	0xBCFC: 0x7469,
	0xBABF: 0x746A,
	0x9CC2: 0x746B,
	0x9CC3: 0x746C,
	0xBAC1: 0x746D,
	0xE2D4: 0x746E,
	0xB7E3: 0x746F,
	0xBAC0: 0x7470,
	0xE2D0: 0x7471,
	0xE2D2: 0x7472,
	0xE2CF: 0x7473,
	0x9CC4: 0x7474,
	0xE2D1: 0x7475,
	0xFA77: 0x7476,
	0x89F9: 0x7477,
	0xFFFD: 0x7478,
	0xE6AB: 0x7479,
	0x9CC5: 0x747A,
	0xFFFD: 0x747B,
	0xE6AA: 0x747C,
	0xE6A7: 0x747D,
	0xBD40: 0x747E,
	0xEA62: 0x747F,
	0xBD41: 0x7480,
	0xE6A6: 0x7481,
	0x9CC6: 0x7482,
	0xBCFE: 0x7483,
	0xFFFD: 0x7484,
	0xE6A8: 0x7485,
	0xE6A5: 0x7486,
	0xE6A2: 0x7487,
	0xE6A9: 0x7488,
	0xE6A3: 0x7489,
	0xE6A4: 0x748A,
	0xBCFD: 0x748B,
	0x81D0: 0x748C,
	0x81D1: 0x748D,
	0x8C7D: 0x748E,
	0xFFFD: 0x748F,
	0xED69: 0x7490,
	0xFFFD: 0x7491,
	0xEA66: 0x7492,
	0xFFFD: 0x7493,
	0xEA65: 0x7494,
	0xEA67: 0x7495,
	0xFFFD: 0x7496,
	0xED66: 0x7497,
	0xBF5A: 0x7498,
	0x81D2: 0x7499,
	0xEA63: 0x749A,
	0x81D3: 0x749B,
	0xBF58: 0x749C,
	0x9D74: 0x749D,
	0xBF5C: 0x749E,
	0xBF5B: 0x749F,
	0xEA64: 0x74A0,
	0xEA68: 0x74A1,
	0xFA78: 0x74A2,
	0xBF59: 0x74A3,
	0x81D4: 0x74A4,
	0xED6D: 0x74A5,
	0xC0F5: 0x74A6,
	0xC27A: 0x74A7,
	0xC0F6: 0x74A8,
	0xC0F3: 0x74A9,
	0xED6A: 0x74AA,
	0xED68: 0x74AB,
	0xFFFD: 0x74AC,
	0xED6B: 0x74AD,
	0xFFFD: 0x74AE,
	0xED6E: 0x74AF,
	0xC0F4: 0x74B0,
	0xED6C: 0x74B1,
	0xED67: 0x74B2,
	0xFFFD: 0x74B3,
	0x81D5: 0x74B4,
	0xF042: 0x74B5,
	0xF045: 0x74B6,
	0xF275: 0x74B7,
	0xF040: 0x74B8,
	0x81D6: 0x74B9,
	0xF46F: 0x74BA,
	0xF046: 0x74BB,
	0xFFFD: 0x74BC,
	0xC3A2: 0x74BD,
	0xF044: 0x74BE,
	0xC27B: 0x74BF,
	0xF041: 0x74C0,
	0xF043: 0x74C1,
	0xF047: 0x74C2,
	0xF276: 0x74C3,
	0xFFFD: 0x74C4,
	0xF274: 0x74C5,
	0xFFFD: 0x74C6,
	0xFFFD: 0x74C7,
	0x81D7: 0x74C8,
	0xFFFD: 0x74C9,
	0xC3A3: 0x74CA,
	0xF273: 0x74CB,
	0x81D8: 0x74CC,
	0xFFFD: 0x74CD,
	0xFFFD: 0x74CE,
	0xC46E: 0x74CF,
	0x81D9: 0x74D0,
	0xFFFD: 0x74D1,
	0x8CF9: 0x74D2,
	0x81DA: 0x74D3,
	0xC4ED: 0x74D4,
	0xF6F1: 0x74D5,
	0xC4EC: 0x74D6,
	0xF6F3: 0x74D7,
	0xF6F0: 0x74D8,
	0xF6F2: 0x74D9,
	0xC5D0: 0x74DA,
	0xF8B2: 0x74DB,
	0xA5CA: 0x74DC,
	0xCD6E: 0x74DD,
	0xD2BC: 0x74DE,
	0xD2BD: 0x74DF,
	0xB27D: 0x74E0,
	0xDEBF: 0x74E1,
	0xBF5D: 0x74E2,
	0xC3A4: 0x74E3,
	0xC57B: 0x74E4,
	0xF8B3: 0x74E5,
	0xA5CB: 0x74E6,
	0x94AC: 0x74E7,
	0xCD6F: 0x74E8,
	0xA260: 0x74E9,
	0xFFFD: 0x74EA,
	0xFFFD: 0x74EB,
	0xCFD7: 0x74EC,
	0xFFFD: 0x74ED,
	0xCFD8: 0x74EE,
	0x88FE: 0x74EF,
	0x94AE: 0x74F0,
	0x94AF: 0x74F1,
	0x94AD: 0x74F2,
	0xFFFD: 0x74F3,
	0xD2BE: 0x74F4,
	0xD2BF: 0x74F5,
	0xB27E: 0x74F6,
	0xB2A1: 0x74F7,
	0x94B0: 0x74F8,
	0xFFFD: 0x74F9,
	0xFFFD: 0x74FA,
	0xDAAB: 0x74FB,
	0xFFFD: 0x74FC,
	0xDEC2: 0x74FD,
	0xDEC1: 0x74FE,
	0xDEC0: 0x74FF,
	0xE2D5: 0x7500,
	0xFA79: 0x7501,
	0xE2D6: 0x7502,
	0xE2D7: 0x7503,
	0xBAC2: 0x7504,
	0x94B1: 0x7505,
	0xFFFD: 0x7506,
	0xE6AD: 0x7507,
	0xE6AC: 0x7508,
	0xFFFD: 0x7509,
	0xFFFD: 0x750A,
	0xEA69: 0x750B,
	0xBF5E: 0x750C,
	0xBF5F: 0x750D,
	0x95C2: 0x750E,
	0xED72: 0x750F,
	0xED6F: 0x7510,
	0xED70: 0x7511,
	0xED71: 0x7512,
	0xF049: 0x7513,
	0xF048: 0x7514,
	0xC27C: 0x7515,
	0xF277: 0x7516,
	0xF5DE: 0x7517,
	0xA5CC: 0x7518,
	0xFA7A: 0x7519,
	0xACC6: 0x751A,
	0xFFFD: 0x751B,
	0xB2A2: 0x751C,
	0xDEC3: 0x751D,
	0xFCBB: 0x751E,
	0xA5CD: 0x751F,
	0xFFFD: 0x7520,
	0xD2C0: 0x7521,
	0xB2A3: 0x7522,
	0xFA7B: 0x7523,
	0xFFFD: 0x7524,
	0xB563: 0x7525,
	0xB564: 0x7526,
	0xFFFD: 0x7527,
	0xA5CE: 0x7528,
	0xA5CF: 0x7529,
	0xCA46: 0x752A,
	0xA86A: 0x752B,
	0xA869: 0x752C,
	0xACC7: 0x752D,
	0xCFD9: 0x752E,
	0xDAAC: 0x752F,
	0xA5D0: 0x7530,
	0xA5D1: 0x7531,
	0xA5D2: 0x7532,
	0xA5D3: 0x7533,
	0xA059: 0x7534,
	0x867A: 0x7535,
	0xFFFD: 0x7536,
	0xA86B: 0x7537,
	0xA86C: 0x7538,
	0xCB6E: 0x7539,
	0xCB6D: 0x753A,
	0x84F8: 0x753B,
	0xFA7C: 0x753C,
	0xAAB6: 0x753D,
	0xCD72: 0x753E,
	0xCD70: 0x753F,
	0xCD71: 0x7540,
	0xFFFD: 0x7541,
	0x81DB: 0x7542,
	0xFFFD: 0x7543,
	0xFA7D: 0x7544,
	0x86D0: 0x7545,
	0xFBD1: 0x7546,
	0xCFDA: 0x7547,
	0xCFDB: 0x7548,
	0xFA7E: 0x7549,
	0x95BF: 0x754A,
	0xACCB: 0x754B,
	0xACC9: 0x754C,
	0xFAA1: 0x754D,
	0xACCA: 0x754E,
	0xACC8: 0x754F,
	0xFFFD: 0x7550,
	0x9455: 0x7551,
	0xFFFD: 0x7552,
	0xFCBC: 0x7553,
	0xAF60: 0x7554,
	0x81DC: 0x7555,
	0xFFFD: 0x7556,
	0xFFFD: 0x7557,
	0xFFFD: 0x7558,
	0xAF64: 0x7559,
	0xAF63: 0x755A,
	0xD2C1: 0x755B,
	0xAF62: 0x755C,
	0xAF61: 0x755D,
	0xFFFD: 0x755E,
	0xD2C2: 0x755F,
	0x9456: 0x7560,
	0xFFFD: 0x7561,
	0xB2A6: 0x7562,
	0xD67B: 0x7563,
	0xD67A: 0x7564,
	0xB2A4: 0x7565,
	0xB2A5: 0x7566,
	0x95CC: 0x7567,
	0xFFFD: 0x7568,
	0x94B2: 0x7569,
	0xB566: 0x756A,
	0xB565: 0x756B,
	0xDAAE: 0x756C,
	0xFAA2: 0x756D,
	0x81DD: 0x756E,
	0xDAAD: 0x756F,
	0xB2A7: 0x7570,
	0xFFFD: 0x7571,
	0x8DE2: 0x7572,
	0x92EC: 0x7573,
	0x8BAA: 0x7574,
	0xFFFD: 0x7575,
	0xB7ED: 0x7576,
	0xDEC5: 0x7577,
	0xB7EE: 0x7578,
	0xDEC4: 0x7579,
	0xFCBD: 0x757A,
	0xFFFD: 0x757B,
	0xFFFD: 0x757C,
	0xE2D8: 0x757D,
	0xE6AE: 0x757E,
	0xBD42: 0x757F,
	0xEA6A: 0x7580,
	0xFFFD: 0x7581,
	0xFAA3: 0x7582,
	0xFAA4: 0x7583,
	0xED73: 0x7584,
	0xFFFD: 0x7585,
	0xC3A6: 0x7586,
	0xC3A5: 0x7587,
	0xFFFD: 0x7588,
	0xFAA5: 0x7589,
	0xC57C: 0x758A,
	0xA5D4: 0x758B,
	0xCD73: 0x758C,
	0x81DE: 0x758D,
	0x9351: 0x758E,
	0xB2A8: 0x758F,
	0xE2D9: 0x7590,
	0xBAC3: 0x7591,
	0xC6D4: 0x7592,
	0xFFFD: 0x7593,
	0xCB6F: 0x7594,
	0xCB70: 0x7595,
	0x8F78: 0x7596,
	0x89FB: 0x7597,
	0xCD74: 0x7598,
	0xAAB8: 0x7599,
	0xAAB9: 0x759A,
	0xFFFD: 0x759B,
	0xFFFD: 0x759C,
	0xAAB7: 0x759D,
	0x81DF: 0x759E,
	0x86E5: 0x759F,
	0x8ADD: 0x75A0,
	0x86E6: 0x75A1,
	0xACCF: 0x75A2,
	0xACD0: 0x75A3,
	0xACCD: 0x75A4,
	0xACCE: 0x75A5,
	0xFFFD: 0x75A6,
	0xCFDC: 0x75A7,
	0xFFFD: 0x75A8,
	0xFFFD: 0x75A9,
	0xCFDD: 0x75AA,
	0xACCC: 0x75AB,
	0xFAA6: 0x75AC,
	0xFFFD: 0x75AD,
	0x87F4: 0x75AE,
	0x86E7: 0x75AF,
	0xD2C3: 0x75B0,
	0xFE51: 0x75B1,
	0xAF68: 0x75B2,
	0xAF69: 0x75B3,
	0xFB5C: 0x75B4,
	0xB2AB: 0x75B5,
	0xD2C9: 0x75B6,
	0xFFFD: 0x75B7,
	0xAF6E: 0x75B8,
	0xAF6C: 0x75B9,
	0xD2CA: 0x75BA,
	0xD2C5: 0x75BB,
	0xAF6B: 0x75BC,
	0xAF6A: 0x75BD,
	0xAF65: 0x75BE,
	0xD2C8: 0x75BF,
	0xD2C7: 0x75C0,
	0xD2C4: 0x75C1,
	0xAF6D: 0x75C2,
	0xFCD3: 0x75C3,
	0xD2C6: 0x75C4,
	0xAF66: 0x75C5,
	0xFFFD: 0x75C6,
	0xAF67: 0x75C7,
	0x8FFD: 0x75C8,
	0x84F9: 0x75C9,
	0xB2AC: 0x75CA,
	0xD6A1: 0x75CB,
	0xD6A2: 0x75CC,
	0xB2AD: 0x75CD,
	0xD67C: 0x75CE,
	0xD67E: 0x75CF,
	0xD6A4: 0x75D0,
	0xD6A3: 0x75D1,
	0xD67D: 0x75D2,
	0xFFFD: 0x75D3,
	0xB2A9: 0x75D4,
	0xB2AA: 0x75D5,
	0xFAA7: 0x75D6,
	0xDAB6: 0x75D7,
	0xB56B: 0x75D8,
	0xB56A: 0x75D9,
	0xDAB0: 0x75DA,
	0xB568: 0x75DB,
	0x81E0: 0x75DC,
	0xDAB3: 0x75DD,
	0xB56C: 0x75DE,
	0xDAB4: 0x75DF,
	0xB56D: 0x75E0,
	0xDAB1: 0x75E1,
	0xB567: 0x75E2,
	0xB569: 0x75E3,
	0xDAB5: 0x75E4,
	0xFFFD: 0x75E5,
	0xDAB2: 0x75E6,
	0xDAAF: 0x75E7,
	0x89FA: 0x75E8,
	0xFAA8: 0x75E9,
	0x86E8: 0x75EA,
	0x8F58: 0x75EB,
	0xFFFD: 0x75EC,
	0xDED2: 0x75ED,
	0xFFFD: 0x75EE,
	0xDEC7: 0x75EF,
	0xB7F0: 0x75F0,
	0xB7F3: 0x75F1,
	0xB7F2: 0x75F2,
	0xB7F7: 0x75F3,
	0xB7F6: 0x75F4,
	0xDED3: 0x75F5,
	0xDED1: 0x75F6,
	0xDECA: 0x75F7,
	0xDECE: 0x75F8,
	0xDECD: 0x75F9,
	0xB7F4: 0x75FA,
	0xDED0: 0x75FB,
	0xDECC: 0x75FC,
	0xDED4: 0x75FD,
	0xDECB: 0x75FE,
	0xB7F5: 0x75FF,
	0xB7EF: 0x7600,
	0xB7F1: 0x7601,
	0xFCD5: 0x7602,
	0xDEC9: 0x7603,
	0xFFFD: 0x7604,
	0x8F57: 0x7605,
	0xFFFD: 0x7606,
	0xFCD4: 0x7607,
	0xE2DB: 0x7608,
	0xBAC7: 0x7609,
	0xE2DF: 0x760A,
	0xBAC6: 0x760B,
	0xE2DC: 0x760C,
	0xBAC5: 0x760D,
	0xFFFD: 0x760E,
	0xDEC8: 0x760F,
	0xDECF: 0x7610,
	0xE2DE: 0x7611,
	0xFFFD: 0x7612,
	0xBAC8: 0x7613,
	0xE2E0: 0x7614,
	0xE2DD: 0x7615,
	0xE2DA: 0x7616,
	0x8EC1: 0x7617,
	0x8940: 0x7618,
	0xE6B1: 0x7619,
	0xE6B5: 0x761A,
	0xE6B7: 0x761B,
	0xE6B3: 0x761C,
	0xE6B2: 0x761D,
	0xE6B0: 0x761E,
	0xBD45: 0x761F,
	0xBD43: 0x7620,
	0xBD48: 0x7621,
	0xBD49: 0x7622,
	0xE6B4: 0x7623,
	0xBD46: 0x7624,
	0xE6AF: 0x7625,
	0xBD47: 0x7626,
	0xBAC4: 0x7627,
	0xE6B6: 0x7628,
	0xBD44: 0x7629,
	0x8BAB: 0x762A,
	0x8D54: 0x762B,
	0x81E1: 0x762C,
	0xEA6C: 0x762D,
	0xFFFD: 0x762E,
	0xEA6B: 0x762F,
	0xEA73: 0x7630,
	0xEA6D: 0x7631,
	0xEA72: 0x7632,
	0xEA6F: 0x7633,
	0xBF60: 0x7634,
	0xEA71: 0x7635,
	0xFFFD: 0x7636,
	0xFFFD: 0x7637,
	0xBF61: 0x7638,
	0xFFFD: 0x7639,
	0xBF62: 0x763A,
	0x95A9: 0x763B,
	0xEA70: 0x763C,
	0xEA6E: 0x763D,
	0x8CD5: 0x763E,
	0x9058: 0x763F,
	0xFAA9: 0x7640,
	0xFFFD: 0x7641,
	0xC0F8: 0x7642,
	0xED74: 0x7643,
	0xFFFD: 0x7644,
	0xFFFD: 0x7645,
	0xC0F7: 0x7646,
	0xED77: 0x7647,
	0xED75: 0x7648,
	0xED76: 0x7649,
	0xFFFD: 0x764A,
	0xFFFD: 0x764B,
	0xC0F9: 0x764C,
	0xFAAA: 0x764D,
	0x956F: 0x764E,
	0x81E2: 0x764F,
	0xF04D: 0x7650,
	0x81E3: 0x7651,
	0xC2A1: 0x7652,
	0xF04E: 0x7653,
	0xFAAB: 0x7654,
	0xFFFD: 0x7655,
	0xC27D: 0x7656,
	0xF04F: 0x7657,
	0xC27E: 0x7658,
	0xF04C: 0x7659,
	0xF050: 0x765A,
	0xFFFD: 0x765B,
	0xF04A: 0x765C,
	0xFFFD: 0x765D,
	0x8C7E: 0x765E,
	0xC3A7: 0x765F,
	0xF278: 0x7660,
	0xC3A8: 0x7661,
	0xC46F: 0x7662,
	0x8CD6: 0x7663,
	0xF04B: 0x7664,
	0xC470: 0x7665,
	0xFB76: 0x7666,
	0xFCD7: 0x7667,
	0xFAAC: 0x7668,
	0xC4EE: 0x7669,
	0xF5DF: 0x766A,
	0x8D55: 0x766B,
	0xC57E: 0x766C,
	0xF6F4: 0x766D,
	0xC57D: 0x766E,
	0xFCD8: 0x766F,
	0xF7EA: 0x7670,
	0xC5F5: 0x7671,
	0xC5F6: 0x7672,
	0x81E4: 0x7673,
	0x81E5: 0x7674,
	0xF9CC: 0x7675,
	0xC6D5: 0x7676,
	0xFFFD: 0x7677,
	0xACD1: 0x7678,
	0xCFDE: 0x7679,
	0x93B9: 0x767A,
	0xB56E: 0x767B,
	0xB56F: 0x767C,
	0xA5D5: 0x767D,
	0xA6CA: 0x767E,
	0xCA47: 0x767F,
	0xFAAD: 0x7680,
	0xCB71: 0x7681,
	0xA86D: 0x7682,
	0xFAAE: 0x7683,
	0xAABA: 0x7684,
	0xFFFD: 0x7685,
	0xACD2: 0x7686,
	0xACD3: 0x7687,
	0xACD4: 0x7688,
	0xD6A6: 0x7689,
	0xD2CB: 0x768A,
	0xAF6F: 0x768B,
	0xFFFD: 0x768C,
	0xFFFD: 0x768D,
	0xB2AE: 0x768E,
	0xD6A5: 0x768F,
	0xFAAF: 0x7690,
	0x87F5: 0x7691,
	0xDAB8: 0x7692,
	0xB571: 0x7693,
	0xFFFD: 0x7694,
	0xDAB7: 0x7695,
	0xB570: 0x7696,
	0xFFFD: 0x7697,
	0xFFFD: 0x7698,
	0xDED5: 0x7699,
	0xBD4A: 0x769A,
	0xE6BB: 0x769B,
	0xE6B8: 0x769C,
	0xE6B9: 0x769D,
	0xE6BA: 0x769E,
	0xFFFD: 0x769F,
	0xFFFD: 0x76A0,
	0xFCBE: 0x76A1,
	0xFFFD: 0x76A2,
	0xFFFD: 0x76A3,
	0xED78: 0x76A4,
	0x81E6: 0x76A5,
	0xF051: 0x76A6,
	0xFFFD: 0x76A7,
	0xFFFD: 0x76A8,
	0xFFFD: 0x76A9,
	0xF471: 0x76AA,
	0xF470: 0x76AB,
	0xFFFD: 0x76AC,
	0xF6F5: 0x76AD,
	0xA5D6: 0x76AE,
	0xCD75: 0x76AF,
	0xAF70: 0x76B0,
	0x87F6: 0x76B1,
	0x8E77: 0x76B2,
	0xFFFD: 0x76B3,
	0xB572: 0x76B4,
	0xDED6: 0x76B5,
	0xFFFD: 0x76B6,
	0xFAB0: 0x76B7,
	0xE2E1: 0x76B8,
	0xFAB1: 0x76B9,
	0xBD4B: 0x76BA,
	0xEA74: 0x76BB,
	0xFFFD: 0x76BC,
	0xF052: 0x76BD,
	0xF472: 0x76BE,
	0xA5D7: 0x76BF,
	0xFFFD: 0x76C0,
	0xFFFD: 0x76C1,
	0xAABB: 0x76C2,
	0xACD7: 0x76C3,
	0xCFDF: 0x76C4,
	0xACD8: 0x76C5,
	0xACD6: 0x76C6,
	0xFFFD: 0x76C7,
	0xACD5: 0x76C8,
	0xD2CC: 0x76C9,
	0xAF71: 0x76CA,
	0xFFFD: 0x76CB,
	0xFCBF: 0x76CC,
	0xAF72: 0x76CD,
	0xAF73: 0x76CE,
	0x85E6: 0x76CF,
	0x8D69: 0x76D0,
	0x86EA: 0x76D1,
	0xB2B0: 0x76D2,
	0xD6A7: 0x76D3,
	0xB2AF: 0x76D4,
	0xFFFD: 0x76D5,
	0x8749: 0x76D6,
	0x84FB: 0x76D7,
	0x87F7: 0x76D8,
	0x81E7: 0x76D9,
	0xDAB9: 0x76DA,
	0xB2B1: 0x76DB,
	0xB573: 0x76DC,
	0xDED7: 0x76DD,
	0xB7F8: 0x76DE,
	0xB7F9: 0x76DF,
	0xFFFD: 0x76E0,
	0xBAC9: 0x76E1,
	0xFFFD: 0x76E2,
	0xBACA: 0x76E3,
	0xBD4C: 0x76E4,
	0xBF64: 0x76E5,
	0xEA75: 0x76E6,
	0xBF63: 0x76E7,
	0xFFFD: 0x76E8,
	0xED79: 0x76E9,
	0xC0FA: 0x76EA,
	0xFFFD: 0x76EB,
	0xF053: 0x76EC,
	0xF473: 0x76ED,
	0xA5D8: 0x76EE,
	0xA86E: 0x76EF,
	0xCD78: 0x76F0,
	0xCD77: 0x76F1,
	0xAABC: 0x76F2,
	0xCD76: 0x76F3,
	0xAABD: 0x76F4,
	0xCD79: 0x76F5,
	0xFFFD: 0x76F6,
	0xCFE5: 0x76F7,
	0xACDB: 0x76F8,
	0xACDA: 0x76F9,
	0xCFE7: 0x76FA,
	0xCFE6: 0x76FB,
	0xACDF: 0x76FC,
	0xFFFD: 0x76FD,
	0xACDE: 0x76FE,
	0xFFFD: 0x76FF,
	0xFFFD: 0x7700,
	0xACD9: 0x7701,
	0xFFFD: 0x7702,
	0xCFE1: 0x7703,
	0xCFE2: 0x7704,
	0xCFE3: 0x7705,
	0xFFFD: 0x7706,
	0xACE0: 0x7707,
	0xCFE0: 0x7708,
	0xACDC: 0x7709,
	0xCFE4: 0x770A,
	0xACDD: 0x770B,
	0x92B1: 0x770C,
	0xFAB2: 0x770D,
	0x81E8: 0x770E,
	0x81E9: 0x770F,
	0xD2CF: 0x7710,
	0xD2D3: 0x7711,
	0xD2D1: 0x7712,
	0xD2D0: 0x7713,
	0xFFFD: 0x7714,
	0xD2D4: 0x7715,
	0xFFFD: 0x7716,
	0xFFFD: 0x7717,
	0xFFFD: 0x7718,
	0xD2D5: 0x7719,
	0xD2D6: 0x771A,
	0xD2CE: 0x771B,
	0xFFFD: 0x771C,
	0xD2CD: 0x771D,
	0xFAB3: 0x771E,
	0xAF75: 0x771F,
	0xAF76: 0x7720,
	0xFFFD: 0x7721,
	0xD2D7: 0x7722,
	0xD2D2: 0x7723,
	0xFCC0: 0x7724,
	0xD6B0: 0x7725,
	0x8DD2: 0x7726,
	0xD2D8: 0x7727,
	0xAF77: 0x7728,
	0xAF74: 0x7729,
	0xFFFD: 0x772A,
	0xFCC1: 0x772B,
	0xFFFD: 0x772C,
	0xD6AA: 0x772D,
	0xFFFD: 0x772E,
	0xD6A9: 0x772F,
	0xFFFD: 0x7730,
	0xD6AB: 0x7731,
	0xD6AC: 0x7732,
	0xD6AE: 0x7733,
	0xD6AD: 0x7734,
	0xD6B2: 0x7735,
	0xB2B5: 0x7736,
	0xB2B2: 0x7737,
	0xB2B6: 0x7738,
	0xD6A8: 0x7739,
	0xB2B7: 0x773A,
	0xD6B1: 0x773B,
	0xB2B4: 0x773C,
	0xD6AF: 0x773D,
	0xB2B3: 0x773E,
	0xFFFD: 0x773F,
	0x954D: 0x7740,
	0x85E8: 0x7741,
	0xFFFD: 0x7742,
	0xFAB4: 0x7743,
	0xDABC: 0x7744,
	0xDABE: 0x7745,
	0xDABA: 0x7746,
	0xDABB: 0x7747,
	0xFFFD: 0x7748,
	0xFFFD: 0x7749,
	0xDABF: 0x774A,
	0xDAC1: 0x774B,
	0xDAC2: 0x774C,
	0xDABD: 0x774D,
	0xDAC0: 0x774E,
	0xB574: 0x774F,
	0x85E7: 0x7750,
	0x8ADE: 0x7751,
	0xDEDB: 0x7752,
	0xFFFD: 0x7753,
	0xDEE0: 0x7754,
	0xDED8: 0x7755,
	0xDEDC: 0x7756,
	0xFFFD: 0x7757,
	0x81EA: 0x7758,
	0xDEE1: 0x7759,
	0xDEDD: 0x775A,
	0xB7FA: 0x775B,
	0xB843: 0x775C,
	0xFFFD: 0x775D,
	0xB7FD: 0x775E,
	0xDED9: 0x775F,
	0xDEDA: 0x7760,
	0xBACE: 0x7761,
	0xB846: 0x7762,
	0xB7FE: 0x7763,
	0xFFFD: 0x7764,
	0xB844: 0x7765,
	0xB7FC: 0x7766,
	0xDEDF: 0x7767,
	0xB845: 0x7768,
	0xDEDE: 0x7769,
	0xB841: 0x776A,
	0xB7FB: 0x776B,
	0xB842: 0x776C,
	0xDEE2: 0x776D,
	0xE2E6: 0x776E,
	0xE2E8: 0x776F,
	0xFFFD: 0x7770,
	0xFFFD: 0x7771,
	0x81EB: 0x7772,
	0xFFFD: 0x7773,
	0xFFFD: 0x7774,
	0xFFFD: 0x7775,
	0xFFFD: 0x7776,
	0x81EC: 0x7777,
	0x81ED: 0x7778,
	0xB840: 0x7779,
	0x81EE: 0x777A,
	0x81EF: 0x777B,
	0xE2E3: 0x777C,
	0xBACC: 0x777D,
	0xE2E9: 0x777E,
	0xBACD: 0x777F,
	0xE2E7: 0x7780,
	0xE2E2: 0x7781,
	0xE2E5: 0x7782,
	0xE2EA: 0x7783,
	0xBACB: 0x7784,
	0xE2E4: 0x7785,
	0xFFFD: 0x7786,
	0xBD4E: 0x7787,
	0xE6BF: 0x7788,
	0xE6BE: 0x7789,
	0xFFFD: 0x778A,
	0xBD51: 0x778B,
	0xBD4F: 0x778C,
	0xE6BC: 0x778D,
	0xBD4D: 0x778E,
	0xE6BD: 0x778F,
	0xFFFD: 0x7790,
	0xBD50: 0x7791,
	0x8942: 0x7792,
	0xFB6B: 0x7793,
	0xFFFD: 0x7794,
	0xEA7D: 0x7795,
	0xFFFD: 0x7796,
	0xEAA1: 0x7797,
	0x81F0: 0x7798,
	0xEA7E: 0x7799,
	0xEA76: 0x779A,
	0xEA7A: 0x779B,
	0xEA79: 0x779C,
	0xEA77: 0x779D,
	0xBF66: 0x779E,
	0xBF67: 0x779F,
	0xBF65: 0x77A0,
	0xEA78: 0x77A1,
	0xEA7B: 0x77A2,
	0xEA7C: 0x77A3,
	0xFFFD: 0x77A4,
	0xBF68: 0x77A5,
	0xFFFD: 0x77A6,
	0xC140: 0x77A7,
	0xEDA3: 0x77A8,
	0x8D7C: 0x77A9,
	0xC0FC: 0x77AA,
	0xED7B: 0x77AB,
	0xC0FE: 0x77AC,
	0xC141: 0x77AD,
	0xFFFD: 0x77AE,
	0x81F1: 0x77AF,
	0xC0FD: 0x77B0,
	0xEDA2: 0x77B1,
	0xED7C: 0x77B2,
	0xC0FB: 0x77B3,
	0xEDA1: 0x77B4,
	0xED7A: 0x77B5,
	0xED7E: 0x77B6,
	0xED7D: 0x77B7,
	0xFFFD: 0x77B8,
	0xFE5A: 0x77B9,
	0xF055: 0x77BA,
	0xC2A4: 0x77BB,
	0xC2A5: 0x77BC,
	0xC2A2: 0x77BD,
	0x81F2: 0x77BE,
	0xC2A3: 0x77BF,
	0xFFFD: 0x77C0,
	0xFFFD: 0x77C1,
	0xF054: 0x77C2,
	0x81F3: 0x77C3,
	0xF27B: 0x77C4,
	0x81F4: 0x77C5,
	0xFFFD: 0x77C6,
	0xC3A9: 0x77C7,
	0xFFFD: 0x77C8,
	0xF279: 0x77C9,
	0xF27A: 0x77CA,
	0x81F5: 0x77CB,
	0xF474: 0x77CC,
	0xF477: 0x77CD,
	0xF475: 0x77CE,
	0xF476: 0x77CF,
	0xF5E0: 0x77D0,
	0xFFFD: 0x77D1,
	0xFFFD: 0x77D2,
	0xC4EF: 0x77D3,
	0xF7EB: 0x77D4,
	0xF8B4: 0x77D5,
	0xFFFD: 0x77D6,
	0xC5F7: 0x77D7,
	0xF8F8: 0x77D8,
	0xF8F9: 0x77D9,
	0xC666: 0x77DA,
	0xA5D9: 0x77DB,
	0xACE1: 0x77DC,
	0x81F6: 0x77DD,
	0xDAC3: 0x77DE,
	0xFFFD: 0x77DF,
	0xDEE3: 0x77E0,
	0xFFFD: 0x77E1,
	0xA5DA: 0x77E2,
	0xA86F: 0x77E3,
	0xFFFD: 0x77E4,
	0xAABE: 0x77E5,
	0x81F7: 0x77E6,
	0xCFE8: 0x77E7,
	0xCFE9: 0x77E8,
	0xAF78: 0x77E9,
	0xFFFD: 0x77EA,
	0x89FC: 0x77EB,
	0xDAC4: 0x77EC,
	0xB575: 0x77ED,
	0xB847: 0x77EE,
	0xC142: 0x77EF,
	0xEDA4: 0x77F0,
	0xF27C: 0x77F1,
	0xF478: 0x77F2,
	0xA5DB: 0x77F3,
	0x81F8: 0x77F4,
	0xFFFD: 0x77F5,
	0x89FE: 0x77F6,
	0xCDA1: 0x77F7,
	0xCD7A: 0x77F8,
	0xCD7C: 0x77F9,
	0xCD7E: 0x77FA,
	0xCD7D: 0x77FB,
	0xCD7B: 0x77FC,
	0xAABF: 0x77FD,
	0x8C41: 0x77FE,
	0x8BFE: 0x77FF,
	0x8E78: 0x7800,
	0x87F9: 0x7801,
	0xACE2: 0x7802,
	0xCFF2: 0x7803,
	0xFFFD: 0x7804,
	0xCFED: 0x7805,
	0xCFEA: 0x7806,
	0xFFFD: 0x7807,
	0x9641: 0x7808,
	0xCFF1: 0x7809,
	0xFFFD: 0x780A,
	0xFFFD: 0x780B,
	0xACE4: 0x780C,
	0xACE5: 0x780D,
	0xCFF0: 0x780E,
	0xCFEF: 0x780F,
	0xCFEE: 0x7810,
	0xCFEB: 0x7811,
	0xCFEC: 0x7812,
	0xCFF3: 0x7813,
	0xACE3: 0x7814,
	0x92C5: 0x7815,
	0x8943: 0x7816,
	0x8DE3: 0x7817,
	0xFAB5: 0x7818,
	0xFFFD: 0x7819,
	0x84FC: 0x781A,
	0xFFFD: 0x781B,
	0xFAB6: 0x781C,
	0xAF7C: 0x781D,
	0x81F9: 0x781E,
	0xAFA4: 0x781F,
	0xAFA3: 0x7820,
	0xD2E1: 0x7821,
	0xD2DB: 0x7822,
	0xD2D9: 0x7823,
	0xFFFD: 0x7824,
	0xAFA1: 0x7825,
	0xD6B9: 0x7826,
	0xAF7A: 0x7827,
	0xD2DE: 0x7828,
	0xD2E2: 0x7829,
	0xD2E4: 0x782A,
	0xD2E0: 0x782B,
	0xD2DA: 0x782C,
	0xAFA2: 0x782D,
	0xD2DF: 0x782E,
	0xD2DD: 0x782F,
	0xAF79: 0x7830,
	0xD2E5: 0x7831,
	0xAFA5: 0x7832,
	0xD2E3: 0x7833,
	0xAF7D: 0x7834,
	0xD2DC: 0x7835,
	0xFFFD: 0x7836,
	0xAF7E: 0x7837,
	0xAF7B: 0x7838,
	0xFAB7: 0x7839,
	0x8C40: 0x783A,
	0x9042: 0x783B,
	0xFAB8: 0x783C,
	0x81FA: 0x783D,
	0x8C42: 0x783E,
	0x825F: 0x783F,
	0x8ADF: 0x7840,
	0xFFFD: 0x7841,
	0x81FB: 0x7842,
	0xB2B9: 0x7843,
	0x81FC: 0x7844,
	0xD6BA: 0x7845,
	0xFFFD: 0x7846,
	0xFAB9: 0x7847,
	0xD6B3: 0x7848,
	0xD6B5: 0x7849,
	0xD6B7: 0x784A,
	0x81FD: 0x784B,
	0xD6B8: 0x784C,
	0xD6B6: 0x784D,
	0xB2BA: 0x784E,
	0xFFFD: 0x784F,
	0xD6BB: 0x7850,
	0x81FE: 0x7851,
	0xD6B4: 0x7852,
	0xFCC3: 0x7853,
	0x964B: 0x7854,
	0x86EB: 0x7855,
	0xFABA: 0x7856,
	0x8F59: 0x7857,
	0xFFFD: 0x7858,
	0xFFFD: 0x7859,
	0xFFFD: 0x785A,
	0xFFFD: 0x785B,
	0xDAC8: 0x785C,
	0xB576: 0x785D,
	0xDAD0: 0x785E,
	0xFFFD: 0x785F,
	0xDAC5: 0x7860,
	0xFFFD: 0x7861,
	0xDAD1: 0x7862,
	0xFFFD: 0x7863,
	0xDAC6: 0x7864,
	0xDAC7: 0x7865,
	0x964C: 0x7866,
	0xFFFD: 0x7867,
	0xDACF: 0x7868,
	0xDACE: 0x7869,
	0xDACB: 0x786A,
	0xB2B8: 0x786B,
	0xB577: 0x786C,
	0xDAC9: 0x786D,
	0xDACC: 0x786E,
	0xB578: 0x786F,
	0xDACD: 0x7870,
	0xDACA: 0x7871,
	0x9454: 0x7872,
	0xFFFD: 0x7873,
	0x94B4: 0x7874,
	0xFFFD: 0x7875,
	0xFFFD: 0x7876,
	0x8D68: 0x7877,
	0xFFFD: 0x7878,
	0xDEEE: 0x7879,
	0xFABB: 0x787A,
	0xDEF2: 0x787B,
	0xB84E: 0x787C,
	0xFFFD: 0x787D,
	0xE2F0: 0x787E,
	0xB851: 0x787F,
	0xDEF0: 0x7880,
	0xF9D6: 0x7881,
	0xFFFD: 0x7882,
	0xDEED: 0x7883,
	0xDEE8: 0x7884,
	0xDEEA: 0x7885,
	0xDEEB: 0x7886,
	0xDEE4: 0x7887,
	0x964D: 0x7888,
	0xB84D: 0x7889,
	0xFFFD: 0x788A,
	0xFFFD: 0x788B,
	0xB84C: 0x788C,
	0x8BAC: 0x788D,
	0xB848: 0x788E,
	0xDEE7: 0x788F,
	0xFFFD: 0x7890,
	0xB84F: 0x7891,
	0xFFFD: 0x7892,
	0xB850: 0x7893,
	0xDEE6: 0x7894,
	0xDEE9: 0x7895,
	0xDEF1: 0x7896,
	0xB84A: 0x7897,
	0xB84B: 0x7898,
	0xDEEF: 0x7899,
	0xDEE5: 0x789A,
	0x8944: 0x789B,
	0x8EED: 0x789C,
	0xFFFD: 0x789D,
	0xE2F2: 0x789E,
	0xBAD0: 0x789F,
	0xE2F4: 0x78A0,
	0xDEEC: 0x78A1,
	0xE2F6: 0x78A2,
	0xBAD4: 0x78A3,
	0xE2F7: 0x78A4,
	0xE2F3: 0x78A5,
	0xFFFD: 0x78A6,
	0xBAD1: 0x78A7,
	0xE2EF: 0x78A8,
	0xBAD3: 0x78A9,
	0xE2EC: 0x78AA,
	0xE2F1: 0x78AB,
	0xE2F5: 0x78AC,
	0xE2EE: 0x78AD,
	0xFFFD: 0x78AE,
	0xFCC7: 0x78AF,
	0xB849: 0x78B0,
	0x95F0: 0x78B1,
	0xE2EB: 0x78B2,
	0xBAD2: 0x78B3,
	0xE2ED: 0x78B4,
	0xFABC: 0x78B5,
	0x964E: 0x78B6,
	0xFFFD: 0x78B7,
	0x96CD: 0x78B8,
	0xFABD: 0x78B9,
	0xBD54: 0x78BA,
	0xE6C1: 0x78BB,
	0xBD58: 0x78BC,
	0xFFFD: 0x78BD,
	0xBD56: 0x78BE,
	0xFFFD: 0x78BF,
	0xFFFD: 0x78C0,
	0xBACF: 0x78C1,
	0xFFFD: 0x78C2,
	0xE6C8: 0x78C3,
	0xE6C9: 0x78C4,
	0xBD53: 0x78C5,
	0xFABE: 0x78C6,
	0x964F: 0x78C7,
	0xE6C7: 0x78C8,
	0xE6CA: 0x78C9,
	0xBD55: 0x78CA,
	0xBD52: 0x78CB,
	0xE6C3: 0x78CC,
	0xE6C0: 0x78CD,
	0xE6C5: 0x78CE,
	0xE6C2: 0x78CF,
	0xBD59: 0x78D0,
	0xE6C4: 0x78D1,
	0x9650: 0x78D2,
	0xFCC4: 0x78D3,
	0xE6C6: 0x78D4,
	0xBD57: 0x78D5,
	0xFFFD: 0x78D6,
	0x9651: 0x78D7,
	0xFCC5: 0x78D8,
	0xFABF: 0x78D9,
	0xBF6A: 0x78DA,
	0xEAA8: 0x78DB,
	0xFFFD: 0x78DC,
	0xEAA2: 0x78DD,
	0xEAA6: 0x78DE,
	0xEAAC: 0x78DF,
	0xEAAD: 0x78E0,
	0xEAA9: 0x78E1,
	0xEAAA: 0x78E2,
	0xEAA7: 0x78E3,
	0x9654: 0x78E4,
	0xEAA4: 0x78E5,
	0xFFFD: 0x78E6,
	0xBF6C: 0x78E7,
	0xBF69: 0x78E8,
	0xEAA3: 0x78E9,
	0xEAA5: 0x78EA,
	0xFFFD: 0x78EB,
	0xBF6B: 0x78EC,
	0xEAAB: 0x78ED,
	0x9655: 0x78EE,
	0xC146: 0x78EF,
	0x9656: 0x78F0,
	0x9657: 0x78F1,
	0xEDAA: 0x78F2,
	0xEDA5: 0x78F3,
	0xC145: 0x78F4,
	0x9658: 0x78F5,
	0xFFFD: 0x78F6,
	0xC143: 0x78F7,
	0xFFFD: 0x78F8,
	0xEDAC: 0x78F9,
	0xC144: 0x78FA,
	0xEDA8: 0x78FB,
	0xEDA9: 0x78FC,
	0xEDA6: 0x78FD,
	0xEDAD: 0x78FE,
	0xF056: 0x78FF,
	0xFFFD: 0x7900,
	0xC147: 0x7901,
	0xEDA7: 0x7902,
	0xFFFD: 0x7903,
	0xEDAE: 0x7904,
	0xEDAB: 0x7905,
	0xFBA8: 0x7906,
	0xFAC0: 0x7907,
	0xFFFD: 0x7908,
	0xF05A: 0x7909,
	0xFFFD: 0x790A,
	0xFFFD: 0x790B,
	0xF057: 0x790C,
	0xFFFD: 0x790D,
	0xC2A6: 0x790E,
	0xFFFD: 0x790F,
	0xF05B: 0x7910,
	0xF05D: 0x7911,
	0xF05C: 0x7912,
	0xF058: 0x7913,
	0xF059: 0x7914,
	0xFFFD: 0x7915,
	0xFFFD: 0x7916,
	0xF2A3: 0x7917,
	0xFFFD: 0x7918,
	0xC3AA: 0x7919,
	0xFFFD: 0x791A,
	0xF27E: 0x791B,
	0xF2A2: 0x791C,
	0xF27D: 0x791D,
	0xF2A4: 0x791E,
	0xFFFD: 0x791F,
	0xFFFD: 0x7920,
	0xF2A1: 0x7921,
	0xFFFD: 0x7922,
	0xF47A: 0x7923,
	0xF47D: 0x7924,
	0xF479: 0x7925,
	0xC471: 0x7926,
	0xF47B: 0x7927,
	0xF47C: 0x7928,
	0xF47E: 0x7929,
	0xC472: 0x792A,
	0xC474: 0x792B,
	0xC473: 0x792C,
	0xF5E1: 0x792D,
	0xFE77: 0x792E,
	0xF5E3: 0x792F,
	0xFAC1: 0x7930,
	0xF5E2: 0x7931,
	0x9659: 0x7932,
	0x965A: 0x7933,
	0xFAC2: 0x7934,
	0xF6F6: 0x7935,
	0x965B: 0x7936,
	0xFFFD: 0x7937,
	0xF8B5: 0x7938,
	0xF8FA: 0x7939,
	0xA5DC: 0x793A,
	0xFAC3: 0x793B,
	0x8AE0: 0x793C,
	0xCB72: 0x793D,
	0xAAC0: 0x793E,
	0xCDA3: 0x793F,
	0xAAC1: 0x7940,
	0xAAC2: 0x7941,
	0xCDA2: 0x7942,
	0xFFFD: 0x7943,
	0xCFF8: 0x7944,
	0xCFF7: 0x7945,
	0xACE6: 0x7946,
	0xACE9: 0x7947,
	0xACE8: 0x7948,
	0xACE7: 0x7949,
	0xCFF4: 0x794A,
	0xCFF6: 0x794B,
	0xCFF5: 0x794C,
	0xFFFD: 0x794D,
	0xFFFD: 0x794E,
	0xD2E8: 0x794F,
	0xAFA7: 0x7950,
	0xD2EC: 0x7951,
	0xD2EB: 0x7952,
	0xD2EA: 0x7953,
	0xD2E6: 0x7954,
	0xAFA6: 0x7955,
	0xAFAA: 0x7956,
	0xAFAD: 0x7957,
	0x965C: 0x7958,
	0x965E: 0x7959,
	0xAFAE: 0x795A,
	0xD2E7: 0x795B,
	0xD2E9: 0x795C,
	0xAFAC: 0x795D,
	0xAFAB: 0x795E,
	0xAFA9: 0x795F,
	0xAFA8: 0x7960,
	0xD6C2: 0x7961,
	0x8FBE: 0x7962,
	0xD6C0: 0x7963,
	0xD6BC: 0x7964,
	0xB2BB: 0x7965,
	0xFFFD: 0x7966,
	0xD6BD: 0x7967,
	0xB2BC: 0x7968,
	0xD6BE: 0x7969,
	0xD6BF: 0x796A,
	0xD6C1: 0x796B,
	0xFFFD: 0x796C,
	0xB2BD: 0x796D,
	0xFFFD: 0x796E,
	0x86EC: 0x796F,
	0xDAD5: 0x7970,
	0x965F: 0x7971,
	0xDAD4: 0x7972,
	0xDAD3: 0x7973,
	0xDAD2: 0x7974,
	0xFFFD: 0x7975,
	0xFFFD: 0x7976,
	0x8270: 0x7977,
	0x86ED: 0x7978,
	0xDEF6: 0x7979,
	0xB852: 0x797A,
	0xFFFD: 0x797B,
	0xDEF3: 0x797C,
	0xDEF5: 0x797D,
	0x9660: 0x797E,
	0xB853: 0x797F,
	0xFAC4: 0x7980,
	0xB854: 0x7981,
	0xDEF4: 0x7982,
	0x9661: 0x7983,
	0x8277: 0x7984,
	0x9350: 0x7985,
	0x9662: 0x7986,
	0x9663: 0x7987,
	0xE341: 0x7988,
	0xFFFD: 0x7989,
	0xE2F9: 0x798A,
	0xE2FA: 0x798B,
	0xFFFD: 0x798C,
	0xBAD7: 0x798D,
	0xBAD5: 0x798E,
	0xBAD6: 0x798F,
	0xE343: 0x7990,
	0x9664: 0x7991,
	0xE342: 0x7992,
	0xE2FE: 0x7993,
	0xE2FD: 0x7994,
	0xE2FC: 0x7995,
	0xE2FB: 0x7996,
	0xE340: 0x7997,
	0xE2F8: 0x7998,
	0x9665: 0x7999,
	0xE6CB: 0x799A,
	0xE6D0: 0x799B,
	0xE6CE: 0x799C,
	0xFAC5: 0x799D,
	0xFFFD: 0x799E,
	0x9666: 0x799F,
	0xE6CD: 0x79A0,
	0xE6CC: 0x79A1,
	0xE6CF: 0x79A2,
	0xFFFD: 0x79A3,
	0xEAAE: 0x79A4,
	0x9667: 0x79A5,
	0xBF6D: 0x79A6,
	0xC148: 0x79A7,
	0xEDB0: 0x79A8,
	0xFCCA: 0x79A9,
	0xC149: 0x79AA,
	0xEDAF: 0x79AB,
	0xF05F: 0x79AC,
	0xF05E: 0x79AD,
	0xC2A7: 0x79AE,
	0xFFFD: 0x79AF,
	0xF2A5: 0x79B0,
	0xC3AB: 0x79B1,
	0xF4A1: 0x79B2,
	0xC5A1: 0x79B3,
	0xF6F7: 0x79B4,
	0xFFFD: 0x79B5,
	0xF8B7: 0x79B6,
	0xF8B6: 0x79B7,
	0xC9A8: 0x79B8,
	0xACEA: 0x79B9,
	0xACEB: 0x79BA,
	0xD6C3: 0x79BB,
	0xFFFD: 0x79BC,
	0xB856: 0x79BD,
	0xA5DD: 0x79BE,
	0xA872: 0x79BF,
	0xA871: 0x79C0,
	0xA870: 0x79C1,
	0xFFFD: 0x79C2,
	0xFAC6: 0x79C3,
	0xFBA9: 0x79C4,
	0xCDA4: 0x79C5,
	0x84FD: 0x79C6,
	0xFFFD: 0x79C7,
	0xAAC4: 0x79C8,
	0xAAC3: 0x79C9,
	0x9DCE: 0x79CA,
	0xACEE: 0x79CB,
	0xFCA6: 0x79CC,
	0xCFFA: 0x79CD,
	0xCFFD: 0x79CE,
	0xCFFB: 0x79CF,
	0xFFFD: 0x79D0,
	0xACEC: 0x79D1,
	0xACED: 0x79D2,
	0xFFFD: 0x79D3,
	0xFCCC: 0x79D4,
	0xCFF9: 0x79D5,
	0xCFFC: 0x79D6,
	0xFFFD: 0x79D7,
	0xAFB5: 0x79D8,
	0xFFFD: 0x79D9,
	0xFFFD: 0x79DA,
	0xFFFD: 0x79DB,
	0xD2F3: 0x79DC,
	0xD2F5: 0x79DD,
	0xD2F4: 0x79DE,
	0xAFB2: 0x79DF,
	0xD2EF: 0x79E0,
	0xFAC7: 0x79E1,
	0x9668: 0x79E2,
	0xAFB0: 0x79E3,
	0xAFAF: 0x79E4,
	0xFFFD: 0x79E5,
	0xAFB3: 0x79E6,
	0xAFB1: 0x79E7,
	0xFFFD: 0x79E8,
	0xAFB4: 0x79E9,
	0xD2F2: 0x79EA,
	0xD2ED: 0x79EB,
	0xD2EE: 0x79EC,
	0xD2F1: 0x79ED,
	0xD2F0: 0x79EE,
	0x85B8: 0x79EF,
	0x86EF: 0x79F0,
	0x9669: 0x79F1,
	0xFFFD: 0x79F2,
	0xFFFD: 0x79F3,
	0x966A: 0x79F4,
	0xFFFD: 0x79F5,
	0xD6C6: 0x79F6,
	0xD6C7: 0x79F7,
	0xD6C5: 0x79F8,
	0xFFFD: 0x79F9,
	0xD6C4: 0x79FA,
	0xB2BE: 0x79FB,
	0xFFFD: 0x79FC,
	0x8AE2: 0x79FD,
	0xFFFD: 0x79FE,
	0xFFFD: 0x79FF,
	0xB57D: 0x7A00,
	0xFFFD: 0x7A01,
	0xDAD6: 0x7A02,
	0xDAD8: 0x7A03,
	0xDADA: 0x7A04,
	0xB57C: 0x7A05,
	0xFAC8: 0x7A06,
	0xFFFD: 0x7A07,
	0xB57A: 0x7A08,
	0xFFFD: 0x7A09,
	0xDAD7: 0x7A0A,
	0xB57B: 0x7A0B,
	0xDAD9: 0x7A0C,
	0xB579: 0x7A0D,
	0xFAC9: 0x7A0E,
	0xFFFD: 0x7A0F,
	0xDF41: 0x7A10,
	0xDEF7: 0x7A11,
	0xDEFA: 0x7A12,
	0xDEFE: 0x7A13,
	0xB85A: 0x7A14,
	0xDEFC: 0x7A15,
	0xFFFD: 0x7A16,
	0xDEFB: 0x7A17,
	0xDEF8: 0x7A18,
	0xDEF9: 0x7A19,
	0xB858: 0x7A1A,
	0xDF40: 0x7A1B,
	0xB857: 0x7A1C,
	0xFFFD: 0x7A1D,
	0xB85C: 0x7A1E,
	0xB85B: 0x7A1F,
	0xB859: 0x7A20,
	0xFFFD: 0x7A21,
	0xDEFD: 0x7A22,
	0x8947: 0x7A23,
	0xFFFD: 0x7A24,
	0xFFFD: 0x7A25,
	0xE349: 0x7A26,
	0xFFFD: 0x7A27,
	0xE348: 0x7A28,
	0xFFFD: 0x7A29,
	0x966B: 0x7A2A,
	0xE344: 0x7A2B,
	0xFFFD: 0x7A2C,
	0xFCCE: 0x7A2D,
	0xBAD8: 0x7A2E,
	0xE347: 0x7A2F,
	0xE346: 0x7A30,
	0xBAD9: 0x7A31,
	0x93A6: 0x7A32,
	0x8BAE: 0x7A33,
	0xFFFD: 0x7A34,
	0xFFFD: 0x7A35,
	0xFFFD: 0x7A36,
	0xBD5E: 0x7A37,
	0xFFFD: 0x7A38,
	0xE6D2: 0x7A39,
	0x966C: 0x7A3A,
	0xBD5F: 0x7A3B,
	0xBD5B: 0x7A3C,
	0xBD5D: 0x7A3D,
	0xFCCF: 0x7A3E,
	0xBD5A: 0x7A3F,
	0xBD5C: 0x7A40,
	0xFFFD: 0x7A41,
	0x92F9: 0x7A42,
	0xFACA: 0x7A43,
	0xEAAF: 0x7A44,
	0x966D: 0x7A45,
	0xBF70: 0x7A46,
	0xEAB1: 0x7A47,
	0xEAB0: 0x7A48,
	0xFCD0: 0x7A49,
	0xE345: 0x7A4A,
	0xBF72: 0x7A4B,
	0xBF71: 0x7A4C,
	0xBF6E: 0x7A4D,
	0xBF6F: 0x7A4E,
	0x9253: 0x7A4F,
	0xFACB: 0x7A50,
	0x8AE1: 0x7A51,
	0xFFFD: 0x7A52,
	0xFFFD: 0x7A53,
	0xEDB5: 0x7A54,
	0xFFFD: 0x7A55,
	0xEDB3: 0x7A56,
	0xC14A: 0x7A57,
	0xEDB4: 0x7A58,
	0xFFFD: 0x7A59,
	0xEDB6: 0x7A5A,
	0xEDB2: 0x7A5B,
	0xEDB1: 0x7A5C,
	0xFFFD: 0x7A5D,
	0xFFFD: 0x7A5E,
	0xF060: 0x7A5F,
	0xC2AA: 0x7A60,
	0xC2A8: 0x7A61,
	0xC2A9: 0x7A62,
	0x8267: 0x7A63,
	0xFFFD: 0x7A64,
	0x966E: 0x7A65,
	0xFFFD: 0x7A66,
	0xF2A6: 0x7A67,
	0xF2A7: 0x7A68,
	0xC3AD: 0x7A69,
	0xFFFD: 0x7A6A,
	0xC3AC: 0x7A6B,
	0xF4A3: 0x7A6C,
	0xF4A4: 0x7A6D,
	0xF4A2: 0x7A6E,
	0xFFFD: 0x7A6F,
	0xF6F8: 0x7A70,
	0xF6F9: 0x7A71,
	0xFFFD: 0x7A72,
	0xFFFD: 0x7A73,
	0xA5DE: 0x7A74,
	0xCA48: 0x7A75,
	0xA873: 0x7A76,
	0x87FB: 0x7A77,
	0xCDA5: 0x7A78,
	0xAAC6: 0x7A79,
	0xAAC5: 0x7A7A,
	0xCDA6: 0x7A7B,
	0xFFFD: 0x7A7C,
	0xFC42: 0x7A7D,
	0xD040: 0x7A7E,
	0xACEF: 0x7A7F,
	0xCFFE: 0x7A80,
	0xACF0: 0x7A81,
	0xFFFD: 0x7A82,
	0x8CFA: 0x7A83,
	0xAFB6: 0x7A84,
	0xD2F8: 0x7A85,
	0xD2F6: 0x7A86,
	0xD2FC: 0x7A87,
	0xAFB7: 0x7A88,
	0xD2F7: 0x7A89,
	0xD2FB: 0x7A8A,
	0xD2F9: 0x7A8B,
	0xD2FA: 0x7A8C,
	0x8AE4: 0x7A8D,
	0xFFFD: 0x7A8E,
	0xD6C8: 0x7A8F,
	0xD6CA: 0x7A90,
	0x87FA: 0x7A91,
	0xB2BF: 0x7A92,
	0x9358: 0x7A93,
	0xD6C9: 0x7A94,
	0xB2C0: 0x7A95,
	0xB5A2: 0x7A96,
	0xB5A1: 0x7A97,
	0xB57E: 0x7A98,
	0xDADB: 0x7A99,
	0xFFFD: 0x7A9A,
	0xFFFD: 0x7A9B,
	0x8AE3: 0x7A9C,
	0x86F1: 0x7A9D,
	0xDF44: 0x7A9E,
	0xB85D: 0x7A9F,
	0xB85E: 0x7AA0,
	0xFFFD: 0x7AA1,
	0xDF43: 0x7AA2,
	0xDF42: 0x7AA3,
	0xFFFD: 0x7AA4,
	0x8948: 0x7AA5,
	0x8C43: 0x7AA6,
	0xFFFD: 0x7AA7,
	0xE34A: 0x7AA8,
	0xBADB: 0x7AA9,
	0xBADA: 0x7AAA,
	0xE34B: 0x7AAB,
	0xE34C: 0x7AAC,
	0x8EEE: 0x7AAD,
	0xBD61: 0x7AAE,
	0xBD60: 0x7AAF,
	0xFEA7: 0x7AB0,
	0xEAB5: 0x7AB1,
	0xE6D3: 0x7AB2,
	0xE6D5: 0x7AB3,
	0xE6D4: 0x7AB4,
	0xEAB4: 0x7AB5,
	0xEAB2: 0x7AB6,
	0xEAB6: 0x7AB7,
	0xEAB3: 0x7AB8,
	0xFFFD: 0x7AB9,
	0xBF73: 0x7ABA,
	0xFC44: 0x7ABB,
	0x966F: 0x7ABC,
	0xFFFD: 0x7ABD,
	0xEDB7: 0x7ABE,
	0xC14B: 0x7ABF,
	0xEDB8: 0x7AC0,
	0xEDB9: 0x7AC1,
	0x9670: 0x7AC2,
	0xFACC: 0x7AC3,
	0xC2AB: 0x7AC4,
	0xC2AC: 0x7AC5,
	0xFFFD: 0x7AC6,
	0xC475: 0x7AC7,
	0xFDE5: 0x7AC8,
	0x9671: 0x7AC9,
	0xC5D1: 0x7ACA,
	0xA5DF: 0x7ACB,
	0xFFFD: 0x7ACC,
	0x94B5: 0x7ACD,
	0xFFFD: 0x7ACE,
	0x94B6: 0x7ACF,
	0xFFFD: 0x7AD0,
	0xD041: 0x7AD1,
	0xFACD: 0x7AD2,
	0x94B8: 0x7AD3,
	0xFFFD: 0x7AD4,
	0x94B7: 0x7AD5,
	0x8867: 0x7AD6,
	0xFFFD: 0x7AD7,
	0xD2FD: 0x7AD8,
	0xAFB8: 0x7AD9,
	0xFCD2: 0x7ADA,
	0x9672: 0x7ADB,
	0x93E2: 0x7ADC,
	0xFCD1: 0x7ADD,
	0x8C44: 0x7ADE,
	0xB3BA: 0x7ADF,
	0xB3B9: 0x7AE0,
	0x94B9: 0x7AE1,
	0xFACE: 0x7AE2,
	0xB5A4: 0x7AE3,
	0xDADD: 0x7AE4,
	0xB5A3: 0x7AE5,
	0xDADC: 0x7AE6,
	0xFACF: 0x7AE7,
	0xFFFD: 0x7AE8,
	0x9673: 0x7AE9,
	0x826D: 0x7AEA,
	0xDF45: 0x7AEB,
	0xFFFD: 0x7AEC,
	0xBADC: 0x7AED,
	0xE34D: 0x7AEE,
	0xBADD: 0x7AEF,
	0x94BA: 0x7AF0,
	0xFFFD: 0x7AF1,
	0xFFFD: 0x7AF2,
	0xFFFD: 0x7AF3,
	0xFFFD: 0x7AF4,
	0xFFFD: 0x7AF5,
	0xC476: 0x7AF6,
	0xF4A5: 0x7AF7,
	0xFAD0: 0x7AF8,
	0xA6CB: 0x7AF9,
	0xAAC7: 0x7AFA,
	0xCDA7: 0x7AFB,
	0xFFFD: 0x7AFC,
	0xACF2: 0x7AFD,
	0x9674: 0x7AFE,
	0xACF1: 0x7AFF,
	0xD042: 0x7B00,
	0xD043: 0x7B01,
	0x94BB: 0x7B02,
	0x8949: 0x7B03,
	0xD340: 0x7B04,
	0xD342: 0x7B05,
	0xAFB9: 0x7B06,
	0xFFFD: 0x7B07,
	0xD344: 0x7B08,
	0xD347: 0x7B09,
	0xD345: 0x7B0A,
	0x8541: 0x7B0B,
	0x9675: 0x7B0C,
	0xFFFD: 0x7B0D,
	0xD346: 0x7B0E,
	0xD343: 0x7B0F,
	0xD2FE: 0x7B10,
	0xAFBA: 0x7B11,
	0xD348: 0x7B12,
	0xD341: 0x7B13,
	0x8540: 0x7B14,
	0x85EC: 0x7B15,
	0xFFFD: 0x7B16,
	0xFFFD: 0x7B17,
	0xD6D3: 0x7B18,
	0xB2C6: 0x7B19,
	0xD6DC: 0x7B1A,
	0xB2C3: 0x7B1B,
	0xFFFD: 0x7B1C,
	0xD6D5: 0x7B1D,
	0xB2C7: 0x7B1E,
	0xFCDC: 0x7B1F,
	0xB2C1: 0x7B20,
	0xFFFD: 0x7B21,
	0xD6D0: 0x7B22,
	0xD6DD: 0x7B23,
	0xD6D1: 0x7B24,
	0xD6CE: 0x7B25,
	0xB2C5: 0x7B26,
	0x9676: 0x7B27,
	0xB2C2: 0x7B28,
	0x9677: 0x7B29,
	0xD6D4: 0x7B2A,
	0xD6D7: 0x7B2B,
	0xB2C4: 0x7B2C,
	0xD6D8: 0x7B2D,
	0xB2C8: 0x7B2E,
	0xD6D9: 0x7B2F,
	0xD6CF: 0x7B30,
	0xD6D6: 0x7B31,
	0xD6DA: 0x7B32,
	0xD6D2: 0x7B33,
	0xD6CD: 0x7B34,
	0xD6CB: 0x7B35,
	0xFAD1: 0x7B36,
	0xFFFD: 0x7B37,
	0xD6DB: 0x7B38,
	0xFE64: 0x7B39,
	0x86F2: 0x7B3A,
	0xDADF: 0x7B3B,
	0x8CD7: 0x7B3C,
	0xFFFD: 0x7B3D,
	0x907A: 0x7B3E,
	0xFFFD: 0x7B3F,
	0xDAE4: 0x7B40,
	0xFFFD: 0x7B41,
	0x9678: 0x7B42,
	0x9679: 0x7B43,
	0xDAE0: 0x7B44,
	0xDAE6: 0x7B45,
	0xB5A7: 0x7B46,
	0xD6CC: 0x7B47,
	0xDAE1: 0x7B48,
	0xB5A5: 0x7B49,
	0xDADE: 0x7B4A,
	0xB5AC: 0x7B4B,
	0xDAE2: 0x7B4C,
	0xB5AB: 0x7B4D,
	0xDAE3: 0x7B4E,
	0xB5AD: 0x7B4F,
	0xB5A8: 0x7B50,
	0xB5AE: 0x7B51,
	0xB5A9: 0x7B52,
	0xFFFD: 0x7B53,
	0xB5AA: 0x7B54,
	0x967A: 0x7B55,
	0xB5A6: 0x7B56,
	0xFFFD: 0x7B57,
	0xDAE5: 0x7B58,
	0xFFFD: 0x7B59,
	0x8F5B: 0x7B5A,
	0x894A: 0x7B5B,
	0xFFFD: 0x7B5C,
	0x86F3: 0x7B5D,
	0xFFFD: 0x7B5E,
	0xFFFD: 0x7B5F,
	0xB861: 0x7B60,
	0xDF50: 0x7B61,
	0xFAD2: 0x7B62,
	0xDF53: 0x7B63,
	0xDF47: 0x7B64,
	0xDF4C: 0x7B65,
	0xDF46: 0x7B66,
	0xB863: 0x7B67,
	0xFFFD: 0x7B68,
	0xDF4A: 0x7B69,
	0xFFFD: 0x7B6A,
	0xFFFD: 0x7B6B,
	0xFAD3: 0x7B6C,
	0xDF48: 0x7B6D,
	0xB862: 0x7B6E,
	0x967B: 0x7B6F,
	0xDF4F: 0x7B70,
	0xDF4E: 0x7B71,
	0xDF4B: 0x7B72,
	0xDF4D: 0x7B73,
	0xDF49: 0x7B74,
	0xBAE1: 0x7B75,
	0xDF52: 0x7B76,
	0xB85F: 0x7B77,
	0xDF51: 0x7B78,
	0x8C45: 0x7B79,
	0xFAD4: 0x7B7A,
	0xFAD5: 0x7B7B,
	0xFFFD: 0x7B7C,
	0xFFFD: 0x7B7D,
	0x8BAF: 0x7B7E,
	0xFFFD: 0x7B7F,
	0x8AE9: 0x7B80,
	0xFFFD: 0x7B81,
	0xE35D: 0x7B82,
	0xFFFD: 0x7B83,
	0xBAE8: 0x7B84,
	0xE358: 0x7B85,
	0x827A: 0x7B86,
	0xBAE7: 0x7B87,
	0xE34E: 0x7B88,
	0xFFFD: 0x7B89,
	0xE350: 0x7B8A,
	0xBAE0: 0x7B8B,
	0xE355: 0x7B8C,
	0xE354: 0x7B8D,
	0xE357: 0x7B8E,
	0xBAE5: 0x7B8F,
	0xE352: 0x7B90,
	0xE351: 0x7B91,
	0xFCDD: 0x7B92,
	0xFFFD: 0x7B93,
	0xBAE4: 0x7B94,
	0xBADF: 0x7B95,
	0xE353: 0x7B96,
	0xBAE2: 0x7B97,
	0xE359: 0x7B98,
	0xE35B: 0x7B99,
	0xFAD6: 0x7B9A,
	0xE356: 0x7B9B,
	0xE34F: 0x7B9C,
	0xBAE3: 0x7B9D,
	0xFAD7: 0x7B9E,
	0xFAD8: 0x7B9F,
	0xBD69: 0x7BA0,
	0xBADE: 0x7BA1,
	0xFAD9: 0x7BA2,
	0xFCDE: 0x7BA3,
	0xE35C: 0x7BA4,
	0xFFFD: 0x7BA5,
	0x8F5A: 0x7BA6,
	0xFADA: 0x7BA7,
	0x9059: 0x7BA8,
	0x8D71: 0x7BA9,
	0x8AE7: 0x7BAA,
	0x8AE5: 0x7BAB,
	0xE6D9: 0x7BAC,
	0xBD62: 0x7BAD,
	0xFFFD: 0x7BAE,
	0xE6DB: 0x7BAF,
	0xFFFD: 0x7BB0,
	0xBD63: 0x7BB1,
	0x967C: 0x7BB2,
	0xFFFD: 0x7BB3,
	0xBD65: 0x7BB4,
	0xE6DE: 0x7BB5,
	0xFFFD: 0x7BB6,
	0xE6D6: 0x7BB7,
	0xBAE6: 0x7BB8,
	0xE6DC: 0x7BB9,
	0xFFFD: 0x7BBA,
	0xFFFD: 0x7BBB,
	0xFFFD: 0x7BBC,
	0xFFFD: 0x7BBD,
	0xE6D8: 0x7BBE,
	0xFFFD: 0x7BBF,
	0xB860: 0x7BC0,
	0xBD68: 0x7BC1,
	0xFFFD: 0x7BC2,
	0xFFFD: 0x7BC3,
	0xBD64: 0x7BC4,
	0xFFFD: 0x7BC5,
	0xBD66: 0x7BC6,
	0xBD67: 0x7BC7,
	0xFFFD: 0x7BC8,
	0xBF76: 0x7BC9,
	0xE6DD: 0x7BCA,
	0xE6D7: 0x7BCB,
	0xBD6A: 0x7BCC,
	0xFFFD: 0x7BCD,
	0xE6DA: 0x7BCE,
	0xFCDF: 0x7BCF,
	0x96D0: 0x7BD0,
	0x8AE8: 0x7BD1,
	0xFFFD: 0x7BD2,
	0x8A40: 0x7BD3,
	0xEAC0: 0x7BD4,
	0xEABB: 0x7BD5,
	0xFFFD: 0x7BD6,
	0xFFFD: 0x7BD7,
	0xEAC5: 0x7BD8,
	0xBF74: 0x7BD9,
	0xEABD: 0x7BDA,
	0xBF78: 0x7BDB,
	0xEAC3: 0x7BDC,
	0xEABA: 0x7BDD,
	0xEAB7: 0x7BDE,
	0xEAC6: 0x7BDF,
	0xC151: 0x7BE0,
	0xBF79: 0x7BE1,
	0xEAC2: 0x7BE2,
	0xEAB8: 0x7BE3,
	0xBF77: 0x7BE4,
	0xEABC: 0x7BE5,
	0xBF7B: 0x7BE6,
	0xEAB9: 0x7BE7,
	0xEABE: 0x7BE8,
	0xBF7A: 0x7BE9,
	0xEAC1: 0x7BEA,
	0xEAC4: 0x7BEB,
	0x96D1: 0x7BEC,
	0x82A1: 0x7BED,
	0x8C46: 0x7BEE,
	0xFFFD: 0x7BEF,
	0xEDCB: 0x7BF0,
	0xEDCC: 0x7BF1,
	0xEDBC: 0x7BF2,
	0xEDC3: 0x7BF3,
	0xEDC1: 0x7BF4,
	0xFFFD: 0x7BF5,
	0xFADB: 0x7BF6,
	0xC14F: 0x7BF7,
	0xEDC8: 0x7BF8,
	0xEABF: 0x7BF9,
	0x96D2: 0x7BFA,
	0xEDBF: 0x7BFB,
	0xFCE1: 0x7BFC,
	0xEDC9: 0x7BFD,
	0xC14E: 0x7BFE,
	0xEDBE: 0x7BFF,
	0xEDBD: 0x7C00,
	0xEDC7: 0x7C01,
	0xEDC4: 0x7C02,
	0xEDC6: 0x7C03,
	0xFFFD: 0x7C04,
	0xEDBA: 0x7C05,
	0xEDCA: 0x7C06,
	0xC14C: 0x7C07,
	0xFFFD: 0x7C08,
	0xEDC5: 0x7C09,
	0xEDCE: 0x7C0A,
	0xEDC2: 0x7C0B,
	0xC150: 0x7C0C,
	0xC14D: 0x7C0D,
	0xEDC0: 0x7C0E,
	0xEDBB: 0x7C0F,
	0xEDCD: 0x7C10,
	0xBF75: 0x7C11,
	0xFADC: 0x7C12,
	0x94BC: 0x7C13,
	0xFADD: 0x7C14,
	0x96D3: 0x7C15,
	0x9077: 0x7C16,
	0x94BD: 0x7C17,
	0xFFFD: 0x7C18,
	0xF063: 0x7C19,
	0xFFFD: 0x7C1A,
	0x96D4: 0x7C1B,
	0xF061: 0x7C1C,
	0xF067: 0x7C1D,
	0xC2B0: 0x7C1E,
	0xF065: 0x7C1F,
	0xF064: 0x7C20,
	0xC2B2: 0x7C21,
	0xF06A: 0x7C22,
	0xC2B1: 0x7C23,
	0xFFFD: 0x7C24,
	0xF06B: 0x7C25,
	0xF068: 0x7C26,
	0xC2AE: 0x7C27,
	0xF069: 0x7C28,
	0xF062: 0x7C29,
	0xC2AF: 0x7C2A,
	0xC2AD: 0x7C2B,
	0xF2AB: 0x7C2C,
	0xF066: 0x7C2D,
	0xFFFD: 0x7C2E,
	0xFFFD: 0x7C2F,
	0xF06C: 0x7C30,
	0xFFFD: 0x7C31,
	0xFFFD: 0x7C32,
	0xF2A8: 0x7C33,
	0xFFFD: 0x7C34,
	0x96D5: 0x7C35,
	0xFFFD: 0x7C36,
	0xC3B2: 0x7C37,
	0xC3B0: 0x7C38,
	0xF2AA: 0x7C39,
	0xFFFD: 0x7C3A,
	0xF2AC: 0x7C3B,
	0xF2A9: 0x7C3C,
	0xC3B1: 0x7C3D,
	0xC3AE: 0x7C3E,
	0xC3AF: 0x7C3F,
	0xC3B3: 0x7C40,
	0x8CD8: 0x7C41,
	0xFCE2: 0x7C42,
	0xC478: 0x7C43,
	0x96D6: 0x7C44,
	0xF4AA: 0x7C45,
	0xFFFD: 0x7C46,
	0xF4A9: 0x7C47,
	0xF4A7: 0x7C48,
	0xF4A6: 0x7C49,
	0xF4A8: 0x7C4A,
	0xFFFD: 0x7C4B,
	0xC477: 0x7C4C,
	0xC479: 0x7C4D,
	0xFFFD: 0x7C4E,
	0xFADE: 0x7C4F,
	0xC4F0: 0x7C50,
	0xFCE3: 0x7C51,
	0xFFFD: 0x7C52,
	0xF5E5: 0x7C53,
	0xF5E4: 0x7C54,
	0xFFFD: 0x7C55,
	0xFADF: 0x7C56,
	0xF6FA: 0x7C57,
	0xFAE0: 0x7C58,
	0xF6FC: 0x7C59,
	0xF6FE: 0x7C5A,
	0xF6FD: 0x7C5B,
	0xF6FB: 0x7C5C,
	0xFCE4: 0x7C5D,
	0xFFFD: 0x7C5E,
	0xC5A3: 0x7C5F,
	0xC5A2: 0x7C60,
	0xFFFD: 0x7C61,
	0xFFFD: 0x7C62,
	0xC5D3: 0x7C63,
	0xC5D2: 0x7C64,
	0xC5D4: 0x7C65,
	0xF7ED: 0x7C66,
	0xF7EC: 0x7C67,
	0xFFFD: 0x7C68,
	0xF8FB: 0x7C69,
	0xF8B8: 0x7C6A,
	0xF8FC: 0x7C6B,
	0xC658: 0x7C6C,
	0x96D7: 0x7C6D,
	0xC659: 0x7C6E,
	0xF96D: 0x7C6F,
	0xFCE5: 0x7C70,
	0xFFFD: 0x7C71,
	0xC67E: 0x7C72,
	0xA6CC: 0x7C73,
	0x905A: 0x7C74,
	0xCDA8: 0x7C75,
	0xFFFD: 0x7C76,
	0xFFFD: 0x7C77,
	0xD045: 0x7C78,
	0xD046: 0x7C79,
	0xD044: 0x7C7A,
	0x8BDD: 0x7C7B,
	0x835E: 0x7C7C,
	0xACF3: 0x7C7D,
	0xFCE6: 0x7C7E,
	0xD047: 0x7C7F,
	0xD048: 0x7C80,
	0xD049: 0x7C81,
	0x9443: 0x7C82,
	0xFCE8: 0x7C83,
	0xD349: 0x7C84,
	0xD34F: 0x7C85,
	0xFCE7: 0x7C86,
	0xFFFD: 0x7C87,
	0xD34D: 0x7C88,
	0xAFBB: 0x7C89,
	0xD34B: 0x7C8A,
	0x92F7: 0x7C8B,
	0xD34C: 0x7C8C,
	0xD34E: 0x7C8D,
	0x96D8: 0x7C8E,
	0xFFFD: 0x7C8F,
	0x94BE: 0x7C90,
	0xD34A: 0x7C91,
	0xB2C9: 0x7C92,
	0xFFFD: 0x7C93,
	0xD6DE: 0x7C94,
	0xB2CB: 0x7C95,
	0xD6E0: 0x7C96,
	0xB2CA: 0x7C97,
	0xD6DF: 0x7C98,
	0xFFFD: 0x7C99,
	0xFFFD: 0x7C9A,
	0x92E0: 0x7C9B,
	0x907B: 0x7C9C,
	0x9043: 0x7C9D,
	0xDAE8: 0x7C9E,
	0xB5AF: 0x7C9F,
	0xFFFD: 0x7CA0,
	0xDAEA: 0x7CA1,
	0xDAE7: 0x7CA2,
	0xD6E1: 0x7CA3,
	0x85ED: 0x7CA4,
	0xB5B0: 0x7CA5,
	0xFE63: 0x7CA6,
	0xF9DB: 0x7CA7,
	0xDAE9: 0x7CA8,
	0xFFFD: 0x7CA9,
	0x8A41: 0x7CAA,
	0xFAE1: 0x7CAB,
	0xFCE9: 0x7CAC,
	0x94BF: 0x7CAD,
	0x8AEA: 0x7CAE,
	0xDF56: 0x7CAF,
	0xFFFD: 0x7CB0,
	0xB864: 0x7CB1,
	0xDF54: 0x7CB2,
	0xB865: 0x7CB3,
	0xDF55: 0x7CB4,
	0xB866: 0x7CB5,
	0xFFFD: 0x7CB6,
	0xFFFD: 0x7CB7,
	0x96D9: 0x7CB8,
	0xBAE9: 0x7CB9,
	0xE361: 0x7CBA,
	0xE35E: 0x7CBB,
	0xE360: 0x7CBC,
	0xBAEA: 0x7CBD,
	0xBAEB: 0x7CBE,
	0xE35F: 0x7CBF,
	0x94C0: 0x7CC0,
	0x8A43: 0x7CC1,
	0xFCEB: 0x7CC2,
	0x96DA: 0x7CC3,
	0xFFFD: 0x7CC4,
	0xE6DF: 0x7CC5,
	0xFFFD: 0x7CC6,
	0xFCEA: 0x7CC7,
	0xE6E0: 0x7CC8,
	0x95B2: 0x7CC9,
	0xBD6B: 0x7CCA,
	0xE6E2: 0x7CCB,
	0xE6E1: 0x7CCC,
	0xA054: 0x7CCD,
	0xA261: 0x7CCE,
	0xFFFD: 0x7CCF,
	0xEACA: 0x7CD0,
	0xEACB: 0x7CD1,
	0xEAC7: 0x7CD2,
	0xFB7E: 0x7CD3,
	0xEAC8: 0x7CD4,
	0xBF7C: 0x7CD5,
	0xBF7D: 0x7CD6,
	0xEAC9: 0x7CD7,
	0x94C1: 0x7CD8,
	0xC157: 0x7CD9,
	0xFCED: 0x7CDA,
	0xFFFD: 0x7CDB,
	0xC153: 0x7CDC,
	0xC158: 0x7CDD,
	0xC154: 0x7CDE,
	0xC156: 0x7CDF,
	0xC152: 0x7CE0,
	0xFFFD: 0x7CE1,
	0xC155: 0x7CE2,
	0xFFFD: 0x7CE3,
	0xFFFD: 0x7CE4,
	0xFFFD: 0x7CE5,
	0x96DB: 0x7CE6,
	0xC2B3: 0x7CE7,
	0xEDCF: 0x7CE8,
	0xFFFD: 0x7CE9,
	0xF2AE: 0x7CEA,
	0xFFFD: 0x7CEB,
	0xF2AD: 0x7CEC,
	0x96DC: 0x7CED,
	0xF4AB: 0x7CEE,
	0xC47A: 0x7CEF,
	0xC47B: 0x7CF0,
	0xF741: 0x7CF1,
	0xF5E6: 0x7CF2,
	0x96DD: 0x7CF3,
	0xF740: 0x7CF4,
	0x96DE: 0x7CF5,
	0xF8FD: 0x7CF6,
	0xF9A4: 0x7CF7,
	0xA6CD: 0x7CF8,
	0x96DF: 0x7CF9,
	0xFAE2: 0x7CFA,
	0xA874: 0x7CFB,
	0x96E1: 0x7CFC,
	0xCDA9: 0x7CFD,
	0xAAC8: 0x7CFE,
	0xFFFD: 0x7CFF,
	0xACF6: 0x7D00,
	0xD04C: 0x7D01,
	0xACF4: 0x7D02,
	0xD04A: 0x7D03,
	0xACF9: 0x7D04,
	0xACF5: 0x7D05,
	0xACFA: 0x7D06,
	0xACF8: 0x7D07,
	0xD04B: 0x7D08,
	0xACF7: 0x7D09,
	0xAFBF: 0x7D0A,
	0xAFBE: 0x7D0B,
	0xD35A: 0x7D0C,
	0xAFC7: 0x7D0D,
	0xD353: 0x7D0E,
	0xD359: 0x7D0F,
	0xAFC3: 0x7D10,
	0xD352: 0x7D11,
	0xD358: 0x7D12,
	0xD356: 0x7D13,
	0xAFC2: 0x7D14,
	0xAFC4: 0x7D15,
	0xD355: 0x7D16,
	0xAFBD: 0x7D17,
	0xD354: 0x7D18,
	0xAFC8: 0x7D19,
	0xAFC5: 0x7D1A,
	0xAFC9: 0x7D1B,
	0xAFC6: 0x7D1C,
	0xD351: 0x7D1D,
	0xD350: 0x7D1E,
	0xD357: 0x7D1F,
	0xAFC0: 0x7D20,
	0xAFBC: 0x7D21,
	0xAFC1: 0x7D22,
	0xFFFD: 0x7D23,
	0xFFFD: 0x7D24,
	0x95E2: 0x7D25,
	0xFFFD: 0x7D26,
	0x86FA: 0x7D27,
	0xD6F0: 0x7D28,
	0xD6E9: 0x7D29,
	0xFFFD: 0x7D2A,
	0xB5B5: 0x7D2B,
	0xD6E8: 0x7D2C,
	0xFFFD: 0x7D2D,
	0xB2CF: 0x7D2E,
	0xB2D6: 0x7D2F,
	0xB2D3: 0x7D30,
	0xB2D9: 0x7D31,
	0xB2D8: 0x7D32,
	0xB2D4: 0x7D33,
	0xFFFD: 0x7D34,
	0xD6E2: 0x7D35,
	0xD6E5: 0x7D36,
	0xFFFD: 0x7D37,
	0xD6E4: 0x7D38,
	0xB2D0: 0x7D39,
	0xD6E6: 0x7D3A,
	0xD6EF: 0x7D3B,
	0xB2D1: 0x7D3C,
	0xD6E3: 0x7D3D,
	0xD6EC: 0x7D3E,
	0xD6ED: 0x7D3F,
	0xB2D2: 0x7D40,
	0xD6EA: 0x7D41,
	0xB2D7: 0x7D42,
	0xB2CD: 0x7D43,
	0xB2D5: 0x7D44,
	0xD6E7: 0x7D45,
	0xB2CC: 0x7D46,
	0xD6EB: 0x7D47,
	0xFAE3: 0x7D48,
	0xFFFD: 0x7D49,
	0xD6EE: 0x7D4A,
	0xFAE4: 0x7D4B,
	0x92AB: 0x7D4C,
	0xFCEF: 0x7D4D,
	0xDAFB: 0x7D4E,
	0xDAF2: 0x7D4F,
	0xB5B2: 0x7D50,
	0xDAF9: 0x7D51,
	0xDAF6: 0x7D52,
	0xDAEE: 0x7D53,
	0xDAF7: 0x7D54,
	0xB5B4: 0x7D55,
	0xDAEF: 0x7D56,
	0xFFFD: 0x7D57,
	0xDAEB: 0x7D58,
	0xFFFD: 0x7D59,
	0xFCF0: 0x7D5A,
	0xB86C: 0x7D5B,
	0xDAF4: 0x7D5C,
	0xFE60: 0x7D5D,
	0xB5B1: 0x7D5E,
	0xDAFA: 0x7D5F,
	0xFFFD: 0x7D60,
	0xB5B8: 0x7D61,
	0xB5BA: 0x7D62,
	0xDAED: 0x7D63,
	0xFFFD: 0x7D64,
	0xFFFD: 0x7D65,
	0xB5B9: 0x7D66,
	0xDAF0: 0x7D67,
	0xB5B3: 0x7D68,
	0xDAF8: 0x7D69,
	0xDAF1: 0x7D6A,
	0xDAF5: 0x7D6B,
	0xFFFD: 0x7D6C,
	0xDAF3: 0x7D6D,
	0xB5B6: 0x7D6E,
	0xDAEC: 0x7D6F,
	0xB5BB: 0x7D70,
	0xB2CE: 0x7D71,
	0xB5B7: 0x7D72,
	0xB5BC: 0x7D73,
	0xFFFD: 0x7D74,
	0x925B: 0x7D75,
	0x9346: 0x7D76,
	0xFAE5: 0x7D77,
	0xFFFD: 0x7D78,
	0xB868: 0x7D79,
	0xDF5D: 0x7D7A,
	0xDF5F: 0x7D7B,
	0xDF61: 0x7D7C,
	0xDF65: 0x7D7D,
	0xFFFD: 0x7D7E,
	0xDF5B: 0x7D7F,
	0xDF59: 0x7D80,
	0xB86A: 0x7D81,
	0xFFFD: 0x7D82,
	0xDF60: 0x7D83,
	0xDF64: 0x7D84,
	0xDF5C: 0x7D85,
	0xDF58: 0x7D86,
	0xFFFD: 0x7D87,
	0xDF57: 0x7D88,
	0x9568: 0x7D89,
	0xFFFD: 0x7D8A,
	0x96E2: 0x7D8B,
	0xDF62: 0x7D8C,
	0xDF5A: 0x7D8D,
	0xDF5E: 0x7D8E,
	0xB86B: 0x7D8F,
	0xFFFD: 0x7D90,
	0xB869: 0x7D91,
	0xDF66: 0x7D92,
	0xB867: 0x7D93,
	0xDF63: 0x7D94,
	0x9DB9: 0x7D95,
	0xE372: 0x7D96,
	0x96E3: 0x7D97,
	0xFFFD: 0x7D98,
	0x92AE: 0x7D99,
	0x9364: 0x7D9A,
	0x94C2: 0x7D9B,
	0xBAEE: 0x7D9C,
	0xE36A: 0x7D9D,
	0xBD78: 0x7D9E,
	0xE374: 0x7D9F,
	0xBAF1: 0x7DA0,
	0xE378: 0x7DA1,
	0xBAF7: 0x7DA2,
	0xE365: 0x7DA3,
	0x96E4: 0x7DA4,
	0xFFFD: 0x7DA5,
	0xE375: 0x7DA6,
	0xE362: 0x7DA7,
	0x96E5: 0x7DA8,
	0xE377: 0x7DA9,
	0xE366: 0x7DAA,
	0x9556: 0x7DAB,
	0xBAFE: 0x7DAC,
	0xBAFB: 0x7DAD,
	0xE376: 0x7DAE,
	0xE370: 0x7DAF,
	0xBAED: 0x7DB0,
	0xBAF5: 0x7DB1,
	0xBAF4: 0x7DB2,
	0x956A: 0x7DB3,
	0xBAF3: 0x7DB4,
	0xBAF9: 0x7DB5,
	0xFFFD: 0x7DB6,
	0xE363: 0x7DB7,
	0xBAFA: 0x7DB8,
	0xE371: 0x7DB9,
	0xBAF6: 0x7DBA,
	0xBAEC: 0x7DBB,
	0xE373: 0x7DBC,
	0xBAEF: 0x7DBD,
	0xBAF0: 0x7DBE,
	0xBAF8: 0x7DBF,
	0xE368: 0x7DC0,
	0xE367: 0x7DC1,
	0xE364: 0x7DC2,
	0xFFFD: 0x7DC3,
	0xE36C: 0x7DC4,
	0xE369: 0x7DC5,
	0xE36D: 0x7DC6,
	0xBAFD: 0x7DC7,
	0xFFFD: 0x7DC8,
	0xE379: 0x7DC9,
	0xBAF2: 0x7DCA,
	0xE36E: 0x7DCB,
	0xE36F: 0x7DCC,
	0x96E6: 0x7DCD,
	0xE36B: 0x7DCE,
	0x935C: 0x7DCF,
	0x96E7: 0x7DD0,
	0x93E7: 0x7DD1,
	0xBAFC: 0x7DD2,
	0x96E8: 0x7DD3,
	0xFAE6: 0x7DD4,
	0xFAE7: 0x7DD5,
	0xFAE8: 0x7DD6,
	0xE6E7: 0x7DD7,
	0xBD70: 0x7DD8,
	0xBD79: 0x7DD9,
	0xBD75: 0x7DDA,
	0xE6E4: 0x7DDB,
	0x95C3: 0x7DDC,
	0xBD72: 0x7DDD,
	0xBD76: 0x7DDE,
	0xE6F0: 0x7DDF,
	0xBD6C: 0x7DE0,
	0xE6E8: 0x7DE1,
	0xFFFD: 0x7DE2,
	0xBD74: 0x7DE3,
	0xFAE9: 0x7DE4,
	0x96E9: 0x7DE5,
	0xE6EB: 0x7DE6,
	0xE6E6: 0x7DE7,
	0xBD73: 0x7DE8,
	0xBD77: 0x7DE9,
	0xE6E5: 0x7DEA,
	0xFFFD: 0x7DEB,
	0xBD71: 0x7DEC,
	0xFFFD: 0x7DED,
	0xE6EF: 0x7DEE,
	0xBD6E: 0x7DEF,
	0xE6EE: 0x7DF0,
	0xE6ED: 0x7DF1,
	0xBD7A: 0x7DF2,
	0xE572: 0x7DF3,
	0xBD6D: 0x7DF4,
	0xFCF1: 0x7DF5,
	0xE6EC: 0x7DF6,
	0xE6E3: 0x7DF7,
	0xFFFD: 0x7DF8,
	0xBD7B: 0x7DF9,
	0xE6EA: 0x7DFA,
	0xBD6F: 0x7DFB,
	0xFFFD: 0x7DFC,
	0x96EA: 0x7DFD,
	0x9F7E: 0x7DFE,
	0xFFFD: 0x7DFF,
	0xFFFD: 0x7E00,
	0x924D: 0x7E01,
	0xFFFD: 0x7E02,
	0xE6E9: 0x7E03,
	0x92ED: 0x7E04,
	0x94C3: 0x7E05,
	0xFFFD: 0x7E06,
	0x9FA1: 0x7E07,
	0xBFA2: 0x7E08,
	0xBFA7: 0x7E09,
	0xBF7E: 0x7E0A,
	0xEAD8: 0x7E0B,
	0xEACF: 0x7E0C,
	0xEADB: 0x7E0D,
	0xEAD3: 0x7E0E,
	0xEAD9: 0x7E0F,
	0xBFA8: 0x7E10,
	0xBFA1: 0x7E11,
	0xEACC: 0x7E12,
	0xEAD2: 0x7E13,
	0xEADC: 0x7E14,
	0xEAD5: 0x7E15,
	0xEADA: 0x7E16,
	0xEACE: 0x7E17,
	0xFFFD: 0x7E18,
	0xFFFD: 0x7E19,
	0xEAD6: 0x7E1A,
	0xBFA3: 0x7E1B,
	0xEAD4: 0x7E1C,
	0xBFA6: 0x7E1D,
	0xBFA5: 0x7E1E,
	0xEAD0: 0x7E1F,
	0xEAD1: 0x7E20,
	0xEACD: 0x7E21,
	0xEAD7: 0x7E22,
	0xBFA4: 0x7E23,
	0xEADE: 0x7E24,
	0xEADD: 0x7E25,
	0x92DF: 0x7E26,
	0xFCF2: 0x7E27,
	0xFFFD: 0x7E28,
	0xEDDA: 0x7E29,
	0xEDD6: 0x7E2A,
	0xC15F: 0x7E2B,
	0xFFFD: 0x7E2C,
	0xEDD0: 0x7E2D,
	0xC159: 0x7E2E,
	0xC169: 0x7E2F,
	0xEDDC: 0x7E30,
	0xC161: 0x7E31,
	0xC15D: 0x7E32,
	0xEDD3: 0x7E33,
	0xC164: 0x7E34,
	0xC167: 0x7E35,
	0xEDDE: 0x7E36,
	0xC15C: 0x7E37,
	0xEDD5: 0x7E38,
	0xC165: 0x7E39,
	0xEDE0: 0x7E3A,
	0xEDDD: 0x7E3B,
	0xEDD1: 0x7E3C,
	0xC160: 0x7E3D,
	0xC15A: 0x7E3E,
	0xC168: 0x7E3F,
	0xEDD8: 0x7E40,
	0xC163: 0x7E41,
	0xEDD2: 0x7E42,
	0xC15E: 0x7E43,
	0xEDDF: 0x7E44,
	0xC162: 0x7E45,
	0xC15B: 0x7E46,
	0xEDD9: 0x7E47,
	0xC166: 0x7E48,
	0xEDD7: 0x7E49,
	0x934F: 0x7E4A,
	0x825A: 0x7E4B,
	0xEDDB: 0x7E4C,
	0xFAEA: 0x7E4D,
	0xFFFD: 0x7E4E,
	0xFFFD: 0x7E4F,
	0xF06E: 0x7E50,
	0xF074: 0x7E51,
	0xC2B9: 0x7E52,
	0xF077: 0x7E53,
	0xC2B4: 0x7E54,
	0xC2B5: 0x7E55,
	0xF06F: 0x7E56,
	0xF076: 0x7E57,
	0xF071: 0x7E58,
	0xC2BA: 0x7E59,
	0xC2B7: 0x7E5A,
	0x9FA2: 0x7E5B,
	0xF06D: 0x7E5C,
	0xFAEB: 0x7E5D,
	0xC2B6: 0x7E5E,
	0xF073: 0x7E5F,
	0xF075: 0x7E60,
	0xC2B8: 0x7E61,
	0xF072: 0x7E62,
	0xF070: 0x7E63,
	0xFFFD: 0x7E64,
	0x9FA3: 0x7E65,
	0x8A50: 0x7E66,
	0x94C4: 0x7E67,
	0xF2B8: 0x7E68,
	0xC3B7: 0x7E69,
	0xC3B8: 0x7E6A,
	0xC3B4: 0x7E6B,
	0x9FA4: 0x7E6C,
	0xC3B5: 0x7E6D,
	0x8CE8: 0x7E6E,
	0xF2B4: 0x7E6F,
	0xF2B2: 0x7E70,
	0xFFFD: 0x7E71,
	0xF2B6: 0x7E72,
	0xC3BA: 0x7E73,
	0xF2B7: 0x7E74,
	0xF2B0: 0x7E75,
	0xF2AF: 0x7E76,
	0xF2B3: 0x7E77,
	0xF2B1: 0x7E78,
	0xC3B6: 0x7E79,
	0xF2B5: 0x7E7A,
	0xF4AC: 0x7E7B,
	0xC47E: 0x7E7C,
	0xC47D: 0x7E7D,
	0xF4AD: 0x7E7E,
	0xFAEC: 0x7E7F,
	0xF4AF: 0x7E80,
	0xF4AE: 0x7E81,
	0xC4A1: 0x7E82,
	0x94C5: 0x7E83,
	0xFFFD: 0x7E84,
	0xFFFD: 0x7E85,
	0xF5EB: 0x7E86,
	0xF5E8: 0x7E87,
	0xF5E9: 0x7E88,
	0xFAED: 0x7E89,
	0xF5E7: 0x7E8A,
	0xF5EA: 0x7E8B,
	0xC4F2: 0x7E8C,
	0xF5EC: 0x7E8D,
	0xFAEE: 0x7E8E,
	0xC4F1: 0x7E8F,
	0x94C6: 0x7E90,
	0xF742: 0x7E91,
	0xFAEF: 0x7E92,
	0xC5D5: 0x7E93,
	0xC5D7: 0x7E94,
	0xF7EE: 0x7E95,
	0xC5D6: 0x7E96,
	0xF8B9: 0x7E97,
	0xF940: 0x7E98,
	0xF942: 0x7E99,
	0xF8FE: 0x7E9A,
	0xF941: 0x7E9B,
	0xC66C: 0x7E9C,
	0xFFFD: 0x7E9D,
	0xFFFD: 0x7E9E,
	0x9CEB: 0x7E9F,
	0x835F: 0x7EA0,
	0x8376: 0x7EA1,
	0x8371: 0x7EA2,
	0x8370: 0x7EA3,
	0x8A4E: 0x7EA4,
	0x8374: 0x7EA5,
	0x8375: 0x7EA6,
	0x83CB: 0x7EA7,
	0x8DBE: 0x7EA8,
	0x9044: 0x7EA9,
	0x8372: 0x7EAA,
	0x8373: 0x7EAB,
	0x87FE: 0x7EAC,
	0x83CC: 0x7EAD,
	0xFFFD: 0x7EAE,
	0x83C8: 0x7EAF,
	0x83CA: 0x7EB0,
	0x83C6: 0x7EB1,
	0x86FC: 0x7EB2,
	0x83CD: 0x7EB3,
	0xFFFD: 0x7EB4,
	0x8A4C: 0x7EB5,
	0x8741: 0x7EB6,
	0x83CF: 0x7EB7,
	0x83CE: 0x7EB8,
	0x83C7: 0x7EB9,
	0x83C5: 0x7EBA,
	0xFFFD: 0x7EBB,
	0xFFFD: 0x7EBC,
	0x83C9: 0x7EBD,
	0x8DC5: 0x7EBE,
	0x8845: 0x7EBF,
	0x8DD3: 0x7EC0,
	0x8471: 0x7EC1,
	0x8472: 0x7EC2,
	0x87FD: 0x7EC3,
	0x846F: 0x7EC4,
	0x846E: 0x7EC5,
	0x846D: 0x7EC6,
	0x8AEB: 0x7EC7,
	0x8470: 0x7EC8,
	0x8953: 0x7EC9,
	0x8468: 0x7ECA,
	0x846B: 0x7ECB,
	0x846C: 0x7ECC,
	0x846A: 0x7ECD,
	0x8BB1: 0x7ECE,
	0x85EE: 0x7ECF,
	0x8DD4: 0x7ED0,
	0x85F0: 0x7ED1,
	0x8544: 0x7ED2,
	0x8543: 0x7ED3,
	0xFAF0: 0x7ED4,
	0x8AED: 0x7ED5,
	0x854A: 0x7ED6,
	0x8DE4: 0x7ED7,
	0x8BB3: 0x7ED8,
	0x8548: 0x7ED9,
	0x8549: 0x7EDA,
	0x854B: 0x7EDB,
	0x8547: 0x7EDC,
	0x8545: 0x7EDD,
	0x8542: 0x7EDE,
	0x8469: 0x7EDF,
	0x8E4A: 0x7EE0,
	0x8E4B: 0x7EE1,
	0x85EF: 0x7EE2,
	0x8AEF: 0x7EE3,
	0xFFFD: 0x7EE4,
	0x85F1: 0x7EE5,
	0x85F2: 0x7EE6,
	0x8C49: 0x7EE7,
	0x8E49: 0x7EE8,
	0x8A45: 0x7EE9,
	0x8743: 0x7EEA,
	0x86F8: 0x7EEB,
	0xFFFD: 0x7EEC,
	0x8CA2: 0x7EED,
	0x86FD: 0x7EEE,
	0x8E7B: 0x7EEF,
	0x86F7: 0x7EF0,
	0xFAF1: 0x7EF1,
	0x8E7A: 0x7EF2,
	0x8BB2: 0x7EF3,
	0x8742: 0x7EF4,
	0x8740: 0x7EF5,
	0x8745: 0x7EF6,
	0x8A49: 0x7EF7,
	0x86FE: 0x7EF8,
	0xFFFD: 0x7EF9,
	0x8E7C: 0x7EFA,
	0x8E79: 0x7EFB,
	0x86F6: 0x7EFC,
	0x86F4: 0x7EFD,
	0x86F5: 0x7EFE,
	0x86F9: 0x7EFF,
	0x86FB: 0x7F00,
	0x8744: 0x7F01,
	0x8849: 0x7F02,
	0x8EC2: 0x7F03,
	0x8840: 0x7F04,
	0x8841: 0x7F05,
	0x8DA3: 0x7F06,
	0x884B: 0x7F07,
	0x884A: 0x7F08,
	0x8842: 0x7F09,
	0xFFFD: 0x7F0A,
	0x8F79: 0x7F0B,
	0x8EC4: 0x7F0C,
	0x8848: 0x7F0D,
	0x8846: 0x7F0E,
	0x8EC5: 0x7F0F,
	0xFFFD: 0x7F10,
	0x8EC6: 0x7F11,
	0xFAF2: 0x7F12,
	0x8847: 0x7F13,
	0x87FC: 0x7F14,
	0x8A47: 0x7F15,
	0x8843: 0x7F16,
	0x8EC3: 0x7F17,
	0x8844: 0x7F18,
	0x8952: 0x7F19,
	0x894E: 0x7F1A,
	0x8EF0: 0x7F1B,
	0x8951: 0x7F1C,
	0x8A4A: 0x7F1D,
	0xFFFD: 0x7F1E,
	0x8950: 0x7F1F,
	0x8CA1: 0x7F20,
	0x8F5D: 0x7F21,
	0x894B: 0x7F22,
	0x894C: 0x7F23,
	0x8C48: 0x7F24,
	0x8A4F: 0x7F25,
	0x8A51: 0x7F26,
	0x8A48: 0x7F27,
	0x8CFB: 0x7F28,
	0x8A44: 0x7F29,
	0x8A46: 0x7F2A,
	0x8A4D: 0x7F2B,
	0x9045: 0x7F2C,
	0x8AEE: 0x7F2D,
	0x8AEC: 0x7F2E,
	0x8AF0: 0x7F2F,
	0xFAF3: 0x7F30,
	0x8FDE: 0x7F31,
	0x8FBF: 0x7F32,
	0x8FC0: 0x7F33,
	0x8BB5: 0x7F34,
	0x907C: 0x7F35,
	0xA6CE: 0x7F36,
	0x9FA5: 0x7F37,
	0xACFB: 0x7F38,
	0xD26F: 0x7F39,
	0xAFCA: 0x7F3A,
	0xFFFD: 0x7F3B,
	0xFFFD: 0x7F3C,
	0xB2DA: 0x7F3D,
	0xDAFC: 0x7F3E,
	0xDAFD: 0x7F3F,
	0x9FA6: 0x7F40,
	0x9FA7: 0x7F41,
	0x8C4A: 0x7F42,
	0xEADF: 0x7F43,
	0xC16A: 0x7F44,
	0xEDE1: 0x7F45,
	0xFFFD: 0x7F46,
	0x9574: 0x7F47,
	0xC2BB: 0x7F48,
	0x9FA8: 0x7F49,
	0xF2BA: 0x7F4A,
	0xF2B9: 0x7F4B,
	0xC4A2: 0x7F4C,
	0xF5ED: 0x7F4D,
	0xFBAA: 0x7F4E,
	0xF743: 0x7F4F,
	0xC5F8: 0x7F50,
	0xCA49: 0x7F51,
	0x9FA9: 0x7F52,
	0x9D75: 0x7F53,
	0xAAC9: 0x7F54,
	0xA875: 0x7F55,
	0xFFFD: 0x7F56,
	0x8BB4: 0x7F57,
	0xD04D: 0x7F58,
	0xFFFD: 0x7F59,
	0x8746: 0x7F5A,
	0xD360: 0x7F5B,
	0xD35B: 0x7F5C,
	0xD35F: 0x7F5D,
	0xD35D: 0x7F5E,
	0xAFCB: 0x7F5F,
	0xD35E: 0x7F60,
	0xD35C: 0x7F61,
	0x884D: 0x7F62,
	0xD6F1: 0x7F63,
	0xFFFD: 0x7F64,
	0xDAFE: 0x7F65,
	0xDB40: 0x7F66,
	0xDF69: 0x7F67,
	0xDF6A: 0x7F68,
	0xB86E: 0x7F69,
	0xB86F: 0x7F6A,
	0xDF68: 0x7F6B,
	0xDF6B: 0x7F6C,
	0xDF67: 0x7F6D,
	0xB86D: 0x7F6E,
	0xFFFD: 0x7F6F,
	0xBB40: 0x7F70,
	0xFAF4: 0x7F71,
	0xB870: 0x7F72,
	0xE37A: 0x7F73,
	0x8FC1: 0x7F74,
	0xBD7C: 0x7F75,
	0xE6F1: 0x7F76,
	0xBD7D: 0x7F77,
	0x9564: 0x7F78,
	0xBFA9: 0x7F79,
	0xEAE2: 0x7F7A,
	0xEAE0: 0x7F7B,
	0xEAE1: 0x7F7C,
	0xEDE4: 0x7F7D,
	0xEDE3: 0x7F7E,
	0xEDE2: 0x7F7F,
	0xFFFD: 0x7F80,
	0x8D56: 0x7F81,
	0xFAF5: 0x7F82,
	0xF2BB: 0x7F83,
	0xFFFD: 0x7F84,
	0xC3B9: 0x7F85,
	0xF2BC: 0x7F86,
	0xF744: 0x7F87,
	0xC5F9: 0x7F88,
	0xF8BA: 0x7F89,
	0xA6CF: 0x7F8A,
	0xAACB: 0x7F8B,
	0xAACA: 0x7F8C,
	0xD04F: 0x7F8D,
	0xACFC: 0x7F8E,
	0x9FAA: 0x7F8F,
	0xFFFD: 0x7F90,
	0xD04E: 0x7F91,
	0xD362: 0x7F92,
	0x9FAB: 0x7F93,
	0xAFCC: 0x7F94,
	0xD6F2: 0x7F95,
	0xD361: 0x7F96,
	0x95E0: 0x7F97,
	0xFFFD: 0x7F98,
	0xFFFD: 0x7F99,
	0xB2DC: 0x7F9A,
	0xD6F5: 0x7F9B,
	0xD6F3: 0x7F9C,
	0xD6F4: 0x7F9D,
	0xB2DB: 0x7F9E,
	0x8E4C: 0x7F9F,
	0xDB42: 0x7FA0,
	0xDB43: 0x7FA1,
	0xDB41: 0x7FA2,
	0x9555: 0x7FA3,
	0xB873: 0x7FA4,
	0xDF6D: 0x7FA5,
	0xDF6C: 0x7FA6,
	0xDF6E: 0x7FA7,
	0xB872: 0x7FA8,
	0xB871: 0x7FA9,
	0xFFFD: 0x7FAA,
	0xFFFD: 0x7FAB,
	0xE6F2: 0x7FAC,
	0xE6F4: 0x7FAD,
	0xFAF6: 0x7FAE,
	0xBD7E: 0x7FAF,
	0xE6F3: 0x7FB0,
	0xEAE3: 0x7FB1,
	0xBFAA: 0x7FB2,
	0xF079: 0x7FB3,
	0x9FAC: 0x7FB4,
	0xF078: 0x7FB5,
	0xC3BB: 0x7FB6,
	0xF2BD: 0x7FB7,
	0xC3BD: 0x7FB8,
	0xC3BC: 0x7FB9,
	0xF4B0: 0x7FBA,
	0xF5EE: 0x7FBB,
	0xC4F3: 0x7FBC,
	0xA6D0: 0x7FBD,
	0xD050: 0x7FBE,
	0xACFD: 0x7FBF,
	0xD365: 0x7FC0,
	0xAFCE: 0x7FC1,
	0xD364: 0x7FC2,
	0xD363: 0x7FC3,
	0xFFFD: 0x7FC4,
	0xAFCD: 0x7FC5,
	0xFAF7: 0x7FC6,
	0xD6FB: 0x7FC7,
	0xFFFD: 0x7FC8,
	0xD6FD: 0x7FC9,
	0xD6F6: 0x7FCA,
	0xD6F7: 0x7FCB,
	0xB2DD: 0x7FCC,
	0xD6F8: 0x7FCD,
	0xB2DE: 0x7FCE,
	0xD6FC: 0x7FCF,
	0xD6F9: 0x7FD0,
	0xD6FA: 0x7FD1,
	0xB2DF: 0x7FD2,
	0xFFFD: 0x7FD3,
	0xB5BE: 0x7FD4,
	0xB5BF: 0x7FD5,
	0xFFFD: 0x7FD6,
	0xDB44: 0x7FD7,
	0x8AF1: 0x7FD8,
	0xFFFD: 0x7FD9,
	0xFFFD: 0x7FDA,
	0xDF6F: 0x7FDB,
	0xDF70: 0x7FDC,
	0x9FAD: 0x7FDD,
	0xE37E: 0x7FDE,
	0xBB43: 0x7FDF,
	0xBB41: 0x7FE0,
	0xBB42: 0x7FE1,
	0xE37B: 0x7FE2,
	0xE37C: 0x7FE3,
	0xFFFD: 0x7FE4,
	0xE37D: 0x7FE5,
	0xE6F9: 0x7FE6,
	0x9FAE: 0x7FE7,
	0xE6FA: 0x7FE8,
	0xBDA1: 0x7FE9,
	0xE6F7: 0x7FEA,
	0xE6F6: 0x7FEB,
	0xE6F8: 0x7FEC,
	0xE6F5: 0x7FED,
	0xBFAD: 0x7FEE,
	0xEAE4: 0x7FEF,
	0xBFAB: 0x7FF0,
	0xBFAC: 0x7FF1,
	0xEDE6: 0x7FF2,
	0xC16B: 0x7FF3,
	0xEDE5: 0x7FF4,
	0xEFA8: 0x7FF5,
	0xFFFD: 0x7FF6,
	0xF07A: 0x7FF7,
	0xF07B: 0x7FF8,
	0xC2BC: 0x7FF9,
	0x9FAF: 0x7FFA,
	0xC2BD: 0x7FFB,
	0xC16C: 0x7FFC,
	0xF2BE: 0x7FFD,
	0xF2BF: 0x7FFE,
	0xF4B1: 0x7FFF,
	0xC4A3: 0x8000,
	0xA6D1: 0x8001,
	0x9FB0: 0x8002,
	0xA6D2: 0x8003,
	0xACFE: 0x8004,
	0xAACC: 0x8005,
	0xAFCF: 0x8006,
	0xD051: 0x8007,
	0x9FB1: 0x8008,
	0xFFFD: 0x8009,
	0xFFFD: 0x800A,
	0xB5C0: 0x800B,
	0xA6D3: 0x800C,
	0xAD41: 0x800D,
	0xD052: 0x800E,
	0xD053: 0x800F,
	0xAD40: 0x8010,
	0xAD42: 0x8011,
	0xA6D4: 0x8012,
	0xFFFD: 0x8013,
	0xD054: 0x8014,
	0xAFD1: 0x8015,
	0xD366: 0x8016,
	0xAFD3: 0x8017,
	0xAFD0: 0x8018,
	0xAFD2: 0x8019,
	0xFFFD: 0x801A,
	0xD741: 0x801B,
	0xB2E0: 0x801C,
	0xFCF6: 0x801D,
	0xD740: 0x801E,
	0xD6FE: 0x801F,
	0xFAF8: 0x8020,
	0xDF71: 0x8021,
	0xFAF9: 0x8022,
	0xFFFD: 0x8023,
	0xE3A1: 0x8024,
	0xFAFA: 0x8025,
	0xBDA2: 0x8026,
	0x8F5E: 0x8027,
	0xBFAE: 0x8028,
	0xEAE6: 0x8029,
	0xEAE5: 0x802A,
	0xFFFD: 0x802B,
	0xEDE7: 0x802C,
	0xFFFD: 0x802D,
	0x9FB2: 0x802E,
	0x9FB3: 0x802F,
	0xF5EF: 0x8030,
	0xFAFB: 0x8031,
	0xFFFD: 0x8032,
	0xA6D5: 0x8033,
	0xCB73: 0x8034,
	0xCDAA: 0x8035,
	0xAD43: 0x8036,
	0xD055: 0x8037,
	0x8A55: 0x8038,
	0xD368: 0x8039,
	0xFFFD: 0x803A,
	0x955C: 0x803B,
	0x9FB4: 0x803C,
	0xAFD4: 0x803D,
	0xD367: 0x803E,
	0xAFD5: 0x803F,
	0xFFFD: 0x8040,
	0xFFFD: 0x8041,
	0x8AF3: 0x8042,
	0xD743: 0x8043,
	0xFFFD: 0x8044,
	0xFFFD: 0x8045,
	0xB2E2: 0x8046,
	0xD742: 0x8047,
	0xD744: 0x8048,
	0xFFFD: 0x8049,
	0xB2E1: 0x804A,
	0x8CD9: 0x804B,
	0x8AF2: 0x804C,
	0x8FDF: 0x804D,
	0xFFFD: 0x804E,
	0xDB46: 0x804F,
	0xDB47: 0x8050,
	0xDB45: 0x8051,
	0xB5C1: 0x8052,
	0xFFFD: 0x8053,
	0x8A54: 0x8054,
	0xFFFD: 0x8055,
	0xB874: 0x8056,
	0xFFFD: 0x8057,
	0xB875: 0x8058,
	0xFFFD: 0x8059,
	0xBB45: 0x805A,
	0xFCFA: 0x805B,
	0xE3A3: 0x805C,
	0xE3A2: 0x805D,
	0xBB44: 0x805E,
	0xFAFC: 0x805F,
	0xFFFD: 0x8060,
	0x826B: 0x8061,
	0xFCF7: 0x8062,
	0xFCF8: 0x8063,
	0xE6FB: 0x8064,
	0xFFFD: 0x8065,
	0xFCF9: 0x8066,
	0xE6FC: 0x8067,
	0xFAFD: 0x8068,
	0x8F7A: 0x8069,
	0x8A53: 0x806A,
	0xFFFD: 0x806B,
	0xEAE7: 0x806C,
	0xFFFD: 0x806D,
	0xFFFD: 0x806E,
	0xC170: 0x806F,
	0xC16F: 0x8070,
	0xC16D: 0x8071,
	0xC16E: 0x8072,
	0xC171: 0x8073,
	0x9377: 0x8074,
	0xF07C: 0x8075,
	0xC2BF: 0x8076,
	0xC2BE: 0x8077,
	0xF2C0: 0x8078,
	0xF4B2: 0x8079,
	0xFFFD: 0x807A,
	0xFFFD: 0x807B,
	0xFFFD: 0x807C,
	0xC5A5: 0x807D,
	0xC5A4: 0x807E,
	0xA6D6: 0x807F,
	0x91D5: 0x8080,
	0xFFFD: 0x8081,
	0xD1FB: 0x8082,
	0x854C: 0x8083,
	0xB877: 0x8084,
	0xB5C2: 0x8085,
	0xB876: 0x8086,
	0xBB46: 0x8087,
	0xFFFD: 0x8088,
	0xA6D7: 0x8089,
	0xC9A9: 0x808A,
	0xA6D8: 0x808B,
	0xA6D9: 0x808C,
	0xFFFD: 0x808D,
	0xFFFD: 0x808E,
	0xCDAB: 0x808F,
	0xCB76: 0x8090,
	0xFFFD: 0x8091,
	0xCB77: 0x8092,
	0xA877: 0x8093,
	0xFFFD: 0x8094,
	0xCB74: 0x8095,
	0xA876: 0x8096,
	0xFFFD: 0x8097,
	0xA879: 0x8098,
	0xCB75: 0x8099,
	0xA87B: 0x809A,
	0xA87A: 0x809B,
	0xCB78: 0x809C,
	0xA878: 0x809D,
	0xFFFD: 0x809E,
	0x96AF: 0x809F,
	0x85F6: 0x80A0,
	0xAAD1: 0x80A1,
	0xAACF: 0x80A2,
	0xCDAD: 0x80A3,
	0x884F: 0x80A4,
	0xAACE: 0x80A5,
	0xFCFB: 0x80A6,
	0x9FB5: 0x80A7,
	0xFFFD: 0x80A8,
	0xAAD3: 0x80A9,
	0xAAD5: 0x80AA,
	0xAAD2: 0x80AB,
	0xFAFE: 0x80AC,
	0xCDB0: 0x80AD,
	0xCDAC: 0x80AE,
	0xAAD6: 0x80AF,
	0xFFFD: 0x80B0,
	0xAAD0: 0x80B1,
	0xA87C: 0x80B2,
	0xFFFD: 0x80B3,
	0xAAD4: 0x80B4,
	0xCDAF: 0x80B5,
	0xFB4D: 0x80B6,
	0xFB40: 0x80B7,
	0xCDAE: 0x80B8,
	0xFFFD: 0x80B9,
	0xAACD: 0x80BA,
	0xFFFD: 0x80BB,
	0x96CB: 0x80BC,
	0x96A6: 0x80BD,
	0x854D: 0x80BE,
	0x85F8: 0x80BF,
	0x854E: 0x80C0,
	0x83D0: 0x80C1,
	0xD05B: 0x80C2,
	0xAD47: 0x80C3,
	0xAD48: 0x80C4,
	0xD05D: 0x80C5,
	0x8A57: 0x80C6,
	0xD057: 0x80C7,
	0xD05A: 0x80C8,
	0xD063: 0x80C9,
	0xD061: 0x80CA,
	0xFFFD: 0x80CB,
	0xAD49: 0x80CC,
	0xD067: 0x80CD,
	0xAD4C: 0x80CE,
	0xD064: 0x80CF,
	0xD05C: 0x80D0,
	0xD059: 0x80D1,
	0xFFFD: 0x80D2,
	0xFFFD: 0x80D3,
	0xDB49: 0x80D4,
	0xD062: 0x80D5,
	0xAD44: 0x80D6,
	0xD065: 0x80D7,
	0xD056: 0x80D8,
	0xD05F: 0x80D9,
	0xAD46: 0x80DA,
	0xAD4B: 0x80DB,
	0xD060: 0x80DC,
	0xAD4F: 0x80DD,
	0xAD4D: 0x80DE,
	0xFFFD: 0x80DF,
	0xD058: 0x80E0,
	0xAD4A: 0x80E1,
	0xFFFD: 0x80E2,
	0xD05E: 0x80E3,
	0xAD4E: 0x80E4,
	0xAD45: 0x80E5,
	0xD066: 0x80E6,
	0x8BF8: 0x80E7,
	0xFDFB: 0x80E8,
	0xFDFC: 0x80E9,
	0x8C4B: 0x80EA,
	0x8DD5: 0x80EB,
	0xFDFD: 0x80EC,
	0xAFDA: 0x80ED,
	0xFFFD: 0x80EE,
	0xAFE3: 0x80EF,
	0xAFD8: 0x80F0,
	0xAFD6: 0x80F1,
	0xD36A: 0x80F2,
	0xAFDE: 0x80F3,
	0xAFDB: 0x80F4,
	0xD36C: 0x80F5,
	0x884E: 0x80F6,
	0xFFFD: 0x80F7,
	0xAFDD: 0x80F8,
	0xD36B: 0x80F9,
	0xD369: 0x80FA,
	0xD36E: 0x80FB,
	0xAFE2: 0x80FC,
	0xAFE0: 0x80FD,
	0xDB48: 0x80FE,
	0xFFFD: 0x80FF,
	0xD36F: 0x8100,
	0xD36D: 0x8101,
	0xAFD7: 0x8102,
	0xFCFC: 0x8103,
	0xFFFD: 0x8104,
	0xAFD9: 0x8105,
	0xAFDC: 0x8106,
	0xFE48: 0x8107,
	0xAFDF: 0x8108,
	0x83D1: 0x8109,
	0xAFE1: 0x810A,
	0xFFFD: 0x810B,
	0x9FB6: 0x810C,
	0x8A59: 0x810D,
	0xFDFE: 0x810E,
	0x8CDA: 0x810F,
	0x8AF4: 0x8110,
	0x85F9: 0x8111,
	0xFEEE: 0x8112,
	0x8A56: 0x8113,
	0x907D: 0x8114,
	0xD74E: 0x8115,
	0xB2E4: 0x8116,
	0x95A8: 0x8117,
	0xD745: 0x8118,
	0xD747: 0x8119,
	0x85F7: 0x811A,
	0xD748: 0x811B,
	0xFFFD: 0x811C,
	0xD750: 0x811D,
	0xD74C: 0x811E,
	0xD74A: 0x811F,
	0xFFFD: 0x8120,
	0xD74D: 0x8121,
	0xD751: 0x8122,
	0xB2E5: 0x8123,
	0xB2E9: 0x8124,
	0xD746: 0x8125,
	0xFFFD: 0x8126,
	0xD74F: 0x8127,
	0xFFFD: 0x8128,
	0xB2E7: 0x8129,
	0x9FB7: 0x812A,
	0xB2E6: 0x812B,
	0xD74B: 0x812C,
	0xD749: 0x812D,
	0xFFFD: 0x812E,
	0xB2E3: 0x812F,
	0xB2E8: 0x8130,
	0xFEEF: 0x8131,
	0x96A5: 0x8132,
	0x93B0: 0x8133,
	0x9FB8: 0x8134,
	0xFFFD: 0x8135,
	0xFEF0: 0x8136,
	0xA042: 0x8137,
	0x8A58: 0x8138,
	0xB5C8: 0x8139,
	0xDB51: 0x813A,
	0xFFFD: 0x813B,
	0xFFFD: 0x813C,
	0xDB4F: 0x813D,
	0xB5CA: 0x813E,
	0xFFFD: 0x813F,
	0xFFFD: 0x8140,
	0xFFFD: 0x8141,
	0x9FB9: 0x8142,
	0xDB4A: 0x8143,
	0xDFA1: 0x8144,
	0xFFFD: 0x8145,
	0xB5C9: 0x8146,
	0xDB4E: 0x8147,
	0x96AB: 0x8148,
	0xFFFD: 0x8149,
	0xDB4B: 0x814A,
	0xB5C5: 0x814B,
	0xB5CB: 0x814C,
	0xDB50: 0x814D,
	0xB5C7: 0x814E,
	0xDB4D: 0x814F,
	0xBB47: 0x8150,
	0xB5C6: 0x8151,
	0xDB4C: 0x8152,
	0xB5CC: 0x8153,
	0xB5C4: 0x8154,
	0xB5C3: 0x8155,
	0x9FBA: 0x8156,
	0xFFFD: 0x8157,
	0xFFFD: 0x8158,
	0x96AE: 0x8159,
	0x96A2: 0x815A,
	0xDF77: 0x815B,
	0xDF75: 0x815C,
	0xFFFD: 0x815D,
	0xDF7B: 0x815E,
	0xFEF1: 0x815F,
	0xDF73: 0x8160,
	0xDFA2: 0x8161,
	0xDF78: 0x8162,
	0xFFFD: 0x8163,
	0xDF72: 0x8164,
	0xB87B: 0x8165,
	0xB8A3: 0x8166,
	0xDF7D: 0x8167,
	0xFFFD: 0x8168,
	0xDF76: 0x8169,
	0xFFFD: 0x816A,
	0xB87E: 0x816B,
	0x9DD0: 0x816C,
	0xFEF2: 0x816D,
	0xB87C: 0x816E,
	0xDF7E: 0x816F,
	0xB879: 0x8170,
	0xB878: 0x8171,
	0xDF79: 0x8172,
	0xB87D: 0x8173,
	0xB5CD: 0x8174,
	0xFFFD: 0x8175,
	0xDF7C: 0x8176,
	0xDF74: 0x8177,
	0xB87A: 0x8178,
	0xB8A1: 0x8179,
	0xB8A2: 0x817A,
	0x8954: 0x817B,
	0x89AE: 0x817C,
	0xFEF3: 0x817D,
	0x8C65: 0x817E,
	0xBB4C: 0x817F,
	0xBB48: 0x8180,
	0xFFFD: 0x8181,
	0xBB4D: 0x8182,
	0xE3A6: 0x8183,
	0x9FBB: 0x8184,
	0xFFFD: 0x8185,
	0xE3A5: 0x8186,
	0xE3A7: 0x8187,
	0xBB4A: 0x8188,
	0xE3A4: 0x8189,
	0xBB4B: 0x818A,
	0xE3AA: 0x818B,
	0xE3A9: 0x818C,
	0xE3A8: 0x818D,
	0xFFFD: 0x818E,
	0xBB49: 0x818F,
	0xFFFD: 0x8190,
	0x8AF5: 0x8191,
	0xFFFD: 0x8192,
	0xFEF4: 0x8193,
	0xFFFD: 0x8194,
	0xE741: 0x8195,
	0xFFFD: 0x8196,
	0xE744: 0x8197,
	0xBDA8: 0x8198,
	0xE743: 0x8199,
	0xBDA7: 0x819A,
	0xBDA3: 0x819B,
	0xBDA4: 0x819C,
	0xBDA5: 0x819D,
	0xE740: 0x819E,
	0xE6FE: 0x819F,
	0xBDA6: 0x81A0,
	0xFFFD: 0x81A1,
	0xE742: 0x81A2,
	0xE6FD: 0x81A3,
	0x94C7: 0x81A4,
	0x9FBC: 0x81A5,
	0xEAE9: 0x81A6,
	0xEAF3: 0x81A7,
	0xBFB1: 0x81A8,
	0xBFB0: 0x81A9,
	0xFEF5: 0x81AA,
	0xEAED: 0x81AB,
	0xEAEF: 0x81AC,
	0xFFFD: 0x81AD,
	0xEAEA: 0x81AE,
	0xFFFD: 0x81AF,
	0xEAEE: 0x81B0,
	0xEAE8: 0x81B1,
	0xEAF1: 0x81B2,
	0xBFAF: 0x81B3,
	0xEAF0: 0x81B4,
	0xEAEC: 0x81B5,
	0xFB6E: 0x81B6,
	0xEAF2: 0x81B7,
	0xFEF6: 0x81B8,
	0xEAEB: 0x81B9,
	0xC174: 0x81BA,
	0xEDE8: 0x81BB,
	0xEDEE: 0x81BC,
	0xC178: 0x81BD,
	0xC17A: 0x81BE,
	0xC177: 0x81BF,
	0xC176: 0x81C0,
	0xFEF7: 0x81C1,
	0xC175: 0x81C2,
	0xC173: 0x81C3,
	0xEDE9: 0x81C4,
	0xEDEC: 0x81C5,
	0xC172: 0x81C6,
	0xEDED: 0x81C7,
	0xFCFE: 0x81C8,
	0xC179: 0x81C9,
	0xEDEB: 0x81CA,
	0xFFFD: 0x81CB,
	0xEDEA: 0x81CC,
	0xC2C0: 0x81CD,
	0xFFFD: 0x81CE,
	0xC2C1: 0x81CF,
	0xF0A1: 0x81D0,
	0xF07D: 0x81D1,
	0xF07E: 0x81D2,
	0x9362: 0x81D3,
	0xFFFD: 0x81D4,
	0xF2C2: 0x81D5,
	0xFFFD: 0x81D6,
	0xF2C1: 0x81D7,
	0xC3BE: 0x81D8,
	0xF4B4: 0x81D9,
	0xC4A4: 0x81DA,
	0xF4B3: 0x81DB,
	0xFFFD: 0x81DC,
	0xF5F0: 0x81DD,
	0xF745: 0x81DE,
	0xC5A6: 0x81DF,
	0xF943: 0x81E0,
	0xF944: 0x81E1,
	0xC5D8: 0x81E2,
	0xA6DA: 0x81E3,
	0x9FBD: 0x81E4,
	0xAAD7: 0x81E5,
	0xDB52: 0x81E6,
	0xBB4E: 0x81E7,
	0xC17B: 0x81E8,
	0xEDEF: 0x81E9,
	0xA6DB: 0x81EA,
	0xFFFD: 0x81EB,
	0xAFE5: 0x81EC,
	0xAFE4: 0x81ED,
	0xDB53: 0x81EE,
	0x95D3: 0x81EF,
	0xFFFD: 0x81F0,
	0xFFFD: 0x81F1,
	0xEAF4: 0x81F2,
	0xA6DC: 0x81F3,
	0xAD50: 0x81F4,
	0xFFFD: 0x81F5,
	0xFD42: 0x81F6,
	0xDB54: 0x81F7,
	0xDB55: 0x81F8,
	0xDB56: 0x81F9,
	0xBB4F: 0x81FA,
	0xBFB2: 0x81FB,
	0xA6DD: 0x81FC,
	0xFFFD: 0x81FD,
	0xAAD8: 0x81FE,
	0xD068: 0x81FF,
	0xAFE6: 0x8200,
	0xD370: 0x8201,
	0xB2EA: 0x8202,
	0xFFFD: 0x8203,
	0xDB57: 0x8204,
	0xB8A4: 0x8205,
	0x8A77: 0x8206,
	0xBB50: 0x8207,
	0xBFB3: 0x8208,
	0xC17C: 0x8209,
	0xC2C2: 0x820A,
	0xF4B5: 0x820B,
	0xA6DE: 0x820C,
	0xAAD9: 0x820D,
	0x92D6: 0x820E,
	0xFFFD: 0x820F,
	0xAFE7: 0x8210,
	0xD752: 0x8211,
	0xB5CE: 0x8212,
	0xFFFD: 0x8213,
	0xBB51: 0x8214,
	0xE3AB: 0x8215,
	0xE745: 0x8216,
	0x93C6: 0x8217,
	0x95EC: 0x8218,
	0xFFFD: 0x8219,
	0xFD43: 0x821A,
	0xA6DF: 0x821B,
	0xB5CF: 0x821C,
	0xDFA3: 0x821D,
	0xBB52: 0x821E,
	0xA6E0: 0x821F,
	0xCDB1: 0x8220,
	0xD069: 0x8221,
	0xAD51: 0x8222,
	0x8FC2: 0x8223,
	0xFFFD: 0x8224,
	0xD372: 0x8225,
	0xFB53: 0x8226,
	0xFFFD: 0x8227,
	0xAFEA: 0x8228,
	0xFEF8: 0x8229,
	0xAFE8: 0x822A,
	0xAFE9: 0x822B,
	0xAFEB: 0x822C,
	0xFEF9: 0x822D,
	0xFEFA: 0x822E,
	0xD371: 0x822F,
	0x8C4C: 0x8230,
	0x8956: 0x8231,
	0xD757: 0x8232,
	0xD754: 0x8233,
	0xD756: 0x8234,
	0xB2EB: 0x8235,
	0xB2ED: 0x8236,
	0xB2EC: 0x8237,
	0xD753: 0x8238,
	0xB2EE: 0x8239,
	0xD755: 0x823A,
	0x905B: 0x823B,
	0xDB58: 0x823C,
	0xDB59: 0x823D,
	0xFEFB: 0x823E,
	0xDB5A: 0x823F,
	0xDFA6: 0x8240,
	0xFFFD: 0x8241,
	0xDFA7: 0x8242,
	0xFFFD: 0x8243,
	0xDFA5: 0x8244,
	0xDFA8: 0x8245,
	0xFFFD: 0x8246,
	0xB8A5: 0x8247,
	0xFFFD: 0x8248,
	0xDFA4: 0x8249,
	0xFFFD: 0x824A,
	0xBB53: 0x824B,
	0xFFFD: 0x824C,
	0xFFFD: 0x824D,
	0xE74A: 0x824E,
	0xE746: 0x824F,
	0xE749: 0x8250,
	0xE74B: 0x8251,
	0xE748: 0x8252,
	0xE747: 0x8253,
	0x9FBE: 0x8254,
	0xEAF5: 0x8255,
	0xEAF6: 0x8256,
	0xEAF7: 0x8257,
	0xBFB4: 0x8258,
	0xBFB5: 0x8259,
	0xEDF1: 0x825A,
	0xEDF0: 0x825B,
	0xEDF2: 0x825C,
	0x94C8: 0x825D,
	0xF0A3: 0x825E,
	0xF0A2: 0x825F,
	0xFFFD: 0x8260,
	0xF2C4: 0x8261,
	0xFEFC: 0x8262,
	0xF2C5: 0x8263,
	0xF2C3: 0x8264,
	0x9FBF: 0x8265,
	0xC4A5: 0x8266,
	0xFFFD: 0x8267,
	0xF4B6: 0x8268,
	0xF4B7: 0x8269,
	0xFEFD: 0x826A,
	0xF746: 0x826B,
	0xF7EF: 0x826C,
	0xF8BB: 0x826D,
	0xA6E1: 0x826E,
	0xA87D: 0x826F,
	0x8A5C: 0x8270,
	0xC17D: 0x8271,
	0xA6E2: 0x8272,
	0x8D5B: 0x8273,
	0xD758: 0x8274,
	0xDB5B: 0x8275,
	0x8245: 0x8276,
	0xC641: 0x8277,
	0xCA4A: 0x8278,
	0x9CD2: 0x8279,
	0x8BB7: 0x827A,
	0x9FC0: 0x827B,
	0xCA4B: 0x827C,
	0xCA4D: 0x827D,
	0xA6E3: 0x827E,
	0xCA4E: 0x827F,
	0xCA4C: 0x8280,
	0xFFFD: 0x8281,
	0x85EB: 0x8282,
	0xCBA2: 0x8283,
	0xCBA3: 0x8284,
	0xCB7B: 0x8285,
	0xFFFD: 0x8286,
	0x9FC1: 0x8287,
	0xFEFE: 0x8288,
	0xFFFD: 0x8289,
	0xCBA1: 0x828A,
	0xA8A1: 0x828B,
	0xFFFD: 0x828C,
	0xA8A2: 0x828D,
	0xCB7C: 0x828E,
	0xCB7A: 0x828F,
	0xCB79: 0x8290,
	0xCB7D: 0x8291,
	0xA87E: 0x8292,
	0xCB7E: 0x8293,
	0xD06A: 0x8294,
	0xFFFD: 0x8295,
	0xFFFD: 0x8296,
	0x8EF6: 0x8297,
	0xCDB6: 0x8298,
	0xAADC: 0x8299,
	0xCDB5: 0x829A,
	0xCDB7: 0x829B,
	0x8959: 0x829C,
	0xAADB: 0x829D,
	0xCDBC: 0x829E,
	0xAADF: 0x829F,
	0xCDB2: 0x82A0,
	0xCDC0: 0x82A1,
	0xCDC6: 0x82A2,
	0xAAE6: 0x82A3,
	0xCDC3: 0x82A4,
	0xAAE3: 0x82A5,
	0x8C4F: 0x82A6,
	0xCDB9: 0x82A7,
	0xCDBF: 0x82A8,
	0xCDC1: 0x82A9,
	0xFBA5: 0x82AA,
	0xCDB4: 0x82AB,
	0xAAE2: 0x82AC,
	0xAADD: 0x82AD,
	0xCDBA: 0x82AE,
	0xAAE4: 0x82AF,
	0xAAE7: 0x82B0,
	0xAAE1: 0x82B1,
	0xFFFD: 0x82B2,
	0xAADA: 0x82B3,
	0xCDBE: 0x82B4,
	0xCDB8: 0x82B5,
	0xCDC5: 0x82B6,
	0xAAE9: 0x82B7,
	0xAAE5: 0x82B8,
	0xAAE0: 0x82B9,
	0xCDBD: 0x82BA,
	0xAFEC: 0x82BB,
	0xCDBB: 0x82BC,
	0xAADE: 0x82BD,
	0xAAE8: 0x82BE,
	0x9FC2: 0x82BF,
	0xCDB3: 0x82C0,
	0x8ECA: 0x82C1,
	0xCDC2: 0x82C2,
	0xCDC4: 0x82C3,
	0x96BE: 0x82C4,
	0x9140: 0x82C5,
	0xFFFD: 0x82C6,
	0x85FB: 0x82C7,
	0x8FE1: 0x82C8,
	0xFFFD: 0x82C9,
	0x9141: 0x82CA,
	0x8479: 0x82CB,
	0x8551: 0x82CC,
	0x874B: 0x82CD,
	0x8378: 0x82CE,
	0x84F7: 0x82CF,
	0xFD5F: 0x82D0,
	0xAD62: 0x82D1,
	0xAD5C: 0x82D2,
	0xAD64: 0x82D3,
	0xAD61: 0x82D4,
	0xD071: 0x82D5,
	0xD074: 0x82D6,
	0xAD5D: 0x82D7,
	0x9142: 0x82D8,
	0xD06B: 0x82D9,
	0xFFFD: 0x82DA,
	0xAD56: 0x82DB,
	0xAD60: 0x82DC,
	0xFFFD: 0x82DD,
	0xAD63: 0x82DE,
	0xAD65: 0x82DF,
	0xD0A2: 0x82E0,
	0xD077: 0x82E1,
	0x9FC3: 0x82E2,
	0xAD55: 0x82E3,
	0xD0A1: 0x82E4,
	0xAD59: 0x82E5,
	0xAD57: 0x82E6,
	0xAD52: 0x82E7,
	0xD06F: 0x82E8,
	0xFFFD: 0x82E9,
	0xD07E: 0x82EA,
	0xD073: 0x82EB,
	0xD076: 0x82EC,
	0xD0A5: 0x82ED,
	0x9FC4: 0x82EE,
	0xAD66: 0x82EF,
	0xD07D: 0x82F0,
	0xAD5E: 0x82F1,
	0xD078: 0x82F2,
	0xD0A4: 0x82F3,
	0xD075: 0x82F4,
	0xD079: 0x82F5,
	0xD07C: 0x82F6,
	0x96A3: 0x82F7,
	0x9FC5: 0x82F8,
	0xD06D: 0x82F9,
	0xD0A3: 0x82FA,
	0xD07B: 0x82FB,
	0x9FC6: 0x82FC,
	0xFD5D: 0x82FD,
	0xD06C: 0x82FE,
	0x9FC7: 0x82FF,
	0xD070: 0x8300,
	0xAD5F: 0x8301,
	0xAD5A: 0x8302,
	0xAD53: 0x8303,
	0xAD58: 0x8304,
	0xAD54: 0x8305,
	0xAD67: 0x8306,
	0xD06E: 0x8307,
	0xD3A5: 0x8308,
	0xAD5B: 0x8309,
	0xFFFD: 0x830A,
	0x9FC8: 0x830B,
	0xD07A: 0x830C,
	0xCE41: 0x830D,
	0x92A7: 0x830E,
	0x8FE0: 0x830F,
	0xFFFD: 0x8310,
	0x8EC9: 0x8311,
	0xFFFD: 0x8312,
	0xFFFD: 0x8313,
	0x85C3: 0x8314,
	0x8E46: 0x8315,
	0xD3A8: 0x8316,
	0xAFFA: 0x8317,
	0x9143: 0x8318,
	0xD376: 0x8319,
	0x9144: 0x831A,
	0xD3A3: 0x831B,
	0xD37D: 0x831C,
	0x9FC9: 0x831D,
	0xD3B2: 0x831E,
	0xFFFD: 0x831F,
	0xD3AA: 0x8320,
	0xFFFD: 0x8321,
	0xD37E: 0x8322,
	0x9145: 0x8323,
	0xD3A9: 0x8324,
	0xD378: 0x8325,
	0xD37C: 0x8326,
	0xD3B5: 0x8327,
	0xAFFD: 0x8328,
	0xD3AD: 0x8329,
	0xD3A4: 0x832A,
	0xAFED: 0x832B,
	0xD3B3: 0x832C,
	0xD374: 0x832D,
	0xFFFD: 0x832E,
	0xD3AC: 0x832F,
	0xFFFD: 0x8330,
	0xAFFC: 0x8331,
	0xAFF7: 0x8332,
	0xD373: 0x8333,
	0xAFF5: 0x8334,
	0xAFF4: 0x8335,
	0xAFF9: 0x8336,
	0xD3AB: 0x8337,
	0xAFF1: 0x8338,
	0xAFF8: 0x8339,
	0xD072: 0x833A,
	0xDB5C: 0x833B,
	0xD3A6: 0x833C,
	0x9FCA: 0x833D,
	0xFFFD: 0x833E,
	0xD37A: 0x833F,
	0xAFFB: 0x8340,
	0xD37B: 0x8341,
	0xD3A1: 0x8342,
	0xAFFE: 0x8343,
	0xD375: 0x8344,
	0xD3AF: 0x8345,
	0x9146: 0x8346,
	0xD3AE: 0x8347,
	0xD3B6: 0x8348,
	0xAFF3: 0x8349,
	0xAFF0: 0x834A,
	0xD3B4: 0x834B,
	0xD3B0: 0x834C,
	0xD3A7: 0x834D,
	0xD3A2: 0x834E,
	0xAFF6: 0x834F,
	0xAFF2: 0x8350,
	0xD377: 0x8351,
	0xAFEE: 0x8352,
	0xD3B1: 0x8353,
	0xAFEF: 0x8354,
	0xFFFD: 0x8355,
	0xD379: 0x8356,
	0x9FCB: 0x8357,
	0x9354: 0x8358,
	0xFFFD: 0x8359,
	0x8475: 0x835A,
	0x9147: 0x835B,
	0x8EC7: 0x835C,
	0xFFFD: 0x835D,
	0x8EF4: 0x835E,
	0x8F5F: 0x835F,
	0x8AF9: 0x8360,
	0x8957: 0x8361,
	0x9148: 0x8362,
	0x86D1: 0x8363,
	0x85FA: 0x8364,
	0x8E73: 0x8365,
	0x86E1: 0x8366,
	0x86DF: 0x8367,
	0x8EF2: 0x8368,
	0x8F7B: 0x8369,
	0x874A: 0x836A,
	0x8851: 0x836B,
	0x9149: 0x836C,
	0x8E4D: 0x836D,
	0x914A: 0x836E,
	0x8BB9: 0x836F,
	0xFFFD: 0x8370,
	0xFFFD: 0x8371,
	0xFFFD: 0x8372,
	0xD75E: 0x8373,
	0xD760: 0x8374,
	0xD765: 0x8375,
	0xD779: 0x8376,
	0xB2FC: 0x8377,
	0xB2F2: 0x8378,
	0xFFFD: 0x8379,
	0xD75D: 0x837A,
	0xB2FD: 0x837B,
	0xB2FE: 0x837C,
	0xD768: 0x837D,
	0xD76F: 0x837E,
	0xD775: 0x837F,
	0xFFFD: 0x8380,
	0xD762: 0x8381,
	0xFFFD: 0x8382,
	0xD769: 0x8383,
	0xFFFD: 0x8384,
	0x8748: 0x8385,
	0xB340: 0x8386,
	0xD777: 0x8387,
	0xD772: 0x8388,
	0xB2FA: 0x8389,
	0xB2F8: 0x838A,
	0xD76E: 0x838B,
	0xD76A: 0x838C,
	0xD75C: 0x838D,
	0xB2EF: 0x838E,
	0xD761: 0x838F,
	0xD759: 0x8390,
	0x9FCC: 0x8391,
	0xB2F7: 0x8392,
	0xB2F9: 0x8393,
	0xD766: 0x8394,
	0xD763: 0x8395,
	0xB2F4: 0x8396,
	0xD773: 0x8397,
	0xB2F1: 0x8398,
	0xD764: 0x8399,
	0xD77A: 0x839A,
	0xD76C: 0x839B,
	0x914B: 0x839C,
	0xD76B: 0x839D,
	0xB2F0: 0x839E,
	0x914C: 0x839F,
	0xB2FB: 0x83A0,
	0xFFFD: 0x83A1,
	0xB2F3: 0x83A2,
	0xD75A: 0x83A3,
	0xD75F: 0x83A4,
	0xD770: 0x83A5,
	0xD776: 0x83A6,
	0xB341: 0x83A7,
	0xD75B: 0x83A8,
	0xD767: 0x83A9,
	0xD76D: 0x83AA,
	0xB2F6: 0x83AB,
	0x9FCD: 0x83AC,
	0xFFFD: 0x83AD,
	0xD778: 0x83AE,
	0xD771: 0x83AF,
	0xD774: 0x83B0,
	0x8550: 0x83B1,
	0x8850: 0x83B2,
	0x8E7D: 0x83B3,
	0x85FD: 0x83B4,
	0x914D: 0x83B5,
	0x8F60: 0x83B6,
	0x89F7: 0x83B7,
	0x8EF5: 0x83B8,
	0x87F3: 0x83B9,
	0x8CC2: 0x83BA,
	0xFFFD: 0x83BB,
	0x914E: 0x83BC,
	0xB2F5: 0x83BD,
	0xFBAD: 0x83BE,
	0xDB6C: 0x83BF,
	0xDB60: 0x83C0,
	0xB5D7: 0x83C1,
	0xDB7D: 0x83C2,
	0xDBA7: 0x83C3,
	0xDBAA: 0x83C4,
	0xB5D5: 0x83C5,
	0xDB68: 0x83C6,
	0xDBA3: 0x83C7,
	0xDB69: 0x83C8,
	0xDB77: 0x83C9,
	0xB5E2: 0x83CA,
	0xDB73: 0x83CB,
	0xB5DF: 0x83CC,
	0x9FCE: 0x83CD,
	0xDB74: 0x83CE,
	0xDB5D: 0x83CF,
	0xFFFD: 0x83D0,
	0xDBA4: 0x83D1,
	0xFFFD: 0x83D2,
	0xFE52: 0x83D3,
	0xB5E8: 0x83D4,
	0xDBA1: 0x83D5,
	0xDB75: 0x83D6,
	0xDBAC: 0x83D7,
	0xDB70: 0x83D8,
	0xDFC8: 0x83D9,
	0xFFFD: 0x83DA,
	0xDBAF: 0x83DB,
	0xB5E6: 0x83DC,
	0xDB6E: 0x83DD,
	0xDB7A: 0x83DE,
	0xB5E9: 0x83DF,
	0xB5D4: 0x83E0,
	0xDB72: 0x83E1,
	0xDBAD: 0x83E2,
	0xDB6B: 0x83E3,
	0xDB64: 0x83E4,
	0xDB6F: 0x83E5,
	0xFFFD: 0x83E6,
	0xDB63: 0x83E7,
	0xDB61: 0x83E8,
	0xB5D0: 0x83E9,
	0xDBA5: 0x83EA,
	0xDB6A: 0x83EB,
	0xDBA8: 0x83EC,
	0x9FCF: 0x83ED,
	0xDBA9: 0x83EE,
	0xB5D8: 0x83EF,
	0xB5DD: 0x83F0,
	0xB5D9: 0x83F1,
	0xB5E1: 0x83F2,
	0xDB7E: 0x83F3,
	0xB5DA: 0x83F4,
	0xDB76: 0x83F5,
	0xDB66: 0x83F6,
	0x914F: 0x83F7,
	0xB5D2: 0x83F8,
	0xDB5E: 0x83F9,
	0xDBA2: 0x83FA,
	0xDBAB: 0x83FB,
	0xDB65: 0x83FC,
	0xB5E0: 0x83FD,
	0xDBB0: 0x83FE,
	0xDB71: 0x83FF,
	0xFFFD: 0x8400,
	0xDB6D: 0x8401,
	0xFFFD: 0x8402,
	0xB5D1: 0x8403,
	0xB5E5: 0x8404,
	0x9FD0: 0x8405,
	0xDB7C: 0x8406,
	0xB5E7: 0x8407,
	0xFFFD: 0x8408,
	0xDB78: 0x8409,
	0xB5DC: 0x840A,
	0xB5D6: 0x840B,
	0xB5DE: 0x840C,
	0xB5D3: 0x840D,
	0xB5E4: 0x840E,
	0xDB79: 0x840F,
	0xDB67: 0x8410,
	0xDB7B: 0x8411,
	0xDB62: 0x8412,
	0xDBA6: 0x8413,
	0x9FD1: 0x8414,
	0xFFFD: 0x8415,
	0x9FD2: 0x8416,
	0xFFFD: 0x8417,
	0x96A7: 0x8418,
	0xFFFD: 0x8419,
	0xFFFD: 0x841A,
	0xDBAE: 0x841B,
	0x96BD: 0x841C,
	0x8CFD: 0x841D,
	0xFFFD: 0x841E,
	0xFFFD: 0x841F,
	0xFD63: 0x8420,
	0x9FD3: 0x8421,
	0x94C9: 0x8422,
	0xDB5F: 0x8423,
	0x895B: 0x8424,
	0x89F1: 0x8425,
	0x894D: 0x8426,
	0x8958: 0x8427,
	0x8AF7: 0x8428,
	0xDFC7: 0x8429,
	0x9150: 0x842A,
	0xDFDD: 0x842B,
	0xB855: 0x842C,
	0xDFCC: 0x842D,
	0x9FD4: 0x842E,
	0xDFCA: 0x842F,
	0xDFB5: 0x8430,
	0xB8A9: 0x8431,
	0xDFC5: 0x8432,
	0xDFD9: 0x8433,
	0xDFC1: 0x8434,
	0xB8B1: 0x8435,
	0xDFD8: 0x8436,
	0xDFBF: 0x8437,
	0xB5E3: 0x8438,
	0xDFCF: 0x8439,
	0xDFC0: 0x843A,
	0xDFD6: 0x843B,
	0xB8B0: 0x843C,
	0xB8A8: 0x843D,
	0x9FD5: 0x843E,
	0xDFAA: 0x843F,
	0xDFB2: 0x8440,
	0xFFFD: 0x8441,
	0xDFCB: 0x8442,
	0xDFC3: 0x8443,
	0xDFDC: 0x8444,
	0xDFC6: 0x8445,
	0xB8B6: 0x8446,
	0xDFD7: 0x8447,
	0x9151: 0x8448,
	0xB8AD: 0x8449,
	0x9FD6: 0x844A,
	0xDFC9: 0x844B,
	0xDFD1: 0x844C,
	0xDFB6: 0x844D,
	0xDFD0: 0x844E,
	0xFFFD: 0x844F,
	0xDFE1: 0x8450,
	0xDFB1: 0x8451,
	0xDFD2: 0x8452,
	0x9FD7: 0x8453,
	0xDFDF: 0x8454,
	0x9FD8: 0x8455,
	0xDFAB: 0x8456,
	0xB5DB: 0x8457,
	0x9FD9: 0x8458,
	0xDFB9: 0x8459,
	0xDFB8: 0x845A,
	0xB8AF: 0x845B,
	0x9152: 0x845C,
	0xDFBC: 0x845D,
	0xDFBE: 0x845E,
	0xDFCD: 0x845F,
	0xDFDE: 0x8460,
	0xB8B2: 0x8461,
	0x9153: 0x8462,
	0xB8B3: 0x8463,
	0x9FDA: 0x8464,
	0xDFB0: 0x8465,
	0xB8AB: 0x8466,
	0xDFB4: 0x8467,
	0xDFDA: 0x8468,
	0xB8B4: 0x8469,
	0xFFFD: 0x846A,
	0xB8AC: 0x846B,
	0xB8AE: 0x846C,
	0xB8B5: 0x846D,
	0xDFE0: 0x846E,
	0xDFD3: 0x846F,
	0xDFCE: 0x8470,
	0x95F5: 0x8471,
	0x9FDB: 0x8472,
	0xDFBB: 0x8473,
	0xDFBA: 0x8474,
	0xB8AA: 0x8475,
	0xDFAC: 0x8476,
	0xB8A7: 0x8477,
	0xDFC4: 0x8478,
	0xDFAD: 0x8479,
	0xDFC2: 0x847A,
	0x96C0: 0x847B,
	0xFFFD: 0x847C,
	0xDFB7: 0x847D,
	0xDFDB: 0x847E,
	0x9FDC: 0x847F,
	0x9FDD: 0x8480,
	0xFFFD: 0x8481,
	0xB8A6: 0x8482,
	0xFFFD: 0x8483,
	0x9154: 0x8484,
	0xFFFD: 0x8485,
	0xDFB3: 0x8486,
	0x8EF1: 0x8487,
	0x9155: 0x8488,
	0x8EF3: 0x8489,
	0xFFFD: 0x848A,
	0x8852: 0x848B,
	0x8EC8: 0x848C,
	0xDFAF: 0x848D,
	0xDFD5: 0x848E,
	0xDFAE: 0x848F,
	0xBB60: 0x8490,
	0xE3D3: 0x8491,
	0x9FDE: 0x8492,
	0x9FDF: 0x8493,
	0xE3C2: 0x8494,
	0xFFFD: 0x8495,
	0x9FE0: 0x8496,
	0xE3AC: 0x8497,
	0xE3CA: 0x8498,
	0xBB58: 0x8499,
	0xE3BB: 0x849A,
	0xE3C5: 0x849B,
	0xBB5B: 0x849C,
	0xE3BE: 0x849D,
	0xBB59: 0x849E,
	0xE3AF: 0x849F,
	0xE3CD: 0x84A0,
	0xE3AE: 0x84A1,
	0xE3C1: 0x84A2,
	0x9FE1: 0x84A3,
	0xE3AD: 0x84A4,
	0xFFFD: 0x84A5,
	0xFFFD: 0x84A6,
	0xE3BF: 0x84A7,
	0xE3C8: 0x84A8,
	0xE3C6: 0x84A9,
	0xE3BA: 0x84AA,
	0xE3B5: 0x84AB,
	0xE3B3: 0x84AC,
	0xFD66: 0x84AD,
	0xE3B4: 0x84AE,
	0xE3C7: 0x84AF,
	0xE3D2: 0x84B0,
	0xE3BC: 0x84B1,
	0xBB5A: 0x84B2,
	0xFFFD: 0x84B3,
	0xE3B7: 0x84B4,
	0xFFFD: 0x84B5,
	0xE3CB: 0x84B6,
	0xFFFD: 0x84B7,
	0xBB5D: 0x84B8,
	0xE3B6: 0x84B9,
	0xE3B0: 0x84BA,
	0xE3C0: 0x84BB,
	0xBB61: 0x84BC,
	0x96BC: 0x84BD,
	0x9FE2: 0x84BE,
	0xBB55: 0x84BF,
	0xBB5E: 0x84C0,
	0xE3B8: 0x84C1,
	0xE3B2: 0x84C2,
	0xFFFD: 0x84C3,
	0xBB57: 0x84C4,
	0xDFD4: 0x84C5,
	0xBB56: 0x84C6,
	0xE3C3: 0x84C7,
	0xFFFD: 0x84C8,
	0xBB54: 0x84C9,
	0xBB63: 0x84CA,
	0xBB5C: 0x84CB,
	0xE3C4: 0x84CC,
	0xE3B9: 0x84CD,
	0xE3B1: 0x84CE,
	0xE3CC: 0x84CF,
	0xE3BD: 0x84D0,
	0xBB62: 0x84D1,
	0xE3D0: 0x84D2,
	0xBB5F: 0x84D3,
	0xE3CF: 0x84D4,
	0xFFFD: 0x84D5,
	0xE3C9: 0x84D6,
	0xE3CE: 0x84D7,
	0xFFFD: 0x84D8,
	0x94CA: 0x84D9,
	0xFD65: 0x84DA,
	0xE3D1: 0x84DB,
	0x9156: 0x84DC,
	0x8AF8: 0x84DD,
	0x9FE3: 0x84DE,
	0x8A5E: 0x84DF,
	0x906C: 0x84E0,
	0x9FE4: 0x84E1,
	0x9FE5: 0x84E2,
	0x9157: 0x84E3,
	0x9FE6: 0x84E4,
	0x8FAA: 0x84E5,
	0x8CBD: 0x84E6,
	0xE773: 0x84E7,
	0xE774: 0x84E8,
	0xE767: 0x84E9,
	0xE766: 0x84EA,
	0xE762: 0x84EB,
	0xBDB4: 0x84EC,
	0xFFFD: 0x84ED,
	0xBDAC: 0x84EE,
	0xE776: 0x84EF,
	0xE775: 0x84F0,
	0xDFA9: 0x84F1,
	0xE75F: 0x84F2,
	0xE763: 0x84F3,
	0xE75D: 0x84F4,
	0xFFFD: 0x84F5,
	0xE770: 0x84F6,
	0xE761: 0x84F7,
	0x9FE7: 0x84F8,
	0xE777: 0x84F9,
	0xE75A: 0x84FA,
	0xE758: 0x84FB,
	0xE764: 0x84FC,
	0xE76E: 0x84FD,
	0xE769: 0x84FE,
	0xBDB6: 0x84FF,
	0xE74F: 0x8500,
	0xFFFD: 0x8501,
	0xE76D: 0x8502,
	0x9FE8: 0x8503,
	0xFFFD: 0x8504,
	0x9FE9: 0x8505,
	0xBDB7: 0x8506,
	0xDFBD: 0x8507,
	0xE75B: 0x8508,
	0xE752: 0x8509,
	0xE755: 0x850A,
	0xE77B: 0x850B,
	0xE75C: 0x850C,
	0xE753: 0x850D,
	0xE751: 0x850E,
	0xE74E: 0x850F,
	0x9FEA: 0x8510,
	0xBDB0: 0x8511,
	0xE765: 0x8512,
	0xBDAF: 0x8513,
	0xBDB3: 0x8514,
	0xE760: 0x8515,
	0xE768: 0x8516,
	0xBDA9: 0x8517,
	0xE778: 0x8518,
	0xE77C: 0x8519,
	0xBDAB: 0x851A,
	0xFFFD: 0x851B,
	0xE757: 0x851C,
	0xE76B: 0x851D,
	0xE76F: 0x851E,
	0xE754: 0x851F,
	0xE779: 0x8520,
	0xBDB2: 0x8521,
	0xFFFD: 0x8522,
	0xBDB1: 0x8523,
	0xE74C: 0x8524,
	0xBDB5: 0x8525,
	0xE772: 0x8526,
	0xE756: 0x8527,
	0xE76A: 0x8528,
	0xE750: 0x8529,
	0xE75E: 0x852A,
	0xE759: 0x852B,
	0xBDAD: 0x852C,
	0xBDAE: 0x852D,
	0xE76C: 0x852E,
	0xE77D: 0x852F,
	0xE77A: 0x8530,
	0xE771: 0x8531,
	0xFFFD: 0x8532,
	0x9FEB: 0x8533,
	0xFE4C: 0x8534,
	0x9360: 0x8535,
	0xFFFD: 0x8536,
	0x8A5D: 0x8537,
	0x9158: 0x8538,
	0x9046: 0x8539,
	0x8C4E: 0x853A,
	0xE74D: 0x853B,
	0x8C4D: 0x853C,
	0xBDAA: 0x853D,
	0xEB49: 0x853E,
	0xFFFD: 0x853F,
	0xEB40: 0x8540,
	0xEB43: 0x8541,
	0x9FED: 0x8542,
	0xBFBB: 0x8543,
	0xEB45: 0x8544,
	0xEAF9: 0x8545,
	0xEB41: 0x8546,
	0xEB47: 0x8547,
	0xBFB8: 0x8548,
	0xBFBC: 0x8549,
	0xBFB6: 0x854A,
	0xFD68: 0x854B,
	0x9FEE: 0x854C,
	0xEAFB: 0x854D,
	0xEB4C: 0x854E,
	0xFFFD: 0x854F,
	0xFFFD: 0x8550,
	0xEB46: 0x8551,
	0x9FEF: 0x8552,
	0xEAFC: 0x8553,
	0xEB55: 0x8554,
	0xEB4F: 0x8555,
	0xEAF8: 0x8556,
	0xEE46: 0x8557,
	0xEAFE: 0x8558,
	0xBFB7: 0x8559,
	0x9159: 0x855A,
	0xEB4A: 0x855B,
	0xFFFD: 0x855C,
	0xEB54: 0x855D,
	0xBFBF: 0x855E,
	0x9FF0: 0x855F,
	0xEB51: 0x8560,
	0xEAFD: 0x8561,
	0xEB44: 0x8562,
	0xEB48: 0x8563,
	0xEB42: 0x8564,
	0xEB56: 0x8565,
	0xEB53: 0x8566,
	0xEB50: 0x8567,
	0xBFB9: 0x8568,
	0xBFBA: 0x8569,
	0xBFBE: 0x856A,
	0xEAFA: 0x856B,
	0xEB57: 0x856C,
	0xBFBD: 0x856D,
	0xEB4D: 0x856E,
	0x9FF1: 0x856F,
	0x9FF2: 0x8570,
	0xEB4B: 0x8571,
	0x8FE2: 0x8572,
	0x9FF3: 0x8573,
	0x8C51: 0x8574,
	0xEB4E: 0x8575,
	0xEE53: 0x8576,
	0xEE40: 0x8577,
	0xEE45: 0x8578,
	0xEE52: 0x8579,
	0xEE44: 0x857A,
	0xEDFB: 0x857B,
	0xEE41: 0x857C,
	0xFFFD: 0x857D,
	0xC1A2: 0x857E,
	0xFFFD: 0x857F,
	0xEDF4: 0x8580,
	0xEE4D: 0x8581,
	0xEE4F: 0x8582,
	0xEDF3: 0x8583,
	0xC1A1: 0x8584,
	0xEE51: 0x8585,
	0xEE49: 0x8586,
	0xC1A8: 0x8587,
	0xEE50: 0x8588,
	0xEE42: 0x8589,
	0xC1AA: 0x858A,
	0xEDF9: 0x858B,
	0xEB52: 0x858C,
	0xEE4A: 0x858D,
	0xEE47: 0x858E,
	0xEDF5: 0x858F,
	0xEE55: 0x8590,
	0xC1A4: 0x8591,
	0xFFFD: 0x8592,
	0x9D76: 0x8593,
	0xC1A5: 0x8594,
	0xEDF7: 0x8595,
	0xEE48: 0x8596,
	0x915A: 0x8597,
	0xEE54: 0x8598,
	0xEE4B: 0x8599,
	0xEDFD: 0x859A,
	0xC1A7: 0x859B,
	0xC1A3: 0x859C,
	0xEE4C: 0x859D,
	0xEDFE: 0x859E,
	0xEE56: 0x859F,
	0xEDF8: 0x85A0,
	0xEE43: 0x85A1,
	0xEE4E: 0x85A2,
	0xEDFA: 0x85A3,
	0xEDFC: 0x85A4,
	0xFFFD: 0x85A5,
	0xC2CB: 0x85A6,
	0xEDF6: 0x85A7,
	0xC1A9: 0x85A8,
	0xC2C4: 0x85A9,
	0xC17E: 0x85AA,
	0x915B: 0x85AB,
	0x93D6: 0x85AC,
	0xFFFD: 0x85AD,
	0x827E: 0x85AE,
	0xC1A6: 0x85AF,
	0xC2C8: 0x85B0,
	0xF0B3: 0x85B1,
	0xFFFD: 0x85B2,
	0xF0A9: 0x85B3,
	0xF0A4: 0x85B4,
	0xF0AA: 0x85B5,
	0xF0B4: 0x85B6,
	0xF0B8: 0x85B7,
	0xF0B7: 0x85B8,
	0xC2CA: 0x85B9,
	0xC2C9: 0x85BA,
	0xFFFD: 0x85BB,
	0xFFFD: 0x85BC,
	0xF0AB: 0x85BD,
	0xF0B9: 0x85BE,
	0xF0AE: 0x85BF,
	0xF0A6: 0x85C0,
	0x915C: 0x85C1,
	0xF0A8: 0x85C2,
	0xF0A7: 0x85C3,
	0xF0AD: 0x85C4,
	0xF0B2: 0x85C5,
	0xF0A5: 0x85C6,
	0xF0AC: 0x85C7,
	0xF0B1: 0x85C8,
	0xC2C7: 0x85C9,
	0xFFFD: 0x85CA,
	0xF0AF: 0x85CB,
	0xFFFD: 0x85CC,
	0xC2C5: 0x85CD,
	0xF0B0: 0x85CE,
	0xC2C3: 0x85CF,
	0xC2C6: 0x85D0,
	0xF2D5: 0x85D1,
	0xF0B5: 0x85D2,
	0x8CA4: 0x85D3,
	0xFFFD: 0x85D4,
	0xC3C2: 0x85D5,
	0x9FF4: 0x85D6,
	0xF2CD: 0x85D7,
	0xF2D1: 0x85D8,
	0xF2C9: 0x85D9,
	0xF2CC: 0x85DA,
	0xFFFD: 0x85DB,
	0xF2D4: 0x85DC,
	0xC3C0: 0x85DD,
	0xF2D9: 0x85DE,
	0xF2D2: 0x85DF,
	0x9FF5: 0x85E0,
	0xF2CA: 0x85E1,
	0xF2DA: 0x85E2,
	0xF2D3: 0x85E3,
	0xC3C3: 0x85E4,
	0xC3C4: 0x85E5,
	0xF2D7: 0x85E6,
	0xFFFD: 0x85E7,
	0xF2CB: 0x85E8,
	0xC3BF: 0x85E9,
	0xC3C1: 0x85EA,
	0xF2C6: 0x85EB,
	0xF2CE: 0x85EC,
	0xF2C8: 0x85ED,
	0x9FF6: 0x85EE,
	0xF2D8: 0x85EF,
	0xF2D6: 0x85F0,
	0xF2C7: 0x85F1,
	0xF2CF: 0x85F2,
	0xFFFD: 0x85F3,
	0xFFFD: 0x85F4,
	0xFFFD: 0x85F5,
	0xF4BE: 0x85F6,
	0xC3C5: 0x85F7,
	0xF2D0: 0x85F8,
	0xC4A7: 0x85F9,
	0xC4A9: 0x85FA,
	0xC4A6: 0x85FB,
	0x9FF7: 0x85FC,
	0xF4C3: 0x85FD,
	0xF4BB: 0x85FE,
	0xF4B9: 0x85FF,
	0xF4BD: 0x8600,
	0xF4BA: 0x8601,
	0xFD6A: 0x8602,
	0xFFFD: 0x8603,
	0xF4BF: 0x8604,
	0xF4C1: 0x8605,
	0xC4AA: 0x8606,
	0xC4AC: 0x8607,
	0xFFFD: 0x8608,
	0xF4C0: 0x8609,
	0xC4AD: 0x860A,
	0xC4AB: 0x860B,
	0xF4C2: 0x860C,
	0x9FF8: 0x860D,
	0xFFFD: 0x860E,
	0x9FF9: 0x860F,
	0xFD6B: 0x8610,
	0xC4A8: 0x8611,
	0xFFFD: 0x8612,
	0x915D: 0x8613,
	0x9FFA: 0x8614,
	0xFFFD: 0x8615,
	0x915E: 0x8616,
	0xC4F4: 0x8617,
	0xF5F1: 0x8618,
	0xF5F7: 0x8619,
	0xC4F6: 0x861A,
	0xF4BC: 0x861B,
	0xF5F6: 0x861C,
	0xFFFD: 0x861D,
	0xF5FD: 0x861E,
	0xF5F4: 0x861F,
	0xF5FB: 0x8620,
	0xF5FA: 0x8621,
	0xF4B8: 0x8622,
	0xF5F5: 0x8623,
	0xF0B6: 0x8624,
	0xF5FE: 0x8625,
	0xF5F3: 0x8626,
	0xF5F8: 0x8627,
	0x9FFB: 0x8628,
	0xF5FC: 0x8629,
	0xF5F2: 0x862A,
	0xFFFD: 0x862B,
	0xF74A: 0x862C,
	0xC4F5: 0x862D,
	0xF5F9: 0x862E,
	0xFBAE: 0x862F,
	0x94CB: 0x8630,
	0xF7F4: 0x8631,
	0xF74B: 0x8632,
	0xF749: 0x8633,
	0xF747: 0x8634,
	0xF748: 0x8635,
	0xF74C: 0x8636,
	0xFFFD: 0x8637,
	0xC5D9: 0x8638,
	0xF7F2: 0x8639,
	0xF7F0: 0x863A,
	0xF7F5: 0x863B,
	0xF7F3: 0x863C,
	0xFFFD: 0x863D,
	0xF7F6: 0x863E,
	0xC5DA: 0x863F,
	0xF7F1: 0x8640,
	0xFFFD: 0x8641,
	0x9FFC: 0x8642,
	0xF8BC: 0x8643,
	0xFFFD: 0x8644,
	0x9FFD: 0x8645,
	0xF945: 0x8646,
	0xF946: 0x8647,
	0xF947: 0x8648,
	0xFFFD: 0x8649,
	0xFFFD: 0x864A,
	0xF9C7: 0x864B,
	0xF9BD: 0x864C,
	0xCA4F: 0x864D,
	0xAAEA: 0x864E,
	0x8640: 0x864F,
	0xAD68: 0x8650,
	0x87CB: 0x8651,
	0xD3B8: 0x8652,
	0xD3B7: 0x8653,
	0xB040: 0x8654,
	0xB342: 0x8655,
	0xD77C: 0x8656,
	0xFFFD: 0x8657,
	0xFFFD: 0x8658,
	0xD77B: 0x8659,
	0x8552: 0x865A,
	0xB5EA: 0x865B,
	0xB8B8: 0x865C,
	0xFFFD: 0x865D,
	0xB8B7: 0x865E,
	0xB8B9: 0x865F,
	0xFFFD: 0x8660,
	0xE3D4: 0x8661,
	0xE77E: 0x8662,
	0xEB58: 0x8663,
	0xEB5A: 0x8664,
	0xEB59: 0x8665,
	0xFFFD: 0x8666,
	0xC1AB: 0x8667,
	0xEE57: 0x8668,
	0xF0BA: 0x8669,
	0xF9A5: 0x866A,
	0xA6E4: 0x866B,
	0x9578: 0x866C,
	0xCDC9: 0x866D,
	0xCDCA: 0x866E,
	0xCDC8: 0x866F,
	0xCDC7: 0x8670,
	0xAAEB: 0x8671,
	0x9FFE: 0x8672,
	0xD0A9: 0x8673,
	0xD0A7: 0x8674,
	0xFFFD: 0x8675,
	0xFFFD: 0x8676,
	0xD0A6: 0x8677,
	0xFFFD: 0x8678,
	0xAD69: 0x8679,
	0xAD6B: 0x867A,
	0xAD6A: 0x867B,
	0xD0A8: 0x867C,
	0x8AAF: 0x867D,
	0x8853: 0x867E,
	0x8FC4: 0x867F,
	0x874C: 0x8680,
	0x8BBA: 0x8681,
	0x895A: 0x8682,
	0xFFFD: 0x8683,
	0xFFFD: 0x8684,
	0xD3C4: 0x8685,
	0xD3C1: 0x8686,
	0xD3BF: 0x8687,
	0xFFFD: 0x8688,
	0xFFFD: 0x8689,
	0xB041: 0x868A,
	0xD3C2: 0x868B,
	0xB046: 0x868C,
	0xD3BC: 0x868D,
	0xD3CB: 0x868E,
	0xFFFD: 0x868F,
	0xD3CD: 0x8690,
	0xD3BD: 0x8691,
	0xFEBB: 0x8692,
	0xB043: 0x8693,
	0xD3CE: 0x8694,
	0xD3C9: 0x8695,
	0xD3BB: 0x8696,
	0xD3C0: 0x8697,
	0xD3CA: 0x8698,
	0xD3C6: 0x8699,
	0xD3C3: 0x869A,
	0xFFFD: 0x869B,
	0xB048: 0x869C,
	0xD3CC: 0x869D,
	0xD3BE: 0x869E,
	0xFFFD: 0x869F,
	0xFEBC: 0x86A0,
	0xD3C7: 0x86A1,
	0xD3B9: 0x86A2,
	0xB047: 0x86A3,
	0xB044: 0x86A4,
	0xD3C5: 0x86A5,
	0xFFFD: 0x86A6,
	0xD3C8: 0x86A7,
	0xD3BA: 0x86A8,
	0xB045: 0x86A9,
	0xB042: 0x86AA,
	0x94CC: 0x86AB,
	0x8643: 0x86AC,
	0xFEBD: 0x86AD,
	0xFFFD: 0x86AE,
	0xB34C: 0x86AF,
	0xD7A5: 0x86B0,
	0xB34B: 0x86B1,
	0xFEBE: 0x86B2,
	0xD7A8: 0x86B3,
	0xD7AB: 0x86B4,
	0xB348: 0x86B5,
	0xB346: 0x86B6,
	0xD77E: 0x86B7,
	0xD7A9: 0x86B8,
	0xD7A7: 0x86B9,
	0xD7A4: 0x86BA,
	0xD7AC: 0x86BB,
	0xD7AD: 0x86BC,
	0xD7AF: 0x86BD,
	0xD7B0: 0x86BE,
	0xD77D: 0x86BF,
	0xB345: 0x86C0,
	0xD7A2: 0x86C1,
	0xD7A1: 0x86C2,
	0xD7AE: 0x86C3,
	0xB347: 0x86C4,
	0xD7A3: 0x86C5,
	0xB349: 0x86C6,
	0xB344: 0x86C7,
	0xD7A6: 0x86C8,
	0xB34D: 0x86C9,
	0x8CFE: 0x86CA,
	0xB34A: 0x86CB,
	0xD7AA: 0x86CC,
	0x92AC: 0x86CD,
	0x824C: 0x86CE,
	0x8FC3: 0x86CF,
	0xB5F1: 0x86D0,
	0xDBBF: 0x86D1,
	0xFFFD: 0x86D2,
	0xDBB4: 0x86D3,
	0xB5EE: 0x86D4,
	0xFFFD: 0x86D5,
	0xDFE7: 0x86D6,
	0xDBBD: 0x86D7,
	0xDBB1: 0x86D8,
	0xB5EC: 0x86D9,
	0xDBB6: 0x86DA,
	0xB5EF: 0x86DB,
	0xDBBA: 0x86DC,
	0xDBB8: 0x86DD,
	0xB5F2: 0x86DE,
	0xB5EB: 0x86DF,
	0xFFFD: 0x86E0,
	0xFFFD: 0x86E1,
	0xDBB2: 0x86E2,
	0xDBB5: 0x86E3,
	0xB5F0: 0x86E4,
	0xFFFD: 0x86E5,
	0xDBB3: 0x86E6,
	0xFFFD: 0x86E7,
	0xDBBE: 0x86E8,
	0xDBBC: 0x86E9,
	0xDBB7: 0x86EA,
	0xDBB9: 0x86EB,
	0xDBBB: 0x86EC,
	0xB5ED: 0x86ED,
	0x8D72: 0x86EE,
	0x94CD: 0x86EF,
	0x8F61: 0x86F0,
	0x8E4E: 0x86F1,
	0x8AFA: 0x86F2,
	0x8EF7: 0x86F3,
	0x8FE3: 0x86F4,
	0xDFE8: 0x86F5,
	0xDFEE: 0x86F6,
	0xDFE4: 0x86F7,
	0xDFEA: 0x86F8,
	0xB8BA: 0x86F9,
	0xDFE6: 0x86FA,
	0xB8C0: 0x86FB,
	0xFFFD: 0x86FC,
	0xFFFD: 0x86FD,
	0xB8BF: 0x86FE,
	0xFFFD: 0x86FF,
	0xB8BE: 0x8700,
	0xDFED: 0x8701,
	0xB8C1: 0x8702,
	0xB8C2: 0x8703,
	0xDFE3: 0x8704,
	0xDFF0: 0x8705,
	0xB8C3: 0x8706,
	0xB8BD: 0x8707,
	0xB8BC: 0x8708,
	0xDFEC: 0x8709,
	0xB8C4: 0x870A,
	0xDFE2: 0x870B,
	0xDFE5: 0x870C,
	0xDFEF: 0x870D,
	0xDFEB: 0x870E,
	0xFFFD: 0x870F,
	0xFFFD: 0x8710,
	0xE3F4: 0x8711,
	0xE3E9: 0x8712,
	0xB8BB: 0x8713,
	0xFFFD: 0x8714,
	0x9160: 0x8715,
	0xFFFD: 0x8716,
	0x8854: 0x8717,
	0xBB6A: 0x8718,
	0xE3DD: 0x8719,
	0xE3F2: 0x871A,
	0xE3DE: 0x871B,
	0xBB65: 0x871C,
	0xFFFD: 0x871D,
	0xE3DB: 0x871E,
	0xFFFD: 0x871F,
	0xE3E4: 0x8720,
	0xE3DC: 0x8721,
	0xBB67: 0x8722,
	0xE3D6: 0x8723,
	0xE3F1: 0x8724,
	0xBB68: 0x8725,
	0xE3EE: 0x8726,
	0xE3EF: 0x8727,
	0xE3D7: 0x8728,
	0xBB6D: 0x8729,
	0xE3E6: 0x872A,
	0xFFFD: 0x872B,
	0xE3E0: 0x872C,
	0xE3E7: 0x872D,
	0xE3DA: 0x872E,
	0xFFFD: 0x872F,
	0xE3F3: 0x8730,
	0xE3EB: 0x8731,
	0xE3E5: 0x8732,
	0xE3D5: 0x8733,
	0xBB69: 0x8734,
	0xE3EC: 0x8735,
	0xFFFD: 0x8736,
	0xBB6C: 0x8737,
	0xE3F0: 0x8738,
	0xFFFD: 0x8739,
	0xE3EA: 0x873A,
	0xBB66: 0x873B,
	0xE3E8: 0x873C,
	0xFFFD: 0x873D,
	0xE3E2: 0x873E,
	0xBB64: 0x873F,
	0xE3D9: 0x8740,
	0xE3E1: 0x8741,
	0xE3ED: 0x8742,
	0xE3DF: 0x8743,
	0xFFFD: 0x8744,
	0xFFFD: 0x8745,
	0xE3E3: 0x8746,
	0x8BBB: 0x8747,
	0x8A61: 0x8748,
	0x8AFB: 0x8749,
	0xFFFD: 0x874A,
	0x82A2: 0x874B,
	0xBDC1: 0x874C,
	0xDFE9: 0x874D,
	0xE7B2: 0x874E,
	0xE7BB: 0x874F,
	0xE7B1: 0x8750,
	0xE7AD: 0x8751,
	0xE7AA: 0x8752,
	0xBDC2: 0x8753,
	0xE7A8: 0x8754,
	0xBB6B: 0x8755,
	0xE7A1: 0x8756,
	0xBDC0: 0x8757,
	0xE7A7: 0x8758,
	0xBDBF: 0x8759,
	0xE7AC: 0x875A,
	0xE7A9: 0x875B,
	0xE7B9: 0x875C,
	0xE7B4: 0x875D,
	0xE7AE: 0x875E,
	0xE7B3: 0x875F,
	0xBDBB: 0x8760,
	0xE7AB: 0x8761,
	0xE7BE: 0x8762,
	0xE7A2: 0x8763,
	0xE7A3: 0x8764,
	0xE7BA: 0x8765,
	0xBDBC: 0x8766,
	0xE7BF: 0x8767,
	0xBDBE: 0x8768,
	0xE7C0: 0x8769,
	0xE7B0: 0x876A,
	0xE3D8: 0x876B,
	0xE7B6: 0x876C,
	0xE7AF: 0x876D,
	0xE7B8: 0x876E,
	0xE7B5: 0x876F,
	0x9161: 0x8770,
	0xFD45: 0x8771,
	0xFFFD: 0x8772,
	0xE7A6: 0x8773,
	0xBDB9: 0x8774,
	0xE7BD: 0x8775,
	0xBDBA: 0x8776,
	0xE7A4: 0x8777,
	0xBDBD: 0x8778,
	0xEB64: 0x8779,
	0xE7B7: 0x877A,
	0xE7BC: 0x877B,
	0x8A60: 0x877C,
	0x9162: 0x877D,
	0x8FE4: 0x877E,
	0x8275: 0x877F,
	0xFFFD: 0x8780,
	0xEB61: 0x8781,
	0xBDB8: 0x8782,
	0xBFC0: 0x8783,
	0xEB6B: 0x8784,
	0xEB67: 0x8785,
	0xFB6C: 0x8786,
	0xEB65: 0x8787,
	0xEB60: 0x8788,
	0xEB6F: 0x8789,
	0xFFFD: 0x878A,
	0x9163: 0x878B,
	0xFD47: 0x878C,
	0xBFC4: 0x878D,
	0xFFFD: 0x878E,
	0xEB5C: 0x878F,
	0xEB68: 0x8790,
	0xEB69: 0x8791,
	0xEB5F: 0x8792,
	0xEB5E: 0x8793,
	0xEB6C: 0x8794,
	0xFFFD: 0x8795,
	0xEB62: 0x8796,
	0xEB5D: 0x8797,
	0xEB63: 0x8798,
	0xFFFD: 0x8799,
	0xEB6E: 0x879A,
	0xEB5B: 0x879B,
	0xEB6D: 0x879C,
	0xEB6A: 0x879D,
	0xBFC2: 0x879E,
	0xBFC1: 0x879F,
	0xFFFD: 0x87A0,
	0xFFFD: 0x87A1,
	0xBFC3: 0x87A2,
	0xEB66: 0x87A3,
	0xF0CB: 0x87A4,
	0xFEBF: 0x87A5,
	0xFFFD: 0x87A6,
	0xFFFD: 0x87A7,
	0x9164: 0x87A8,
	0xFD46: 0x87A9,
	0xEE59: 0x87AA,
	0xC1B1: 0x87AB,
	0xEE5D: 0x87AC,
	0xEE5A: 0x87AD,
	0xEE61: 0x87AE,
	0xEE67: 0x87AF,
	0xEE5C: 0x87B0,
	0xFEC0: 0x87B1,
	0xEE70: 0x87B2,
	0xC1AE: 0x87B3,
	0xEE6A: 0x87B4,
	0xEE5F: 0x87B5,
	0xEE6B: 0x87B6,
	0xEE66: 0x87B7,
	0xEE6D: 0x87B8,
	0xEE5E: 0x87B9,
	0xC1B3: 0x87BA,
	0xC1B2: 0x87BB,
	0xEE60: 0x87BC,
	0xEE6E: 0x87BD,
	0xEE58: 0x87BE,
	0xEE6C: 0x87BF,
	0xC1AC: 0x87C0,
	0xFD49: 0x87C1,
	0xEE64: 0x87C2,
	0xEE63: 0x87C3,
	0xEE68: 0x87C4,
	0xEE5B: 0x87C5,
	0xC1B0: 0x87C6,
	0x9165: 0x87C7,
	0xC1B4: 0x87C8,
	0xEE62: 0x87C9,
	0xEE69: 0x87CA,
	0xC1B5: 0x87CB,
	0xEE65: 0x87CC,
	0xFFFD: 0x87CD,
	0x96C7: 0x87CE,
	0xFFFD: 0x87CF,
	0x9166: 0x87D0,
	0xC1AD: 0x87D1,
	0xC1AF: 0x87D2,
	0xF0C7: 0x87D3,
	0xF0C5: 0x87D4,
	0xFFFD: 0x87D5,
	0xFD4C: 0x87D6,
	0xF0CC: 0x87D7,
	0xF0C9: 0x87D8,
	0xF0CD: 0x87D9,
	0xFEC5: 0x87DA,
	0xF0BE: 0x87DB,
	0xF0C6: 0x87DC,
	0xF0D1: 0x87DD,
	0xEE6F: 0x87DE,
	0xF0C2: 0x87DF,
	0xC2CF: 0x87E0,
	0xE7A5: 0x87E1,
	0xF0BD: 0x87E2,
	0xF0CA: 0x87E3,
	0xF0C4: 0x87E4,
	0xF0C1: 0x87E5,
	0xF0BC: 0x87E6,
	0xF0BB: 0x87E7,
	0xF0D0: 0x87E8,
	0xFFFD: 0x87E9,
	0xF0C0: 0x87EA,
	0xF0BF: 0x87EB,
	0xC2CD: 0x87EC,
	0xF0C8: 0x87ED,
	0xFBAB: 0x87EE,
	0xC2CC: 0x87EF,
	0xFFFD: 0x87F0,
	0xFFFD: 0x87F1,
	0xC2CE: 0x87F2,
	0xF0C3: 0x87F3,
	0xF0CF: 0x87F4,
	0xFD4D: 0x87F5,
	0xF2DE: 0x87F6,
	0xF2DF: 0x87F7,
	0xFFFD: 0x87F8,
	0xC3C9: 0x87F9,
	0xF2DC: 0x87FA,
	0xC3C6: 0x87FB,
	0xF2E4: 0x87FC,
	0xFFFD: 0x87FD,
	0xC3CA: 0x87FE,
	0xF2E6: 0x87FF,
	0xF2DB: 0x8800,
	0xF0CE: 0x8801,
	0xF2E8: 0x8802,
	0xF2DD: 0x8803,
	0xFB72: 0x8804,
	0xC3C7: 0x8805,
	0xF2E3: 0x8806,
	0x9167: 0x8807,
	0xF2E5: 0x8808,
	0xF2E0: 0x8809,
	0xF2E7: 0x880A,
	0xF2E2: 0x880B,
	0xF2E1: 0x880C,
	0xC3C8: 0x880D,
	0x9168: 0x880E,
	0xFD4E: 0x880F,
	0xF4C5: 0x8810,
	0xF4C6: 0x8811,
	0xFFFD: 0x8812,
	0xF4C8: 0x8813,
	0xC4AE: 0x8814,
	0xC4AF: 0x8815,
	0xF4C9: 0x8816,
	0xF4C7: 0x8817,
	0xFD4F: 0x8818,
	0xF4C4: 0x8819,
	0xFFFD: 0x881A,
	0xF642: 0x881B,
	0xF645: 0x881C,
	0xF641: 0x881D,
	0xFFFD: 0x881E,
	0xC4FA: 0x881F,
	0xF643: 0x8820,
	0xC4F9: 0x8821,
	0xC4F8: 0x8822,
	0xC4F7: 0x8823,
	0xF644: 0x8824,
	0xF751: 0x8825,
	0xF74F: 0x8826,
	0x9169: 0x8827,
	0xF74E: 0x8828,
	0xF640: 0x8829,
	0xF750: 0x882A,
	0xF646: 0x882B,
	0xF74D: 0x882C,
	0xFD50: 0x882D,
	0xF7F9: 0x882E,
	0xF7D7: 0x882F,
	0xF7F7: 0x8830,
	0xC5DB: 0x8831,
	0xF7F8: 0x8832,
	0xF7FA: 0x8833,
	0xFFFD: 0x8834,
	0xF8BF: 0x8835,
	0xC5FA: 0x8836,
	0xF8BE: 0x8837,
	0xF8BD: 0x8838,
	0xC5FB: 0x8839,
	0xFFFD: 0x883A,
	0xC65A: 0x883B,
	0xF96E: 0x883C,
	0xF9A7: 0x883D,
	0xF9A6: 0x883E,
	0xF9A8: 0x883F,
	0xA6E5: 0x8840,
	0xD0AA: 0x8841,
	0xFD51: 0x8842,
	0xD3CF: 0x8843,
	0xD3D0: 0x8844,
	0x8D75: 0x8845,
	0x92DB: 0x8846,
	0xFFFD: 0x8847,
	0xDBC0: 0x8848,
	0xFFFD: 0x8849,
	0xF647: 0x884A,
	0xF8C0: 0x884B,
	0xA6E6: 0x884C,
	0xAD6C: 0x884D,
	0xD0AB: 0x884E,
	0xFEC6: 0x884F,
	0xFFFD: 0x8850,
	0xFFFD: 0x8851,
	0xD7B1: 0x8852,
	0xB34E: 0x8853,
	0x83F5: 0x8854,
	0xDBC2: 0x8855,
	0xDBC1: 0x8856,
	0xB5F3: 0x8857,
	0xFFFD: 0x8858,
	0xB8C5: 0x8859,
	0xE7C1: 0x885A,
	0xBDC3: 0x885B,
	0xFFFD: 0x885C,
	0xBDC4: 0x885D,
	0xFD5B: 0x885E,
	0xFFFD: 0x885F,
	0xFEC7: 0x8860,
	0xBFC5: 0x8861,
	0xC5FC: 0x8862,
	0xA6E7: 0x8863,
	0x91D6: 0x8864,
	0x8644: 0x8865,
	0xFFFD: 0x8866,
	0xD0AC: 0x8867,
	0xAAED: 0x8868,
	0xD0AE: 0x8869,
	0xD0AD: 0x886A,
	0xAD6D: 0x886B,
	0x8CDC: 0x886C,
	0xD3D1: 0x886D,
	0x847C: 0x886E,
	0xD3D8: 0x886F,
	0xB049: 0x8870,
	0xD3D6: 0x8871,
	0xD3D4: 0x8872,
	0xFFFD: 0x8873,
	0xD3DB: 0x8874,
	0xD3D2: 0x8875,
	0xD3D3: 0x8876,
	0xB04A: 0x8877,
	0xFFFD: 0x8878,
	0xB04E: 0x8879,
	0xFFFD: 0x887A,
	0xFFFD: 0x887B,
	0xD3DC: 0x887C,
	0xB04D: 0x887D,
	0xD3DA: 0x887E,
	0xD3D7: 0x887F,
	0xD3D5: 0x8880,
	0xB04B: 0x8881,
	0xB04C: 0x8882,
	0xD3D9: 0x8883,
	0x8BBD: 0x8884,
	0x88D3: 0x8885,
	0xFFFD: 0x8886,
	0xFEC8: 0x8887,
	0xB350: 0x8888,
	0xD7B2: 0x8889,
	0xFFFD: 0x888A,
	0xB355: 0x888B,
	0xD7C2: 0x888C,
	0xB354: 0x888D,
	0xD7C4: 0x888E,
	0xFEC9: 0x888F,
	0xFECA: 0x8890,
	0xD7B8: 0x8891,
	0xB352: 0x8892,
	0xD7C3: 0x8893,
	0xFFFD: 0x8894,
	0xD7B3: 0x8895,
	0xB353: 0x8896,
	0xD7BF: 0x8897,
	0xD7BB: 0x8898,
	0xD7BD: 0x8899,
	0xD7B7: 0x889A,
	0xD7BE: 0x889B,
	0x90BA: 0x889C,
	0xFFFD: 0x889D,
	0xB34F: 0x889E,
	0xD7BA: 0x889F,
	0xFD56: 0x88A0,
	0xD7B9: 0x88A1,
	0xD7B5: 0x88A2,
	0xFFFD: 0x88A3,
	0xD7C0: 0x88A4,
	0xFFFD: 0x88A5,
	0xFFFD: 0x88A6,
	0xD7BC: 0x88A7,
	0xD7B4: 0x88A8,
	0xFFFD: 0x88A9,
	0xD7B6: 0x88AA,
	0xB351: 0x88AB,
	0xD7C1: 0x88AC,
	0x8CDB: 0x88AD,
	0x916A: 0x88AE,
	0xFFFD: 0x88AF,
	0x94CE: 0x88B0,
	0xB5F6: 0x88B1,
	0xDBCD: 0x88B2,
	0xFFFD: 0x88B3,
	0x95DD: 0x88B4,
	0x916C: 0x88B5,
	0xDBC9: 0x88B6,
	0xDBCB: 0x88B7,
	0xDBC6: 0x88B8,
	0xDBC5: 0x88B9,
	0xDBC3: 0x88BA,
	0xFFFD: 0x88BB,
	0xDBCA: 0x88BC,
	0xDBCC: 0x88BD,
	0xDBC8: 0x88BE,
	0x916D: 0x88BF,
	0xDBC7: 0x88C0,
	0xB5F4: 0x88C1,
	0xB5F5: 0x88C2,
	0x94CF: 0x88C3,
	0x94D0: 0x88C4,
	0x8645: 0x88C5,
	0x8BBC: 0x88C6,
	0xFB63: 0x88C7,
	0xFFFD: 0x88C8,
	0xDBCF: 0x88C9,
	0xB8CD: 0x88CA,
	0xDFF2: 0x88CB,
	0xDFF8: 0x88CC,
	0xDFF3: 0x88CD,
	0xDFF4: 0x88CE,
	0xF9D8: 0x88CF,
	0xDFF9: 0x88D0,
	0xFFFD: 0x88D1,
	0xB8CF: 0x88D2,
	0xFFFD: 0x88D3,
	0xB8C7: 0x88D4,
	0xB8CE: 0x88D5,
	0xDFF1: 0x88D6,
	0xDBC4: 0x88D7,
	0xB8CA: 0x88D8,
	0xB8C8: 0x88D9,
	0xDFF7: 0x88DA,
	0xDFF6: 0x88DB,
	0xB8C9: 0x88DC,
	0xB8CB: 0x88DD,
	0xDFF5: 0x88DE,
	0xB8C6: 0x88DF,
	0xFFFD: 0x88E0,
	0xB8CC: 0x88E1,
	0x8F62: 0x88E2,
	0x8FC5: 0x88E3,
	0x895C: 0x88E4,
	0x916E: 0x88E5,
	0xFECB: 0x88E6,
	0xE3F6: 0x88E7,
	0xBB74: 0x88E8,
	0xFFFD: 0x88E9,
	0xFFFD: 0x88EA,
	0xE442: 0x88EB,
	0xE441: 0x88EC,
	0xFFFD: 0x88ED,
	0xE3FB: 0x88EE,
	0xBB76: 0x88EF,
	0xE440: 0x88F0,
	0xE3F7: 0x88F1,
	0xE3F8: 0x88F2,
	0xBB6E: 0x88F3,
	0xBB70: 0x88F4,
	0x916F: 0x88F5,
	0xE3FD: 0x88F6,
	0xE3F5: 0x88F7,
	0xBB72: 0x88F8,
	0xBB71: 0x88F9,
	0xE3F9: 0x88FA,
	0xE3FE: 0x88FB,
	0xE3FC: 0x88FC,
	0xBB73: 0x88FD,
	0xE3FA: 0x88FE,
	0xFECC: 0x88FF,
	0xFECD: 0x8900,
	0xDBCE: 0x8901,
	0xBB6F: 0x8902,
	0xFFFD: 0x8903,
	0x94D1: 0x8904,
	0xE7C2: 0x8905,
	0xE7C9: 0x8906,
	0xBDC6: 0x8907,
	0xFFFD: 0x8908,
	0xE7CD: 0x8909,
	0xBDCA: 0x890A,
	0xE7C5: 0x890B,
	0xE7C3: 0x890C,
	0xFFFD: 0x890D,
	0xE7CC: 0x890E,
	0xFFFD: 0x890F,
	0xBDC5: 0x8910,
	0xE7CB: 0x8911,
	0xBDC7: 0x8912,
	0xBDC8: 0x8913,
	0xE7C4: 0x8914,
	0xBDC9: 0x8915,
	0xE7CA: 0x8916,
	0xE7C6: 0x8917,
	0xE7C7: 0x8918,
	0xE7C8: 0x8919,
	0xBB75: 0x891A,
	0x8A63: 0x891B,
	0x9170: 0x891C,
	0x9171: 0x891D,
	0xEB70: 0x891E,
	0xEB7C: 0x891F,
	0xFFFD: 0x8920,
	0xBFCA: 0x8921,
	0xEB77: 0x8922,
	0xEB79: 0x8923,
	0xFECE: 0x8924,
	0xBFC8: 0x8925,
	0xEB71: 0x8926,
	0xEB75: 0x8927,
	0xFFFD: 0x8928,
	0xEB78: 0x8929,
	0xBFC6: 0x892A,
	0xBFC9: 0x892B,
	0xEB7B: 0x892C,
	0xEB73: 0x892D,
	0xEB74: 0x892E,
	0xEB7A: 0x892F,
	0xEB72: 0x8930,
	0xEB76: 0x8931,
	0xBFC7: 0x8932,
	0xEE72: 0x8933,
	0x8C53: 0x8934,
	0xEE71: 0x8935,
	0xC1B7: 0x8936,
	0xEE77: 0x8937,
	0xC1B9: 0x8938,
	0xFFFD: 0x8939,
	0xFFFD: 0x893A,
	0xC1B6: 0x893B,
	0xEE73: 0x893C,
	0xC1BA: 0x893D,
	0xEE74: 0x893E,
	0xFFFD: 0x893F,
	0xFFFD: 0x8940,
	0xEE75: 0x8941,
	0xEE78: 0x8942,
	0xFD58: 0x8943,
	0xC1B8: 0x8944,
	0xFFFD: 0x8945,
	0xF0D6: 0x8946,
	0xFECF: 0x8947,
	0xFFFD: 0x8948,
	0xF0D9: 0x8949,
	0xFFFD: 0x894A,
	0xF0D3: 0x894B,
	0xF0D5: 0x894C,
	0xFD59: 0x894D,
	0xFFFD: 0x894E,
	0xF0D4: 0x894F,
	0xF0D7: 0x8950,
	0xF0D8: 0x8951,
	0xEE76: 0x8952,
	0xF0D2: 0x8953,
	0xFED0: 0x8954,
	0xFFFD: 0x8955,
	0xC3CD: 0x8956,
	0xF2EC: 0x8957,
	0xF2EF: 0x8958,
	0xF2F1: 0x8959,
	0xF2EA: 0x895A,
	0xF2EB: 0x895B,
	0xF2EE: 0x895C,
	0xF2F0: 0x895D,
	0xC3CE: 0x895E,
	0xC3CC: 0x895F,
	0xC3CB: 0x8960,
	0xF2ED: 0x8961,
	0xF2E9: 0x8962,
	0xF4CA: 0x8963,
	0xC4B0: 0x8964,
	0xFED1: 0x8965,
	0xF4CB: 0x8966,
	0xFFFD: 0x8967,
	0xFFFD: 0x8968,
	0xF649: 0x8969,
	0xC4FB: 0x896A,
	0xF64B: 0x896B,
	0xC4FC: 0x896C,
	0xF648: 0x896D,
	0xF64A: 0x896E,
	0xC5A8: 0x896F,
	0xFFFD: 0x8970,
	0xF752: 0x8971,
	0xC5A7: 0x8972,
	0xF7FD: 0x8973,
	0xF7FC: 0x8974,
	0xFFFD: 0x8975,
	0xF7FB: 0x8976,
	0x9172: 0x8977,
	0xFFFD: 0x8978,
	0xF948: 0x8979,
	0xF949: 0x897A,
	0xF94B: 0x897B,
	0xF94A: 0x897C,
	0xFFFD: 0x897D,
	0xCA50: 0x897E,
	0xA6E8: 0x897F,
	0xFED2: 0x8980,
	0xAD6E: 0x8981,
	0xD7C5: 0x8982,
	0xB5F7: 0x8983,
	0xFFFD: 0x8984,
	0xDFFA: 0x8985,
	0xC2D0: 0x8986,
	0x95F6: 0x8987,
	0xF2F2: 0x8988,
	0xFD6D: 0x8989,
	0xFD6E: 0x898A,
	0xA8A3: 0x898B,
	0xFFFD: 0x898C,
	0xFFFD: 0x898D,
	0xFFFD: 0x898E,
	0xB357: 0x898F,
	0xFFFD: 0x8990,
	0xFED3: 0x8991,
	0xFFFD: 0x8992,
	0xB356: 0x8993,
	0xFD6F: 0x8994,
	0xDBD0: 0x8995,
	0xB5F8: 0x8996,
	0xDBD2: 0x8997,
	0xDBD1: 0x8998,
	0xFFFD: 0x8999,
	0x9260: 0x899A,
	0xDFFB: 0x899B,
	0xB8D0: 0x899C,
	0xE443: 0x899D,
	0xE446: 0x899E,
	0xE445: 0x899F,
	0xFFFD: 0x89A0,
	0xE444: 0x89A1,
	0xE7CE: 0x89A2,
	0xE7D0: 0x89A3,
	0xE7CF: 0x89A4,
	0xFBAF: 0x89A5,
	0xBFCC: 0x89A6,
	0x93E1: 0x89A7,
	0xFFFD: 0x89A8,
	0x95C5: 0x89A9,
	0xBFCB: 0x89AA,
	0xFFFD: 0x89AB,
	0xC1BB: 0x89AC,
	0xEE79: 0x89AD,
	0xEE7B: 0x89AE,
	0xEE7A: 0x89AF,
	0xFFFD: 0x89B0,
	0xFFFD: 0x89B1,
	0xC2D1: 0x89B2,
	0x926D: 0x89B3,
	0xFFFD: 0x89B4,
	0xFFFD: 0x89B5,
	0xF2F4: 0x89B6,
	0xF2F3: 0x89B7,
	0xFFFD: 0x89B8,
	0xF4CC: 0x89B9,
	0xC4B1: 0x89BA,
	0xFFFD: 0x89BB,
	0xFD71: 0x89BC,
	0xC4FD: 0x89BD,
	0xF754: 0x89BE,
	0xF753: 0x89BF,
	0xC65B: 0x89C0,
	0x834E: 0x89C1,
	0x8D73: 0x89C2,
	0xFFFD: 0x89C3,
	0x847E: 0x89C4,
	0x847D: 0x89C5,
	0x8553: 0x89C6,
	0x8DE6: 0x89C7,
	0x8CA6: 0x89C8,
	0x8C54: 0x89C9,
	0x8A64: 0x89CA,
	0x8E7E: 0x89CB,
	0x905C: 0x89CC,
	0xFFFD: 0x89CD,
	0x895E: 0x89CE,
	0x8F63: 0x89CF,
	0x8AFC: 0x89D0,
	0x8FC6: 0x89D1,
	0xA8A4: 0x89D2,
	0xD0AF: 0x89D3,
	0xAD6F: 0x89D4,
	0xD7C8: 0x89D5,
	0xD7C6: 0x89D6,
	0xFFFD: 0x89D7,
	0xFFFD: 0x89D8,
	0xD7C7: 0x89D9,
	0xDBD4: 0x89DA,
	0xDBD5: 0x89DB,
	0xE043: 0x89DC,
	0xDBD3: 0x89DD,
	0x8AFD: 0x89DE,
	0xDFFC: 0x89DF,
	0xE041: 0x89E0,
	0xE040: 0x89E1,
	0xE042: 0x89E2,
	0xB8D1: 0x89E3,
	0xDFFE: 0x89E4,
	0xDFFD: 0x89E5,
	0xE044: 0x89E6,
	0x9173: 0x89E7,
	0xE449: 0x89E8,
	0xE447: 0x89E9,
	0xFFFD: 0x89EA,
	0xE448: 0x89EB,
	0xE7D3: 0x89EC,
	0xE7D1: 0x89ED,
	0xFFFD: 0x89EE,
	0x8FC7: 0x89EF,
	0xE7D2: 0x89F0,
	0xEB7D: 0x89F1,
	0xEE7C: 0x89F2,
	0xEE7D: 0x89F3,
	0xC2D2: 0x89F4,
	0xFFFD: 0x89F5,
	0xF2F5: 0x89F6,
	0xF4CD: 0x89F7,
	0xC4B2: 0x89F8,
	0xFFFD: 0x89F9,
	0xF64C: 0x89FA,
	0xF755: 0x89FB,
	0xC5A9: 0x89FC,
	0xFFFD: 0x89FD,
	0xF7FE: 0x89FE,
	0xF94C: 0x89FF,
	0xA8A5: 0x8A00,
	0xFFFD: 0x8A01,
	0xAD71: 0x8A02,
	0xAD72: 0x8A03,
	0xD0B0: 0x8A04,
	0xFFFD: 0x8A05,
	0xFFFD: 0x8A06,
	0xD0B1: 0x8A07,
	0xAD70: 0x8A08,
	0xFFFD: 0x8A09,
	0xB054: 0x8A0A,
	0xFFFD: 0x8A0B,
	0xB052: 0x8A0C,
	0xFFFD: 0x8A0D,
	0xB051: 0x8A0E,
	0xB058: 0x8A0F,
	0xB050: 0x8A10,
	0xB059: 0x8A11,
	0xD3DD: 0x8A12,
	0xB056: 0x8A13,
	0xFFFD: 0x8A14,
	0xB053: 0x8A15,
	0xB057: 0x8A16,
	0xB055: 0x8A17,
	0xB04F: 0x8A18,
	0xFFFD: 0x8A19,
	0xFFFD: 0x8A1A,
	0xB35F: 0x8A1B,
	0xFED4: 0x8A1C,
	0xB359: 0x8A1D,
	0xD7CC: 0x8A1E,
	0xB35E: 0x8A1F,
	0xFFFD: 0x8A20,
	0xFFFD: 0x8A21,
	0xB360: 0x8A22,
	0xB35A: 0x8A23,
	0xFFFD: 0x8A24,
	0xB35B: 0x8A25,
	0xFFFD: 0x8A26,
	0xD7CA: 0x8A27,
	0xFFFD: 0x8A28,
	0xFED5: 0x8A29,
	0xB358: 0x8A2A,
	0xFED6: 0x8A2B,
	0xD7CB: 0x8A2C,
	0xB35D: 0x8A2D,
	0xFFFD: 0x8A2E,
	0xFFFD: 0x8A2F,
	0xD7C9: 0x8A30,
	0xB35C: 0x8A31,
	0xFFFD: 0x8A32,
	0x93D5: 0x8A33,
	0xB644: 0x8A34,
	0xFFFD: 0x8A35,
	0xB646: 0x8A36,
	0x9174: 0x8A37,
	0xFED7: 0x8A38,
	0xDBD8: 0x8A39,
	0xB645: 0x8A3A,
	0xB5F9: 0x8A3B,
	0xB5FD: 0x8A3C,
	0xFED8: 0x8A3D,
	0xB8E4: 0x8A3E,
	0xE049: 0x8A3F,
	0xDBDA: 0x8A40,
	0xB5FE: 0x8A41,
	0xFFFD: 0x8A42,
	0xFFFD: 0x8A43,
	0xDBDD: 0x8A44,
	0xDBDE: 0x8A45,
	0xB643: 0x8A46,
	0xFFFD: 0x8A47,
	0xDBE0: 0x8A48,
	0xFD73: 0x8A49,
	0xDBE2: 0x8A4A,
	0xFFFD: 0x8A4B,
	0xDBE3: 0x8A4C,
	0xDBD7: 0x8A4D,
	0xDBD6: 0x8A4E,
	0xDBE4: 0x8A4F,
	0xB642: 0x8A50,
	0xDBE1: 0x8A51,
	0xDBDF: 0x8A52,
	0xFFFD: 0x8A53,
	0xB640: 0x8A54,
	0xB5FB: 0x8A55,
	0xB647: 0x8A56,
	0xDBDB: 0x8A57,
	0xDBDC: 0x8A58,
	0xDBD9: 0x8A59,
	0xFFFD: 0x8A5A,
	0xB641: 0x8A5B,
	0xFFFD: 0x8A5C,
	0xFFFD: 0x8A5D,
	0xB5FC: 0x8A5E,
	0xFFFD: 0x8A5F,
	0xB5FA: 0x8A60,
	0xE048: 0x8A61,
	0xB8DF: 0x8A62,
	0xB8DA: 0x8A63,
	0xFFFD: 0x8A64,
	0xFFFD: 0x8A65,
	0xB8D5: 0x8A66,
	0xFCDA: 0x8A67,
	0xB8E5: 0x8A68,
	0xB8D6: 0x8A69,
	0xFFFD: 0x8A6A,
	0xB8D2: 0x8A6B,
	0xB8E1: 0x8A6C,
	0xB8DE: 0x8A6D,
	0xB8E0: 0x8A6E,
	0xFFFD: 0x8A6F,
	0xB8D7: 0x8A70,
	0xB8DC: 0x8A71,
	0xB8D3: 0x8A72,
	0xB8D4: 0x8A73,
	0xE050: 0x8A74,
	0xE04D: 0x8A75,
	0xE045: 0x8A76,
	0xE04A: 0x8A77,
	0xFFFD: 0x8A78,
	0xB8E2: 0x8A79,
	0xE051: 0x8A7A,
	0xB8E3: 0x8A7B,
	0xB8D9: 0x8A7C,
	0xFFFD: 0x8A7D,
	0xFD72: 0x8A7E,
	0xE047: 0x8A7F,
	0xFFFD: 0x8A80,
	0xE04F: 0x8A81,
	0xE04B: 0x8A82,
	0xE04E: 0x8A83,
	0xE04C: 0x8A84,
	0xB8DD: 0x8A85,
	0xE046: 0x8A86,
	0xB8D8: 0x8A87,
	0xFFFD: 0x8A88,
	0x8CA9: 0x8A89,
	0x8A6C: 0x8A8A,
	0xE44C: 0x8A8B,
	0xBB78: 0x8A8C,
	0xBB7B: 0x8A8D,
	0xFFFD: 0x8A8E,
	0xE44E: 0x8A8F,
	0xFEDA: 0x8A90,
	0xBBA5: 0x8A91,
	0xE44D: 0x8A92,
	0xBB7D: 0x8A93,
	0xFEDB: 0x8A94,
	0xBDCF: 0x8A95,
	0xE44F: 0x8A96,
	0xFFFD: 0x8A97,
	0xBBA4: 0x8A98,
	0xE44B: 0x8A99,
	0xBBA6: 0x8A9A,
	0xFFFD: 0x8A9B,
	0xFEDC: 0x8A9C,
	0xFFFD: 0x8A9D,
	0xBB79: 0x8A9E,
	0xFFFD: 0x8A9F,
	0xB8DB: 0x8AA0,
	0xBB7C: 0x8AA1,
	0xFFFD: 0x8AA2,
	0xBB7A: 0x8AA3,
	0xBB7E: 0x8AA4,
	0xBBA2: 0x8AA5,
	0xBB77: 0x8AA6,
	0xBBA7: 0x8AA7,
	0xBBA3: 0x8AA8,
	0xFEDD: 0x8AA9,
	0xBBA1: 0x8AAA,
	0xE44A: 0x8AAB,
	0x9175: 0x8AAC,
	0x93AB: 0x8AAD,
	0xFFFD: 0x8AAE,
	0xFEDE: 0x8AAF,
	0xBDD6: 0x8AB0,
	0xFFFD: 0x8AB1,
	0xBDD2: 0x8AB2,
	0xFFFD: 0x8AB3,
	0xFEDF: 0x8AB4,
	0xFFFD: 0x8AB5,
	0xBDD9: 0x8AB6,
	0xFFFD: 0x8AB7,
	0xE7D6: 0x8AB8,
	0xBDDA: 0x8AB9,
	0xE7E2: 0x8ABA,
	0xE7DB: 0x8ABB,
	0xBDCB: 0x8ABC,
	0xE7E3: 0x8ABD,
	0xE7DD: 0x8ABE,
	0xBDD5: 0x8ABF,
	0xE7DE: 0x8AC0,
	0xFFFD: 0x8AC1,
	0xBDD4: 0x8AC2,
	0xE7E1: 0x8AC3,
	0xBDCE: 0x8AC4,
	0xE7DF: 0x8AC5,
	0xE7D5: 0x8AC6,
	0xBDCD: 0x8AC7,
	0xEBAA: 0x8AC8,
	0xBDD3: 0x8AC9,
	0xFFFD: 0x8ACA,
	0xBDD0: 0x8ACB,
	0x8251: 0x8ACC,
	0xBDD8: 0x8ACD,
	0xFFFD: 0x8ACE,
	0xE7D4: 0x8ACF,
	0xFFFD: 0x8AD0,
	0xE7D8: 0x8AD1,
	0xBDCC: 0x8AD2,
	0xE7D7: 0x8AD3,
	0xE7D9: 0x8AD4,
	0xE7DA: 0x8AD5,
	0xBDD7: 0x8AD6,
	0xE7DC: 0x8AD7,
	0xE7E0: 0x8AD8,
	0xE7E4: 0x8AD9,
	0x9176: 0x8ADA,
	0xBDDB: 0x8ADB,
	0xBFD2: 0x8ADC,
	0xEBA5: 0x8ADD,
	0xEBAB: 0x8ADE,
	0xEBA8: 0x8ADF,
	0xEB7E: 0x8AE0,
	0xEBAC: 0x8AE1,
	0xEBA1: 0x8AE2,
	0xFFFD: 0x8AE3,
	0xEBA7: 0x8AE4,
	0xFFFD: 0x8AE5,
	0xBFCD: 0x8AE6,
	0xBFD3: 0x8AE7,
	0xEBAD: 0x8AE8,
	0xFFFD: 0x8AE9,
	0xFEE0: 0x8AEA,
	0xBFCF: 0x8AEB,
	0xFFFD: 0x8AEC,
	0xBFD9: 0x8AED,
	0xBFD4: 0x8AEE,
	0xEBAF: 0x8AEF,
	0xEBA9: 0x8AF0,
	0xBFD0: 0x8AF1,
	0xEBA2: 0x8AF2,
	0xBFDA: 0x8AF3,
	0xEBA3: 0x8AF4,
	0xEBA4: 0x8AF5,
	0xBFDB: 0x8AF6,
	0xBFD8: 0x8AF7,
	0xBDD1: 0x8AF8,
	0x9DD1: 0x8AF9,
	0xBFCE: 0x8AFA,
	0xEBB0: 0x8AFB,
	0xBFDC: 0x8AFC,
	0xFFFD: 0x8AFD,
	0xBFD5: 0x8AFE,
	0xEBAE: 0x8AFF,
	0xBFD1: 0x8B00,
	0xBFD6: 0x8B01,
	0xBFD7: 0x8B02,
	0xFFFD: 0x8B03,
	0xC1C3: 0x8B04,
	0xEEA4: 0x8B05,
	0xEEAD: 0x8B06,
	0xEEAA: 0x8B07,
	0xEEAC: 0x8B08,
	0xFFFD: 0x8B09,
	0xC1C0: 0x8B0A,
	0xEEA5: 0x8B0B,
	0xFD74: 0x8B0C,
	0xEEAB: 0x8B0D,
	0xC1BC: 0x8B0E,
	0xEEA7: 0x8B0F,
	0xC1C4: 0x8B10,
	0xEEA3: 0x8B11,
	0xEEA8: 0x8B12,
	0xEEAF: 0x8B13,
	0xEBA6: 0x8B14,
	0xEEA9: 0x8B15,
	0xEEA2: 0x8B16,
	0xC1BD: 0x8B17,
	0xEEA1: 0x8B18,
	0xC1BE: 0x8B19,
	0xEEB0: 0x8B1A,
	0xC1BF: 0x8B1B,
	0xEEAE: 0x8B1C,
	0xC1C2: 0x8B1D,
	0xEE7E: 0x8B1E,
	0xFEE1: 0x8B1F,
	0xC1C1: 0x8B20,
	0x93DC: 0x8B21,
	0xEEA6: 0x8B22,
	0xF0DC: 0x8B23,
	0xF0EA: 0x8B24,
	0xF0E5: 0x8B25,
	0xF0E7: 0x8B26,
	0xF0DB: 0x8B27,
	0xC2D3: 0x8B28,
	0xFFFD: 0x8B29,
	0xF0DA: 0x8B2A,
	0xC2D6: 0x8B2B,
	0xC2D5: 0x8B2C,
	0x96C1: 0x8B2D,
	0xF0E9: 0x8B2E,
	0xF0E1: 0x8B2F,
	0xF0DE: 0x8B30,
	0xF0E4: 0x8B31,
	0xFFFD: 0x8B32,
	0xF0DD: 0x8B33,
	0xFFFD: 0x8B34,
	0xF0DF: 0x8B35,
	0xF0E8: 0x8B36,
	0xF0E6: 0x8B37,
	0xFFFD: 0x8B38,
	0xC2D4: 0x8B39,
	0xF0ED: 0x8B3A,
	0xF0EB: 0x8B3B,
	0xF0E2: 0x8B3C,
	0xF0EC: 0x8B3D,
	0xF0E3: 0x8B3E,
	0xFEE3: 0x8B3F,
	0xF2F9: 0x8B40,
	0xC3CF: 0x8B41,
	0xF341: 0x8B42,
	0xFD75: 0x8B43,
	0xFFFD: 0x8B44,
	0xF64F: 0x8B45,
	0xC3D6: 0x8B46,
	0xF0E0: 0x8B47,
	0xF2F7: 0x8B48,
	0xC3D2: 0x8B49,
	0xF2F8: 0x8B4A,
	0xF2FD: 0x8B4B,
	0xFD77: 0x8B4C,
	0xFEE4: 0x8B4D,
	0xC3D4: 0x8B4E,
	0xC3D5: 0x8B4F,
	0xF2F6: 0x8B50,
	0xF340: 0x8B51,
	0xF342: 0x8B52,
	0xF2FA: 0x8B53,
	0xF2FC: 0x8B54,
	0xF2FE: 0x8B55,
	0xF2FB: 0x8B56,
	0xF343: 0x8B57,
	0xC3D1: 0x8B58,
	0xC3D7: 0x8B59,
	0xC3D3: 0x8B5A,
	0x9177: 0x8B5B,
	0xC3D0: 0x8B5C,
	0xF4D0: 0x8B5D,
	0xFEE5: 0x8B5E,
	0xC4B7: 0x8B5F,
	0xF4CE: 0x8B60,
	0xFFFD: 0x8B61,
	0xFEE6: 0x8B62,
	0xF4D2: 0x8B63,
	0xFFFD: 0x8B64,
	0xF4D3: 0x8B65,
	0xC4B5: 0x8B66,
	0xF4D4: 0x8B67,
	0xF4D1: 0x8B68,
	0xFEE7: 0x8B69,
	0xF4CF: 0x8B6A,
	0xC4B8: 0x8B6B,
	0xC4B4: 0x8B6C,
	0xF4D5: 0x8B6D,
	0xFFFD: 0x8B6E,
	0xC4B6: 0x8B6F,
	0xC4B3: 0x8B70,
	0x9178: 0x8B71,
	0x92F0: 0x8B72,
	0xFFFD: 0x8B73,
	0xC4FE: 0x8B74,
	0xFFFD: 0x8B75,
	0xFFFD: 0x8B76,
	0xC540: 0x8B77,
	0xF64E: 0x8B78,
	0xF64D: 0x8B79,
	0xF650: 0x8B7A,
	0xF651: 0x8B7B,
	0xFFFD: 0x8B7C,
	0xC541: 0x8B7D,
	0xF756: 0x8B7E,
	0xF75B: 0x8B7F,
	0xC5AA: 0x8B80,
	0xFD76: 0x8B81,
	0xF758: 0x8B82,
	0x8263: 0x8B83,
	0xF757: 0x8B84,
	0xF75A: 0x8B85,
	0xF759: 0x8B86,
	0xFFFD: 0x8B87,
	0xF843: 0x8B88,
	0xFFFD: 0x8B89,
	0xC5DC: 0x8B8A,
	0xF842: 0x8B8B,
	0xF840: 0x8B8C,
	0xFFFD: 0x8B8D,
	0xF841: 0x8B8E,
	0xFFFD: 0x8B8F,
	0x95F8: 0x8B90,
	0xFFFD: 0x8B91,
	0xC5FE: 0x8B92,
	0xC5FD: 0x8B93,
	0xF8C1: 0x8B94,
	0xF8C2: 0x8B95,
	0xC640: 0x8B96,
	0xFFFD: 0x8B97,
	0xF94D: 0x8B98,
	0xF94E: 0x8B99,
	0xC667: 0x8B9A,
	0xFEE8: 0x8B9B,
	0xC66D: 0x8B9C,
	0xFFFD: 0x8B9D,
	0xF9A9: 0x8B9E,
	0xF9C8: 0x8B9F,
	0x9CEC: 0x8BA0,
	0x8379: 0x8BA1,
	0x837A: 0x8BA2,
	0x837B: 0x8BA3,
	0x8750: 0x8BA4,
	0x8BC2: 0x8BA5,
	0x83D4: 0x8BA6,
	0x83D6: 0x8BA7,
	0x83D5: 0x8BA8,
	0x8D58: 0x8BA9,
	0x83D7: 0x8BAA,
	0x83DA: 0x8BAB,
	0xFFFD: 0x8BAC,
	0x83D9: 0x8BAD,
	0x8C56: 0x8BAE,
	0x83D8: 0x8BAF,
	0x83D3: 0x8BB0,
	0xFFFD: 0x8BB1,
	0x8A68: 0x8BB2,
	0x8962: 0x8BB3,
	0x8F7E: 0x8BB4,
	0x8DE7: 0x8BB5,
	0x84A2: 0x8BB6,
	0x84A4: 0x8BB7,
	0x84A5: 0x8BB8,
	0x84A8: 0x8BB9,
	0x8862: 0x8BBA,
	0xFFFD: 0x8BBB,
	0x84A7: 0x8BBC,
	0x896A: 0x8BBD,
	0x84A6: 0x8BBE,
	0x84A1: 0x8BBF,
	0x84A3: 0x8BC0,
	0x8556: 0x8BC1,
	0x8557: 0x8BC2,
	0x855E: 0x8BC3,
	0x8554: 0x8BC4,
	0x8559: 0x8BC5,
	0x8BBF: 0x8BC6,
	0xFFFD: 0x8BC7,
	0x855A: 0x8BC8,
	0x855C: 0x8BC9,
	0x855D: 0x8BCA,
	0x855B: 0x8BCB,
	0x8F65: 0x8BCC,
	0x8555: 0x8BCD,
	0x8DE8: 0x8BCE,
	0x8558: 0x8BCF,
	0xFFFD: 0x8BD0,
	0x8C57: 0x8BD1,
	0x8DE9: 0x8BD2,
	0x8E4F: 0x8BD3,
	0x8E52: 0x8BD4,
	0x8649: 0x8BD5,
	0x8E50: 0x8BD6,
	0x864A: 0x8BD7,
	0x864B: 0x8BD8,
	0x864C: 0x8BD9,
	0x864E: 0x8BDA,
	0x8650: 0x8BDB,
	0x8E53: 0x8BDC,
	0x864F: 0x8BDD,
	0x885A: 0x8BDE,
	0x8654: 0x8BDF,
	0x8653: 0x8BE0,
	0x8651: 0x8BE1,
	0x8652: 0x8BE2,
	0x864D: 0x8BE3,
	0x8863: 0x8BE4,
	0x8647: 0x8BE5,
	0x8648: 0x8BE6,
	0x8646: 0x8BE7,
	0x8EF8: 0x8BE8,
	0x8E51: 0x8BE9,
	0xFFFD: 0x8BEA,
	0x8751: 0x8BEB,
	0x874F: 0x8BEC,
	0x874E: 0x8BED,
	0x8758: 0x8BEE,
	0x8752: 0x8BEF,
	0x8754: 0x8BF0,
	0x8756: 0x8BF1,
	0x8755: 0x8BF2,
	0x8757: 0x8BF3,
	0x8753: 0x8BF4,
	0x874D: 0x8BF5,
	0x8EA1: 0x8BF6,
	0x885B: 0x8BF7,
	0x885C: 0x8BF8,
	0x8ECB: 0x8BF9,
	0x8967: 0x8BFA,
	0x8CDD: 0x8BFB,
	0x8ECC: 0x8BFC,
	0x8865: 0x8BFD,
	0x885D: 0x8BFE,
	0x885E: 0x8BFF,
	0x8866: 0x8C00,
	0x8861: 0x8C01,
	0x8ECD: 0x8C02,
	0x8860: 0x8C03,
	0x885F: 0x8C04,
	0x8857: 0x8C05,
	0x8859: 0x8C06,
	0x8864: 0x8C07,
	0x8858: 0x8C08,
	0xFFFD: 0x8C09,
	0x8856: 0x8C0A,
	0x8963: 0x8C0B,
	0x896D: 0x8C0C,
	0x8964: 0x8C0D,
	0x8A69: 0x8C0E,
	0x8961: 0x8C0F,
	0x8965: 0x8C10,
	0x8EF9: 0x8C11,
	0x8968: 0x8C12,
	0x8969: 0x8C13,
	0x8EFA: 0x8C14,
	0x896B: 0x8C15,
	0x896E: 0x8C16,
	0x8D59: 0x8C17,
	0x8966: 0x8C18,
	0x896C: 0x8C19,
	0x8960: 0x8C1A,
	0x895F: 0x8C1B,
	0x8A65: 0x8C1C,
	0x8EFB: 0x8C1D,
	0xFFFD: 0x8C1E,
	0x8AFE: 0x8C1F,
	0x8DA4: 0x8C20,
	0x8F64: 0x8C21,
	0x8A6B: 0x8C22,
	0x8A6A: 0x8C23,
	0x8A66: 0x8C24,
	0x8F66: 0x8C25,
	0x8A67: 0x8C26,
	0x8A6D: 0x8C27,
	0x8B40: 0x8C28,
	0x8FA1: 0x8C29,
	0x8B42: 0x8C2A,
	0x9179: 0x8C2B,
	0x8B41: 0x8C2C,
	0x8BC0: 0x8C2D,
	0x8FC8: 0x8C2E,
	0x8BC3: 0x8C2F,
	0x9078: 0x8C30,
	0x8BBE: 0x8C31,
	0x8BC1: 0x8C32,
	0x90A6: 0x8C33,
	0x8CA7: 0x8C34,
	0x8C58: 0x8C35,
	0x8D5A: 0x8C36,
	0xA8A6: 0x8C37,
	0xFFFD: 0x8C38,
	0xD7CD: 0x8C39,
	0x917A: 0x8C3A,
	0xD7CE: 0x8C3B,
	0xE052: 0x8C3C,
	0xE450: 0x8C3D,
	0xE7E5: 0x8C3E,
	0xC1C6: 0x8C3F,
	0xFFFD: 0x8C40,
	0xC1C5: 0x8C41,
	0xF0EE: 0x8C42,
	0xF344: 0x8C43,
	0xFFFD: 0x8C44,
	0xF844: 0x8C45,
	0xA8A7: 0x8C46,
	0xD3DE: 0x8C47,
	0xB05A: 0x8C48,
	0xB361: 0x8C49,
	0xE054: 0x8C4A,
	0xE053: 0x8C4B,
	0xBDDC: 0x8C4C,
	0xE7E6: 0x8C4D,
	0xBDDD: 0x8C4E,
	0xEEB1: 0x8C4F,
	0xC2D7: 0x8C50,
	0xFEE9: 0x8C51,
	0xFFFD: 0x8C52,
	0xFFFD: 0x8C53,
	0xC676: 0x8C54,
	0xA8A8: 0x8C55,
	0xCDCB: 0x8C56,
	0xD3DF: 0x8C57,
	0xFFFD: 0x8C58,
	0xFFFD: 0x8C59,
	0xB362: 0x8C5A,
	0xFFFD: 0x8C5B,
	0xD7CF: 0x8C5C,
	0xD7D0: 0x8C5D,
	0xFFFD: 0x8C5E,
	0xDBE5: 0x8C5F,
	0xFFFD: 0x8C60,
	0xB648: 0x8C61,
	0xB8E6: 0x8C62,
	0xFFFD: 0x8C63,
	0xE056: 0x8C64,
	0xE055: 0x8C65,
	0xE057: 0x8C66,
	0xFFFD: 0x8C67,
	0xE451: 0x8C68,
	0xE452: 0x8C69,
	0xBBA8: 0x8C6A,
	0xBFDD: 0x8C6B,
	0xBDDE: 0x8C6C,
	0xBFDE: 0x8C6D,
	0xFFFD: 0x8C6E,
	0xEEB5: 0x8C6F,
	0xEEB2: 0x8C70,
	0xEEB4: 0x8C71,
	0xEEB3: 0x8C72,
	0xC1C7: 0x8C73,
	0xFFFD: 0x8C74,
	0xF0EF: 0x8C75,
	0xF346: 0x8C76,
	0xF345: 0x8C77,
	0xCBA4: 0x8C78,
	0xB05C: 0x8C79,
	0xB05B: 0x8C7A,
	0xD3E0: 0x8C7B,
	0x917B: 0x8C7C,
	0xD7D1: 0x8C7D,
	0xFFFD: 0x8C7E,
	0xFFFD: 0x8C7F,
	0xDBE7: 0x8C80,
	0xDBE6: 0x8C81,
	0xB649: 0x8C82,
	0xFFFD: 0x8C83,
	0xE059: 0x8C84,
	0xE05A: 0x8C85,
	0xE058: 0x8C86,
	0xFFFD: 0x8C87,
	0xFFFD: 0x8C88,
	0xB8E8: 0x8C89,
	0xB8E7: 0x8C8A,
	0xFFFD: 0x8C8B,
	0xBBAA: 0x8C8C,
	0xBBA9: 0x8C8D,
	0x917C: 0x8C8E,
	0xE7E7: 0x8C8F,
	0xEBB3: 0x8C90,
	0xEBB1: 0x8C91,
	0xEBB2: 0x8C92,
	0xBFDF: 0x8C93,
	0xEEB7: 0x8C94,
	0xEEB6: 0x8C95,
	0xFFFD: 0x8C96,
	0xF0F2: 0x8C97,
	0xF0F1: 0x8C98,
	0xF0F0: 0x8C99,
	0xF347: 0x8C9A,
	0xFEEA: 0x8C9B,
	0xF9AA: 0x8C9C,
	0xA8A9: 0x8C9D,
	0xAD73: 0x8C9E,
	0xFEEB: 0x8C9F,
	0xAD74: 0x8CA0,
	0xB05D: 0x8CA1,
	0xB05E: 0x8CA2,
	0xD3E2: 0x8CA3,
	0xD3E1: 0x8CA4,
	0xD7D2: 0x8CA5,
	0xFFFD: 0x8CA6,
	0xB368: 0x8CA7,
	0xB366: 0x8CA8,
	0xB363: 0x8CA9,
	0xB367: 0x8CAA,
	0xB365: 0x8CAB,
	0xB364: 0x8CAC,
	0xFD79: 0x8CAD,
	0x917D: 0x8CAE,
	0xB64A: 0x8CAF,
	0xDBEA: 0x8CB0,
	0xFFFD: 0x8CB1,
	0xB8ED: 0x8CB2,
	0xB64C: 0x8CB3,
	0xB651: 0x8CB4,
	0xDBEC: 0x8CB5,
	0xB653: 0x8CB6,
	0xB652: 0x8CB7,
	0xB655: 0x8CB8,
	0xDBEB: 0x8CB9,
	0xDBE8: 0x8CBA,
	0xB64F: 0x8CBB,
	0xB64B: 0x8CBC,
	0xB64D: 0x8CBD,
	0xDBE9: 0x8CBE,
	0xB654: 0x8CBF,
	0xB650: 0x8CC0,
	0xB64E: 0x8CC1,
	0xB8EF: 0x8CC2,
	0xB8EE: 0x8CC3,
	0xB8EC: 0x8CC4,
	0xB8F0: 0x8CC5,
	0xFFFD: 0x8CC6,
	0xB8EA: 0x8CC7,
	0xB8EB: 0x8CC8,
	0xFFFD: 0x8CC9,
	0xB8E9: 0x8CCA,
	0xFFFD: 0x8CCB,
	0xE05B: 0x8CCC,
	0x9560: 0x8CCD,
	0x8262: 0x8CCE,
	0xE454: 0x8CCF,
	0xFFFD: 0x8CD0,
	0xBBAC: 0x8CD1,
	0xBBAD: 0x8CD2,
	0xBBAB: 0x8CD3,
	0xFEEC: 0x8CD4,
	0xE453: 0x8CD5,
	0xFEED: 0x8CD6,
	0xE455: 0x8CD7,
	0xFFFD: 0x8CD8,
	0xE7EA: 0x8CD9,
	0xE7EC: 0x8CDA,
	0x92CE: 0x8CDB,
	0xBDE7: 0x8CDC,
	0xE7ED: 0x8CDD,
	0xBDE0: 0x8CDE,
	0xE7E9: 0x8CDF,
	0xBDDF: 0x8CE0,
	0xBDE9: 0x8CE1,
	0xBDE5: 0x8CE2,
	0xBDE6: 0x8CE3,
	0xBDE2: 0x8CE4,
	0xE7E8: 0x8CE5,
	0xBDE1: 0x8CE6,
	0xE7EE: 0x8CE7,
	0xE7EB: 0x8CE8,
	0x9E40: 0x8CE9,
	0xBDE8: 0x8CEA,
	0xFD7A: 0x8CEB,
	0xBDE3: 0x8CEC,
	0xBDE4: 0x8CED,
	0xEBB5: 0x8CEE,
	0xFFFD: 0x8CEF,
	0xEBB7: 0x8CF0,
	0xEBB6: 0x8CF1,
	0x9E41: 0x8CF2,
	0xEBB8: 0x8CF3,
	0xBFE0: 0x8CF4,
	0xEBB4: 0x8CF5,
	0xFFFD: 0x8CF6,
	0xFD7B: 0x8CF7,
	0xC1CB: 0x8CF8,
	0xEEB8: 0x8CF9,
	0xC1C8: 0x8CFA,
	0xC1CC: 0x8CFB,
	0xC1CA: 0x8CFC,
	0xC1C9: 0x8CFD,
	0xF0F3: 0x8CFE,
	0xFFFD: 0x8CFF,
	0xF0F6: 0x8D00,
	0xFFFD: 0x8D01,
	0xF0F5: 0x8D02,
	0x9E42: 0x8D03,
	0xF0F4: 0x8D04,
	0xC2D8: 0x8D05,
	0xF348: 0x8D06,
	0xF349: 0x8D07,
	0xC3D8: 0x8D08,
	0xF34A: 0x8D09,
	0xC3D9: 0x8D0A,
	0x8257: 0x8D0B,
	0xFD7C: 0x8D0C,
	0xC4BA: 0x8D0D,
	0xFFFD: 0x8D0E,
	0xC4B9: 0x8D0F,
	0xF652: 0x8D10,
	0x9E43: 0x8D11,
	0x917E: 0x8D12,
	0xC542: 0x8D13,
	0xF653: 0x8D14,
	0xF75C: 0x8D15,
	0xC5AB: 0x8D16,
	0xC5AC: 0x8D17,
	0x9576: 0x8D18,
	0xF845: 0x8D19,
	0xFFFD: 0x8D1A,
	0xC642: 0x8D1B,
	0x9E44: 0x8D1C,
	0x8350: 0x8D1D,
	0x837C: 0x8D1E,
	0x837D: 0x8D1F,
	0xFFFD: 0x8D20,
	0x83DD: 0x8D21,
	0x83DC: 0x8D22,
	0x84AA: 0x8D23,
	0x886E: 0x8D24,
	0x8450: 0x8D25,
	0x886C: 0x8D26,
	0x84AC: 0x8D27,
	0x8871: 0x8D28,
	0x84A9: 0x8D29,
	0x84AD: 0x8D2A,
	0x84AE: 0x8D2B,
	0x8568: 0x8D2C,
	0x8A70: 0x8D2D,
	0x855F: 0x8D2E,
	0x84AB: 0x8D2F,
	0x8561: 0x8D30,
	0x886B: 0x8D31,
	0x8563: 0x8D32,
	0x8DEB: 0x8D33,
	0x8560: 0x8D34,
	0x8566: 0x8D35,
	0x8DEA: 0x8D36,
	0x856A: 0x8D37,
	0x8569: 0x8D38,
	0x8564: 0x8D39,
	0x8565: 0x8D3A,
	0x8562: 0x8D3B,
	0x8655: 0x8D3C,
	0x8FA3: 0x8D3D,
	0x8657: 0x8D3E,
	0x8658: 0x8D3F,
	0x8659: 0x8D40,
	0x865A: 0x8D41,
	0x865B: 0x8D42,
	0x8CAA: 0x8D43,
	0x8656: 0x8D44,
	0x865C: 0x8D45,
	0x9047: 0x8D46,
	0x8EA2: 0x8D47,
	0x875A: 0x8D48,
	0x91A1: 0x8D49,
	0x875B: 0x8D4A,
	0x886A: 0x8D4B,
	0x886D: 0x8D4C,
	0x91A2: 0x8D4D,
	0x8CDE: 0x8D4E,
	0x8869: 0x8D4F,
	0x8870: 0x8D50,
	0xFFFD: 0x8D51,
	0xFFFD: 0x8D52,
	0x8872: 0x8D53,
	0x8868: 0x8D54,
	0x8ECE: 0x8D55,
	0x896F: 0x8D56,
	0xFFFD: 0x8D57,
	0x8B43: 0x8D58,
	0x8A71: 0x8D59,
	0x8A6E: 0x8D5A,
	0x8A6F: 0x8D5B,
	0x8FA2: 0x8D5C,
	0x8CDF: 0x8D5D,
	0x8BC5: 0x8D5E,
	0xFFFD: 0x8D5F,
	0x8BC4: 0x8D60,
	0x8C5A: 0x8D61,
	0x8C59: 0x8D62,
	0x8D5C: 0x8D63,
	0xA8AA: 0x8D64,
	0xFFFD: 0x8D65,
	0xB36A: 0x8D66,
	0xB369: 0x8D67,
	0xE05C: 0x8D68,
	0xE05D: 0x8D69,
	0xFFFD: 0x8D6A,
	0xBBAE: 0x8D6B,
	0xEBB9: 0x8D6C,
	0xBDEA: 0x8D6D,
	0xEBBA: 0x8D6E,
	0xEEB9: 0x8D6F,
	0xA8AB: 0x8D70,
	0x91A3: 0x8D71,
	0xD0B2: 0x8D72,
	0xAD76: 0x8D73,
	0xAD75: 0x8D74,
	0x875C: 0x8D75,
	0xD3E3: 0x8D76,
	0xB05F: 0x8D77,
	0xD3E4: 0x8D78,
	0xD7D5: 0x8D79,
	0x9E45: 0x8D7A,
	0xD7D4: 0x8D7B,
	0xFFFD: 0x8D7C,
	0xD7D3: 0x8D7D,
	0xFFFD: 0x8D7E,
	0xFFFD: 0x8D7F,
	0xDBEE: 0x8D80,
	0xB658: 0x8D81,
	0xFD7D: 0x8D82,
	0xFFFD: 0x8D83,
	0xDBED: 0x8D84,
	0xB657: 0x8D85,
	0xFFFD: 0x8D86,
	0xFFFD: 0x8D87,
	0xFFFD: 0x8D88,
	0xDBEF: 0x8D89,
	0xB656: 0x8D8A,
	0x8A72: 0x8D8B,
	0xE05F: 0x8D8C,
	0xE062: 0x8D8D,
	0xE060: 0x8D8E,
	0xE061: 0x8D8F,
	0xE065: 0x8D90,
	0xE05E: 0x8D91,
	0xE066: 0x8D92,
	0xE063: 0x8D93,
	0xE064: 0x8D94,
	0xBBB0: 0x8D95,
	0xE456: 0x8D96,
	0xFFFD: 0x8D97,
	0xFFFD: 0x8D98,
	0xBBAF: 0x8D99,
	0xFFFD: 0x8D9A,
	0xE7F2: 0x8D9B,
	0xE7F0: 0x8D9C,
	0xFFFD: 0x8D9D,
	0xFFFD: 0x8D9E,
	0xBDEB: 0x8D9F,
	0xE7EF: 0x8DA0,
	0xE7F1: 0x8DA1,
	0xFFFD: 0x8DA2,
	0xBDEC: 0x8DA3,
	0xFFFD: 0x8DA4,
	0xEBBB: 0x8DA5,
	0xFD7E: 0x8DA6,
	0xEBBC: 0x8DA7,
	0xC1CD: 0x8DA8,
	0x9E46: 0x8DA9,
	0xF34C: 0x8DAA,
	0xF34E: 0x8DAB,
	0xF34B: 0x8DAC,
	0xF34D: 0x8DAD,
	0xF4D6: 0x8DAE,
	0xF654: 0x8DAF,
	0xFFFD: 0x8DB0,
	0x90A3: 0x8DB1,
	0xF96F: 0x8DB2,
	0xA8AC: 0x8DB3,
	0xAD77: 0x8DB4,
	0xD3E5: 0x8DB5,
	0xD3E7: 0x8DB6,
	0xD3E6: 0x8DB7,
	0x8C5B: 0x8DB8,
	0xD7D8: 0x8DB9,
	0xB36C: 0x8DBA,
	0xFFFD: 0x8DBB,
	0xD7D6: 0x8DBC,
	0xFFFD: 0x8DBD,
	0xB36B: 0x8DBE,
	0xD7D9: 0x8DBF,
	0x9E47: 0x8DC0,
	0xD7DA: 0x8DC1,
	0xD7D7: 0x8DC2,
	0x8CAC: 0x8DC3,
	0x8F67: 0x8DC4,
	0xDBFB: 0x8DC5,
	0xB660: 0x8DC6,
	0xDBF3: 0x8DC7,
	0xDBF9: 0x8DC8,
	0xFFFD: 0x8DC9,
	0xFFFD: 0x8DCA,
	0xB65B: 0x8DCB,
	0xB65E: 0x8DCC,
	0xDBF2: 0x8DCD,
	0xB659: 0x8DCE,
	0xDBF6: 0x8DCF,
	0xE06C: 0x8DD0,
	0xB65D: 0x8DD1,
	0xFFFD: 0x8DD2,
	0xDBF1: 0x8DD3,
	0xFDA1: 0x8DD4,
	0xDBF7: 0x8DD5,
	0xDBF4: 0x8DD6,
	0xDBFA: 0x8DD7,
	0xDBF0: 0x8DD8,
	0xDBF8: 0x8DD9,
	0xB65C: 0x8DDA,
	0xB65F: 0x8DDB,
	0xDBF5: 0x8DDC,
	0xB65A: 0x8DDD,
	0x905E: 0x8DDE,
	0xB8F2: 0x8DDF,
	0xE068: 0x8DE0,
	0xB8F1: 0x8DE1,
	0xE06F: 0x8DE2,
	0xE06E: 0x8DE3,
	0xB8F8: 0x8DE4,
	0xFFFD: 0x8DE5,
	0xB8F9: 0x8DE6,
	0xE070: 0x8DE7,
	0xB8F3: 0x8DE8,
	0xE06D: 0x8DE9,
	0xB8F7: 0x8DEA,
	0xE072: 0x8DEB,
	0xE069: 0x8DEC,
	0xFFFD: 0x8DED,
	0xE06B: 0x8DEE,
	0xB8F4: 0x8DEF,
	0xE067: 0x8DF0,
	0xE06A: 0x8DF1,
	0xE071: 0x8DF2,
	0xB8F5: 0x8DF3,
	0xE073: 0x8DF4,
	0x8873: 0x8DF5,
	0xFFFD: 0x8DF6,
	0x8BC6: 0x8DF7,
	0x8B46: 0x8DF8,
	0x905D: 0x8DF9,
	0xB8F6: 0x8DFA,
	0x8CAD: 0x8DFB,
	0xBBB1: 0x8DFC,
	0xE45B: 0x8DFD,
	0xE461: 0x8DFE,
	0xE459: 0x8DFF,
	0xE462: 0x8E00,
	0x9E48: 0x8E01,
	0xE458: 0x8E02,
	0xE45D: 0x8E03,
	0xE463: 0x8E04,
	0xE460: 0x8E05,
	0xE45F: 0x8E06,
	0xE45E: 0x8E07,
	0x91A4: 0x8E08,
	0xE457: 0x8E09,
	0xE45C: 0x8E0A,
	0xFFFD: 0x8E0B,
	0x8CAB: 0x8E0C,
	0xE45A: 0x8E0D,
	0x9E49: 0x8E0E,
	0xBDF1: 0x8E0F,
	0xBDEE: 0x8E10,
	0xE7FB: 0x8E11,
	0xE841: 0x8E12,
	0xE843: 0x8E13,
	0xE840: 0x8E14,
	0xE7F8: 0x8E15,
	0xE7FA: 0x8E16,
	0xE845: 0x8E17,
	0xE842: 0x8E18,
	0xE7FC: 0x8E19,
	0xE846: 0x8E1A,
	0xE7F9: 0x8E1B,
	0xE844: 0x8E1C,
	0xBDEF: 0x8E1D,
	0xBDF5: 0x8E1E,
	0xBDF3: 0x8E1F,
	0xE7F3: 0x8E20,
	0xBDF4: 0x8E21,
	0xBDF0: 0x8E22,
	0xE7F4: 0x8E23,
	0xE7F6: 0x8E24,
	0xE7F5: 0x8E25,
	0xE7FD: 0x8E26,
	0xE7FE: 0x8E27,
	0xFDA2: 0x8E28,
	0xBDF2: 0x8E29,
	0x9557: 0x8E2A,
	0xBDED: 0x8E2B,
	0x8CE1: 0x8E2C,
	0xFB6D: 0x8E2D,
	0xE7F7: 0x8E2E,
	0x8CE0: 0x8E2F,
	0xEBC6: 0x8E30,
	0xBFE2: 0x8E31,
	0xFFFD: 0x8E32,
	0xEBBD: 0x8E33,
	0xBFE3: 0x8E34,
	0xBFE6: 0x8E35,
	0xEBC2: 0x8E36,
	0xFFFD: 0x8E37,
	0xEBBF: 0x8E38,
	0xBFE5: 0x8E39,
	0x91A5: 0x8E3A,
	0xFFFD: 0x8E3B,
	0xEBC3: 0x8E3C,
	0xEBC4: 0x8E3D,
	0xEBBE: 0x8E3E,
	0xEBC7: 0x8E3F,
	0xEBC0: 0x8E40,
	0xEBC5: 0x8E41,
	0xBFE4: 0x8E42,
	0xFFFD: 0x8E43,
	0xBFE1: 0x8E44,
	0xEBC1: 0x8E45,
	0x9E4A: 0x8E46,
	0xEEBF: 0x8E47,
	0xC1D0: 0x8E48,
	0xC1CE: 0x8E49,
	0xC1D1: 0x8E4A,
	0xC1CF: 0x8E4B,
	0xEEBE: 0x8E4C,
	0xEEBB: 0x8E4D,
	0xEEBA: 0x8E4E,
	0xFDA3: 0x8E4F,
	0xEEBD: 0x8E50,
	0x8D74: 0x8E51,
	0x8B44: 0x8E52,
	0xEEBC: 0x8E53,
	0xF145: 0x8E54,
	0xC2DE: 0x8E55,
	0xF0FB: 0x8E56,
	0xF0FA: 0x8E57,
	0xFFFD: 0x8E58,
	0xC2D9: 0x8E59,
	0xF141: 0x8E5A,
	0xF140: 0x8E5B,
	0xF0F7: 0x8E5C,
	0xF143: 0x8E5D,
	0xF0FC: 0x8E5E,
	0xC2DD: 0x8E5F,
	0xF0F9: 0x8E60,
	0xF142: 0x8E61,
	0xF0F8: 0x8E62,
	0xC2DA: 0x8E63,
	0xC2DC: 0x8E64,
	0xF0FD: 0x8E65,
	0xC2DB: 0x8E66,
	0xF0FE: 0x8E67,
	0x9E4B: 0x8E68,
	0xF144: 0x8E69,
	0xF352: 0x8E6A,
	0xFFFD: 0x8E6B,
	0xC3DE: 0x8E6C,
	0xF34F: 0x8E6D,
	0xFFFD: 0x8E6E,
	0xF353: 0x8E6F,
	0x91A6: 0x8E70,
	0x9E4C: 0x8E71,
	0xC3DB: 0x8E72,
	0xF351: 0x8E73,
	0xC3E0: 0x8E74,
	0xFDA5: 0x8E75,
	0xC3DD: 0x8E76,
	0xFDA4: 0x8E77,
	0xF350: 0x8E78,
	0xFFFD: 0x8E79,
	0xC3DF: 0x8E7A,
	0xF354: 0x8E7B,
	0xC3DA: 0x8E7C,
	0xFFFD: 0x8E7D,
	0x9E4D: 0x8E7E,
	0x907E: 0x8E7F,
	0x9E4E: 0x8E80,
	0xC4BC: 0x8E81,
	0xC4BE: 0x8E82,
	0xFFFD: 0x8E83,
	0xF4D9: 0x8E84,
	0xC4BD: 0x8E85,
	0xF4D7: 0x8E86,
	0xC3DC: 0x8E87,
	0xF4D8: 0x8E88,
	0xC4BB: 0x8E89,
	0xC543: 0x8E8A,
	0xC545: 0x8E8B,
	0xF656: 0x8E8C,
	0xC544: 0x8E8D,
	0xF655: 0x8E8E,
	0x8DA5: 0x8E8F,
	0xF761: 0x8E90,
	0xC5AD: 0x8E91,
	0xF760: 0x8E92,
	0xC5AE: 0x8E93,
	0xF75E: 0x8E94,
	0xF75D: 0x8E95,
	0xF762: 0x8E96,
	0xF763: 0x8E97,
	0xF846: 0x8E98,
	0x91A7: 0x8E99,
	0xF75F: 0x8E9A,
	0xFFFD: 0x8E9B,
	0x90A4: 0x8E9C,
	0xF8C6: 0x8E9D,
	0xF8C3: 0x8E9E,
	0xF8C4: 0x8E9F,
	0xF8C5: 0x8EA0,
	0xC65C: 0x8EA1,
	0xFFFD: 0x8EA2,
	0xF951: 0x8EA3,
	0xF950: 0x8EA4,
	0xF94F: 0x8EA5,
	0xF970: 0x8EA6,
	0xFDA6: 0x8EA7,
	0xF9BE: 0x8EA8,
	0xF9AB: 0x8EA9,
	0xC66E: 0x8EAA,
	0xA8AD: 0x8EAB,
	0xB060: 0x8EAC,
	0x95DF: 0x8EAD,
	0xFFFD: 0x8EAE,
	0x8249: 0x8EAF,
	0x91A8: 0x8EB0,
	0x91A9: 0x8EB1,
	0xB8FA: 0x8EB2,
	0xFFFD: 0x8EB3,
	0xFFFD: 0x8EB4,
	0xFFFD: 0x8EB5,
	0x9E4F: 0x8EB6,
	0xFFFD: 0x8EB7,
	0xFFFD: 0x8EB8,
	0x9E50: 0x8EB9,
	0xBDF6: 0x8EBA,
	0xFFFD: 0x8EBB,
	0x9E51: 0x8EBC,
	0xEBC8: 0x8EBD,
	0x94D3: 0x8EBE,
	0xFFFD: 0x8EBF,
	0xC2DF: 0x8EC0,
	0xFFFD: 0x8EC1,
	0xF355: 0x8EC2,
	0x9E52: 0x8EC3,
	0xFFFD: 0x8EC4,
	0x91AA: 0x8EC5,
	0x91AB: 0x8EC6,
	0xFFFD: 0x8EC7,
	0x94D4: 0x8EC8,
	0xF9AC: 0x8EC9,
	0xA8AE: 0x8ECA,
	0xAAEE: 0x8ECB,
	0xAD79: 0x8ECC,
	0xAD78: 0x8ECD,
	0x91AC: 0x8ECE,
	0xB063: 0x8ECF,
	0xFFFD: 0x8ED0,
	0xD3E8: 0x8ED1,
	0xB061: 0x8ED2,
	0xD3E9: 0x8ED3,
	0xB062: 0x8ED4,
	0xFFFD: 0x8ED5,
	0xFFFD: 0x8ED6,
	0xD7DF: 0x8ED7,
	0xD7DB: 0x8ED8,
	0xFFFD: 0x8ED9,
	0xFBA1: 0x8EDA,
	0xB36D: 0x8EDB,
	0xD7DE: 0x8EDC,
	0xD7DD: 0x8EDD,
	0xD7DC: 0x8EDE,
	0xB36E: 0x8EDF,
	0xD7E0: 0x8EE0,
	0xD7E1: 0x8EE1,
	0x937D: 0x8EE2,
	0x91AD: 0x8EE3,
	0x9E53: 0x8EE4,
	0xDC43: 0x8EE5,
	0xDC41: 0x8EE6,
	0xDC45: 0x8EE7,
	0xDC46: 0x8EE8,
	0xDC4C: 0x8EE9,
	0xFFFD: 0x8EEA,
	0xDC48: 0x8EEB,
	0xDC4A: 0x8EEC,
	0x9E54: 0x8EED,
	0xDC42: 0x8EEE,
	0xDBFC: 0x8EEF,
	0xFFFD: 0x8EF0,
	0xDC49: 0x8EF1,
	0x9E55: 0x8EF2,
	0xFFFD: 0x8EF3,
	0xDC4B: 0x8EF4,
	0xDC44: 0x8EF5,
	0xDC47: 0x8EF6,
	0xDBFD: 0x8EF7,
	0xB662: 0x8EF8,
	0xDC40: 0x8EF9,
	0xDBFE: 0x8EFA,
	0xB661: 0x8EFB,
	0xB663: 0x8EFC,
	0x92AD: 0x8EFD,
	0xB8FD: 0x8EFE,
	0xE075: 0x8EFF,
	0xE077: 0x8F00,
	0xE076: 0x8F01,
	0xE07B: 0x8F02,
	0xB8FB: 0x8F03,
	0xFFFD: 0x8F04,
	0xE078: 0x8F05,
	0xE074: 0x8F06,
	0xE079: 0x8F07,
	0xE07A: 0x8F08,
	0xB8FC: 0x8F09,
	0xB8FE: 0x8F0A,
	0xE07C: 0x8F0B,
	0x91AE: 0x8F0C,
	0xE467: 0x8F0D,
	0xE466: 0x8F0E,
	0xFFFD: 0x8F0F,
	0xE464: 0x8F10,
	0xE465: 0x8F11,
	0xBBB3: 0x8F12,
	0xBBB5: 0x8F13,
	0xBBB2: 0x8F14,
	0xBBB4: 0x8F15,
	0xE84D: 0x8F16,
	0xE84E: 0x8F17,
	0xE849: 0x8F18,
	0xFDA7: 0x8F19,
	0xE84A: 0x8F1A,
	0xBDF8: 0x8F1B,
	0xBDFD: 0x8F1C,
	0xBDF7: 0x8F1D,
	0xBDFE: 0x8F1E,
	0xBDF9: 0x8F1F,
	0xE84B: 0x8F20,
	0xFFFD: 0x8F21,
	0xFFFD: 0x8F22,
	0xE84C: 0x8F23,
	0xE848: 0x8F24,
	0xBE40: 0x8F25,
	0xBDFB: 0x8F26,
	0xFFFD: 0x8F27,
	0xFFFD: 0x8F28,
	0xBDFA: 0x8F29,
	0xBDFC: 0x8F2A,
	0xFFFD: 0x8F2B,
	0xE847: 0x8F2C,
	0x9570: 0x8F2D,
	0xEBCA: 0x8F2E,
	0xBFE8: 0x8F2F,
	0x9E56: 0x8F30,
	0xFFFD: 0x8F31,
	0xEBCC: 0x8F32,
	0xBFEA: 0x8F33,
	0xEBCF: 0x8F34,
	0xEBCB: 0x8F35,
	0xEBC9: 0x8F36,
	0xEBCE: 0x8F37,
	0xBFE9: 0x8F38,
	0xEBCD: 0x8F39,
	0xFFFD: 0x8F3A,
	0xBFE7: 0x8F3B,
	0xFFFD: 0x8F3C,
	0xFFFD: 0x8F3D,
	0xC1D3: 0x8F3E,
	0xC1D6: 0x8F3F,
	0xEEC1: 0x8F40,
	0x9E57: 0x8F41,
	0xC1D4: 0x8F42,
	0xEEC0: 0x8F43,
	0xC1D2: 0x8F44,
	0xC1D5: 0x8F45,
	0xF146: 0x8F46,
	0xF147: 0x8F47,
	0xF148: 0x8F48,
	0xC2E0: 0x8F49,
	0x9E58: 0x8F4A,
	0xF149: 0x8F4B,
	0x94D5: 0x8F4C,
	0xC2E1: 0x8F4D,
	0xC3E2: 0x8F4E,
	0xF358: 0x8F4F,
	0xF359: 0x8F50,
	0xF357: 0x8F51,
	0xF356: 0x8F52,
	0xF35A: 0x8F53,
	0xC3E1: 0x8F54,
	0xF4DD: 0x8F55,
	0xF4DB: 0x8F56,
	0xF4DC: 0x8F57,
	0xF4DE: 0x8F58,
	0xF4DA: 0x8F59,
	0xF4DF: 0x8F5A,
	0xF658: 0x8F5B,
	0xFDA9: 0x8F5C,
	0xF659: 0x8F5D,
	0xF657: 0x8F5E,
	0xC546: 0x8F5F,
	0xF764: 0x8F60,
	0xC5AF: 0x8F61,
	0xF765: 0x8F62,
	0xF848: 0x8F63,
	0xF847: 0x8F64,
	0xFFFD: 0x8F65,
	0x8351: 0x8F66,
	0x8361: 0x8F67,
	0x83A1: 0x8F68,
	0x83DE: 0x8F69,
	0xFFFD: 0x8F6A,
	0x83DF: 0x8F6B,
	0x8B48: 0x8F6C,
	0x84AF: 0x8F6D,
	0x8879: 0x8F6E,
	0x84B0: 0x8F6F,
	0x8CAE: 0x8F70,
	0x91AF: 0x8F71,
	0x856B: 0x8F72,
	0x906E: 0x8F73,
	0x856C: 0x8F74,
	0x8DED: 0x8F75,
	0x856D: 0x8F76,
	0x91B0: 0x8F77,
	0x8DEE: 0x8F78,
	0x905F: 0x8F79,
	0x8DEC: 0x8F7A,
	0x8760: 0x8F7B,
	0x865F: 0x8F7C,
	0x865E: 0x8F7D,
	0x8660: 0x8F7E,
	0x8BC8: 0x8F7F,
	0xFFFD: 0x8F80,
	0x8E56: 0x8F81,
	0x8E55: 0x8F82,
	0x865D: 0x8F83,
	0x875F: 0x8F84,
	0x875E: 0x8F85,
	0x8875: 0x8F86,
	0x8878: 0x8F87,
	0x8877: 0x8F88,
	0x8874: 0x8F89,
	0x887C: 0x8F8A,
	0x887B: 0x8F8B,
	0xFFFD: 0x8F8C,
	0x8876: 0x8F8D,
	0x887A: 0x8F8E,
	0x8973: 0x8F8F,
	0x8970: 0x8F90,
	0x8971: 0x8F91,
	0xFFFD: 0x8F92,
	0x8972: 0x8F93,
	0x8CE2: 0x8F94,
	0x8A76: 0x8F95,
	0x8A73: 0x8F96,
	0x8A74: 0x8F97,
	0x8FA4: 0x8F98,
	0x8B49: 0x8F99,
	0x8BC7: 0x8F9A,
	0xA8AF: 0x8F9B,
	0xB664: 0x8F9C,
	0xFFFD: 0x8F9D,
	0x8BC9: 0x8F9E,
	0xB940: 0x8F9F,
	0xFD41: 0x8FA0,
	0xFFFD: 0x8FA1,
	0xFFFD: 0x8FA2,
	0xBBB6: 0x8FA3,
	0xFFFD: 0x8FA4,
	0x9E59: 0x8FA5,
	0xBFEC: 0x8FA6,
	0x91B1: 0x8FA7,
	0xBFEB: 0x8FA8,
	0x8CAF: 0x8FA9,
	0xFFFD: 0x8FAA,
	0x8C47: 0x8FAB,
	0xFFFD: 0x8FAC,
	0xC3E3: 0x8FAD,
	0xC47C: 0x8FAE,
	0xC547: 0x8FAF,
	0xA8B0: 0x8FB0,
	0xB064: 0x8FB1,
	0xB941: 0x8FB2,
	0x9E5A: 0x8FB3,
	0xF35B: 0x8FB4,
	0xC6D6: 0x8FB5,
	0x9CE0: 0x8FB6,
	0x94D6: 0x8FB7,
	0x9E5B: 0x8FB8,
	0x8BCA: 0x8FB9,
	0x93C3: 0x8FBA,
	0x944E: 0x8FBB,
	0x9444: 0x8FBC,
	0x8977: 0x8FBD,
	0x8663: 0x8FBE,
	0xCBA6: 0x8FBF,
	0xFFFD: 0x8FC0,
	0x887E: 0x8FC1,
	0xA8B1: 0x8FC2,
	0xFFFD: 0x8FC3,
	0xA8B4: 0x8FC4,
	0xA8B3: 0x8FC5,
	0xA8B2: 0x8FC6,
	0x8665: 0x8FC7,
	0x8A79: 0x8FC8,
	0xCBA5: 0x8FC9,
	0x9E5C: 0x8FCA,
	0xCDCD: 0x8FCB,
	0xA0A4: 0x8FCC,
	0xCDCF: 0x8FCD,
	0xAAEF: 0x8FCE,
	0x9E5D: 0x8FCF,
	0x8662: 0x8FD0,
	0xAAF1: 0x8FD1,
	0xCDCC: 0x8FD2,
	0xCDCE: 0x8FD3,
	0xAAF0: 0x8FD4,
	0xCDD1: 0x8FD5,
	0xCDD0: 0x8FD6,
	0xCDD2: 0x8FD7,
	0x8A78: 0x8FD8,
	0x84B1: 0x8FD9,
	0x94D7: 0x8FDA,
	0x856E: 0x8FDB,
	0x8761: 0x8FDC,
	0x8664: 0x8FDD,
	0x84B2: 0x8FDE,
	0x8976: 0x8FDF,
	0xD0B6: 0x8FE0,
	0xD0B4: 0x8FE1,
	0xAD7C: 0x8FE2,
	0xD0B3: 0x8FE3,
	0xADA3: 0x8FE4,
	0xAD7E: 0x8FE5,
	0xAD7B: 0x8FE6,
	0xFFFD: 0x8FE7,
	0xADA4: 0x8FE8,
	0x8B4A: 0x8FE9,
	0xAD7D: 0x8FEA,
	0xADA2: 0x8FEB,
	0xFFFD: 0x8FEC,
	0xADA1: 0x8FED,
	0xD0B5: 0x8FEE,
	0x91B2: 0x8FEF,
	0xAD7A: 0x8FF0,
	0xFFFD: 0x8FF1,
	0xFFFD: 0x8FF2,
	0x84B3: 0x8FF3,
	0xB06A: 0x8FF4,
	0xD3EB: 0x8FF5,
	0xD3F1: 0x8FF6,
	0xB067: 0x8FF7,
	0xB06E: 0x8FF8,
	0x95D9: 0x8FF9,
	0xB069: 0x8FFA,
	0xD3EE: 0x8FFB,
	0xD3F0: 0x8FFC,
	0xB06C: 0x8FFD,
	0xD3EA: 0x8FFE,
	0xD3ED: 0x8FFF,
	0xB068: 0x9000,
	0xB065: 0x9001,
	0xD3EC: 0x9002,
	0xB06B: 0x9003,
	0xD3EF: 0x9004,
	0xB06D: 0x9005,
	0xB066: 0x9006,
	0xFFFD: 0x9007,
	0x9E5E: 0x9008,
	0x8975: 0x9009,
	0x8762: 0x900A,
	0xD7E3: 0x900B,
	0xD7E6: 0x900C,
	0xB370: 0x900D,
	0x91B3: 0x900E,
	0xB37A: 0x900F,
	0xB376: 0x9010,
	0xD7E4: 0x9011,
	0x8763: 0x9012,
	0x937A: 0x9013,
	0xB37E: 0x9014,
	0xB377: 0x9015,
	0xB37C: 0x9016,
	0xB372: 0x9017,
	0xFFFD: 0x9018,
	0xB36F: 0x9019,
	0xB371: 0x901A,
	0xB37D: 0x901B,
	0xD7E5: 0x901C,
	0xB375: 0x901D,
	0xB378: 0x901E,
	0xB374: 0x901F,
	0xB379: 0x9020,
	0xD7E7: 0x9021,
	0xB37B: 0x9022,
	0xB373: 0x9023,
	0xD7E2: 0x9024,
	0xFFFD: 0x9025,
	0x8D41: 0x9026,
	0x94D8: 0x9027,
	0xFFFD: 0x9028,
	0xFFFD: 0x9029,
	0xFFFD: 0x902A,
	0xFFFD: 0x902B,
	0xFFFD: 0x902C,
	0xDC4D: 0x902D,
	0xB665: 0x902E,
	0xDC4F: 0x902F,
	0xFFFD: 0x9030,
	0xB667: 0x9031,
	0xB669: 0x9032,
	0x9E5F: 0x9033,
	0xDC4E: 0x9034,
	0xB666: 0x9035,
	0xB66A: 0x9036,
	0x9E60: 0x9037,
	0xB668: 0x9038,
	0x91B4: 0x9039,
	0xFFFD: 0x903A,
	0x8D42: 0x903B,
	0xB947: 0x903C,
	0xE0A3: 0x903D,
	0xB94F: 0x903E,
	0xE07E: 0x903F,
	0xFFFD: 0x9040,
	0xB950: 0x9041,
	0xB945: 0x9042,
	0xFFFD: 0x9043,
	0xE0A1: 0x9044,
	0x9372: 0x9045,
	0xFFFD: 0x9046,
	0xB94A: 0x9047,
	0xFFFD: 0x9048,
	0xE0A2: 0x9049,
	0xB943: 0x904A,
	0xB942: 0x904B,
	0xFDB6: 0x904C,
	0xB94D: 0x904D,
	0xB94C: 0x904E,
	0xB94B: 0x904F,
	0xB949: 0x9050,
	0xB94E: 0x9051,
	0xE07D: 0x9052,
	0xB944: 0x9053,
	0xB946: 0x9054,
	0xB948: 0x9055,
	0xFDB5: 0x9056,
	0x8978: 0x9057,
	0xBBB8: 0x9058,
	0xBBBB: 0x9059,
	0xFFFD: 0x905A,
	0xBBBF: 0x905B,
	0xBBB9: 0x905C,
	0xBBBE: 0x905D,
	0xBBBC: 0x905E,
	0xFFFD: 0x905F,
	0xBBB7: 0x9060,
	0xFE61: 0x9061,
	0xBBBD: 0x9062,
	0xBBBA: 0x9063,
	0x9E61: 0x9064,
	0x91B5: 0x9065,
	0xFFFD: 0x9066,
	0xE852: 0x9067,
	0xBE43: 0x9068,
	0xBE41: 0x9069,
	0xFFFD: 0x906A,
	0xE853: 0x906B,
	0x9E62: 0x906C,
	0xBE44: 0x906D,
	0xBE42: 0x906E,
	0xE851: 0x906F,
	0xE850: 0x9070,
	0xFFFD: 0x9071,
	0xBFF0: 0x9072,
	0xE84F: 0x9073,
	0xBFEE: 0x9074,
	0xBFED: 0x9075,
	0xEBD0: 0x9076,
	0xBE45: 0x9077,
	0xBFEF: 0x9078,
	0xEBD1: 0x9079,
	0xBFF2: 0x907A,
	0xEBD2: 0x907B,
	0xBFF1: 0x907C,
	0xC1D8: 0x907D,
	0xEEC3: 0x907E,
	0xC1D7: 0x907F,
	0xC1DC: 0x9080,
	0xC1DA: 0x9081,
	0xC1DB: 0x9082,
	0xC2E3: 0x9083,
	0xC1D9: 0x9084,
	0xEEC2: 0x9085,
	0xEBD3: 0x9086,
	0xC2E2: 0x9087,
	0xC2E4: 0x9088,
	0x91B6: 0x9089,
	0xC3E4: 0x908A,
	0xC3E5: 0x908B,
	0xFFFD: 0x908C,
	0xF4E0: 0x908D,
	0xFFFD: 0x908E,
	0xC5DE: 0x908F,
	0xC5DD: 0x9090,
	0xA8B6: 0x9091,
	0xFFFD: 0x9092,
	0x88A3: 0x9093,
	0xCA55: 0x9094,
	0xB06F: 0x9095,
	0xFFFD: 0x9096,
	0xCA52: 0x9097,
	0xCA53: 0x9098,
	0xCA51: 0x9099,
	0xFFFD: 0x909A,
	0xCA54: 0x909B,
	0xFFFD: 0x909C,
	0x8FA5: 0x909D,
	0xCBAA: 0x909E,
	0xCBA7: 0x909F,
	0xCBAC: 0x90A0,
	0xCBA8: 0x90A1,
	0xA8B7: 0x90A2,
	0xA8BA: 0x90A3,
	0xFFFD: 0x90A4,
	0xCBA9: 0x90A5,
	0xA8B9: 0x90A6,
	0xCBAB: 0x90A7,
	0x9540: 0x90A8,
	0xFFFD: 0x90A9,
	0xA8B8: 0x90AA,
	0xFFFD: 0x90AB,
	0x8E57: 0x90AC,
	0xFFFD: 0x90AD,
	0x856F: 0x90AE,
	0xCDD5: 0x90AF,
	0xCDD7: 0x90B0,
	0xAAF4: 0x90B1,
	0xCDD3: 0x90B2,
	0xCDD6: 0x90B3,
	0xCDD4: 0x90B4,
	0xAAF2: 0x90B5,
	0xAAF5: 0x90B6,
	0xFFFD: 0x90B7,
	0xAAF3: 0x90B8,
	0x8666: 0x90B9,
	0x8979: 0x90BA,
	0x88A1: 0x90BB,
	0xFFFD: 0x90BC,
	0xD0B8: 0x90BD,
	0xD0BC: 0x90BE,
	0xD0B9: 0x90BF,
	0xFFFD: 0x90C0,
	0xADA7: 0x90C1,
	0xFFFD: 0x90C2,
	0xADA8: 0x90C3,
	0xFDAB: 0x90C4,
	0xD0BB: 0x90C5,
	0xFFFD: 0x90C6,
	0xD0BD: 0x90C7,
	0xD0BF: 0x90C8,
	0xFFFD: 0x90C9,
	0xADA5: 0x90CA,
	0xD0BE: 0x90CB,
	0xFFFD: 0x90CC,
	0xFFFD: 0x90CD,
	0xADA6: 0x90CE,
	0x8DC6: 0x90CF,
	0x8EFC: 0x90D0,
	0x88A2: 0x90D1,
	0xFFFD: 0x90D2,
	0x8DF0: 0x90D3,
	0xD7EE: 0x90D4,
	0xD0BA: 0x90D5,
	0xD3F2: 0x90D6,
	0xD3FB: 0x90D7,
	0xD3F9: 0x90D8,
	0xD3F4: 0x90D9,
	0xD3F5: 0x90DA,
	0xD3FA: 0x90DB,
	0xD3FC: 0x90DC,
	0xB071: 0x90DD,
	0x91B7: 0x90DE,
	0xD3F7: 0x90DF,
	0xD3F3: 0x90E0,
	0xB070: 0x90E1,
	0xB072: 0x90E2,
	0xD3F6: 0x90E3,
	0xD3FD: 0x90E4,
	0xD3F8: 0x90E5,
	0x8CE3: 0x90E6,
	0x90BB: 0x90E7,
	0xB3A1: 0x90E8,
	0xD7F1: 0x90E9,
	0xD7E9: 0x90EA,
	0xD7EF: 0x90EB,
	0xD7F0: 0x90EC,
	0xB3A2: 0x90ED,
	0xFFFD: 0x90EE,
	0xD7E8: 0x90EF,
	0xD7EA: 0x90F0,
	0xD0B7: 0x90F1,
	0xD7EC: 0x90F2,
	0xD7ED: 0x90F3,
	0xD7EB: 0x90F4,
	0xB66C: 0x90F5,
	0xFFFD: 0x90F6,
	0x927B: 0x90F7,
	0x8ECF: 0x90F8,
	0xDC56: 0x90F9,
	0xEBD4: 0x90FA,
	0xDC57: 0x90FB,
	0xDC54: 0x90FC,
	0xB3A3: 0x90FD,
	0xB66E: 0x90FE,
	0xDC53: 0x90FF,
	0xDC59: 0x9100,
	0xDC58: 0x9101,
	0xB66B: 0x9102,
	0xDC5C: 0x9103,
	0xDC52: 0x9104,
	0xDC5B: 0x9105,
	0xDC50: 0x9106,
	0xDC5A: 0x9107,
	0xDC55: 0x9108,
	0xB66D: 0x9109,
	0xFFFD: 0x910A,
	0xE0AA: 0x910B,
	0xFFFD: 0x910C,
	0xE0A5: 0x910D,
	0xE0AB: 0x910E,
	0xE0A6: 0x910F,
	0xE0A4: 0x9110,
	0xE0A7: 0x9111,
	0xB951: 0x9112,
	0xFFFD: 0x9113,
	0xE0A9: 0x9114,
	0x91B8: 0x9115,
	0xE0A8: 0x9116,
	0xB952: 0x9117,
	0xBBC1: 0x9118,
	0xBBC0: 0x9119,
	0xE46E: 0x911A,
	0xE471: 0x911B,
	0xE469: 0x911C,
	0xE46D: 0x911D,
	0xBBC2: 0x911E,
	0xE46C: 0x911F,
	0xE46A: 0x9120,
	0xE470: 0x9121,
	0xE46B: 0x9122,
	0xE468: 0x9123,
	0xE46F: 0x9124,
	0xFFFD: 0x9125,
	0xE859: 0x9126,
	0xBE48: 0x9127,
	0xF14A: 0x9128,
	0xE856: 0x9129,
	0xE857: 0x912A,
	0xE855: 0x912B,
	0xDC51: 0x912C,
	0xBE47: 0x912D,
	0xE85A: 0x912E,
	0xE854: 0x912F,
	0xBE46: 0x9130,
	0xBE49: 0x9131,
	0xE858: 0x9132,
	0xEBD5: 0x9133,
	0xBFF3: 0x9134,
	0xEBD6: 0x9135,
	0xEBD7: 0x9136,
	0xFFFD: 0x9137,
	0xEEC4: 0x9138,
	0xC1DD: 0x9139,
	0xF14B: 0x913A,
	0xF14C: 0x913B,
	0xFFFD: 0x913C,
	0xFFFD: 0x913D,
	0xF14D: 0x913E,
	0xF35D: 0x913F,
	0xF35C: 0x9140,
	0xF4E2: 0x9141,
	0xFFFD: 0x9142,
	0xF4E1: 0x9143,
	0xF65B: 0x9144,
	0xF65C: 0x9145,
	0xF65A: 0x9146,
	0xF766: 0x9147,
	0xC5B0: 0x9148,
	0xA8BB: 0x9149,
	0xADAA: 0x914A,
	0xADA9: 0x914B,
	0xB075: 0x914C,
	0xB074: 0x914D,
	0xD440: 0x914E,
	0xD441: 0x914F,
	0xD3FE: 0x9150,
	0xFDAC: 0x9151,
	0xB073: 0x9152,
	0xD7F5: 0x9153,
	0x92F8: 0x9154,
	0xD7F6: 0x9155,
	0xD7F2: 0x9156,
	0xB3A4: 0x9157,
	0xD7F3: 0x9158,
	0xFDAF: 0x9159,
	0xD7F4: 0x915A,
	0xFFFD: 0x915B,
	0xFDAE: 0x915C,
	0x8A7A: 0x915D,
	0x96A8: 0x915E,
	0xDC5F: 0x915F,
	0xDC61: 0x9160,
	0xDC5D: 0x9161,
	0xDC60: 0x9162,
	0xB66F: 0x9163,
	0xDC5E: 0x9164,
	0xB670: 0x9165,
	0xFFFD: 0x9166,
	0xFDB0: 0x9167,
	0xDD73: 0x9168,
	0xB955: 0x9169,
	0xB954: 0x916A,
	0xFFFD: 0x916B,
	0xB953: 0x916C,
	0xFFFD: 0x916D,
	0xE0AC: 0x916E,
	0xE0AD: 0x916F,
	0x96A9: 0x9170,
	0x8B4C: 0x9171,
	0xE473: 0x9172,
	0xE475: 0x9173,
	0xBBC6: 0x9174,
	0xBBC3: 0x9175,
	0x96A1: 0x9176,
	0xBBC5: 0x9177,
	0xBBC4: 0x9178,
	0xE474: 0x9179,
	0xE472: 0x917A,
	0xFFFD: 0x917B,
	0xFDB1: 0x917C,
	0x8DA6: 0x917D,
	0x90A5: 0x917E,
	0x8D5D: 0x917F,
	0xE861: 0x9180,
	0xE85E: 0x9181,
	0xE85F: 0x9182,
	0xBE4D: 0x9183,
	0xE860: 0x9184,
	0xE85B: 0x9185,
	0xE85C: 0x9186,
	0xBE4A: 0x9187,
	0xFFFD: 0x9188,
	0xBE4B: 0x9189,
	0xE85D: 0x918A,
	0xBE4C: 0x918B,
	0x96AA: 0x918C,
	0xEBDB: 0x918D,
	0xFDB2: 0x918E,
	0xEBDC: 0x918F,
	0xEBD9: 0x9190,
	0xEBDA: 0x9191,
	0xBFF4: 0x9192,
	0xEBD8: 0x9193,
	0xFFFD: 0x9194,
	0xFFFD: 0x9195,
	0xFFFD: 0x9196,
	0x8279: 0x9197,
	0xFFFD: 0x9198,
	0xEEC8: 0x9199,
	0xEEC5: 0x919A,
	0xEEC7: 0x919B,
	0xC1E0: 0x919C,
	0xEECB: 0x919D,
	0xC1DF: 0x919E,
	0xEEC9: 0x919F,
	0xEECC: 0x91A0,
	0xEECA: 0x91A1,
	0xEEC6: 0x91A2,
	0xC1DE: 0x91A3,
	0x8266: 0x91A4,
	0xF14F: 0x91A5,
	0xFFFD: 0x91A6,
	0xF150: 0x91A7,
	0xF14E: 0x91A8,
	0x9E63: 0x91A9,
	0xF152: 0x91AA,
	0xC2E5: 0x91AB,
	0xC2E6: 0x91AC,
	0xF35F: 0x91AD,
	0xC3E7: 0x91AE,
	0xF151: 0x91AF,
	0xF35E: 0x91B0,
	0xC3E6: 0x91B1,
	0xF4E5: 0x91B2,
	0xF4E6: 0x91B3,
	0xC4BF: 0x91B4,
	0xF4E4: 0x91B5,
	0x9E64: 0x91B6,
	0xF4E3: 0x91B7,
	0x92F1: 0x91B8,
	0xF65D: 0x91B9,
	0xC548: 0x91BA,
	0xFDB3: 0x91BB,
	0xF849: 0x91BC,
	0xF8C8: 0x91BD,
	0xF8C7: 0x91BE,
	0xFFFD: 0x91BF,
	0xC643: 0x91C0,
	0xC65D: 0x91C1,
	0xF8C9: 0x91C2,
	0xF971: 0x91C3,
	0x9E65: 0x91C4,
	0xC66F: 0x91C5,
	0xA8BC: 0x91C6,
	0xAAF6: 0x91C7,
	0x92D8: 0x91C8,
	0xB956: 0x91C9,
	0x8C5C: 0x91CA,
	0xC4C0: 0x91CB,
	0xA8BD: 0x91CC,
	0xADAB: 0x91CD,
	0xB3A5: 0x91CE,
	0xB671: 0x91CF,
	0xC2E7: 0x91D0,
	0xAAF7: 0x91D1,
	0xFFFD: 0x91D2,
	0xD0C1: 0x91D3,
	0xD0C0: 0x91D4,
	0xD442: 0x91D5,
	0x91B9: 0x91D6,
	0xB078: 0x91D7,
	0xB076: 0x91D8,
	0xB07A: 0x91D9,
	0xD444: 0x91DA,
	0x91BA: 0x91DB,
	0xB079: 0x91DC,
	0xB077: 0x91DD,
	0x91BB: 0x91DE,
	0x9649: 0x91DF,
	0xFFFD: 0x91E0,
	0x91BC: 0x91E1,
	0xD443: 0x91E2,
	0xB3A8: 0x91E3,
	0xD7FC: 0x91E4,
	0x91BD: 0x91E5,
	0xB3A7: 0x91E6,
	0xB3A9: 0x91E7,
	0xD842: 0x91E8,
	0xB3AB: 0x91E9,
	0xD7FE: 0x91EA,
	0xD840: 0x91EB,
	0xD7F7: 0x91EC,
	0xB3AA: 0x91ED,
	0xD843: 0x91EE,
	0xFFFD: 0x91EF,
	0xFFFD: 0x91F0,
	0xD7F9: 0x91F1,
	0xFFFD: 0x91F2,
	0xD7FA: 0x91F3,
	0xD7F8: 0x91F4,
	0xB3A6: 0x91F5,
	0x91BE: 0x91F6,
	0xD841: 0x91F7,
	0xD7FB: 0x91F8,
	0xD7FD: 0x91F9,
	0x9E66: 0x91FA,
	0xFFFD: 0x91FB,
	0x91BF: 0x91FC,
	0xDC6D: 0x91FD,
	0xFDB7: 0x91FE,
	0xDC6C: 0x91FF,
	0xDC6A: 0x9200,
	0xDC62: 0x9201,
	0xDC71: 0x9202,
	0xDC65: 0x9203,
	0xDC6F: 0x9204,
	0xDC76: 0x9205,
	0xDC6E: 0x9206,
	0xB679: 0x9207,
	0x9E67: 0x9208,
	0xB675: 0x9209,
	0xDC63: 0x920A,
	0xFFFD: 0x920B,
	0xDC69: 0x920C,
	0xB677: 0x920D,
	0x954C: 0x920E,
	0xDC68: 0x920F,
	0xB678: 0x9210,
	0xB67A: 0x9211,
	0xDC6B: 0x9212,
	0x9E68: 0x9213,
	0xB672: 0x9214,
	0xB673: 0x9215,
	0xDC77: 0x9216,
	0xDC75: 0x9217,
	0xFFFD: 0x9218,
	0xDC74: 0x9219,
	0xDC66: 0x921A,
	0xFFFD: 0x921B,
	0xDC72: 0x921C,
	0xFFFD: 0x921D,
	0xB676: 0x921E,
	0xFFFD: 0x921F,
	0xFFFD: 0x9220,
	0x9E69: 0x9221,
	0xFFFD: 0x9222,
	0xB674: 0x9223,
	0xDC73: 0x9224,
	0xDC64: 0x9225,
	0xDC67: 0x9226,
	0xDC70: 0x9227,
	0x9E6A: 0x9228,
	0x91C0: 0x9229,
	0xFB5F: 0x922A,
	0x9E6B: 0x922B,
	0x91C1: 0x922C,
	0xE4BA: 0x922D,
	0xE0B7: 0x922E,
	0xFFFD: 0x922F,
	0xE0B0: 0x9230,
	0xE0C3: 0x9231,
	0xE0CC: 0x9232,
	0xE0B3: 0x9233,
	0xB961: 0x9234,
	0x9E6C: 0x9235,
	0xE0C0: 0x9236,
	0xB957: 0x9237,
	0xB959: 0x9238,
	0xB965: 0x9239,
	0xE0B1: 0x923A,
	0xFFFD: 0x923B,
	0x9E6D: 0x923C,
	0xB95A: 0x923D,
	0xB95C: 0x923E,
	0xB966: 0x923F,
	0xB95B: 0x9240,
	0x9E6E: 0x9241,
	0xFFFD: 0x9242,
	0xFFFD: 0x9243,
	0x937B: 0x9244,
	0xB964: 0x9245,
	0xE0B9: 0x9246,
	0xFFFD: 0x9247,
	0xE0AE: 0x9248,
	0xB962: 0x9249,
	0xE0B8: 0x924A,
	0xB95E: 0x924B,
	0xE0CA: 0x924C,
	0xB963: 0x924D,
	0xE0C8: 0x924E,
	0xE0BC: 0x924F,
	0xE0C6: 0x9250,
	0xB960: 0x9251,
	0xE0AF: 0x9252,
	0xE0C9: 0x9253,
	0xE0C4: 0x9254,
	0x9640: 0x9255,
	0xE0CB: 0x9256,
	0xB958: 0x9257,
	0x9E6F: 0x9258,
	0x91C3: 0x9259,
	0xB967: 0x925A,
	0xB95D: 0x925B,
	0xFFFD: 0x925C,
	0x9E70: 0x925D,
	0xE0B5: 0x925E,
	0x9E71: 0x925F,
	0xE0BD: 0x9260,
	0xE0C1: 0x9261,
	0x95F1: 0x9262,
	0xE0C5: 0x9263,
	0xB95F: 0x9264,
	0xE0B4: 0x9265,
	0xE0B2: 0x9266,
	0xE0BE: 0x9267,
	0xFFFD: 0x9268,
	0xFFFD: 0x9269,
	0xFFFD: 0x926A,
	0x9E72: 0x926B,
	0xE0BB: 0x926C,
	0xE0BA: 0x926D,
	0x9E73: 0x926E,
	0xE0BF: 0x926F,
	0xE0C2: 0x9270,
	0x92C0: 0x9271,
	0xE0C7: 0x9272,
	0x9643: 0x9273,
	0x8CE5: 0x9274,
	0xFFFD: 0x9275,
	0xE478: 0x9276,
	0x91C4: 0x9277,
	0xBBC7: 0x9278,
	0xE4A4: 0x9279,
	0xE47A: 0x927A,
	0xBBCC: 0x927B,
	0xBBD0: 0x927C,
	0xE4AD: 0x927D,
	0xE4B5: 0x927E,
	0xE4A6: 0x927F,
	0xBBC8: 0x9280,
	0x9E74: 0x9281,
	0xE4AA: 0x9282,
	0xE0B6: 0x9283,
	0x9E75: 0x9284,
	0xBBC9: 0x9285,
	0xE4B1: 0x9286,
	0xE4B6: 0x9287,
	0xE4AE: 0x9288,
	0x9E76: 0x9289,
	0xE4B0: 0x928A,
	0xE4B9: 0x928B,
	0xE4B2: 0x928C,
	0xE47E: 0x928D,
	0xE4A9: 0x928E,
	0x9E77: 0x928F,
	0xFFFD: 0x9290,
	0xBBD1: 0x9291,
	0xFFFD: 0x9292,
	0xBBCD: 0x9293,
	0xE47C: 0x9294,
	0xE4AB: 0x9295,
	0xBBCB: 0x9296,
	0xE4A5: 0x9297,
	0xBBCA: 0x9298,
	0xE4B3: 0x9299,
	0xE4A2: 0x929A,
	0xE479: 0x929B,
	0xBBCE: 0x929C,
	0xE4B8: 0x929D,
	0xFFFD: 0x929E,
	0xFFFD: 0x929F,
	0xE47B: 0x92A0,
	0xE4AF: 0x92A1,
	0xE4AC: 0x92A2,
	0xE4A7: 0x92A3,
	0xE477: 0x92A4,
	0xE476: 0x92A5,
	0xE4A1: 0x92A6,
	0xE4B4: 0x92A7,
	0xBBCF: 0x92A8,
	0xE4B7: 0x92A9,
	0xE47D: 0x92AA,
	0xE4A3: 0x92AB,
	0xBE52: 0x92AC,
	0x934B: 0x92AD,
	0x8DA8: 0x92AE,
	0xFFFD: 0x92AF,
	0xFFFD: 0x92B0,
	0x9E78: 0x92B1,
	0xBE5A: 0x92B2,
	0xBE55: 0x92B3,
	0xE8A4: 0x92B4,
	0xE8A1: 0x92B5,
	0xE867: 0x92B6,
	0xBE50: 0x92B7,
	0xFFFD: 0x92B8,
	0xF9D7: 0x92B9,
	0x9E79: 0x92BA,
	0xBE4F: 0x92BB,
	0xBE56: 0x92BC,
	0xFFFD: 0x92BD,
	0xFDB9: 0x92BE,
	0x9E7A: 0x92BF,
	0xE865: 0x92C0,
	0xBE54: 0x92C1,
	0xE871: 0x92C2,
	0xE863: 0x92C3,
	0xE864: 0x92C4,
	0xBE4E: 0x92C5,
	0xE8A3: 0x92C6,
	0xBE58: 0x92C7,
	0xE874: 0x92C8,
	0xE879: 0x92C9,
	0xE873: 0x92CA,
	0xEBEE: 0x92CB,
	0xE86F: 0x92CC,
	0xE877: 0x92CD,
	0xE875: 0x92CE,
	0xE868: 0x92CF,
	0xE862: 0x92D0,
	0xE87D: 0x92D1,
	0xBE57: 0x92D2,
	0xE87E: 0x92D3,
	0x9E7B: 0x92D4,
	0xE878: 0x92D5,
	0xFFFD: 0x92D6,
	0xE86D: 0x92D7,
	0xE86B: 0x92D8,
	0xE866: 0x92D9,
	0xFFFD: 0x92DA,
	0x9E7C: 0x92DB,
	0xFFFD: 0x92DC,
	0xE86E: 0x92DD,
	0xE87B: 0x92DE,
	0xE86A: 0x92DF,
	0xE87A: 0x92E0,
	0xE8A2: 0x92E1,
	0xFFFD: 0x92E2,
	0x9E7D: 0x92E3,
	0xBE53: 0x92E4,
	0x9E7E: 0x92E5,
	0xE876: 0x92E6,
	0xE87C: 0x92E7,
	0xE872: 0x92E8,
	0xE86C: 0x92E9,
	0xBE51: 0x92EA,
	0x9EA1: 0x92EB,
	0x9EA2: 0x92EC,
	0x91C5: 0x92ED,
	0xE4A8: 0x92EE,
	0xE870: 0x92EF,
	0xBE59: 0x92F0,
	0xE869: 0x92F1,
	0x9458: 0x92F2,
	0x9374: 0x92F3,
	0x9EA3: 0x92F4,
	0xFFFD: 0x92F5,
	0x9EA4: 0x92F6,
	0xEBF4: 0x92F7,
	0xBFF7: 0x92F8,
	0xEBF3: 0x92F9,
	0xEBF0: 0x92FA,
	0xEC44: 0x92FB,
	0xBFFB: 0x92FC,
	0x9EA5: 0x92FD,
	0xEC41: 0x92FE,
	0xEBF8: 0x92FF,
	0xEC43: 0x9300,
	0xEBE9: 0x9301,
	0xEBF6: 0x9302,
	0x9EA6: 0x9303,
	0xBFFD: 0x9304,
	0xFFFD: 0x9305,
	0xEBE1: 0x9306,
	0x9EA7: 0x9307,
	0xEBDF: 0x9308,
	0xEC42: 0x9309,
	0xFFFD: 0x930A,
	0xEC40: 0x930B,
	0xEBFE: 0x930C,
	0xEBED: 0x930D,
	0xEBEC: 0x930E,
	0xEBE2: 0x930F,
	0xC040: 0x9310,
	0xFFFD: 0x9311,
	0xEBE8: 0x9312,
	0xEBF2: 0x9313,
	0xEBFD: 0x9314,
	0xC043: 0x9315,
	0xEC45: 0x9316,
	0xFFFD: 0x9317,
	0xC1E8: 0x9318,
	0xC045: 0x9319,
	0xBFFE: 0x931A,
	0xEBE6: 0x931B,
	0xFFFD: 0x931C,
	0xEBEF: 0x931D,
	0xEBDE: 0x931E,
	0xEBE0: 0x931F,
	0xBFF5: 0x9320,
	0xC042: 0x9321,
	0xBFFA: 0x9322,
	0xEBE7: 0x9323,
	0xEBF7: 0x9324,
	0xEBF1: 0x9325,
	0xC041: 0x9326,
	0xEBDD: 0x9327,
	0xC1E3: 0x9328,
	0xEBF9: 0x9329,
	0xEBFC: 0x932A,
	0xBFFC: 0x932B,
	0x93F3: 0x932C,
	0xEBEB: 0x932D,
	0xC044: 0x932E,
	0xBFF9: 0x932F,
	0x9EA8: 0x9330,
	0x9EA9: 0x9331,
	0x93F7: 0x9332,
	0xBFF8: 0x9333,
	0xEBF5: 0x9334,
	0xEBFB: 0x9335,
	0xBFF6: 0x9336,
	0xFFFD: 0x9337,
	0xEBE4: 0x9338,
	0xEBFA: 0x9339,
	0x91C6: 0x933A,
	0x94DB: 0x933B,
	0xEBE5: 0x933C,
	0xFFFD: 0x933D,
	0x8BD6: 0x933E,
	0xFFFD: 0x933F,
	0x9EAA: 0x9340,
	0xFE7C: 0x9341,
	0x9EAB: 0x9342,
	0x9EAC: 0x9343,
	0x9755: 0x9344,
	0x9642: 0x9345,
	0xEBEA: 0x9346,
	0xEED2: 0x9347,
	0xFE79: 0x9348,
	0xEED7: 0x9349,
	0xC1E5: 0x934A,
	0xC1E7: 0x934B,
	0xEEDD: 0x934C,
	0xC1E1: 0x934D,
	0xEEEC: 0x934E,
	0xEEE3: 0x934F,
	0xEED8: 0x9350,
	0xEED9: 0x9351,
	0xEEE2: 0x9352,
	0xFFFD: 0x9353,
	0xC1EE: 0x9354,
	0xEEE1: 0x9355,
	0xEED1: 0x9356,
	0xEEE0: 0x9357,
	0xEED4: 0x9358,
	0xEEED: 0x9359,
	0xC1ED: 0x935A,
	0xC1EB: 0x935B,
	0xEED5: 0x935C,
	0xFFFD: 0x935D,
	0xEEE8: 0x935E,
	0x9EAD: 0x935F,
	0xEEDA: 0x9360,
	0xEEE7: 0x9361,
	0x9EAE: 0x9362,
	0xEEE9: 0x9363,
	0xEED0: 0x9364,
	0xC1E6: 0x9365,
	0x9EAF: 0x9366,
	0xEEEA: 0x9367,
	0x9EB0: 0x9368,
	0x9644: 0x9369,
	0xEEDE: 0x936A,
	0xFDBA: 0x936B,
	0xC1EA: 0x936C,
	0xEEDB: 0x936D,
	0xFDBB: 0x936E,
	0xFFFD: 0x936F,
	0xC1EC: 0x9370,
	0xEEE4: 0x9371,
	0xFFFD: 0x9372,
	0x9EB1: 0x9373,
	0x9EB2: 0x9374,
	0xC1E4: 0x9375,
	0xEED6: 0x9376,
	0xEEE5: 0x9377,
	0x9EB3: 0x9378,
	0xEEDF: 0x9379,
	0xEBE3: 0x937A,
	0xEEE6: 0x937B,
	0xEED3: 0x937C,
	0x9EB4: 0x937D,
	0xC1E9: 0x937E,
	0xFFFD: 0x937F,
	0xEEEB: 0x9380,
	0x9EB5: 0x9381,
	0xC1E2: 0x9382,
	0xEECE: 0x9383,
	0x9EB6: 0x9384,
	0xFB73: 0x9385,
	0x9EB7: 0x9386,
	0x9EB8: 0x9387,
	0xF160: 0x9388,
	0xF159: 0x9389,
	0xC2E9: 0x938A,
	0xFFFD: 0x938B,
	0xF154: 0x938C,
	0xF163: 0x938D,
	0xF15B: 0x938E,
	0xEEDC: 0x938F,
	0x9EB9: 0x9390,
	0xF165: 0x9391,
	0xF155: 0x9392,
	0xFFFD: 0x9393,
	0xC2E8: 0x9394,
	0xF15F: 0x9395,
	0xC2EA: 0x9396,
	0xC2F2: 0x9397,
	0xC2F0: 0x9398,
	0xF161: 0x9399,
	0xC2F1: 0x939A,
	0xF157: 0x939B,
	0x9EBA: 0x939C,
	0xF158: 0x939D,
	0xF15D: 0x939E,
	0xF162: 0x939F,
	0x9EBB: 0x93A0,
	0xEECD: 0x93A1,
	0xC2EB: 0x93A2,
	0xF16A: 0x93A3,
	0xF167: 0x93A4,
	0xF16B: 0x93A5,
	0xF15E: 0x93A6,
	0xF15A: 0x93A7,
	0xF168: 0x93A8,
	0xF36A: 0x93A9,
	0xF15C: 0x93AA,
	0xFFFD: 0x93AB,
	0xC2EE: 0x93AC,
	0x9756: 0x93AD,
	0xC2ED: 0x93AE,
	0xEECF: 0x93AF,
	0xC2EF: 0x93B0,
	0xF164: 0x93B1,
	0xF166: 0x93B2,
	0xC2EC: 0x93B3,
	0xF169: 0x93B4,
	0xF153: 0x93B5,
	0xFFFD: 0x93B6,
	0xF156: 0x93B7,
	0x9EBC: 0x93B8,
	0x94DC: 0x93B9,
	0xFDBC: 0x93BA,
	0x9EBD: 0x93BB,
	0xFFFD: 0x93BC,
	0x9EBE: 0x93BD,
	0xFFFD: 0x93BE,
	0x9EBF: 0x93BF,
	0xF373: 0x93C0,
	0xFFFD: 0x93C1,
	0xF363: 0x93C2,
	0xC3EB: 0x93C3,
	0xF371: 0x93C4,
	0xFFFD: 0x93C5,
	0x9757: 0x93C6,
	0xF361: 0x93C7,
	0xC3EC: 0x93C8,
	0xFFFD: 0x93C9,
	0xF36C: 0x93CA,
	0x9EC0: 0x93CB,
	0xF368: 0x93CC,
	0xC3F1: 0x93CD,
	0xF372: 0x93CE,
	0xF362: 0x93CF,
	0xF365: 0x93D0,
	0xC3E9: 0x93D1,
	0xF374: 0x93D2,
	0x9EC1: 0x93D3,
	0xF36D: 0x93D4,
	0xF370: 0x93D5,
	0xC3EF: 0x93D6,
	0xC3F4: 0x93D7,
	0xC3F2: 0x93D8,
	0xF369: 0x93D9,
	0xF364: 0x93DA,
	0x9EC2: 0x93DB,
	0xC3ED: 0x93DC,
	0xC3EE: 0x93DD,
	0xF360: 0x93DE,
	0xC3EA: 0x93DF,
	0x9EC3: 0x93E0,
	0xC3E8: 0x93E1,
	0xC3F0: 0x93E2,
	0xF36F: 0x93E3,
	0xC3F3: 0x93E4,
	0x9758: 0x93E5,
	0xF36B: 0x93E6,
	0xF375: 0x93E7,
	0xC3F5: 0x93E8,
	0xFFFD: 0x93E9,
	0xFFFD: 0x93EA,
	0xFFFD: 0x93EB,
	0xF367: 0x93EC,
	0xFFFD: 0x93ED,
	0xF36E: 0x93EE,
	0xFFFD: 0x93EF,
	0x9EC4: 0x93F0,
	0x9EC5: 0x93F1,
	0xFFFD: 0x93F2,
	0x9EC6: 0x93F3,
	0x9EC7: 0x93F4,
	0xF4F3: 0x93F5,
	0xF542: 0x93F6,
	0xF4F5: 0x93F7,
	0xF4FC: 0x93F8,
	0xF366: 0x93F9,
	0xF4FA: 0x93FA,
	0xF4E9: 0x93FB,
	0xF540: 0x93FC,
	0xC4C3: 0x93FD,
	0xF4ED: 0x93FE,
	0xF4FE: 0x93FF,
	0xF4F4: 0x9400,
	0x9EC8: 0x9401,
	0xFFFD: 0x9402,
	0xC4C2: 0x9403,
	0x9EC9: 0x9404,
	0xFFFD: 0x9405,
	0xF544: 0x9406,
	0xF4F6: 0x9407,
	0x9ECA: 0x9408,
	0xF4FB: 0x9409,
	0xF4FD: 0x940A,
	0xF4E7: 0x940B,
	0xF541: 0x940C,
	0xF4F2: 0x940D,
	0xF4F7: 0x940E,
	0xF4EB: 0x940F,
	0xF4EF: 0x9410,
	0xF543: 0x9411,
	0xF4F9: 0x9412,
	0xF4E8: 0x9413,
	0xF4EC: 0x9414,
	0xF4EE: 0x9415,
	0xF4F8: 0x9416,
	0x9ECB: 0x9417,
	0xC4C1: 0x9418,
	0xF4F1: 0x9419,
	0x9759: 0x941A,
	0x9ECC: 0x941B,
	0xFFFD: 0x941C,
	0x9ECD: 0x941D,
	0xFFFD: 0x941E,
	0xFFFD: 0x941F,
	0xF4EA: 0x9420,
	0x975A: 0x9421,
	0xFFFD: 0x9422,
	0xFFFD: 0x9423,
	0x9ECE: 0x9424,
	0x9ECF: 0x9425,
	0x9ED0: 0x9426,
	0xFDBD: 0x9427,
	0xF4F0: 0x9428,
	0xF661: 0x9429,
	0xF666: 0x942A,
	0xC54F: 0x942B,
	0xF668: 0x942C,
	0x9ED1: 0x942D,
	0xC549: 0x942E,
	0xFFFD: 0x942F,
	0xF664: 0x9430,
	0xF66A: 0x9431,
	0xC54E: 0x9432,
	0xC54A: 0x9433,
	0xFFFD: 0x9434,
	0xC54B: 0x9435,
	0xF660: 0x9436,
	0xF667: 0x9437,
	0xC54D: 0x9438,
	0xF665: 0x9439,
	0xC54C: 0x943A,
	0xF65F: 0x943B,
	0xF663: 0x943C,
	0xF662: 0x943D,
	0x975B: 0x943E,
	0xF65E: 0x943F,
	0xF669: 0x9440,
	0x975C: 0x9441,
	0x9ED2: 0x9442,
	0x9ED3: 0x9443,
	0xC5B1: 0x9444,
	0xF76D: 0x9445,
	0xF770: 0x9446,
	0xF76C: 0x9447,
	0xF76E: 0x9448,
	0xF76F: 0x9449,
	0xF769: 0x944A,
	0xF76A: 0x944B,
	0xF767: 0x944C,
	0x9ED4: 0x944D,
	0xFFFD: 0x944E,
	0xF76B: 0x944F,
	0xF768: 0x9450,
	0xC5B2: 0x9451,
	0xC5B3: 0x9452,
	0x975D: 0x9453,
	0x9ED5: 0x9454,
	0xF84B: 0x9455,
	0xFFFD: 0x9456,
	0xF84D: 0x9457,
	0x9ED6: 0x9458,
	0xFFFD: 0x9459,
	0x975E: 0x945A,
	0x9558: 0x945B,
	0xFFFD: 0x945C,
	0xF84C: 0x945D,
	0xF84E: 0x945E,
	0xFFFD: 0x945F,
	0xC5E0: 0x9460,
	0xFFFD: 0x9461,
	0xF84A: 0x9462,
	0xC5DF: 0x9463,
	0xC5E1: 0x9464,
	0x9ED7: 0x9465,
	0xFFFD: 0x9466,
	0x9ED8: 0x9467,
	0xF8CB: 0x9468,
	0xF8CC: 0x9469,
	0xC644: 0x946A,
	0xF8CA: 0x946B,
	0x9ED9: 0x946C,
	0xF953: 0x946D,
	0xF952: 0x946E,
	0xF954: 0x946F,
	0xC65F: 0x9470,
	0xF955: 0x9471,
	0xC65E: 0x9472,
	0xF956: 0x9473,
	0xF972: 0x9474,
	0xF975: 0x9475,
	0xF974: 0x9476,
	0xC668: 0x9477,
	0xF973: 0x9478,
	0x9EDA: 0x9479,
	0xFFFD: 0x947A,
	0x9EDB: 0x947B,
	0xC672: 0x947C,
	0xC670: 0x947D,
	0xC671: 0x947E,
	0xC677: 0x947F,
	0xF9C0: 0x9480,
	0xF9C1: 0x9481,
	0xF9BF: 0x9482,
	0xF9C9: 0x9483,
	0xFFFD: 0x9484,
	0x9CF0: 0x9485,
	0x8DC1: 0x9486,
	0x8DC0: 0x9487,
	0x83E1: 0x9488,
	0x83E0: 0x9489,
	0x83E2: 0x948A,
	0x83E3: 0x948B,
	0x8DC7: 0x948C,
	0x8DD9: 0x948D,
	0x8DD6: 0x948E,
	0x84B6: 0x948F,
	0x8DD7: 0x9490,
	0xFFFD: 0x9491,
	0x84B7: 0x9492,
	0x84B5: 0x9493,
	0x8F46: 0x9494,
	0x8DD8: 0x9495,
	0xFFFD: 0x9496,
	0x84B4: 0x9497,
	0xFFFD: 0x9498,
	0x8573: 0x9499,
	0x975F: 0x949A,
	0x8DF4: 0x949B,
	0x8673: 0x949C,
	0x8576: 0x949D,
	0x8571: 0x949E,
	0x8C5D: 0x949F,
	0x8574: 0x94A0,
	0x88AE: 0x94A1,
	0x89A1: 0x94A2,
	0x8578: 0x94A3,
	0x8577: 0x94A4,
	0x8D76: 0x94A5,
	0x84E8: 0x94A6,
	0x8575: 0x94A7,
	0x8B4F: 0x94A8,
	0x866E: 0x94A9,
	0x8DF7: 0x94AA,
	0x8DF2: 0x94AB,
	0x8DF3: 0x94AC,
	0x8DF6: 0x94AD,
	0x8572: 0x94AE,
	0x8DF5: 0x94AF,
	0x8E5A: 0x94B0,
	0x897E: 0x94B1,
	0x8E5B: 0x94B2,
	0x8668: 0x94B3,
	0x8667: 0x94B4,
	0x8473: 0x94B5,
	0x8E5C: 0x94B6,
	0x9760: 0x94B7,
	0x866A: 0x94B8,
	0x8669: 0x94B9,
	0x8DB2: 0x94BA,
	0x8DA7: 0x94BB,
	0x8E60: 0x94BC,
	0x8E5F: 0x94BD,
	0x866B: 0x94BE,
	0x8675: 0x94BF,
	0x866C: 0x94C0,
	0x8CB2: 0x94C1,
	0x866F: 0x94C2,
	0x8670: 0x94C3,
	0x8D44: 0x94C4,
	0x866D: 0x94C5,
	0x8676: 0x94C6,
	0xFFFD: 0x94C7,
	0x8E59: 0x94C8,
	0x8671: 0x94C9,
	0x8E58: 0x94CA,
	0x8672: 0x94CB,
	0x8E5E: 0x94CC,
	0x8674: 0x94CD,
	0x8CB4: 0x94CE,
	0xFFFD: 0x94CF,
	0x88A8: 0x94D0,
	0x8EA5: 0x94D1,
	0x8EA4: 0x94D2,
	0xFFFD: 0x94D3,
	0xFFFD: 0x94D4,
	0x8EA6: 0x94D5,
	0x8EAC: 0x94D6,
	0x8ED1: 0x94D7,
	0x9761: 0x94D8,
	0x8C5E: 0x94D9,
	0xFFFD: 0x94DA,
	0x8CB3: 0x94DB,
	0x8766: 0x94DC,
	0x88AA: 0x94DD,
	0x9762: 0x94DE,
	0x8EA7: 0x94DF,
	0x8FA7: 0x94E0,
	0x8F6A: 0x94E1,
	0x8768: 0x94E2,
	0x876C: 0x94E3,
	0x8ED5: 0x94E4,
	0x8EAD: 0x94E5,
	0xFFFD: 0x94E6,
	0x8FEC: 0x94E7,
	0x876A: 0x94E8,
	0x8FCD: 0x94E9,
	0x8EAA: 0x94EA,
	0x8EA8: 0x94EB,
	0x8769: 0x94EC,
	0x8767: 0x94ED,
	0x89A4: 0x94EE,
	0x8EA9: 0x94EF,
	0x8764: 0x94F0,
	0x8EA3: 0x94F1,
	0x85B6: 0x94F2,
	0x9763: 0x94F3,
	0x8FE5: 0x94F4,
	0x876B: 0x94F5,
	0x8765: 0x94F6,
	0x8EAB: 0x94F7,
	0x8CE4: 0x94F8,
	0x8FEE: 0x94F9,
	0x88A7: 0x94FA,
	0xFFFD: 0x94FB,
	0x8F42: 0x94FC,
	0x8ED2: 0x94FD,
	0x8BCE: 0x94FE,
	0x8BD5: 0x94FF,
	0x88A6: 0x9500,
	0x8B4E: 0x9501,
	0x88AF: 0x9502,
	0x9764: 0x9503,
	0x88A9: 0x9504,
	0x8AA2: 0x9505,
	0x8ED6: 0x9506,
	0x8ED7: 0x9507,
	0x8C5F: 0x9508,
	0x88AC: 0x9509,
	0x8ED4: 0x950A,
	0x88AD: 0x950B,
	0x88A4: 0x950C,
	0x8E5D: 0x950D,
	0x9765: 0x950E,
	0x9766: 0x950F,
	0x88AB: 0x9510,
	0x88A5: 0x9511,
	0x8ED0: 0x9512,
	0x8ED3: 0x9513,
	0x8ED8: 0x9514,
	0x8F44: 0x9515,
	0x8F40: 0x9516,
	0x8F41: 0x9517,
	0x9767: 0x9518,
	0x897D: 0x9519,
	0x8A7D: 0x951A,
	0x8F43: 0x951B,
	0xFFFD: 0x951C,
	0x9768: 0x951D,
	0x8F45: 0x951E,
	0x89A7: 0x951F,
	0xFFFD: 0x9520,
	0x89A2: 0x9521,
	0x89A8: 0x9522,
	0x8DA9: 0x9523,
	0x8AA3: 0x9524,
	0x89A5: 0x9525,
	0x89A6: 0x9526,
	0xFFFD: 0x9527,
	0x90F1: 0x9528,
	0x8EFD: 0x9529,
	0x9769: 0x952A,
	0x976A: 0x952B,
	0x8EFE: 0x952C,
	0x897A: 0x952D,
	0x8A7E: 0x952E,
	0x897B: 0x952F,
	0x897C: 0x9530,
	0x89A9: 0x9531,
	0x8AA1: 0x9532,
	0xFFFD: 0x9533,
	0x8F69: 0x9534,
	0x8BD3: 0x9535,
	0x8F6B: 0x9536,
	0x8AA8: 0x9537,
	0x8F68: 0x9538,
	0x8AA5: 0x9539,
	0x8AA4: 0x953A,
	0x8AA6: 0x953B,
	0x8FA8: 0x953C,
	0xFFFD: 0x953D,
	0x8AA7: 0x953E,
	0x976B: 0x953F,
	0x8A7B: 0x9540,
	0x8A7C: 0x9541,
	0x8BD4: 0x9542,
	0xFFFD: 0x9543,
	0x8FEA: 0x9544,
	0x976C: 0x9545,
	0x8A42: 0x9546,
	0x8B51: 0x9547,
	0xFFFD: 0x9548,
	0x8B54: 0x9549,
	0x8D7D: 0x954A,
	0xFFFD: 0x954B,
	0x8CB6: 0x954C,
	0x8B50: 0x954D,
	0x976D: 0x954E,
	0x8FA9: 0x954F,
	0x8B52: 0x9550,
	0x8B4D: 0x9551,
	0x8B53: 0x9552,
	0x8FA6: 0x9553,
	0x9060: 0x9554,
	0xFFFD: 0x9555,
	0x8BD1: 0x9556,
	0x8BCF: 0x9557,
	0x8BD0: 0x9558,
	0x8BD2: 0x9559,
	0xFFFD: 0x955A,
	0x8FC9: 0x955B,
	0x8BCB: 0x955C,
	0x8BCC: 0x955D,
	0x8BCD: 0x955E,
	0x8FCA: 0x955F,
	0xFFFD: 0x9560,
	0x8FE8: 0x9561,
	0x976E: 0x9562,
	0x8FE9: 0x9563,
	0x8FED: 0x9564,
	0x976F: 0x9565,
	0x8FE6: 0x9566,
	0x90A1: 0x9567,
	0x8FE7: 0x9568,
	0x9770: 0x9569,
	0x8FCB: 0x956A,
	0x8FEB: 0x956B,
	0x9061: 0x956C,
	0x8CB1: 0x956D,
	0xFFFD: 0x956E,
	0x8CB5: 0x956F,
	0x8CB0: 0x9570,
	0x9048: 0x9571,
	0x9771: 0x9572,
	0x8D43: 0x9573,
	0xFFFD: 0x9574,
	0xFFFD: 0x9575,
	0x8C7C: 0x9576,
	0xAAF8: 0x9577,
	0x9EDC: 0x9578,
	0xFFFD: 0x9579,
	0xD844: 0x957A,
	0xDC78: 0x957B,
	0xE8A5: 0x957C,
	0xF376: 0x957D,
	0xFFFD: 0x957E,
	0x8363: 0x957F,
	0xAAF9: 0x9580,
	0xFFFD: 0x9581,
	0xADAC: 0x9582,
	0xB07B: 0x9583,
	0xFFFD: 0x9584,
	0x9EDD: 0x9585,
	0xD845: 0x9586,
	0x9772: 0x9587,
	0xD846: 0x9588,
	0xB3AC: 0x9589,
	0x94DD: 0x958A,
	0xB67D: 0x958B,
	0xDC7A: 0x958C,
	0xDC79: 0x958D,
	0xB6A3: 0x958E,
	0xB67C: 0x958F,
	0xDC7B: 0x9590,
	0xB67E: 0x9591,
	0xB6A2: 0x9592,
	0xB6A1: 0x9593,
	0xB67B: 0x9594,
	0xFFFD: 0x9595,
	0x94DE: 0x9596,
	0xFDBE: 0x9597,
	0xB968: 0x9598,
	0x9773: 0x9599,
	0xFFFD: 0x959A,
	0xE0D0: 0x959B,
	0xE0CE: 0x959C,
	0xFFFD: 0x959D,
	0xE0CF: 0x959E,
	0xE0CD: 0x959F,
	0x9774: 0x95A0,
	0xBBD2: 0x95A1,
	0x926B: 0x95A2,
	0xBBD5: 0x95A3,
	0xBBD7: 0x95A4,
	0xBBD6: 0x95A5,
	0x9EDE: 0x95A6,
	0xFDBF: 0x95A7,
	0xBBD3: 0x95A8,
	0xBBD4: 0x95A9,
	0x9EDF: 0x95AA,
	0xE8A7: 0x95AB,
	0xE8A6: 0x95AC,
	0xBE5B: 0x95AD,
	0xE8A8: 0x95AE,
	0xFFFD: 0x95AF,
	0xE8A9: 0x95B0,
	0xBE5C: 0x95B1,
	0x9775: 0x95B2,
	0xFFFD: 0x95B3,
	0xFFFD: 0x95B4,
	0xEC4D: 0x95B5,
	0xEC4B: 0x95B6,
	0xEEF3: 0x95B7,
	0xFFFD: 0x95B8,
	0xEC49: 0x95B9,
	0xEC4A: 0x95BA,
	0xC046: 0x95BB,
	0xEC46: 0x95BC,
	0xEC4E: 0x95BD,
	0xEC48: 0x95BE,
	0xEC4C: 0x95BF,
	0xEEEF: 0x95C0,
	0xFFFD: 0x95C1,
	0xFFFD: 0x95C2,
	0xEEF1: 0x95C3,
	0xFFFD: 0x95C4,
	0xEEF2: 0x95C5,
	0xC1F3: 0x95C6,
	0xEEEE: 0x95C7,
	0xC1F2: 0x95C8,
	0xEEF0: 0x95C9,
	0xC1EF: 0x95CA,
	0xC1F0: 0x95CB,
	0xC1F1: 0x95CC,
	0xEC47: 0x95CD,
	0xFFFD: 0x95CE,
	0xFFFD: 0x95CF,
	0xC2F5: 0x95D0,
	0xF16E: 0x95D1,
	0xF16C: 0x95D2,
	0xF16D: 0x95D3,
	0xC2F3: 0x95D4,
	0xC2F6: 0x95D5,
	0xC2F4: 0x95D6,
	0xFFFD: 0x95D7,
	0x93A7: 0x95D8,
	0xFFFD: 0x95D9,
	0xF377: 0x95DA,
	0xF378: 0x95DB,
	0xC3F6: 0x95DC,
	0xFFFD: 0x95DD,
	0xF545: 0x95DE,
	0xF547: 0x95DF,
	0xF546: 0x95E0,
	0xC4C4: 0x95E1,
	0xC550: 0x95E2,
	0xF66D: 0x95E3,
	0xF66C: 0x95E4,
	0xF66B: 0x95E5,
	0xFFFD: 0x95E6,
	0xFFFD: 0x95E7,
	0x8364: 0x95E8,
	0x83A2: 0x95E9,
	0x83E4: 0x95EA,
	0x8DDA: 0x95EB,
	0xFFFD: 0x95EC,
	0x84B8: 0x95ED,
	0x83F4: 0x95EE,
	0x8B56: 0x95EF,
	0x857A: 0x95F0,
	0x8AAC: 0x95F1,
	0x857C: 0x95F2,
	0x857E: 0x95F3,
	0x857D: 0x95F4,
	0x8579: 0x95F5,
	0x8DF8: 0x95F6,
	0x84DD: 0x95F7,
	0x8677: 0x95F8,
	0x88C1: 0x95F9,
	0x876E: 0x95FA,
	0x8747: 0x95FB,
	0x9049: 0x95FC,
	0x876F: 0x95FD,
	0x88B0: 0x95FE,
	0xFFFD: 0x95FF,
	0x8771: 0x9600,
	0x8770: 0x9601,
	0x876D: 0x9602,
	0x8EDA: 0x9603,
	0x90AC: 0x9604,
	0x88B1: 0x9605,
	0x8ED9: 0x9606,
	0xFFFD: 0x9607,
	0x8F48: 0x9608,
	0x8F49: 0x9609,
	0x8F4A: 0x960A,
	0x8FB0: 0x960B,
	0x8F4B: 0x960C,
	0x8F4C: 0x960D,
	0x89AA: 0x960E,
	0x8F47: 0x960F,
	0x8C60: 0x9610,
	0x8AAB: 0x9611,
	0x8F6C: 0x9612,
	0xFFFD: 0x9613,
	0x8AA9: 0x9614,
	0x8AAA: 0x9615,
	0x8B55: 0x9616,
	0x8B57: 0x9617,
	0xFFFD: 0x9618,
	0x8B58: 0x9619,
	0x8FEF: 0x961A,
	0xFFFD: 0x961B,
	0xAAFA: 0x961C,
	0x9CF1: 0x961D,
	0xC9AA: 0x961E,
	0x85A1: 0x961F,
	0xCA58: 0x9620,
	0xA6E9: 0x9621,
	0xCA56: 0x9622,
	0xCA59: 0x9623,
	0xCA57: 0x9624,
	0xFFFD: 0x9625,
	0xFFFD: 0x9626,
	0xFFFD: 0x9627,
	0xCBAE: 0x9628,
	0xFFFD: 0x9629,
	0xA8C1: 0x962A,
	0xFFFD: 0x962B,
	0xA8C2: 0x962C,
	0xCBB0: 0x962D,
	0xA8BF: 0x962E,
	0xCBAF: 0x962F,
	0xCBAD: 0x9630,
	0xA8C0: 0x9631,
	0xA8BE: 0x9632,
	0x85A3: 0x9633,
	0x84BB: 0x9634,
	0x83E5: 0x9635,
	0x85A2: 0x9636,
	0xFFFD: 0x9637,
	0xFDC1: 0x9638,
	0xCDD8: 0x9639,
	0xCDDB: 0x963A,
	0xAAFD: 0x963B,
	0xCDDA: 0x963C,
	0xCDD9: 0x963D,
	0xFFFD: 0x963E,
	0xAAFC: 0x963F,
	0xAAFB: 0x9640,
	0xFE42: 0x9641,
	0xAB40: 0x9642,
	0xCDDC: 0x9643,
	0xAAFE: 0x9644,
	0x8772: 0x9645,
	0x84BA: 0x9646,
	0x8BD8: 0x9647,
	0x84B9: 0x9648,
	0x83E7: 0x9649,
	0xD0C6: 0x964A,
	0xADAE: 0x964B,
	0xADAF: 0x964C,
	0xADB0: 0x964D,
	0xD0C7: 0x964E,
	0xD0C3: 0x964F,
	0xADAD: 0x9650,
	0xD0C4: 0x9651,
	0xFFFD: 0x9652,
	0xD0C5: 0x9653,
	0xD0C2: 0x9654,
	0x83E6: 0x9655,
	0x9EE0: 0x9656,
	0xFFFD: 0x9657,
	0xB0A4: 0x9658,
	0xFFFD: 0x9659,
	0xFFFD: 0x965A,
	0xB0A1: 0x965B,
	0xD445: 0x965C,
	0xB0A2: 0x965D,
	0xB0A5: 0x965E,
	0xD446: 0x965F,
	0xFFFD: 0x9660,
	0xB07E: 0x9661,
	0xB07C: 0x9662,
	0xB07D: 0x9663,
	0xB0A3: 0x9664,
	0x9267: 0x9665,
	0x9776: 0x9666,
	0x8DF9: 0x9667,
	0x8678: 0x9668,
	0x89AC: 0x9669,
	0xB3AD: 0x966A,
	0xD849: 0x966B,
	0xB3B5: 0x966C,
	0xD848: 0x966D,
	0xFFFD: 0x966E,
	0xD84B: 0x966F,
	0xB3B1: 0x9670,
	0xD84A: 0x9671,
	0xB6AB: 0x9672,
	0xB3AF: 0x9673,
	0xB3B2: 0x9674,
	0xB3AE: 0x9675,
	0xB3B3: 0x9676,
	0xB3B4: 0x9677,
	0xB3B0: 0x9678,
	0xFFFD: 0x9679,
	0x92B4: 0x967A,
	0x9EE1: 0x967B,
	0xD847: 0x967C,
	0xB6A7: 0x967D,
	0xDC7D: 0x967E,
	0xFFFD: 0x967F,
	0xDCA3: 0x9680,
	0xFDC5: 0x9681,
	0xFFFD: 0x9682,
	0xDCA2: 0x9683,
	0xB6AC: 0x9684,
	0xB6A8: 0x9685,
	0xB6A9: 0x9686,
	0xDC7C: 0x9687,
	0xDC7E: 0x9688,
	0xDCA1: 0x9689,
	0xB6A4: 0x968A,
	0xB6A6: 0x968B,
	0xFFFD: 0x968C,
	0xB6AA: 0x968D,
	0xB6A5: 0x968E,
	0x92FA: 0x968F,
	0x8AAD: 0x9690,
	0xE0D3: 0x9691,
	0xE0D1: 0x9692,
	0xE0D2: 0x9693,
	0xB96A: 0x9694,
	0xB96B: 0x9695,
	0xFDC4: 0x9696,
	0xE0D4: 0x9697,
	0xB969: 0x9698,
	0xBBD8: 0x9699,
	0xFFFD: 0x969A,
	0xBBDA: 0x969B,
	0xBBD9: 0x969C,
	0x9777: 0x969D,
	0xE4BB: 0x969E,
	0xFFFD: 0x969F,
	0x9247: 0x96A0,
	0xE4BC: 0x96A1,
	0xE8AB: 0x96A2,
	0x95F9: 0x96A3,
	0xE8AA: 0x96A4,
	0x9EE2: 0x96A5,
	0xFFFD: 0x96A6,
	0xC047: 0x96A7,
	0xC048: 0x96A8,
	0xEC4F: 0x96A9,
	0xC049: 0x96AA,
	0xFFFD: 0x96AB,
	0xEEF6: 0x96AC,
	0xFFFD: 0x96AD,
	0xEEF4: 0x96AE,
	0x9778: 0x96AF,
	0xEEF5: 0x96B0,
	0xC1F4: 0x96B1,
	0x9779: 0x96B2,
	0xF16F: 0x96B3,
	0xC3F7: 0x96B4,
	0xFFFD: 0x96B5,
	0xC6D7: 0x96B6,
	0x95FB: 0x96B7,
	0xC1F5: 0x96B8,
	0xAB41: 0x96B9,
	0xFFFD: 0x96BA,
	0xB0A6: 0x96BB,
	0xD447: 0x96BC,
	0x8679: 0x96BD,
	0x8BD9: 0x96BE,
	0xD84C: 0x96BF,
	0xB3B6: 0x96C0,
	0xB6AD: 0x96C1,
	0xDCA4: 0x96C2,
	0xDCA6: 0x96C3,
	0xB6AF: 0x96C4,
	0xB6AE: 0x96C5,
	0xB6B0: 0x96C6,
	0xB6B1: 0x96C7,
	0xDCA5: 0x96C8,
	0xB96E: 0x96C9,
	0xB96F: 0x96CA,
	0xB96D: 0x96CB,
	0xBBDB: 0x96CC,
	0xB96C: 0x96CD,
	0xE0D5: 0x96CE,
	0x8B5B: 0x96CF,
	0xFFFD: 0x96D0,
	0x92CA: 0x96D1,
	0xBBDC: 0x96D2,
	0xE8AC: 0x96D3,
	0xEC50: 0x96D4,
	0xC04A: 0x96D5,
	0xC1F6: 0x96D6,
	0xF170: 0x96D7,
	0xF174: 0x96D8,
	0xC2F9: 0x96D9,
	0xF171: 0x96DA,
	0xC2FA: 0x96DB,
	0xC2F8: 0x96DC,
	0xF175: 0x96DD,
	0xC2FB: 0x96DE,
	0xF173: 0x96DF,
	0x906D: 0x96E0,
	0xF379: 0x96E1,
	0xC2F7: 0x96E2,
	0xC3F8: 0x96E3,
	0xFFFD: 0x96E4,
	0xF8CD: 0x96E5,
	0xFFFD: 0x96E6,
	0xFFFD: 0x96E7,
	0xAB42: 0x96E8,
	0xB3B8: 0x96E9,
	0xB3B7: 0x96EA,
	0x9448: 0x96EB,
	0xFFFD: 0x96EC,
	0xFFFD: 0x96ED,
	0xFFFD: 0x96EE,
	0xB6B2: 0x96EF,
	0xDCA8: 0x96F0,
	0xDCA7: 0x96F1,
	0xB6B3: 0x96F2,
	0x8D5E: 0x96F3,
	0x9EE3: 0x96F4,
	0xE0D9: 0x96F5,
	0xB973: 0x96F6,
	0xB970: 0x96F7,
	0xE0D8: 0x96F8,
	0xB972: 0x96F9,
	0xE0D6: 0x96FA,
	0xB971: 0x96FB,
	0xFFFD: 0x96FC,
	0xE0D7: 0x96FD,
	0x8BDA: 0x96FE,
	0xE4BD: 0x96FF,
	0xBBDD: 0x9700,
	0x8CE6: 0x9701,
	0xE8AF: 0x9702,
	0xFDC7: 0x9703,
	0xBE5D: 0x9704,
	0xE8AD: 0x9705,
	0xBE5E: 0x9706,
	0xBE5F: 0x9707,
	0xE8AE: 0x9708,
	0xBE60: 0x9709,
	0x93ED: 0x970A,
	0xEC51: 0x970B,
	0xFFFD: 0x970C,
	0xC04E: 0x970D,
	0xC04B: 0x970E,
	0xC050: 0x970F,
	0xEC53: 0x9710,
	0xC04C: 0x9711,
	0xEC52: 0x9712,
	0xC04F: 0x9713,
	0xFFFD: 0x9714,
	0xFFFD: 0x9715,
	0xC04D: 0x9716,
	0xFFFD: 0x9717,
	0xEEF9: 0x9718,
	0xEEFB: 0x9719,
	0xFFFD: 0x971A,
	0x9EE4: 0x971B,
	0xC1F7: 0x971C,
	0xEEFA: 0x971D,
	0xC1F8: 0x971E,
	0xEEF8: 0x971F,
	0xEEF7: 0x9720,
	0xFDC8: 0x9721,
	0xF177: 0x9722,
	0xF176: 0x9723,
	0xC2FC: 0x9724,
	0xF178: 0x9725,
	0xF37E: 0x9726,
	0xC3FA: 0x9727,
	0xF37D: 0x9728,
	0xF37A: 0x9729,
	0xC3F9: 0x972A,
	0xF37B: 0x972B,
	0xF37C: 0x972C,
	0x8D60: 0x972D,
	0xF548: 0x972E,
	0xF549: 0x972F,
	0xC4C5: 0x9730,
	0xFDC9: 0x9731,
	0xC553: 0x9732,
	0x977A: 0x9733,
	0x9DBB: 0x9734,
	0xF66E: 0x9735,
	0x9EE5: 0x9736,
	0xFFFD: 0x9737,
	0xC551: 0x9738,
	0xC552: 0x9739,
	0xF66F: 0x973A,
	0x977B: 0x973B,
	0xFFFD: 0x973C,
	0xC5B4: 0x973D,
	0xC5B5: 0x973E,
	0xF771: 0x973F,
	0x9EE6: 0x9740,
	0x9EE7: 0x9741,
	0xC645: 0x9742,
	0xF8CF: 0x9743,
	0xC647: 0x9744,
	0xFFFD: 0x9745,
	0xF8CE: 0x9746,
	0xF8D0: 0x9747,
	0xC646: 0x9748,
	0xF957: 0x9749,
	0xFFFD: 0x974A,
	0xF9AD: 0x974B,
	0xFFFD: 0x974C,
	0x977C: 0x974D,
	0xFFFD: 0x974E,
	0x977D: 0x974F,
	0xFFFD: 0x9750,
	0x977E: 0x9751,
	0xAB43: 0x9752,
	0x8EDB: 0x9753,
	0xFFFD: 0x9754,
	0x97A1: 0x9755,
	0xB974: 0x9756,
	0x9EE8: 0x9757,
	0xE4BE: 0x9758,
	0x9343: 0x9759,
	0xE8B0: 0x975A,
	0xC051: 0x975B,
	0xC052: 0x975C,
	0xFE6D: 0x975D,
	0xAB44: 0x975E,
	0xFDCA: 0x975F,
	0xBE61: 0x9760,
	0xC3FB: 0x9761,
	0xADB1: 0x9762,
	0xFFFD: 0x9763,
	0x97A2: 0x9764,
	0x8D45: 0x9765,
	0xC053: 0x9766,
	0xFFFD: 0x9767,
	0xC5E2: 0x9768,
	0xADB2: 0x9769,
	0xD84D: 0x976A,
	0x97A3: 0x976B,
	0xDCA9: 0x976C,
	0x95F7: 0x976D,
	0xDCAB: 0x976E,
	0xFFFD: 0x976F,
	0xDCAA: 0x9770,
	0x97A4: 0x9771,
	0xE0DD: 0x9772,
	0xE0DA: 0x9773,
	0xB975: 0x9774,
	0xFFFD: 0x9775,
	0xB976: 0x9776,
	0xE0DB: 0x9777,
	0xE0DC: 0x9778,
	0x94DF: 0x9779,
	0xE4C0: 0x977A,
	0xE4C5: 0x977B,
	0xBBDE: 0x977C,
	0xE4BF: 0x977D,
	0xE4C1: 0x977E,
	0xE4C8: 0x977F,
	0xE4C3: 0x9780,
	0xE4C7: 0x9781,
	0xE4C4: 0x9782,
	0xE4C2: 0x9783,
	0xE4C6: 0x9784,
	0xBBDF: 0x9785,
	0x94E0: 0x9786,
	0x9EE9: 0x9787,
	0xE8B3: 0x9788,
	0x9EEA: 0x9789,
	0xE8B1: 0x978A,
	0xBE63: 0x978B,
	0xFFFD: 0x978C,
	0xBE62: 0x978D,
	0xE8B2: 0x978E,
	0xBE64: 0x978F,
	0x94E1: 0x9790,
	0x8CE7: 0x9791,
	0x97A5: 0x9792,
	0xFFFD: 0x9793,
	0xEC56: 0x9794,
	0xFFFD: 0x9795,
	0xFFFD: 0x9796,
	0xEC55: 0x9797,
	0xC054: 0x9798,
	0xEC54: 0x9799,
	0xEEFC: 0x979A,
	0x9EEB: 0x979B,
	0xEEFE: 0x979C,
	0xEF41: 0x979D,
	0xEF40: 0x979E,
	0xFDCB: 0x979F,
	0xC1F9: 0x97A0,
	0xEEFD: 0x97A1,
	0xF1A1: 0x97A2,
	0xC2FD: 0x97A3,
	0xF17D: 0x97A4,
	0xF1A2: 0x97A5,
	0xC2FE: 0x97A6,
	0xFFFD: 0x97A7,
	0xF17B: 0x97A8,
	0xFFFD: 0x97A9,
	0xF17E: 0x97AA,
	0xF17C: 0x97AB,
	0xF179: 0x97AC,
	0xC340: 0x97AD,
	0xF17A: 0x97AE,
	0x8D7E: 0x97AF,
	0xFFFD: 0x97B0,
	0x9EEC: 0x97B1,
	0x97A6: 0x97B2,
	0xF3A1: 0x97B3,
	0xFDCC: 0x97B4,
	0xFFFD: 0x97B5,
	0xF3A3: 0x97B6,
	0xF3A2: 0x97B7,
	0xFDCD: 0x97B8,
	0xF54A: 0x97B9,
	0xFDCE: 0x97BA,
	0xF54B: 0x97BB,
	0xFFFD: 0x97BC,
	0x9EED: 0x97BD,
	0xFDCF: 0x97BE,
	0xF670: 0x97BF,
	0x9EEE: 0x97C0,
	0xC5B7: 0x97C1,
	0x9EEF: 0x97C2,
	0xC5B6: 0x97C3,
	0xF84F: 0x97C4,
	0xF850: 0x97C5,
	0xC648: 0x97C6,
	0xF8D1: 0x97C7,
	0xFDD0: 0x97C8,
	0xC669: 0x97C9,
	0xFFFD: 0x97CA,
	0xADB3: 0x97CB,
	0xB6B4: 0x97CC,
	0xE4CA: 0x97CD,
	0xE4C9: 0x97CE,
	0xE8B5: 0x97CF,
	0xE8B4: 0x97D0,
	0xFFFD: 0x97D1,
	0x9EF0: 0x97D2,
	0xC1FA: 0x97D3,
	0xEF43: 0x97D4,
	0xEF42: 0x97D5,
	0xF1A5: 0x97D6,
	0xF1A3: 0x97D7,
	0xF1A6: 0x97D8,
	0xF1A4: 0x97D9,
	0xFFFD: 0x97DA,
	0xFFFD: 0x97DB,
	0xC3FC: 0x97DC,
	0xF3A4: 0x97DD,
	0xF3A5: 0x97DE,
	0xF3A6: 0x97DF,
	0x9EF1: 0x97E0,
	0xF671: 0x97E1,
	0xFFFD: 0x97E2,
	0xF772: 0x97E3,
	0xFFFD: 0x97E4,
	0xF8D2: 0x97E5,
	0x83A3: 0x97E6,
	0x85A4: 0x97E7,
	0xFFFD: 0x97E8,
	0x8AB0: 0x97E9,
	0x8FAB: 0x97EA,
	0x8FCE: 0x97EB,
	0x8BDB: 0x97EC,
	0xADB4: 0x97ED,
	0x9561: 0x97EE,
	0xFFFD: 0x97EF,
	0xEC57: 0x97F0,
	0xEF44: 0x97F1,
	0x97A7: 0x97F2,
	0xADB5: 0x97F3,
	0xFFFD: 0x97F4,
	0x8BDC: 0x97F5,
	0xBBE0: 0x97F6,
	0xFFFD: 0x97F7,
	0xEC58: 0x97F8,
	0xC341: 0x97F9,
	0xF1A7: 0x97FA,
	0xC3FD: 0x97FB,
	0xFFFD: 0x97FC,
	0xF54C: 0x97FD,
	0xF54D: 0x97FE,
	0xC554: 0x97FF,
	0xF851: 0x9800,
	0xADB6: 0x9801,
	0xB3BB: 0x9802,
	0xB3BC: 0x9803,
	0xD84E: 0x9804,
	0xB6B5: 0x9805,
	0xB6B6: 0x9806,
	0xDCAC: 0x9807,
	0xB6B7: 0x9808,
	0xFFFD: 0x9809,
	0xB97A: 0x980A,
	0xFFFD: 0x980B,
	0xB97C: 0x980C,
	0xE0DF: 0x980D,
	0xE0E0: 0x980E,
	0xE0DE: 0x980F,
	0xB977: 0x9810,
	0xB978: 0x9811,
	0xB97B: 0x9812,
	0xB979: 0x9813,
	0x9EF2: 0x9814,
	0x9EF3: 0x9815,
	0xE4CB: 0x9816,
	0xBBE1: 0x9817,
	0xBBE2: 0x9818,
	0xFFFD: 0x9819,
	0x825B: 0x981A,
	0xE8BC: 0x981B,
	0xBE67: 0x981C,
	0xE8B7: 0x981D,
	0xE8B6: 0x981E,
	0xFDD2: 0x981F,
	0xE8BB: 0x9820,
	0xBE65: 0x9821,
	0xFFFD: 0x9822,
	0x9EF4: 0x9823,
	0xC05B: 0x9824,
	0xFFFD: 0x9825,
	0xE8B8: 0x9826,
	0xE8BD: 0x9827,
	0xE8BA: 0x9828,
	0xE8B9: 0x9829,
	0xFFFD: 0x982A,
	0xBE66: 0x982B,
	0x827B: 0x982C,
	0xC059: 0x982D,
	0xFDD3: 0x982E,
	0xEC5A: 0x982F,
	0xC055: 0x9830,
	0xFFFD: 0x9831,
	0xEC5B: 0x9832,
	0x9EF5: 0x9833,
	0x8242: 0x9834,
	0xEC59: 0x9835,
	0xFFFD: 0x9836,
	0xC058: 0x9837,
	0xC056: 0x9838,
	0xC05A: 0x9839,
	0xFFFD: 0x983A,
	0xC057: 0x983B,
	0x93DF: 0x983C,
	0x97A8: 0x983D,
	0xFFFD: 0x983E,
	0xFFFD: 0x983F,
	0xFFFD: 0x9840,
	0xEF45: 0x9841,
	0xFFFD: 0x9842,
	0xEF4A: 0x9843,
	0xEF46: 0x9844,
	0xEF49: 0x9845,
	0xC1FB: 0x9846,
	0xFDD5: 0x9847,
	0xEDD4: 0x9848,
	0xEF48: 0x9849,
	0xEF47: 0x984A,
	0xFDD6: 0x984B,
	0xC344: 0x984C,
	0xC342: 0x984D,
	0xC345: 0x984E,
	0xC343: 0x984F,
	0xF1A8: 0x9850,
	0xF1A9: 0x9851,
	0xF1AA: 0x9852,
	0xC346: 0x9853,
	0x97A9: 0x9854,
	0x92B8: 0x9855,
	0x9DD2: 0x9856,
	0xF3AA: 0x9857,
	0xC440: 0x9858,
	0xF3A8: 0x9859,
	0xFFFD: 0x985A,
	0xC441: 0x985B,
	0xF3A7: 0x985C,
	0xF3A9: 0x985D,
	0xC3FE: 0x985E,
	0xF551: 0x985F,
	0xF54E: 0x9860,
	0xFFFD: 0x9861,
	0xF54F: 0x9862,
	0xF550: 0x9863,
	0xF672: 0x9864,
	0xC556: 0x9865,
	0xFDD7: 0x9866,
	0xC555: 0x9867,
	0x9EF6: 0x9868,
	0xF774: 0x9869,
	0xF773: 0x986A,
	0xC5B8: 0x986B,
	0xFDD8: 0x986C,
	0xFFFD: 0x986D,
	0xFFFD: 0x986E,
	0xC5E3: 0x986F,
	0xC649: 0x9870,
	0xC660: 0x9871,
	0xF958: 0x9872,
	0xF9AE: 0x9873,
	0xF9AF: 0x9874,
	0x83A4: 0x9875,
	0x84BC: 0x9876,
	0x84BD: 0x9877,
	0x8DFA: 0x9878,
	0x85A5: 0x9879,
	0x85A6: 0x987A,
	0x85A7: 0x987B,
	0x867E: 0x987C,
	0x867C: 0x987D,
	0x8CB8: 0x987E,
	0x867D: 0x987F,
	0x8E62: 0x9880,
	0x86A1: 0x9881,
	0x86A2: 0x9882,
	0x8E61: 0x9883,
	0x867B: 0x9884,
	0x8D77: 0x9885,
	0x8774: 0x9886,
	0x8773: 0x9887,
	0x89B0: 0x9888,
	0x88B3: 0x9889,
	0x89AF: 0x988A,
	0xFFFD: 0x988B,
	0x88B4: 0x988C,
	0x8EBA: 0x988D,
	0xFFFD: 0x988E,
	0x8EDC: 0x988F,
	0x89B5: 0x9890,
	0x89B1: 0x9891,
	0xFFFD: 0x9892,
	0x89B4: 0x9893,
	0x89B2: 0x9894,
	0xFFFD: 0x9895,
	0x8946: 0x9896,
	0x8AB1: 0x9897,
	0x8B5F: 0x9898,
	0xFFFD: 0x9899,
	0x8B60: 0x989A,
	0x8B61: 0x989B,
	0x8B5E: 0x989C,
	0x8B5D: 0x989D,
	0x90A7: 0x989E,
	0x8FF0: 0x989F,
	0x8BDE: 0x98A0,
	0x8FCF: 0x98A1,
	0x8CB9: 0x98A2,
	0xFFFD: 0x98A3,
	0x8CE9: 0x98A4,
	0x97AA: 0x98A5,
	0x8D61: 0x98A6,
	0x90A8: 0x98A7,
	0xADB7: 0x98A8,
	0xDCAD: 0x98A9,
	0x94E2: 0x98AA,
	0xFFFD: 0x98AB,
	0xE0E1: 0x98AC,
	0xE4CC: 0x98AD,
	0xE4CD: 0x98AE,
	0xBBE3: 0x98AF,
	0xFFFD: 0x98B0,
	0xBBE4: 0x98B1,
	0xE8BE: 0x98B2,
	0xBE68: 0x98B3,
	0xFDD9: 0x98B4,
	0xFFFD: 0x98B5,
	0xC1FC: 0x98B6,
	0x9EF7: 0x98B7,
	0xF1AB: 0x98B8,
	0x9EF8: 0x98B9,
	0xC347: 0x98BA,
	0xF3AD: 0x98BB,
	0xC442: 0x98BC,
	0xF3AC: 0x98BD,
	0xF3AE: 0x98BE,
	0xF3AB: 0x98BF,
	0xF675: 0x98C0,
	0xF552: 0x98C1,
	0xF553: 0x98C2,
	0x97AB: 0x98C3,
	0xC4C6: 0x98C4,
	0xFFFD: 0x98C5,
	0xF674: 0x98C6,
	0x9EF9: 0x98C7,
	0xFBB2: 0x98C8,
	0xF673: 0x98C9,
	0x9EFA: 0x98CA,
	0xF775: 0x98CB,
	0xF9B0: 0x98CC,
	0xFFFD: 0x98CD,
	0x83A5: 0x98CE,
	0xFFFD: 0x98CF,
	0xFFFD: 0x98D0,
	0x8EAE: 0x98D1,
	0x8775: 0x98D2,
	0x8AB2: 0x98D3,
	0xFFFD: 0x98D4,
	0x8BDF: 0x98D5,
	0xFFFD: 0x98D6,
	0xFFFD: 0x98D7,
	0x8C61: 0x98D8,
	0x904A: 0x98D9,
	0x97AC: 0x98DA,
	0xADB8: 0x98DB,
	0xFDDB: 0x98DC,
	0xFFFD: 0x98DD,
	0x83A6: 0x98DE,
	0xADB9: 0x98DF,
	0x9EFB: 0x98E0,
	0x9EFC: 0x98E1,
	0xB0A7: 0x98E2,
	0xD448: 0x98E3,
	0xFFFD: 0x98E4,
	0xD84F: 0x98E5,
	0xFDDC: 0x98E6,
	0xB6B8: 0x98E7,
	0x8CBA: 0x98E8,
	0xB6BB: 0x98E9,
	0xB6B9: 0x98EA,
	0xDCAE: 0x98EB,
	0x9EFD: 0x98EC,
	0xB6BD: 0x98ED,
	0x97AD: 0x98EE,
	0xB6BA: 0x98EF,
	0xFFFD: 0x98F0,
	0x95DA: 0x98F1,
	0xB6BC: 0x98F2,
	0xFFFD: 0x98F3,
	0xB97E: 0x98F4,
	0x9EFE: 0x98F5,
	0xE0E2: 0x98F6,
	0xFFFD: 0x98F7,
	0xFFFD: 0x98F8,
	0xE0E3: 0x98F9,
	0xE8C0: 0x98FA,
	0xFFFD: 0x98FB,
	0xB97D: 0x98FC,
	0xB9A1: 0x98FD,
	0xB9A2: 0x98FE,
	0xFFFD: 0x98FF,
	0xE4CF: 0x9900,
	0xFFFD: 0x9901,
	0xE4CE: 0x9902,
	0xBBE5: 0x9903,
	0xFFFD: 0x9904,
	0xBBE6: 0x9905,
	0xFFFD: 0x9906,
	0xE4D0: 0x9907,
	0xE8BF: 0x9908,
	0xBBE8: 0x9909,
	0xBE69: 0x990A,
	0xFFFD: 0x990B,
	0xBBE7: 0x990C,
	0x8D47: 0x990D,
	0x9F70: 0x990E,
	0xFFFD: 0x990F,
	0xC05C: 0x9910,
	0xE8C1: 0x9911,
	0xBE6B: 0x9912,
	0xBE6A: 0x9913,
	0xE8C2: 0x9914,
	0xE8C5: 0x9915,
	0xE8C3: 0x9916,
	0xE8C4: 0x9917,
	0xBE6C: 0x9918,
	0x9F71: 0x9919,
	0xC061: 0x991A,
	0xC05F: 0x991B,
	0x9F72: 0x991C,
	0x97AE: 0x991D,
	0xC05E: 0x991E,
	0xEC5D: 0x991F,
	0x97AF: 0x9920,
	0xC060: 0x9921,
	0xFFFD: 0x9922,
	0xFFFD: 0x9923,
	0xEC5C: 0x9924,
	0xEF4B: 0x9925,
	0xFFFD: 0x9926,
	0xEC5E: 0x9927,
	0xC05D: 0x9928,
	0xEC5F: 0x9929,
	0xEF4E: 0x992A,
	0xEF4C: 0x992B,
	0xEF4D: 0x992C,
	0xEF52: 0x992D,
	0xC34B: 0x992E,
	0xEF51: 0x992F,
	0xEF54: 0x9930,
	0xEF53: 0x9931,
	0xEF50: 0x9932,
	0xEF4F: 0x9933,
	0xFFFD: 0x9934,
	0xC1FD: 0x9935,
	0xFFFD: 0x9936,
	0x9F73: 0x9937,
	0xA044: 0x9938,
	0xFDDE: 0x9939,
	0xF1AE: 0x993A,
	0xFDDF: 0x993B,
	0xF1AD: 0x993C,
	0xC34A: 0x993D,
	0xC348: 0x993E,
	0xC349: 0x993F,
	0xFBB3: 0x9940,
	0xF1AC: 0x9941,
	0xFDDD: 0x9942,
	0xF3B1: 0x9943,
	0xFFFD: 0x9944,
	0xC443: 0x9945,
	0xFFFD: 0x9946,
	0xF3B0: 0x9947,
	0xF3AF: 0x9948,
	0xC444: 0x9949,
	0xFDE1: 0x994A,
	0xF558: 0x994B,
	0xF557: 0x994C,
	0xFBB4: 0x994D,
	0xF555: 0x994E,
	0xFFFD: 0x994F,
	0xF554: 0x9950,
	0xC4C8: 0x9951,
	0xC4C7: 0x9952,
	0xF559: 0x9953,
	0xF776: 0x9954,
	0xC5B9: 0x9955,
	0xF677: 0x9956,
	0xC557: 0x9957,
	0xF676: 0x9958,
	0xF556: 0x9959,
	0xFFFD: 0x995A,
	0xF777: 0x995B,
	0xC5E4: 0x995C,
	0x9F74: 0x995D,
	0xC661: 0x995E,
	0xF959: 0x995F,
	0xFFFD: 0x9960,
	0xF9B1: 0x9961,
	0x9F75: 0x9962,
	0x97B0: 0x9963,
	0xFFFD: 0x9964,
	0x83E8: 0x9965,
	0xFFFD: 0x9966,
	0x8F6D: 0x9967,
	0x85AA: 0x9968,
	0x8FAC: 0x9969,
	0x85A8: 0x996A,
	0x8DFB: 0x996B,
	0x85AC: 0x996C,
	0x85A9: 0x996D,
	0x85AB: 0x996E,
	0x89B7: 0x996F,
	0x86A6: 0x9970,
	0x86A5: 0x9971,
	0x86A3: 0x9972,
	0xFFFD: 0x9973,
	0x86A4: 0x9974,
	0x8778: 0x9975,
	0x8C62: 0x9976,
	0x8779: 0x9977,
	0xFFFD: 0x9978,
	0xFFFD: 0x9979,
	0x8776: 0x997A,
	0xFFFD: 0x997B,
	0x8777: 0x997C,
	0x8EDD: 0x997D,
	0xFFFD: 0x997E,
	0x88B6: 0x997F,
	0x97B1: 0x9980,
	0x88B7: 0x9981,
	0xFFFD: 0x9982,
	0xFFFD: 0x9983,
	0x89B8: 0x9984,
	0x89B9: 0x9985,
	0x89B6: 0x9986,
	0x97B2: 0x9987,
	0x8B64: 0x9988,
	0xFFFD: 0x9989,
	0x8B63: 0x998A,
	0x8D78: 0x998B,
	0xFFFD: 0x998C,
	0x97B3: 0x998D,
	0xFFFD: 0x998E,
	0x8B62: 0x998F,
	0x8FD0: 0x9990,
	0x8BE1: 0x9991,
	0x8BE0: 0x9992,
	0x97B4: 0x9993,
	0x8FF1: 0x9994,
	0x97B5: 0x9995,
	0xADBA: 0x9996,
	0xD850: 0x9997,
	0xEF55: 0x9998,
	0xADBB: 0x9999,
	0xFFFD: 0x999A,
	0x9F76: 0x999B,
	0xE4D2: 0x999C,
	0xE4D1: 0x999D,
	0xEC60: 0x999E,
	0xFFFD: 0x999F,
	0xFFFD: 0x99A0,
	0xEF57: 0x99A1,
	0xFFFD: 0x99A2,
	0xEF56: 0x99A3,
	0x9F77: 0x99A4,
	0xC34C: 0x99A5,
	0xF3B2: 0x99A6,
	0xF3B3: 0x99A7,
	0xC4C9: 0x99A8,
	0xFFFD: 0x99A9,
	0x9F78: 0x99AA,
	0xF9B2: 0x99AB,
	0xB0A8: 0x99AC,
	0xB6BF: 0x99AD,
	0xB6BE: 0x99AE,
	0xE0E4: 0x99AF,
	0xE0E6: 0x99B0,
	0xB9A4: 0x99B1,
	0xE0E5: 0x99B2,
	0xB9A3: 0x99B3,
	0xB9A5: 0x99B4,
	0xE0E7: 0x99B5,
	0xFFFD: 0x99B6,
	0xFFFD: 0x99B7,
	0x9F79: 0x99B8,
	0xE4D4: 0x99B9,
	0xE4D6: 0x99BA,
	0xE4D5: 0x99BB,
	0x97B6: 0x99BC,
	0xE4D8: 0x99BD,
	0xFFFD: 0x99BE,
	0xFFFD: 0x99BF,
	0xFFFD: 0x99C0,
	0xBBE9: 0x99C1,
	0xE4D7: 0x99C2,
	0xE4D3: 0x99C3,
	0x944B: 0x99C4,
	0x924A: 0x99C5,
	0x92A3: 0x99C6,
	0xE4D9: 0x99C7,
	0x97B7: 0x99C8,
	0xE8CC: 0x99C9,
	0xFFFD: 0x99CA,
	0xE8CF: 0x99CB,
	0xE8D1: 0x99CC,
	0xE8C7: 0x99CD,
	0xE8CB: 0x99CE,
	0xE8C8: 0x99CF,
	0xBE6E: 0x99D0,
	0xBE71: 0x99D1,
	0xBE73: 0x99D2,
	0xE8C9: 0x99D3,
	0xE8CA: 0x99D4,
	0xBE72: 0x99D5,
	0xE8CD: 0x99D6,
	0xE8D0: 0x99D7,
	0xE8CE: 0x99D8,
	0xBE74: 0x99D9,
	0xFDE4: 0x99DA,
	0xBE70: 0x99DB,
	0xE8C6: 0x99DC,
	0xBE6D: 0x99DD,
	0xFFFD: 0x99DE,
	0xBE6F: 0x99DF,
	0x9F7A: 0x99E0,
	0x95C4: 0x99E1,
	0xC063: 0x99E2,
	0xEC66: 0x99E3,
	0xEC64: 0x99E4,
	0xEC63: 0x99E5,
	0x9F7B: 0x99E6,
	0xEC69: 0x99E7,
	0xFFFD: 0x99E8,
	0xEC68: 0x99E9,
	0xEC67: 0x99EA,
	0xFFFD: 0x99EB,
	0xEC62: 0x99EC,
	0xC062: 0x99ED,
	0xEC61: 0x99EE,
	0xFFFD: 0x99EF,
	0xEC65: 0x99F0,
	0xC064: 0x99F1,
	0x97B8: 0x99F2,
	0xFFFD: 0x99F3,
	0xEF5A: 0x99F4,
	0x9F7C: 0x99F5,
	0xEF5E: 0x99F6,
	0xEF5B: 0x99F7,
	0xEF5D: 0x99F8,
	0xEF5C: 0x99F9,
	0xEF59: 0x99FA,
	0xEF5F: 0x99FB,
	0xEF62: 0x99FC,
	0xEF60: 0x99FD,
	0xEF61: 0x99FE,
	0xC240: 0x99FF,
	0xFFFD: 0x9A00,
	0xC1FE: 0x9A01,
	0xEF58: 0x9A02,
	0xEF63: 0x9A03,
	0xF1B3: 0x9A04,
	0xF1B6: 0x9A05,
	0xF1B8: 0x9A06,
	0xF1B7: 0x9A07,
	0xFFFD: 0x9A08,
	0xF1B1: 0x9A09,
	0xF1B5: 0x9A0A,
	0xF1B0: 0x9A0B,
	0xFBB5: 0x9A0C,
	0xF1B2: 0x9A0D,
	0xC34D: 0x9A0E,
	0xF1AF: 0x9A0F,
	0x95E1: 0x9A10,
	0xF1B4: 0x9A11,
	0x935D: 0x9A12,
	0x92B9: 0x9A13,
	0xF3C0: 0x9A14,
	0xF3B5: 0x9A15,
	0xC445: 0x9A16,
	0xFFFD: 0x9A17,
	0xFFFD: 0x9A18,
	0xC446: 0x9A19,
	0xF3B4: 0x9A1A,
	0xF3B9: 0x9A1B,
	0xF3BF: 0x9A1C,
	0xF3B7: 0x9A1D,
	0xF3BE: 0x9A1E,
	0x9F7D: 0x9A1F,
	0xF3BB: 0x9A20,
	0x9AFB: 0x9A21,
	0xF3BA: 0x9A22,
	0xF3BD: 0x9A23,
	0xF3B8: 0x9A24,
	0xF3B6: 0x9A25,
	0x9AFC: 0x9A26,
	0xF3BC: 0x9A27,
	0x8255: 0x9A28,
	0xF560: 0x9A29,
	0xF55E: 0x9A2A,
	0xC4CA: 0x9A2B,
	0xF55D: 0x9A2C,
	0xF563: 0x9A2D,
	0xF561: 0x9A2E,
	0x9AFD: 0x9A2F,
	0xC4CB: 0x9A30,
	0xF55C: 0x9A31,
	0xF55A: 0x9A32,
	0xFFFD: 0x9A33,
	0xF55B: 0x9A34,
	0xC4CD: 0x9A35,
	0xF55F: 0x9A36,
	0xC4CC: 0x9A37,
	0xF562: 0x9A38,
	0xF678: 0x9A39,
	0xF67E: 0x9A3A,
	0x9CFA: 0x9A3B,
	0x9CFB: 0x9A3C,
	0xF679: 0x9A3D,
	0xC55B: 0x9A3E,
	0xF6A1: 0x9A3F,
	0xC55A: 0x9A40,
	0xF67D: 0x9A41,
	0xF67C: 0x9A42,
	0xC559: 0x9A43,
	0xF67B: 0x9A44,
	0xC558: 0x9A45,
	0xF67A: 0x9A46,
	0xFFFD: 0x9A47,
	0xF77D: 0x9A48,
	0xF7A1: 0x9A49,
	0xF77E: 0x9A4A,
	0xFFFD: 0x9A4B,
	0xF77B: 0x9A4C,
	0xC5BB: 0x9A4D,
	0xF778: 0x9A4E,
	0xF77C: 0x9A4F,
	0xF7A3: 0x9A50,
	0xFFFD: 0x9A51,
	0xF7A2: 0x9A52,
	0xF779: 0x9A53,
	0xF77A: 0x9A54,
	0xC5BA: 0x9A55,
	0xF852: 0x9A56,
	0xC5E7: 0x9A57,
	0x9CFC: 0x9A58,
	0xF853: 0x9A59,
	0xC5E5: 0x9A5A,
	0xC5E6: 0x9A5B,
	0x9CFD: 0x9A5C,
	0xFFFD: 0x9A5D,
	0xF8D3: 0x9A5E,
	0xC64A: 0x9A5F,
	0xF976: 0x9A60,
	0xFFFD: 0x9A61,
	0xC66A: 0x9A62,
	0x9CFE: 0x9A63,
	0xF9B3: 0x9A64,
	0xC66B: 0x9A65,
	0xF9B4: 0x9A66,
	0xF9B5: 0x9A67,
	0xF9C3: 0x9A68,
	0xF9C2: 0x9A69,
	0xC67A: 0x9A6A,
	0xF9CD: 0x9A6B,
	0x83E9: 0x9A6C,
	0x85AE: 0x9A6D,
	0x86A8: 0x9A6E,
	0x86A9: 0x9A6F,
	0x86A7: 0x9A70,
	0x8CBB: 0x9A71,
	0xFFFD: 0x9A72,
	0x877A: 0x9A73,
	0x8DA1: 0x9A74,
	0x8EDE: 0x9A75,
	0x88BB: 0x9A76,
	0x88BA: 0x9A77,
	0x88BF: 0x9A78,
	0x88BE: 0x9A79,
	0x8FF2: 0x9A7A,
	0x88B9: 0x9A7B,
	0x88B8: 0x9A7C,
	0x88BC: 0x9A7D,
	0x88BD: 0x9A7E,
	0x8D49: 0x9A7F,
	0x8EDF: 0x9A80,
	0x8CEB: 0x9A81,
	0x884C: 0x9A82,
	0xFFFD: 0x9A83,
	0x8CEA: 0x9A84,
	0x9063: 0x9A85,
	0x89BC: 0x9A86,
	0x89BA: 0x9A87,
	0x89BB: 0x9A88,
	0xFFFD: 0x9A89,
	0x8DAF: 0x9A8A,
	0x8AB3: 0x9A8B,
	0x8D4A: 0x9A8C,
	0xFFFD: 0x9A8D,
	0xFFFD: 0x9A8E,
	0x8AB4: 0x9A8F,
	0x8FAD: 0x9A90,
	0x8B65: 0x9A91,
	0x8FAE: 0x9A92,
	0x8FAF: 0x9A93,
	0xFFFD: 0x9A94,
	0xFFFD: 0x9A95,
	0x904C: 0x9A96,
	0x8BE3: 0x9A97,
	0x8FF5: 0x9A98,
	0xFFFD: 0x9A99,
	0x8C66: 0x9A9A,
	0x8BE2: 0x9A9B,
	0x904D: 0x9A9C,
	0x8FF3: 0x9A9D,
	0x8C64: 0x9A9E,
	0x8FF4: 0x9A9F,
	0x8CBC: 0x9AA0,
	0x8CBE: 0x9AA1,
	0x904B: 0x9AA2,
	0x9062: 0x9AA3,
	0x8D62: 0x9AA4,
	0x8DA2: 0x9AA5,
	0xFFFD: 0x9AA6,
	0x90A9: 0x9AA7,
	0xB0A9: 0x9AA8,
	0xFFFD: 0x9AA9,
	0xFFFD: 0x9AAA,
	0xE0E9: 0x9AAB,
	0xFFFD: 0x9AAC,
	0xE0E8: 0x9AAD,
	0xFFFD: 0x9AAE,
	0xBBEA: 0x9AAF,
	0xBBEB: 0x9AB0,
	0xE4DA: 0x9AB1,
	0x9DB0: 0x9AB2,
	0xE8D2: 0x9AB3,
	0xEC6C: 0x9AB4,
	0xFFFD: 0x9AB5,
	0x97B9: 0x9AB6,
	0xBE75: 0x9AB7,
	0xC065: 0x9AB8,
	0xEC6A: 0x9AB9,
	0xFDE6: 0x9ABA,
	0xEC6D: 0x9ABB,
	0xC066: 0x9ABC,
	0xFDE7: 0x9ABD,
	0xEF64: 0x9ABE,
	0xEC6B: 0x9ABF,
	0xF1B9: 0x9AC0,
	0xC34E: 0x9AC1,
	0xF3C1: 0x9AC2,
	0xFFFD: 0x9AC3,
	0x92FB: 0x9AC4,
	0x8CBF: 0x9AC5,
	0xF566: 0x9AC6,
	0xF564: 0x9AC7,
	0xFFFD: 0x9AC8,
	0xFFFD: 0x9AC9,
	0xF565: 0x9ACA,
	0x8D79: 0x9ACB,
	0x9079: 0x9ACC,
	0xF6A2: 0x9ACD,
	0xFFFD: 0x9ACE,
	0xC55C: 0x9ACF,
	0xF7A4: 0x9AD0,
	0xC5EA: 0x9AD1,
	0xC5BC: 0x9AD2,
	0xC5E8: 0x9AD3,
	0xC5E9: 0x9AD4,
	0xF8D4: 0x9AD5,
	0xC662: 0x9AD6,
	0xFBB6: 0x9AD7,
	0xB0AA: 0x9AD8,
	0x97BA: 0x9AD9,
	0xFFFD: 0x9ADA,
	0xFFFD: 0x9ADB,
	0xF1BA: 0x9ADC,
	0xFFFD: 0x9ADD,
	0x97BB: 0x9ADE,
	0xD449: 0x9ADF,
	0x9DB1: 0x9AE0,
	0xB9A6: 0x9AE1,
	0xFDEC: 0x9AE2,
	0xE4DB: 0x9AE3,
	0xFFFD: 0x9AE4,
	0xFFFD: 0x9AE5,
	0xBBEC: 0x9AE6,
	0xE4DC: 0x9AE7,
	0xFFFD: 0x9AE8,
	0xFFFD: 0x9AE9,
	0x93BA: 0x9AEA,
	0xE8D4: 0x9AEB,
	0xE8D3: 0x9AEC,
	0xC068: 0x9AED,
	0xBE76: 0x9AEE,
	0xBE77: 0x9AEF,
	0xFFFD: 0x9AF0,
	0xE8D7: 0x9AF1,
	0xE8D6: 0x9AF2,
	0xE8D5: 0x9AF3,
	0xFE57: 0x9AF4,
	0xFFFD: 0x9AF5,
	0xEC6E: 0x9AF6,
	0xEC71: 0x9AF7,
	0xFFFD: 0x9AF8,
	0xEC70: 0x9AF9,
	0xEC6F: 0x9AFA,
	0xC067: 0x9AFB,
	0xEF68: 0x9AFC,
	0xEF66: 0x9AFD,
	0xEF65: 0x9AFE,
	0xFDEE: 0x9AFF,
	0xFFFD: 0x9B00,
	0xEF67: 0x9B01,
	0xFDED: 0x9B02,
	0xC34F: 0x9B03,
	0xF1BC: 0x9B04,
	0xF1BD: 0x9B05,
	0xC350: 0x9B06,
	0xFFFD: 0x9B07,
	0xF1BB: 0x9B08,
	0xFDF0: 0x9B09,
	0xF3C3: 0x9B0A,
	0xF3C2: 0x9B0B,
	0xF3C5: 0x9B0C,
	0xC447: 0x9B0D,
	0xF3C4: 0x9B0E,
	0x97BC: 0x9B0F,
	0xF567: 0x9B10,
	0xF569: 0x9B11,
	0xF568: 0x9B12,
	0x8D63: 0x9B13,
	0x9DB2: 0x9B14,
	0xF6A3: 0x9B15,
	0xF6A6: 0x9B16,
	0xF6A4: 0x9B17,
	0xF6A5: 0x9B18,
	0xF7A5: 0x9B19,
	0xC5BD: 0x9B1A,
	0xFFFD: 0x9B1B,
	0xFFFD: 0x9B1C,
	0xFFFD: 0x9B1D,
	0xF854: 0x9B1E,
	0xF855: 0x9B1F,
	0xF856: 0x9B20,
	0xFFFD: 0x9B21,
	0xC64B: 0x9B22,
	0xC663: 0x9B23,
	0xF9B6: 0x9B24,
	0xB0AB: 0x9B25,
	0xFFFD: 0x9B26,
	0xBE78: 0x9B27,
	0xC069: 0x9B28,
	0xF1BE: 0x9B29,
	0xFDE9: 0x9B2A,
	0xF7A6: 0x9B2B,
	0xFFFD: 0x9B2C,
	0xFDEB: 0x9B2D,
	0xF9C4: 0x9B2E,
	0xD44A: 0x9B2F,
	0xFFFD: 0x9B30,
	0xC67B: 0x9B31,
	0xB0AC: 0x9B32,
	0xEC72: 0x9B33,
	0x9DB3: 0x9B34,
	0xF1BF: 0x9B35,
	0xFFFD: 0x9B36,
	0xF3C6: 0x9B37,
	0xFFFD: 0x9B38,
	0x9DB4: 0x9B39,
	0xF6A7: 0x9B3A,
	0xF7A7: 0x9B3B,
	0xB0AD: 0x9B3C,
	0xFFFD: 0x9B3D,
	0xE4DD: 0x9B3E,
	0xE4DE: 0x9B3F,
	0x9DB5: 0x9B40,
	0xBBED: 0x9B41,
	0xBBEE: 0x9B42,
	0xE8D9: 0x9B43,
	0xBE7A: 0x9B44,
	0xBE79: 0x9B45,
	0xE8D8: 0x9B46,
	0x8D64: 0x9B47,
	0xEF69: 0x9B48,
	0x97BD: 0x9B49,
	0xF1C0: 0x9B4A,
	0xF1C2: 0x9B4B,
	0xF1C1: 0x9B4C,
	0xC353: 0x9B4D,
	0xC352: 0x9B4E,
	0xC351: 0x9B4F,
	0x9DB6: 0x9B50,
	0xC55E: 0x9B51,
	0xF6A8: 0x9B52,
	0xFFFD: 0x9B53,
	0xC55D: 0x9B54,
	0xF7A9: 0x9B55,
	0xF7A8: 0x9B56,
	0xFFFD: 0x9B57,
	0xC64C: 0x9B58,
	0xF8D5: 0x9B59,
	0xB3BD: 0x9B5A,
	0xE0EA: 0x9B5B,
	0xFFFD: 0x9B5C,
	0xFFFD: 0x9B5D,
	0xFFFD: 0x9B5E,
	0xE4E1: 0x9B5F,
	0xE4DF: 0x9B60,
	0xE4E0: 0x9B61,
	0xFFFD: 0x9B62,
	0xFFFD: 0x9B63,
	0xE8E2: 0x9B64,
	0xFFFD: 0x9B65,
	0xE8DD: 0x9B66,
	0xE8DA: 0x9B67,
	0xE8E1: 0x9B68,
	0xFEAF: 0x9B69,
	0xFFFD: 0x9B6A,
	0xFFFD: 0x9B6B,
	0xE8E3: 0x9B6C,
	0xFFFD: 0x9B6D,
	0xFFFD: 0x9B6E,
	0xBE7C: 0x9B6F,
	0xE8E0: 0x9B70,
	0xE8DC: 0x9B71,
	0x97BE: 0x9B72,
	0xFFFD: 0x9B73,
	0xE8DB: 0x9B74,
	0xE8DF: 0x9B75,
	0xE8DE: 0x9B76,
	0xBE7B: 0x9B77,
	0xFFFD: 0x9B78,
	0xFFFD: 0x9B79,
	0xEC7D: 0x9B7A,
	0xEC78: 0x9B7B,
	0xEC76: 0x9B7C,
	0xECA1: 0x9B7D,
	0xEC77: 0x9B7E,
	0x9DB7: 0x9B7F,
	0xEC73: 0x9B80,
	0x9DEE: 0x9B81,
	0xEC79: 0x9B82,
	0x97BF: 0x9B83,
	0xFFFD: 0x9B84,
	0xEC74: 0x9B85,
	0xEF72: 0x9B86,
	0xEC75: 0x9B87,
	0xECA2: 0x9B88,
	0xFFFD: 0x9B89,
	0xFFFD: 0x9B8A,
	0x9DEF: 0x9B8B,
	0xFFFD: 0x9B8C,
	0x9DF0: 0x9B8D,
	0x94FE: 0x9B8E,
	0xFDF3: 0x9B8F,
	0xEC7C: 0x9B90,
	0xC06A: 0x9B91,
	0xEC7B: 0x9B92,
	0xEC7A: 0x9B93,
	0xFFFD: 0x9B94,
	0xEC7E: 0x9B95,
	0x94E3: 0x9B96,
	0x94E4: 0x9B97,
	0xFFFD: 0x9B98,
	0xFFFD: 0x9B99,
	0xEF6A: 0x9B9A,
	0xEF6D: 0x9B9B,
	0xFFFD: 0x9B9C,
	0xFDF4: 0x9B9D,
	0xEF6C: 0x9B9E,
	0x97C0: 0x9B9F,
	0xEF74: 0x9BA0,
	0xEF6F: 0x9BA1,
	0xEF73: 0x9BA2,
	0xFFFD: 0x9BA3,
	0xEF71: 0x9BA4,
	0xEF70: 0x9BA5,
	0xEF6E: 0x9BA6,
	0xFFFD: 0x9BA7,
	0xEF6B: 0x9BA8,
	0xFFFD: 0x9BA9,
	0xC243: 0x9BAA,
	0xC242: 0x9BAB,
	0xFFFD: 0x9BAC,
	0xC244: 0x9BAD,
	0xC241: 0x9BAE,
	0xEF75: 0x9BAF,
	0xFDF5: 0x9BB0,
	0x94F5: 0x9BB1,
	0xFFFD: 0x9BB2,
	0xFFFD: 0x9BB3,
	0x94E5: 0x9BB4,
	0xF1C8: 0x9BB5,
	0xF1CB: 0x9BB6,
	0xFFFD: 0x9BB7,
	0xF1C9: 0x9BB8,
	0xF1CD: 0x9BB9,
	0xFFFD: 0x9BBA,
	0x97C1: 0x9BBB,
	0xFFFD: 0x9BBC,
	0xF1CE: 0x9BBD,
	0xFFFD: 0x9BBE,
	0xF1C6: 0x9BBF,
	0xC358: 0x9BC0,
	0xF1C7: 0x9BC1,
	0xFFFD: 0x9BC2,
	0xF1C5: 0x9BC3,
	0xF1CC: 0x9BC4,
	0xFFFD: 0x9BC5,
	0xF1C4: 0x9BC6,
	0xF1C3: 0x9BC7,
	0xC357: 0x9BC8,
	0xC355: 0x9BC9,
	0xC354: 0x9BCA,
	0xFFFD: 0x9BCB,
	0xFFFD: 0x9BCC,
	0xFFFD: 0x9BCD,
	0xFFFD: 0x9BCE,
	0x94E6: 0x9BCF,
	0xFFFD: 0x9BD0,
	0x94E7: 0x9BD1,
	0x94E8: 0x9BD2,
	0xF1CA: 0x9BD3,
	0xF3CF: 0x9BD4,
	0xF3D5: 0x9BD5,
	0xC44A: 0x9BD6,
	0xF3D0: 0x9BD7,
	0xFFFD: 0x9BD8,
	0xF3D3: 0x9BD9,
	0xF3D7: 0x9BDA,
	0xC44B: 0x9BDB,
	0xF3D2: 0x9BDC,
	0x9DF1: 0x9BDD,
	0xF3CA: 0x9BDE,
	0xFFFD: 0x9BDF,
	0xF3C9: 0x9BE0,
	0xF3D6: 0x9BE1,
	0xF3CD: 0x9BE2,
	0x97C2: 0x9BE3,
	0xF3CB: 0x9BE4,
	0xF3D4: 0x9BE5,
	0xF3CC: 0x9BE6,
	0xC449: 0x9BE7,
	0xC448: 0x9BE8,
	0x9DF2: 0x9BE9,
	0xF3C7: 0x9BEA,
	0xF3C8: 0x9BEB,
	0xF3D1: 0x9BEC,
	0x9DF3: 0x9BED,
	0xFFFD: 0x9BEE,
	0xFFFD: 0x9BEF,
	0xF3CE: 0x9BF0,
	0x94EA: 0x9BF1,
	0x94E9: 0x9BF2,
	0xFFFD: 0x9BF3,
	0x9DF4: 0x9BF4,
	0x97C3: 0x9BF5,
	0xFFFD: 0x9BF6,
	0xF56C: 0x9BF7,
	0xF56F: 0x9BF8,
	0xFFFD: 0x9BF9,
	0xFFFD: 0x9BFA,
	0xFFFD: 0x9BFB,
	0xFFFD: 0x9BFC,
	0xC356: 0x9BFD,
	0xFFFD: 0x9BFE,
	0xFDF9: 0x9BFF,
	0x97C4: 0x9C00,
	0xFFFD: 0x9C01,
	0xFE50: 0x9C02,
	0xFFFD: 0x9C03,
	0x97C5: 0x9C04,
	0xF56D: 0x9C05,
	0xF573: 0x9C06,
	0xF571: 0x9C07,
	0xF56B: 0x9C08,
	0xF576: 0x9C09,
	0xFDF8: 0x9C0A,
	0xF56A: 0x9C0B,
	0xFDF6: 0x9C0C,
	0xC4CF: 0x9C0D,
	0xF572: 0x9C0E,
	0xFFFD: 0x9C0F,
	0x95FD: 0x9C10,
	0xFFFD: 0x9C11,
	0xF56E: 0x9C12,
	0xC4CE: 0x9C13,
	0xF575: 0x9C14,
	0xFDF7: 0x9C15,
	0xFFFD: 0x9C16,
	0xF574: 0x9C17,
	0xFFFD: 0x9C18,
	0xFFFD: 0x9C19,
	0xFFFD: 0x9C1A,
	0x97C6: 0x9C1B,
	0xF6AB: 0x9C1C,
	0xF6AA: 0x9C1D,
	0xFFFD: 0x9C1E,
	0x9DF5: 0x9C1F,
	0x9DF6: 0x9C20,
	0xF6B1: 0x9C21,
	0xFFFD: 0x9C22,
	0xF6AD: 0x9C23,
	0xF6B0: 0x9C24,
	0xC560: 0x9C25,
	0x9DF7: 0x9C26,
	0xFFFD: 0x9C27,
	0xF6AE: 0x9C28,
	0xF6AF: 0x9C29,
	0xFFFD: 0x9C2A,
	0xF6A9: 0x9C2B,
	0xF6AC: 0x9C2C,
	0xC55F: 0x9C2D,
	0xFDFA: 0x9C2E,
	0x94F9: 0x9C2F,
	0x94EB: 0x9C30,
	0xC5BF: 0x9C31,
	0xF7B4: 0x9C32,
	0xF7AF: 0x9C33,
	0xF7B3: 0x9C34,
	0xFD53: 0x9C35,
	0xF7B6: 0x9C36,
	0xF7B2: 0x9C37,
	0xFFFD: 0x9C38,
	0xF7AE: 0x9C39,
	0xFCCB: 0x9C3A,
	0xC5C1: 0x9C3B,
	0xF7B1: 0x9C3C,
	0xF7B5: 0x9C3D,
	0xC5C0: 0x9C3E,
	0xF7AC: 0x9C3F,
	0xF570: 0x9C40,
	0xF7B0: 0x9C41,
	0xFFFD: 0x9C42,
	0xFFFD: 0x9C43,
	0xF7AD: 0x9C44,
	0xFD70: 0x9C45,
	0xF7AA: 0x9C46,
	0x94EC: 0x9C47,
	0xF7AB: 0x9C48,
	0xC5BE: 0x9C49,
	0xF85A: 0x9C4A,
	0xF85C: 0x9C4B,
	0xF85F: 0x9C4C,
	0xF85B: 0x9C4D,
	0xF860: 0x9C4E,
	0x9F50: 0x9C4F,
	0xF859: 0x9C50,
	0xFFFD: 0x9C51,
	0xF857: 0x9C52,
	0x9DF8: 0x9C53,
	0xC5EB: 0x9C54,
	0xF85D: 0x9C55,
	0xC5ED: 0x9C56,
	0xC5EC: 0x9C57,
	0xF858: 0x9C58,
	0xF85E: 0x9C59,
	0x94ED: 0x9C5A,
	0xFFFD: 0x9C5B,
	0xFFFD: 0x9C5C,
	0x9DF9: 0x9C5D,
	0xF8DA: 0x9C5E,
	0xC64D: 0x9C5F,
	0xF8DB: 0x9C60,
	0xFFFD: 0x9C61,
	0xF8D9: 0x9C62,
	0xF8D6: 0x9C63,
	0xFFFD: 0x9C64,
	0xFFFD: 0x9C65,
	0xF8D8: 0x9C66,
	0xF8D7: 0x9C67,
	0xF95A: 0x9C68,
	0x94F6: 0x9C69,
	0xFFFD: 0x9C6A,
	0xFFFD: 0x9C6B,
	0xFFFD: 0x9C6C,
	0xF95C: 0x9C6D,
	0xF95B: 0x9C6E,
	0xFFFD: 0x9C6F,
	0xFFFD: 0x9C70,
	0xF979: 0x9C71,
	0xFB78: 0x9C72,
	0xF978: 0x9C73,
	0xF977: 0x9C74,
	0xF97A: 0x9C75,
	0x9840: 0x9C76,
	0xC673: 0x9C77,
	0xC674: 0x9C78,
	0xF9CA: 0x9C79,
	0xF9CE: 0x9C7A,
	0x9DFA: 0x9C7B,
	0x84BE: 0x9C7C,
	0xFFFD: 0x9C7D,
	0xFFFD: 0x9C7E,
	0x88C2: 0x9C7F,
	0xFFFD: 0x9C80,
	0x88C3: 0x9C81,
	0x8EE0: 0x9C82,
	0xFFFD: 0x9C83,
	0xFFFD: 0x9C84,
	0x984B: 0x9C85,
	0x984C: 0x9C86,
	0x984D: 0x9C87,
	0x8DAB: 0x9C88,
	0xFFFD: 0x9C89,
	0xFFFD: 0x9C8A,
	0x984E: 0x9C8B,
	0xFFFD: 0x9C8C,
	0x89BF: 0x9C8D,
	0x8D65: 0x9C8E,
	0xFFFD: 0x9C8F,
	0x984F: 0x9C90,
	0x8AB8: 0x9C91,
	0x8F6E: 0x9C92,
	0xFFFD: 0x9C93,
	0x8AB7: 0x9C94,
	0x8F6F: 0x9C95,
	0xFFFD: 0x9C96,
	0x90F2: 0x9C97,
	0xFFFD: 0x9C98,
	0xFFFD: 0x9C99,
	0x90A2: 0x9C9A,
	0x8AB6: 0x9C9B,
	0x8AB5: 0x9C9C,
	0xFFFD: 0x9C9D,
	0x9850: 0x9C9E,
	0x9070: 0x9C9F,
	0x8FB2: 0x9CA0,
	0x90AD: 0x9CA1,
	0x8CED: 0x9CA2,
	0x9065: 0x9CA3,
	0x8B68: 0x9CA4,
	0x904E: 0x9CA5,
	0x9066: 0x9CA6,
	0x8B6A: 0x9CA7,
	0x8B67: 0x9CA8,
	0x8FB1: 0x9CA9,
	0xFFFD: 0x9CAA,
	0x8B69: 0x9CAB,
	0xFFFD: 0x9CAC,
	0x8BE6: 0x9CAD,
	0x9851: 0x9CAE,
	0xFFFD: 0x9CAF,
	0x9852: 0x9CB0,
	0x8FD5: 0x9CB1,
	0x9853: 0x9CB2,
	0x8BE5: 0x9CB3,
	0x9854: 0x9CB4,
	0x8FD2: 0x9CB5,
	0x8FD3: 0x9CB6,
	0x8BE7: 0x9CB7,
	0x8BE4: 0x9CB8,
	0xFFFD: 0x9CB9,
	0x9855: 0x9CBA,
	0x8FD4: 0x9CBB,
	0x9856: 0x9CBC,
	0x9857: 0x9CBD,
	0xFFFD: 0x9CBE,
	0xFFFD: 0x9CBF,
	0xFFFD: 0x9CC0,
	0xFFFD: 0x9CC1,
	0xFFFD: 0x9CC2,
	0x8C67: 0x9CC3,
	0x8DAA: 0x9CC4,
	0x8C68: 0x9CC5,
	0x9858: 0x9CC6,
	0x9859: 0x9CC7,
	0xFFFD: 0x9CC8,
	0xFFFD: 0x9CC9,
	0x985A: 0x9CCA,
	0x985B: 0x9CCB,
	0x8D6A: 0x9CCC,
	0x8CC0: 0x9CCD,
	0x904F: 0x9CCE,
	0x8CC1: 0x9CCF,
	0x9050: 0x9CD0,
	0xFFFD: 0x9CD1,
	0xFFFD: 0x9CD2,
	0x985C: 0x9CD3,
	0x8CEE: 0x9CD4,
	0x9064: 0x9CD5,
	0x8CEC: 0x9CD6,
	0x8CEF: 0x9CD7,
	0x985D: 0x9CD8,
	0x985E: 0x9CD9,
	0xFFFD: 0x9CDA,
	0xFFFD: 0x9CDB,
	0x8D4F: 0x9CDC,
	0x8D4D: 0x9CDD,
	0x8D4E: 0x9CDE,
	0x906F: 0x9CDF,
	0xFFFD: 0x9CE0,
	0xFFFD: 0x9CE1,
	0x985F: 0x9CE2,
	0xFFFD: 0x9CE3,
	0xFFFD: 0x9CE4,
	0xB3BE: 0x9CE5,
	0xDCAF: 0x9CE6,
	0xE0ED: 0x9CE7,
	0xFFFD: 0x9CE8,
	0xB9A7: 0x9CE9,
	0xE0EB: 0x9CEA,
	0x9860: 0x9CEB,
	0x9861: 0x9CEC,
	0xE0EC: 0x9CED,
	0xFFFD: 0x9CEE,
	0xFFFD: 0x9CEF,
	0x94EE: 0x9CF0,
	0xE4E2: 0x9CF1,
	0xE4E3: 0x9CF2,
	0xBBF1: 0x9CF3,
	0xBBEF: 0x9CF4,
	0xE4E4: 0x9CF5,
	0xBBF0: 0x9CF6,
	0xE8E8: 0x9CF7,
	0xFFFD: 0x9CF8,
	0xE8EB: 0x9CF9,
	0xE8E5: 0x9CFA,
	0xE8EC: 0x9CFB,
	0xE8E4: 0x9CFC,
	0xE8E6: 0x9CFD,
	0xFFFD: 0x9CFE,
	0xE8E7: 0x9CFF,
	0xE8EA: 0x9D00,
	0xFFFD: 0x9D01,
	0xFD61: 0x9D02,
	0xBEA1: 0x9D03,
	0xE8EF: 0x9D04,
	0xE8EE: 0x9D05,
	0xBE7D: 0x9D06,
	0xE8E9: 0x9D07,
	0xE8ED: 0x9D08,
	0xBE7E: 0x9D09,
	0xFFFD: 0x9D0A,
	0xFFFD: 0x9D0B,
	0x9DFB: 0x9D0C,
	0xFFFD: 0x9D0D,
	0x8248: 0x9D0E,
	0xFFFD: 0x9D0F,
	0xECAC: 0x9D10,
	0xFFFD: 0x9D11,
	0xC06F: 0x9D12,
	0xFFFD: 0x9D13,
	0xECA7: 0x9D14,
	0xC06B: 0x9D15,
	0x9DFC: 0x9D16,
	0xECA4: 0x9D17,
	0xECAA: 0x9D18,
	0xECAD: 0x9D19,
	0xFFFD: 0x9D1A,
	0xC070: 0x9D1B,
	0xFFFD: 0x9D1C,
	0xECA9: 0x9D1D,
	0xECA6: 0x9D1E,
	0xECAE: 0x9D1F,
	0xECA5: 0x9D20,
	0x9F40: 0x9D21,
	0xECAB: 0x9D22,
	0xC06C: 0x9D23,
	0xFFFD: 0x9D24,
	0xECA3: 0x9D25,
	0xC06D: 0x9D26,
	0xFFFD: 0x9D27,
	0xC06E: 0x9D28,
	0xECA8: 0x9D29,
	0x9862: 0x9D2A,
	0x9447: 0x9D2B,
	0x8247: 0x9D2C,
	0xEFA9: 0x9D2D,
	0xEF7A: 0x9D2E,
	0xEF7B: 0x9D2F,
	0xEF7E: 0x9D30,
	0xEF7C: 0x9D31,
	0xFFFD: 0x9D32,
	0xEF76: 0x9D33,
	0x9F41: 0x9D34,
	0xFFFD: 0x9D35,
	0xEF79: 0x9D36,
	0xEFA5: 0x9D37,
	0xEF7D: 0x9D38,
	0x9F42: 0x9D39,
	0xFFFD: 0x9D3A,
	0xC245: 0x9D3B,
	0xFFFD: 0x9D3C,
	0xEFA7: 0x9D3D,
	0xEFA4: 0x9D3E,
	0xC246: 0x9D3F,
	0xEFA6: 0x9D40,
	0xEF77: 0x9D41,
	0xEFA2: 0x9D42,
	0xEFA3: 0x9D43,
	0xFDAA: 0x9D44,
	0xEFA1: 0x9D45,
	0x94EF: 0x9D46,
	0x94F7: 0x9D47,
	0x9863: 0x9D48,
	0x9F43: 0x9D49,
	0xF1D2: 0x9D4A,
	0xF1D4: 0x9D4B,
	0xF1D7: 0x9D4C,
	0xFFFD: 0x9D4D,
	0x9F44: 0x9D4E,
	0xF1D1: 0x9D4F,
	0x9864: 0x9D50,
	0xC359: 0x9D51,
	0xF1D9: 0x9D52,
	0xF1D0: 0x9D53,
	0xF1DA: 0x9D54,
	0xFFFD: 0x9D55,
	0xF1D6: 0x9D56,
	0xF1D8: 0x9D57,
	0xF1DC: 0x9D58,
	0xF1D5: 0x9D59,
	0xF1DD: 0x9D5A,
	0xF1D3: 0x9D5B,
	0xF1CF: 0x9D5C,
	0xC35A: 0x9D5D,
	0x9572: 0x9D5E,
	0xF1DB: 0x9D5F,
	0xC35B: 0x9D60,
	0xC44D: 0x9D61,
	0xFFFD: 0x9D62,
	0xFFFD: 0x9D63,
	0x94F0: 0x9D64,
	0x94F8: 0x9D65,
	0xFFFD: 0x9D66,
	0xEF78: 0x9D67,
	0xF3F1: 0x9D68,
	0xF3E8: 0x9D69,
	0xC44F: 0x9D6A,
	0xF3E4: 0x9D6B,
	0xC450: 0x9D6C,
	0x9F45: 0x9D6D,
	0x9F47: 0x9D6E,
	0xF3ED: 0x9D6F,
	0xF3E7: 0x9D70,
	0xF3DD: 0x9D71,
	0xC44E: 0x9D72,
	0xF3EA: 0x9D73,
	0xF3E5: 0x9D74,
	0xF3E6: 0x9D75,
	0xFFFD: 0x9D76,
	0xF3D8: 0x9D77,
	0xF3DF: 0x9D78,
	0xF3EE: 0x9D79,
	0x9865: 0x9D7A,
	0xF3EB: 0x9D7B,
	0x9F48: 0x9D7C,
	0xF3E3: 0x9D7D,
	0xFCC6: 0x9D7E,
	0xF3EF: 0x9D7F,
	0xF3DE: 0x9D80,
	0xF3D9: 0x9D81,
	0xF3EC: 0x9D82,
	0x9F49: 0x9D83,
	0xF3DB: 0x9D84,
	0xF3E9: 0x9D85,
	0xF3E0: 0x9D86,
	0xF3F0: 0x9D87,
	0xF3DC: 0x9D88,
	0xC44C: 0x9D89,
	0xF3DA: 0x9D8A,
	0xF3E1: 0x9D8B,
	0xF3E2: 0x9D8C,
	0xFFFD: 0x9D8D,
	0xFFFD: 0x9D8E,
	0x92AF: 0x9D8F,
	0xF57D: 0x9D90,
	0xFFFD: 0x9D91,
	0xF57B: 0x9D92,
	0x9F4A: 0x9D93,
	0xF5A2: 0x9D94,
	0xFFFD: 0x9D95,
	0xF5AE: 0x9D96,
	0xF5A5: 0x9D97,
	0xF57C: 0x9D98,
	0xF578: 0x9D99,
	0xF5A7: 0x9D9A,
	0xF57E: 0x9D9B,
	0xF5A3: 0x9D9C,
	0xF57A: 0x9D9D,
	0xF5AA: 0x9D9E,
	0xF577: 0x9D9F,
	0xF5A1: 0x9DA0,
	0xF5A6: 0x9DA1,
	0xF5A8: 0x9DA2,
	0xF5AB: 0x9DA3,
	0xF579: 0x9DA4,
	0x9F4B: 0x9DA5,
	0xF5AF: 0x9DA6,
	0xF5B0: 0x9DA7,
	0xF5A9: 0x9DA8,
	0xF5AD: 0x9DA9,
	0xF5A4: 0x9DAA,
	0x94F1: 0x9DAB,
	0xF6C1: 0x9DAC,
	0xF6C4: 0x9DAD,
	0xFFFD: 0x9DAE,
	0xC561: 0x9DAF,
	0xFFFD: 0x9DB0,
	0xF6C3: 0x9DB1,
	0xF6C8: 0x9DB2,
	0xF6C6: 0x9DB3,
	0xC562: 0x9DB4,
	0xF6BD: 0x9DB5,
	0xF6B3: 0x9DB6,
	0xF6B2: 0x9DB7,
	0xC564: 0x9DB8,
	0xF6BF: 0x9DB9,
	0xF6C0: 0x9DBA,
	0xF6BC: 0x9DBB,
	0xF6B4: 0x9DBC,
	0x9F4D: 0x9DBD,
	0xF6B9: 0x9DBE,
	0xF5AC: 0x9DBF,
	0x9F52: 0x9DC0,
	0xF6B5: 0x9DC1,
	0xC563: 0x9DC2,
	0xF6BB: 0x9DC3,
	0x9575: 0x9DC4,
	0xF6BA: 0x9DC5,
	0x9866: 0x9DC6,
	0xF6B6: 0x9DC7,
	0xF6C2: 0x9DC8,
	0x9F5E: 0x9DC9,
	0xF6B7: 0x9DCA,
	0xF7BB: 0x9DCB,
	0xF6C5: 0x9DCC,
	0xF6C7: 0x9DCD,
	0xF6BE: 0x9DCE,
	0xF6B8: 0x9DCF,
	0xF7BC: 0x9DD0,
	0xF7BE: 0x9DD1,
	0xF7B8: 0x9DD2,
	0xC5C2: 0x9DD3,
	0x9F5F: 0x9DD4,
	0xF7C5: 0x9DD5,
	0xF7C3: 0x9DD6,
	0xC5C3: 0x9DD7,
	0xF7C2: 0x9DD8,
	0xF7C1: 0x9DD9,
	0xF7BA: 0x9DDA,
	0xF7B7: 0x9DDB,
	0xF7BD: 0x9DDC,
	0xF7C6: 0x9DDD,
	0xF7B9: 0x9DDE,
	0xF7BF: 0x9DDF,
	0xFFFD: 0x9DE0,
	0xF869: 0x9DE1,
	0xF86E: 0x9DE2,
	0xF864: 0x9DE3,
	0xF867: 0x9DE4,
	0xC5EE: 0x9DE5,
	0xF86B: 0x9DE6,
	0xFFFD: 0x9DE7,
	0xF872: 0x9DE8,
	0xF7C0: 0x9DE9,
	0xFFFD: 0x9DEA,
	0xF865: 0x9DEB,
	0xF86F: 0x9DEC,
	0xF873: 0x9DED,
	0xF86A: 0x9DEE,
	0xF863: 0x9DEF,
	0xF86D: 0x9DF0,
	0xFFFD: 0x9DF1,
	0xF86C: 0x9DF2,
	0xF871: 0x9DF3,
	0xF870: 0x9DF4,
	0xF7C4: 0x9DF5,
	0xF868: 0x9DF6,
	0xF862: 0x9DF7,
	0xF866: 0x9DF8,
	0xC64E: 0x9DF9,
	0xC64F: 0x9DFA,
	0xF861: 0x9DFB,
	0x9F60: 0x9DFC,
	0xF8E6: 0x9DFD,
	0xF8DD: 0x9DFE,
	0xF8E5: 0x9DFF,
	0xF8E2: 0x9E00,
	0xF8E3: 0x9E01,
	0xF8DC: 0x9E02,
	0xF8DF: 0x9E03,
	0xF8E7: 0x9E04,
	0xF8E1: 0x9E05,
	0xF8E0: 0x9E06,
	0xF8DE: 0x9E07,
	0xFFFD: 0x9E08,
	0xF8E4: 0x9E09,
	0x9F61: 0x9E0A,
	0xF95D: 0x9E0B,
	0x9F62: 0x9E0C,
	0xF95E: 0x9E0D,
	0x9F63: 0x9E0E,
	0xF960: 0x9E0F,
	0xF95F: 0x9E10,
	0xF962: 0x9E11,
	0xF961: 0x9E12,
	0xF97C: 0x9E13,
	0xF97B: 0x9E14,
	0xF9B7: 0x9E15,
	0xFFFD: 0x9E16,
	0xF9B8: 0x9E17,
	0x9F64: 0x9E18,
	0xF9C5: 0x9E19,
	0xC678: 0x9E1A,
	0xC67C: 0x9E1B,
	0xFD4A: 0x9E1C,
	0xF9CF: 0x9E1D,
	0xC67D: 0x9E1E,
	0x84BF: 0x9E1F,
	0x86AA: 0x9E20,
	0x8B5C: 0x9E21,
	0x877E: 0x9E22,
	0x877D: 0x9E23,
	0xFFFD: 0x9E24,
	0x8CF1: 0x9E25,
	0x88C5: 0x9E26,
	0xFFFD: 0x9E27,
	0x8EE1: 0x9E28,
	0x88C4: 0x9E29,
	0x89C1: 0x9E2A,
	0x8FD7: 0x9E2B,
	0x90AA: 0x9E2C,
	0x89C3: 0x9E2D,
	0xFFFD: 0x9E2E,
	0x89C2: 0x9E2F,
	0xFFFD: 0x9E30,
	0x8F4E: 0x9E31,
	0x8F4D: 0x9E32,
	0x89C4: 0x9E33,
	0xFFFD: 0x9E34,
	0x89C0: 0x9E35,
	0x8D50: 0x9E36,
	0x9068: 0x9E37,
	0x8F70: 0x9E38,
	0x8F71: 0x9E39,
	0x8F72: 0x9E3A,
	0xFFFD: 0x9E3B,
	0xFFFD: 0x9E3C,
	0x8ABA: 0x9E3D,
	0x8DB1: 0x9E3E,
	0x8AB9: 0x9E3F,
	0xFFFD: 0x9E40,
	0x8FB4: 0x9E41,
	0x90AE: 0x9E42,
	0x8B6B: 0x9E43,
	0x8B6D: 0x9E44,
	0x8B6C: 0x9E45,
	0x8FB5: 0x9E46,
	0x9075: 0x9E47,
	0x8FB3: 0x9E48,
	0x8BE9: 0x9E49,
	0x8BEA: 0x9E4A,
	0x9867: 0x9E4B,
	0x8BEB: 0x9E4C,
	0xFFFD: 0x9E4D,
	0x8FD6: 0x9E4E,
	0x8BEC: 0x9E4F,
	0xFFFD: 0x9E50,
	0x8BE8: 0x9E51,
	0xFFFD: 0x9E52,
	0xFFFD: 0x9E53,
	0xFFFD: 0x9E54,
	0x9868: 0x9E55,
	0xFFFD: 0x9E56,
	0x8FF6: 0x9E57,
	0x9052: 0x9E58,
	0xFFFD: 0x9E59,
	0x8FF7: 0x9E5A,
	0x9869: 0x9E5B,
	0x8FF8: 0x9E5C,
	0xFFFD: 0x9E5D,
	0x8CC4: 0x9E5E,
	0xFFFD: 0x9E5F,
	0xFFFD: 0x9E60,
	0xFFFD: 0x9E61,
	0xFFFD: 0x9E62,
	0x9051: 0x9E63,
	0x8CC3: 0x9E64,
	0xFFFD: 0x9E65,
	0x8DAE: 0x9E66,
	0x8CF0: 0x9E67,
	0x9067: 0x9E68,
	0x9071: 0x9E69,
	0x9073: 0x9E6A,
	0x9074: 0x9E6B,
	0x9072: 0x9E6C,
	0x8D67: 0x9E6D,
	0xFFFD: 0x9E6E,
	0xFFFD: 0x9E6F,
	0x8D66: 0x9E70,
	0x986A: 0x9E71,
	0xFFFD: 0x9E72,
	0x8DB0: 0x9E73,
	0xFFFD: 0x9E74,
	0xB3BF: 0x9E75,
	0xFFFD: 0x9E76,
	0xFFFD: 0x9E77,
	0x825E: 0x9E78,
	0xC4D0: 0x9E79,
	0xF6C9: 0x9E7A,
	0x9F65: 0x9E7B,
	0xC650: 0x9E7C,
	0xC651: 0x9E7D,
	0x9053: 0x9E7E,
	0xB3C0: 0x9E7F,
	0xE0EE: 0x9E80,
	0xFCFD: 0x9E81,
	0xB9A8: 0x9E82,
	0xE8F0: 0x9E83,
	0xFB5E: 0x9E84,
	0x9F66: 0x9E85,
	0xECB0: 0x9E86,
	0xECB1: 0x9E87,
	0xECAF: 0x9E88,
	0xEFAB: 0x9E89,
	0xEFAA: 0x9E8A,
	0xC247: 0x9E8B,
	0xF1DF: 0x9E8C,
	0xEFAC: 0x9E8D,
	0xF1DE: 0x9E8E,
	0xFFFD: 0x9E8F,
	0x9F51: 0x9E90,
	0xF3F3: 0x9E91,
	0xC451: 0x9E92,
	0xC453: 0x9E93,
	0xF3F2: 0x9E94,
	0xFCF4: 0x9E95,
	0xFB7C: 0x9E96,
	0xC452: 0x9E97,
	0xFBB7: 0x9E98,
	0xF5B1: 0x9E99,
	0xF5B3: 0x9E9A,
	0xF5B2: 0x9E9B,
	0xF6CA: 0x9E9C,
	0xC565: 0x9E9D,
	0xFD48: 0x9E9E,
	0xC5EF: 0x9E9F,
	0xF8E8: 0x9EA0,
	0xF963: 0x9EA1,
	0x9F67: 0x9EA2,
	0xFFFD: 0x9EA3,
	0xF9D2: 0x9EA4,
	0xB3C1: 0x9EA5,
	0x84C1: 0x9EA6,
	0xE4E5: 0x9EA7,
	0xFDB4: 0x9EA8,
	0xBEA2: 0x9EA9,
	0x986B: 0x9EAA,
	0xFBA2: 0x9EAB,
	0x9F68: 0x9EAC,
	0xECB3: 0x9EAD,
	0xECB2: 0x9EAE,
	0x9573: 0x9EAF,
	0xEFAD: 0x9EB0,
	0x9F69: 0x9EB1,
	0xFFFD: 0x9EB2,
	0xFFFD: 0x9EB3,
	0xC454: 0x9EB4,
	0xC4D1: 0x9EB5,
	0xF7C7: 0x9EB6,
	0xF9CB: 0x9EB7,
	0x88C6: 0x9EB8,
	0x8260: 0x9EB9,
	0x8261: 0x9EBA,
	0xB3C2: 0x9EBB,
	0xBBF2: 0x9EBC,
	0x986C: 0x9EBD,
	0xBEA3: 0x9EBE,
	0x94FA: 0x9EBF,
	0xF3F4: 0x9EC0,
	0x9F6A: 0x9EC1,
	0xF874: 0x9EC2,
	0xB6C0: 0x9EC3,
	0x986D: 0x9EC4,
	0xFFFD: 0x9EC5,
	0x9F6B: 0x9EC6,
	0x9F6C: 0x9EC7,
	0xEFAE: 0x9EC8,
	0x8D7A: 0x9EC9,
	0xFFFD: 0x9ECA,
	0xFFFD: 0x9ECB,
	0xC664: 0x9ECC,
	0xB6C1: 0x9ECD,
	0xBEA4: 0x9ECE,
	0xC248: 0x9ECF,
	0xF875: 0x9ED0,
	0xB6C2: 0x9ED1,
	0x92C3: 0x9ED2,
	0xE8F1: 0x9ED3,
	0xC072: 0x9ED4,
	0xECB4: 0x9ED5,
	0xECB5: 0x9ED6,
	0xFFFD: 0x9ED7,
	0xC071: 0x9ED8,
	0x93D4: 0x9ED9,
	0xEFAF: 0x9EDA,
	0xC24C: 0x9EDB,
	0xC24A: 0x9EDC,
	0xC24B: 0x9EDD,
	0xC249: 0x9EDE,
	0xF1E0: 0x9EDF,
	0xC35C: 0x9EE0,
	0xFFFD: 0x9EE1,
	0x986E: 0x9EE2,
	0xFFFD: 0x9EE3,
	0xF5B5: 0x9EE4,
	0xF5B4: 0x9EE5,
	0xF5B7: 0x9EE6,
	0xF5B6: 0x9EE7,
	0xC4D2: 0x9EE8,
	0x8DAC: 0x9EE9,
	0x986F: 0x9EEA,
	0xF6CB: 0x9EEB,
	0xFFFD: 0x9EEC,
	0xF6CD: 0x9EED,
	0xF6CC: 0x9EEE,
	0xC566: 0x9EEF,
	0xF7C8: 0x9EF0,
	0x9F6D: 0x9EF1,
	0xF876: 0x9EF2,
	0xF877: 0x9EF3,
	0xC5F0: 0x9EF4,
	0xF964: 0x9EF5,
	0xF97D: 0x9EF6,
	0xC675: 0x9EF7,
	0x9F6E: 0x9EF8,
	0xDCB0: 0x9EF9,
	0xECB6: 0x9EFA,
	0xEFB0: 0x9EFB,
	0xF3F5: 0x9EFC,
	0xE0EF: 0x9EFD,
	0x8E64: 0x9EFE,
	0xEFB1: 0x9EFF,
	0xF1E2: 0x9F00,
	0xF1E1: 0x9F01,
	0xFDE8: 0x9F02,
	0xFFFD: 0x9F03,
	0xFFFD: 0x9F04,
	0xFFFD: 0x9F05,
	0xF878: 0x9F06,
	0xC652: 0x9F07,
	0x9870: 0x9F08,
	0xF965: 0x9F09,
	0xF97E: 0x9F0A,
	0x9871: 0x9F0B,
	0xFFFD: 0x9F0C,
	0x9872: 0x9F0D,
	0xB9A9: 0x9F0E,
	0xE8F2: 0x9F0F,
	0xE8F3: 0x9F10,
	0xFFFD: 0x9F11,
	0xECB7: 0x9F12,
	0xB9AA: 0x9F13,
	0xFFFD: 0x9F14,
	0xC35D: 0x9F15,
	0xF1E3: 0x9F16,
	0xFCDB: 0x9F17,
	0xF6CF: 0x9F18,
	0xC567: 0x9F19,
	0xF6D0: 0x9F1A,
	0xF6CE: 0x9F1B,
	0xF879: 0x9F1C,
	0xFFFD: 0x9F1D,
	0xF8E9: 0x9F1E,
	0xFFFD: 0x9F1F,
	0xB9AB: 0x9F20,
	0x9873: 0x9F21,
	0xEFB4: 0x9F22,
	0xEFB3: 0x9F23,
	0xEFB2: 0x9F24,
	0xF1E4: 0x9F25,
	0xFBB8: 0x9F26,
	0x9F6F: 0x9F27,
	0xF1E8: 0x9F28,
	0xF1E7: 0x9F29,
	0xF1E6: 0x9F2A,
	0xF1E5: 0x9F2B,
	0xC35E: 0x9F2C,
	0xF3F6: 0x9F2D,
	0xF5B9: 0x9F2E,
	0xC4D3: 0x9F2F,
	0xF5B8: 0x9F30,
	0xF6D1: 0x9F31,
	0xF7CB: 0x9F32,
	0xF7CA: 0x9F33,
	0xC5C4: 0x9F34,
	0xF7C9: 0x9F35,
	0xF87C: 0x9F36,
	0xF87B: 0x9F37,
	0xF87A: 0x9F38,
	0x8CF2: 0x9F39,
	0xFFFD: 0x9F3A,
	0xBBF3: 0x9F3B,
	0xFFFD: 0x9F3C,
	0xECB8: 0x9F3D,
	0xC24D: 0x9F3E,
	0xFFFD: 0x9F3F,
	0xF3F7: 0x9F40,
	0xF3F8: 0x9F41,
	0xF7CC: 0x9F42,
	0xF87D: 0x9F43,
	0x9874: 0x9F44,
	0xFDE2: 0x9F45,
	0xF8EA: 0x9F46,
	0xF966: 0x9F47,
	0xF9B9: 0x9F48,
	0xF9D4: 0x9F49,
	0xBBF4: 0x9F4A,
	0xC24E: 0x9F4B,
	0xF1E9: 0x9F4C,
	0xF3F9: 0x9F4D,
	0xF6D2: 0x9F4E,
	0xF87E: 0x9F4F,
	0x87A2: 0x9F50,
	0x9875: 0x9F51,
	0xBEA6: 0x9F52,
	0xFDE0: 0x9F53,
	0xEFB5: 0x9F54,
	0xF1EA: 0x9F55,
	0xF3FA: 0x9F56,
	0xF3FB: 0x9F57,
	0xF3FC: 0x9F58,
	0xF5BE: 0x9F59,
	0xFDDA: 0x9F5A,
	0xF5BA: 0x9F5B,
	0xC568: 0x9F5C,
	0xF5BD: 0x9F5D,
	0xF5BC: 0x9F5E,
	0xC4D4: 0x9F5F,
	0xF5BB: 0x9F60,
	0xC4D6: 0x9F61,
	0x93EE: 0x9F62,
	0xC4D5: 0x9F63,
	0xF6D4: 0x9F64,
	0xF6D3: 0x9F65,
	0xC569: 0x9F66,
	0xC56A: 0x9F67,
	0xFFFD: 0x9F68,
	0xFD62: 0x9F69,
	0xC5C6: 0x9F6A,
	0xF7CD: 0x9F6B,
	0xC5C5: 0x9F6C,
	0xFFFD: 0x9F6D,
	0xF8A3: 0x9F6E,
	0xF8A4: 0x9F6F,
	0xF8A2: 0x9F70,
	0xF8A1: 0x9F71,
	0xC654: 0x9F72,
	0xFFFD: 0x9F73,
	0xF8EB: 0x9F74,
	0xF8EC: 0x9F75,
	0xF8ED: 0x9F76,
	0xC653: 0x9F77,
	0xF967: 0x9F78,
	0xF96A: 0x9F79,
	0xF969: 0x9F7A,
	0xF968: 0x9F7B,
	0xFFFD: 0x9F7C,
	0xFFFD: 0x9F7D,
	0xF9D3: 0x9F7E,
	0x88C7: 0x9F7F,
	0x8F73: 0x9F80,
	0xFFFD: 0x9F81,
	0xFFFD: 0x9F82,
	0x8C6A: 0x9F83,
	0x8C6B: 0x9F84,
	0x8FFA: 0x9F85,
	0x8FF9: 0x9F86,
	0x8CC5: 0x9F87,
	0x8CC6: 0x9F88,
	0x8CF3: 0x9F89,
	0x8CF4: 0x9F8A,
	0x8D6C: 0x9F8B,
	0x8D6B: 0x9F8C,
	0xC073: 0x9F8D,
	0xFBD8: 0x9F8E,
	0xFFFD: 0x9F8F,
	0xC365: 0x9F90,
	0xF5BF: 0x9F91,
	0xF6D5: 0x9F92,
	0xFFFD: 0x9F93,
	0xC5C7: 0x9F94,
	0xF7CE: 0x9F95,
	0xFFFD: 0x9F96,
	0xFFFD: 0x9F97,
	0xF9D5: 0x9F98,
	0x89C5: 0x9F99,
	0x8CF5: 0x9F9A,
	0x9069: 0x9F9B,
	0xC074: 0x9F9C,
	0x9876: 0x9F9D,
	0xFFFD: 0x9F9E,
	0x89C6: 0x9F9F,
	0xEFB6: 0x9FA0,
	0xFFFD: 0x9FA1,
	0xF7CF: 0x9FA2,
	0xFFFD: 0x9FA3,
	0xF9A1: 0x9FA4,
	0xFDD4: 0x9FA5,
	0xFFFD: 0x9FA6,
	0xFFFD: 0x9FA7,
	0xFFFD: 0x9FA8,
	0xFFFD: 0x9FA9,
	0xFFFD: 0x9FAA,
	0xFFFD: 0x9FAB,
	0xFFFD: 0x9FAC,
	0xFFFD: 0x9FAD,
	0xFFFD: 0x9FAE,
	0xFFFD: 0x9FAF,
	0xC8A1: 0x9FB0,
	0xC8A3: 0x9FB1,
	0xFFFD: 0x9FB2,
	0xFFFD: 0x9FB3,
	0xFFFD: 0x9FB4,
	0xFFFD: 0x9FB5,
	0xFFFD: 0x9FB6,
	0xFFFD: 0x9FB7,
	0xFFFD: 0x9FB8,
	0xFFFD: 0x9FB9,
	0xFFFD: 0x9FBA,
	0xFFFD: 0x9FBB,
	0xFFFD: 0x9FBC,
	0xFFFD: 0x9FBD,
	0xFFFD: 0x9FBE,
	0xFFFD: 0x9FBF,
	0xFFFD: 0x9FC0,
	0xFFFD: 0x9FC1,
	0xFFFD: 0x9FC2,
	0xFFFD: 0x9FC3,
	0xFFFD: 0x9FC4,
	0xFFFD: 0x9FC5,
	0xFFFD: 0x9FC6,
	0xFFFD: 0x9FC7,
	0xFFFD: 0x9FC8,
	0xFFFD: 0x9FC9,
	0xFFFD: 0x9FCA,
	0xFFFD: 0x9FCB,
	0xFFFD: 0x9FCC,
	0xFFFD: 0x9FCD,
	0xFFFD: 0x9FCE,
	0xFFFD: 0x9FCF,
	0xFFFD: 0x9FD0,
	0xFFFD: 0x9FD1,
	0xFFFD: 0x9FD2,
	0xFFFD: 0x9FD3,
	0xFFFD: 0x9FD4,
	0xFFFD: 0x9FD5,
	0xFFFD: 0x9FD6,
	0xFFFD: 0x9FD7,
	0xFFFD: 0x9FD8,
	0xFFFD: 0x9FD9,
	0xFFFD: 0x9FDA,
	0xFFFD: 0x9FDB,
	0xFFFD: 0x9FDC,
	0xFFFD: 0x9FDD,
	0xFFFD: 0x9FDE,
	0xFFFD: 0x9FDF,
	0xFFFD: 0x9FE0,
	0xFFFD: 0x9FE1,
	0xFFFD: 0x9FE2,
	0xFFFD: 0x9FE3,
	0xFFFD: 0x9FE4,
	0xFFFD: 0x9FE5,
	0xFFFD: 0x9FE6,
	0xFFFD: 0x9FE7,
	0xFFFD: 0x9FE8,
	0xFFFD: 0x9FE9,
	0xFFFD: 0x9FEA,
	0xFFFD: 0x9FEB,
	0xFFFD: 0x9FEC,
	0xFFFD: 0x9FED,
	0xFFFD: 0x9FEE,
	0xFFFD: 0x9FEF,
	0xFFFD: 0x9FF0,
	0xFFFD: 0x9FF1,
	0xFFFD: 0x9FF2,
	0xFFFD: 0x9FF3,
	0xFFFD: 0x9FF4,
	0xFFFD: 0x9FF5,
	0xFFFD: 0x9FF6,
	0xFFFD: 0x9FF7,
	0xFFFD: 0x9FF8,
	0xFFFD: 0x9FF9,
	0xFFFD: 0x9FFA,
	0xFFFD: 0x9FFB,
	0xFFFD: 0x9FFC,
	0xFFFD: 0x9FFD,
	0xFFFD: 0x9FFE,
	0xFFFD: 0x9FFF,
	0xFFFD: 0xA000,
	0xFFFD: 0xA001,
	0xFFFD: 0xA002,
	0xFFFD: 0xA003,
	0xFFFD: 0xA004,
	0xFFFD: 0xA005,
	0xFFFD: 0xA006,
	0xFFFD: 0xA007,
	0xFFFD: 0xA008,
	0xFFFD: 0xA009,
	0xFFFD: 0xA00A,
	0xFFFD: 0xA00B,
	0xFFFD: 0xA00C,
	0xFFFD: 0xA00D,
	0xFFFD: 0xA00E,
	0xFFFD: 0xA00F,
	0xFFFD: 0xA010,
	0xFFFD: 0xA011,
	0xFFFD: 0xA012,
	0xFFFD: 0xA013,
	0xFFFD: 0xA014,
	0xFFFD: 0xA015,
	0xFFFD: 0xA016,
	0xFFFD: 0xA017,
	0xFFFD: 0xA018,
	0xFFFD: 0xA019,
	0xFFFD: 0xA01A,
	0xFFFD: 0xA01B,
	0xFFFD: 0xA01C,
	0xFFFD: 0xA01D,
	0xFFFD: 0xA01E,
	0xFFFD: 0xA01F,
	0xFFFD: 0xA020,
	0xFFFD: 0xA021,
	0xFFFD: 0xA022,
	0xFFFD: 0xA023,
	0xFFFD: 0xA024,
	0xFFFD: 0xA025,
	0xFFFD: 0xA026,
	0xFFFD: 0xA027,
	0xFFFD: 0xA028,
	0xFFFD: 0xA029,
	0xFFFD: 0xA02A,
	0xFFFD: 0xA02B,
	0xFFFD: 0xA02C,
	0xFFFD: 0xA02D,
	0xFFFD: 0xA02E,
	0xFFFD: 0xA02F,
	0xFFFD: 0xA030,
	0xFFFD: 0xA031,
	0xFFFD: 0xA032,
	0xFFFD: 0xA033,
	0xFFFD: 0xA034,
	0xFFFD: 0xA035,
	0xFFFD: 0xA036,
	0xFFFD: 0xA037,
	0xFFFD: 0xA038,
	0xFFFD: 0xA039,
	0xFFFD: 0xA03A,
	0xFFFD: 0xA03B,
	0xFFFD: 0xA03C,
	0xFFFD: 0xA03D,
	0xFFFD: 0xA03E,
	0xFFFD: 0xA03F,
	0xFFFD: 0xA040,
	0xFFFD: 0xA041,
	0xFFFD: 0xA042,
	0xFFFD: 0xA043,
	0xFFFD: 0xA044,
	0xFFFD: 0xA045,
	0xFFFD: 0xA046,
	0xFFFD: 0xA047,
	0xFFFD: 0xA048,
	0xFFFD: 0xA049,
	0xFFFD: 0xA04A,
	0xFFFD: 0xA04B,
	0xFFFD: 0xA04C,
	0xFFFD: 0xA04D,
	0xFFFD: 0xA04E,
	0xFFFD: 0xA04F,
	0xFFFD: 0xA050,
	0xFFFD: 0xA051,
	0xFFFD: 0xA052,
	0xFFFD: 0xA053,
	0xFFFD: 0xA054,
	0xFFFD: 0xA055,
	0xFFFD: 0xA056,
	0xFFFD: 0xA057,
	0xFFFD: 0xA058,
	0xFFFD: 0xA059,
	0xFFFD: 0xA05A,
	0xFFFD: 0xA05B,
	0xFFFD: 0xA05C,
	0xFFFD: 0xA05D,
	0xFFFD: 0xA05E,
	0xFFFD: 0xA05F,
	0xFFFD: 0xA060,
	0xFFFD: 0xA061,
	0xFFFD: 0xA062,
	0xFFFD: 0xA063,
	0xFFFD: 0xA064,
	0xFFFD: 0xA065,
	0xFFFD: 0xA066,
	0xFFFD: 0xA067,
	0xFFFD: 0xA068,
	0xFFFD: 0xA069,
	0xFFFD: 0xA06A,
	0xFFFD: 0xA06B,
	0xFFFD: 0xA06C,
	0xFFFD: 0xA06D,
	0xFFFD: 0xA06E,
	0xFFFD: 0xA06F,
	0xFFFD: 0xA070,
	0xFFFD: 0xA071,
	0xFFFD: 0xA072,
	0xFFFD: 0xA073,
	0xFFFD: 0xA074,
	0xFFFD: 0xA075,
	0xFFFD: 0xA076,
	0xFFFD: 0xA077,
	0xFFFD: 0xA078,
	0xFFFD: 0xA079,
	0xFFFD: 0xA07A,
	0xFFFD: 0xA07B,
	0xFFFD: 0xA07C,
	0xFFFD: 0xA07D,
	0xFFFD: 0xA07E,
	0xFFFD: 0xA07F,
	0xFFFD: 0xA080,
	0xFFFD: 0xA081,
	0xFFFD: 0xA082,
	0xFFFD: 0xA083,
	0xFFFD: 0xA084,
	0xFFFD: 0xA085,
	0xFFFD: 0xA086,
	0xFFFD: 0xA087,
	0xFFFD: 0xA088,
	0xFFFD: 0xA089,
	0xFFFD: 0xA08A,
	0xFFFD: 0xA08B,
	0xFFFD: 0xA08C,
	0xFFFD: 0xA08D,
	0xFFFD: 0xA08E,
	0xFFFD: 0xA08F,
	0xFFFD: 0xA090,
	0xFFFD: 0xA091,
	0xFFFD: 0xA092,
	0xFFFD: 0xA093,
	0xFFFD: 0xA094,
	0xFFFD: 0xA095,
	0xFFFD: 0xA096,
	0xFFFD: 0xA097,
	0xFFFD: 0xA098,
	0xFFFD: 0xA099,
	0xFFFD: 0xA09A,
	0xFFFD: 0xA09B,
	0xFFFD: 0xA09C,
	0xFFFD: 0xA09D,
	0xFFFD: 0xA09E,
	0xFFFD: 0xA09F,
	0xFFFD: 0xA0A0,
	0xFFFD: 0xA0A1,
	0xFFFD: 0xA0A2,
	0xFFFD: 0xA0A3,
	0xFFFD: 0xA0A4,
	0xFFFD: 0xA0A5,
	0xFFFD: 0xA0A6,
	0xFFFD: 0xA0A7,
	0xFFFD: 0xA0A8,
	0xFFFD: 0xA0A9,
	0xFFFD: 0xA0AA,
	0xFFFD: 0xA0AB,
	0xFFFD: 0xA0AC,
	0xFFFD: 0xA0AD,
	0xFFFD: 0xA0AE,
	0xFFFD: 0xA0AF,
	0xFFFD: 0xA0B0,
	0xFFFD: 0xA0B1,
	0xFFFD: 0xA0B2,
	0xFFFD: 0xA0B3,
	0xFFFD: 0xA0B4,
	0xFFFD: 0xA0B5,
	0xFFFD: 0xA0B6,
	0xFFFD: 0xA0B7,
	0xFFFD: 0xA0B8,
	0xFFFD: 0xA0B9,
	0xFFFD: 0xA0BA,
	0xFFFD: 0xA0BB,
	0xFFFD: 0xA0BC,
	0xFFFD: 0xA0BD,
	0xFFFD: 0xA0BE,
	0xFFFD: 0xA0BF,
	0xFFFD: 0xA0C0,
	0xFFFD: 0xA0C1,
	0xFFFD: 0xA0C2,
	0xFFFD: 0xA0C3,
	0xFFFD: 0xA0C4,
	0xFFFD: 0xA0C5,
	0xFFFD: 0xA0C6,
	0xFFFD: 0xA0C7,
	0xFFFD: 0xA0C8,
	0xFFFD: 0xA0C9,
	0xFFFD: 0xA0CA,
	0xFFFD: 0xA0CB,
	0xFFFD: 0xA0CC,
	0xFFFD: 0xA0CD,
	0xFFFD: 0xA0CE,
	0xFFFD: 0xA0CF,
	0xFFFD: 0xA0D0,
	0xFFFD: 0xA0D1,
	0xFFFD: 0xA0D2,
	0xFFFD: 0xA0D3,
	0xFFFD: 0xA0D4,
	0xFFFD: 0xA0D5,
	0xFFFD: 0xA0D6,
	0xFFFD: 0xA0D7,
	0xFFFD: 0xA0D8,
	0xFFFD: 0xA0D9,
	0xFFFD: 0xA0DA,
	0xFFFD: 0xA0DB,
	0xFFFD: 0xA0DC,
	0xFFFD: 0xA0DD,
	0xFFFD: 0xA0DE,
	0xFFFD: 0xA0DF,
	0xFFFD: 0xA0E0,
	0xFFFD: 0xA0E1,
	0xFFFD: 0xA0E2,
	0xFFFD: 0xA0E3,
	0xFFFD: 0xA0E4,
	0xFFFD: 0xA0E5,
	0xFFFD: 0xA0E6,
	0xFFFD: 0xA0E7,
	0xFFFD: 0xA0E8,
	0xFFFD: 0xA0E9,
	0xFFFD: 0xA0EA,
	0xFFFD: 0xA0EB,
	0xFFFD: 0xA0EC,
	0xFFFD: 0xA0ED,
	0xFFFD: 0xA0EE,
	0xFFFD: 0xA0EF,
	0xFFFD: 0xA0F0,
	0xFFFD: 0xA0F1,
	0xFFFD: 0xA0F2,
	0xFFFD: 0xA0F3,
	0xFFFD: 0xA0F4,
	0xFFFD: 0xA0F5,
	0xFFFD: 0xA0F6,
	0xFFFD: 0xA0F7,
	0xFFFD: 0xA0F8,
	0xFFFD: 0xA0F9,
	0xFFFD: 0xA0FA,
	0xFFFD: 0xA0FB,
	0xFFFD: 0xA0FC,
	0xFFFD: 0xA0FD,
	0xFFFD: 0xA0FE,
	0xFFFD: 0xA0FF,
	0xFFFD: 0xA100,
	0xFFFD: 0xA101,
	0xFFFD: 0xA102,
	0xFFFD: 0xA103,
	0xFFFD: 0xA104,
	0xFFFD: 0xA105,
	0xFFFD: 0xA106,
	0xFFFD: 0xA107,
	0xFFFD: 0xA108,
	0xFFFD: 0xA109,
	0xFFFD: 0xA10A,
	0xFFFD: 0xA10B,
	0xFFFD: 0xA10C,
	0xFFFD: 0xA10D,
	0xFFFD: 0xA10E,
	0xFFFD: 0xA10F,
	0xFFFD: 0xA110,
	0xFFFD: 0xA111,
	0xFFFD: 0xA112,
	0xFFFD: 0xA113,
	0xFFFD: 0xA114,
	0xFFFD: 0xA115,
	0xFFFD: 0xA116,
	0xFFFD: 0xA117,
	0xFFFD: 0xA118,
	0xFFFD: 0xA119,
	0xFFFD: 0xA11A,
	0xFFFD: 0xA11B,
	0xFFFD: 0xA11C,
	0xFFFD: 0xA11D,
	0xFFFD: 0xA11E,
	0xFFFD: 0xA11F,
	0xFFFD: 0xA120,
	0xFFFD: 0xA121,
	0xFFFD: 0xA122,
	0xFFFD: 0xA123,
	0xFFFD: 0xA124,
	0xFFFD: 0xA125,
	0xFFFD: 0xA126,
	0xFFFD: 0xA127,
	0xFFFD: 0xA128,
	0xFFFD: 0xA129,
	0xFFFD: 0xA12A,
	0xFFFD: 0xA12B,
	0xFFFD: 0xA12C,
	0xFFFD: 0xA12D,
	0xFFFD: 0xA12E,
	0xFFFD: 0xA12F,
	0xFFFD: 0xA130,
	0xFFFD: 0xA131,
	0xFFFD: 0xA132,
	0xFFFD: 0xA133,
	0xFFFD: 0xA134,
	0xFFFD: 0xA135,
	0xFFFD: 0xA136,
	0xFFFD: 0xA137,
	0xFFFD: 0xA138,
	0xFFFD: 0xA139,
	0xFFFD: 0xA13A,
	0xFFFD: 0xA13B,
	0xFFFD: 0xA13C,
	0xFFFD: 0xA13D,
	0xFFFD: 0xA13E,
	0xFFFD: 0xA13F,
	0xFFFD: 0xA140,
	0xFFFD: 0xA141,
	0xFFFD: 0xA142,
	0xFFFD: 0xA143,
	0xFFFD: 0xA144,
	0xFFFD: 0xA145,
	0xFFFD: 0xA146,
	0xFFFD: 0xA147,
	0xFFFD: 0xA148,
	0xFFFD: 0xA149,
	0xFFFD: 0xA14A,
	0xFFFD: 0xA14B,
	0xFFFD: 0xA14C,
	0xFFFD: 0xA14D,
	0xFFFD: 0xA14E,
	0xFFFD: 0xA14F,
	0xFFFD: 0xA150,
	0xFFFD: 0xA151,
	0xFFFD: 0xA152,
	0xFFFD: 0xA153,
	0xFFFD: 0xA154,
	0xFFFD: 0xA155,
	0xFFFD: 0xA156,
	0xFFFD: 0xA157,
	0xFFFD: 0xA158,
	0xFFFD: 0xA159,
	0xFFFD: 0xA15A,
	0xFFFD: 0xA15B,
	0xFFFD: 0xA15C,
	0xFFFD: 0xA15D,
	0xFFFD: 0xA15E,
	0xFFFD: 0xA15F,
	0xFFFD: 0xA160,
	0xFFFD: 0xA161,
	0xFFFD: 0xA162,
	0xFFFD: 0xA163,
	0xFFFD: 0xA164,
	0xFFFD: 0xA165,
	0xFFFD: 0xA166,
	0xFFFD: 0xA167,
	0xFFFD: 0xA168,
	0xFFFD: 0xA169,
	0xFFFD: 0xA16A,
	0xFFFD: 0xA16B,
	0xFFFD: 0xA16C,
	0xFFFD: 0xA16D,
	0xFFFD: 0xA16E,
	0xFFFD: 0xA16F,
	0xFFFD: 0xA170,
	0xFFFD: 0xA171,
	0xFFFD: 0xA172,
	0xFFFD: 0xA173,
	0xFFFD: 0xA174,
	0xFFFD: 0xA175,
	0xFFFD: 0xA176,
	0xFFFD: 0xA177,
	0xFFFD: 0xA178,
	0xFFFD: 0xA179,
	0xFFFD: 0xA17A,
	0xFFFD: 0xA17B,
	0xFFFD: 0xA17C,
	0xFFFD: 0xA17D,
	0xFFFD: 0xA17E,
	0xFFFD: 0xA17F,
	0xFFFD: 0xA180,
	0xFFFD: 0xA181,
	0xFFFD: 0xA182,
	0xFFFD: 0xA183,
	0xFFFD: 0xA184,
	0xFFFD: 0xA185,
	0xFFFD: 0xA186,
	0xFFFD: 0xA187,
	0xFFFD: 0xA188,
	0xFFFD: 0xA189,
	0xFFFD: 0xA18A,
	0xFFFD: 0xA18B,
	0xFFFD: 0xA18C,
	0xFFFD: 0xA18D,
	0xFFFD: 0xA18E,
	0xFFFD: 0xA18F,
	0xFFFD: 0xA190,
	0xFFFD: 0xA191,
	0xFFFD: 0xA192,
	0xFFFD: 0xA193,
	0xFFFD: 0xA194,
	0xFFFD: 0xA195,
	0xFFFD: 0xA196,
	0xFFFD: 0xA197,
	0xFFFD: 0xA198,
	0xFFFD: 0xA199,
	0xFFFD: 0xA19A,
	0xFFFD: 0xA19B,
	0xFFFD: 0xA19C,
	0xFFFD: 0xA19D,
	0xFFFD: 0xA19E,
	0xFFFD: 0xA19F,
	0xFFFD: 0xA1A0,
	0xFFFD: 0xA1A1,
	0xFFFD: 0xA1A2,
	0xFFFD: 0xA1A3,
	0xFFFD: 0xA1A4,
	0xFFFD: 0xA1A5,
	0xFFFD: 0xA1A6,
	0xFFFD: 0xA1A7,
	0xFFFD: 0xA1A8,
	0xFFFD: 0xA1A9,
	0xFFFD: 0xA1AA,
	0xFFFD: 0xA1AB,
	0xFFFD: 0xA1AC,
	0xFFFD: 0xA1AD,
	0xFFFD: 0xA1AE,
	0xFFFD: 0xA1AF,
	0xFFFD: 0xA1B0,
	0xFFFD: 0xA1B1,
	0xFFFD: 0xA1B2,
	0xFFFD: 0xA1B3,
	0xFFFD: 0xA1B4,
	0xFFFD: 0xA1B5,
	0xFFFD: 0xA1B6,
	0xFFFD: 0xA1B7,
	0xFFFD: 0xA1B8,
	0xFFFD: 0xA1B9,
	0xFFFD: 0xA1BA,
	0xFFFD: 0xA1BB,
	0xFFFD: 0xA1BC,
	0xFFFD: 0xA1BD,
	0xFFFD: 0xA1BE,
	0xFFFD: 0xA1BF,
	0xFFFD: 0xA1C0,
	0xFFFD: 0xA1C1,
	0xFFFD: 0xA1C2,
	0xFFFD: 0xA1C3,
	0xFFFD: 0xA1C4,
	0xFFFD: 0xA1C5,
	0xFFFD: 0xA1C6,
	0xFFFD: 0xA1C7,
	0xFFFD: 0xA1C8,
	0xFFFD: 0xA1C9,
	0xFFFD: 0xA1CA,
	0xFFFD: 0xA1CB,
	0xFFFD: 0xA1CC,
	0xFFFD: 0xA1CD,
	0xFFFD: 0xA1CE,
	0xFFFD: 0xA1CF,
	0xFFFD: 0xA1D0,
	0xFFFD: 0xA1D1,
	0xFFFD: 0xA1D2,
	0xFFFD: 0xA1D3,
	0xFFFD: 0xA1D4,
	0xFFFD: 0xA1D5,
	0xFFFD: 0xA1D6,
	0xFFFD: 0xA1D7,
	0xFFFD: 0xA1D8,
	0xFFFD: 0xA1D9,
	0xFFFD: 0xA1DA,
	0xFFFD: 0xA1DB,
	0xFFFD: 0xA1DC,
	0xFFFD: 0xA1DD,
	0xFFFD: 0xA1DE,
	0xFFFD: 0xA1DF,
	0xFFFD: 0xA1E0,
	0xFFFD: 0xA1E1,
	0xFFFD: 0xA1E2,
	0xFFFD: 0xA1E3,
	0xFFFD: 0xA1E4,
	0xFFFD: 0xA1E5,
	0xFFFD: 0xA1E6,
	0xFFFD: 0xA1E7,
	0xFFFD: 0xA1E8,
	0xFFFD: 0xA1E9,
	0xFFFD: 0xA1EA,
	0xFFFD: 0xA1EB,
	0xFFFD: 0xA1EC,
	0xFFFD: 0xA1ED,
	0xFFFD: 0xA1EE,
	0xFFFD: 0xA1EF,
	0xFFFD: 0xA1F0,
	0xFFFD: 0xA1F1,
	0xFFFD: 0xA1F2,
	0xFFFD: 0xA1F3,
	0xFFFD: 0xA1F4,
	0xFFFD: 0xA1F5,
	0xFFFD: 0xA1F6,
	0xFFFD: 0xA1F7,
	0xFFFD: 0xA1F8,
	0xFFFD: 0xA1F9,
	0xFFFD: 0xA1FA,
	0xFFFD: 0xA1FB,
	0xFFFD: 0xA1FC,
	0xFFFD: 0xA1FD,
	0xFFFD: 0xA1FE,
	0xFFFD: 0xA1FF,
	0xFFFD: 0xA200,
	0xFFFD: 0xA201,
	0xFFFD: 0xA202,
	0xFFFD: 0xA203,
	0xFFFD: 0xA204,
	0xFFFD: 0xA205,
	0xFFFD: 0xA206,
	0xFFFD: 0xA207,
	0xFFFD: 0xA208,
	0xFFFD: 0xA209,
	0xFFFD: 0xA20A,
	0xFFFD: 0xA20B,
	0xFFFD: 0xA20C,
	0xFFFD: 0xA20D,
	0xFFFD: 0xA20E,
	0xFFFD: 0xA20F,
	0xFFFD: 0xA210,
	0xFFFD: 0xA211,
	0xFFFD: 0xA212,
	0xFFFD: 0xA213,
	0xFFFD: 0xA214,
	0xFFFD: 0xA215,
	0xFFFD: 0xA216,
	0xFFFD: 0xA217,
	0xFFFD: 0xA218,
	0xFFFD: 0xA219,
	0xFFFD: 0xA21A,
	0xFFFD: 0xA21B,
	0xFFFD: 0xA21C,
	0xFFFD: 0xA21D,
	0xFFFD: 0xA21E,
	0xFFFD: 0xA21F,
	0xFFFD: 0xA220,
	0xFFFD: 0xA221,
	0xFFFD: 0xA222,
	0xFFFD: 0xA223,
	0xFFFD: 0xA224,
	0xFFFD: 0xA225,
	0xFFFD: 0xA226,
	0xFFFD: 0xA227,
	0xFFFD: 0xA228,
	0xFFFD: 0xA229,
	0xFFFD: 0xA22A,
	0xFFFD: 0xA22B,
	0xFFFD: 0xA22C,
	0xFFFD: 0xA22D,
	0xFFFD: 0xA22E,
	0xFFFD: 0xA22F,
	0xFFFD: 0xA230,
	0xFFFD: 0xA231,
	0xFFFD: 0xA232,
	0xFFFD: 0xA233,
	0xFFFD: 0xA234,
	0xFFFD: 0xA235,
	0xFFFD: 0xA236,
	0xFFFD: 0xA237,
	0xFFFD: 0xA238,
	0xFFFD: 0xA239,
	0xFFFD: 0xA23A,
	0xFFFD: 0xA23B,
	0xFFFD: 0xA23C,
	0xFFFD: 0xA23D,
	0xFFFD: 0xA23E,
	0xFFFD: 0xA23F,
	0xFFFD: 0xA240,
	0xFFFD: 0xA241,
	0xFFFD: 0xA242,
	0xFFFD: 0xA243,
	0xFFFD: 0xA244,
	0xFFFD: 0xA245,
	0xFFFD: 0xA246,
	0xFFFD: 0xA247,
	0xFFFD: 0xA248,
	0xFFFD: 0xA249,
	0xFFFD: 0xA24A,
	0xFFFD: 0xA24B,
	0xFFFD: 0xA24C,
	0xFFFD: 0xA24D,
	0xFFFD: 0xA24E,
	0xFFFD: 0xA24F,
	0xFFFD: 0xA250,
	0xFFFD: 0xA251,
	0xFFFD: 0xA252,
	0xFFFD: 0xA253,
	0xFFFD: 0xA254,
	0xFFFD: 0xA255,
	0xFFFD: 0xA256,
	0xFFFD: 0xA257,
	0xFFFD: 0xA258,
	0xFFFD: 0xA259,
	0xFFFD: 0xA25A,
	0xFFFD: 0xA25B,
	0xFFFD: 0xA25C,
	0xFFFD: 0xA25D,
	0xFFFD: 0xA25E,
	0xFFFD: 0xA25F,
	0xFFFD: 0xA260,
	0xFFFD: 0xA261,
	0xFFFD: 0xA262,
	0xFFFD: 0xA263,
	0xFFFD: 0xA264,
	0xFFFD: 0xA265,
	0xFFFD: 0xA266,
	0xFFFD: 0xA267,
	0xFFFD: 0xA268,
	0xFFFD: 0xA269,
	0xFFFD: 0xA26A,
	0xFFFD: 0xA26B,
	0xFFFD: 0xA26C,
	0xFFFD: 0xA26D,
	0xFFFD: 0xA26E,
	0xFFFD: 0xA26F,
	0xFFFD: 0xA270,
	0xFFFD: 0xA271,
	0xFFFD: 0xA272,
	0xFFFD: 0xA273,
	0xFFFD: 0xA274,
	0xFFFD: 0xA275,
	0xFFFD: 0xA276,
	0xFFFD: 0xA277,
	0xFFFD: 0xA278,
	0xFFFD: 0xA279,
	0xFFFD: 0xA27A,
	0xFFFD: 0xA27B,
	0xFFFD: 0xA27C,
	0xFFFD: 0xA27D,
	0xFFFD: 0xA27E,
	0xFFFD: 0xA27F,
	0xFFFD: 0xA280,
	0xFFFD: 0xA281,
	0xFFFD: 0xA282,
	0xFFFD: 0xA283,
	0xFFFD: 0xA284,
	0xFFFD: 0xA285,
	0xFFFD: 0xA286,
	0xFFFD: 0xA287,
	0xFFFD: 0xA288,
	0xFFFD: 0xA289,
	0xFFFD: 0xA28A,
	0xFFFD: 0xA28B,
	0xFFFD: 0xA28C,
	0xFFFD: 0xA28D,
	0xFFFD: 0xA28E,
	0xFFFD: 0xA28F,
	0xFFFD: 0xA290,
	0xFFFD: 0xA291,
	0xFFFD: 0xA292,
	0xFFFD: 0xA293,
	0xFFFD: 0xA294,
	0xFFFD: 0xA295,
	0xFFFD: 0xA296,
	0xFFFD: 0xA297,
	0xFFFD: 0xA298,
	0xFFFD: 0xA299,
	0xFFFD: 0xA29A,
	0xFFFD: 0xA29B,
	0xFFFD: 0xA29C,
	0xFFFD: 0xA29D,
	0xFFFD: 0xA29E,
	0xFFFD: 0xA29F,
	0xFFFD: 0xA2A0,
	0xFFFD: 0xA2A1,
	0xFFFD: 0xA2A2,
	0xFFFD: 0xA2A3,
	0xFFFD: 0xA2A4,
	0xFFFD: 0xA2A5,
	0xFFFD: 0xA2A6,
	0xFFFD: 0xA2A7,
	0xFFFD: 0xA2A8,
	0xFFFD: 0xA2A9,
	0xFFFD: 0xA2AA,
	0xFFFD: 0xA2AB,
	0xFFFD: 0xA2AC,
	0xFFFD: 0xA2AD,
	0xFFFD: 0xA2AE,
	0xFFFD: 0xA2AF,
	0xFFFD: 0xA2B0,
	0xFFFD: 0xA2B1,
	0xFFFD: 0xA2B2,
	0xFFFD: 0xA2B3,
	0xFFFD: 0xA2B4,
	0xFFFD: 0xA2B5,
	0xFFFD: 0xA2B6,
	0xFFFD: 0xA2B7,
	0xFFFD: 0xA2B8,
	0xFFFD: 0xA2B9,
	0xFFFD: 0xA2BA,
	0xFFFD: 0xA2BB,
	0xFFFD: 0xA2BC,
	0xFFFD: 0xA2BD,
	0xFFFD: 0xA2BE,
	0xFFFD: 0xA2BF,
	0xFFFD: 0xA2C0,
	0xFFFD: 0xA2C1,
	0xFFFD: 0xA2C2,
	0xFFFD: 0xA2C3,
	0xFFFD: 0xA2C4,
	0xFFFD: 0xA2C5,
	0xFFFD: 0xA2C6,
	0xFFFD: 0xA2C7,
	0xFFFD: 0xA2C8,
	0xFFFD: 0xA2C9,
	0xFFFD: 0xA2CA,
	0xFFFD: 0xA2CB,
	0xFFFD: 0xA2CC,
	0xFFFD: 0xA2CD,
	0xFFFD: 0xA2CE,
	0xFFFD: 0xA2CF,
	0xFFFD: 0xA2D0,
	0xFFFD: 0xA2D1,
	0xFFFD: 0xA2D2,
	0xFFFD: 0xA2D3,
	0xFFFD: 0xA2D4,
	0xFFFD: 0xA2D5,
	0xFFFD: 0xA2D6,
	0xFFFD: 0xA2D7,
	0xFFFD: 0xA2D8,
	0xFFFD: 0xA2D9,
	0xFFFD: 0xA2DA,
	0xFFFD: 0xA2DB,
	0xFFFD: 0xA2DC,
	0xFFFD: 0xA2DD,
	0xFFFD: 0xA2DE,
	0xFFFD: 0xA2DF,
	0xFFFD: 0xA2E0,
	0xFFFD: 0xA2E1,
	0xFFFD: 0xA2E2,
	0xFFFD: 0xA2E3,
	0xFFFD: 0xA2E4,
	0xFFFD: 0xA2E5,
	0xFFFD: 0xA2E6,
	0xFFFD: 0xA2E7,
	0xFFFD: 0xA2E8,
	0xFFFD: 0xA2E9,
	0xFFFD: 0xA2EA,
	0xFFFD: 0xA2EB,
	0xFFFD: 0xA2EC,
	0xFFFD: 0xA2ED,
	0xFFFD: 0xA2EE,
	0xFFFD: 0xA2EF,
	0xFFFD: 0xA2F0,
	0xFFFD: 0xA2F1,
	0xFFFD: 0xA2F2,
	0xFFFD: 0xA2F3,
	0xFFFD: 0xA2F4,
	0xFFFD: 0xA2F5,
	0xFFFD: 0xA2F6,
	0xFFFD: 0xA2F7,
	0xFFFD: 0xA2F8,
	0xFFFD: 0xA2F9,
	0xFFFD: 0xA2FA,
	0xFFFD: 0xA2FB,
	0xFFFD: 0xA2FC,
	0xFFFD: 0xA2FD,
	0xFFFD: 0xA2FE,
	0xFFFD: 0xA2FF,
	0xFFFD: 0xA300,
	0xFFFD: 0xA301,
	0xFFFD: 0xA302,
	0xFFFD: 0xA303,
	0xFFFD: 0xA304,
	0xFFFD: 0xA305,
	0xFFFD: 0xA306,
	0xFFFD: 0xA307,
	0xFFFD: 0xA308,
	0xFFFD: 0xA309,
	0xFFFD: 0xA30A,
	0xFFFD: 0xA30B,
	0xFFFD: 0xA30C,
	0xFFFD: 0xA30D,
	0xFFFD: 0xA30E,
	0xFFFD: 0xA30F,
	0xFFFD: 0xA310,
	0xFFFD: 0xA311,
	0xFFFD: 0xA312,
	0xFFFD: 0xA313,
	0xFFFD: 0xA314,
	0xFFFD: 0xA315,
	0xFFFD: 0xA316,
	0xFFFD: 0xA317,
	0xFFFD: 0xA318,
	0xFFFD: 0xA319,
	0xFFFD: 0xA31A,
	0xFFFD: 0xA31B,
	0xFFFD: 0xA31C,
	0xFFFD: 0xA31D,
	0xFFFD: 0xA31E,
	0xFFFD: 0xA31F,
	0xFFFD: 0xA320,
	0xFFFD: 0xA321,
	0xFFFD: 0xA322,
	0xFFFD: 0xA323,
	0xFFFD: 0xA324,
	0xFFFD: 0xA325,
	0xFFFD: 0xA326,
	0xFFFD: 0xA327,
	0xFFFD: 0xA328,
	0xFFFD: 0xA329,
	0xFFFD: 0xA32A,
	0xFFFD: 0xA32B,
	0xFFFD: 0xA32C,
	0xFFFD: 0xA32D,
	0xFFFD: 0xA32E,
	0xFFFD: 0xA32F,
	0xFFFD: 0xA330,
	0xFFFD: 0xA331,
	0xFFFD: 0xA332,
	0xFFFD: 0xA333,
	0xFFFD: 0xA334,
	0xFFFD: 0xA335,
	0xFFFD: 0xA336,
	0xFFFD: 0xA337,
	0xFFFD: 0xA338,
	0xFFFD: 0xA339,
	0xFFFD: 0xA33A,
	0xFFFD: 0xA33B,
	0xFFFD: 0xA33C,
	0xFFFD: 0xA33D,
	0xFFFD: 0xA33E,
	0xFFFD: 0xA33F,
	0xFFFD: 0xA340,
	0xFFFD: 0xA341,
	0xFFFD: 0xA342,
	0xFFFD: 0xA343,
	0xFFFD: 0xA344,
	0xFFFD: 0xA345,
	0xFFFD: 0xA346,
	0xFFFD: 0xA347,
	0xFFFD: 0xA348,
	0xFFFD: 0xA349,
	0xFFFD: 0xA34A,
	0xFFFD: 0xA34B,
	0xFFFD: 0xA34C,
	0xFFFD: 0xA34D,
	0xFFFD: 0xA34E,
	0xFFFD: 0xA34F,
	0xFFFD: 0xA350,
	0xFFFD: 0xA351,
	0xFFFD: 0xA352,
	0xFFFD: 0xA353,
	0xFFFD: 0xA354,
	0xFFFD: 0xA355,
	0xFFFD: 0xA356,
	0xFFFD: 0xA357,
	0xFFFD: 0xA358,
	0xFFFD: 0xA359,
	0xFFFD: 0xA35A,
	0xFFFD: 0xA35B,
	0xFFFD: 0xA35C,
	0xFFFD: 0xA35D,
	0xFFFD: 0xA35E,
	0xFFFD: 0xA35F,
	0xFFFD: 0xA360,
	0xFFFD: 0xA361,
	0xFFFD: 0xA362,
	0xFFFD: 0xA363,
	0xFFFD: 0xA364,
	0xFFFD: 0xA365,
	0xFFFD: 0xA366,
	0xFFFD: 0xA367,
	0xFFFD: 0xA368,
	0xFFFD: 0xA369,
	0xFFFD: 0xA36A,
	0xFFFD: 0xA36B,
	0xFFFD: 0xA36C,
	0xFFFD: 0xA36D,
	0xFFFD: 0xA36E,
	0xFFFD: 0xA36F,
	0xFFFD: 0xA370,
	0xFFFD: 0xA371,
	0xFFFD: 0xA372,
	0xFFFD: 0xA373,
	0xFFFD: 0xA374,
	0xFFFD: 0xA375,
	0xFFFD: 0xA376,
	0xFFFD: 0xA377,
	0xFFFD: 0xA378,
	0xFFFD: 0xA379,
	0xFFFD: 0xA37A,
	0xFFFD: 0xA37B,
	0xFFFD: 0xA37C,
	0xFFFD: 0xA37D,
	0xFFFD: 0xA37E,
	0xFFFD: 0xA37F,
	0xFFFD: 0xA380,
	0xFFFD: 0xA381,
	0xFFFD: 0xA382,
	0xFFFD: 0xA383,
	0xFFFD: 0xA384,
	0xFFFD: 0xA385,
	0xFFFD: 0xA386,
	0xFFFD: 0xA387,
	0xFFFD: 0xA388,
	0xFFFD: 0xA389,
	0xFFFD: 0xA38A,
	0xFFFD: 0xA38B,
	0xFFFD: 0xA38C,
	0xFFFD: 0xA38D,
	0xFFFD: 0xA38E,
	0xFFFD: 0xA38F,
	0xFFFD: 0xA390,
	0xFFFD: 0xA391,
	0xFFFD: 0xA392,
	0xFFFD: 0xA393,
	0xFFFD: 0xA394,
	0xFFFD: 0xA395,
	0xFFFD: 0xA396,
	0xFFFD: 0xA397,
	0xFFFD: 0xA398,
	0xFFFD: 0xA399,
	0xFFFD: 0xA39A,
	0xFFFD: 0xA39B,
	0xFFFD: 0xA39C,
	0xFFFD: 0xA39D,
	0xFFFD: 0xA39E,
	0xFFFD: 0xA39F,
	0xFFFD: 0xA3A0,
	0xFFFD: 0xA3A1,
	0xFFFD: 0xA3A2,
	0xFFFD: 0xA3A3,
	0xFFFD: 0xA3A4,
	0xFFFD: 0xA3A5,
	0xFFFD: 0xA3A6,
	0xFFFD: 0xA3A7,
	0xFFFD: 0xA3A8,
	0xFFFD: 0xA3A9,
	0xFFFD: 0xA3AA,
	0xFFFD: 0xA3AB,
	0xFFFD: 0xA3AC,
	0xFFFD: 0xA3AD,
	0xFFFD: 0xA3AE,
	0xFFFD: 0xA3AF,
	0xFFFD: 0xA3B0,
	0xFFFD: 0xA3B1,
	0xFFFD: 0xA3B2,
	0xFFFD: 0xA3B3,
	0xFFFD: 0xA3B4,
	0xFFFD: 0xA3B5,
	0xFFFD: 0xA3B6,
	0xFFFD: 0xA3B7,
	0xFFFD: 0xA3B8,
	0xFFFD: 0xA3B9,
	0xFFFD: 0xA3BA,
	0xFFFD: 0xA3BB,
	0xFFFD: 0xA3BC,
	0xFFFD: 0xA3BD,
	0xFFFD: 0xA3BE,
	0xFFFD: 0xA3BF,
	0xFFFD: 0xA3C0,
	0xFFFD: 0xA3C1,
	0xFFFD: 0xA3C2,
	0xFFFD: 0xA3C3,
	0xFFFD: 0xA3C4,
	0xFFFD: 0xA3C5,
	0xFFFD: 0xA3C6,
	0xFFFD: 0xA3C7,
	0xFFFD: 0xA3C8,
	0xFFFD: 0xA3C9,
	0xFFFD: 0xA3CA,
	0xFFFD: 0xA3CB,
	0xFFFD: 0xA3CC,
	0xFFFD: 0xA3CD,
	0xFFFD: 0xA3CE,
	0xFFFD: 0xA3CF,
	0xFFFD: 0xA3D0,
	0xFFFD: 0xA3D1,
	0xFFFD: 0xA3D2,
	0xFFFD: 0xA3D3,
	0xFFFD: 0xA3D4,
	0xFFFD: 0xA3D5,
	0xFFFD: 0xA3D6,
	0xFFFD: 0xA3D7,
	0xFFFD: 0xA3D8,
	0xFFFD: 0xA3D9,
	0xFFFD: 0xA3DA,
	0xFFFD: 0xA3DB,
	0xFFFD: 0xA3DC,
	0xFFFD: 0xA3DD,
	0xFFFD: 0xA3DE,
	0xFFFD: 0xA3DF,
	0xFFFD: 0xA3E0,
	0xFFFD: 0xA3E1,
	0xFFFD: 0xA3E2,
	0xFFFD: 0xA3E3,
	0xFFFD: 0xA3E4,
	0xFFFD: 0xA3E5,
	0xFFFD: 0xA3E6,
	0xFFFD: 0xA3E7,
	0xFFFD: 0xA3E8,
	0xFFFD: 0xA3E9,
	0xFFFD: 0xA3EA,
	0xFFFD: 0xA3EB,
	0xFFFD: 0xA3EC,
	0xFFFD: 0xA3ED,
	0xFFFD: 0xA3EE,
	0xFFFD: 0xA3EF,
	0xFFFD: 0xA3F0,
	0xFFFD: 0xA3F1,
	0xFFFD: 0xA3F2,
	0xFFFD: 0xA3F3,
	0xFFFD: 0xA3F4,
	0xFFFD: 0xA3F5,
	0xFFFD: 0xA3F6,
	0xFFFD: 0xA3F7,
	0xFFFD: 0xA3F8,
	0xFFFD: 0xA3F9,
	0xFFFD: 0xA3FA,
	0xFFFD: 0xA3FB,
	0xFFFD: 0xA3FC,
	0xFFFD: 0xA3FD,
	0xFFFD: 0xA3FE,
	0xFFFD: 0xA3FF,
	0xFFFD: 0xA400,
	0xFFFD: 0xA401,
	0xFFFD: 0xA402,
	0xFFFD: 0xA403,
	0xFFFD: 0xA404,
	0xFFFD: 0xA405,
	0xFFFD: 0xA406,
	0xFFFD: 0xA407,
	0xFFFD: 0xA408,
	0xFFFD: 0xA409,
	0xFFFD: 0xA40A,
	0xFFFD: 0xA40B,
	0xFFFD: 0xA40C,
	0xFFFD: 0xA40D,
	0xFFFD: 0xA40E,
	0xFFFD: 0xA40F,
	0xFFFD: 0xA410,
	0xFFFD: 0xA411,
	0xFFFD: 0xA412,
	0xFFFD: 0xA413,
	0xFFFD: 0xA414,
	0xFFFD: 0xA415,
	0xFFFD: 0xA416,
	0xFFFD: 0xA417,
	0xFFFD: 0xA418,
	0xFFFD: 0xA419,
	0xFFFD: 0xA41A,
	0xFFFD: 0xA41B,
	0xFFFD: 0xA41C,
	0xFFFD: 0xA41D,
	0xFFFD: 0xA41E,
	0xFFFD: 0xA41F,
	0xFFFD: 0xA420,
	0xFFFD: 0xA421,
	0xFFFD: 0xA422,
	0xFFFD: 0xA423,
	0xFFFD: 0xA424,
	0xFFFD: 0xA425,
	0xFFFD: 0xA426,
	0xFFFD: 0xA427,
	0xFFFD: 0xA428,
	0xFFFD: 0xA429,
	0xFFFD: 0xA42A,
	0xFFFD: 0xA42B,
	0xFFFD: 0xA42C,
	0xFFFD: 0xA42D,
	0xFFFD: 0xA42E,
	0xFFFD: 0xA42F,
	0xFFFD: 0xA430,
	0xFFFD: 0xA431,
	0xFFFD: 0xA432,
	0xFFFD: 0xA433,
	0xFFFD: 0xA434,
	0xFFFD: 0xA435,
	0xFFFD: 0xA436,
	0xFFFD: 0xA437,
	0xFFFD: 0xA438,
	0xFFFD: 0xA439,
	0xFFFD: 0xA43A,
	0xFFFD: 0xA43B,
	0xFFFD: 0xA43C,
	0xFFFD: 0xA43D,
	0xFFFD: 0xA43E,
	0xFFFD: 0xA43F,
	0xFFFD: 0xA440,
	0xFFFD: 0xA441,
	0xFFFD: 0xA442,
	0xFFFD: 0xA443,
	0xFFFD: 0xA444,
	0xFFFD: 0xA445,
	0xFFFD: 0xA446,
	0xFFFD: 0xA447,
	0xFFFD: 0xA448,
	0xFFFD: 0xA449,
	0xFFFD: 0xA44A,
	0xFFFD: 0xA44B,
	0xFFFD: 0xA44C,
	0xFFFD: 0xA44D,
	0xFFFD: 0xA44E,
	0xFFFD: 0xA44F,
	0xFFFD: 0xA450,
	0xFFFD: 0xA451,
	0xFFFD: 0xA452,
	0xFFFD: 0xA453,
	0xFFFD: 0xA454,
	0xFFFD: 0xA455,
	0xFFFD: 0xA456,
	0xFFFD: 0xA457,
	0xFFFD: 0xA458,
	0xFFFD: 0xA459,
	0xFFFD: 0xA45A,
	0xFFFD: 0xA45B,
	0xFFFD: 0xA45C,
	0xFFFD: 0xA45D,
	0xFFFD: 0xA45E,
	0xFFFD: 0xA45F,
	0xFFFD: 0xA460,
	0xFFFD: 0xA461,
	0xFFFD: 0xA462,
	0xFFFD: 0xA463,
	0xFFFD: 0xA464,
	0xFFFD: 0xA465,
	0xFFFD: 0xA466,
	0xFFFD: 0xA467,
	0xFFFD: 0xA468,
	0xFFFD: 0xA469,
	0xFFFD: 0xA46A,
	0xFFFD: 0xA46B,
	0xFFFD: 0xA46C,
	0xFFFD: 0xA46D,
	0xFFFD: 0xA46E,
	0xFFFD: 0xA46F,
	0xFFFD: 0xA470,
	0xFFFD: 0xA471,
	0xFFFD: 0xA472,
	0xFFFD: 0xA473,
	0xFFFD: 0xA474,
	0xFFFD: 0xA475,
	0xFFFD: 0xA476,
	0xFFFD: 0xA477,
	0xFFFD: 0xA478,
	0xFFFD: 0xA479,
	0xFFFD: 0xA47A,
	0xFFFD: 0xA47B,
	0xFFFD: 0xA47C,
	0xFFFD: 0xA47D,
	0xFFFD: 0xA47E,
	0xFFFD: 0xA47F,
	0xFFFD: 0xA480,
	0xFFFD: 0xA481,
	0xFFFD: 0xA482,
	0xFFFD: 0xA483,
	0xFFFD: 0xA484,
	0xFFFD: 0xA485,
	0xFFFD: 0xA486,
	0xFFFD: 0xA487,
	0xFFFD: 0xA488,
	0xFFFD: 0xA489,
	0xFFFD: 0xA48A,
	0xFFFD: 0xA48B,
	0xFFFD: 0xA48C,
	0xFFFD: 0xA48D,
	0xFFFD: 0xA48E,
	0xFFFD: 0xA48F,
	0xFFFD: 0xA490,
	0xFFFD: 0xA491,
	0xFFFD: 0xA492,
	0xFFFD: 0xA493,
	0xFFFD: 0xA494,
	0xFFFD: 0xA495,
	0xFFFD: 0xA496,
	0xFFFD: 0xA497,
	0xFFFD: 0xA498,
	0xFFFD: 0xA499,
	0xFFFD: 0xA49A,
	0xFFFD: 0xA49B,
	0xFFFD: 0xA49C,
	0xFFFD: 0xA49D,
	0xFFFD: 0xA49E,
	0xFFFD: 0xA49F,
	0xFFFD: 0xA4A0,
	0xFFFD: 0xA4A1,
	0xFFFD: 0xA4A2,
	0xFFFD: 0xA4A3,
	0xFFFD: 0xA4A4,
	0xFFFD: 0xA4A5,
	0xFFFD: 0xA4A6,
	0xFFFD: 0xA4A7,
	0xFFFD: 0xA4A8,
	0xFFFD: 0xA4A9,
	0xFFFD: 0xA4AA,
	0xFFFD: 0xA4AB,
	0xFFFD: 0xA4AC,
	0xFFFD: 0xA4AD,
	0xFFFD: 0xA4AE,
	0xFFFD: 0xA4AF,
	0xFFFD: 0xA4B0,
	0xFFFD: 0xA4B1,
	0xFFFD: 0xA4B2,
	0xFFFD: 0xA4B3,
	0xFFFD: 0xA4B4,
	0xFFFD: 0xA4B5,
	0xFFFD: 0xA4B6,
	0xFFFD: 0xA4B7,
	0xFFFD: 0xA4B8,
	0xFFFD: 0xA4B9,
	0xFFFD: 0xA4BA,
	0xFFFD: 0xA4BB,
	0xFFFD: 0xA4BC,
	0xFFFD: 0xA4BD,
	0xFFFD: 0xA4BE,
	0xFFFD: 0xA4BF,
	0xFFFD: 0xA4C0,
	0xFFFD: 0xA4C1,
	0xFFFD: 0xA4C2,
	0xFFFD: 0xA4C3,
	0xFFFD: 0xA4C4,
	0xFFFD: 0xA4C5,
	0xFFFD: 0xA4C6,
	0xFFFD: 0xA4C7,
	0xFFFD: 0xA4C8,
	0xFFFD: 0xA4C9,
	0xFFFD: 0xA4CA,
	0xFFFD: 0xA4CB,
	0xFFFD: 0xA4CC,
	0xFFFD: 0xA4CD,
	0xFFFD: 0xA4CE,
	0xFFFD: 0xA4CF,
	0xFFFD: 0xA4D0,
	0xFFFD: 0xA4D1,
	0xFFFD: 0xA4D2,
	0xFFFD: 0xA4D3,
	0xFFFD: 0xA4D4,
	0xFFFD: 0xA4D5,
	0xFFFD: 0xA4D6,
	0xFFFD: 0xA4D7,
	0xFFFD: 0xA4D8,
	0xFFFD: 0xA4D9,
	0xFFFD: 0xA4DA,
	0xFFFD: 0xA4DB,
	0xFFFD: 0xA4DC,
	0xFFFD: 0xA4DD,
	0xFFFD: 0xA4DE,
	0xFFFD: 0xA4DF,
	0xFFFD: 0xA4E0,
	0xFFFD: 0xA4E1,
	0xFFFD: 0xA4E2,
	0xFFFD: 0xA4E3,
	0xFFFD: 0xA4E4,
	0xFFFD: 0xA4E5,
	0xFFFD: 0xA4E6,
	0xFFFD: 0xA4E7,
	0xFFFD: 0xA4E8,
	0xFFFD: 0xA4E9,
	0xFFFD: 0xA4EA,
	0xFFFD: 0xA4EB,
	0xFFFD: 0xA4EC,
	0xFFFD: 0xA4ED,
	0xFFFD: 0xA4EE,
	0xFFFD: 0xA4EF,
	0xFFFD: 0xA4F0,
	0xFFFD: 0xA4F1,
	0xFFFD: 0xA4F2,
	0xFFFD: 0xA4F3,
	0xFFFD: 0xA4F4,
	0xFFFD: 0xA4F5,
	0xFFFD: 0xA4F6,
	0xFFFD: 0xA4F7,
	0xFFFD: 0xA4F8,
	0xFFFD: 0xA4F9,
	0xFFFD: 0xA4FA,
	0xFFFD: 0xA4FB,
	0xFFFD: 0xA4FC,
	0xFFFD: 0xA4FD,
	0xFFFD: 0xA4FE,
	0xFFFD: 0xA4FF,
	0xFFFD: 0xA500,
	0xFFFD: 0xA501,
	0xFFFD: 0xA502,
	0xFFFD: 0xA503,
	0xFFFD: 0xA504,
	0xFFFD: 0xA505,
	0xFFFD: 0xA506,
	0xFFFD: 0xA507,
	0xFFFD: 0xA508,
	0xFFFD: 0xA509,
	0xFFFD: 0xA50A,
	0xFFFD: 0xA50B,
	0xFFFD: 0xA50C,
	0xFFFD: 0xA50D,
	0xFFFD: 0xA50E,
	0xFFFD: 0xA50F,
	0xFFFD: 0xA510,
	0xFFFD: 0xA511,
	0xFFFD: 0xA512,
	0xFFFD: 0xA513,
	0xFFFD: 0xA514,
	0xFFFD: 0xA515,
	0xFFFD: 0xA516,
	0xFFFD: 0xA517,
	0xFFFD: 0xA518,
	0xFFFD: 0xA519,
	0xFFFD: 0xA51A,
	0xFFFD: 0xA51B,
	0xFFFD: 0xA51C,
	0xFFFD: 0xA51D,
	0xFFFD: 0xA51E,
	0xFFFD: 0xA51F,
	0xFFFD: 0xA520,
	0xFFFD: 0xA521,
	0xFFFD: 0xA522,
	0xFFFD: 0xA523,
	0xFFFD: 0xA524,
	0xFFFD: 0xA525,
	0xFFFD: 0xA526,
	0xFFFD: 0xA527,
	0xFFFD: 0xA528,
	0xFFFD: 0xA529,
	0xFFFD: 0xA52A,
	0xFFFD: 0xA52B,
	0xFFFD: 0xA52C,
	0xFFFD: 0xA52D,
	0xFFFD: 0xA52E,
	0xFFFD: 0xA52F,
	0xFFFD: 0xA530,
	0xFFFD: 0xA531,
	0xFFFD: 0xA532,
	0xFFFD: 0xA533,
	0xFFFD: 0xA534,
	0xFFFD: 0xA535,
	0xFFFD: 0xA536,
	0xFFFD: 0xA537,
	0xFFFD: 0xA538,
	0xFFFD: 0xA539,
	0xFFFD: 0xA53A,
	0xFFFD: 0xA53B,
	0xFFFD: 0xA53C,
	0xFFFD: 0xA53D,
	0xFFFD: 0xA53E,
	0xFFFD: 0xA53F,
	0xFFFD: 0xA540,
	0xFFFD: 0xA541,
	0xFFFD: 0xA542,
	0xFFFD: 0xA543,
	0xFFFD: 0xA544,
	0xFFFD: 0xA545,
	0xFFFD: 0xA546,
	0xFFFD: 0xA547,
	0xFFFD: 0xA548,
	0xFFFD: 0xA549,
	0xFFFD: 0xA54A,
	0xFFFD: 0xA54B,
	0xFFFD: 0xA54C,
	0xFFFD: 0xA54D,
	0xFFFD: 0xA54E,
	0xFFFD: 0xA54F,
	0xFFFD: 0xA550,
	0xFFFD: 0xA551,
	0xFFFD: 0xA552,
	0xFFFD: 0xA553,
	0xFFFD: 0xA554,
	0xFFFD: 0xA555,
	0xFFFD: 0xA556,
	0xFFFD: 0xA557,
	0xFFFD: 0xA558,
	0xFFFD: 0xA559,
	0xFFFD: 0xA55A,
	0xFFFD: 0xA55B,
	0xFFFD: 0xA55C,
	0xFFFD: 0xA55D,
	0xFFFD: 0xA55E,
	0xFFFD: 0xA55F,
	0xFFFD: 0xA560,
	0xFFFD: 0xA561,
	0xFFFD: 0xA562,
	0xFFFD: 0xA563,
	0xFFFD: 0xA564,
	0xFFFD: 0xA565,
	0xFFFD: 0xA566,
	0xFFFD: 0xA567,
	0xFFFD: 0xA568,
	0xFFFD: 0xA569,
	0xFFFD: 0xA56A,
	0xFFFD: 0xA56B,
	0xFFFD: 0xA56C,
	0xFFFD: 0xA56D,
	0xFFFD: 0xA56E,
	0xFFFD: 0xA56F,
	0xFFFD: 0xA570,
	0xFFFD: 0xA571,
	0xFFFD: 0xA572,
	0xFFFD: 0xA573,
	0xFFFD: 0xA574,
	0xFFFD: 0xA575,
	0xFFFD: 0xA576,
	0xFFFD: 0xA577,
	0xFFFD: 0xA578,
	0xFFFD: 0xA579,
	0xFFFD: 0xA57A,
	0xFFFD: 0xA57B,
	0xFFFD: 0xA57C,
	0xFFFD: 0xA57D,
	0xFFFD: 0xA57E,
	0xFFFD: 0xA57F,
	0xFFFD: 0xA580,
	0xFFFD: 0xA581,
	0xFFFD: 0xA582,
	0xFFFD: 0xA583,
	0xFFFD: 0xA584,
	0xFFFD: 0xA585,
	0xFFFD: 0xA586,
	0xFFFD: 0xA587,
	0xFFFD: 0xA588,
	0xFFFD: 0xA589,
	0xFFFD: 0xA58A,
	0xFFFD: 0xA58B,
	0xFFFD: 0xA58C,
	0xFFFD: 0xA58D,
	0xFFFD: 0xA58E,
	0xFFFD: 0xA58F,
	0xFFFD: 0xA590,
	0xFFFD: 0xA591,
	0xFFFD: 0xA592,
	0xFFFD: 0xA593,
	0xFFFD: 0xA594,
	0xFFFD: 0xA595,
	0xFFFD: 0xA596,
	0xFFFD: 0xA597,
	0xFFFD: 0xA598,
	0xFFFD: 0xA599,
	0xFFFD: 0xA59A,
	0xFFFD: 0xA59B,
	0xFFFD: 0xA59C,
	0xFFFD: 0xA59D,
	0xFFFD: 0xA59E,
	0xFFFD: 0xA59F,
	0xFFFD: 0xA5A0,
	0xFFFD: 0xA5A1,
	0xFFFD: 0xA5A2,
	0xFFFD: 0xA5A3,
	0xFFFD: 0xA5A4,
	0xFFFD: 0xA5A5,
	0xFFFD: 0xA5A6,
	0xFFFD: 0xA5A7,
	0xFFFD: 0xA5A8,
	0xFFFD: 0xA5A9,
	0xFFFD: 0xA5AA,
	0xFFFD: 0xA5AB,
	0xFFFD: 0xA5AC,
	0xFFFD: 0xA5AD,
	0xFFFD: 0xA5AE,
	0xFFFD: 0xA5AF,
	0xFFFD: 0xA5B0,
	0xFFFD: 0xA5B1,
	0xFFFD: 0xA5B2,
	0xFFFD: 0xA5B3,
	0xFFFD: 0xA5B4,
	0xFFFD: 0xA5B5,
	0xFFFD: 0xA5B6,
	0xFFFD: 0xA5B7,
	0xFFFD: 0xA5B8,
	0xFFFD: 0xA5B9,
	0xFFFD: 0xA5BA,
	0xFFFD: 0xA5BB,
	0xFFFD: 0xA5BC,
	0xFFFD: 0xA5BD,
	0xFFFD: 0xA5BE,
	0xFFFD: 0xA5BF,
	0xFFFD: 0xA5C0,
	0xFFFD: 0xA5C1,
	0xFFFD: 0xA5C2,
	0xFFFD: 0xA5C3,
	0xFFFD: 0xA5C4,
	0xFFFD: 0xA5C5,
	0xFFFD: 0xA5C6,
	0xFFFD: 0xA5C7,
	0xFFFD: 0xA5C8,
	0xFFFD: 0xA5C9,
	0xFFFD: 0xA5CA,
	0xFFFD: 0xA5CB,
	0xFFFD: 0xA5CC,
	0xFFFD: 0xA5CD,
	0xFFFD: 0xA5CE,
	0xFFFD: 0xA5CF,
	0xFFFD: 0xA5D0,
	0xFFFD: 0xA5D1,
	0xFFFD: 0xA5D2,
	0xFFFD: 0xA5D3,
	0xFFFD: 0xA5D4,
	0xFFFD: 0xA5D5,
	0xFFFD: 0xA5D6,
	0xFFFD: 0xA5D7,
	0xFFFD: 0xA5D8,
	0xFFFD: 0xA5D9,
	0xFFFD: 0xA5DA,
	0xFFFD: 0xA5DB,
	0xFFFD: 0xA5DC,
	0xFFFD: 0xA5DD,
	0xFFFD: 0xA5DE,
	0xFFFD: 0xA5DF,
	0xFFFD: 0xA5E0,
	0xFFFD: 0xA5E1,
	0xFFFD: 0xA5E2,
	0xFFFD: 0xA5E3,
	0xFFFD: 0xA5E4,
	0xFFFD: 0xA5E5,
	0xFFFD: 0xA5E6,
	0xFFFD: 0xA5E7,
	0xFFFD: 0xA5E8,
	0xFFFD: 0xA5E9,
	0xFFFD: 0xA5EA,
	0xFFFD: 0xA5EB,
	0xFFFD: 0xA5EC,
	0xFFFD: 0xA5ED,
	0xFFFD: 0xA5EE,
	0xFFFD: 0xA5EF,
	0xFFFD: 0xA5F0,
	0xFFFD: 0xA5F1,
	0xFFFD: 0xA5F2,
	0xFFFD: 0xA5F3,
	0xFFFD: 0xA5F4,
	0xFFFD: 0xA5F5,
	0xFFFD: 0xA5F6,
	0xFFFD: 0xA5F7,
	0xFFFD: 0xA5F8,
	0xFFFD: 0xA5F9,
	0xFFFD: 0xA5FA,
	0xFFFD: 0xA5FB,
	0xFFFD: 0xA5FC,
	0xFFFD: 0xA5FD,
	0xFFFD: 0xA5FE,
	0xFFFD: 0xA5FF,
	0xFFFD: 0xA600,
	0xFFFD: 0xA601,
	0xFFFD: 0xA602,
	0xFFFD: 0xA603,
	0xFFFD: 0xA604,
	0xFFFD: 0xA605,
	0xFFFD: 0xA606,
	0xFFFD: 0xA607,
	0xFFFD: 0xA608,
	0xFFFD: 0xA609,
	0xFFFD: 0xA60A,
	0xFFFD: 0xA60B,
	0xFFFD: 0xA60C,
	0xFFFD: 0xA60D,
	0xFFFD: 0xA60E,
	0xFFFD: 0xA60F,
	0xFFFD: 0xA610,
	0xFFFD: 0xA611,
	0xFFFD: 0xA612,
	0xFFFD: 0xA613,
	0xFFFD: 0xA614,
	0xFFFD: 0xA615,
	0xFFFD: 0xA616,
	0xFFFD: 0xA617,
	0xFFFD: 0xA618,
	0xFFFD: 0xA619,
	0xFFFD: 0xA61A,
	0xFFFD: 0xA61B,
	0xFFFD: 0xA61C,
	0xFFFD: 0xA61D,
	0xFFFD: 0xA61E,
	0xFFFD: 0xA61F,
	0xFFFD: 0xA620,
	0xFFFD: 0xA621,
	0xFFFD: 0xA622,
	0xFFFD: 0xA623,
	0xFFFD: 0xA624,
	0xFFFD: 0xA625,
	0xFFFD: 0xA626,
	0xFFFD: 0xA627,
	0xFFFD: 0xA628,
	0xFFFD: 0xA629,
	0xFFFD: 0xA62A,
	0xFFFD: 0xA62B,
	0xFFFD: 0xA62C,
	0xFFFD: 0xA62D,
	0xFFFD: 0xA62E,
	0xFFFD: 0xA62F,
	0xFFFD: 0xA630,
	0xFFFD: 0xA631,
	0xFFFD: 0xA632,
	0xFFFD: 0xA633,
	0xFFFD: 0xA634,
	0xFFFD: 0xA635,
	0xFFFD: 0xA636,
	0xFFFD: 0xA637,
	0xFFFD: 0xA638,
	0xFFFD: 0xA639,
	0xFFFD: 0xA63A,
	0xFFFD: 0xA63B,
	0xFFFD: 0xA63C,
	0xFFFD: 0xA63D,
	0xFFFD: 0xA63E,
	0xFFFD: 0xA63F,
	0xFFFD: 0xA640,
	0xFFFD: 0xA641,
	0xFFFD: 0xA642,
	0xFFFD: 0xA643,
	0xFFFD: 0xA644,
	0xFFFD: 0xA645,
	0xFFFD: 0xA646,
	0xFFFD: 0xA647,
	0xFFFD: 0xA648,
	0xFFFD: 0xA649,
	0xFFFD: 0xA64A,
	0xFFFD: 0xA64B,
	0xFFFD: 0xA64C,
	0xFFFD: 0xA64D,
	0xFFFD: 0xA64E,
	0xFFFD: 0xA64F,
	0xFFFD: 0xA650,
	0xFFFD: 0xA651,
	0xFFFD: 0xA652,
	0xFFFD: 0xA653,
	0xFFFD: 0xA654,
	0xFFFD: 0xA655,
	0xFFFD: 0xA656,
	0xFFFD: 0xA657,
	0xFFFD: 0xA658,
	0xFFFD: 0xA659,
	0xFFFD: 0xA65A,
	0xFFFD: 0xA65B,
	0xFFFD: 0xA65C,
	0xFFFD: 0xA65D,
	0xFFFD: 0xA65E,
	0xFFFD: 0xA65F,
	0xFFFD: 0xA660,
	0xFFFD: 0xA661,
	0xFFFD: 0xA662,
	0xFFFD: 0xA663,
	0xFFFD: 0xA664,
	0xFFFD: 0xA665,
	0xFFFD: 0xA666,
	0xFFFD: 0xA667,
	0xFFFD: 0xA668,
	0xFFFD: 0xA669,
	0xFFFD: 0xA66A,
	0xFFFD: 0xA66B,
	0xFFFD: 0xA66C,
	0xFFFD: 0xA66D,
	0xFFFD: 0xA66E,
	0xFFFD: 0xA66F,
	0xFFFD: 0xA670,
	0xFFFD: 0xA671,
	0xFFFD: 0xA672,
	0xFFFD: 0xA673,
	0xFFFD: 0xA674,
	0xFFFD: 0xA675,
	0xFFFD: 0xA676,
	0xFFFD: 0xA677,
	0xFFFD: 0xA678,
	0xFFFD: 0xA679,
	0xFFFD: 0xA67A,
	0xFFFD: 0xA67B,
	0xFFFD: 0xA67C,
	0xFFFD: 0xA67D,
	0xFFFD: 0xA67E,
	0xFFFD: 0xA67F,
	0xFFFD: 0xA680,
	0xFFFD: 0xA681,
	0xFFFD: 0xA682,
	0xFFFD: 0xA683,
	0xFFFD: 0xA684,
	0xFFFD: 0xA685,
	0xFFFD: 0xA686,
	0xFFFD: 0xA687,
	0xFFFD: 0xA688,
	0xFFFD: 0xA689,
	0xFFFD: 0xA68A,
	0xFFFD: 0xA68B,
	0xFFFD: 0xA68C,
	0xFFFD: 0xA68D,
	0xFFFD: 0xA68E,
	0xFFFD: 0xA68F,
	0xFFFD: 0xA690,
	0xFFFD: 0xA691,
	0xFFFD: 0xA692,
	0xFFFD: 0xA693,
	0xFFFD: 0xA694,
	0xFFFD: 0xA695,
	0xFFFD: 0xA696,
	0xFFFD: 0xA697,
	0xFFFD: 0xA698,
	0xFFFD: 0xA699,
	0xFFFD: 0xA69A,
	0xFFFD: 0xA69B,
	0xFFFD: 0xA69C,
	0xFFFD: 0xA69D,
	0xFFFD: 0xA69E,
	0xFFFD: 0xA69F,
	0xFFFD: 0xA6A0,
	0xFFFD: 0xA6A1,
	0xFFFD: 0xA6A2,
	0xFFFD: 0xA6A3,
	0xFFFD: 0xA6A4,
	0xFFFD: 0xA6A5,
	0xFFFD: 0xA6A6,
	0xFFFD: 0xA6A7,
	0xFFFD: 0xA6A8,
	0xFFFD: 0xA6A9,
	0xFFFD: 0xA6AA,
	0xFFFD: 0xA6AB,
	0xFFFD: 0xA6AC,
	0xFFFD: 0xA6AD,
	0xFFFD: 0xA6AE,
	0xFFFD: 0xA6AF,
	0xFFFD: 0xA6B0,
	0xFFFD: 0xA6B1,
	0xFFFD: 0xA6B2,
	0xFFFD: 0xA6B3,
	0xFFFD: 0xA6B4,
	0xFFFD: 0xA6B5,
	0xFFFD: 0xA6B6,
	0xFFFD: 0xA6B7,
	0xFFFD: 0xA6B8,
	0xFFFD: 0xA6B9,
	0xFFFD: 0xA6BA,
	0xFFFD: 0xA6BB,
	0xFFFD: 0xA6BC,
	0xFFFD: 0xA6BD,
	0xFFFD: 0xA6BE,
	0xFFFD: 0xA6BF,
	0xFFFD: 0xA6C0,
	0xFFFD: 0xA6C1,
	0xFFFD: 0xA6C2,
	0xFFFD: 0xA6C3,
	0xFFFD: 0xA6C4,
	0xFFFD: 0xA6C5,
	0xFFFD: 0xA6C6,
	0xFFFD: 0xA6C7,
	0xFFFD: 0xA6C8,
	0xFFFD: 0xA6C9,
	0xFFFD: 0xA6CA,
	0xFFFD: 0xA6CB,
	0xFFFD: 0xA6CC,
	0xFFFD: 0xA6CD,
	0xFFFD: 0xA6CE,
	0xFFFD: 0xA6CF,
	0xFFFD: 0xA6D0,
	0xFFFD: 0xA6D1,
	0xFFFD: 0xA6D2,
	0xFFFD: 0xA6D3,
	0xFFFD: 0xA6D4,
	0xFFFD: 0xA6D5,
	0xFFFD: 0xA6D6,
	0xFFFD: 0xA6D7,
	0xFFFD: 0xA6D8,
	0xFFFD: 0xA6D9,
	0xFFFD: 0xA6DA,
	0xFFFD: 0xA6DB,
	0xFFFD: 0xA6DC,
	0xFFFD: 0xA6DD,
	0xFFFD: 0xA6DE,
	0xFFFD: 0xA6DF,
	0xFFFD: 0xA6E0,
	0xFFFD: 0xA6E1,
	0xFFFD: 0xA6E2,
	0xFFFD: 0xA6E3,
	0xFFFD: 0xA6E4,
	0xFFFD: 0xA6E5,
	0xFFFD: 0xA6E6,
	0xFFFD: 0xA6E7,
	0xFFFD: 0xA6E8,
	0xFFFD: 0xA6E9,
	0xFFFD: 0xA6EA,
	0xFFFD: 0xA6EB,
	0xFFFD: 0xA6EC,
	0xFFFD: 0xA6ED,
	0xFFFD: 0xA6EE,
	0xFFFD: 0xA6EF,
	0xFFFD: 0xA6F0,
	0xFFFD: 0xA6F1,
	0xFFFD: 0xA6F2,
	0xFFFD: 0xA6F3,
	0xFFFD: 0xA6F4,
	0xFFFD: 0xA6F5,
	0xFFFD: 0xA6F6,
	0xFFFD: 0xA6F7,
	0xFFFD: 0xA6F8,
	0xFFFD: 0xA6F9,
	0xFFFD: 0xA6FA,
	0xFFFD: 0xA6FB,
	0xFFFD: 0xA6FC,
	0xFFFD: 0xA6FD,
	0xFFFD: 0xA6FE,
	0xFFFD: 0xA6FF,
	0xFFFD: 0xA700,
	0xFFFD: 0xA701,
	0xFFFD: 0xA702,
	0xFFFD: 0xA703,
	0xFFFD: 0xA704,
	0xFFFD: 0xA705,
	0xFFFD: 0xA706,
	0xFFFD: 0xA707,
	0xFFFD: 0xA708,
	0xFFFD: 0xA709,
	0xFFFD: 0xA70A,
	0xFFFD: 0xA70B,
	0xFFFD: 0xA70C,
	0xFFFD: 0xA70D,
	0xFFFD: 0xA70E,
	0xFFFD: 0xA70F,
	0xFFFD: 0xA710,
	0xFFFD: 0xA711,
	0xFFFD: 0xA712,
	0xFFFD: 0xA713,
	0xFFFD: 0xA714,
	0xFFFD: 0xA715,
	0xFFFD: 0xA716,
	0xFFFD: 0xA717,
	0xFFFD: 0xA718,
	0xFFFD: 0xA719,
	0xFFFD: 0xA71A,
	0xFFFD: 0xA71B,
	0xFFFD: 0xA71C,
	0xFFFD: 0xA71D,
	0xFFFD: 0xA71E,
	0xFFFD: 0xA71F,
	0xFFFD: 0xA720,
	0xFFFD: 0xA721,
	0xFFFD: 0xA722,
	0xFFFD: 0xA723,
	0xFFFD: 0xA724,
	0xFFFD: 0xA725,
	0xFFFD: 0xA726,
	0xFFFD: 0xA727,
	0xFFFD: 0xA728,
	0xFFFD: 0xA729,
	0xFFFD: 0xA72A,
	0xFFFD: 0xA72B,
	0xFFFD: 0xA72C,
	0xFFFD: 0xA72D,
	0xFFFD: 0xA72E,
	0xFFFD: 0xA72F,
	0xFFFD: 0xA730,
	0xFFFD: 0xA731,
	0xFFFD: 0xA732,
	0xFFFD: 0xA733,
	0xFFFD: 0xA734,
	0xFFFD: 0xA735,
	0xFFFD: 0xA736,
	0xFFFD: 0xA737,
	0xFFFD: 0xA738,
	0xFFFD: 0xA739,
	0xFFFD: 0xA73A,
	0xFFFD: 0xA73B,
	0xFFFD: 0xA73C,
	0xFFFD: 0xA73D,
	0xFFFD: 0xA73E,
	0xFFFD: 0xA73F,
	0xFFFD: 0xA740,
	0xFFFD: 0xA741,
	0xFFFD: 0xA742,
	0xFFFD: 0xA743,
	0xFFFD: 0xA744,
	0xFFFD: 0xA745,
	0xFFFD: 0xA746,
	0xFFFD: 0xA747,
	0xFFFD: 0xA748,
	0xFFFD: 0xA749,
	0xFFFD: 0xA74A,
	0xFFFD: 0xA74B,
	0xFFFD: 0xA74C,
	0xFFFD: 0xA74D,
	0xFFFD: 0xA74E,
	0xFFFD: 0xA74F,
	0xFFFD: 0xA750,
	0xFFFD: 0xA751,
	0xFFFD: 0xA752,
	0xFFFD: 0xA753,
	0xFFFD: 0xA754,
	0xFFFD: 0xA755,
	0xFFFD: 0xA756,
	0xFFFD: 0xA757,
	0xFFFD: 0xA758,
	0xFFFD: 0xA759,
	0xFFFD: 0xA75A,
	0xFFFD: 0xA75B,
	0xFFFD: 0xA75C,
	0xFFFD: 0xA75D,
	0xFFFD: 0xA75E,
	0xFFFD: 0xA75F,
	0xFFFD: 0xA760,
	0xFFFD: 0xA761,
	0xFFFD: 0xA762,
	0xFFFD: 0xA763,
	0xFFFD: 0xA764,
	0xFFFD: 0xA765,
	0xFFFD: 0xA766,
	0xFFFD: 0xA767,
	0xFFFD: 0xA768,
	0xFFFD: 0xA769,
	0xFFFD: 0xA76A,
	0xFFFD: 0xA76B,
	0xFFFD: 0xA76C,
	0xFFFD: 0xA76D,
	0xFFFD: 0xA76E,
	0xFFFD: 0xA76F,
	0xFFFD: 0xA770,
	0xFFFD: 0xA771,
	0xFFFD: 0xA772,
	0xFFFD: 0xA773,
	0xFFFD: 0xA774,
	0xFFFD: 0xA775,
	0xFFFD: 0xA776,
	0xFFFD: 0xA777,
	0xFFFD: 0xA778,
	0xFFFD: 0xA779,
	0xFFFD: 0xA77A,
	0xFFFD: 0xA77B,
	0xFFFD: 0xA77C,
	0xFFFD: 0xA77D,
	0xFFFD: 0xA77E,
	0xFFFD: 0xA77F,
	0xFFFD: 0xA780,
	0xFFFD: 0xA781,
	0xFFFD: 0xA782,
	0xFFFD: 0xA783,
	0xFFFD: 0xA784,
	0xFFFD: 0xA785,
	0xFFFD: 0xA786,
	0xFFFD: 0xA787,
	0xFFFD: 0xA788,
	0xFFFD: 0xA789,
	0xFFFD: 0xA78A,
	0xFFFD: 0xA78B,
	0xFFFD: 0xA78C,
	0xFFFD: 0xA78D,
	0xFFFD: 0xA78E,
	0xFFFD: 0xA78F,
	0xFFFD: 0xA790,
	0xFFFD: 0xA791,
	0xFFFD: 0xA792,
	0xFFFD: 0xA793,
	0xFFFD: 0xA794,
	0xFFFD: 0xA795,
	0xFFFD: 0xA796,
	0xFFFD: 0xA797,
	0xFFFD: 0xA798,
	0xFFFD: 0xA799,
	0xFFFD: 0xA79A,
	0xFFFD: 0xA79B,
	0xFFFD: 0xA79C,
	0xFFFD: 0xA79D,
	0xFFFD: 0xA79E,
	0xFFFD: 0xA79F,
	0xFFFD: 0xA7A0,
	0xFFFD: 0xA7A1,
	0xFFFD: 0xA7A2,
	0xFFFD: 0xA7A3,
	0xFFFD: 0xA7A4,
	0xFFFD: 0xA7A5,
	0xFFFD: 0xA7A6,
	0xFFFD: 0xA7A7,
	0xFFFD: 0xA7A8,
	0xFFFD: 0xA7A9,
	0xFFFD: 0xA7AA,
	0xFFFD: 0xA7AB,
	0xFFFD: 0xA7AC,
	0xFFFD: 0xA7AD,
	0xFFFD: 0xA7AE,
	0xFFFD: 0xA7AF,
	0xFFFD: 0xA7B0,
	0xFFFD: 0xA7B1,
	0xFFFD: 0xA7B2,
	0xFFFD: 0xA7B3,
	0xFFFD: 0xA7B4,
	0xFFFD: 0xA7B5,
	0xFFFD: 0xA7B6,
	0xFFFD: 0xA7B7,
	0xFFFD: 0xA7B8,
	0xFFFD: 0xA7B9,
	0xFFFD: 0xA7BA,
	0xFFFD: 0xA7BB,
	0xFFFD: 0xA7BC,
	0xFFFD: 0xA7BD,
	0xFFFD: 0xA7BE,
	0xFFFD: 0xA7BF,
	0xFFFD: 0xA7C0,
	0xFFFD: 0xA7C1,
	0xFFFD: 0xA7C2,
	0xFFFD: 0xA7C3,
	0xFFFD: 0xA7C4,
	0xFFFD: 0xA7C5,
	0xFFFD: 0xA7C6,
	0xFFFD: 0xA7C7,
	0xFFFD: 0xA7C8,
	0xFFFD: 0xA7C9,
	0xFFFD: 0xA7CA,
	0xFFFD: 0xA7CB,
	0xFFFD: 0xA7CC,
	0xFFFD: 0xA7CD,
	0xFFFD: 0xA7CE,
	0xFFFD: 0xA7CF,
	0xFFFD: 0xA7D0,
	0xFFFD: 0xA7D1,
	0xFFFD: 0xA7D2,
	0xFFFD: 0xA7D3,
	0xFFFD: 0xA7D4,
	0xFFFD: 0xA7D5,
	0xFFFD: 0xA7D6,
	0xFFFD: 0xA7D7,
	0xFFFD: 0xA7D8,
	0xFFFD: 0xA7D9,
	0xFFFD: 0xA7DA,
	0xFFFD: 0xA7DB,
	0xFFFD: 0xA7DC,
	0xFFFD: 0xA7DD,
	0xFFFD: 0xA7DE,
	0xFFFD: 0xA7DF,
	0xFFFD: 0xA7E0,
	0xFFFD: 0xA7E1,
	0xFFFD: 0xA7E2,
	0xFFFD: 0xA7E3,
	0xFFFD: 0xA7E4,
	0xFFFD: 0xA7E5,
	0xFFFD: 0xA7E6,
	0xFFFD: 0xA7E7,
	0xFFFD: 0xA7E8,
	0xFFFD: 0xA7E9,
	0xFFFD: 0xA7EA,
	0xFFFD: 0xA7EB,
	0xFFFD: 0xA7EC,
	0xFFFD: 0xA7ED,
	0xFFFD: 0xA7EE,
	0xFFFD: 0xA7EF,
	0xFFFD: 0xA7F0,
	0xFFFD: 0xA7F1,
	0xFFFD: 0xA7F2,
	0xFFFD: 0xA7F3,
	0xFFFD: 0xA7F4,
	0xFFFD: 0xA7F5,
	0xFFFD: 0xA7F6,
	0xFFFD: 0xA7F7,
	0xFFFD: 0xA7F8,
	0xFFFD: 0xA7F9,
	0xFFFD: 0xA7FA,
	0xFFFD: 0xA7FB,
	0xFFFD: 0xA7FC,
	0xFFFD: 0xA7FD,
	0xFFFD: 0xA7FE,
	0xFFFD: 0xA7FF,
	0xFFFD: 0xA800,
	0xFFFD: 0xA801,
	0xFFFD: 0xA802,
	0xFFFD: 0xA803,
	0xFFFD: 0xA804,
	0xFFFD: 0xA805,
	0xFFFD: 0xA806,
	0xFFFD: 0xA807,
	0xFFFD: 0xA808,
	0xFFFD: 0xA809,
	0xFFFD: 0xA80A,
	0xFFFD: 0xA80B,
	0xFFFD: 0xA80C,
	0xFFFD: 0xA80D,
	0xFFFD: 0xA80E,
	0xFFFD: 0xA80F,
	0xFFFD: 0xA810,
	0xFFFD: 0xA811,
	0xFFFD: 0xA812,
	0xFFFD: 0xA813,
	0xFFFD: 0xA814,
	0xFFFD: 0xA815,
	0xFFFD: 0xA816,
	0xFFFD: 0xA817,
	0xFFFD: 0xA818,
	0xFFFD: 0xA819,
	0xFFFD: 0xA81A,
	0xFFFD: 0xA81B,
	0xFFFD: 0xA81C,
	0xFFFD: 0xA81D,
	0xFFFD: 0xA81E,
	0xFFFD: 0xA81F,
	0xFFFD: 0xA820,
	0xFFFD: 0xA821,
	0xFFFD: 0xA822,
	0xFFFD: 0xA823,
	0xFFFD: 0xA824,
	0xFFFD: 0xA825,
	0xFFFD: 0xA826,
	0xFFFD: 0xA827,
	0xFFFD: 0xA828,
	0xFFFD: 0xA829,
	0xFFFD: 0xA82A,
	0xFFFD: 0xA82B,
	0xFFFD: 0xA82C,
	0xFFFD: 0xA82D,
	0xFFFD: 0xA82E,
	0xFFFD: 0xA82F,
	0xFFFD: 0xA830,
	0xFFFD: 0xA831,
	0xFFFD: 0xA832,
	0xFFFD: 0xA833,
	0xFFFD: 0xA834,
	0xFFFD: 0xA835,
	0xFFFD: 0xA836,
	0xFFFD: 0xA837,
	0xFFFD: 0xA838,
	0xFFFD: 0xA839,
	0xFFFD: 0xA83A,
	0xFFFD: 0xA83B,
	0xFFFD: 0xA83C,
	0xFFFD: 0xA83D,
	0xFFFD: 0xA83E,
	0xFFFD: 0xA83F,
	0xFFFD: 0xA840,
	0xFFFD: 0xA841,
	0xFFFD: 0xA842,
	0xFFFD: 0xA843,
	0xFFFD: 0xA844,
	0xFFFD: 0xA845,
	0xFFFD: 0xA846,
	0xFFFD: 0xA847,
	0xFFFD: 0xA848,
	0xFFFD: 0xA849,
	0xFFFD: 0xA84A,
	0xFFFD: 0xA84B,
	0xFFFD: 0xA84C,
	0xFFFD: 0xA84D,
	0xFFFD: 0xA84E,
	0xFFFD: 0xA84F,
	0xFFFD: 0xA850,
	0xFFFD: 0xA851,
	0xFFFD: 0xA852,
	0xFFFD: 0xA853,
	0xFFFD: 0xA854,
	0xFFFD: 0xA855,
	0xFFFD: 0xA856,
	0xFFFD: 0xA857,
	0xFFFD: 0xA858,
	0xFFFD: 0xA859,
	0xFFFD: 0xA85A,
	0xFFFD: 0xA85B,
	0xFFFD: 0xA85C,
	0xFFFD: 0xA85D,
	0xFFFD: 0xA85E,
	0xFFFD: 0xA85F,
	0xFFFD: 0xA860,
	0xFFFD: 0xA861,
	0xFFFD: 0xA862,
	0xFFFD: 0xA863,
	0xFFFD: 0xA864,
	0xFFFD: 0xA865,
	0xFFFD: 0xA866,
	0xFFFD: 0xA867,
	0xFFFD: 0xA868,
	0xFFFD: 0xA869,
	0xFFFD: 0xA86A,
	0xFFFD: 0xA86B,
	0xFFFD: 0xA86C,
	0xFFFD: 0xA86D,
	0xFFFD: 0xA86E,
	0xFFFD: 0xA86F,
	0xFFFD: 0xA870,
	0xFFFD: 0xA871,
	0xFFFD: 0xA872,
	0xFFFD: 0xA873,
	0xFFFD: 0xA874,
	0xFFFD: 0xA875,
	0xFFFD: 0xA876,
	0xFFFD: 0xA877,
	0xFFFD: 0xA878,
	0xFFFD: 0xA879,
	0xFFFD: 0xA87A,
	0xFFFD: 0xA87B,
	0xFFFD: 0xA87C,
	0xFFFD: 0xA87D,
	0xFFFD: 0xA87E,
	0xFFFD: 0xA87F,
	0xFFFD: 0xA880,
	0xFFFD: 0xA881,
	0xFFFD: 0xA882,
	0xFFFD: 0xA883,
	0xFFFD: 0xA884,
	0xFFFD: 0xA885,
	0xFFFD: 0xA886,
	0xFFFD: 0xA887,
	0xFFFD: 0xA888,
	0xFFFD: 0xA889,
	0xFFFD: 0xA88A,
	0xFFFD: 0xA88B,
	0xFFFD: 0xA88C,
	0xFFFD: 0xA88D,
	0xFFFD: 0xA88E,
	0xFFFD: 0xA88F,
	0xFFFD: 0xA890,
	0xFFFD: 0xA891,
	0xFFFD: 0xA892,
	0xFFFD: 0xA893,
	0xFFFD: 0xA894,
	0xFFFD: 0xA895,
	0xFFFD: 0xA896,
	0xFFFD: 0xA897,
	0xFFFD: 0xA898,
	0xFFFD: 0xA899,
	0xFFFD: 0xA89A,
	0xFFFD: 0xA89B,
	0xFFFD: 0xA89C,
	0xFFFD: 0xA89D,
	0xFFFD: 0xA89E,
	0xFFFD: 0xA89F,
	0xFFFD: 0xA8A0,
	0xFFFD: 0xA8A1,
	0xFFFD: 0xA8A2,
	0xFFFD: 0xA8A3,
	0xFFFD: 0xA8A4,
	0xFFFD: 0xA8A5,
	0xFFFD: 0xA8A6,
	0xFFFD: 0xA8A7,
	0xFFFD: 0xA8A8,
	0xFFFD: 0xA8A9,
	0xFFFD: 0xA8AA,
	0xFFFD: 0xA8AB,
	0xFFFD: 0xA8AC,
	0xFFFD: 0xA8AD,
	0xFFFD: 0xA8AE,
	0xFFFD: 0xA8AF,
	0xFFFD: 0xA8B0,
	0xFFFD: 0xA8B1,
	0xFFFD: 0xA8B2,
	0xFFFD: 0xA8B3,
	0xFFFD: 0xA8B4,
	0xFFFD: 0xA8B5,
	0xFFFD: 0xA8B6,
	0xFFFD: 0xA8B7,
	0xFFFD: 0xA8B8,
	0xFFFD: 0xA8B9,
	0xFFFD: 0xA8BA,
	0xFFFD: 0xA8BB,
	0xFFFD: 0xA8BC,
	0xFFFD: 0xA8BD,
	0xFFFD: 0xA8BE,
	0xFFFD: 0xA8BF,
	0xFFFD: 0xA8C0,
	0xFFFD: 0xA8C1,
	0xFFFD: 0xA8C2,
	0xFFFD: 0xA8C3,
	0xFFFD: 0xA8C4,
	0xFFFD: 0xA8C5,
	0xFFFD: 0xA8C6,
	0xFFFD: 0xA8C7,
	0xFFFD: 0xA8C8,
	0xFFFD: 0xA8C9,
	0xFFFD: 0xA8CA,
	0xFFFD: 0xA8CB,
	0xFFFD: 0xA8CC,
	0xFFFD: 0xA8CD,
	0xFFFD: 0xA8CE,
	0xFFFD: 0xA8CF,
	0xFFFD: 0xA8D0,
	0xFFFD: 0xA8D1,
	0xFFFD: 0xA8D2,
	0xFFFD: 0xA8D3,
	0xFFFD: 0xA8D4,
	0xFFFD: 0xA8D5,
	0xFFFD: 0xA8D6,
	0xFFFD: 0xA8D7,
	0xFFFD: 0xA8D8,
	0xFFFD: 0xA8D9,
	0xFFFD: 0xA8DA,
	0xFFFD: 0xA8DB,
	0xFFFD: 0xA8DC,
	0xFFFD: 0xA8DD,
	0xFFFD: 0xA8DE,
	0xFFFD: 0xA8DF,
	0xFFFD: 0xA8E0,
	0xFFFD: 0xA8E1,
	0xFFFD: 0xA8E2,
	0xFFFD: 0xA8E3,
	0xFFFD: 0xA8E4,
	0xFFFD: 0xA8E5,
	0xFFFD: 0xA8E6,
	0xFFFD: 0xA8E7,
	0xFFFD: 0xA8E8,
	0xFFFD: 0xA8E9,
	0xFFFD: 0xA8EA,
	0xFFFD: 0xA8EB,
	0xFFFD: 0xA8EC,
	0xFFFD: 0xA8ED,
	0xFFFD: 0xA8EE,
	0xFFFD: 0xA8EF,
	0xFFFD: 0xA8F0,
	0xFFFD: 0xA8F1,
	0xFFFD: 0xA8F2,
	0xFFFD: 0xA8F3,
	0xFFFD: 0xA8F4,
	0xFFFD: 0xA8F5,
	0xFFFD: 0xA8F6,
	0xFFFD: 0xA8F7,
	0xFFFD: 0xA8F8,
	0xFFFD: 0xA8F9,
	0xFFFD: 0xA8FA,
	0xFFFD: 0xA8FB,
	0xFFFD: 0xA8FC,
	0xFFFD: 0xA8FD,
	0xFFFD: 0xA8FE,
	0xFFFD: 0xA8FF,
	0xFFFD: 0xA900,
	0xFFFD: 0xA901,
	0xFFFD: 0xA902,
	0xFFFD: 0xA903,
	0xFFFD: 0xA904,
	0xFFFD: 0xA905,
	0xFFFD: 0xA906,
	0xFFFD: 0xA907,
	0xFFFD: 0xA908,
	0xFFFD: 0xA909,
	0xFFFD: 0xA90A,
	0xFFFD: 0xA90B,
	0xFFFD: 0xA90C,
	0xFFFD: 0xA90D,
	0xFFFD: 0xA90E,
	0xFFFD: 0xA90F,
	0xFFFD: 0xA910,
	0xFFFD: 0xA911,
	0xFFFD: 0xA912,
	0xFFFD: 0xA913,
	0xFFFD: 0xA914,
	0xFFFD: 0xA915,
	0xFFFD: 0xA916,
	0xFFFD: 0xA917,
	0xFFFD: 0xA918,
	0xFFFD: 0xA919,
	0xFFFD: 0xA91A,
	0xFFFD: 0xA91B,
	0xFFFD: 0xA91C,
	0xFFFD: 0xA91D,
	0xFFFD: 0xA91E,
	0xFFFD: 0xA91F,
	0xFFFD: 0xA920,
	0xFFFD: 0xA921,
	0xFFFD: 0xA922,
	0xFFFD: 0xA923,
	0xFFFD: 0xA924,
	0xFFFD: 0xA925,
	0xFFFD: 0xA926,
	0xFFFD: 0xA927,
	0xFFFD: 0xA928,
	0xFFFD: 0xA929,
	0xFFFD: 0xA92A,
	0xFFFD: 0xA92B,
	0xFFFD: 0xA92C,
	0xFFFD: 0xA92D,
	0xFFFD: 0xA92E,
	0xFFFD: 0xA92F,
	0xFFFD: 0xA930,
	0xFFFD: 0xA931,
	0xFFFD: 0xA932,
	0xFFFD: 0xA933,
	0xFFFD: 0xA934,
	0xFFFD: 0xA935,
	0xFFFD: 0xA936,
	0xFFFD: 0xA937,
	0xFFFD: 0xA938,
	0xFFFD: 0xA939,
	0xFFFD: 0xA93A,
	0xFFFD: 0xA93B,
	0xFFFD: 0xA93C,
	0xFFFD: 0xA93D,
	0xFFFD: 0xA93E,
	0xFFFD: 0xA93F,
	0xFFFD: 0xA940,
	0xFFFD: 0xA941,
	0xFFFD: 0xA942,
	0xFFFD: 0xA943,
	0xFFFD: 0xA944,
	0xFFFD: 0xA945,
	0xFFFD: 0xA946,
	0xFFFD: 0xA947,
	0xFFFD: 0xA948,
	0xFFFD: 0xA949,
	0xFFFD: 0xA94A,
	0xFFFD: 0xA94B,
	0xFFFD: 0xA94C,
	0xFFFD: 0xA94D,
	0xFFFD: 0xA94E,
	0xFFFD: 0xA94F,
	0xFFFD: 0xA950,
	0xFFFD: 0xA951,
	0xFFFD: 0xA952,
	0xFFFD: 0xA953,
	0xFFFD: 0xA954,
	0xFFFD: 0xA955,
	0xFFFD: 0xA956,
	0xFFFD: 0xA957,
	0xFFFD: 0xA958,
	0xFFFD: 0xA959,
	0xFFFD: 0xA95A,
	0xFFFD: 0xA95B,
	0xFFFD: 0xA95C,
	0xFFFD: 0xA95D,
	0xFFFD: 0xA95E,
	0xFFFD: 0xA95F,
	0xFFFD: 0xA960,
	0xFFFD: 0xA961,
	0xFFFD: 0xA962,
	0xFFFD: 0xA963,
	0xFFFD: 0xA964,
	0xFFFD: 0xA965,
	0xFFFD: 0xA966,
	0xFFFD: 0xA967,
	0xFFFD: 0xA968,
	0xFFFD: 0xA969,
	0xFFFD: 0xA96A,
	0xFFFD: 0xA96B,
	0xFFFD: 0xA96C,
	0xFFFD: 0xA96D,
	0xFFFD: 0xA96E,
	0xFFFD: 0xA96F,
	0xFFFD: 0xA970,
	0xFFFD: 0xA971,
	0xFFFD: 0xA972,
	0xFFFD: 0xA973,
	0xFFFD: 0xA974,
	0xFFFD: 0xA975,
	0xFFFD: 0xA976,
	0xFFFD: 0xA977,
	0xFFFD: 0xA978,
	0xFFFD: 0xA979,
	0xFFFD: 0xA97A,
	0xFFFD: 0xA97B,
	0xFFFD: 0xA97C,
	0xFFFD: 0xA97D,
	0xFFFD: 0xA97E,
	0xFFFD: 0xA97F,
	0xFFFD: 0xA980,
	0xFFFD: 0xA981,
	0xFFFD: 0xA982,
	0xFFFD: 0xA983,
	0xFFFD: 0xA984,
	0xFFFD: 0xA985,
	0xFFFD: 0xA986,
	0xFFFD: 0xA987,
	0xFFFD: 0xA988,
	0xFFFD: 0xA989,
	0xFFFD: 0xA98A,
	0xFFFD: 0xA98B,
	0xFFFD: 0xA98C,
	0xFFFD: 0xA98D,
	0xFFFD: 0xA98E,
	0xFFFD: 0xA98F,
	0xFFFD: 0xA990,
	0xFFFD: 0xA991,
	0xFFFD: 0xA992,
	0xFFFD: 0xA993,
	0xFFFD: 0xA994,
	0xFFFD: 0xA995,
	0xFFFD: 0xA996,
	0xFFFD: 0xA997,
	0xFFFD: 0xA998,
	0xFFFD: 0xA999,
	0xFFFD: 0xA99A,
	0xFFFD: 0xA99B,
	0xFFFD: 0xA99C,
	0xFFFD: 0xA99D,
	0xFFFD: 0xA99E,
	0xFFFD: 0xA99F,
	0xFFFD: 0xA9A0,
	0xFFFD: 0xA9A1,
	0xFFFD: 0xA9A2,
	0xFFFD: 0xA9A3,
	0xFFFD: 0xA9A4,
	0xFFFD: 0xA9A5,
	0xFFFD: 0xA9A6,
	0xFFFD: 0xA9A7,
	0xFFFD: 0xA9A8,
	0xFFFD: 0xA9A9,
	0xFFFD: 0xA9AA,
	0xFFFD: 0xA9AB,
	0xFFFD: 0xA9AC,
	0xFFFD: 0xA9AD,
	0xFFFD: 0xA9AE,
	0xFFFD: 0xA9AF,
	0xFFFD: 0xA9B0,
	0xFFFD: 0xA9B1,
	0xFFFD: 0xA9B2,
	0xFFFD: 0xA9B3,
	0xFFFD: 0xA9B4,
	0xFFFD: 0xA9B5,
	0xFFFD: 0xA9B6,
	0xFFFD: 0xA9B7,
	0xFFFD: 0xA9B8,
	0xFFFD: 0xA9B9,
	0xFFFD: 0xA9BA,
	0xFFFD: 0xA9BB,
	0xFFFD: 0xA9BC,
	0xFFFD: 0xA9BD,
	0xFFFD: 0xA9BE,
	0xFFFD: 0xA9BF,
	0xFFFD: 0xA9C0,
	0xFFFD: 0xA9C1,
	0xFFFD: 0xA9C2,
	0xFFFD: 0xA9C3,
	0xFFFD: 0xA9C4,
	0xFFFD: 0xA9C5,
	0xFFFD: 0xA9C6,
	0xFFFD: 0xA9C7,
	0xFFFD: 0xA9C8,
	0xFFFD: 0xA9C9,
	0xFFFD: 0xA9CA,
	0xFFFD: 0xA9CB,
	0xFFFD: 0xA9CC,
	0xFFFD: 0xA9CD,
	0xFFFD: 0xA9CE,
	0xFFFD: 0xA9CF,
	0xFFFD: 0xA9D0,
	0xFFFD: 0xA9D1,
	0xFFFD: 0xA9D2,
	0xFFFD: 0xA9D3,
	0xFFFD: 0xA9D4,
	0xFFFD: 0xA9D5,
	0xFFFD: 0xA9D6,
	0xFFFD: 0xA9D7,
	0xFFFD: 0xA9D8,
	0xFFFD: 0xA9D9,
	0xFFFD: 0xA9DA,
	0xFFFD: 0xA9DB,
	0xFFFD: 0xA9DC,
	0xFFFD: 0xA9DD,
	0xFFFD: 0xA9DE,
	0xFFFD: 0xA9DF,
	0xFFFD: 0xA9E0,
	0xFFFD: 0xA9E1,
	0xFFFD: 0xA9E2,
	0xFFFD: 0xA9E3,
	0xFFFD: 0xA9E4,
	0xFFFD: 0xA9E5,
	0xFFFD: 0xA9E6,
	0xFFFD: 0xA9E7,
	0xFFFD: 0xA9E8,
	0xFFFD: 0xA9E9,
	0xFFFD: 0xA9EA,
	0xFFFD: 0xA9EB,
	0xFFFD: 0xA9EC,
	0xFFFD: 0xA9ED,
	0xFFFD: 0xA9EE,
	0xFFFD: 0xA9EF,
	0xFFFD: 0xA9F0,
	0xFFFD: 0xA9F1,
	0xFFFD: 0xA9F2,
	0xFFFD: 0xA9F3,
	0xFFFD: 0xA9F4,
	0xFFFD: 0xA9F5,
	0xFFFD: 0xA9F6,
	0xFFFD: 0xA9F7,
	0xFFFD: 0xA9F8,
	0xFFFD: 0xA9F9,
	0xFFFD: 0xA9FA,
	0xFFFD: 0xA9FB,
	0xFFFD: 0xA9FC,
	0xFFFD: 0xA9FD,
	0xFFFD: 0xA9FE,
	0xFFFD: 0xA9FF,
	0xFFFD: 0xAA00,
	0xFFFD: 0xAA01,
	0xFFFD: 0xAA02,
	0xFFFD: 0xAA03,
	0xFFFD: 0xAA04,
	0xFFFD: 0xAA05,
	0xFFFD: 0xAA06,
	0xFFFD: 0xAA07,
	0xFFFD: 0xAA08,
	0xFFFD: 0xAA09,
	0xFFFD: 0xAA0A,
	0xFFFD: 0xAA0B,
	0xFFFD: 0xAA0C,
	0xFFFD: 0xAA0D,
	0xFFFD: 0xAA0E,
	0xFFFD: 0xAA0F,
	0xFFFD: 0xAA10,
	0xFFFD: 0xAA11,
	0xFFFD: 0xAA12,
	0xFFFD: 0xAA13,
	0xFFFD: 0xAA14,
	0xFFFD: 0xAA15,
	0xFFFD: 0xAA16,
	0xFFFD: 0xAA17,
	0xFFFD: 0xAA18,
	0xFFFD: 0xAA19,
	0xFFFD: 0xAA1A,
	0xFFFD: 0xAA1B,
	0xFFFD: 0xAA1C,
	0xFFFD: 0xAA1D,
	0xFFFD: 0xAA1E,
	0xFFFD: 0xAA1F,
	0xFFFD: 0xAA20,
	0xFFFD: 0xAA21,
	0xFFFD: 0xAA22,
	0xFFFD: 0xAA23,
	0xFFFD: 0xAA24,
	0xFFFD: 0xAA25,
	0xFFFD: 0xAA26,
	0xFFFD: 0xAA27,
	0xFFFD: 0xAA28,
	0xFFFD: 0xAA29,
	0xFFFD: 0xAA2A,
	0xFFFD: 0xAA2B,
	0xFFFD: 0xAA2C,
	0xFFFD: 0xAA2D,
	0xFFFD: 0xAA2E,
	0xFFFD: 0xAA2F,
	0xFFFD: 0xAA30,
	0xFFFD: 0xAA31,
	0xFFFD: 0xAA32,
	0xFFFD: 0xAA33,
	0xFFFD: 0xAA34,
	0xFFFD: 0xAA35,
	0xFFFD: 0xAA36,
	0xFFFD: 0xAA37,
	0xFFFD: 0xAA38,
	0xFFFD: 0xAA39,
	0xFFFD: 0xAA3A,
	0xFFFD: 0xAA3B,
	0xFFFD: 0xAA3C,
	0xFFFD: 0xAA3D,
	0xFFFD: 0xAA3E,
	0xFFFD: 0xAA3F,
	0xFFFD: 0xAA40,
	0xFFFD: 0xAA41,
	0xFFFD: 0xAA42,
	0xFFFD: 0xAA43,
	0xFFFD: 0xAA44,
	0xFFFD: 0xAA45,
	0xFFFD: 0xAA46,
	0xFFFD: 0xAA47,
	0xFFFD: 0xAA48,
	0xFFFD: 0xAA49,
	0xFFFD: 0xAA4A,
	0xFFFD: 0xAA4B,
	0xFFFD: 0xAA4C,
	0xFFFD: 0xAA4D,
	0xFFFD: 0xAA4E,
	0xFFFD: 0xAA4F,
	0xFFFD: 0xAA50,
	0xFFFD: 0xAA51,
	0xFFFD: 0xAA52,
	0xFFFD: 0xAA53,
	0xFFFD: 0xAA54,
	0xFFFD: 0xAA55,
	0xFFFD: 0xAA56,
	0xFFFD: 0xAA57,
	0xFFFD: 0xAA58,
	0xFFFD: 0xAA59,
	0xFFFD: 0xAA5A,
	0xFFFD: 0xAA5B,
	0xFFFD: 0xAA5C,
	0xFFFD: 0xAA5D,
	0xFFFD: 0xAA5E,
	0xFFFD: 0xAA5F,
	0xFFFD: 0xAA60,
	0xFFFD: 0xAA61,
	0xFFFD: 0xAA62,
	0xFFFD: 0xAA63,
	0xFFFD: 0xAA64,
	0xFFFD: 0xAA65,
	0xFFFD: 0xAA66,
	0xFFFD: 0xAA67,
	0xFFFD: 0xAA68,
	0xFFFD: 0xAA69,
	0xFFFD: 0xAA6A,
	0xFFFD: 0xAA6B,
	0xFFFD: 0xAA6C,
	0xFFFD: 0xAA6D,
	0xFFFD: 0xAA6E,
	0xFFFD: 0xAA6F,
	0xFFFD: 0xAA70,
	0xFFFD: 0xAA71,
	0xFFFD: 0xAA72,
	0xFFFD: 0xAA73,
	0xFFFD: 0xAA74,
	0xFFFD: 0xAA75,
	0xFFFD: 0xAA76,
	0xFFFD: 0xAA77,
	0xFFFD: 0xAA78,
	0xFFFD: 0xAA79,
	0xFFFD: 0xAA7A,
	0xFFFD: 0xAA7B,
	0xFFFD: 0xAA7C,
	0xFFFD: 0xAA7D,
	0xFFFD: 0xAA7E,
	0xFFFD: 0xAA7F,
	0xFFFD: 0xAA80,
	0xFFFD: 0xAA81,
	0xFFFD: 0xAA82,
	0xFFFD: 0xAA83,
	0xFFFD: 0xAA84,
	0xFFFD: 0xAA85,
	0xFFFD: 0xAA86,
	0xFFFD: 0xAA87,
	0xFFFD: 0xAA88,
	0xFFFD: 0xAA89,
	0xFFFD: 0xAA8A,
	0xFFFD: 0xAA8B,
	0xFFFD: 0xAA8C,
	0xFFFD: 0xAA8D,
	0xFFFD: 0xAA8E,
	0xFFFD: 0xAA8F,
	0xFFFD: 0xAA90,
	0xFFFD: 0xAA91,
	0xFFFD: 0xAA92,
	0xFFFD: 0xAA93,
	0xFFFD: 0xAA94,
	0xFFFD: 0xAA95,
	0xFFFD: 0xAA96,
	0xFFFD: 0xAA97,
	0xFFFD: 0xAA98,
	0xFFFD: 0xAA99,
	0xFFFD: 0xAA9A,
	0xFFFD: 0xAA9B,
	0xFFFD: 0xAA9C,
	0xFFFD: 0xAA9D,
	0xFFFD: 0xAA9E,
	0xFFFD: 0xAA9F,
	0xFFFD: 0xAAA0,
	0xFFFD: 0xAAA1,
	0xFFFD: 0xAAA2,
	0xFFFD: 0xAAA3,
	0xFFFD: 0xAAA4,
	0xFFFD: 0xAAA5,
	0xFFFD: 0xAAA6,
	0xFFFD: 0xAAA7,
	0xFFFD: 0xAAA8,
	0xFFFD: 0xAAA9,
	0xFFFD: 0xAAAA,
	0xFFFD: 0xAAAB,
	0xFFFD: 0xAAAC,
	0xFFFD: 0xAAAD,
	0xFFFD: 0xAAAE,
	0xFFFD: 0xAAAF,
	0xFFFD: 0xAAB0,
	0xFFFD: 0xAAB1,
	0xFFFD: 0xAAB2,
	0xFFFD: 0xAAB3,
	0xFFFD: 0xAAB4,
	0xFFFD: 0xAAB5,
	0xFFFD: 0xAAB6,
	0xFFFD: 0xAAB7,
	0xFFFD: 0xAAB8,
	0xFFFD: 0xAAB9,
	0xFFFD: 0xAABA,
	0xFFFD: 0xAABB,
	0xFFFD: 0xAABC,
	0xFFFD: 0xAABD,
	0xFFFD: 0xAABE,
	0xFFFD: 0xAABF,
	0xFFFD: 0xAAC0,
	0xFFFD: 0xAAC1,
	0xFFFD: 0xAAC2,
	0xFFFD: 0xAAC3,
	0xFFFD: 0xAAC4,
	0xFFFD: 0xAAC5,
	0xFFFD: 0xAAC6,
	0xFFFD: 0xAAC7,
	0xFFFD: 0xAAC8,
	0xFFFD: 0xAAC9,
	0xFFFD: 0xAACA,
	0xFFFD: 0xAACB,
	0xFFFD: 0xAACC,
	0xFFFD: 0xAACD,
	0xFFFD: 0xAACE,
	0xFFFD: 0xAACF,
	0xFFFD: 0xAAD0,
	0xFFFD: 0xAAD1,
	0xFFFD: 0xAAD2,
	0xFFFD: 0xAAD3,
	0xFFFD: 0xAAD4,
	0xFFFD: 0xAAD5,
	0xFFFD: 0xAAD6,
	0xFFFD: 0xAAD7,
	0xFFFD: 0xAAD8,
	0xFFFD: 0xAAD9,
	0xFFFD: 0xAADA,
	0xFFFD: 0xAADB,
	0xFFFD: 0xAADC,
	0xFFFD: 0xAADD,
	0xFFFD: 0xAADE,
	0xFFFD: 0xAADF,
	0xFFFD: 0xAAE0,
	0xFFFD: 0xAAE1,
	0xFFFD: 0xAAE2,
	0xFFFD: 0xAAE3,
	0xFFFD: 0xAAE4,
	0xFFFD: 0xAAE5,
	0xFFFD: 0xAAE6,
	0xFFFD: 0xAAE7,
	0xFFFD: 0xAAE8,
	0xFFFD: 0xAAE9,
	0xFFFD: 0xAAEA,
	0xFFFD: 0xAAEB,
	0xFFFD: 0xAAEC,
	0xFFFD: 0xAAED,
	0xFFFD: 0xAAEE,
	0xFFFD: 0xAAEF,
	0xFFFD: 0xAAF0,
	0xFFFD: 0xAAF1,
	0xFFFD: 0xAAF2,
	0xFFFD: 0xAAF3,
	0xFFFD: 0xAAF4,
	0xFFFD: 0xAAF5,
	0xFFFD: 0xAAF6,
	0xFFFD: 0xAAF7,
	0xFFFD: 0xAAF8,
	0xFFFD: 0xAAF9,
	0xFFFD: 0xAAFA,
	0xFFFD: 0xAAFB,
	0xFFFD: 0xAAFC,
	0xFFFD: 0xAAFD,
	0xFFFD: 0xAAFE,
	0xFFFD: 0xAAFF,
	0xFFFD: 0xAB00,
	0xFFFD: 0xAB01,
	0xFFFD: 0xAB02,
	0xFFFD: 0xAB03,
	0xFFFD: 0xAB04,
	0xFFFD: 0xAB05,
	0xFFFD: 0xAB06,
	0xFFFD: 0xAB07,
	0xFFFD: 0xAB08,
	0xFFFD: 0xAB09,
	0xFFFD: 0xAB0A,
	0xFFFD: 0xAB0B,
	0xFFFD: 0xAB0C,
	0xFFFD: 0xAB0D,
	0xFFFD: 0xAB0E,
	0xFFFD: 0xAB0F,
	0xFFFD: 0xAB10,
	0xFFFD: 0xAB11,
	0xFFFD: 0xAB12,
	0xFFFD: 0xAB13,
	0xFFFD: 0xAB14,
	0xFFFD: 0xAB15,
	0xFFFD: 0xAB16,
	0xFFFD: 0xAB17,
	0xFFFD: 0xAB18,
	0xFFFD: 0xAB19,
	0xFFFD: 0xAB1A,
	0xFFFD: 0xAB1B,
	0xFFFD: 0xAB1C,
	0xFFFD: 0xAB1D,
	0xFFFD: 0xAB1E,
	0xFFFD: 0xAB1F,
	0xFFFD: 0xAB20,
	0xFFFD: 0xAB21,
	0xFFFD: 0xAB22,
	0xFFFD: 0xAB23,
	0xFFFD: 0xAB24,
	0xFFFD: 0xAB25,
	0xFFFD: 0xAB26,
	0xFFFD: 0xAB27,
	0xFFFD: 0xAB28,
	0xFFFD: 0xAB29,
	0xFFFD: 0xAB2A,
	0xFFFD: 0xAB2B,
	0xFFFD: 0xAB2C,
	0xFFFD: 0xAB2D,
	0xFFFD: 0xAB2E,
	0xFFFD: 0xAB2F,
	0xFFFD: 0xAB30,
	0xFFFD: 0xAB31,
	0xFFFD: 0xAB32,
	0xFFFD: 0xAB33,
	0xFFFD: 0xAB34,
	0xFFFD: 0xAB35,
	0xFFFD: 0xAB36,
	0xFFFD: 0xAB37,
	0xFFFD: 0xAB38,
	0xFFFD: 0xAB39,
	0xFFFD: 0xAB3A,
	0xFFFD: 0xAB3B,
	0xFFFD: 0xAB3C,
	0xFFFD: 0xAB3D,
	0xFFFD: 0xAB3E,
	0xFFFD: 0xAB3F,
	0xFFFD: 0xAB40,
	0xFFFD: 0xAB41,
	0xFFFD: 0xAB42,
	0xFFFD: 0xAB43,
	0xFFFD: 0xAB44,
	0xFFFD: 0xAB45,
	0xFFFD: 0xAB46,
	0xFFFD: 0xAB47,
	0xFFFD: 0xAB48,
	0xFFFD: 0xAB49,
	0xFFFD: 0xAB4A,
	0xFFFD: 0xAB4B,
	0xFFFD: 0xAB4C,
	0xFFFD: 0xAB4D,
	0xFFFD: 0xAB4E,
	0xFFFD: 0xAB4F,
	0xFFFD: 0xAB50,
	0xFFFD: 0xAB51,
	0xFFFD: 0xAB52,
	0xFFFD: 0xAB53,
	0xFFFD: 0xAB54,
	0xFFFD: 0xAB55,
	0xFFFD: 0xAB56,
	0xFFFD: 0xAB57,
	0xFFFD: 0xAB58,
	0xFFFD: 0xAB59,
	0xFFFD: 0xAB5A,
	0xFFFD: 0xAB5B,
	0xFFFD: 0xAB5C,
	0xFFFD: 0xAB5D,
	0xFFFD: 0xAB5E,
	0xFFFD: 0xAB5F,
	0xFFFD: 0xAB60,
	0xFFFD: 0xAB61,
	0xFFFD: 0xAB62,
	0xFFFD: 0xAB63,
	0xFFFD: 0xAB64,
	0xFFFD: 0xAB65,
	0xFFFD: 0xAB66,
	0xFFFD: 0xAB67,
	0xFFFD: 0xAB68,
	0xFFFD: 0xAB69,
	0xFFFD: 0xAB6A,
	0xFFFD: 0xAB6B,
	0xFFFD: 0xAB6C,
	0xFFFD: 0xAB6D,
	0xFFFD: 0xAB6E,
	0xFFFD: 0xAB6F,
	0xFFFD: 0xAB70,
	0xFFFD: 0xAB71,
	0xFFFD: 0xAB72,
	0xFFFD: 0xAB73,
	0xFFFD: 0xAB74,
	0xFFFD: 0xAB75,
	0xFFFD: 0xAB76,
	0xFFFD: 0xAB77,
	0xFFFD: 0xAB78,
	0xFFFD: 0xAB79,
	0xFFFD: 0xAB7A,
	0xFFFD: 0xAB7B,
	0xFFFD: 0xAB7C,
	0xFFFD: 0xAB7D,
	0xFFFD: 0xAB7E,
	0xFFFD: 0xAB7F,
	0xFFFD: 0xAB80,
	0xFFFD: 0xAB81,
	0xFFFD: 0xAB82,
	0xFFFD: 0xAB83,
	0xFFFD: 0xAB84,
	0xFFFD: 0xAB85,
	0xFFFD: 0xAB86,
	0xFFFD: 0xAB87,
	0xFFFD: 0xAB88,
	0xFFFD: 0xAB89,
	0xFFFD: 0xAB8A,
	0xFFFD: 0xAB8B,
	0xFFFD: 0xAB8C,
	0xFFFD: 0xAB8D,
	0xFFFD: 0xAB8E,
	0xFFFD: 0xAB8F,
	0xFFFD: 0xAB90,
	0xFFFD: 0xAB91,
	0xFFFD: 0xAB92,
	0xFFFD: 0xAB93,
	0xFFFD: 0xAB94,
	0xFFFD: 0xAB95,
	0xFFFD: 0xAB96,
	0xFFFD: 0xAB97,
	0xFFFD: 0xAB98,
	0xFFFD: 0xAB99,
	0xFFFD: 0xAB9A,
	0xFFFD: 0xAB9B,
	0xFFFD: 0xAB9C,
	0xFFFD: 0xAB9D,
	0xFFFD: 0xAB9E,
	0xFFFD: 0xAB9F,
	0xFFFD: 0xABA0,
	0xFFFD: 0xABA1,
	0xFFFD: 0xABA2,
	0xFFFD: 0xABA3,
	0xFFFD: 0xABA4,
	0xFFFD: 0xABA5,
	0xFFFD: 0xABA6,
	0xFFFD: 0xABA7,
	0xFFFD: 0xABA8,
	0xFFFD: 0xABA9,
	0xFFFD: 0xABAA,
	0xFFFD: 0xABAB,
	0xFFFD: 0xABAC,
	0xFFFD: 0xABAD,
	0xFFFD: 0xABAE,
	0xFFFD: 0xABAF,
	0xFFFD: 0xABB0,
	0xFFFD: 0xABB1,
	0xFFFD: 0xABB2,
	0xFFFD: 0xABB3,
	0xFFFD: 0xABB4,
	0xFFFD: 0xABB5,
	0xFFFD: 0xABB6,
	0xFFFD: 0xABB7,
	0xFFFD: 0xABB8,
	0xFFFD: 0xABB9,
	0xFFFD: 0xABBA,
	0xFFFD: 0xABBB,
	0xFFFD: 0xABBC,
	0xFFFD: 0xABBD,
	0xFFFD: 0xABBE,
	0xFFFD: 0xABBF,
	0xFFFD: 0xABC0,
	0xFFFD: 0xABC1,
	0xFFFD: 0xABC2,
	0xFFFD: 0xABC3,
	0xFFFD: 0xABC4,
	0xFFFD: 0xABC5,
	0xFFFD: 0xABC6,
	0xFFFD: 0xABC7,
	0xFFFD: 0xABC8,
	0xFFFD: 0xABC9,
	0xFFFD: 0xABCA,
	0xFFFD: 0xABCB,
	0xFFFD: 0xABCC,
	0xFFFD: 0xABCD,
	0xFFFD: 0xABCE,
	0xFFFD: 0xABCF,
	0xFFFD: 0xABD0,
	0xFFFD: 0xABD1,
	0xFFFD: 0xABD2,
	0xFFFD: 0xABD3,
	0xFFFD: 0xABD4,
	0xFFFD: 0xABD5,
	0xFFFD: 0xABD6,
	0xFFFD: 0xABD7,
	0xFFFD: 0xABD8,
	0xFFFD: 0xABD9,
	0xFFFD: 0xABDA,
	0xFFFD: 0xABDB,
	0xFFFD: 0xABDC,
	0xFFFD: 0xABDD,
	0xFFFD: 0xABDE,
	0xFFFD: 0xABDF,
	0xFFFD: 0xABE0,
	0xFFFD: 0xABE1,
	0xFFFD: 0xABE2,
	0xFFFD: 0xABE3,
	0xFFFD: 0xABE4,
	0xFFFD: 0xABE5,
	0xFFFD: 0xABE6,
	0xFFFD: 0xABE7,
	0xFFFD: 0xABE8,
	0xFFFD: 0xABE9,
	0xFFFD: 0xABEA,
	0xFFFD: 0xABEB,
	0xFFFD: 0xABEC,
	0xFFFD: 0xABED,
	0xFFFD: 0xABEE,
	0xFFFD: 0xABEF,
	0xFFFD: 0xABF0,
	0xFFFD: 0xABF1,
	0xFFFD: 0xABF2,
	0xFFFD: 0xABF3,
	0xFFFD: 0xABF4,
	0xFFFD: 0xABF5,
	0xFFFD: 0xABF6,
	0xFFFD: 0xABF7,
	0xFFFD: 0xABF8,
	0xFFFD: 0xABF9,
	0xFFFD: 0xABFA,
	0xFFFD: 0xABFB,
	0xFFFD: 0xABFC,
	0xFFFD: 0xABFD,
	0xFFFD: 0xABFE,
	0xFFFD: 0xABFF,
	0xFFFD: 0xAC00,
	0xFFFD: 0xAC01,
	0xFFFD: 0xAC02,
	0xFFFD: 0xAC03,
	0xFFFD: 0xAC04,
	0xFFFD: 0xAC05,
	0xFFFD: 0xAC06,
	0xFFFD: 0xAC07,
	0xFFFD: 0xAC08,
	0xFFFD: 0xAC09,
	0xFFFD: 0xAC0A,
	0xFFFD: 0xAC0B,
	0xFFFD: 0xAC0C,
	0xFFFD: 0xAC0D,
	0xFFFD: 0xAC0E,
	0xFFFD: 0xAC0F,
	0xFFFD: 0xAC10,
	0xFFFD: 0xAC11,
	0xFFFD: 0xAC12,
	0xFFFD: 0xAC13,
	0xFFFD: 0xAC14,
	0xFFFD: 0xAC15,
	0xFFFD: 0xAC16,
	0xFFFD: 0xAC17,
	0xFFFD: 0xAC18,
	0xFFFD: 0xAC19,
	0xFFFD: 0xAC1A,
	0xFFFD: 0xAC1B,
	0xFFFD: 0xAC1C,
	0xFFFD: 0xAC1D,
	0xFFFD: 0xAC1E,
	0xFFFD: 0xAC1F,
	0xFFFD: 0xAC20,
	0xFFFD: 0xAC21,
	0xFFFD: 0xAC22,
	0xFFFD: 0xAC23,
	0xFFFD: 0xAC24,
	0xFFFD: 0xAC25,
	0xFFFD: 0xAC26,
	0xFFFD: 0xAC27,
	0xFFFD: 0xAC28,
	0xFFFD: 0xAC29,
	0xFFFD: 0xAC2A,
	0xFFFD: 0xAC2B,
	0xFFFD: 0xAC2C,
	0xFFFD: 0xAC2D,
	0xFFFD: 0xAC2E,
	0xFFFD: 0xAC2F,
	0xFFFD: 0xAC30,
	0xFFFD: 0xAC31,
	0xFFFD: 0xAC32,
	0xFFFD: 0xAC33,
	0xFFFD: 0xAC34,
	0xFFFD: 0xAC35,
	0xFFFD: 0xAC36,
	0xFFFD: 0xAC37,
	0xFFFD: 0xAC38,
	0xFFFD: 0xAC39,
	0xFFFD: 0xAC3A,
	0xFFFD: 0xAC3B,
	0xFFFD: 0xAC3C,
	0xFFFD: 0xAC3D,
	0xFFFD: 0xAC3E,
	0xFFFD: 0xAC3F,
	0xFFFD: 0xAC40,
	0xFFFD: 0xAC41,
	0xFFFD: 0xAC42,
	0xFFFD: 0xAC43,
	0xFFFD: 0xAC44,
	0xFFFD: 0xAC45,
	0xFFFD: 0xAC46,
	0xFFFD: 0xAC47,
	0xFFFD: 0xAC48,
	0xFFFD: 0xAC49,
	0xFFFD: 0xAC4A,
	0xFFFD: 0xAC4B,
	0xFFFD: 0xAC4C,
	0xFFFD: 0xAC4D,
	0xFFFD: 0xAC4E,
	0xFFFD: 0xAC4F,
	0xFFFD: 0xAC50,
	0xFFFD: 0xAC51,
	0xFFFD: 0xAC52,
	0xFFFD: 0xAC53,
	0xFFFD: 0xAC54,
	0xFFFD: 0xAC55,
	0xFFFD: 0xAC56,
	0xFFFD: 0xAC57,
	0xFFFD: 0xAC58,
	0xFFFD: 0xAC59,
	0xFFFD: 0xAC5A,
	0xFFFD: 0xAC5B,
	0xFFFD: 0xAC5C,
	0xFFFD: 0xAC5D,
	0xFFFD: 0xAC5E,
	0xFFFD: 0xAC5F,
	0xFFFD: 0xAC60,
	0xFFFD: 0xAC61,
	0xFFFD: 0xAC62,
	0xFFFD: 0xAC63,
	0xFFFD: 0xAC64,
	0xFFFD: 0xAC65,
	0xFFFD: 0xAC66,
	0xFFFD: 0xAC67,
	0xFFFD: 0xAC68,
	0xFFFD: 0xAC69,
	0xFFFD: 0xAC6A,
	0xFFFD: 0xAC6B,
	0xFFFD: 0xAC6C,
	0xFFFD: 0xAC6D,
	0xFFFD: 0xAC6E,
	0xFFFD: 0xAC6F,
	0xFFFD: 0xAC70,
	0xFFFD: 0xAC71,
	0xFFFD: 0xAC72,
	0xFFFD: 0xAC73,
	0xFFFD: 0xAC74,
	0xFFFD: 0xAC75,
	0xFFFD: 0xAC76,
	0xFFFD: 0xAC77,
	0xFFFD: 0xAC78,
	0xFFFD: 0xAC79,
	0xFFFD: 0xAC7A,
	0xFFFD: 0xAC7B,
	0xFFFD: 0xAC7C,
	0xFFFD: 0xAC7D,
	0xFFFD: 0xAC7E,
	0xFFFD: 0xAC7F,
	0xFFFD: 0xAC80,
	0xFFFD: 0xAC81,
	0xFFFD: 0xAC82,
	0xFFFD: 0xAC83,
	0xFFFD: 0xAC84,
	0xFFFD: 0xAC85,
	0xFFFD: 0xAC86,
	0xFFFD: 0xAC87,
	0xFFFD: 0xAC88,
	0xFFFD: 0xAC89,
	0xFFFD: 0xAC8A,
	0xFFFD: 0xAC8B,
	0xFFFD: 0xAC8C,
	0xFFFD: 0xAC8D,
	0xFFFD: 0xAC8E,
	0xFFFD: 0xAC8F,
	0xFFFD: 0xAC90,
	0xFFFD: 0xAC91,
	0xFFFD: 0xAC92,
	0xFFFD: 0xAC93,
	0xFFFD: 0xAC94,
	0xFFFD: 0xAC95,
	0xFFFD: 0xAC96,
	0xFFFD: 0xAC97,
	0xFFFD: 0xAC98,
	0xFFFD: 0xAC99,
	0xFFFD: 0xAC9A,
	0xFFFD: 0xAC9B,
	0xFFFD: 0xAC9C,
	0xFFFD: 0xAC9D,
	0xFFFD: 0xAC9E,
	0xFFFD: 0xAC9F,
	0xFFFD: 0xACA0,
	0xFFFD: 0xACA1,
	0xFFFD: 0xACA2,
	0xFFFD: 0xACA3,
	0xFFFD: 0xACA4,
	0xFFFD: 0xACA5,
	0xFFFD: 0xACA6,
	0xFFFD: 0xACA7,
	0xFFFD: 0xACA8,
	0xFFFD: 0xACA9,
	0xFFFD: 0xACAA,
	0xFFFD: 0xACAB,
	0xFFFD: 0xACAC,
	0xFFFD: 0xACAD,
	0xFFFD: 0xACAE,
	0xFFFD: 0xACAF,
	0xFFFD: 0xACB0,
	0xFFFD: 0xACB1,
	0xFFFD: 0xACB2,
	0xFFFD: 0xACB3,
	0xFFFD: 0xACB4,
	0xFFFD: 0xACB5,
	0xFFFD: 0xACB6,
	0xFFFD: 0xACB7,
	0xFFFD: 0xACB8,
	0xFFFD: 0xACB9,
	0xFFFD: 0xACBA,
	0xFFFD: 0xACBB,
	0xFFFD: 0xACBC,
	0xFFFD: 0xACBD,
	0xFFFD: 0xACBE,
	0xFFFD: 0xACBF,
	0xFFFD: 0xACC0,
	0xFFFD: 0xACC1,
	0xFFFD: 0xACC2,
	0xFFFD: 0xACC3,
	0xFFFD: 0xACC4,
	0xFFFD: 0xACC5,
	0xFFFD: 0xACC6,
	0xFFFD: 0xACC7,
	0xFFFD: 0xACC8,
	0xFFFD: 0xACC9,
	0xFFFD: 0xACCA,
	0xFFFD: 0xACCB,
	0xFFFD: 0xACCC,
	0xFFFD: 0xACCD,
	0xFFFD: 0xACCE,
	0xFFFD: 0xACCF,
	0xFFFD: 0xACD0,
	0xFFFD: 0xACD1,
	0xFFFD: 0xACD2,
	0xFFFD: 0xACD3,
	0xFFFD: 0xACD4,
	0xFFFD: 0xACD5,
	0xFFFD: 0xACD6,
	0xFFFD: 0xACD7,
	0xFFFD: 0xACD8,
	0xFFFD: 0xACD9,
	0xFFFD: 0xACDA,
	0xFFFD: 0xACDB,
	0xFFFD: 0xACDC,
	0xFFFD: 0xACDD,
	0xFFFD: 0xACDE,
	0xFFFD: 0xACDF,
	0xFFFD: 0xACE0,
	0xFFFD: 0xACE1,
	0xFFFD: 0xACE2,
	0xFFFD: 0xACE3,
	0xFFFD: 0xACE4,
	0xFFFD: 0xACE5,
	0xFFFD: 0xACE6,
	0xFFFD: 0xACE7,
	0xFFFD: 0xACE8,
	0xFFFD: 0xACE9,
	0xFFFD: 0xACEA,
	0xFFFD: 0xACEB,
	0xFFFD: 0xACEC,
	0xFFFD: 0xACED,
	0xFFFD: 0xACEE,
	0xFFFD: 0xACEF,
	0xFFFD: 0xACF0,
	0xFFFD: 0xACF1,
	0xFFFD: 0xACF2,
	0xFFFD: 0xACF3,
	0xFFFD: 0xACF4,
	0xFFFD: 0xACF5,
	0xFFFD: 0xACF6,
	0xFFFD: 0xACF7,
	0xFFFD: 0xACF8,
	0xFFFD: 0xACF9,
	0xFFFD: 0xACFA,
	0xFFFD: 0xACFB,
	0xFFFD: 0xACFC,
	0xFFFD: 0xACFD,
	0xFFFD: 0xACFE,
	0xFFFD: 0xACFF,
	0xFFFD: 0xAD00,
	0xFFFD: 0xAD01,
	0xFFFD: 0xAD02,
	0xFFFD: 0xAD03,
	0xFFFD: 0xAD04,
	0xFFFD: 0xAD05,
	0xFFFD: 0xAD06,
	0xFFFD: 0xAD07,
	0xFFFD: 0xAD08,
	0xFFFD: 0xAD09,
	0xFFFD: 0xAD0A,
	0xFFFD: 0xAD0B,
	0xFFFD: 0xAD0C,
	0xFFFD: 0xAD0D,
	0xFFFD: 0xAD0E,
	0xFFFD: 0xAD0F,
	0xFFFD: 0xAD10,
	0xFFFD: 0xAD11,
	0xFFFD: 0xAD12,
	0xFFFD: 0xAD13,
	0xFFFD: 0xAD14,
	0xFFFD: 0xAD15,
	0xFFFD: 0xAD16,
	0xFFFD: 0xAD17,
	0xFFFD: 0xAD18,
	0xFFFD: 0xAD19,
	0xFFFD: 0xAD1A,
	0xFFFD: 0xAD1B,
	0xFFFD: 0xAD1C,
	0xFFFD: 0xAD1D,
	0xFFFD: 0xAD1E,
	0xFFFD: 0xAD1F,
	0xFFFD: 0xAD20,
	0xFFFD: 0xAD21,
	0xFFFD: 0xAD22,
	0xFFFD: 0xAD23,
	0xFFFD: 0xAD24,
	0xFFFD: 0xAD25,
	0xFFFD: 0xAD26,
	0xFFFD: 0xAD27,
	0xFFFD: 0xAD28,
	0xFFFD: 0xAD29,
	0xFFFD: 0xAD2A,
	0xFFFD: 0xAD2B,
	0xFFFD: 0xAD2C,
	0xFFFD: 0xAD2D,
	0xFFFD: 0xAD2E,
	0xFFFD: 0xAD2F,
	0xFFFD: 0xAD30,
	0xFFFD: 0xAD31,
	0xFFFD: 0xAD32,
	0xFFFD: 0xAD33,
	0xFFFD: 0xAD34,
	0xFFFD: 0xAD35,
	0xFFFD: 0xAD36,
	0xFFFD: 0xAD37,
	0xFFFD: 0xAD38,
	0xFFFD: 0xAD39,
	0xFFFD: 0xAD3A,
	0xFFFD: 0xAD3B,
	0xFFFD: 0xAD3C,
	0xFFFD: 0xAD3D,
	0xFFFD: 0xAD3E,
	0xFFFD: 0xAD3F,
	0xFFFD: 0xAD40,
	0xFFFD: 0xAD41,
	0xFFFD: 0xAD42,
	0xFFFD: 0xAD43,
	0xFFFD: 0xAD44,
	0xFFFD: 0xAD45,
	0xFFFD: 0xAD46,
	0xFFFD: 0xAD47,
	0xFFFD: 0xAD48,
	0xFFFD: 0xAD49,
	0xFFFD: 0xAD4A,
	0xFFFD: 0xAD4B,
	0xFFFD: 0xAD4C,
	0xFFFD: 0xAD4D,
	0xFFFD: 0xAD4E,
	0xFFFD: 0xAD4F,
	0xFFFD: 0xAD50,
	0xFFFD: 0xAD51,
	0xFFFD: 0xAD52,
	0xFFFD: 0xAD53,
	0xFFFD: 0xAD54,
	0xFFFD: 0xAD55,
	0xFFFD: 0xAD56,
	0xFFFD: 0xAD57,
	0xFFFD: 0xAD58,
	0xFFFD: 0xAD59,
	0xFFFD: 0xAD5A,
	0xFFFD: 0xAD5B,
	0xFFFD: 0xAD5C,
	0xFFFD: 0xAD5D,
	0xFFFD: 0xAD5E,
	0xFFFD: 0xAD5F,
	0xFFFD: 0xAD60,
	0xFFFD: 0xAD61,
	0xFFFD: 0xAD62,
	0xFFFD: 0xAD63,
	0xFFFD: 0xAD64,
	0xFFFD: 0xAD65,
	0xFFFD: 0xAD66,
	0xFFFD: 0xAD67,
	0xFFFD: 0xAD68,
	0xFFFD: 0xAD69,
	0xFFFD: 0xAD6A,
	0xFFFD: 0xAD6B,
	0xFFFD: 0xAD6C,
	0xFFFD: 0xAD6D,
	0xFFFD: 0xAD6E,
	0xFFFD: 0xAD6F,
	0xFFFD: 0xAD70,
	0xFFFD: 0xAD71,
	0xFFFD: 0xAD72,
	0xFFFD: 0xAD73,
	0xFFFD: 0xAD74,
	0xFFFD: 0xAD75,
	0xFFFD: 0xAD76,
	0xFFFD: 0xAD77,
	0xFFFD: 0xAD78,
	0xFFFD: 0xAD79,
	0xFFFD: 0xAD7A,
	0xFFFD: 0xAD7B,
	0xFFFD: 0xAD7C,
	0xFFFD: 0xAD7D,
	0xFFFD: 0xAD7E,
	0xFFFD: 0xAD7F,
	0xFFFD: 0xAD80,
	0xFFFD: 0xAD81,
	0xFFFD: 0xAD82,
	0xFFFD: 0xAD83,
	0xFFFD: 0xAD84,
	0xFFFD: 0xAD85,
	0xFFFD: 0xAD86,
	0xFFFD: 0xAD87,
	0xFFFD: 0xAD88,
	0xFFFD: 0xAD89,
	0xFFFD: 0xAD8A,
	0xFFFD: 0xAD8B,
	0xFFFD: 0xAD8C,
	0xFFFD: 0xAD8D,
	0xFFFD: 0xAD8E,
	0xFFFD: 0xAD8F,
	0xFFFD: 0xAD90,
	0xFFFD: 0xAD91,
	0xFFFD: 0xAD92,
	0xFFFD: 0xAD93,
	0xFFFD: 0xAD94,
	0xFFFD: 0xAD95,
	0xFFFD: 0xAD96,
	0xFFFD: 0xAD97,
	0xFFFD: 0xAD98,
	0xFFFD: 0xAD99,
	0xFFFD: 0xAD9A,
	0xFFFD: 0xAD9B,
	0xFFFD: 0xAD9C,
	0xFFFD: 0xAD9D,
	0xFFFD: 0xAD9E,
	0xFFFD: 0xAD9F,
	0xFFFD: 0xADA0,
	0xFFFD: 0xADA1,
	0xFFFD: 0xADA2,
	0xFFFD: 0xADA3,
	0xFFFD: 0xADA4,
	0xFFFD: 0xADA5,
	0xFFFD: 0xADA6,
	0xFFFD: 0xADA7,
	0xFFFD: 0xADA8,
	0xFFFD: 0xADA9,
	0xFFFD: 0xADAA,
	0xFFFD: 0xADAB,
	0xFFFD: 0xADAC,
	0xFFFD: 0xADAD,
	0xFFFD: 0xADAE,
	0xFFFD: 0xADAF,
	0xFFFD: 0xADB0,
	0xFFFD: 0xADB1,
	0xFFFD: 0xADB2,
	0xFFFD: 0xADB3,
	0xFFFD: 0xADB4,
	0xFFFD: 0xADB5,
	0xFFFD: 0xADB6,
	0xFFFD: 0xADB7,
	0xFFFD: 0xADB8,
	0xFFFD: 0xADB9,
	0xFFFD: 0xADBA,
	0xFFFD: 0xADBB,
	0xFFFD: 0xADBC,
	0xFFFD: 0xADBD,
	0xFFFD: 0xADBE,
	0xFFFD: 0xADBF,
	0xFFFD: 0xADC0,
	0xFFFD: 0xADC1,
	0xFFFD: 0xADC2,
	0xFFFD: 0xADC3,
	0xFFFD: 0xADC4,
	0xFFFD: 0xADC5,
	0xFFFD: 0xADC6,
	0xFFFD: 0xADC7,
	0xFFFD: 0xADC8,
	0xFFFD: 0xADC9,
	0xFFFD: 0xADCA,
	0xFFFD: 0xADCB,
	0xFFFD: 0xADCC,
	0xFFFD: 0xADCD,
	0xFFFD: 0xADCE,
	0xFFFD: 0xADCF,
	0xFFFD: 0xADD0,
	0xFFFD: 0xADD1,
	0xFFFD: 0xADD2,
	0xFFFD: 0xADD3,
	0xFFFD: 0xADD4,
	0xFFFD: 0xADD5,
	0xFFFD: 0xADD6,
	0xFFFD: 0xADD7,
	0xFFFD: 0xADD8,
	0xFFFD: 0xADD9,
	0xFFFD: 0xADDA,
	0xFFFD: 0xADDB,
	0xFFFD: 0xADDC,
	0xFFFD: 0xADDD,
	0xFFFD: 0xADDE,
	0xFFFD: 0xADDF,
	0xFFFD: 0xADE0,
	0xFFFD: 0xADE1,
	0xFFFD: 0xADE2,
	0xFFFD: 0xADE3,
	0xFFFD: 0xADE4,
	0xFFFD: 0xADE5,
	0xFFFD: 0xADE6,
	0xFFFD: 0xADE7,
	0xFFFD: 0xADE8,
	0xFFFD: 0xADE9,
	0xFFFD: 0xADEA,
	0xFFFD: 0xADEB,
	0xFFFD: 0xADEC,
	0xFFFD: 0xADED,
	0xFFFD: 0xADEE,
	0xFFFD: 0xADEF,
	0xFFFD: 0xADF0,
	0xFFFD: 0xADF1,
	0xFFFD: 0xADF2,
	0xFFFD: 0xADF3,
	0xFFFD: 0xADF4,
	0xFFFD: 0xADF5,
	0xFFFD: 0xADF6,
	0xFFFD: 0xADF7,
	0xFFFD: 0xADF8,
	0xFFFD: 0xADF9,
	0xFFFD: 0xADFA,
	0xFFFD: 0xADFB,
	0xFFFD: 0xADFC,
	0xFFFD: 0xADFD,
	0xFFFD: 0xADFE,
	0xFFFD: 0xADFF,
	0xFFFD: 0xAE00,
	0xFFFD: 0xAE01,
	0xFFFD: 0xAE02,
	0xFFFD: 0xAE03,
	0xFFFD: 0xAE04,
	0xFFFD: 0xAE05,
	0xFFFD: 0xAE06,
	0xFFFD: 0xAE07,
	0xFFFD: 0xAE08,
	0xFFFD: 0xAE09,
	0xFFFD: 0xAE0A,
	0xFFFD: 0xAE0B,
	0xFFFD: 0xAE0C,
	0xFFFD: 0xAE0D,
	0xFFFD: 0xAE0E,
	0xFFFD: 0xAE0F,
	0xFFFD: 0xAE10,
	0xFFFD: 0xAE11,
	0xFFFD: 0xAE12,
	0xFFFD: 0xAE13,
	0xFFFD: 0xAE14,
	0xFFFD: 0xAE15,
	0xFFFD: 0xAE16,
	0xFFFD: 0xAE17,
	0xFFFD: 0xAE18,
	0xFFFD: 0xAE19,
	0xFFFD: 0xAE1A,
	0xFFFD: 0xAE1B,
	0xFFFD: 0xAE1C,
	0xFFFD: 0xAE1D,
	0xFFFD: 0xAE1E,
	0xFFFD: 0xAE1F,
	0xFFFD: 0xAE20,
	0xFFFD: 0xAE21,
	0xFFFD: 0xAE22,
	0xFFFD: 0xAE23,
	0xFFFD: 0xAE24,
	0xFFFD: 0xAE25,
	0xFFFD: 0xAE26,
	0xFFFD: 0xAE27,
	0xFFFD: 0xAE28,
	0xFFFD: 0xAE29,
	0xFFFD: 0xAE2A,
	0xFFFD: 0xAE2B,
	0xFFFD: 0xAE2C,
	0xFFFD: 0xAE2D,
	0xFFFD: 0xAE2E,
	0xFFFD: 0xAE2F,
	0xFFFD: 0xAE30,
	0xFFFD: 0xAE31,
	0xFFFD: 0xAE32,
	0xFFFD: 0xAE33,
	0xFFFD: 0xAE34,
	0xFFFD: 0xAE35,
	0xFFFD: 0xAE36,
	0xFFFD: 0xAE37,
	0xFFFD: 0xAE38,
	0xFFFD: 0xAE39,
	0xFFFD: 0xAE3A,
	0xFFFD: 0xAE3B,
	0xFFFD: 0xAE3C,
	0xFFFD: 0xAE3D,
	0xFFFD: 0xAE3E,
	0xFFFD: 0xAE3F,
	0xFFFD: 0xAE40,
	0xFFFD: 0xAE41,
	0xFFFD: 0xAE42,
	0xFFFD: 0xAE43,
	0xFFFD: 0xAE44,
	0xFFFD: 0xAE45,
	0xFFFD: 0xAE46,
	0xFFFD: 0xAE47,
	0xFFFD: 0xAE48,
	0xFFFD: 0xAE49,
	0xFFFD: 0xAE4A,
	0xFFFD: 0xAE4B,
	0xFFFD: 0xAE4C,
	0xFFFD: 0xAE4D,
	0xFFFD: 0xAE4E,
	0xFFFD: 0xAE4F,
	0xFFFD: 0xAE50,
	0xFFFD: 0xAE51,
	0xFFFD: 0xAE52,
	0xFFFD: 0xAE53,
	0xFFFD: 0xAE54,
	0xFFFD: 0xAE55,
	0xFFFD: 0xAE56,
	0xFFFD: 0xAE57,
	0xFFFD: 0xAE58,
	0xFFFD: 0xAE59,
	0xFFFD: 0xAE5A,
	0xFFFD: 0xAE5B,
	0xFFFD: 0xAE5C,
	0xFFFD: 0xAE5D,
	0xFFFD: 0xAE5E,
	0xFFFD: 0xAE5F,
	0xFFFD: 0xAE60,
	0xFFFD: 0xAE61,
	0xFFFD: 0xAE62,
	0xFFFD: 0xAE63,
	0xFFFD: 0xAE64,
	0xFFFD: 0xAE65,
	0xFFFD: 0xAE66,
	0xFFFD: 0xAE67,
	0xFFFD: 0xAE68,
	0xFFFD: 0xAE69,
	0xFFFD: 0xAE6A,
	0xFFFD: 0xAE6B,
	0xFFFD: 0xAE6C,
	0xFFFD: 0xAE6D,
	0xFFFD: 0xAE6E,
	0xFFFD: 0xAE6F,
	0xFFFD: 0xAE70,
	0xFFFD: 0xAE71,
	0xFFFD: 0xAE72,
	0xFFFD: 0xAE73,
	0xFFFD: 0xAE74,
	0xFFFD: 0xAE75,
	0xFFFD: 0xAE76,
	0xFFFD: 0xAE77,
	0xFFFD: 0xAE78,
	0xFFFD: 0xAE79,
	0xFFFD: 0xAE7A,
	0xFFFD: 0xAE7B,
	0xFFFD: 0xAE7C,
	0xFFFD: 0xAE7D,
	0xFFFD: 0xAE7E,
	0xFFFD: 0xAE7F,
	0xFFFD: 0xAE80,
	0xFFFD: 0xAE81,
	0xFFFD: 0xAE82,
	0xFFFD: 0xAE83,
	0xFFFD: 0xAE84,
	0xFFFD: 0xAE85,
	0xFFFD: 0xAE86,
	0xFFFD: 0xAE87,
	0xFFFD: 0xAE88,
	0xFFFD: 0xAE89,
	0xFFFD: 0xAE8A,
	0xFFFD: 0xAE8B,
	0xFFFD: 0xAE8C,
	0xFFFD: 0xAE8D,
	0xFFFD: 0xAE8E,
	0xFFFD: 0xAE8F,
	0xFFFD: 0xAE90,
	0xFFFD: 0xAE91,
	0xFFFD: 0xAE92,
	0xFFFD: 0xAE93,
	0xFFFD: 0xAE94,
	0xFFFD: 0xAE95,
	0xFFFD: 0xAE96,
	0xFFFD: 0xAE97,
	0xFFFD: 0xAE98,
	0xFFFD: 0xAE99,
	0xFFFD: 0xAE9A,
	0xFFFD: 0xAE9B,
	0xFFFD: 0xAE9C,
	0xFFFD: 0xAE9D,
	0xFFFD: 0xAE9E,
	0xFFFD: 0xAE9F,
	0xFFFD: 0xAEA0,
	0xFFFD: 0xAEA1,
	0xFFFD: 0xAEA2,
	0xFFFD: 0xAEA3,
	0xFFFD: 0xAEA4,
	0xFFFD: 0xAEA5,
	0xFFFD: 0xAEA6,
	0xFFFD: 0xAEA7,
	0xFFFD: 0xAEA8,
	0xFFFD: 0xAEA9,
	0xFFFD: 0xAEAA,
	0xFFFD: 0xAEAB,
	0xFFFD: 0xAEAC,
	0xFFFD: 0xAEAD,
	0xFFFD: 0xAEAE,
	0xFFFD: 0xAEAF,
	0xFFFD: 0xAEB0,
	0xFFFD: 0xAEB1,
	0xFFFD: 0xAEB2,
	0xFFFD: 0xAEB3,
	0xFFFD: 0xAEB4,
	0xFFFD: 0xAEB5,
	0xFFFD: 0xAEB6,
	0xFFFD: 0xAEB7,
	0xFFFD: 0xAEB8,
	0xFFFD: 0xAEB9,
	0xFFFD: 0xAEBA,
	0xFFFD: 0xAEBB,
	0xFFFD: 0xAEBC,
	0xFFFD: 0xAEBD,
	0xFFFD: 0xAEBE,
	0xFFFD: 0xAEBF,
	0xFFFD: 0xAEC0,
	0xFFFD: 0xAEC1,
	0xFFFD: 0xAEC2,
	0xFFFD: 0xAEC3,
	0xFFFD: 0xAEC4,
	0xFFFD: 0xAEC5,
	0xFFFD: 0xAEC6,
	0xFFFD: 0xAEC7,
	0xFFFD: 0xAEC8,
	0xFFFD: 0xAEC9,
	0xFFFD: 0xAECA,
	0xFFFD: 0xAECB,
	0xFFFD: 0xAECC,
	0xFFFD: 0xAECD,
	0xFFFD: 0xAECE,
	0xFFFD: 0xAECF,
	0xFFFD: 0xAED0,
	0xFFFD: 0xAED1,
	0xFFFD: 0xAED2,
	0xFFFD: 0xAED3,
	0xFFFD: 0xAED4,
	0xFFFD: 0xAED5,
	0xFFFD: 0xAED6,
	0xFFFD: 0xAED7,
	0xFFFD: 0xAED8,
	0xFFFD: 0xAED9,
	0xFFFD: 0xAEDA,
	0xFFFD: 0xAEDB,
	0xFFFD: 0xAEDC,
	0xFFFD: 0xAEDD,
	0xFFFD: 0xAEDE,
	0xFFFD: 0xAEDF,
	0xFFFD: 0xAEE0,
	0xFFFD: 0xAEE1,
	0xFFFD: 0xAEE2,
	0xFFFD: 0xAEE3,
	0xFFFD: 0xAEE4,
	0xFFFD: 0xAEE5,
	0xFFFD: 0xAEE6,
	0xFFFD: 0xAEE7,
	0xFFFD: 0xAEE8,
	0xFFFD: 0xAEE9,
	0xFFFD: 0xAEEA,
	0xFFFD: 0xAEEB,
	0xFFFD: 0xAEEC,
	0xFFFD: 0xAEED,
	0xFFFD: 0xAEEE,
	0xFFFD: 0xAEEF,
	0xFFFD: 0xAEF0,
	0xFFFD: 0xAEF1,
	0xFFFD: 0xAEF2,
	0xFFFD: 0xAEF3,
	0xFFFD: 0xAEF4,
	0xFFFD: 0xAEF5,
	0xFFFD: 0xAEF6,
	0xFFFD: 0xAEF7,
	0xFFFD: 0xAEF8,
	0xFFFD: 0xAEF9,
	0xFFFD: 0xAEFA,
	0xFFFD: 0xAEFB,
	0xFFFD: 0xAEFC,
	0xFFFD: 0xAEFD,
	0xFFFD: 0xAEFE,
	0xFFFD: 0xAEFF,
	0xFFFD: 0xAF00,
	0xFFFD: 0xAF01,
	0xFFFD: 0xAF02,
	0xFFFD: 0xAF03,
	0xFFFD: 0xAF04,
	0xFFFD: 0xAF05,
	0xFFFD: 0xAF06,
	0xFFFD: 0xAF07,
	0xFFFD: 0xAF08,
	0xFFFD: 0xAF09,
	0xFFFD: 0xAF0A,
	0xFFFD: 0xAF0B,
	0xFFFD: 0xAF0C,
	0xFFFD: 0xAF0D,
	0xFFFD: 0xAF0E,
	0xFFFD: 0xAF0F,
	0xFFFD: 0xAF10,
	0xFFFD: 0xAF11,
	0xFFFD: 0xAF12,
	0xFFFD: 0xAF13,
	0xFFFD: 0xAF14,
	0xFFFD: 0xAF15,
	0xFFFD: 0xAF16,
	0xFFFD: 0xAF17,
	0xFFFD: 0xAF18,
	0xFFFD: 0xAF19,
	0xFFFD: 0xAF1A,
	0xFFFD: 0xAF1B,
	0xFFFD: 0xAF1C,
	0xFFFD: 0xAF1D,
	0xFFFD: 0xAF1E,
	0xFFFD: 0xAF1F,
	0xFFFD: 0xAF20,
	0xFFFD: 0xAF21,
	0xFFFD: 0xAF22,
	0xFFFD: 0xAF23,
	0xFFFD: 0xAF24,
	0xFFFD: 0xAF25,
	0xFFFD: 0xAF26,
	0xFFFD: 0xAF27,
	0xFFFD: 0xAF28,
	0xFFFD: 0xAF29,
	0xFFFD: 0xAF2A,
	0xFFFD: 0xAF2B,
	0xFFFD: 0xAF2C,
	0xFFFD: 0xAF2D,
	0xFFFD: 0xAF2E,
	0xFFFD: 0xAF2F,
	0xFFFD: 0xAF30,
	0xFFFD: 0xAF31,
	0xFFFD: 0xAF32,
	0xFFFD: 0xAF33,
	0xFFFD: 0xAF34,
	0xFFFD: 0xAF35,
	0xFFFD: 0xAF36,
	0xFFFD: 0xAF37,
	0xFFFD: 0xAF38,
	0xFFFD: 0xAF39,
	0xFFFD: 0xAF3A,
	0xFFFD: 0xAF3B,
	0xFFFD: 0xAF3C,
	0xFFFD: 0xAF3D,
	0xFFFD: 0xAF3E,
	0xFFFD: 0xAF3F,
	0xFFFD: 0xAF40,
	0xFFFD: 0xAF41,
	0xFFFD: 0xAF42,
	0xFFFD: 0xAF43,
	0xFFFD: 0xAF44,
	0xFFFD: 0xAF45,
	0xFFFD: 0xAF46,
	0xFFFD: 0xAF47,
	0xFFFD: 0xAF48,
	0xFFFD: 0xAF49,
	0xFFFD: 0xAF4A,
	0xFFFD: 0xAF4B,
	0xFFFD: 0xAF4C,
	0xFFFD: 0xAF4D,
	0xFFFD: 0xAF4E,
	0xFFFD: 0xAF4F,
	0xFFFD: 0xAF50,
	0xFFFD: 0xAF51,
	0xFFFD: 0xAF52,
	0xFFFD: 0xAF53,
	0xFFFD: 0xAF54,
	0xFFFD: 0xAF55,
	0xFFFD: 0xAF56,
	0xFFFD: 0xAF57,
	0xFFFD: 0xAF58,
	0xFFFD: 0xAF59,
	0xFFFD: 0xAF5A,
	0xFFFD: 0xAF5B,
	0xFFFD: 0xAF5C,
	0xFFFD: 0xAF5D,
	0xFFFD: 0xAF5E,
	0xFFFD: 0xAF5F,
	0xFFFD: 0xAF60,
	0xFFFD: 0xAF61,
	0xFFFD: 0xAF62,
	0xFFFD: 0xAF63,
	0xFFFD: 0xAF64,
	0xFFFD: 0xAF65,
	0xFFFD: 0xAF66,
	0xFFFD: 0xAF67,
	0xFFFD: 0xAF68,
	0xFFFD: 0xAF69,
	0xFFFD: 0xAF6A,
	0xFFFD: 0xAF6B,
	0xFFFD: 0xAF6C,
	0xFFFD: 0xAF6D,
	0xFFFD: 0xAF6E,
	0xFFFD: 0xAF6F,
	0xFFFD: 0xAF70,
	0xFFFD: 0xAF71,
	0xFFFD: 0xAF72,
	0xFFFD: 0xAF73,
	0xFFFD: 0xAF74,
	0xFFFD: 0xAF75,
	0xFFFD: 0xAF76,
	0xFFFD: 0xAF77,
	0xFFFD: 0xAF78,
	0xFFFD: 0xAF79,
	0xFFFD: 0xAF7A,
	0xFFFD: 0xAF7B,
	0xFFFD: 0xAF7C,
	0xFFFD: 0xAF7D,
	0xFFFD: 0xAF7E,
	0xFFFD: 0xAF7F,
	0xFFFD: 0xAF80,
	0xFFFD: 0xAF81,
	0xFFFD: 0xAF82,
	0xFFFD: 0xAF83,
	0xFFFD: 0xAF84,
	0xFFFD: 0xAF85,
	0xFFFD: 0xAF86,
	0xFFFD: 0xAF87,
	0xFFFD: 0xAF88,
	0xFFFD: 0xAF89,
	0xFFFD: 0xAF8A,
	0xFFFD: 0xAF8B,
	0xFFFD: 0xAF8C,
	0xFFFD: 0xAF8D,
	0xFFFD: 0xAF8E,
	0xFFFD: 0xAF8F,
	0xFFFD: 0xAF90,
	0xFFFD: 0xAF91,
	0xFFFD: 0xAF92,
	0xFFFD: 0xAF93,
	0xFFFD: 0xAF94,
	0xFFFD: 0xAF95,
	0xFFFD: 0xAF96,
	0xFFFD: 0xAF97,
	0xFFFD: 0xAF98,
	0xFFFD: 0xAF99,
	0xFFFD: 0xAF9A,
	0xFFFD: 0xAF9B,
	0xFFFD: 0xAF9C,
	0xFFFD: 0xAF9D,
	0xFFFD: 0xAF9E,
	0xFFFD: 0xAF9F,
	0xFFFD: 0xAFA0,
	0xFFFD: 0xAFA1,
	0xFFFD: 0xAFA2,
	0xFFFD: 0xAFA3,
	0xFFFD: 0xAFA4,
	0xFFFD: 0xAFA5,
	0xFFFD: 0xAFA6,
	0xFFFD: 0xAFA7,
	0xFFFD: 0xAFA8,
	0xFFFD: 0xAFA9,
	0xFFFD: 0xAFAA,
	0xFFFD: 0xAFAB,
	0xFFFD: 0xAFAC,
	0xFFFD: 0xAFAD,
	0xFFFD: 0xAFAE,
	0xFFFD: 0xAFAF,
	0xFFFD: 0xAFB0,
	0xFFFD: 0xAFB1,
	0xFFFD: 0xAFB2,
	0xFFFD: 0xAFB3,
	0xFFFD: 0xAFB4,
	0xFFFD: 0xAFB5,
	0xFFFD: 0xAFB6,
	0xFFFD: 0xAFB7,
	0xFFFD: 0xAFB8,
	0xFFFD: 0xAFB9,
	0xFFFD: 0xAFBA,
	0xFFFD: 0xAFBB,
	0xFFFD: 0xAFBC,
	0xFFFD: 0xAFBD,
	0xFFFD: 0xAFBE,
	0xFFFD: 0xAFBF,
	0xFFFD: 0xAFC0,
	0xFFFD: 0xAFC1,
	0xFFFD: 0xAFC2,
	0xFFFD: 0xAFC3,
	0xFFFD: 0xAFC4,
	0xFFFD: 0xAFC5,
	0xFFFD: 0xAFC6,
	0xFFFD: 0xAFC7,
	0xFFFD: 0xAFC8,
	0xFFFD: 0xAFC9,
	0xFFFD: 0xAFCA,
	0xFFFD: 0xAFCB,
	0xFFFD: 0xAFCC,
	0xFFFD: 0xAFCD,
	0xFFFD: 0xAFCE,
	0xFFFD: 0xAFCF,
	0xFFFD: 0xAFD0,
	0xFFFD: 0xAFD1,
	0xFFFD: 0xAFD2,
	0xFFFD: 0xAFD3,
	0xFFFD: 0xAFD4,
	0xFFFD: 0xAFD5,
	0xFFFD: 0xAFD6,
	0xFFFD: 0xAFD7,
	0xFFFD: 0xAFD8,
	0xFFFD: 0xAFD9,
	0xFFFD: 0xAFDA,
	0xFFFD: 0xAFDB,
	0xFFFD: 0xAFDC,
	0xFFFD: 0xAFDD,
	0xFFFD: 0xAFDE,
	0xFFFD: 0xAFDF,
	0xFFFD: 0xAFE0,
	0xFFFD: 0xAFE1,
	0xFFFD: 0xAFE2,
	0xFFFD: 0xAFE3,
	0xFFFD: 0xAFE4,
	0xFFFD: 0xAFE5,
	0xFFFD: 0xAFE6,
	0xFFFD: 0xAFE7,
	0xFFFD: 0xAFE8,
	0xFFFD: 0xAFE9,
	0xFFFD: 0xAFEA,
	0xFFFD: 0xAFEB,
	0xFFFD: 0xAFEC,
	0xFFFD: 0xAFED,
	0xFFFD: 0xAFEE,
	0xFFFD: 0xAFEF,
	0xFFFD: 0xAFF0,
	0xFFFD: 0xAFF1,
	0xFFFD: 0xAFF2,
	0xFFFD: 0xAFF3,
	0xFFFD: 0xAFF4,
	0xFFFD: 0xAFF5,
	0xFFFD: 0xAFF6,
	0xFFFD: 0xAFF7,
	0xFFFD: 0xAFF8,
	0xFFFD: 0xAFF9,
	0xFFFD: 0xAFFA,
	0xFFFD: 0xAFFB,
	0xFFFD: 0xAFFC,
	0xFFFD: 0xAFFD,
	0xFFFD: 0xAFFE,
	0xFFFD: 0xAFFF,
	0xFFFD: 0xB000,
	0xFFFD: 0xB001,
	0xFFFD: 0xB002,
	0xFFFD: 0xB003,
	0xFFFD: 0xB004,
	0xFFFD: 0xB005,
	0xFFFD: 0xB006,
	0xFFFD: 0xB007,
	0xFFFD: 0xB008,
	0xFFFD: 0xB009,
	0xFFFD: 0xB00A,
	0xFFFD: 0xB00B,
	0xFFFD: 0xB00C,
	0xFFFD: 0xB00D,
	0xFFFD: 0xB00E,
	0xFFFD: 0xB00F,
	0xFFFD: 0xB010,
	0xFFFD: 0xB011,
	0xFFFD: 0xB012,
	0xFFFD: 0xB013,
	0xFFFD: 0xB014,
	0xFFFD: 0xB015,
	0xFFFD: 0xB016,
	0xFFFD: 0xB017,
	0xFFFD: 0xB018,
	0xFFFD: 0xB019,
	0xFFFD: 0xB01A,
	0xFFFD: 0xB01B,
	0xFFFD: 0xB01C,
	0xFFFD: 0xB01D,
	0xFFFD: 0xB01E,
	0xFFFD: 0xB01F,
	0xFFFD: 0xB020,
	0xFFFD: 0xB021,
	0xFFFD: 0xB022,
	0xFFFD: 0xB023,
	0xFFFD: 0xB024,
	0xFFFD: 0xB025,
	0xFFFD: 0xB026,
	0xFFFD: 0xB027,
	0xFFFD: 0xB028,
	0xFFFD: 0xB029,
	0xFFFD: 0xB02A,
	0xFFFD: 0xB02B,
	0xFFFD: 0xB02C,
	0xFFFD: 0xB02D,
	0xFFFD: 0xB02E,
	0xFFFD: 0xB02F,
	0xFFFD: 0xB030,
	0xFFFD: 0xB031,
	0xFFFD: 0xB032,
	0xFFFD: 0xB033,
	0xFFFD: 0xB034,
	0xFFFD: 0xB035,
	0xFFFD: 0xB036,
	0xFFFD: 0xB037,
	0xFFFD: 0xB038,
	0xFFFD: 0xB039,
	0xFFFD: 0xB03A,
	0xFFFD: 0xB03B,
	0xFFFD: 0xB03C,
	0xFFFD: 0xB03D,
	0xFFFD: 0xB03E,
	0xFFFD: 0xB03F,
	0xFFFD: 0xB040,
	0xFFFD: 0xB041,
	0xFFFD: 0xB042,
	0xFFFD: 0xB043,
	0xFFFD: 0xB044,
	0xFFFD: 0xB045,
	0xFFFD: 0xB046,
	0xFFFD: 0xB047,
	0xFFFD: 0xB048,
	0xFFFD: 0xB049,
	0xFFFD: 0xB04A,
	0xFFFD: 0xB04B,
	0xFFFD: 0xB04C,
	0xFFFD: 0xB04D,
	0xFFFD: 0xB04E,
	0xFFFD: 0xB04F,
	0xFFFD: 0xB050,
	0xFFFD: 0xB051,
	0xFFFD: 0xB052,
	0xFFFD: 0xB053,
	0xFFFD: 0xB054,
	0xFFFD: 0xB055,
	0xFFFD: 0xB056,
	0xFFFD: 0xB057,
	0xFFFD: 0xB058,
	0xFFFD: 0xB059,
	0xFFFD: 0xB05A,
	0xFFFD: 0xB05B,
	0xFFFD: 0xB05C,
	0xFFFD: 0xB05D,
	0xFFFD: 0xB05E,
	0xFFFD: 0xB05F,
	0xFFFD: 0xB060,
	0xFFFD: 0xB061,
	0xFFFD: 0xB062,
	0xFFFD: 0xB063,
	0xFFFD: 0xB064,
	0xFFFD: 0xB065,
	0xFFFD: 0xB066,
	0xFFFD: 0xB067,
	0xFFFD: 0xB068,
	0xFFFD: 0xB069,
	0xFFFD: 0xB06A,
	0xFFFD: 0xB06B,
	0xFFFD: 0xB06C,
	0xFFFD: 0xB06D,
	0xFFFD: 0xB06E,
	0xFFFD: 0xB06F,
	0xFFFD: 0xB070,
	0xFFFD: 0xB071,
	0xFFFD: 0xB072,
	0xFFFD: 0xB073,
	0xFFFD: 0xB074,
	0xFFFD: 0xB075,
	0xFFFD: 0xB076,
	0xFFFD: 0xB077,
	0xFFFD: 0xB078,
	0xFFFD: 0xB079,
	0xFFFD: 0xB07A,
	0xFFFD: 0xB07B,
	0xFFFD: 0xB07C,
	0xFFFD: 0xB07D,
	0xFFFD: 0xB07E,
	0xFFFD: 0xB07F,
	0xFFFD: 0xB080,
	0xFFFD: 0xB081,
	0xFFFD: 0xB082,
	0xFFFD: 0xB083,
	0xFFFD: 0xB084,
	0xFFFD: 0xB085,
	0xFFFD: 0xB086,
	0xFFFD: 0xB087,
	0xFFFD: 0xB088,
	0xFFFD: 0xB089,
	0xFFFD: 0xB08A,
	0xFFFD: 0xB08B,
	0xFFFD: 0xB08C,
	0xFFFD: 0xB08D,
	0xFFFD: 0xB08E,
	0xFFFD: 0xB08F,
	0xFFFD: 0xB090,
	0xFFFD: 0xB091,
	0xFFFD: 0xB092,
	0xFFFD: 0xB093,
	0xFFFD: 0xB094,
	0xFFFD: 0xB095,
	0xFFFD: 0xB096,
	0xFFFD: 0xB097,
	0xFFFD: 0xB098,
	0xFFFD: 0xB099,
	0xFFFD: 0xB09A,
	0xFFFD: 0xB09B,
	0xFFFD: 0xB09C,
	0xFFFD: 0xB09D,
	0xFFFD: 0xB09E,
	0xFFFD: 0xB09F,
	0xFFFD: 0xB0A0,
	0xFFFD: 0xB0A1,
	0xFFFD: 0xB0A2,
	0xFFFD: 0xB0A3,
	0xFFFD: 0xB0A4,
	0xFFFD: 0xB0A5,
	0xFFFD: 0xB0A6,
	0xFFFD: 0xB0A7,
	0xFFFD: 0xB0A8,
	0xFFFD: 0xB0A9,
	0xFFFD: 0xB0AA,
	0xFFFD: 0xB0AB,
	0xFFFD: 0xB0AC,
	0xFFFD: 0xB0AD,
	0xFFFD: 0xB0AE,
	0xFFFD: 0xB0AF,
	0xFFFD: 0xB0B0,
	0xFFFD: 0xB0B1,
	0xFFFD: 0xB0B2,
	0xFFFD: 0xB0B3,
	0xFFFD: 0xB0B4,
	0xFFFD: 0xB0B5,
	0xFFFD: 0xB0B6,
	0xFFFD: 0xB0B7,
	0xFFFD: 0xB0B8,
	0xFFFD: 0xB0B9,
	0xFFFD: 0xB0BA,
	0xFFFD: 0xB0BB,
	0xFFFD: 0xB0BC,
	0xFFFD: 0xB0BD,
	0xFFFD: 0xB0BE,
	0xFFFD: 0xB0BF,
	0xFFFD: 0xB0C0,
	0xFFFD: 0xB0C1,
	0xFFFD: 0xB0C2,
	0xFFFD: 0xB0C3,
	0xFFFD: 0xB0C4,
	0xFFFD: 0xB0C5,
	0xFFFD: 0xB0C6,
	0xFFFD: 0xB0C7,
	0xFFFD: 0xB0C8,
	0xFFFD: 0xB0C9,
	0xFFFD: 0xB0CA,
	0xFFFD: 0xB0CB,
	0xFFFD: 0xB0CC,
	0xFFFD: 0xB0CD,
	0xFFFD: 0xB0CE,
	0xFFFD: 0xB0CF,
	0xFFFD: 0xB0D0,
	0xFFFD: 0xB0D1,
	0xFFFD: 0xB0D2,
	0xFFFD: 0xB0D3,
	0xFFFD: 0xB0D4,
	0xFFFD: 0xB0D5,
	0xFFFD: 0xB0D6,
	0xFFFD: 0xB0D7,
	0xFFFD: 0xB0D8,
	0xFFFD: 0xB0D9,
	0xFFFD: 0xB0DA,
	0xFFFD: 0xB0DB,
	0xFFFD: 0xB0DC,
	0xFFFD: 0xB0DD,
	0xFFFD: 0xB0DE,
	0xFFFD: 0xB0DF,
	0xFFFD: 0xB0E0,
	0xFFFD: 0xB0E1,
	0xFFFD: 0xB0E2,
	0xFFFD: 0xB0E3,
	0xFFFD: 0xB0E4,
	0xFFFD: 0xB0E5,
	0xFFFD: 0xB0E6,
	0xFFFD: 0xB0E7,
	0xFFFD: 0xB0E8,
	0xFFFD: 0xB0E9,
	0xFFFD: 0xB0EA,
	0xFFFD: 0xB0EB,
	0xFFFD: 0xB0EC,
	0xFFFD: 0xB0ED,
	0xFFFD: 0xB0EE,
	0xFFFD: 0xB0EF,
	0xFFFD: 0xB0F0,
	0xFFFD: 0xB0F1,
	0xFFFD: 0xB0F2,
	0xFFFD: 0xB0F3,
	0xFFFD: 0xB0F4,
	0xFFFD: 0xB0F5,
	0xFFFD: 0xB0F6,
	0xFFFD: 0xB0F7,
	0xFFFD: 0xB0F8,
	0xFFFD: 0xB0F9,
	0xFFFD: 0xB0FA,
	0xFFFD: 0xB0FB,
	0xFFFD: 0xB0FC,
	0xFFFD: 0xB0FD,
	0xFFFD: 0xB0FE,
	0xFFFD: 0xB0FF,
	0xFFFD: 0xB100,
	0xFFFD: 0xB101,
	0xFFFD: 0xB102,
	0xFFFD: 0xB103,
	0xFFFD: 0xB104,
	0xFFFD: 0xB105,
	0xFFFD: 0xB106,
	0xFFFD: 0xB107,
	0xFFFD: 0xB108,
	0xFFFD: 0xB109,
	0xFFFD: 0xB10A,
	0xFFFD: 0xB10B,
	0xFFFD: 0xB10C,
	0xFFFD: 0xB10D,
	0xFFFD: 0xB10E,
	0xFFFD: 0xB10F,
	0xFFFD: 0xB110,
	0xFFFD: 0xB111,
	0xFFFD: 0xB112,
	0xFFFD: 0xB113,
	0xFFFD: 0xB114,
	0xFFFD: 0xB115,
	0xFFFD: 0xB116,
	0xFFFD: 0xB117,
	0xFFFD: 0xB118,
	0xFFFD: 0xB119,
	0xFFFD: 0xB11A,
	0xFFFD: 0xB11B,
	0xFFFD: 0xB11C,
	0xFFFD: 0xB11D,
	0xFFFD: 0xB11E,
	0xFFFD: 0xB11F,
	0xFFFD: 0xB120,
	0xFFFD: 0xB121,
	0xFFFD: 0xB122,
	0xFFFD: 0xB123,
	0xFFFD: 0xB124,
	0xFFFD: 0xB125,
	0xFFFD: 0xB126,
	0xFFFD: 0xB127,
	0xFFFD: 0xB128,
	0xFFFD: 0xB129,
	0xFFFD: 0xB12A,
	0xFFFD: 0xB12B,
	0xFFFD: 0xB12C,
	0xFFFD: 0xB12D,
	0xFFFD: 0xB12E,
	0xFFFD: 0xB12F,
	0xFFFD: 0xB130,
	0xFFFD: 0xB131,
	0xFFFD: 0xB132,
	0xFFFD: 0xB133,
	0xFFFD: 0xB134,
	0xFFFD: 0xB135,
	0xFFFD: 0xB136,
	0xFFFD: 0xB137,
	0xFFFD: 0xB138,
	0xFFFD: 0xB139,
	0xFFFD: 0xB13A,
	0xFFFD: 0xB13B,
	0xFFFD: 0xB13C,
	0xFFFD: 0xB13D,
	0xFFFD: 0xB13E,
	0xFFFD: 0xB13F,
	0xFFFD: 0xB140,
	0xFFFD: 0xB141,
	0xFFFD: 0xB142,
	0xFFFD: 0xB143,
	0xFFFD: 0xB144,
	0xFFFD: 0xB145,
	0xFFFD: 0xB146,
	0xFFFD: 0xB147,
	0xFFFD: 0xB148,
	0xFFFD: 0xB149,
	0xFFFD: 0xB14A,
	0xFFFD: 0xB14B,
	0xFFFD: 0xB14C,
	0xFFFD: 0xB14D,
	0xFFFD: 0xB14E,
	0xFFFD: 0xB14F,
	0xFFFD: 0xB150,
	0xFFFD: 0xB151,
	0xFFFD: 0xB152,
	0xFFFD: 0xB153,
	0xFFFD: 0xB154,
	0xFFFD: 0xB155,
	0xFFFD: 0xB156,
	0xFFFD: 0xB157,
	0xFFFD: 0xB158,
	0xFFFD: 0xB159,
	0xFFFD: 0xB15A,
	0xFFFD: 0xB15B,
	0xFFFD: 0xB15C,
	0xFFFD: 0xB15D,
	0xFFFD: 0xB15E,
	0xFFFD: 0xB15F,
	0xFFFD: 0xB160,
	0xFFFD: 0xB161,
	0xFFFD: 0xB162,
	0xFFFD: 0xB163,
	0xFFFD: 0xB164,
	0xFFFD: 0xB165,
	0xFFFD: 0xB166,
	0xFFFD: 0xB167,
	0xFFFD: 0xB168,
	0xFFFD: 0xB169,
	0xFFFD: 0xB16A,
	0xFFFD: 0xB16B,
	0xFFFD: 0xB16C,
	0xFFFD: 0xB16D,
	0xFFFD: 0xB16E,
	0xFFFD: 0xB16F,
	0xFFFD: 0xB170,
	0xFFFD: 0xB171,
	0xFFFD: 0xB172,
	0xFFFD: 0xB173,
	0xFFFD: 0xB174,
	0xFFFD: 0xB175,
	0xFFFD: 0xB176,
	0xFFFD: 0xB177,
	0xFFFD: 0xB178,
	0xFFFD: 0xB179,
	0xFFFD: 0xB17A,
	0xFFFD: 0xB17B,
	0xFFFD: 0xB17C,
	0xFFFD: 0xB17D,
	0xFFFD: 0xB17E,
	0xFFFD: 0xB17F,
	0xFFFD: 0xB180,
	0xFFFD: 0xB181,
	0xFFFD: 0xB182,
	0xFFFD: 0xB183,
	0xFFFD: 0xB184,
	0xFFFD: 0xB185,
	0xFFFD: 0xB186,
	0xFFFD: 0xB187,
	0xFFFD: 0xB188,
	0xFFFD: 0xB189,
	0xFFFD: 0xB18A,
	0xFFFD: 0xB18B,
	0xFFFD: 0xB18C,
	0xFFFD: 0xB18D,
	0xFFFD: 0xB18E,
	0xFFFD: 0xB18F,
	0xFFFD: 0xB190,
	0xFFFD: 0xB191,
	0xFFFD: 0xB192,
	0xFFFD: 0xB193,
	0xFFFD: 0xB194,
	0xFFFD: 0xB195,
	0xFFFD: 0xB196,
	0xFFFD: 0xB197,
	0xFFFD: 0xB198,
	0xFFFD: 0xB199,
	0xFFFD: 0xB19A,
	0xFFFD: 0xB19B,
	0xFFFD: 0xB19C,
	0xFFFD: 0xB19D,
	0xFFFD: 0xB19E,
	0xFFFD: 0xB19F,
	0xFFFD: 0xB1A0,
	0xFFFD: 0xB1A1,
	0xFFFD: 0xB1A2,
	0xFFFD: 0xB1A3,
	0xFFFD: 0xB1A4,
	0xFFFD: 0xB1A5,
	0xFFFD: 0xB1A6,
	0xFFFD: 0xB1A7,
	0xFFFD: 0xB1A8,
	0xFFFD: 0xB1A9,
	0xFFFD: 0xB1AA,
	0xFFFD: 0xB1AB,
	0xFFFD: 0xB1AC,
	0xFFFD: 0xB1AD,
	0xFFFD: 0xB1AE,
	0xFFFD: 0xB1AF,
	0xFFFD: 0xB1B0,
	0xFFFD: 0xB1B1,
	0xFFFD: 0xB1B2,
	0xFFFD: 0xB1B3,
	0xFFFD: 0xB1B4,
	0xFFFD: 0xB1B5,
	0xFFFD: 0xB1B6,
	0xFFFD: 0xB1B7,
	0xFFFD: 0xB1B8,
	0xFFFD: 0xB1B9,
	0xFFFD: 0xB1BA,
	0xFFFD: 0xB1BB,
	0xFFFD: 0xB1BC,
	0xFFFD: 0xB1BD,
	0xFFFD: 0xB1BE,
	0xFFFD: 0xB1BF,
	0xFFFD: 0xB1C0,
	0xFFFD: 0xB1C1,
	0xFFFD: 0xB1C2,
	0xFFFD: 0xB1C3,
	0xFFFD: 0xB1C4,
	0xFFFD: 0xB1C5,
	0xFFFD: 0xB1C6,
	0xFFFD: 0xB1C7,
	0xFFFD: 0xB1C8,
	0xFFFD: 0xB1C9,
	0xFFFD: 0xB1CA,
	0xFFFD: 0xB1CB,
	0xFFFD: 0xB1CC,
	0xFFFD: 0xB1CD,
	0xFFFD: 0xB1CE,
	0xFFFD: 0xB1CF,
	0xFFFD: 0xB1D0,
	0xFFFD: 0xB1D1,
	0xFFFD: 0xB1D2,
	0xFFFD: 0xB1D3,
	0xFFFD: 0xB1D4,
	0xFFFD: 0xB1D5,
	0xFFFD: 0xB1D6,
	0xFFFD: 0xB1D7,
	0xFFFD: 0xB1D8,
	0xFFFD: 0xB1D9,
	0xFFFD: 0xB1DA,
	0xFFFD: 0xB1DB,
	0xFFFD: 0xB1DC,
	0xFFFD: 0xB1DD,
	0xFFFD: 0xB1DE,
	0xFFFD: 0xB1DF,
	0xFFFD: 0xB1E0,
	0xFFFD: 0xB1E1,
	0xFFFD: 0xB1E2,
	0xFFFD: 0xB1E3,
	0xFFFD: 0xB1E4,
	0xFFFD: 0xB1E5,
	0xFFFD: 0xB1E6,
	0xFFFD: 0xB1E7,
	0xFFFD: 0xB1E8,
	0xFFFD: 0xB1E9,
	0xFFFD: 0xB1EA,
	0xFFFD: 0xB1EB,
	0xFFFD: 0xB1EC,
	0xFFFD: 0xB1ED,
	0xFFFD: 0xB1EE,
	0xFFFD: 0xB1EF,
	0xFFFD: 0xB1F0,
	0xFFFD: 0xB1F1,
	0xFFFD: 0xB1F2,
	0xFFFD: 0xB1F3,
	0xFFFD: 0xB1F4,
	0xFFFD: 0xB1F5,
	0xFFFD: 0xB1F6,
	0xFFFD: 0xB1F7,
	0xFFFD: 0xB1F8,
	0xFFFD: 0xB1F9,
	0xFFFD: 0xB1FA,
	0xFFFD: 0xB1FB,
	0xFFFD: 0xB1FC,
	0xFFFD: 0xB1FD,
	0xFFFD: 0xB1FE,
	0xFFFD: 0xB1FF,
	0xFFFD: 0xB200,
	0xFFFD: 0xB201,
	0xFFFD: 0xB202,
	0xFFFD: 0xB203,
	0xFFFD: 0xB204,
	0xFFFD: 0xB205,
	0xFFFD: 0xB206,
	0xFFFD: 0xB207,
	0xFFFD: 0xB208,
	0xFFFD: 0xB209,
	0xFFFD: 0xB20A,
	0xFFFD: 0xB20B,
	0xFFFD: 0xB20C,
	0xFFFD: 0xB20D,
	0xFFFD: 0xB20E,
	0xFFFD: 0xB20F,
	0xFFFD: 0xB210,
	0xFFFD: 0xB211,
	0xFFFD: 0xB212,
	0xFFFD: 0xB213,
	0xFFFD: 0xB214,
	0xFFFD: 0xB215,
	0xFFFD: 0xB216,
	0xFFFD: 0xB217,
	0xFFFD: 0xB218,
	0xFFFD: 0xB219,
	0xFFFD: 0xB21A,
	0xFFFD: 0xB21B,
	0xFFFD: 0xB21C,
	0xFFFD: 0xB21D,
	0xFFFD: 0xB21E,
	0xFFFD: 0xB21F,
	0xFFFD: 0xB220,
	0xFFFD: 0xB221,
	0xFFFD: 0xB222,
	0xFFFD: 0xB223,
	0xFFFD: 0xB224,
	0xFFFD: 0xB225,
	0xFFFD: 0xB226,
	0xFFFD: 0xB227,
	0xFFFD: 0xB228,
	0xFFFD: 0xB229,
	0xFFFD: 0xB22A,
	0xFFFD: 0xB22B,
	0xFFFD: 0xB22C,
	0xFFFD: 0xB22D,
	0xFFFD: 0xB22E,
	0xFFFD: 0xB22F,
	0xFFFD: 0xB230,
	0xFFFD: 0xB231,
	0xFFFD: 0xB232,
	0xFFFD: 0xB233,
	0xFFFD: 0xB234,
	0xFFFD: 0xB235,
	0xFFFD: 0xB236,
	0xFFFD: 0xB237,
	0xFFFD: 0xB238,
	0xFFFD: 0xB239,
	0xFFFD: 0xB23A,
	0xFFFD: 0xB23B,
	0xFFFD: 0xB23C,
	0xFFFD: 0xB23D,
	0xFFFD: 0xB23E,
	0xFFFD: 0xB23F,
	0xFFFD: 0xB240,
	0xFFFD: 0xB241,
	0xFFFD: 0xB242,
	0xFFFD: 0xB243,
	0xFFFD: 0xB244,
	0xFFFD: 0xB245,
	0xFFFD: 0xB246,
	0xFFFD: 0xB247,
	0xFFFD: 0xB248,
	0xFFFD: 0xB249,
	0xFFFD: 0xB24A,
	0xFFFD: 0xB24B,
	0xFFFD: 0xB24C,
	0xFFFD: 0xB24D,
	0xFFFD: 0xB24E,
	0xFFFD: 0xB24F,
	0xFFFD: 0xB250,
	0xFFFD: 0xB251,
	0xFFFD: 0xB252,
	0xFFFD: 0xB253,
	0xFFFD: 0xB254,
	0xFFFD: 0xB255,
	0xFFFD: 0xB256,
	0xFFFD: 0xB257,
	0xFFFD: 0xB258,
	0xFFFD: 0xB259,
	0xFFFD: 0xB25A,
	0xFFFD: 0xB25B,
	0xFFFD: 0xB25C,
	0xFFFD: 0xB25D,
	0xFFFD: 0xB25E,
	0xFFFD: 0xB25F,
	0xFFFD: 0xB260,
	0xFFFD: 0xB261,
	0xFFFD: 0xB262,
	0xFFFD: 0xB263,
	0xFFFD: 0xB264,
	0xFFFD: 0xB265,
	0xFFFD: 0xB266,
	0xFFFD: 0xB267,
	0xFFFD: 0xB268,
	0xFFFD: 0xB269,
	0xFFFD: 0xB26A,
	0xFFFD: 0xB26B,
	0xFFFD: 0xB26C,
	0xFFFD: 0xB26D,
	0xFFFD: 0xB26E,
	0xFFFD: 0xB26F,
	0xFFFD: 0xB270,
	0xFFFD: 0xB271,
	0xFFFD: 0xB272,
	0xFFFD: 0xB273,
	0xFFFD: 0xB274,
	0xFFFD: 0xB275,
	0xFFFD: 0xB276,
	0xFFFD: 0xB277,
	0xFFFD: 0xB278,
	0xFFFD: 0xB279,
	0xFFFD: 0xB27A,
	0xFFFD: 0xB27B,
	0xFFFD: 0xB27C,
	0xFFFD: 0xB27D,
	0xFFFD: 0xB27E,
	0xFFFD: 0xB27F,
	0xFFFD: 0xB280,
	0xFFFD: 0xB281,
	0xFFFD: 0xB282,
	0xFFFD: 0xB283,
	0xFFFD: 0xB284,
	0xFFFD: 0xB285,
	0xFFFD: 0xB286,
	0xFFFD: 0xB287,
	0xFFFD: 0xB288,
	0xFFFD: 0xB289,
	0xFFFD: 0xB28A,
	0xFFFD: 0xB28B,
	0xFFFD: 0xB28C,
	0xFFFD: 0xB28D,
	0xFFFD: 0xB28E,
	0xFFFD: 0xB28F,
	0xFFFD: 0xB290,
	0xFFFD: 0xB291,
	0xFFFD: 0xB292,
	0xFFFD: 0xB293,
	0xFFFD: 0xB294,
	0xFFFD: 0xB295,
	0xFFFD: 0xB296,
	0xFFFD: 0xB297,
	0xFFFD: 0xB298,
	0xFFFD: 0xB299,
	0xFFFD: 0xB29A,
	0xFFFD: 0xB29B,
	0xFFFD: 0xB29C,
	0xFFFD: 0xB29D,
	0xFFFD: 0xB29E,
	0xFFFD: 0xB29F,
	0xFFFD: 0xB2A0,
	0xFFFD: 0xB2A1,
	0xFFFD: 0xB2A2,
	0xFFFD: 0xB2A3,
	0xFFFD: 0xB2A4,
	0xFFFD: 0xB2A5,
	0xFFFD: 0xB2A6,
	0xFFFD: 0xB2A7,
	0xFFFD: 0xB2A8,
	0xFFFD: 0xB2A9,
	0xFFFD: 0xB2AA,
	0xFFFD: 0xB2AB,
	0xFFFD: 0xB2AC,
	0xFFFD: 0xB2AD,
	0xFFFD: 0xB2AE,
	0xFFFD: 0xB2AF,
	0xFFFD: 0xB2B0,
	0xFFFD: 0xB2B1,
	0xFFFD: 0xB2B2,
	0xFFFD: 0xB2B3,
	0xFFFD: 0xB2B4,
	0xFFFD: 0xB2B5,
	0xFFFD: 0xB2B6,
	0xFFFD: 0xB2B7,
	0xFFFD: 0xB2B8,
	0xFFFD: 0xB2B9,
	0xFFFD: 0xB2BA,
	0xFFFD: 0xB2BB,
	0xFFFD: 0xB2BC,
	0xFFFD: 0xB2BD,
	0xFFFD: 0xB2BE,
	0xFFFD: 0xB2BF,
	0xFFFD: 0xB2C0,
	0xFFFD: 0xB2C1,
	0xFFFD: 0xB2C2,
	0xFFFD: 0xB2C3,
	0xFFFD: 0xB2C4,
	0xFFFD: 0xB2C5,
	0xFFFD: 0xB2C6,
	0xFFFD: 0xB2C7,
	0xFFFD: 0xB2C8,
	0xFFFD: 0xB2C9,
	0xFFFD: 0xB2CA,
	0xFFFD: 0xB2CB,
	0xFFFD: 0xB2CC,
	0xFFFD: 0xB2CD,
	0xFFFD: 0xB2CE,
	0xFFFD: 0xB2CF,
	0xFFFD: 0xB2D0,
	0xFFFD: 0xB2D1,
	0xFFFD: 0xB2D2,
	0xFFFD: 0xB2D3,
	0xFFFD: 0xB2D4,
	0xFFFD: 0xB2D5,
	0xFFFD: 0xB2D6,
	0xFFFD: 0xB2D7,
	0xFFFD: 0xB2D8,
	0xFFFD: 0xB2D9,
	0xFFFD: 0xB2DA,
	0xFFFD: 0xB2DB,
	0xFFFD: 0xB2DC,
	0xFFFD: 0xB2DD,
	0xFFFD: 0xB2DE,
	0xFFFD: 0xB2DF,
	0xFFFD: 0xB2E0,
	0xFFFD: 0xB2E1,
	0xFFFD: 0xB2E2,
	0xFFFD: 0xB2E3,
	0xFFFD: 0xB2E4,
	0xFFFD: 0xB2E5,
	0xFFFD: 0xB2E6,
	0xFFFD: 0xB2E7,
	0xFFFD: 0xB2E8,
	0xFFFD: 0xB2E9,
	0xFFFD: 0xB2EA,
	0xFFFD: 0xB2EB,
	0xFFFD: 0xB2EC,
	0xFFFD: 0xB2ED,
	0xFFFD: 0xB2EE,
	0xFFFD: 0xB2EF,
	0xFFFD: 0xB2F0,
	0xFFFD: 0xB2F1,
	0xFFFD: 0xB2F2,
	0xFFFD: 0xB2F3,
	0xFFFD: 0xB2F4,
	0xFFFD: 0xB2F5,
	0xFFFD: 0xB2F6,
	0xFFFD: 0xB2F7,
	0xFFFD: 0xB2F8,
	0xFFFD: 0xB2F9,
	0xFFFD: 0xB2FA,
	0xFFFD: 0xB2FB,
	0xFFFD: 0xB2FC,
	0xFFFD: 0xB2FD,
	0xFFFD: 0xB2FE,
	0xFFFD: 0xB2FF,
	0xFFFD: 0xB300,
	0xFFFD: 0xB301,
	0xFFFD: 0xB302,
	0xFFFD: 0xB303,
	0xFFFD: 0xB304,
	0xFFFD: 0xB305,
	0xFFFD: 0xB306,
	0xFFFD: 0xB307,
	0xFFFD: 0xB308,
	0xFFFD: 0xB309,
	0xFFFD: 0xB30A,
	0xFFFD: 0xB30B,
	0xFFFD: 0xB30C,
	0xFFFD: 0xB30D,
	0xFFFD: 0xB30E,
	0xFFFD: 0xB30F,
	0xFFFD: 0xB310,
	0xFFFD: 0xB311,
	0xFFFD: 0xB312,
	0xFFFD: 0xB313,
	0xFFFD: 0xB314,
	0xFFFD: 0xB315,
	0xFFFD: 0xB316,
	0xFFFD: 0xB317,
	0xFFFD: 0xB318,
	0xFFFD: 0xB319,
	0xFFFD: 0xB31A,
	0xFFFD: 0xB31B,
	0xFFFD: 0xB31C,
	0xFFFD: 0xB31D,
	0xFFFD: 0xB31E,
	0xFFFD: 0xB31F,
	0xFFFD: 0xB320,
	0xFFFD: 0xB321,
	0xFFFD: 0xB322,
	0xFFFD: 0xB323,
	0xFFFD: 0xB324,
	0xFFFD: 0xB325,
	0xFFFD: 0xB326,
	0xFFFD: 0xB327,
	0xFFFD: 0xB328,
	0xFFFD: 0xB329,
	0xFFFD: 0xB32A,
	0xFFFD: 0xB32B,
	0xFFFD: 0xB32C,
	0xFFFD: 0xB32D,
	0xFFFD: 0xB32E,
	0xFFFD: 0xB32F,
	0xFFFD: 0xB330,
	0xFFFD: 0xB331,
	0xFFFD: 0xB332,
	0xFFFD: 0xB333,
	0xFFFD: 0xB334,
	0xFFFD: 0xB335,
	0xFFFD: 0xB336,
	0xFFFD: 0xB337,
	0xFFFD: 0xB338,
	0xFFFD: 0xB339,
	0xFFFD: 0xB33A,
	0xFFFD: 0xB33B,
	0xFFFD: 0xB33C,
	0xFFFD: 0xB33D,
	0xFFFD: 0xB33E,
	0xFFFD: 0xB33F,
	0xFFFD: 0xB340,
	0xFFFD: 0xB341,
	0xFFFD: 0xB342,
	0xFFFD: 0xB343,
	0xFFFD: 0xB344,
	0xFFFD: 0xB345,
	0xFFFD: 0xB346,
	0xFFFD: 0xB347,
	0xFFFD: 0xB348,
	0xFFFD: 0xB349,
	0xFFFD: 0xB34A,
	0xFFFD: 0xB34B,
	0xFFFD: 0xB34C,
	0xFFFD: 0xB34D,
	0xFFFD: 0xB34E,
	0xFFFD: 0xB34F,
	0xFFFD: 0xB350,
	0xFFFD: 0xB351,
	0xFFFD: 0xB352,
	0xFFFD: 0xB353,
	0xFFFD: 0xB354,
	0xFFFD: 0xB355,
	0xFFFD: 0xB356,
	0xFFFD: 0xB357,
	0xFFFD: 0xB358,
	0xFFFD: 0xB359,
	0xFFFD: 0xB35A,
	0xFFFD: 0xB35B,
	0xFFFD: 0xB35C,
	0xFFFD: 0xB35D,
	0xFFFD: 0xB35E,
	0xFFFD: 0xB35F,
	0xFFFD: 0xB360,
	0xFFFD: 0xB361,
	0xFFFD: 0xB362,
	0xFFFD: 0xB363,
	0xFFFD: 0xB364,
	0xFFFD: 0xB365,
	0xFFFD: 0xB366,
	0xFFFD: 0xB367,
	0xFFFD: 0xB368,
	0xFFFD: 0xB369,
	0xFFFD: 0xB36A,
	0xFFFD: 0xB36B,
	0xFFFD: 0xB36C,
	0xFFFD: 0xB36D,
	0xFFFD: 0xB36E,
	0xFFFD: 0xB36F,
	0xFFFD: 0xB370,
	0xFFFD: 0xB371,
	0xFFFD: 0xB372,
	0xFFFD: 0xB373,
	0xFFFD: 0xB374,
	0xFFFD: 0xB375,
	0xFFFD: 0xB376,
	0xFFFD: 0xB377,
	0xFFFD: 0xB378,
	0xFFFD: 0xB379,
	0xFFFD: 0xB37A,
	0xFFFD: 0xB37B,
	0xFFFD: 0xB37C,
	0xFFFD: 0xB37D,
	0xFFFD: 0xB37E,
	0xFFFD: 0xB37F,
	0xFFFD: 0xB380,
	0xFFFD: 0xB381,
	0xFFFD: 0xB382,
	0xFFFD: 0xB383,
	0xFFFD: 0xB384,
	0xFFFD: 0xB385,
	0xFFFD: 0xB386,
	0xFFFD: 0xB387,
	0xFFFD: 0xB388,
	0xFFFD: 0xB389,
	0xFFFD: 0xB38A,
	0xFFFD: 0xB38B,
	0xFFFD: 0xB38C,
	0xFFFD: 0xB38D,
	0xFFFD: 0xB38E,
	0xFFFD: 0xB38F,
	0xFFFD: 0xB390,
	0xFFFD: 0xB391,
	0xFFFD: 0xB392,
	0xFFFD: 0xB393,
	0xFFFD: 0xB394,
	0xFFFD: 0xB395,
	0xFFFD: 0xB396,
	0xFFFD: 0xB397,
	0xFFFD: 0xB398,
	0xFFFD: 0xB399,
	0xFFFD: 0xB39A,
	0xFFFD: 0xB39B,
	0xFFFD: 0xB39C,
	0xFFFD: 0xB39D,
	0xFFFD: 0xB39E,
	0xFFFD: 0xB39F,
	0xFFFD: 0xB3A0,
	0xFFFD: 0xB3A1,
	0xFFFD: 0xB3A2,
	0xFFFD: 0xB3A3,
	0xFFFD: 0xB3A4,
	0xFFFD: 0xB3A5,
	0xFFFD: 0xB3A6,
	0xFFFD: 0xB3A7,
	0xFFFD: 0xB3A8,
	0xFFFD: 0xB3A9,
	0xFFFD: 0xB3AA,
	0xFFFD: 0xB3AB,
	0xFFFD: 0xB3AC,
	0xFFFD: 0xB3AD,
	0xFFFD: 0xB3AE,
	0xFFFD: 0xB3AF,
	0xFFFD: 0xB3B0,
	0xFFFD: 0xB3B1,
	0xFFFD: 0xB3B2,
	0xFFFD: 0xB3B3,
	0xFFFD: 0xB3B4,
	0xFFFD: 0xB3B5,
	0xFFFD: 0xB3B6,
	0xFFFD: 0xB3B7,
	0xFFFD: 0xB3B8,
	0xFFFD: 0xB3B9,
	0xFFFD: 0xB3BA,
	0xFFFD: 0xB3BB,
	0xFFFD: 0xB3BC,
	0xFFFD: 0xB3BD,
	0xFFFD: 0xB3BE,
	0xFFFD: 0xB3BF,
	0xFFFD: 0xB3C0,
	0xFFFD: 0xB3C1,
	0xFFFD: 0xB3C2,
	0xFFFD: 0xB3C3,
	0xFFFD: 0xB3C4,
	0xFFFD: 0xB3C5,
	0xFFFD: 0xB3C6,
	0xFFFD: 0xB3C7,
	0xFFFD: 0xB3C8,
	0xFFFD: 0xB3C9,
	0xFFFD: 0xB3CA,
	0xFFFD: 0xB3CB,
	0xFFFD: 0xB3CC,
	0xFFFD: 0xB3CD,
	0xFFFD: 0xB3CE,
	0xFFFD: 0xB3CF,
	0xFFFD: 0xB3D0,
	0xFFFD: 0xB3D1,
	0xFFFD: 0xB3D2,
	0xFFFD: 0xB3D3,
	0xFFFD: 0xB3D4,
	0xFFFD: 0xB3D5,
	0xFFFD: 0xB3D6,
	0xFFFD: 0xB3D7,
	0xFFFD: 0xB3D8,
	0xFFFD: 0xB3D9,
	0xFFFD: 0xB3DA,
	0xFFFD: 0xB3DB,
	0xFFFD: 0xB3DC,
	0xFFFD: 0xB3DD,
	0xFFFD: 0xB3DE,
	0xFFFD: 0xB3DF,
	0xFFFD: 0xB3E0,
	0xFFFD: 0xB3E1,
	0xFFFD: 0xB3E2,
	0xFFFD: 0xB3E3,
	0xFFFD: 0xB3E4,
	0xFFFD: 0xB3E5,
	0xFFFD: 0xB3E6,
	0xFFFD: 0xB3E7,
	0xFFFD: 0xB3E8,
	0xFFFD: 0xB3E9,
	0xFFFD: 0xB3EA,
	0xFFFD: 0xB3EB,
	0xFFFD: 0xB3EC,
	0xFFFD: 0xB3ED,
	0xFFFD: 0xB3EE,
	0xFFFD: 0xB3EF,
	0xFFFD: 0xB3F0,
	0xFFFD: 0xB3F1,
	0xFFFD: 0xB3F2,
	0xFFFD: 0xB3F3,
	0xFFFD: 0xB3F4,
	0xFFFD: 0xB3F5,
	0xFFFD: 0xB3F6,
	0xFFFD: 0xB3F7,
	0xFFFD: 0xB3F8,
	0xFFFD: 0xB3F9,
	0xFFFD: 0xB3FA,
	0xFFFD: 0xB3FB,
	0xFFFD: 0xB3FC,
	0xFFFD: 0xB3FD,
	0xFFFD: 0xB3FE,
	0xFFFD: 0xB3FF,
	0xFFFD: 0xB400,
	0xFFFD: 0xB401,
	0xFFFD: 0xB402,
	0xFFFD: 0xB403,
	0xFFFD: 0xB404,
	0xFFFD: 0xB405,
	0xFFFD: 0xB406,
	0xFFFD: 0xB407,
	0xFFFD: 0xB408,
	0xFFFD: 0xB409,
	0xFFFD: 0xB40A,
	0xFFFD: 0xB40B,
	0xFFFD: 0xB40C,
	0xFFFD: 0xB40D,
	0xFFFD: 0xB40E,
	0xFFFD: 0xB40F,
	0xFFFD: 0xB410,
	0xFFFD: 0xB411,
	0xFFFD: 0xB412,
	0xFFFD: 0xB413,
	0xFFFD: 0xB414,
	0xFFFD: 0xB415,
	0xFFFD: 0xB416,
	0xFFFD: 0xB417,
	0xFFFD: 0xB418,
	0xFFFD: 0xB419,
	0xFFFD: 0xB41A,
	0xFFFD: 0xB41B,
	0xFFFD: 0xB41C,
	0xFFFD: 0xB41D,
	0xFFFD: 0xB41E,
	0xFFFD: 0xB41F,
	0xFFFD: 0xB420,
	0xFFFD: 0xB421,
	0xFFFD: 0xB422,
	0xFFFD: 0xB423,
	0xFFFD: 0xB424,
	0xFFFD: 0xB425,
	0xFFFD: 0xB426,
	0xFFFD: 0xB427,
	0xFFFD: 0xB428,
	0xFFFD: 0xB429,
	0xFFFD: 0xB42A,
	0xFFFD: 0xB42B,
	0xFFFD: 0xB42C,
	0xFFFD: 0xB42D,
	0xFFFD: 0xB42E,
	0xFFFD: 0xB42F,
	0xFFFD: 0xB430,
	0xFFFD: 0xB431,
	0xFFFD: 0xB432,
	0xFFFD: 0xB433,
	0xFFFD: 0xB434,
	0xFFFD: 0xB435,
	0xFFFD: 0xB436,
	0xFFFD: 0xB437,
	0xFFFD: 0xB438,
	0xFFFD: 0xB439,
	0xFFFD: 0xB43A,
	0xFFFD: 0xB43B,
	0xFFFD: 0xB43C,
	0xFFFD: 0xB43D,
	0xFFFD: 0xB43E,
	0xFFFD: 0xB43F,
	0xFFFD: 0xB440,
	0xFFFD: 0xB441,
	0xFFFD: 0xB442,
	0xFFFD: 0xB443,
	0xFFFD: 0xB444,
	0xFFFD: 0xB445,
	0xFFFD: 0xB446,
	0xFFFD: 0xB447,
	0xFFFD: 0xB448,
	0xFFFD: 0xB449,
	0xFFFD: 0xB44A,
	0xFFFD: 0xB44B,
	0xFFFD: 0xB44C,
	0xFFFD: 0xB44D,
	0xFFFD: 0xB44E,
	0xFFFD: 0xB44F,
	0xFFFD: 0xB450,
	0xFFFD: 0xB451,
	0xFFFD: 0xB452,
	0xFFFD: 0xB453,
	0xFFFD: 0xB454,
	0xFFFD: 0xB455,
	0xFFFD: 0xB456,
	0xFFFD: 0xB457,
	0xFFFD: 0xB458,
	0xFFFD: 0xB459,
	0xFFFD: 0xB45A,
	0xFFFD: 0xB45B,
	0xFFFD: 0xB45C,
	0xFFFD: 0xB45D,
	0xFFFD: 0xB45E,
	0xFFFD: 0xB45F,
	0xFFFD: 0xB460,
	0xFFFD: 0xB461,
	0xFFFD: 0xB462,
	0xFFFD: 0xB463,
	0xFFFD: 0xB464,
	0xFFFD: 0xB465,
	0xFFFD: 0xB466,
	0xFFFD: 0xB467,
	0xFFFD: 0xB468,
	0xFFFD: 0xB469,
	0xFFFD: 0xB46A,
	0xFFFD: 0xB46B,
	0xFFFD: 0xB46C,
	0xFFFD: 0xB46D,
	0xFFFD: 0xB46E,
	0xFFFD: 0xB46F,
	0xFFFD: 0xB470,
	0xFFFD: 0xB471,
	0xFFFD: 0xB472,
	0xFFFD: 0xB473,
	0xFFFD: 0xB474,
	0xFFFD: 0xB475,
	0xFFFD: 0xB476,
	0xFFFD: 0xB477,
	0xFFFD: 0xB478,
	0xFFFD: 0xB479,
	0xFFFD: 0xB47A,
	0xFFFD: 0xB47B,
	0xFFFD: 0xB47C,
	0xFFFD: 0xB47D,
	0xFFFD: 0xB47E,
	0xFFFD: 0xB47F,
	0xFFFD: 0xB480,
	0xFFFD: 0xB481,
	0xFFFD: 0xB482,
	0xFFFD: 0xB483,
	0xFFFD: 0xB484,
	0xFFFD: 0xB485,
	0xFFFD: 0xB486,
	0xFFFD: 0xB487,
	0xFFFD: 0xB488,
	0xFFFD: 0xB489,
	0xFFFD: 0xB48A,
	0xFFFD: 0xB48B,
	0xFFFD: 0xB48C,
	0xFFFD: 0xB48D,
	0xFFFD: 0xB48E,
	0xFFFD: 0xB48F,
	0xFFFD: 0xB490,
	0xFFFD: 0xB491,
	0xFFFD: 0xB492,
	0xFFFD: 0xB493,
	0xFFFD: 0xB494,
	0xFFFD: 0xB495,
	0xFFFD: 0xB496,
	0xFFFD: 0xB497,
	0xFFFD: 0xB498,
	0xFFFD: 0xB499,
	0xFFFD: 0xB49A,
	0xFFFD: 0xB49B,
	0xFFFD: 0xB49C,
	0xFFFD: 0xB49D,
	0xFFFD: 0xB49E,
	0xFFFD: 0xB49F,
	0xFFFD: 0xB4A0,
	0xFFFD: 0xB4A1,
	0xFFFD: 0xB4A2,
	0xFFFD: 0xB4A3,
	0xFFFD: 0xB4A4,
	0xFFFD: 0xB4A5,
	0xFFFD: 0xB4A6,
	0xFFFD: 0xB4A7,
	0xFFFD: 0xB4A8,
	0xFFFD: 0xB4A9,
	0xFFFD: 0xB4AA,
	0xFFFD: 0xB4AB,
	0xFFFD: 0xB4AC,
	0xFFFD: 0xB4AD,
	0xFFFD: 0xB4AE,
	0xFFFD: 0xB4AF,
	0xFFFD: 0xB4B0,
	0xFFFD: 0xB4B1,
	0xFFFD: 0xB4B2,
	0xFFFD: 0xB4B3,
	0xFFFD: 0xB4B4,
	0xFFFD: 0xB4B5,
	0xFFFD: 0xB4B6,
	0xFFFD: 0xB4B7,
	0xFFFD: 0xB4B8,
	0xFFFD: 0xB4B9,
	0xFFFD: 0xB4BA,
	0xFFFD: 0xB4BB,
	0xFFFD: 0xB4BC,
	0xFFFD: 0xB4BD,
	0xFFFD: 0xB4BE,
	0xFFFD: 0xB4BF,
	0xFFFD: 0xB4C0,
	0xFFFD: 0xB4C1,
	0xFFFD: 0xB4C2,
	0xFFFD: 0xB4C3,
	0xFFFD: 0xB4C4,
	0xFFFD: 0xB4C5,
	0xFFFD: 0xB4C6,
	0xFFFD: 0xB4C7,
	0xFFFD: 0xB4C8,
	0xFFFD: 0xB4C9,
	0xFFFD: 0xB4CA,
	0xFFFD: 0xB4CB,
	0xFFFD: 0xB4CC,
	0xFFFD: 0xB4CD,
	0xFFFD: 0xB4CE,
	0xFFFD: 0xB4CF,
	0xFFFD: 0xB4D0,
	0xFFFD: 0xB4D1,
	0xFFFD: 0xB4D2,
	0xFFFD: 0xB4D3,
	0xFFFD: 0xB4D4,
	0xFFFD: 0xB4D5,
	0xFFFD: 0xB4D6,
	0xFFFD: 0xB4D7,
	0xFFFD: 0xB4D8,
	0xFFFD: 0xB4D9,
	0xFFFD: 0xB4DA,
	0xFFFD: 0xB4DB,
	0xFFFD: 0xB4DC,
	0xFFFD: 0xB4DD,
	0xFFFD: 0xB4DE,
	0xFFFD: 0xB4DF,
	0xFFFD: 0xB4E0,
	0xFFFD: 0xB4E1,
	0xFFFD: 0xB4E2,
	0xFFFD: 0xB4E3,
	0xFFFD: 0xB4E4,
	0xFFFD: 0xB4E5,
	0xFFFD: 0xB4E6,
	0xFFFD: 0xB4E7,
	0xFFFD: 0xB4E8,
	0xFFFD: 0xB4E9,
	0xFFFD: 0xB4EA,
	0xFFFD: 0xB4EB,
	0xFFFD: 0xB4EC,
	0xFFFD: 0xB4ED,
	0xFFFD: 0xB4EE,
	0xFFFD: 0xB4EF,
	0xFFFD: 0xB4F0,
	0xFFFD: 0xB4F1,
	0xFFFD: 0xB4F2,
	0xFFFD: 0xB4F3,
	0xFFFD: 0xB4F4,
	0xFFFD: 0xB4F5,
	0xFFFD: 0xB4F6,
	0xFFFD: 0xB4F7,
	0xFFFD: 0xB4F8,
	0xFFFD: 0xB4F9,
	0xFFFD: 0xB4FA,
	0xFFFD: 0xB4FB,
	0xFFFD: 0xB4FC,
	0xFFFD: 0xB4FD,
	0xFFFD: 0xB4FE,
	0xFFFD: 0xB4FF,
	0xFFFD: 0xB500,
	0xFFFD: 0xB501,
	0xFFFD: 0xB502,
	0xFFFD: 0xB503,
	0xFFFD: 0xB504,
	0xFFFD: 0xB505,
	0xFFFD: 0xB506,
	0xFFFD: 0xB507,
	0xFFFD: 0xB508,
	0xFFFD: 0xB509,
	0xFFFD: 0xB50A,
	0xFFFD: 0xB50B,
	0xFFFD: 0xB50C,
	0xFFFD: 0xB50D,
	0xFFFD: 0xB50E,
	0xFFFD: 0xB50F,
	0xFFFD: 0xB510,
	0xFFFD: 0xB511,
	0xFFFD: 0xB512,
	0xFFFD: 0xB513,
	0xFFFD: 0xB514,
	0xFFFD: 0xB515,
	0xFFFD: 0xB516,
	0xFFFD: 0xB517,
	0xFFFD: 0xB518,
	0xFFFD: 0xB519,
	0xFFFD: 0xB51A,
	0xFFFD: 0xB51B,
	0xFFFD: 0xB51C,
	0xFFFD: 0xB51D,
	0xFFFD: 0xB51E,
	0xFFFD: 0xB51F,
	0xFFFD: 0xB520,
	0xFFFD: 0xB521,
	0xFFFD: 0xB522,
	0xFFFD: 0xB523,
	0xFFFD: 0xB524,
	0xFFFD: 0xB525,
	0xFFFD: 0xB526,
	0xFFFD: 0xB527,
	0xFFFD: 0xB528,
	0xFFFD: 0xB529,
	0xFFFD: 0xB52A,
	0xFFFD: 0xB52B,
	0xFFFD: 0xB52C,
	0xFFFD: 0xB52D,
	0xFFFD: 0xB52E,
	0xFFFD: 0xB52F,
	0xFFFD: 0xB530,
	0xFFFD: 0xB531,
	0xFFFD: 0xB532,
	0xFFFD: 0xB533,
	0xFFFD: 0xB534,
	0xFFFD: 0xB535,
	0xFFFD: 0xB536,
	0xFFFD: 0xB537,
	0xFFFD: 0xB538,
	0xFFFD: 0xB539,
	0xFFFD: 0xB53A,
	0xFFFD: 0xB53B,
	0xFFFD: 0xB53C,
	0xFFFD: 0xB53D,
	0xFFFD: 0xB53E,
	0xFFFD: 0xB53F,
	0xFFFD: 0xB540,
	0xFFFD: 0xB541,
	0xFFFD: 0xB542,
	0xFFFD: 0xB543,
	0xFFFD: 0xB544,
	0xFFFD: 0xB545,
	0xFFFD: 0xB546,
	0xFFFD: 0xB547,
	0xFFFD: 0xB548,
	0xFFFD: 0xB549,
	0xFFFD: 0xB54A,
	0xFFFD: 0xB54B,
	0xFFFD: 0xB54C,
	0xFFFD: 0xB54D,
	0xFFFD: 0xB54E,
	0xFFFD: 0xB54F,
	0xFFFD: 0xB550,
	0xFFFD: 0xB551,
	0xFFFD: 0xB552,
	0xFFFD: 0xB553,
	0xFFFD: 0xB554,
	0xFFFD: 0xB555,
	0xFFFD: 0xB556,
	0xFFFD: 0xB557,
	0xFFFD: 0xB558,
	0xFFFD: 0xB559,
	0xFFFD: 0xB55A,
	0xFFFD: 0xB55B,
	0xFFFD: 0xB55C,
	0xFFFD: 0xB55D,
	0xFFFD: 0xB55E,
	0xFFFD: 0xB55F,
	0xFFFD: 0xB560,
	0xFFFD: 0xB561,
	0xFFFD: 0xB562,
	0xFFFD: 0xB563,
	0xFFFD: 0xB564,
	0xFFFD: 0xB565,
	0xFFFD: 0xB566,
	0xFFFD: 0xB567,
	0xFFFD: 0xB568,
	0xFFFD: 0xB569,
	0xFFFD: 0xB56A,
	0xFFFD: 0xB56B,
	0xFFFD: 0xB56C,
	0xFFFD: 0xB56D,
	0xFFFD: 0xB56E,
	0xFFFD: 0xB56F,
	0xFFFD: 0xB570,
	0xFFFD: 0xB571,
	0xFFFD: 0xB572,
	0xFFFD: 0xB573,
	0xFFFD: 0xB574,
	0xFFFD: 0xB575,
	0xFFFD: 0xB576,
	0xFFFD: 0xB577,
	0xFFFD: 0xB578,
	0xFFFD: 0xB579,
	0xFFFD: 0xB57A,
	0xFFFD: 0xB57B,
	0xFFFD: 0xB57C,
	0xFFFD: 0xB57D,
	0xFFFD: 0xB57E,
	0xFFFD: 0xB57F,
	0xFFFD: 0xB580,
	0xFFFD: 0xB581,
	0xFFFD: 0xB582,
	0xFFFD: 0xB583,
	0xFFFD: 0xB584,
	0xFFFD: 0xB585,
	0xFFFD: 0xB586,
	0xFFFD: 0xB587,
	0xFFFD: 0xB588,
	0xFFFD: 0xB589,
	0xFFFD: 0xB58A,
	0xFFFD: 0xB58B,
	0xFFFD: 0xB58C,
	0xFFFD: 0xB58D,
	0xFFFD: 0xB58E,
	0xFFFD: 0xB58F,
	0xFFFD: 0xB590,
	0xFFFD: 0xB591,
	0xFFFD: 0xB592,
	0xFFFD: 0xB593,
	0xFFFD: 0xB594,
	0xFFFD: 0xB595,
	0xFFFD: 0xB596,
	0xFFFD: 0xB597,
	0xFFFD: 0xB598,
	0xFFFD: 0xB599,
	0xFFFD: 0xB59A,
	0xFFFD: 0xB59B,
	0xFFFD: 0xB59C,
	0xFFFD: 0xB59D,
	0xFFFD: 0xB59E,
	0xFFFD: 0xB59F,
	0xFFFD: 0xB5A0,
	0xFFFD: 0xB5A1,
	0xFFFD: 0xB5A2,
	0xFFFD: 0xB5A3,
	0xFFFD: 0xB5A4,
	0xFFFD: 0xB5A5,
	0xFFFD: 0xB5A6,
	0xFFFD: 0xB5A7,
	0xFFFD: 0xB5A8,
	0xFFFD: 0xB5A9,
	0xFFFD: 0xB5AA,
	0xFFFD: 0xB5AB,
	0xFFFD: 0xB5AC,
	0xFFFD: 0xB5AD,
	0xFFFD: 0xB5AE,
	0xFFFD: 0xB5AF,
	0xFFFD: 0xB5B0,
	0xFFFD: 0xB5B1,
	0xFFFD: 0xB5B2,
	0xFFFD: 0xB5B3,
	0xFFFD: 0xB5B4,
	0xFFFD: 0xB5B5,
	0xFFFD: 0xB5B6,
	0xFFFD: 0xB5B7,
	0xFFFD: 0xB5B8,
	0xFFFD: 0xB5B9,
	0xFFFD: 0xB5BA,
	0xFFFD: 0xB5BB,
	0xFFFD: 0xB5BC,
	0xFFFD: 0xB5BD,
	0xFFFD: 0xB5BE,
	0xFFFD: 0xB5BF,
	0xFFFD: 0xB5C0,
	0xFFFD: 0xB5C1,
	0xFFFD: 0xB5C2,
	0xFFFD: 0xB5C3,
	0xFFFD: 0xB5C4,
	0xFFFD: 0xB5C5,
	0xFFFD: 0xB5C6,
	0xFFFD: 0xB5C7,
	0xFFFD: 0xB5C8,
	0xFFFD: 0xB5C9,
	0xFFFD: 0xB5CA,
	0xFFFD: 0xB5CB,
	0xFFFD: 0xB5CC,
	0xFFFD: 0xB5CD,
	0xFFFD: 0xB5CE,
	0xFFFD: 0xB5CF,
	0xFFFD: 0xB5D0,
	0xFFFD: 0xB5D1,
	0xFFFD: 0xB5D2,
	0xFFFD: 0xB5D3,
	0xFFFD: 0xB5D4,
	0xFFFD: 0xB5D5,
	0xFFFD: 0xB5D6,
	0xFFFD: 0xB5D7,
	0xFFFD: 0xB5D8,
	0xFFFD: 0xB5D9,
	0xFFFD: 0xB5DA,
	0xFFFD: 0xB5DB,
	0xFFFD: 0xB5DC,
	0xFFFD: 0xB5DD,
	0xFFFD: 0xB5DE,
	0xFFFD: 0xB5DF,
	0xFFFD: 0xB5E0,
	0xFFFD: 0xB5E1,
	0xFFFD: 0xB5E2,
	0xFFFD: 0xB5E3,
	0xFFFD: 0xB5E4,
	0xFFFD: 0xB5E5,
	0xFFFD: 0xB5E6,
	0xFFFD: 0xB5E7,
	0xFFFD: 0xB5E8,
	0xFFFD: 0xB5E9,
	0xFFFD: 0xB5EA,
	0xFFFD: 0xB5EB,
	0xFFFD: 0xB5EC,
	0xFFFD: 0xB5ED,
	0xFFFD: 0xB5EE,
	0xFFFD: 0xB5EF,
	0xFFFD: 0xB5F0,
	0xFFFD: 0xB5F1,
	0xFFFD: 0xB5F2,
	0xFFFD: 0xB5F3,
	0xFFFD: 0xB5F4,
	0xFFFD: 0xB5F5,
	0xFFFD: 0xB5F6,
	0xFFFD: 0xB5F7,
	0xFFFD: 0xB5F8,
	0xFFFD: 0xB5F9,
	0xFFFD: 0xB5FA,
	0xFFFD: 0xB5FB,
	0xFFFD: 0xB5FC,
	0xFFFD: 0xB5FD,
	0xFFFD: 0xB5FE,
	0xFFFD: 0xB5FF,
	0xFFFD: 0xB600,
	0xFFFD: 0xB601,
	0xFFFD: 0xB602,
	0xFFFD: 0xB603,
	0xFFFD: 0xB604,
	0xFFFD: 0xB605,
	0xFFFD: 0xB606,
	0xFFFD: 0xB607,
	0xFFFD: 0xB608,
	0xFFFD: 0xB609,
	0xFFFD: 0xB60A,
	0xFFFD: 0xB60B,
	0xFFFD: 0xB60C,
	0xFFFD: 0xB60D,
	0xFFFD: 0xB60E,
	0xFFFD: 0xB60F,
	0xFFFD: 0xB610,
	0xFFFD: 0xB611,
	0xFFFD: 0xB612,
	0xFFFD: 0xB613,
	0xFFFD: 0xB614,
	0xFFFD: 0xB615,
	0xFFFD: 0xB616,
	0xFFFD: 0xB617,
	0xFFFD: 0xB618,
	0xFFFD: 0xB619,
	0xFFFD: 0xB61A,
	0xFFFD: 0xB61B,
	0xFFFD: 0xB61C,
	0xFFFD: 0xB61D,
	0xFFFD: 0xB61E,
	0xFFFD: 0xB61F,
	0xFFFD: 0xB620,
	0xFFFD: 0xB621,
	0xFFFD: 0xB622,
	0xFFFD: 0xB623,
	0xFFFD: 0xB624,
	0xFFFD: 0xB625,
	0xFFFD: 0xB626,
	0xFFFD: 0xB627,
	0xFFFD: 0xB628,
	0xFFFD: 0xB629,
	0xFFFD: 0xB62A,
	0xFFFD: 0xB62B,
	0xFFFD: 0xB62C,
	0xFFFD: 0xB62D,
	0xFFFD: 0xB62E,
	0xFFFD: 0xB62F,
	0xFFFD: 0xB630,
	0xFFFD: 0xB631,
	0xFFFD: 0xB632,
	0xFFFD: 0xB633,
	0xFFFD: 0xB634,
	0xFFFD: 0xB635,
	0xFFFD: 0xB636,
	0xFFFD: 0xB637,
	0xFFFD: 0xB638,
	0xFFFD: 0xB639,
	0xFFFD: 0xB63A,
	0xFFFD: 0xB63B,
	0xFFFD: 0xB63C,
	0xFFFD: 0xB63D,
	0xFFFD: 0xB63E,
	0xFFFD: 0xB63F,
	0xFFFD: 0xB640,
	0xFFFD: 0xB641,
	0xFFFD: 0xB642,
	0xFFFD: 0xB643,
	0xFFFD: 0xB644,
	0xFFFD: 0xB645,
	0xFFFD: 0xB646,
	0xFFFD: 0xB647,
	0xFFFD: 0xB648,
	0xFFFD: 0xB649,
	0xFFFD: 0xB64A,
	0xFFFD: 0xB64B,
	0xFFFD: 0xB64C,
	0xFFFD: 0xB64D,
	0xFFFD: 0xB64E,
	0xFFFD: 0xB64F,
	0xFFFD: 0xB650,
	0xFFFD: 0xB651,
	0xFFFD: 0xB652,
	0xFFFD: 0xB653,
	0xFFFD: 0xB654,
	0xFFFD: 0xB655,
	0xFFFD: 0xB656,
	0xFFFD: 0xB657,
	0xFFFD: 0xB658,
	0xFFFD: 0xB659,
	0xFFFD: 0xB65A,
	0xFFFD: 0xB65B,
	0xFFFD: 0xB65C,
	0xFFFD: 0xB65D,
	0xFFFD: 0xB65E,
	0xFFFD: 0xB65F,
	0xFFFD: 0xB660,
	0xFFFD: 0xB661,
	0xFFFD: 0xB662,
	0xFFFD: 0xB663,
	0xFFFD: 0xB664,
	0xFFFD: 0xB665,
	0xFFFD: 0xB666,
	0xFFFD: 0xB667,
	0xFFFD: 0xB668,
	0xFFFD: 0xB669,
	0xFFFD: 0xB66A,
	0xFFFD: 0xB66B,
	0xFFFD: 0xB66C,
	0xFFFD: 0xB66D,
	0xFFFD: 0xB66E,
	0xFFFD: 0xB66F,
	0xFFFD: 0xB670,
	0xFFFD: 0xB671,
	0xFFFD: 0xB672,
	0xFFFD: 0xB673,
	0xFFFD: 0xB674,
	0xFFFD: 0xB675,
	0xFFFD: 0xB676,
	0xFFFD: 0xB677,
	0xFFFD: 0xB678,
	0xFFFD: 0xB679,
	0xFFFD: 0xB67A,
	0xFFFD: 0xB67B,
	0xFFFD: 0xB67C,
	0xFFFD: 0xB67D,
	0xFFFD: 0xB67E,
	0xFFFD: 0xB67F,
	0xFFFD: 0xB680,
	0xFFFD: 0xB681,
	0xFFFD: 0xB682,
	0xFFFD: 0xB683,
	0xFFFD: 0xB684,
	0xFFFD: 0xB685,
	0xFFFD: 0xB686,
	0xFFFD: 0xB687,
	0xFFFD: 0xB688,
	0xFFFD: 0xB689,
	0xFFFD: 0xB68A,
	0xFFFD: 0xB68B,
	0xFFFD: 0xB68C,
	0xFFFD: 0xB68D,
	0xFFFD: 0xB68E,
	0xFFFD: 0xB68F,
	0xFFFD: 0xB690,
	0xFFFD: 0xB691,
	0xFFFD: 0xB692,
	0xFFFD: 0xB693,
	0xFFFD: 0xB694,
	0xFFFD: 0xB695,
	0xFFFD: 0xB696,
	0xFFFD: 0xB697,
	0xFFFD: 0xB698,
	0xFFFD: 0xB699,
	0xFFFD: 0xB69A,
	0xFFFD: 0xB69B,
	0xFFFD: 0xB69C,
	0xFFFD: 0xB69D,
	0xFFFD: 0xB69E,
	0xFFFD: 0xB69F,
	0xFFFD: 0xB6A0,
	0xFFFD: 0xB6A1,
	0xFFFD: 0xB6A2,
	0xFFFD: 0xB6A3,
	0xFFFD: 0xB6A4,
	0xFFFD: 0xB6A5,
	0xFFFD: 0xB6A6,
	0xFFFD: 0xB6A7,
	0xFFFD: 0xB6A8,
	0xFFFD: 0xB6A9,
	0xFFFD: 0xB6AA,
	0xFFFD: 0xB6AB,
	0xFFFD: 0xB6AC,
	0xFFFD: 0xB6AD,
	0xFFFD: 0xB6AE,
	0xFFFD: 0xB6AF,
	0xFFFD: 0xB6B0,
	0xFFFD: 0xB6B1,
	0xFFFD: 0xB6B2,
	0xFFFD: 0xB6B3,
	0xFFFD: 0xB6B4,
	0xFFFD: 0xB6B5,
	0xFFFD: 0xB6B6,
	0xFFFD: 0xB6B7,
	0xFFFD: 0xB6B8,
	0xFFFD: 0xB6B9,
	0xFFFD: 0xB6BA,
	0xFFFD: 0xB6BB,
	0xFFFD: 0xB6BC,
	0xFFFD: 0xB6BD,
	0xFFFD: 0xB6BE,
	0xFFFD: 0xB6BF,
	0xFFFD: 0xB6C0,
	0xFFFD: 0xB6C1,
	0xFFFD: 0xB6C2,
	0xFFFD: 0xB6C3,
	0xFFFD: 0xB6C4,
	0xFFFD: 0xB6C5,
	0xFFFD: 0xB6C6,
	0xFFFD: 0xB6C7,
	0xFFFD: 0xB6C8,
	0xFFFD: 0xB6C9,
	0xFFFD: 0xB6CA,
	0xFFFD: 0xB6CB,
	0xFFFD: 0xB6CC,
	0xFFFD: 0xB6CD,
	0xFFFD: 0xB6CE,
	0xFFFD: 0xB6CF,
	0xFFFD: 0xB6D0,
	0xFFFD: 0xB6D1,
	0xFFFD: 0xB6D2,
	0xFFFD: 0xB6D3,
	0xFFFD: 0xB6D4,
	0xFFFD: 0xB6D5,
	0xFFFD: 0xB6D6,
	0xFFFD: 0xB6D7,
	0xFFFD: 0xB6D8,
	0xFFFD: 0xB6D9,
	0xFFFD: 0xB6DA,
	0xFFFD: 0xB6DB,
	0xFFFD: 0xB6DC,
	0xFFFD: 0xB6DD,
	0xFFFD: 0xB6DE,
	0xFFFD: 0xB6DF,
	0xFFFD: 0xB6E0,
	0xFFFD: 0xB6E1,
	0xFFFD: 0xB6E2,
	0xFFFD: 0xB6E3,
	0xFFFD: 0xB6E4,
	0xFFFD: 0xB6E5,
	0xFFFD: 0xB6E6,
	0xFFFD: 0xB6E7,
	0xFFFD: 0xB6E8,
	0xFFFD: 0xB6E9,
	0xFFFD: 0xB6EA,
	0xFFFD: 0xB6EB,
	0xFFFD: 0xB6EC,
	0xFFFD: 0xB6ED,
	0xFFFD: 0xB6EE,
	0xFFFD: 0xB6EF,
	0xFFFD: 0xB6F0,
	0xFFFD: 0xB6F1,
	0xFFFD: 0xB6F2,
	0xFFFD: 0xB6F3,
	0xFFFD: 0xB6F4,
	0xFFFD: 0xB6F5,
	0xFFFD: 0xB6F6,
	0xFFFD: 0xB6F7,
	0xFFFD: 0xB6F8,
	0xFFFD: 0xB6F9,
	0xFFFD: 0xB6FA,
	0xFFFD: 0xB6FB,
	0xFFFD: 0xB6FC,
	0xFFFD: 0xB6FD,
	0xFFFD: 0xB6FE,
	0xFFFD: 0xB6FF,
	0xFFFD: 0xB700,
	0xFFFD: 0xB701,
	0xFFFD: 0xB702,
	0xFFFD: 0xB703,
	0xFFFD: 0xB704,
	0xFFFD: 0xB705,
	0xFFFD: 0xB706,
	0xFFFD: 0xB707,
	0xFFFD: 0xB708,
	0xFFFD: 0xB709,
	0xFFFD: 0xB70A,
	0xFFFD: 0xB70B,
	0xFFFD: 0xB70C,
	0xFFFD: 0xB70D,
	0xFFFD: 0xB70E,
	0xFFFD: 0xB70F,
	0xFFFD: 0xB710,
	0xFFFD: 0xB711,
	0xFFFD: 0xB712,
	0xFFFD: 0xB713,
	0xFFFD: 0xB714,
	0xFFFD: 0xB715,
	0xFFFD: 0xB716,
	0xFFFD: 0xB717,
	0xFFFD: 0xB718,
	0xFFFD: 0xB719,
	0xFFFD: 0xB71A,
	0xFFFD: 0xB71B,
	0xFFFD: 0xB71C,
	0xFFFD: 0xB71D,
	0xFFFD: 0xB71E,
	0xFFFD: 0xB71F,
	0xFFFD: 0xB720,
	0xFFFD: 0xB721,
	0xFFFD: 0xB722,
	0xFFFD: 0xB723,
	0xFFFD: 0xB724,
	0xFFFD: 0xB725,
	0xFFFD: 0xB726,
	0xFFFD: 0xB727,
	0xFFFD: 0xB728,
	0xFFFD: 0xB729,
	0xFFFD: 0xB72A,
	0xFFFD: 0xB72B,
	0xFFFD: 0xB72C,
	0xFFFD: 0xB72D,
	0xFFFD: 0xB72E,
	0xFFFD: 0xB72F,
	0xFFFD: 0xB730,
	0xFFFD: 0xB731,
	0xFFFD: 0xB732,
	0xFFFD: 0xB733,
	0xFFFD: 0xB734,
	0xFFFD: 0xB735,
	0xFFFD: 0xB736,
	0xFFFD: 0xB737,
	0xFFFD: 0xB738,
	0xFFFD: 0xB739,
	0xFFFD: 0xB73A,
	0xFFFD: 0xB73B,
	0xFFFD: 0xB73C,
	0xFFFD: 0xB73D,
	0xFFFD: 0xB73E,
	0xFFFD: 0xB73F,
	0xFFFD: 0xB740,
	0xFFFD: 0xB741,
	0xFFFD: 0xB742,
	0xFFFD: 0xB743,
	0xFFFD: 0xB744,
	0xFFFD: 0xB745,
	0xFFFD: 0xB746,
	0xFFFD: 0xB747,
	0xFFFD: 0xB748,
	0xFFFD: 0xB749,
	0xFFFD: 0xB74A,
	0xFFFD: 0xB74B,
	0xFFFD: 0xB74C,
	0xFFFD: 0xB74D,
	0xFFFD: 0xB74E,
	0xFFFD: 0xB74F,
	0xFFFD: 0xB750,
	0xFFFD: 0xB751,
	0xFFFD: 0xB752,
	0xFFFD: 0xB753,
	0xFFFD: 0xB754,
	0xFFFD: 0xB755,
	0xFFFD: 0xB756,
	0xFFFD: 0xB757,
	0xFFFD: 0xB758,
	0xFFFD: 0xB759,
	0xFFFD: 0xB75A,
	0xFFFD: 0xB75B,
	0xFFFD: 0xB75C,
	0xFFFD: 0xB75D,
	0xFFFD: 0xB75E,
	0xFFFD: 0xB75F,
	0xFFFD: 0xB760,
	0xFFFD: 0xB761,
	0xFFFD: 0xB762,
	0xFFFD: 0xB763,
	0xFFFD: 0xB764,
	0xFFFD: 0xB765,
	0xFFFD: 0xB766,
	0xFFFD: 0xB767,
	0xFFFD: 0xB768,
	0xFFFD: 0xB769,
	0xFFFD: 0xB76A,
	0xFFFD: 0xB76B,
	0xFFFD: 0xB76C,
	0xFFFD: 0xB76D,
	0xFFFD: 0xB76E,
	0xFFFD: 0xB76F,
	0xFFFD: 0xB770,
	0xFFFD: 0xB771,
	0xFFFD: 0xB772,
	0xFFFD: 0xB773,
	0xFFFD: 0xB774,
	0xFFFD: 0xB775,
	0xFFFD: 0xB776,
	0xFFFD: 0xB777,
	0xFFFD: 0xB778,
	0xFFFD: 0xB779,
	0xFFFD: 0xB77A,
	0xFFFD: 0xB77B,
	0xFFFD: 0xB77C,
	0xFFFD: 0xB77D,
	0xFFFD: 0xB77E,
	0xFFFD: 0xB77F,
	0xFFFD: 0xB780,
	0xFFFD: 0xB781,
	0xFFFD: 0xB782,
	0xFFFD: 0xB783,
	0xFFFD: 0xB784,
	0xFFFD: 0xB785,
	0xFFFD: 0xB786,
	0xFFFD: 0xB787,
	0xFFFD: 0xB788,
	0xFFFD: 0xB789,
	0xFFFD: 0xB78A,
	0xFFFD: 0xB78B,
	0xFFFD: 0xB78C,
	0xFFFD: 0xB78D,
	0xFFFD: 0xB78E,
	0xFFFD: 0xB78F,
	0xFFFD: 0xB790,
	0xFFFD: 0xB791,
	0xFFFD: 0xB792,
	0xFFFD: 0xB793,
	0xFFFD: 0xB794,
	0xFFFD: 0xB795,
	0xFFFD: 0xB796,
	0xFFFD: 0xB797,
	0xFFFD: 0xB798,
	0xFFFD: 0xB799,
	0xFFFD: 0xB79A,
	0xFFFD: 0xB79B,
	0xFFFD: 0xB79C,
	0xFFFD: 0xB79D,
	0xFFFD: 0xB79E,
	0xFFFD: 0xB79F,
	0xFFFD: 0xB7A0,
	0xFFFD: 0xB7A1,
	0xFFFD: 0xB7A2,
	0xFFFD: 0xB7A3,
	0xFFFD: 0xB7A4,
	0xFFFD: 0xB7A5,
	0xFFFD: 0xB7A6,
	0xFFFD: 0xB7A7,
	0xFFFD: 0xB7A8,
	0xFFFD: 0xB7A9,
	0xFFFD: 0xB7AA,
	0xFFFD: 0xB7AB,
	0xFFFD: 0xB7AC,
	0xFFFD: 0xB7AD,
	0xFFFD: 0xB7AE,
	0xFFFD: 0xB7AF,
	0xFFFD: 0xB7B0,
	0xFFFD: 0xB7B1,
	0xFFFD: 0xB7B2,
	0xFFFD: 0xB7B3,
	0xFFFD: 0xB7B4,
	0xFFFD: 0xB7B5,
	0xFFFD: 0xB7B6,
	0xFFFD: 0xB7B7,
	0xFFFD: 0xB7B8,
	0xFFFD: 0xB7B9,
	0xFFFD: 0xB7BA,
	0xFFFD: 0xB7BB,
	0xFFFD: 0xB7BC,
	0xFFFD: 0xB7BD,
	0xFFFD: 0xB7BE,
	0xFFFD: 0xB7BF,
	0xFFFD: 0xB7C0,
	0xFFFD: 0xB7C1,
	0xFFFD: 0xB7C2,
	0xFFFD: 0xB7C3,
	0xFFFD: 0xB7C4,
	0xFFFD: 0xB7C5,
	0xFFFD: 0xB7C6,
	0xFFFD: 0xB7C7,
	0xFFFD: 0xB7C8,
	0xFFFD: 0xB7C9,
	0xFFFD: 0xB7CA,
	0xFFFD: 0xB7CB,
	0xFFFD: 0xB7CC,
	0xFFFD: 0xB7CD,
	0xFFFD: 0xB7CE,
	0xFFFD: 0xB7CF,
	0xFFFD: 0xB7D0,
	0xFFFD: 0xB7D1,
	0xFFFD: 0xB7D2,
	0xFFFD: 0xB7D3,
	0xFFFD: 0xB7D4,
	0xFFFD: 0xB7D5,
	0xFFFD: 0xB7D6,
	0xFFFD: 0xB7D7,
	0xFFFD: 0xB7D8,
	0xFFFD: 0xB7D9,
	0xFFFD: 0xB7DA,
	0xFFFD: 0xB7DB,
	0xFFFD: 0xB7DC,
	0xFFFD: 0xB7DD,
	0xFFFD: 0xB7DE,
	0xFFFD: 0xB7DF,
	0xFFFD: 0xB7E0,
	0xFFFD: 0xB7E1,
	0xFFFD: 0xB7E2,
	0xFFFD: 0xB7E3,
	0xFFFD: 0xB7E4,
	0xFFFD: 0xB7E5,
	0xFFFD: 0xB7E6,
	0xFFFD: 0xB7E7,
	0xFFFD: 0xB7E8,
	0xFFFD: 0xB7E9,
	0xFFFD: 0xB7EA,
	0xFFFD: 0xB7EB,
	0xFFFD: 0xB7EC,
	0xFFFD: 0xB7ED,
	0xFFFD: 0xB7EE,
	0xFFFD: 0xB7EF,
	0xFFFD: 0xB7F0,
	0xFFFD: 0xB7F1,
	0xFFFD: 0xB7F2,
	0xFFFD: 0xB7F3,
	0xFFFD: 0xB7F4,
	0xFFFD: 0xB7F5,
	0xFFFD: 0xB7F6,
	0xFFFD: 0xB7F7,
	0xFFFD: 0xB7F8,
	0xFFFD: 0xB7F9,
	0xFFFD: 0xB7FA,
	0xFFFD: 0xB7FB,
	0xFFFD: 0xB7FC,
	0xFFFD: 0xB7FD,
	0xFFFD: 0xB7FE,
	0xFFFD: 0xB7FF,
	0xFFFD: 0xB800,
	0xFFFD: 0xB801,
	0xFFFD: 0xB802,
	0xFFFD: 0xB803,
	0xFFFD: 0xB804,
	0xFFFD: 0xB805,
	0xFFFD: 0xB806,
	0xFFFD: 0xB807,
	0xFFFD: 0xB808,
	0xFFFD: 0xB809,
	0xFFFD: 0xB80A,
	0xFFFD: 0xB80B,
	0xFFFD: 0xB80C,
	0xFFFD: 0xB80D,
	0xFFFD: 0xB80E,
	0xFFFD: 0xB80F,
	0xFFFD: 0xB810,
	0xFFFD: 0xB811,
	0xFFFD: 0xB812,
	0xFFFD: 0xB813,
	0xFFFD: 0xB814,
	0xFFFD: 0xB815,
	0xFFFD: 0xB816,
	0xFFFD: 0xB817,
	0xFFFD: 0xB818,
	0xFFFD: 0xB819,
	0xFFFD: 0xB81A,
	0xFFFD: 0xB81B,
	0xFFFD: 0xB81C,
	0xFFFD: 0xB81D,
	0xFFFD: 0xB81E,
	0xFFFD: 0xB81F,
	0xFFFD: 0xB820,
	0xFFFD: 0xB821,
	0xFFFD: 0xB822,
	0xFFFD: 0xB823,
	0xFFFD: 0xB824,
	0xFFFD: 0xB825,
	0xFFFD: 0xB826,
	0xFFFD: 0xB827,
	0xFFFD: 0xB828,
	0xFFFD: 0xB829,
	0xFFFD: 0xB82A,
	0xFFFD: 0xB82B,
	0xFFFD: 0xB82C,
	0xFFFD: 0xB82D,
	0xFFFD: 0xB82E,
	0xFFFD: 0xB82F,
	0xFFFD: 0xB830,
	0xFFFD: 0xB831,
	0xFFFD: 0xB832,
	0xFFFD: 0xB833,
	0xFFFD: 0xB834,
	0xFFFD: 0xB835,
	0xFFFD: 0xB836,
	0xFFFD: 0xB837,
	0xFFFD: 0xB838,
	0xFFFD: 0xB839,
	0xFFFD: 0xB83A,
	0xFFFD: 0xB83B,
	0xFFFD: 0xB83C,
	0xFFFD: 0xB83D,
	0xFFFD: 0xB83E,
	0xFFFD: 0xB83F,
	0xFFFD: 0xB840,
	0xFFFD: 0xB841,
	0xFFFD: 0xB842,
	0xFFFD: 0xB843,
	0xFFFD: 0xB844,
	0xFFFD: 0xB845,
	0xFFFD: 0xB846,
	0xFFFD: 0xB847,
	0xFFFD: 0xB848,
	0xFFFD: 0xB849,
	0xFFFD: 0xB84A,
	0xFFFD: 0xB84B,
	0xFFFD: 0xB84C,
	0xFFFD: 0xB84D,
	0xFFFD: 0xB84E,
	0xFFFD: 0xB84F,
	0xFFFD: 0xB850,
	0xFFFD: 0xB851,
	0xFFFD: 0xB852,
	0xFFFD: 0xB853,
	0xFFFD: 0xB854,
	0xFFFD: 0xB855,
	0xFFFD: 0xB856,
	0xFFFD: 0xB857,
	0xFFFD: 0xB858,
	0xFFFD: 0xB859,
	0xFFFD: 0xB85A,
	0xFFFD: 0xB85B,
	0xFFFD: 0xB85C,
	0xFFFD: 0xB85D,
	0xFFFD: 0xB85E,
	0xFFFD: 0xB85F,
	0xFFFD: 0xB860,
	0xFFFD: 0xB861,
	0xFFFD: 0xB862,
	0xFFFD: 0xB863,
	0xFFFD: 0xB864,
	0xFFFD: 0xB865,
	0xFFFD: 0xB866,
	0xFFFD: 0xB867,
	0xFFFD: 0xB868,
	0xFFFD: 0xB869,
	0xFFFD: 0xB86A,
	0xFFFD: 0xB86B,
	0xFFFD: 0xB86C,
	0xFFFD: 0xB86D,
	0xFFFD: 0xB86E,
	0xFFFD: 0xB86F,
	0xFFFD: 0xB870,
	0xFFFD: 0xB871,
	0xFFFD: 0xB872,
	0xFFFD: 0xB873,
	0xFFFD: 0xB874,
	0xFFFD: 0xB875,
	0xFFFD: 0xB876,
	0xFFFD: 0xB877,
	0xFFFD: 0xB878,
	0xFFFD: 0xB879,
	0xFFFD: 0xB87A,
	0xFFFD: 0xB87B,
	0xFFFD: 0xB87C,
	0xFFFD: 0xB87D,
	0xFFFD: 0xB87E,
	0xFFFD: 0xB87F,
	0xFFFD: 0xB880,
	0xFFFD: 0xB881,
	0xFFFD: 0xB882,
	0xFFFD: 0xB883,
	0xFFFD: 0xB884,
	0xFFFD: 0xB885,
	0xFFFD: 0xB886,
	0xFFFD: 0xB887,
	0xFFFD: 0xB888,
	0xFFFD: 0xB889,
	0xFFFD: 0xB88A,
	0xFFFD: 0xB88B,
	0xFFFD: 0xB88C,
	0xFFFD: 0xB88D,
	0xFFFD: 0xB88E,
	0xFFFD: 0xB88F,
	0xFFFD: 0xB890,
	0xFFFD: 0xB891,
	0xFFFD: 0xB892,
	0xFFFD: 0xB893,
	0xFFFD: 0xB894,
	0xFFFD: 0xB895,
	0xFFFD: 0xB896,
	0xFFFD: 0xB897,
	0xFFFD: 0xB898,
	0xFFFD: 0xB899,
	0xFFFD: 0xB89A,
	0xFFFD: 0xB89B,
	0xFFFD: 0xB89C,
	0xFFFD: 0xB89D,
	0xFFFD: 0xB89E,
	0xFFFD: 0xB89F,
	0xFFFD: 0xB8A0,
	0xFFFD: 0xB8A1,
	0xFFFD: 0xB8A2,
	0xFFFD: 0xB8A3,
	0xFFFD: 0xB8A4,
	0xFFFD: 0xB8A5,
	0xFFFD: 0xB8A6,
	0xFFFD: 0xB8A7,
	0xFFFD: 0xB8A8,
	0xFFFD: 0xB8A9,
	0xFFFD: 0xB8AA,
	0xFFFD: 0xB8AB,
	0xFFFD: 0xB8AC,
	0xFFFD: 0xB8AD,
	0xFFFD: 0xB8AE,
	0xFFFD: 0xB8AF,
	0xFFFD: 0xB8B0,
	0xFFFD: 0xB8B1,
	0xFFFD: 0xB8B2,
	0xFFFD: 0xB8B3,
	0xFFFD: 0xB8B4,
	0xFFFD: 0xB8B5,
	0xFFFD: 0xB8B6,
	0xFFFD: 0xB8B7,
	0xFFFD: 0xB8B8,
	0xFFFD: 0xB8B9,
	0xFFFD: 0xB8BA,
	0xFFFD: 0xB8BB,
	0xFFFD: 0xB8BC,
	0xFFFD: 0xB8BD,
	0xFFFD: 0xB8BE,
	0xFFFD: 0xB8BF,
	0xFFFD: 0xB8C0,
	0xFFFD: 0xB8C1,
	0xFFFD: 0xB8C2,
	0xFFFD: 0xB8C3,
	0xFFFD: 0xB8C4,
	0xFFFD: 0xB8C5,
	0xFFFD: 0xB8C6,
	0xFFFD: 0xB8C7,
	0xFFFD: 0xB8C8,
	0xFFFD: 0xB8C9,
	0xFFFD: 0xB8CA,
	0xFFFD: 0xB8CB,
	0xFFFD: 0xB8CC,
	0xFFFD: 0xB8CD,
	0xFFFD: 0xB8CE,
	0xFFFD: 0xB8CF,
	0xFFFD: 0xB8D0,
	0xFFFD: 0xB8D1,
	0xFFFD: 0xB8D2,
	0xFFFD: 0xB8D3,
	0xFFFD: 0xB8D4,
	0xFFFD: 0xB8D5,
	0xFFFD: 0xB8D6,
	0xFFFD: 0xB8D7,
	0xFFFD: 0xB8D8,
	0xFFFD: 0xB8D9,
	0xFFFD: 0xB8DA,
	0xFFFD: 0xB8DB,
	0xFFFD: 0xB8DC,
	0xFFFD: 0xB8DD,
	0xFFFD: 0xB8DE,
	0xFFFD: 0xB8DF,
	0xFFFD: 0xB8E0,
	0xFFFD: 0xB8E1,
	0xFFFD: 0xB8E2,
	0xFFFD: 0xB8E3,
	0xFFFD: 0xB8E4,
	0xFFFD: 0xB8E5,
	0xFFFD: 0xB8E6,
	0xFFFD: 0xB8E7,
	0xFFFD: 0xB8E8,
	0xFFFD: 0xB8E9,
	0xFFFD: 0xB8EA,
	0xFFFD: 0xB8EB,
	0xFFFD: 0xB8EC,
	0xFFFD: 0xB8ED,
	0xFFFD: 0xB8EE,
	0xFFFD: 0xB8EF,
	0xFFFD: 0xB8F0,
	0xFFFD: 0xB8F1,
	0xFFFD: 0xB8F2,
	0xFFFD: 0xB8F3,
	0xFFFD: 0xB8F4,
	0xFFFD: 0xB8F5,
	0xFFFD: 0xB8F6,
	0xFFFD: 0xB8F7,
	0xFFFD: 0xB8F8,
	0xFFFD: 0xB8F9,
	0xFFFD: 0xB8FA,
	0xFFFD: 0xB8FB,
	0xFFFD: 0xB8FC,
	0xFFFD: 0xB8FD,
	0xFFFD: 0xB8FE,
	0xFFFD: 0xB8FF,
	0xFFFD: 0xB900,
	0xFFFD: 0xB901,
	0xFFFD: 0xB902,
	0xFFFD: 0xB903,
	0xFFFD: 0xB904,
	0xFFFD: 0xB905,
	0xFFFD: 0xB906,
	0xFFFD: 0xB907,
	0xFFFD: 0xB908,
	0xFFFD: 0xB909,
	0xFFFD: 0xB90A,
	0xFFFD: 0xB90B,
	0xFFFD: 0xB90C,
	0xFFFD: 0xB90D,
	0xFFFD: 0xB90E,
	0xFFFD: 0xB90F,
	0xFFFD: 0xB910,
	0xFFFD: 0xB911,
	0xFFFD: 0xB912,
	0xFFFD: 0xB913,
	0xFFFD: 0xB914,
	0xFFFD: 0xB915,
	0xFFFD: 0xB916,
	0xFFFD: 0xB917,
	0xFFFD: 0xB918,
	0xFFFD: 0xB919,
	0xFFFD: 0xB91A,
	0xFFFD: 0xB91B,
	0xFFFD: 0xB91C,
	0xFFFD: 0xB91D,
	0xFFFD: 0xB91E,
	0xFFFD: 0xB91F,
	0xFFFD: 0xB920,
	0xFFFD: 0xB921,
	0xFFFD: 0xB922,
	0xFFFD: 0xB923,
	0xFFFD: 0xB924,
	0xFFFD: 0xB925,
	0xFFFD: 0xB926,
	0xFFFD: 0xB927,
	0xFFFD: 0xB928,
	0xFFFD: 0xB929,
	0xFFFD: 0xB92A,
	0xFFFD: 0xB92B,
	0xFFFD: 0xB92C,
	0xFFFD: 0xB92D,
	0xFFFD: 0xB92E,
	0xFFFD: 0xB92F,
	0xFFFD: 0xB930,
	0xFFFD: 0xB931,
	0xFFFD: 0xB932,
	0xFFFD: 0xB933,
	0xFFFD: 0xB934,
	0xFFFD: 0xB935,
	0xFFFD: 0xB936,
	0xFFFD: 0xB937,
	0xFFFD: 0xB938,
	0xFFFD: 0xB939,
	0xFFFD: 0xB93A,
	0xFFFD: 0xB93B,
	0xFFFD: 0xB93C,
	0xFFFD: 0xB93D,
	0xFFFD: 0xB93E,
	0xFFFD: 0xB93F,
	0xFFFD: 0xB940,
	0xFFFD: 0xB941,
	0xFFFD: 0xB942,
	0xFFFD: 0xB943,
	0xFFFD: 0xB944,
	0xFFFD: 0xB945,
	0xFFFD: 0xB946,
	0xFFFD: 0xB947,
	0xFFFD: 0xB948,
	0xFFFD: 0xB949,
	0xFFFD: 0xB94A,
	0xFFFD: 0xB94B,
	0xFFFD: 0xB94C,
	0xFFFD: 0xB94D,
	0xFFFD: 0xB94E,
	0xFFFD: 0xB94F,
	0xFFFD: 0xB950,
	0xFFFD: 0xB951,
	0xFFFD: 0xB952,
	0xFFFD: 0xB953,
	0xFFFD: 0xB954,
	0xFFFD: 0xB955,
	0xFFFD: 0xB956,
	0xFFFD: 0xB957,
	0xFFFD: 0xB958,
	0xFFFD: 0xB959,
	0xFFFD: 0xB95A,
	0xFFFD: 0xB95B,
	0xFFFD: 0xB95C,
	0xFFFD: 0xB95D,
	0xFFFD: 0xB95E,
	0xFFFD: 0xB95F,
	0xFFFD: 0xB960,
	0xFFFD: 0xB961,
	0xFFFD: 0xB962,
	0xFFFD: 0xB963,
	0xFFFD: 0xB964,
	0xFFFD: 0xB965,
	0xFFFD: 0xB966,
	0xFFFD: 0xB967,
	0xFFFD: 0xB968,
	0xFFFD: 0xB969,
	0xFFFD: 0xB96A,
	0xFFFD: 0xB96B,
	0xFFFD: 0xB96C,
	0xFFFD: 0xB96D,
	0xFFFD: 0xB96E,
	0xFFFD: 0xB96F,
	0xFFFD: 0xB970,
	0xFFFD: 0xB971,
	0xFFFD: 0xB972,
	0xFFFD: 0xB973,
	0xFFFD: 0xB974,
	0xFFFD: 0xB975,
	0xFFFD: 0xB976,
	0xFFFD: 0xB977,
	0xFFFD: 0xB978,
	0xFFFD: 0xB979,
	0xFFFD: 0xB97A,
	0xFFFD: 0xB97B,
	0xFFFD: 0xB97C,
	0xFFFD: 0xB97D,
	0xFFFD: 0xB97E,
	0xFFFD: 0xB97F,
	0xFFFD: 0xB980,
	0xFFFD: 0xB981,
	0xFFFD: 0xB982,
	0xFFFD: 0xB983,
	0xFFFD: 0xB984,
	0xFFFD: 0xB985,
	0xFFFD: 0xB986,
	0xFFFD: 0xB987,
	0xFFFD: 0xB988,
	0xFFFD: 0xB989,
	0xFFFD: 0xB98A,
	0xFFFD: 0xB98B,
	0xFFFD: 0xB98C,
	0xFFFD: 0xB98D,
	0xFFFD: 0xB98E,
	0xFFFD: 0xB98F,
	0xFFFD: 0xB990,
	0xFFFD: 0xB991,
	0xFFFD: 0xB992,
	0xFFFD: 0xB993,
	0xFFFD: 0xB994,
	0xFFFD: 0xB995,
	0xFFFD: 0xB996,
	0xFFFD: 0xB997,
	0xFFFD: 0xB998,
	0xFFFD: 0xB999,
	0xFFFD: 0xB99A,
	0xFFFD: 0xB99B,
	0xFFFD: 0xB99C,
	0xFFFD: 0xB99D,
	0xFFFD: 0xB99E,
	0xFFFD: 0xB99F,
	0xFFFD: 0xB9A0,
	0xFFFD: 0xB9A1,
	0xFFFD: 0xB9A2,
	0xFFFD: 0xB9A3,
	0xFFFD: 0xB9A4,
	0xFFFD: 0xB9A5,
	0xFFFD: 0xB9A6,
	0xFFFD: 0xB9A7,
	0xFFFD: 0xB9A8,
	0xFFFD: 0xB9A9,
	0xFFFD: 0xB9AA,
	0xFFFD: 0xB9AB,
	0xFFFD: 0xB9AC,
	0xFFFD: 0xB9AD,
	0xFFFD: 0xB9AE,
	0xFFFD: 0xB9AF,
	0xFFFD: 0xB9B0,
	0xFFFD: 0xB9B1,
	0xFFFD: 0xB9B2,
	0xFFFD: 0xB9B3,
	0xFFFD: 0xB9B4,
	0xFFFD: 0xB9B5,
	0xFFFD: 0xB9B6,
	0xFFFD: 0xB9B7,
	0xFFFD: 0xB9B8,
	0xFFFD: 0xB9B9,
	0xFFFD: 0xB9BA,
	0xFFFD: 0xB9BB,
	0xFFFD: 0xB9BC,
	0xFFFD: 0xB9BD,
	0xFFFD: 0xB9BE,
	0xFFFD: 0xB9BF,
	0xFFFD: 0xB9C0,
	0xFFFD: 0xB9C1,
	0xFFFD: 0xB9C2,
	0xFFFD: 0xB9C3,
	0xFFFD: 0xB9C4,
	0xFFFD: 0xB9C5,
	0xFFFD: 0xB9C6,
	0xFFFD: 0xB9C7,
	0xFFFD: 0xB9C8,
	0xFFFD: 0xB9C9,
	0xFFFD: 0xB9CA,
	0xFFFD: 0xB9CB,
	0xFFFD: 0xB9CC,
	0xFFFD: 0xB9CD,
	0xFFFD: 0xB9CE,
	0xFFFD: 0xB9CF,
	0xFFFD: 0xB9D0,
	0xFFFD: 0xB9D1,
	0xFFFD: 0xB9D2,
	0xFFFD: 0xB9D3,
	0xFFFD: 0xB9D4,
	0xFFFD: 0xB9D5,
	0xFFFD: 0xB9D6,
	0xFFFD: 0xB9D7,
	0xFFFD: 0xB9D8,
	0xFFFD: 0xB9D9,
	0xFFFD: 0xB9DA,
	0xFFFD: 0xB9DB,
	0xFFFD: 0xB9DC,
	0xFFFD: 0xB9DD,
	0xFFFD: 0xB9DE,
	0xFFFD: 0xB9DF,
	0xFFFD: 0xB9E0,
	0xFFFD: 0xB9E1,
	0xFFFD: 0xB9E2,
	0xFFFD: 0xB9E3,
	0xFFFD: 0xB9E4,
	0xFFFD: 0xB9E5,
	0xFFFD: 0xB9E6,
	0xFFFD: 0xB9E7,
	0xFFFD: 0xB9E8,
	0xFFFD: 0xB9E9,
	0xFFFD: 0xB9EA,
	0xFFFD: 0xB9EB,
	0xFFFD: 0xB9EC,
	0xFFFD: 0xB9ED,
	0xFFFD: 0xB9EE,
	0xFFFD: 0xB9EF,
	0xFFFD: 0xB9F0,
	0xFFFD: 0xB9F1,
	0xFFFD: 0xB9F2,
	0xFFFD: 0xB9F3,
	0xFFFD: 0xB9F4,
	0xFFFD: 0xB9F5,
	0xFFFD: 0xB9F6,
	0xFFFD: 0xB9F7,
	0xFFFD: 0xB9F8,
	0xFFFD: 0xB9F9,
	0xFFFD: 0xB9FA,
	0xFFFD: 0xB9FB,
	0xFFFD: 0xB9FC,
	0xFFFD: 0xB9FD,
	0xFFFD: 0xB9FE,
	0xFFFD: 0xB9FF,
	0xFFFD: 0xBA00,
	0xFFFD: 0xBA01,
	0xFFFD: 0xBA02,
	0xFFFD: 0xBA03,
	0xFFFD: 0xBA04,
	0xFFFD: 0xBA05,
	0xFFFD: 0xBA06,
	0xFFFD: 0xBA07,
	0xFFFD: 0xBA08,
	0xFFFD: 0xBA09,
	0xFFFD: 0xBA0A,
	0xFFFD: 0xBA0B,
	0xFFFD: 0xBA0C,
	0xFFFD: 0xBA0D,
	0xFFFD: 0xBA0E,
	0xFFFD: 0xBA0F,
	0xFFFD: 0xBA10,
	0xFFFD: 0xBA11,
	0xFFFD: 0xBA12,
	0xFFFD: 0xBA13,
	0xFFFD: 0xBA14,
	0xFFFD: 0xBA15,
	0xFFFD: 0xBA16,
	0xFFFD: 0xBA17,
	0xFFFD: 0xBA18,
	0xFFFD: 0xBA19,
	0xFFFD: 0xBA1A,
	0xFFFD: 0xBA1B,
	0xFFFD: 0xBA1C,
	0xFFFD: 0xBA1D,
	0xFFFD: 0xBA1E,
	0xFFFD: 0xBA1F,
	0xFFFD: 0xBA20,
	0xFFFD: 0xBA21,
	0xFFFD: 0xBA22,
	0xFFFD: 0xBA23,
	0xFFFD: 0xBA24,
	0xFFFD: 0xBA25,
	0xFFFD: 0xBA26,
	0xFFFD: 0xBA27,
	0xFFFD: 0xBA28,
	0xFFFD: 0xBA29,
	0xFFFD: 0xBA2A,
	0xFFFD: 0xBA2B,
	0xFFFD: 0xBA2C,
	0xFFFD: 0xBA2D,
	0xFFFD: 0xBA2E,
	0xFFFD: 0xBA2F,
	0xFFFD: 0xBA30,
	0xFFFD: 0xBA31,
	0xFFFD: 0xBA32,
	0xFFFD: 0xBA33,
	0xFFFD: 0xBA34,
	0xFFFD: 0xBA35,
	0xFFFD: 0xBA36,
	0xFFFD: 0xBA37,
	0xFFFD: 0xBA38,
	0xFFFD: 0xBA39,
	0xFFFD: 0xBA3A,
	0xFFFD: 0xBA3B,
	0xFFFD: 0xBA3C,
	0xFFFD: 0xBA3D,
	0xFFFD: 0xBA3E,
	0xFFFD: 0xBA3F,
	0xFFFD: 0xBA40,
	0xFFFD: 0xBA41,
	0xFFFD: 0xBA42,
	0xFFFD: 0xBA43,
	0xFFFD: 0xBA44,
	0xFFFD: 0xBA45,
	0xFFFD: 0xBA46,
	0xFFFD: 0xBA47,
	0xFFFD: 0xBA48,
	0xFFFD: 0xBA49,
	0xFFFD: 0xBA4A,
	0xFFFD: 0xBA4B,
	0xFFFD: 0xBA4C,
	0xFFFD: 0xBA4D,
	0xFFFD: 0xBA4E,
	0xFFFD: 0xBA4F,
	0xFFFD: 0xBA50,
	0xFFFD: 0xBA51,
	0xFFFD: 0xBA52,
	0xFFFD: 0xBA53,
	0xFFFD: 0xBA54,
	0xFFFD: 0xBA55,
	0xFFFD: 0xBA56,
	0xFFFD: 0xBA57,
	0xFFFD: 0xBA58,
	0xFFFD: 0xBA59,
	0xFFFD: 0xBA5A,
	0xFFFD: 0xBA5B,
	0xFFFD: 0xBA5C,
	0xFFFD: 0xBA5D,
	0xFFFD: 0xBA5E,
	0xFFFD: 0xBA5F,
	0xFFFD: 0xBA60,
	0xFFFD: 0xBA61,
	0xFFFD: 0xBA62,
	0xFFFD: 0xBA63,
	0xFFFD: 0xBA64,
	0xFFFD: 0xBA65,
	0xFFFD: 0xBA66,
	0xFFFD: 0xBA67,
	0xFFFD: 0xBA68,
	0xFFFD: 0xBA69,
	0xFFFD: 0xBA6A,
	0xFFFD: 0xBA6B,
	0xFFFD: 0xBA6C,
	0xFFFD: 0xBA6D,
	0xFFFD: 0xBA6E,
	0xFFFD: 0xBA6F,
	0xFFFD: 0xBA70,
	0xFFFD: 0xBA71,
	0xFFFD: 0xBA72,
	0xFFFD: 0xBA73,
	0xFFFD: 0xBA74,
	0xFFFD: 0xBA75,
	0xFFFD: 0xBA76,
	0xFFFD: 0xBA77,
	0xFFFD: 0xBA78,
	0xFFFD: 0xBA79,
	0xFFFD: 0xBA7A,
	0xFFFD: 0xBA7B,
	0xFFFD: 0xBA7C,
	0xFFFD: 0xBA7D,
	0xFFFD: 0xBA7E,
	0xFFFD: 0xBA7F,
	0xFFFD: 0xBA80,
	0xFFFD: 0xBA81,
	0xFFFD: 0xBA82,
	0xFFFD: 0xBA83,
	0xFFFD: 0xBA84,
	0xFFFD: 0xBA85,
	0xFFFD: 0xBA86,
	0xFFFD: 0xBA87,
	0xFFFD: 0xBA88,
	0xFFFD: 0xBA89,
	0xFFFD: 0xBA8A,
	0xFFFD: 0xBA8B,
	0xFFFD: 0xBA8C,
	0xFFFD: 0xBA8D,
	0xFFFD: 0xBA8E,
	0xFFFD: 0xBA8F,
	0xFFFD: 0xBA90,
	0xFFFD: 0xBA91,
	0xFFFD: 0xBA92,
	0xFFFD: 0xBA93,
	0xFFFD: 0xBA94,
	0xFFFD: 0xBA95,
	0xFFFD: 0xBA96,
	0xFFFD: 0xBA97,
	0xFFFD: 0xBA98,
	0xFFFD: 0xBA99,
	0xFFFD: 0xBA9A,
	0xFFFD: 0xBA9B,
	0xFFFD: 0xBA9C,
	0xFFFD: 0xBA9D,
	0xFFFD: 0xBA9E,
	0xFFFD: 0xBA9F,
	0xFFFD: 0xBAA0,
	0xFFFD: 0xBAA1,
	0xFFFD: 0xBAA2,
	0xFFFD: 0xBAA3,
	0xFFFD: 0xBAA4,
	0xFFFD: 0xBAA5,
	0xFFFD: 0xBAA6,
	0xFFFD: 0xBAA7,
	0xFFFD: 0xBAA8,
	0xFFFD: 0xBAA9,
	0xFFFD: 0xBAAA,
	0xFFFD: 0xBAAB,
	0xFFFD: 0xBAAC,
	0xFFFD: 0xBAAD,
	0xFFFD: 0xBAAE,
	0xFFFD: 0xBAAF,
	0xFFFD: 0xBAB0,
	0xFFFD: 0xBAB1,
	0xFFFD: 0xBAB2,
	0xFFFD: 0xBAB3,
	0xFFFD: 0xBAB4,
	0xFFFD: 0xBAB5,
	0xFFFD: 0xBAB6,
	0xFFFD: 0xBAB7,
	0xFFFD: 0xBAB8,
	0xFFFD: 0xBAB9,
	0xFFFD: 0xBABA,
	0xFFFD: 0xBABB,
	0xFFFD: 0xBABC,
	0xFFFD: 0xBABD,
	0xFFFD: 0xBABE,
	0xFFFD: 0xBABF,
	0xFFFD: 0xBAC0,
	0xFFFD: 0xBAC1,
	0xFFFD: 0xBAC2,
	0xFFFD: 0xBAC3,
	0xFFFD: 0xBAC4,
	0xFFFD: 0xBAC5,
	0xFFFD: 0xBAC6,
	0xFFFD: 0xBAC7,
	0xFFFD: 0xBAC8,
	0xFFFD: 0xBAC9,
	0xFFFD: 0xBACA,
	0xFFFD: 0xBACB,
	0xFFFD: 0xBACC,
	0xFFFD: 0xBACD,
	0xFFFD: 0xBACE,
	0xFFFD: 0xBACF,
	0xFFFD: 0xBAD0,
	0xFFFD: 0xBAD1,
	0xFFFD: 0xBAD2,
	0xFFFD: 0xBAD3,
	0xFFFD: 0xBAD4,
	0xFFFD: 0xBAD5,
	0xFFFD: 0xBAD6,
	0xFFFD: 0xBAD7,
	0xFFFD: 0xBAD8,
	0xFFFD: 0xBAD9,
	0xFFFD: 0xBADA,
	0xFFFD: 0xBADB,
	0xFFFD: 0xBADC,
	0xFFFD: 0xBADD,
	0xFFFD: 0xBADE,
	0xFFFD: 0xBADF,
	0xFFFD: 0xBAE0,
	0xFFFD: 0xBAE1,
	0xFFFD: 0xBAE2,
	0xFFFD: 0xBAE3,
	0xFFFD: 0xBAE4,
	0xFFFD: 0xBAE5,
	0xFFFD: 0xBAE6,
	0xFFFD: 0xBAE7,
	0xFFFD: 0xBAE8,
	0xFFFD: 0xBAE9,
	0xFFFD: 0xBAEA,
	0xFFFD: 0xBAEB,
	0xFFFD: 0xBAEC,
	0xFFFD: 0xBAED,
	0xFFFD: 0xBAEE,
	0xFFFD: 0xBAEF,
	0xFFFD: 0xBAF0,
	0xFFFD: 0xBAF1,
	0xFFFD: 0xBAF2,
	0xFFFD: 0xBAF3,
	0xFFFD: 0xBAF4,
	0xFFFD: 0xBAF5,
	0xFFFD: 0xBAF6,
	0xFFFD: 0xBAF7,
	0xFFFD: 0xBAF8,
	0xFFFD: 0xBAF9,
	0xFFFD: 0xBAFA,
	0xFFFD: 0xBAFB,
	0xFFFD: 0xBAFC,
	0xFFFD: 0xBAFD,
	0xFFFD: 0xBAFE,
	0xFFFD: 0xBAFF,
	0xFFFD: 0xBB00,
	0xFFFD: 0xBB01,
	0xFFFD: 0xBB02,
	0xFFFD: 0xBB03,
	0xFFFD: 0xBB04,
	0xFFFD: 0xBB05,
	0xFFFD: 0xBB06,
	0xFFFD: 0xBB07,
	0xFFFD: 0xBB08,
	0xFFFD: 0xBB09,
	0xFFFD: 0xBB0A,
	0xFFFD: 0xBB0B,
	0xFFFD: 0xBB0C,
	0xFFFD: 0xBB0D,
	0xFFFD: 0xBB0E,
	0xFFFD: 0xBB0F,
	0xFFFD: 0xBB10,
	0xFFFD: 0xBB11,
	0xFFFD: 0xBB12,
	0xFFFD: 0xBB13,
	0xFFFD: 0xBB14,
	0xFFFD: 0xBB15,
	0xFFFD: 0xBB16,
	0xFFFD: 0xBB17,
	0xFFFD: 0xBB18,
	0xFFFD: 0xBB19,
	0xFFFD: 0xBB1A,
	0xFFFD: 0xBB1B,
	0xFFFD: 0xBB1C,
	0xFFFD: 0xBB1D,
	0xFFFD: 0xBB1E,
	0xFFFD: 0xBB1F,
	0xFFFD: 0xBB20,
	0xFFFD: 0xBB21,
	0xFFFD: 0xBB22,
	0xFFFD: 0xBB23,
	0xFFFD: 0xBB24,
	0xFFFD: 0xBB25,
	0xFFFD: 0xBB26,
	0xFFFD: 0xBB27,
	0xFFFD: 0xBB28,
	0xFFFD: 0xBB29,
	0xFFFD: 0xBB2A,
	0xFFFD: 0xBB2B,
	0xFFFD: 0xBB2C,
	0xFFFD: 0xBB2D,
	0xFFFD: 0xBB2E,
	0xFFFD: 0xBB2F,
	0xFFFD: 0xBB30,
	0xFFFD: 0xBB31,
	0xFFFD: 0xBB32,
	0xFFFD: 0xBB33,
	0xFFFD: 0xBB34,
	0xFFFD: 0xBB35,
	0xFFFD: 0xBB36,
	0xFFFD: 0xBB37,
	0xFFFD: 0xBB38,
	0xFFFD: 0xBB39,
	0xFFFD: 0xBB3A,
	0xFFFD: 0xBB3B,
	0xFFFD: 0xBB3C,
	0xFFFD: 0xBB3D,
	0xFFFD: 0xBB3E,
	0xFFFD: 0xBB3F,
	0xFFFD: 0xBB40,
	0xFFFD: 0xBB41,
	0xFFFD: 0xBB42,
	0xFFFD: 0xBB43,
	0xFFFD: 0xBB44,
	0xFFFD: 0xBB45,
	0xFFFD: 0xBB46,
	0xFFFD: 0xBB47,
	0xFFFD: 0xBB48,
	0xFFFD: 0xBB49,
	0xFFFD: 0xBB4A,
	0xFFFD: 0xBB4B,
	0xFFFD: 0xBB4C,
	0xFFFD: 0xBB4D,
	0xFFFD: 0xBB4E,
	0xFFFD: 0xBB4F,
	0xFFFD: 0xBB50,
	0xFFFD: 0xBB51,
	0xFFFD: 0xBB52,
	0xFFFD: 0xBB53,
	0xFFFD: 0xBB54,
	0xFFFD: 0xBB55,
	0xFFFD: 0xBB56,
	0xFFFD: 0xBB57,
	0xFFFD: 0xBB58,
	0xFFFD: 0xBB59,
	0xFFFD: 0xBB5A,
	0xFFFD: 0xBB5B,
	0xFFFD: 0xBB5C,
	0xFFFD: 0xBB5D,
	0xFFFD: 0xBB5E,
	0xFFFD: 0xBB5F,
	0xFFFD: 0xBB60,
	0xFFFD: 0xBB61,
	0xFFFD: 0xBB62,
	0xFFFD: 0xBB63,
	0xFFFD: 0xBB64,
	0xFFFD: 0xBB65,
	0xFFFD: 0xBB66,
	0xFFFD: 0xBB67,
	0xFFFD: 0xBB68,
	0xFFFD: 0xBB69,
	0xFFFD: 0xBB6A,
	0xFFFD: 0xBB6B,
	0xFFFD: 0xBB6C,
	0xFFFD: 0xBB6D,
	0xFFFD: 0xBB6E,
	0xFFFD: 0xBB6F,
	0xFFFD: 0xBB70,
	0xFFFD: 0xBB71,
	0xFFFD: 0xBB72,
	0xFFFD: 0xBB73,
	0xFFFD: 0xBB74,
	0xFFFD: 0xBB75,
	0xFFFD: 0xBB76,
	0xFFFD: 0xBB77,
	0xFFFD: 0xBB78,
	0xFFFD: 0xBB79,
	0xFFFD: 0xBB7A,
	0xFFFD: 0xBB7B,
	0xFFFD: 0xBB7C,
	0xFFFD: 0xBB7D,
	0xFFFD: 0xBB7E,
	0xFFFD: 0xBB7F,
	0xFFFD: 0xBB80,
	0xFFFD: 0xBB81,
	0xFFFD: 0xBB82,
	0xFFFD: 0xBB83,
	0xFFFD: 0xBB84,
	0xFFFD: 0xBB85,
	0xFFFD: 0xBB86,
	0xFFFD: 0xBB87,
	0xFFFD: 0xBB88,
	0xFFFD: 0xBB89,
	0xFFFD: 0xBB8A,
	0xFFFD: 0xBB8B,
	0xFFFD: 0xBB8C,
	0xFFFD: 0xBB8D,
	0xFFFD: 0xBB8E,
	0xFFFD: 0xBB8F,
	0xFFFD: 0xBB90,
	0xFFFD: 0xBB91,
	0xFFFD: 0xBB92,
	0xFFFD: 0xBB93,
	0xFFFD: 0xBB94,
	0xFFFD: 0xBB95,
	0xFFFD: 0xBB96,
	0xFFFD: 0xBB97,
	0xFFFD: 0xBB98,
	0xFFFD: 0xBB99,
	0xFFFD: 0xBB9A,
	0xFFFD: 0xBB9B,
	0xFFFD: 0xBB9C,
	0xFFFD: 0xBB9D,
	0xFFFD: 0xBB9E,
	0xFFFD: 0xBB9F,
	0xFFFD: 0xBBA0,
	0xFFFD: 0xBBA1,
	0xFFFD: 0xBBA2,
	0xFFFD: 0xBBA3,
	0xFFFD: 0xBBA4,
	0xFFFD: 0xBBA5,
	0xFFFD: 0xBBA6,
	0xFFFD: 0xBBA7,
	0xFFFD: 0xBBA8,
	0xFFFD: 0xBBA9,
	0xFFFD: 0xBBAA,
	0xFFFD: 0xBBAB,
	0xFFFD: 0xBBAC,
	0xFFFD: 0xBBAD,
	0xFFFD: 0xBBAE,
	0xFFFD: 0xBBAF,
	0xFFFD: 0xBBB0,
	0xFFFD: 0xBBB1,
	0xFFFD: 0xBBB2,
	0xFFFD: 0xBBB3,
	0xFFFD: 0xBBB4,
	0xFFFD: 0xBBB5,
	0xFFFD: 0xBBB6,
	0xFFFD: 0xBBB7,
	0xFFFD: 0xBBB8,
	0xFFFD: 0xBBB9,
	0xFFFD: 0xBBBA,
	0xFFFD: 0xBBBB,
	0xFFFD: 0xBBBC,
	0xFFFD: 0xBBBD,
	0xFFFD: 0xBBBE,
	0xFFFD: 0xBBBF,
	0xFFFD: 0xBBC0,
	0xFFFD: 0xBBC1,
	0xFFFD: 0xBBC2,
	0xFFFD: 0xBBC3,
	0xFFFD: 0xBBC4,
	0xFFFD: 0xBBC5,
	0xFFFD: 0xBBC6,
	0xFFFD: 0xBBC7,
	0xFFFD: 0xBBC8,
	0xFFFD: 0xBBC9,
	0xFFFD: 0xBBCA,
	0xFFFD: 0xBBCB,
	0xFFFD: 0xBBCC,
	0xFFFD: 0xBBCD,
	0xFFFD: 0xBBCE,
	0xFFFD: 0xBBCF,
	0xFFFD: 0xBBD0,
	0xFFFD: 0xBBD1,
	0xFFFD: 0xBBD2,
	0xFFFD: 0xBBD3,
	0xFFFD: 0xBBD4,
	0xFFFD: 0xBBD5,
	0xFFFD: 0xBBD6,
	0xFFFD: 0xBBD7,
	0xFFFD: 0xBBD8,
	0xFFFD: 0xBBD9,
	0xFFFD: 0xBBDA,
	0xFFFD: 0xBBDB,
	0xFFFD: 0xBBDC,
	0xFFFD: 0xBBDD,
	0xFFFD: 0xBBDE,
	0xFFFD: 0xBBDF,
	0xFFFD: 0xBBE0,
	0xFFFD: 0xBBE1,
	0xFFFD: 0xBBE2,
	0xFFFD: 0xBBE3,
	0xFFFD: 0xBBE4,
	0xFFFD: 0xBBE5,
	0xFFFD: 0xBBE6,
	0xFFFD: 0xBBE7,
	0xFFFD: 0xBBE8,
	0xFFFD: 0xBBE9,
	0xFFFD: 0xBBEA,
	0xFFFD: 0xBBEB,
	0xFFFD: 0xBBEC,
	0xFFFD: 0xBBED,
	0xFFFD: 0xBBEE,
	0xFFFD: 0xBBEF,
	0xFFFD: 0xBBF0,
	0xFFFD: 0xBBF1,
	0xFFFD: 0xBBF2,
	0xFFFD: 0xBBF3,
	0xFFFD: 0xBBF4,
	0xFFFD: 0xBBF5,
	0xFFFD: 0xBBF6,
	0xFFFD: 0xBBF7,
	0xFFFD: 0xBBF8,
	0xFFFD: 0xBBF9,
	0xFFFD: 0xBBFA,
	0xFFFD: 0xBBFB,
	0xFFFD: 0xBBFC,
	0xFFFD: 0xBBFD,
	0xFFFD: 0xBBFE,
	0xFFFD: 0xBBFF,
	0xFFFD: 0xBC00,
	0xFFFD: 0xBC01,
	0xFFFD: 0xBC02,
	0xFFFD: 0xBC03,
	0xFFFD: 0xBC04,
	0xFFFD: 0xBC05,
	0xFFFD: 0xBC06,
	0xFFFD: 0xBC07,
	0xFFFD: 0xBC08,
	0xFFFD: 0xBC09,
	0xFFFD: 0xBC0A,
	0xFFFD: 0xBC0B,
	0xFFFD: 0xBC0C,
	0xFFFD: 0xBC0D,
	0xFFFD: 0xBC0E,
	0xFFFD: 0xBC0F,
	0xFFFD: 0xBC10,
	0xFFFD: 0xBC11,
	0xFFFD: 0xBC12,
	0xFFFD: 0xBC13,
	0xFFFD: 0xBC14,
	0xFFFD: 0xBC15,
	0xFFFD: 0xBC16,
	0xFFFD: 0xBC17,
	0xFFFD: 0xBC18,
	0xFFFD: 0xBC19,
	0xFFFD: 0xBC1A,
	0xFFFD: 0xBC1B,
	0xFFFD: 0xBC1C,
	0xFFFD: 0xBC1D,
	0xFFFD: 0xBC1E,
	0xFFFD: 0xBC1F,
	0xFFFD: 0xBC20,
	0xFFFD: 0xBC21,
	0xFFFD: 0xBC22,
	0xFFFD: 0xBC23,
	0xFFFD: 0xBC24,
	0xFFFD: 0xBC25,
	0xFFFD: 0xBC26,
	0xFFFD: 0xBC27,
	0xFFFD: 0xBC28,
	0xFFFD: 0xBC29,
	0xFFFD: 0xBC2A,
	0xFFFD: 0xBC2B,
	0xFFFD: 0xBC2C,
	0xFFFD: 0xBC2D,
	0xFFFD: 0xBC2E,
	0xFFFD: 0xBC2F,
	0xFFFD: 0xBC30,
	0xFFFD: 0xBC31,
	0xFFFD: 0xBC32,
	0xFFFD: 0xBC33,
	0xFFFD: 0xBC34,
	0xFFFD: 0xBC35,
	0xFFFD: 0xBC36,
	0xFFFD: 0xBC37,
	0xFFFD: 0xBC38,
	0xFFFD: 0xBC39,
	0xFFFD: 0xBC3A,
	0xFFFD: 0xBC3B,
	0xFFFD: 0xBC3C,
	0xFFFD: 0xBC3D,
	0xFFFD: 0xBC3E,
	0xFFFD: 0xBC3F,
	0xFFFD: 0xBC40,
	0xFFFD: 0xBC41,
	0xFFFD: 0xBC42,
	0xFFFD: 0xBC43,
	0xFFFD: 0xBC44,
	0xFFFD: 0xBC45,
	0xFFFD: 0xBC46,
	0xFFFD: 0xBC47,
	0xFFFD: 0xBC48,
	0xFFFD: 0xBC49,
	0xFFFD: 0xBC4A,
	0xFFFD: 0xBC4B,
	0xFFFD: 0xBC4C,
	0xFFFD: 0xBC4D,
	0xFFFD: 0xBC4E,
	0xFFFD: 0xBC4F,
	0xFFFD: 0xBC50,
	0xFFFD: 0xBC51,
	0xFFFD: 0xBC52,
	0xFFFD: 0xBC53,
	0xFFFD: 0xBC54,
	0xFFFD: 0xBC55,
	0xFFFD: 0xBC56,
	0xFFFD: 0xBC57,
	0xFFFD: 0xBC58,
	0xFFFD: 0xBC59,
	0xFFFD: 0xBC5A,
	0xFFFD: 0xBC5B,
	0xFFFD: 0xBC5C,
	0xFFFD: 0xBC5D,
	0xFFFD: 0xBC5E,
	0xFFFD: 0xBC5F,
	0xFFFD: 0xBC60,
	0xFFFD: 0xBC61,
	0xFFFD: 0xBC62,
	0xFFFD: 0xBC63,
	0xFFFD: 0xBC64,
	0xFFFD: 0xBC65,
	0xFFFD: 0xBC66,
	0xFFFD: 0xBC67,
	0xFFFD: 0xBC68,
	0xFFFD: 0xBC69,
	0xFFFD: 0xBC6A,
	0xFFFD: 0xBC6B,
	0xFFFD: 0xBC6C,
	0xFFFD: 0xBC6D,
	0xFFFD: 0xBC6E,
	0xFFFD: 0xBC6F,
	0xFFFD: 0xBC70,
	0xFFFD: 0xBC71,
	0xFFFD: 0xBC72,
	0xFFFD: 0xBC73,
	0xFFFD: 0xBC74,
	0xFFFD: 0xBC75,
	0xFFFD: 0xBC76,
	0xFFFD: 0xBC77,
	0xFFFD: 0xBC78,
	0xFFFD: 0xBC79,
	0xFFFD: 0xBC7A,
	0xFFFD: 0xBC7B,
	0xFFFD: 0xBC7C,
	0xFFFD: 0xBC7D,
	0xFFFD: 0xBC7E,
	0xFFFD: 0xBC7F,
	0xFFFD: 0xBC80,
	0xFFFD: 0xBC81,
	0xFFFD: 0xBC82,
	0xFFFD: 0xBC83,
	0xFFFD: 0xBC84,
	0xFFFD: 0xBC85,
	0xFFFD: 0xBC86,
	0xFFFD: 0xBC87,
	0xFFFD: 0xBC88,
	0xFFFD: 0xBC89,
	0xFFFD: 0xBC8A,
	0xFFFD: 0xBC8B,
	0xFFFD: 0xBC8C,
	0xFFFD: 0xBC8D,
	0xFFFD: 0xBC8E,
	0xFFFD: 0xBC8F,
	0xFFFD: 0xBC90,
	0xFFFD: 0xBC91,
	0xFFFD: 0xBC92,
	0xFFFD: 0xBC93,
	0xFFFD: 0xBC94,
	0xFFFD: 0xBC95,
	0xFFFD: 0xBC96,
	0xFFFD: 0xBC97,
	0xFFFD: 0xBC98,
	0xFFFD: 0xBC99,
	0xFFFD: 0xBC9A,
	0xFFFD: 0xBC9B,
	0xFFFD: 0xBC9C,
	0xFFFD: 0xBC9D,
	0xFFFD: 0xBC9E,
	0xFFFD: 0xBC9F,
	0xFFFD: 0xBCA0,
	0xFFFD: 0xBCA1,
	0xFFFD: 0xBCA2,
	0xFFFD: 0xBCA3,
	0xFFFD: 0xBCA4,
	0xFFFD: 0xBCA5,
	0xFFFD: 0xBCA6,
	0xFFFD: 0xBCA7,
	0xFFFD: 0xBCA8,
	0xFFFD: 0xBCA9,
	0xFFFD: 0xBCAA,
	0xFFFD: 0xBCAB,
	0xFFFD: 0xBCAC,
	0xFFFD: 0xBCAD,
	0xFFFD: 0xBCAE,
	0xFFFD: 0xBCAF,
	0xFFFD: 0xBCB0,
	0xFFFD: 0xBCB1,
	0xFFFD: 0xBCB2,
	0xFFFD: 0xBCB3,
	0xFFFD: 0xBCB4,
	0xFFFD: 0xBCB5,
	0xFFFD: 0xBCB6,
	0xFFFD: 0xBCB7,
	0xFFFD: 0xBCB8,
	0xFFFD: 0xBCB9,
	0xFFFD: 0xBCBA,
	0xFFFD: 0xBCBB,
	0xFFFD: 0xBCBC,
	0xFFFD: 0xBCBD,
	0xFFFD: 0xBCBE,
	0xFFFD: 0xBCBF,
	0xFFFD: 0xBCC0,
	0xFFFD: 0xBCC1,
	0xFFFD: 0xBCC2,
	0xFFFD: 0xBCC3,
	0xFFFD: 0xBCC4,
	0xFFFD: 0xBCC5,
	0xFFFD: 0xBCC6,
	0xFFFD: 0xBCC7,
	0xFFFD: 0xBCC8,
	0xFFFD: 0xBCC9,
	0xFFFD: 0xBCCA,
	0xFFFD: 0xBCCB,
	0xFFFD: 0xBCCC,
	0xFFFD: 0xBCCD,
	0xFFFD: 0xBCCE,
	0xFFFD: 0xBCCF,
	0xFFFD: 0xBCD0,
	0xFFFD: 0xBCD1,
	0xFFFD: 0xBCD2,
	0xFFFD: 0xBCD3,
	0xFFFD: 0xBCD4,
	0xFFFD: 0xBCD5,
	0xFFFD: 0xBCD6,
	0xFFFD: 0xBCD7,
	0xFFFD: 0xBCD8,
	0xFFFD: 0xBCD9,
	0xFFFD: 0xBCDA,
	0xFFFD: 0xBCDB,
	0xFFFD: 0xBCDC,
	0xFFFD: 0xBCDD,
	0xFFFD: 0xBCDE,
	0xFFFD: 0xBCDF,
	0xFFFD: 0xBCE0,
	0xFFFD: 0xBCE1,
	0xFFFD: 0xBCE2,
	0xFFFD: 0xBCE3,
	0xFFFD: 0xBCE4,
	0xFFFD: 0xBCE5,
	0xFFFD: 0xBCE6,
	0xFFFD: 0xBCE7,
	0xFFFD: 0xBCE8,
	0xFFFD: 0xBCE9,
	0xFFFD: 0xBCEA,
	0xFFFD: 0xBCEB,
	0xFFFD: 0xBCEC,
	0xFFFD: 0xBCED,
	0xFFFD: 0xBCEE,
	0xFFFD: 0xBCEF,
	0xFFFD: 0xBCF0,
	0xFFFD: 0xBCF1,
	0xFFFD: 0xBCF2,
	0xFFFD: 0xBCF3,
	0xFFFD: 0xBCF4,
	0xFFFD: 0xBCF5,
	0xFFFD: 0xBCF6,
	0xFFFD: 0xBCF7,
	0xFFFD: 0xBCF8,
	0xFFFD: 0xBCF9,
	0xFFFD: 0xBCFA,
	0xFFFD: 0xBCFB,
	0xFFFD: 0xBCFC,
	0xFFFD: 0xBCFD,
	0xFFFD: 0xBCFE,
	0xFFFD: 0xBCFF,
	0xFFFD: 0xBD00,
	0xFFFD: 0xBD01,
	0xFFFD: 0xBD02,
	0xFFFD: 0xBD03,
	0xFFFD: 0xBD04,
	0xFFFD: 0xBD05,
	0xFFFD: 0xBD06,
	0xFFFD: 0xBD07,
	0xFFFD: 0xBD08,
	0xFFFD: 0xBD09,
	0xFFFD: 0xBD0A,
	0xFFFD: 0xBD0B,
	0xFFFD: 0xBD0C,
	0xFFFD: 0xBD0D,
	0xFFFD: 0xBD0E,
	0xFFFD: 0xBD0F,
	0xFFFD: 0xBD10,
	0xFFFD: 0xBD11,
	0xFFFD: 0xBD12,
	0xFFFD: 0xBD13,
	0xFFFD: 0xBD14,
	0xFFFD: 0xBD15,
	0xFFFD: 0xBD16,
	0xFFFD: 0xBD17,
	0xFFFD: 0xBD18,
	0xFFFD: 0xBD19,
	0xFFFD: 0xBD1A,
	0xFFFD: 0xBD1B,
	0xFFFD: 0xBD1C,
	0xFFFD: 0xBD1D,
	0xFFFD: 0xBD1E,
	0xFFFD: 0xBD1F,
	0xFFFD: 0xBD20,
	0xFFFD: 0xBD21,
	0xFFFD: 0xBD22,
	0xFFFD: 0xBD23,
	0xFFFD: 0xBD24,
	0xFFFD: 0xBD25,
	0xFFFD: 0xBD26,
	0xFFFD: 0xBD27,
	0xFFFD: 0xBD28,
	0xFFFD: 0xBD29,
	0xFFFD: 0xBD2A,
	0xFFFD: 0xBD2B,
	0xFFFD: 0xBD2C,
	0xFFFD: 0xBD2D,
	0xFFFD: 0xBD2E,
	0xFFFD: 0xBD2F,
	0xFFFD: 0xBD30,
	0xFFFD: 0xBD31,
	0xFFFD: 0xBD32,
	0xFFFD: 0xBD33,
	0xFFFD: 0xBD34,
	0xFFFD: 0xBD35,
	0xFFFD: 0xBD36,
	0xFFFD: 0xBD37,
	0xFFFD: 0xBD38,
	0xFFFD: 0xBD39,
	0xFFFD: 0xBD3A,
	0xFFFD: 0xBD3B,
	0xFFFD: 0xBD3C,
	0xFFFD: 0xBD3D,
	0xFFFD: 0xBD3E,
	0xFFFD: 0xBD3F,
	0xFFFD: 0xBD40,
	0xFFFD: 0xBD41,
	0xFFFD: 0xBD42,
	0xFFFD: 0xBD43,
	0xFFFD: 0xBD44,
	0xFFFD: 0xBD45,
	0xFFFD: 0xBD46,
	0xFFFD: 0xBD47,
	0xFFFD: 0xBD48,
	0xFFFD: 0xBD49,
	0xFFFD: 0xBD4A,
	0xFFFD: 0xBD4B,
	0xFFFD: 0xBD4C,
	0xFFFD: 0xBD4D,
	0xFFFD: 0xBD4E,
	0xFFFD: 0xBD4F,
	0xFFFD: 0xBD50,
	0xFFFD: 0xBD51,
	0xFFFD: 0xBD52,
	0xFFFD: 0xBD53,
	0xFFFD: 0xBD54,
	0xFFFD: 0xBD55,
	0xFFFD: 0xBD56,
	0xFFFD: 0xBD57,
	0xFFFD: 0xBD58,
	0xFFFD: 0xBD59,
	0xFFFD: 0xBD5A,
	0xFFFD: 0xBD5B,
	0xFFFD: 0xBD5C,
	0xFFFD: 0xBD5D,
	0xFFFD: 0xBD5E,
	0xFFFD: 0xBD5F,
	0xFFFD: 0xBD60,
	0xFFFD: 0xBD61,
	0xFFFD: 0xBD62,
	0xFFFD: 0xBD63,
	0xFFFD: 0xBD64,
	0xFFFD: 0xBD65,
	0xFFFD: 0xBD66,
	0xFFFD: 0xBD67,
	0xFFFD: 0xBD68,
	0xFFFD: 0xBD69,
	0xFFFD: 0xBD6A,
	0xFFFD: 0xBD6B,
	0xFFFD: 0xBD6C,
	0xFFFD: 0xBD6D,
	0xFFFD: 0xBD6E,
	0xFFFD: 0xBD6F,
	0xFFFD: 0xBD70,
	0xFFFD: 0xBD71,
	0xFFFD: 0xBD72,
	0xFFFD: 0xBD73,
	0xFFFD: 0xBD74,
	0xFFFD: 0xBD75,
	0xFFFD: 0xBD76,
	0xFFFD: 0xBD77,
	0xFFFD: 0xBD78,
	0xFFFD: 0xBD79,
	0xFFFD: 0xBD7A,
	0xFFFD: 0xBD7B,
	0xFFFD: 0xBD7C,
	0xFFFD: 0xBD7D,
	0xFFFD: 0xBD7E,
	0xFFFD: 0xBD7F,
	0xFFFD: 0xBD80,
	0xFFFD: 0xBD81,
	0xFFFD: 0xBD82,
	0xFFFD: 0xBD83,
	0xFFFD: 0xBD84,
	0xFFFD: 0xBD85,
	0xFFFD: 0xBD86,
	0xFFFD: 0xBD87,
	0xFFFD: 0xBD88,
	0xFFFD: 0xBD89,
	0xFFFD: 0xBD8A,
	0xFFFD: 0xBD8B,
	0xFFFD: 0xBD8C,
	0xFFFD: 0xBD8D,
	0xFFFD: 0xBD8E,
	0xFFFD: 0xBD8F,
	0xFFFD: 0xBD90,
	0xFFFD: 0xBD91,
	0xFFFD: 0xBD92,
	0xFFFD: 0xBD93,
	0xFFFD: 0xBD94,
	0xFFFD: 0xBD95,
	0xFFFD: 0xBD96,
	0xFFFD: 0xBD97,
	0xFFFD: 0xBD98,
	0xFFFD: 0xBD99,
	0xFFFD: 0xBD9A,
	0xFFFD: 0xBD9B,
	0xFFFD: 0xBD9C,
	0xFFFD: 0xBD9D,
	0xFFFD: 0xBD9E,
	0xFFFD: 0xBD9F,
	0xFFFD: 0xBDA0,
	0xFFFD: 0xBDA1,
	0xFFFD: 0xBDA2,
	0xFFFD: 0xBDA3,
	0xFFFD: 0xBDA4,
	0xFFFD: 0xBDA5,
	0xFFFD: 0xBDA6,
	0xFFFD: 0xBDA7,
	0xFFFD: 0xBDA8,
	0xFFFD: 0xBDA9,
	0xFFFD: 0xBDAA,
	0xFFFD: 0xBDAB,
	0xFFFD: 0xBDAC,
	0xFFFD: 0xBDAD,
	0xFFFD: 0xBDAE,
	0xFFFD: 0xBDAF,
	0xFFFD: 0xBDB0,
	0xFFFD: 0xBDB1,
	0xFFFD: 0xBDB2,
	0xFFFD: 0xBDB3,
	0xFFFD: 0xBDB4,
	0xFFFD: 0xBDB5,
	0xFFFD: 0xBDB6,
	0xFFFD: 0xBDB7,
	0xFFFD: 0xBDB8,
	0xFFFD: 0xBDB9,
	0xFFFD: 0xBDBA,
	0xFFFD: 0xBDBB,
	0xFFFD: 0xBDBC,
	0xFFFD: 0xBDBD,
	0xFFFD: 0xBDBE,
	0xFFFD: 0xBDBF,
	0xFFFD: 0xBDC0,
	0xFFFD: 0xBDC1,
	0xFFFD: 0xBDC2,
	0xFFFD: 0xBDC3,
	0xFFFD: 0xBDC4,
	0xFFFD: 0xBDC5,
	0xFFFD: 0xBDC6,
	0xFFFD: 0xBDC7,
	0xFFFD: 0xBDC8,
	0xFFFD: 0xBDC9,
	0xFFFD: 0xBDCA,
	0xFFFD: 0xBDCB,
	0xFFFD: 0xBDCC,
	0xFFFD: 0xBDCD,
	0xFFFD: 0xBDCE,
	0xFFFD: 0xBDCF,
	0xFFFD: 0xBDD0,
	0xFFFD: 0xBDD1,
	0xFFFD: 0xBDD2,
	0xFFFD: 0xBDD3,
	0xFFFD: 0xBDD4,
	0xFFFD: 0xBDD5,
	0xFFFD: 0xBDD6,
	0xFFFD: 0xBDD7,
	0xFFFD: 0xBDD8,
	0xFFFD: 0xBDD9,
	0xFFFD: 0xBDDA,
	0xFFFD: 0xBDDB,
	0xFFFD: 0xBDDC,
	0xFFFD: 0xBDDD,
	0xFFFD: 0xBDDE,
	0xFFFD: 0xBDDF,
	0xFFFD: 0xBDE0,
	0xFFFD: 0xBDE1,
	0xFFFD: 0xBDE2,
	0xFFFD: 0xBDE3,
	0xFFFD: 0xBDE4,
	0xFFFD: 0xBDE5,
	0xFFFD: 0xBDE6,
	0xFFFD: 0xBDE7,
	0xFFFD: 0xBDE8,
	0xFFFD: 0xBDE9,
	0xFFFD: 0xBDEA,
	0xFFFD: 0xBDEB,
	0xFFFD: 0xBDEC,
	0xFFFD: 0xBDED,
	0xFFFD: 0xBDEE,
	0xFFFD: 0xBDEF,
	0xFFFD: 0xBDF0,
	0xFFFD: 0xBDF1,
	0xFFFD: 0xBDF2,
	0xFFFD: 0xBDF3,
	0xFFFD: 0xBDF4,
	0xFFFD: 0xBDF5,
	0xFFFD: 0xBDF6,
	0xFFFD: 0xBDF7,
	0xFFFD: 0xBDF8,
	0xFFFD: 0xBDF9,
	0xFFFD: 0xBDFA,
	0xFFFD: 0xBDFB,
	0xFFFD: 0xBDFC,
	0xFFFD: 0xBDFD,
	0xFFFD: 0xBDFE,
	0xFFFD: 0xBDFF,
	0xFFFD: 0xBE00,
	0xFFFD: 0xBE01,
	0xFFFD: 0xBE02,
	0xFFFD: 0xBE03,
	0xFFFD: 0xBE04,
	0xFFFD: 0xBE05,
	0xFFFD: 0xBE06,
	0xFFFD: 0xBE07,
	0xFFFD: 0xBE08,
	0xFFFD: 0xBE09,
	0xFFFD: 0xBE0A,
	0xFFFD: 0xBE0B,
	0xFFFD: 0xBE0C,
	0xFFFD: 0xBE0D,
	0xFFFD: 0xBE0E,
	0xFFFD: 0xBE0F,
	0xFFFD: 0xBE10,
	0xFFFD: 0xBE11,
	0xFFFD: 0xBE12,
	0xFFFD: 0xBE13,
	0xFFFD: 0xBE14,
	0xFFFD: 0xBE15,
	0xFFFD: 0xBE16,
	0xFFFD: 0xBE17,
	0xFFFD: 0xBE18,
	0xFFFD: 0xBE19,
	0xFFFD: 0xBE1A,
	0xFFFD: 0xBE1B,
	0xFFFD: 0xBE1C,
	0xFFFD: 0xBE1D,
	0xFFFD: 0xBE1E,
	0xFFFD: 0xBE1F,
	0xFFFD: 0xBE20,
	0xFFFD: 0xBE21,
	0xFFFD: 0xBE22,
	0xFFFD: 0xBE23,
	0xFFFD: 0xBE24,
	0xFFFD: 0xBE25,
	0xFFFD: 0xBE26,
	0xFFFD: 0xBE27,
	0xFFFD: 0xBE28,
	0xFFFD: 0xBE29,
	0xFFFD: 0xBE2A,
	0xFFFD: 0xBE2B,
	0xFFFD: 0xBE2C,
	0xFFFD: 0xBE2D,
	0xFFFD: 0xBE2E,
	0xFFFD: 0xBE2F,
	0xFFFD: 0xBE30,
	0xFFFD: 0xBE31,
	0xFFFD: 0xBE32,
	0xFFFD: 0xBE33,
	0xFFFD: 0xBE34,
	0xFFFD: 0xBE35,
	0xFFFD: 0xBE36,
	0xFFFD: 0xBE37,
	0xFFFD: 0xBE38,
	0xFFFD: 0xBE39,
	0xFFFD: 0xBE3A,
	0xFFFD: 0xBE3B,
	0xFFFD: 0xBE3C,
	0xFFFD: 0xBE3D,
	0xFFFD: 0xBE3E,
	0xFFFD: 0xBE3F,
	0xFFFD: 0xBE40,
	0xFFFD: 0xBE41,
	0xFFFD: 0xBE42,
	0xFFFD: 0xBE43,
	0xFFFD: 0xBE44,
	0xFFFD: 0xBE45,
	0xFFFD: 0xBE46,
	0xFFFD: 0xBE47,
	0xFFFD: 0xBE48,
	0xFFFD: 0xBE49,
	0xFFFD: 0xBE4A,
	0xFFFD: 0xBE4B,
	0xFFFD: 0xBE4C,
	0xFFFD: 0xBE4D,
	0xFFFD: 0xBE4E,
	0xFFFD: 0xBE4F,
	0xFFFD: 0xBE50,
	0xFFFD: 0xBE51,
	0xFFFD: 0xBE52,
	0xFFFD: 0xBE53,
	0xFFFD: 0xBE54,
	0xFFFD: 0xBE55,
	0xFFFD: 0xBE56,
	0xFFFD: 0xBE57,
	0xFFFD: 0xBE58,
	0xFFFD: 0xBE59,
	0xFFFD: 0xBE5A,
	0xFFFD: 0xBE5B,
	0xFFFD: 0xBE5C,
	0xFFFD: 0xBE5D,
	0xFFFD: 0xBE5E,
	0xFFFD: 0xBE5F,
	0xFFFD: 0xBE60,
	0xFFFD: 0xBE61,
	0xFFFD: 0xBE62,
	0xFFFD: 0xBE63,
	0xFFFD: 0xBE64,
	0xFFFD: 0xBE65,
	0xFFFD: 0xBE66,
	0xFFFD: 0xBE67,
	0xFFFD: 0xBE68,
	0xFFFD: 0xBE69,
	0xFFFD: 0xBE6A,
	0xFFFD: 0xBE6B,
	0xFFFD: 0xBE6C,
	0xFFFD: 0xBE6D,
	0xFFFD: 0xBE6E,
	0xFFFD: 0xBE6F,
	0xFFFD: 0xBE70,
	0xFFFD: 0xBE71,
	0xFFFD: 0xBE72,
	0xFFFD: 0xBE73,
	0xFFFD: 0xBE74,
	0xFFFD: 0xBE75,
	0xFFFD: 0xBE76,
	0xFFFD: 0xBE77,
	0xFFFD: 0xBE78,
	0xFFFD: 0xBE79,
	0xFFFD: 0xBE7A,
	0xFFFD: 0xBE7B,
	0xFFFD: 0xBE7C,
	0xFFFD: 0xBE7D,
	0xFFFD: 0xBE7E,
	0xFFFD: 0xBE7F,
	0xFFFD: 0xBE80,
	0xFFFD: 0xBE81,
	0xFFFD: 0xBE82,
	0xFFFD: 0xBE83,
	0xFFFD: 0xBE84,
	0xFFFD: 0xBE85,
	0xFFFD: 0xBE86,
	0xFFFD: 0xBE87,
	0xFFFD: 0xBE88,
	0xFFFD: 0xBE89,
	0xFFFD: 0xBE8A,
	0xFFFD: 0xBE8B,
	0xFFFD: 0xBE8C,
	0xFFFD: 0xBE8D,
	0xFFFD: 0xBE8E,
	0xFFFD: 0xBE8F,
	0xFFFD: 0xBE90,
	0xFFFD: 0xBE91,
	0xFFFD: 0xBE92,
	0xFFFD: 0xBE93,
	0xFFFD: 0xBE94,
	0xFFFD: 0xBE95,
	0xFFFD: 0xBE96,
	0xFFFD: 0xBE97,
	0xFFFD: 0xBE98,
	0xFFFD: 0xBE99,
	0xFFFD: 0xBE9A,
	0xFFFD: 0xBE9B,
	0xFFFD: 0xBE9C,
	0xFFFD: 0xBE9D,
	0xFFFD: 0xBE9E,
	0xFFFD: 0xBE9F,
	0xFFFD: 0xBEA0,
	0xFFFD: 0xBEA1,
	0xFFFD: 0xBEA2,
	0xFFFD: 0xBEA3,
	0xFFFD: 0xBEA4,
	0xFFFD: 0xBEA5,
	0xFFFD: 0xBEA6,
	0xFFFD: 0xBEA7,
	0xFFFD: 0xBEA8,
	0xFFFD: 0xBEA9,
	0xFFFD: 0xBEAA,
	0xFFFD: 0xBEAB,
	0xFFFD: 0xBEAC,
	0xFFFD: 0xBEAD,
	0xFFFD: 0xBEAE,
	0xFFFD: 0xBEAF,
	0xFFFD: 0xBEB0,
	0xFFFD: 0xBEB1,
	0xFFFD: 0xBEB2,
	0xFFFD: 0xBEB3,
	0xFFFD: 0xBEB4,
	0xFFFD: 0xBEB5,
	0xFFFD: 0xBEB6,
	0xFFFD: 0xBEB7,
	0xFFFD: 0xBEB8,
	0xFFFD: 0xBEB9,
	0xFFFD: 0xBEBA,
	0xFFFD: 0xBEBB,
	0xFFFD: 0xBEBC,
	0xFFFD: 0xBEBD,
	0xFFFD: 0xBEBE,
	0xFFFD: 0xBEBF,
	0xFFFD: 0xBEC0,
	0xFFFD: 0xBEC1,
	0xFFFD: 0xBEC2,
	0xFFFD: 0xBEC3,
	0xFFFD: 0xBEC4,
	0xFFFD: 0xBEC5,
	0xFFFD: 0xBEC6,
	0xFFFD: 0xBEC7,
	0xFFFD: 0xBEC8,
	0xFFFD: 0xBEC9,
	0xFFFD: 0xBECA,
	0xFFFD: 0xBECB,
	0xFFFD: 0xBECC,
	0xFFFD: 0xBECD,
	0xFFFD: 0xBECE,
	0xFFFD: 0xBECF,
	0xFFFD: 0xBED0,
	0xFFFD: 0xBED1,
	0xFFFD: 0xBED2,
	0xFFFD: 0xBED3,
	0xFFFD: 0xBED4,
	0xFFFD: 0xBED5,
	0xFFFD: 0xBED6,
	0xFFFD: 0xBED7,
	0xFFFD: 0xBED8,
	0xFFFD: 0xBED9,
	0xFFFD: 0xBEDA,
	0xFFFD: 0xBEDB,
	0xFFFD: 0xBEDC,
	0xFFFD: 0xBEDD,
	0xFFFD: 0xBEDE,
	0xFFFD: 0xBEDF,
	0xFFFD: 0xBEE0,
	0xFFFD: 0xBEE1,
	0xFFFD: 0xBEE2,
	0xFFFD: 0xBEE3,
	0xFFFD: 0xBEE4,
	0xFFFD: 0xBEE5,
	0xFFFD: 0xBEE6,
	0xFFFD: 0xBEE7,
	0xFFFD: 0xBEE8,
	0xFFFD: 0xBEE9,
	0xFFFD: 0xBEEA,
	0xFFFD: 0xBEEB,
	0xFFFD: 0xBEEC,
	0xFFFD: 0xBEED,
	0xFFFD: 0xBEEE,
	0xFFFD: 0xBEEF,
	0xFFFD: 0xBEF0,
	0xFFFD: 0xBEF1,
	0xFFFD: 0xBEF2,
	0xFFFD: 0xBEF3,
	0xFFFD: 0xBEF4,
	0xFFFD: 0xBEF5,
	0xFFFD: 0xBEF6,
	0xFFFD: 0xBEF7,
	0xFFFD: 0xBEF8,
	0xFFFD: 0xBEF9,
	0xFFFD: 0xBEFA,
	0xFFFD: 0xBEFB,
	0xFFFD: 0xBEFC,
	0xFFFD: 0xBEFD,
	0xFFFD: 0xBEFE,
	0xFFFD: 0xBEFF,
	0xFFFD: 0xBF00,
	0xFFFD: 0xBF01,
	0xFFFD: 0xBF02,
	0xFFFD: 0xBF03,
	0xFFFD: 0xBF04,
	0xFFFD: 0xBF05,
	0xFFFD: 0xBF06,
	0xFFFD: 0xBF07,
	0xFFFD: 0xBF08,
	0xFFFD: 0xBF09,
	0xFFFD: 0xBF0A,
	0xFFFD: 0xBF0B,
	0xFFFD: 0xBF0C,
	0xFFFD: 0xBF0D,
	0xFFFD: 0xBF0E,
	0xFFFD: 0xBF0F,
	0xFFFD: 0xBF10,
	0xFFFD: 0xBF11,
	0xFFFD: 0xBF12,
	0xFFFD: 0xBF13,
	0xFFFD: 0xBF14,
	0xFFFD: 0xBF15,
	0xFFFD: 0xBF16,
	0xFFFD: 0xBF17,
	0xFFFD: 0xBF18,
	0xFFFD: 0xBF19,
	0xFFFD: 0xBF1A,
	0xFFFD: 0xBF1B,
	0xFFFD: 0xBF1C,
	0xFFFD: 0xBF1D,
	0xFFFD: 0xBF1E,
	0xFFFD: 0xBF1F,
	0xFFFD: 0xBF20,
	0xFFFD: 0xBF21,
	0xFFFD: 0xBF22,
	0xFFFD: 0xBF23,
	0xFFFD: 0xBF24,
	0xFFFD: 0xBF25,
	0xFFFD: 0xBF26,
	0xFFFD: 0xBF27,
	0xFFFD: 0xBF28,
	0xFFFD: 0xBF29,
	0xFFFD: 0xBF2A,
	0xFFFD: 0xBF2B,
	0xFFFD: 0xBF2C,
	0xFFFD: 0xBF2D,
	0xFFFD: 0xBF2E,
	0xFFFD: 0xBF2F,
	0xFFFD: 0xBF30,
	0xFFFD: 0xBF31,
	0xFFFD: 0xBF32,
	0xFFFD: 0xBF33,
	0xFFFD: 0xBF34,
	0xFFFD: 0xBF35,
	0xFFFD: 0xBF36,
	0xFFFD: 0xBF37,
	0xFFFD: 0xBF38,
	0xFFFD: 0xBF39,
	0xFFFD: 0xBF3A,
	0xFFFD: 0xBF3B,
	0xFFFD: 0xBF3C,
	0xFFFD: 0xBF3D,
	0xFFFD: 0xBF3E,
	0xFFFD: 0xBF3F,
	0xFFFD: 0xBF40,
	0xFFFD: 0xBF41,
	0xFFFD: 0xBF42,
	0xFFFD: 0xBF43,
	0xFFFD: 0xBF44,
	0xFFFD: 0xBF45,
	0xFFFD: 0xBF46,
	0xFFFD: 0xBF47,
	0xFFFD: 0xBF48,
	0xFFFD: 0xBF49,
	0xFFFD: 0xBF4A,
	0xFFFD: 0xBF4B,
	0xFFFD: 0xBF4C,
	0xFFFD: 0xBF4D,
	0xFFFD: 0xBF4E,
	0xFFFD: 0xBF4F,
	0xFFFD: 0xBF50,
	0xFFFD: 0xBF51,
	0xFFFD: 0xBF52,
	0xFFFD: 0xBF53,
	0xFFFD: 0xBF54,
	0xFFFD: 0xBF55,
	0xFFFD: 0xBF56,
	0xFFFD: 0xBF57,
	0xFFFD: 0xBF58,
	0xFFFD: 0xBF59,
	0xFFFD: 0xBF5A,
	0xFFFD: 0xBF5B,
	0xFFFD: 0xBF5C,
	0xFFFD: 0xBF5D,
	0xFFFD: 0xBF5E,
	0xFFFD: 0xBF5F,
	0xFFFD: 0xBF60,
	0xFFFD: 0xBF61,
	0xFFFD: 0xBF62,
	0xFFFD: 0xBF63,
	0xFFFD: 0xBF64,
	0xFFFD: 0xBF65,
	0xFFFD: 0xBF66,
	0xFFFD: 0xBF67,
	0xFFFD: 0xBF68,
	0xFFFD: 0xBF69,
	0xFFFD: 0xBF6A,
	0xFFFD: 0xBF6B,
	0xFFFD: 0xBF6C,
	0xFFFD: 0xBF6D,
	0xFFFD: 0xBF6E,
	0xFFFD: 0xBF6F,
	0xFFFD: 0xBF70,
	0xFFFD: 0xBF71,
	0xFFFD: 0xBF72,
	0xFFFD: 0xBF73,
	0xFFFD: 0xBF74,
	0xFFFD: 0xBF75,
	0xFFFD: 0xBF76,
	0xFFFD: 0xBF77,
	0xFFFD: 0xBF78,
	0xFFFD: 0xBF79,
	0xFFFD: 0xBF7A,
	0xFFFD: 0xBF7B,
	0xFFFD: 0xBF7C,
	0xFFFD: 0xBF7D,
	0xFFFD: 0xBF7E,
	0xFFFD: 0xBF7F,
	0xFFFD: 0xBF80,
	0xFFFD: 0xBF81,
	0xFFFD: 0xBF82,
	0xFFFD: 0xBF83,
	0xFFFD: 0xBF84,
	0xFFFD: 0xBF85,
	0xFFFD: 0xBF86,
	0xFFFD: 0xBF87,
	0xFFFD: 0xBF88,
	0xFFFD: 0xBF89,
	0xFFFD: 0xBF8A,
	0xFFFD: 0xBF8B,
	0xFFFD: 0xBF8C,
	0xFFFD: 0xBF8D,
	0xFFFD: 0xBF8E,
	0xFFFD: 0xBF8F,
	0xFFFD: 0xBF90,
	0xFFFD: 0xBF91,
	0xFFFD: 0xBF92,
	0xFFFD: 0xBF93,
	0xFFFD: 0xBF94,
	0xFFFD: 0xBF95,
	0xFFFD: 0xBF96,
	0xFFFD: 0xBF97,
	0xFFFD: 0xBF98,
	0xFFFD: 0xBF99,
	0xFFFD: 0xBF9A,
	0xFFFD: 0xBF9B,
	0xFFFD: 0xBF9C,
	0xFFFD: 0xBF9D,
	0xFFFD: 0xBF9E,
	0xFFFD: 0xBF9F,
	0xFFFD: 0xBFA0,
	0xFFFD: 0xBFA1,
	0xFFFD: 0xBFA2,
	0xFFFD: 0xBFA3,
	0xFFFD: 0xBFA4,
	0xFFFD: 0xBFA5,
	0xFFFD: 0xBFA6,
	0xFFFD: 0xBFA7,
	0xFFFD: 0xBFA8,
	0xFFFD: 0xBFA9,
	0xFFFD: 0xBFAA,
	0xFFFD: 0xBFAB,
	0xFFFD: 0xBFAC,
	0xFFFD: 0xBFAD,
	0xFFFD: 0xBFAE,
	0xFFFD: 0xBFAF,
	0xFFFD: 0xBFB0,
	0xFFFD: 0xBFB1,
	0xFFFD: 0xBFB2,
	0xFFFD: 0xBFB3,
	0xFFFD: 0xBFB4,
	0xFFFD: 0xBFB5,
	0xFFFD: 0xBFB6,
	0xFFFD: 0xBFB7,
	0xFFFD: 0xBFB8,
	0xFFFD: 0xBFB9,
	0xFFFD: 0xBFBA,
	0xFFFD: 0xBFBB,
	0xFFFD: 0xBFBC,
	0xFFFD: 0xBFBD,
	0xFFFD: 0xBFBE,
	0xFFFD: 0xBFBF,
	0xFFFD: 0xBFC0,
	0xFFFD: 0xBFC1,
	0xFFFD: 0xBFC2,
	0xFFFD: 0xBFC3,
	0xFFFD: 0xBFC4,
	0xFFFD: 0xBFC5,
	0xFFFD: 0xBFC6,
	0xFFFD: 0xBFC7,
	0xFFFD: 0xBFC8,
	0xFFFD: 0xBFC9,
	0xFFFD: 0xBFCA,
	0xFFFD: 0xBFCB,
	0xFFFD: 0xBFCC,
	0xFFFD: 0xBFCD,
	0xFFFD: 0xBFCE,
	0xFFFD: 0xBFCF,
	0xFFFD: 0xBFD0,
	0xFFFD: 0xBFD1,
	0xFFFD: 0xBFD2,
	0xFFFD: 0xBFD3,
	0xFFFD: 0xBFD4,
	0xFFFD: 0xBFD5,
	0xFFFD: 0xBFD6,
	0xFFFD: 0xBFD7,
	0xFFFD: 0xBFD8,
	0xFFFD: 0xBFD9,
	0xFFFD: 0xBFDA,
	0xFFFD: 0xBFDB,
	0xFFFD: 0xBFDC,
	0xFFFD: 0xBFDD,
	0xFFFD: 0xBFDE,
	0xFFFD: 0xBFDF,
	0xFFFD: 0xBFE0,
	0xFFFD: 0xBFE1,
	0xFFFD: 0xBFE2,
	0xFFFD: 0xBFE3,
	0xFFFD: 0xBFE4,
	0xFFFD: 0xBFE5,
	0xFFFD: 0xBFE6,
	0xFFFD: 0xBFE7,
	0xFFFD: 0xBFE8,
	0xFFFD: 0xBFE9,
	0xFFFD: 0xBFEA,
	0xFFFD: 0xBFEB,
	0xFFFD: 0xBFEC,
	0xFFFD: 0xBFED,
	0xFFFD: 0xBFEE,
	0xFFFD: 0xBFEF,
	0xFFFD: 0xBFF0,
	0xFFFD: 0xBFF1,
	0xFFFD: 0xBFF2,
	0xFFFD: 0xBFF3,
	0xFFFD: 0xBFF4,
	0xFFFD: 0xBFF5,
	0xFFFD: 0xBFF6,
	0xFFFD: 0xBFF7,
	0xFFFD: 0xBFF8,
	0xFFFD: 0xBFF9,
	0xFFFD: 0xBFFA,
	0xFFFD: 0xBFFB,
	0xFFFD: 0xBFFC,
	0xFFFD: 0xBFFD,
	0xFFFD: 0xBFFE,
	0xFFFD: 0xBFFF,
	0xFFFD: 0xC000,
	0xFFFD: 0xC001,
	0xFFFD: 0xC002,
	0xFFFD: 0xC003,
	0xFFFD: 0xC004,
	0xFFFD: 0xC005,
	0xFFFD: 0xC006,
	0xFFFD: 0xC007,
	0xFFFD: 0xC008,
	0xFFFD: 0xC009,
	0xFFFD: 0xC00A,
	0xFFFD: 0xC00B,
	0xFFFD: 0xC00C,
	0xFFFD: 0xC00D,
	0xFFFD: 0xC00E,
	0xFFFD: 0xC00F,
	0xFFFD: 0xC010,
	0xFFFD: 0xC011,
	0xFFFD: 0xC012,
	0xFFFD: 0xC013,
	0xFFFD: 0xC014,
	0xFFFD: 0xC015,
	0xFFFD: 0xC016,
	0xFFFD: 0xC017,
	0xFFFD: 0xC018,
	0xFFFD: 0xC019,
	0xFFFD: 0xC01A,
	0xFFFD: 0xC01B,
	0xFFFD: 0xC01C,
	0xFFFD: 0xC01D,
	0xFFFD: 0xC01E,
	0xFFFD: 0xC01F,
	0xFFFD: 0xC020,
	0xFFFD: 0xC021,
	0xFFFD: 0xC022,
	0xFFFD: 0xC023,
	0xFFFD: 0xC024,
	0xFFFD: 0xC025,
	0xFFFD: 0xC026,
	0xFFFD: 0xC027,
	0xFFFD: 0xC028,
	0xFFFD: 0xC029,
	0xFFFD: 0xC02A,
	0xFFFD: 0xC02B,
	0xFFFD: 0xC02C,
	0xFFFD: 0xC02D,
	0xFFFD: 0xC02E,
	0xFFFD: 0xC02F,
	0xFFFD: 0xC030,
	0xFFFD: 0xC031,
	0xFFFD: 0xC032,
	0xFFFD: 0xC033,
	0xFFFD: 0xC034,
	0xFFFD: 0xC035,
	0xFFFD: 0xC036,
	0xFFFD: 0xC037,
	0xFFFD: 0xC038,
	0xFFFD: 0xC039,
	0xFFFD: 0xC03A,
	0xFFFD: 0xC03B,
	0xFFFD: 0xC03C,
	0xFFFD: 0xC03D,
	0xFFFD: 0xC03E,
	0xFFFD: 0xC03F,
	0xFFFD: 0xC040,
	0xFFFD: 0xC041,
	0xFFFD: 0xC042,
	0xFFFD: 0xC043,
	0xFFFD: 0xC044,
	0xFFFD: 0xC045,
	0xFFFD: 0xC046,
	0xFFFD: 0xC047,
	0xFFFD: 0xC048,
	0xFFFD: 0xC049,
	0xFFFD: 0xC04A,
	0xFFFD: 0xC04B,
	0xFFFD: 0xC04C,
	0xFFFD: 0xC04D,
	0xFFFD: 0xC04E,
	0xFFFD: 0xC04F,
	0xFFFD: 0xC050,
	0xFFFD: 0xC051,
	0xFFFD: 0xC052,
	0xFFFD: 0xC053,
	0xFFFD: 0xC054,
	0xFFFD: 0xC055,
	0xFFFD: 0xC056,
	0xFFFD: 0xC057,
	0xFFFD: 0xC058,
	0xFFFD: 0xC059,
	0xFFFD: 0xC05A,
	0xFFFD: 0xC05B,
	0xFFFD: 0xC05C,
	0xFFFD: 0xC05D,
	0xFFFD: 0xC05E,
	0xFFFD: 0xC05F,
	0xFFFD: 0xC060,
	0xFFFD: 0xC061,
	0xFFFD: 0xC062,
	0xFFFD: 0xC063,
	0xFFFD: 0xC064,
	0xFFFD: 0xC065,
	0xFFFD: 0xC066,
	0xFFFD: 0xC067,
	0xFFFD: 0xC068,
	0xFFFD: 0xC069,
	0xFFFD: 0xC06A,
	0xFFFD: 0xC06B,
	0xFFFD: 0xC06C,
	0xFFFD: 0xC06D,
	0xFFFD: 0xC06E,
	0xFFFD: 0xC06F,
	0xFFFD: 0xC070,
	0xFFFD: 0xC071,
	0xFFFD: 0xC072,
	0xFFFD: 0xC073,
	0xFFFD: 0xC074,
	0xFFFD: 0xC075,
	0xFFFD: 0xC076,
	0xFFFD: 0xC077,
	0xFFFD: 0xC078,
	0xFFFD: 0xC079,
	0xFFFD: 0xC07A,
	0xFFFD: 0xC07B,
	0xFFFD: 0xC07C,
	0xFFFD: 0xC07D,
	0xFFFD: 0xC07E,
	0xFFFD: 0xC07F,
	0xFFFD: 0xC080,
	0xFFFD: 0xC081,
	0xFFFD: 0xC082,
	0xFFFD: 0xC083,
	0xFFFD: 0xC084,
	0xFFFD: 0xC085,
	0xFFFD: 0xC086,
	0xFFFD: 0xC087,
	0xFFFD: 0xC088,
	0xFFFD: 0xC089,
	0xFFFD: 0xC08A,
	0xFFFD: 0xC08B,
	0xFFFD: 0xC08C,
	0xFFFD: 0xC08D,
	0xFFFD: 0xC08E,
	0xFFFD: 0xC08F,
	0xFFFD: 0xC090,
	0xFFFD: 0xC091,
	0xFFFD: 0xC092,
	0xFFFD: 0xC093,
	0xFFFD: 0xC094,
	0xFFFD: 0xC095,
	0xFFFD: 0xC096,
	0xFFFD: 0xC097,
	0xFFFD: 0xC098,
	0xFFFD: 0xC099,
	0xFFFD: 0xC09A,
	0xFFFD: 0xC09B,
	0xFFFD: 0xC09C,
	0xFFFD: 0xC09D,
	0xFFFD: 0xC09E,
	0xFFFD: 0xC09F,
	0xFFFD: 0xC0A0,
	0xFFFD: 0xC0A1,
	0xFFFD: 0xC0A2,
	0xFFFD: 0xC0A3,
	0xFFFD: 0xC0A4,
	0xFFFD: 0xC0A5,
	0xFFFD: 0xC0A6,
	0xFFFD: 0xC0A7,
	0xFFFD: 0xC0A8,
	0xFFFD: 0xC0A9,
	0xFFFD: 0xC0AA,
	0xFFFD: 0xC0AB,
	0xFFFD: 0xC0AC,
	0xFFFD: 0xC0AD,
	0xFFFD: 0xC0AE,
	0xFFFD: 0xC0AF,
	0xFFFD: 0xC0B0,
	0xFFFD: 0xC0B1,
	0xFFFD: 0xC0B2,
	0xFFFD: 0xC0B3,
	0xFFFD: 0xC0B4,
	0xFFFD: 0xC0B5,
	0xFFFD: 0xC0B6,
	0xFFFD: 0xC0B7,
	0xFFFD: 0xC0B8,
	0xFFFD: 0xC0B9,
	0xFFFD: 0xC0BA,
	0xFFFD: 0xC0BB,
	0xFFFD: 0xC0BC,
	0xFFFD: 0xC0BD,
	0xFFFD: 0xC0BE,
	0xFFFD: 0xC0BF,
	0xFFFD: 0xC0C0,
	0xFFFD: 0xC0C1,
	0xFFFD: 0xC0C2,
	0xFFFD: 0xC0C3,
	0xFFFD: 0xC0C4,
	0xFFFD: 0xC0C5,
	0xFFFD: 0xC0C6,
	0xFFFD: 0xC0C7,
	0xFFFD: 0xC0C8,
	0xFFFD: 0xC0C9,
	0xFFFD: 0xC0CA,
	0xFFFD: 0xC0CB,
	0xFFFD: 0xC0CC,
	0xFFFD: 0xC0CD,
	0xFFFD: 0xC0CE,
	0xFFFD: 0xC0CF,
	0xFFFD: 0xC0D0,
	0xFFFD: 0xC0D1,
	0xFFFD: 0xC0D2,
	0xFFFD: 0xC0D3,
	0xFFFD: 0xC0D4,
	0xFFFD: 0xC0D5,
	0xFFFD: 0xC0D6,
	0xFFFD: 0xC0D7,
	0xFFFD: 0xC0D8,
	0xFFFD: 0xC0D9,
	0xFFFD: 0xC0DA,
	0xFFFD: 0xC0DB,
	0xFFFD: 0xC0DC,
	0xFFFD: 0xC0DD,
	0xFFFD: 0xC0DE,
	0xFFFD: 0xC0DF,
	0xFFFD: 0xC0E0,
	0xFFFD: 0xC0E1,
	0xFFFD: 0xC0E2,
	0xFFFD: 0xC0E3,
	0xFFFD: 0xC0E4,
	0xFFFD: 0xC0E5,
	0xFFFD: 0xC0E6,
	0xFFFD: 0xC0E7,
	0xFFFD: 0xC0E8,
	0xFFFD: 0xC0E9,
	0xFFFD: 0xC0EA,
	0xFFFD: 0xC0EB,
	0xFFFD: 0xC0EC,
	0xFFFD: 0xC0ED,
	0xFFFD: 0xC0EE,
	0xFFFD: 0xC0EF,
	0xFFFD: 0xC0F0,
	0xFFFD: 0xC0F1,
	0xFFFD: 0xC0F2,
	0xFFFD: 0xC0F3,
	0xFFFD: 0xC0F4,
	0xFFFD: 0xC0F5,
	0xFFFD: 0xC0F6,
	0xFFFD: 0xC0F7,
	0xFFFD: 0xC0F8,
	0xFFFD: 0xC0F9,
	0xFFFD: 0xC0FA,
	0xFFFD: 0xC0FB,
	0xFFFD: 0xC0FC,
	0xFFFD: 0xC0FD,
	0xFFFD: 0xC0FE,
	0xFFFD: 0xC0FF,
	0xFFFD: 0xC100,
	0xFFFD: 0xC101,
	0xFFFD: 0xC102,
	0xFFFD: 0xC103,
	0xFFFD: 0xC104,
	0xFFFD: 0xC105,
	0xFFFD: 0xC106,
	0xFFFD: 0xC107,
	0xFFFD: 0xC108,
	0xFFFD: 0xC109,
	0xFFFD: 0xC10A,
	0xFFFD: 0xC10B,
	0xFFFD: 0xC10C,
	0xFFFD: 0xC10D,
	0xFFFD: 0xC10E,
	0xFFFD: 0xC10F,
	0xFFFD: 0xC110,
	0xFFFD: 0xC111,
	0xFFFD: 0xC112,
	0xFFFD: 0xC113,
	0xFFFD: 0xC114,
	0xFFFD: 0xC115,
	0xFFFD: 0xC116,
	0xFFFD: 0xC117,
	0xFFFD: 0xC118,
	0xFFFD: 0xC119,
	0xFFFD: 0xC11A,
	0xFFFD: 0xC11B,
	0xFFFD: 0xC11C,
	0xFFFD: 0xC11D,
	0xFFFD: 0xC11E,
	0xFFFD: 0xC11F,
	0xFFFD: 0xC120,
	0xFFFD: 0xC121,
	0xFFFD: 0xC122,
	0xFFFD: 0xC123,
	0xFFFD: 0xC124,
	0xFFFD: 0xC125,
	0xFFFD: 0xC126,
	0xFFFD: 0xC127,
	0xFFFD: 0xC128,
	0xFFFD: 0xC129,
	0xFFFD: 0xC12A,
	0xFFFD: 0xC12B,
	0xFFFD: 0xC12C,
	0xFFFD: 0xC12D,
	0xFFFD: 0xC12E,
	0xFFFD: 0xC12F,
	0xFFFD: 0xC130,
	0xFFFD: 0xC131,
	0xFFFD: 0xC132,
	0xFFFD: 0xC133,
	0xFFFD: 0xC134,
	0xFFFD: 0xC135,
	0xFFFD: 0xC136,
	0xFFFD: 0xC137,
	0xFFFD: 0xC138,
	0xFFFD: 0xC139,
	0xFFFD: 0xC13A,
	0xFFFD: 0xC13B,
	0xFFFD: 0xC13C,
	0xFFFD: 0xC13D,
	0xFFFD: 0xC13E,
	0xFFFD: 0xC13F,
	0xFFFD: 0xC140,
	0xFFFD: 0xC141,
	0xFFFD: 0xC142,
	0xFFFD: 0xC143,
	0xFFFD: 0xC144,
	0xFFFD: 0xC145,
	0xFFFD: 0xC146,
	0xFFFD: 0xC147,
	0xFFFD: 0xC148,
	0xFFFD: 0xC149,
	0xFFFD: 0xC14A,
	0xFFFD: 0xC14B,
	0xFFFD: 0xC14C,
	0xFFFD: 0xC14D,
	0xFFFD: 0xC14E,
	0xFFFD: 0xC14F,
	0xFFFD: 0xC150,
	0xFFFD: 0xC151,
	0xFFFD: 0xC152,
	0xFFFD: 0xC153,
	0xFFFD: 0xC154,
	0xFFFD: 0xC155,
	0xFFFD: 0xC156,
	0xFFFD: 0xC157,
	0xFFFD: 0xC158,
	0xFFFD: 0xC159,
	0xFFFD: 0xC15A,
	0xFFFD: 0xC15B,
	0xFFFD: 0xC15C,
	0xFFFD: 0xC15D,
	0xFFFD: 0xC15E,
	0xFFFD: 0xC15F,
	0xFFFD: 0xC160,
	0xFFFD: 0xC161,
	0xFFFD: 0xC162,
	0xFFFD: 0xC163,
	0xFFFD: 0xC164,
	0xFFFD: 0xC165,
	0xFFFD: 0xC166,
	0xFFFD: 0xC167,
	0xFFFD: 0xC168,
	0xFFFD: 0xC169,
	0xFFFD: 0xC16A,
	0xFFFD: 0xC16B,
	0xFFFD: 0xC16C,
	0xFFFD: 0xC16D,
	0xFFFD: 0xC16E,
	0xFFFD: 0xC16F,
	0xFFFD: 0xC170,
	0xFFFD: 0xC171,
	0xFFFD: 0xC172,
	0xFFFD: 0xC173,
	0xFFFD: 0xC174,
	0xFFFD: 0xC175,
	0xFFFD: 0xC176,
	0xFFFD: 0xC177,
	0xFFFD: 0xC178,
	0xFFFD: 0xC179,
	0xFFFD: 0xC17A,
	0xFFFD: 0xC17B,
	0xFFFD: 0xC17C,
	0xFFFD: 0xC17D,
	0xFFFD: 0xC17E,
	0xFFFD: 0xC17F,
	0xFFFD: 0xC180,
	0xFFFD: 0xC181,
	0xFFFD: 0xC182,
	0xFFFD: 0xC183,
	0xFFFD: 0xC184,
	0xFFFD: 0xC185,
	0xFFFD: 0xC186,
	0xFFFD: 0xC187,
	0xFFFD: 0xC188,
	0xFFFD: 0xC189,
	0xFFFD: 0xC18A,
	0xFFFD: 0xC18B,
	0xFFFD: 0xC18C,
	0xFFFD: 0xC18D,
	0xFFFD: 0xC18E,
	0xFFFD: 0xC18F,
	0xFFFD: 0xC190,
	0xFFFD: 0xC191,
	0xFFFD: 0xC192,
	0xFFFD: 0xC193,
	0xFFFD: 0xC194,
	0xFFFD: 0xC195,
	0xFFFD: 0xC196,
	0xFFFD: 0xC197,
	0xFFFD: 0xC198,
	0xFFFD: 0xC199,
	0xFFFD: 0xC19A,
	0xFFFD: 0xC19B,
	0xFFFD: 0xC19C,
	0xFFFD: 0xC19D,
	0xFFFD: 0xC19E,
	0xFFFD: 0xC19F,
	0xFFFD: 0xC1A0,
	0xFFFD: 0xC1A1,
	0xFFFD: 0xC1A2,
	0xFFFD: 0xC1A3,
	0xFFFD: 0xC1A4,
	0xFFFD: 0xC1A5,
	0xFFFD: 0xC1A6,
	0xFFFD: 0xC1A7,
	0xFFFD: 0xC1A8,
	0xFFFD: 0xC1A9,
	0xFFFD: 0xC1AA,
	0xFFFD: 0xC1AB,
	0xFFFD: 0xC1AC,
	0xFFFD: 0xC1AD,
	0xFFFD: 0xC1AE,
	0xFFFD: 0xC1AF,
	0xFFFD: 0xC1B0,
	0xFFFD: 0xC1B1,
	0xFFFD: 0xC1B2,
	0xFFFD: 0xC1B3,
	0xFFFD: 0xC1B4,
	0xFFFD: 0xC1B5,
	0xFFFD: 0xC1B6,
	0xFFFD: 0xC1B7,
	0xFFFD: 0xC1B8,
	0xFFFD: 0xC1B9,
	0xFFFD: 0xC1BA,
	0xFFFD: 0xC1BB,
	0xFFFD: 0xC1BC,
	0xFFFD: 0xC1BD,
	0xFFFD: 0xC1BE,
	0xFFFD: 0xC1BF,
	0xFFFD: 0xC1C0,
	0xFFFD: 0xC1C1,
	0xFFFD: 0xC1C2,
	0xFFFD: 0xC1C3,
	0xFFFD: 0xC1C4,
	0xFFFD: 0xC1C5,
	0xFFFD: 0xC1C6,
	0xFFFD: 0xC1C7,
	0xFFFD: 0xC1C8,
	0xFFFD: 0xC1C9,
	0xFFFD: 0xC1CA,
	0xFFFD: 0xC1CB,
	0xFFFD: 0xC1CC,
	0xFFFD: 0xC1CD,
	0xFFFD: 0xC1CE,
	0xFFFD: 0xC1CF,
	0xFFFD: 0xC1D0,
	0xFFFD: 0xC1D1,
	0xFFFD: 0xC1D2,
	0xFFFD: 0xC1D3,
	0xFFFD: 0xC1D4,
	0xFFFD: 0xC1D5,
	0xFFFD: 0xC1D6,
	0xFFFD: 0xC1D7,
	0xFFFD: 0xC1D8,
	0xFFFD: 0xC1D9,
	0xFFFD: 0xC1DA,
	0xFFFD: 0xC1DB,
	0xFFFD: 0xC1DC,
	0xFFFD: 0xC1DD,
	0xFFFD: 0xC1DE,
	0xFFFD: 0xC1DF,
	0xFFFD: 0xC1E0,
	0xFFFD: 0xC1E1,
	0xFFFD: 0xC1E2,
	0xFFFD: 0xC1E3,
	0xFFFD: 0xC1E4,
	0xFFFD: 0xC1E5,
	0xFFFD: 0xC1E6,
	0xFFFD: 0xC1E7,
	0xFFFD: 0xC1E8,
	0xFFFD: 0xC1E9,
	0xFFFD: 0xC1EA,
	0xFFFD: 0xC1EB,
	0xFFFD: 0xC1EC,
	0xFFFD: 0xC1ED,
	0xFFFD: 0xC1EE,
	0xFFFD: 0xC1EF,
	0xFFFD: 0xC1F0,
	0xFFFD: 0xC1F1,
	0xFFFD: 0xC1F2,
	0xFFFD: 0xC1F3,
	0xFFFD: 0xC1F4,
	0xFFFD: 0xC1F5,
	0xFFFD: 0xC1F6,
	0xFFFD: 0xC1F7,
	0xFFFD: 0xC1F8,
	0xFFFD: 0xC1F9,
	0xFFFD: 0xC1FA,
	0xFFFD: 0xC1FB,
	0xFFFD: 0xC1FC,
	0xFFFD: 0xC1FD,
	0xFFFD: 0xC1FE,
	0xFFFD: 0xC1FF,
	0xFFFD: 0xC200,
	0xFFFD: 0xC201,
	0xFFFD: 0xC202,
	0xFFFD: 0xC203,
	0xFFFD: 0xC204,
	0xFFFD: 0xC205,
	0xFFFD: 0xC206,
	0xFFFD: 0xC207,
	0xFFFD: 0xC208,
	0xFFFD: 0xC209,
	0xFFFD: 0xC20A,
	0xFFFD: 0xC20B,
	0xFFFD: 0xC20C,
	0xFFFD: 0xC20D,
	0xFFFD: 0xC20E,
	0xFFFD: 0xC20F,
	0xFFFD: 0xC210,
	0xFFFD: 0xC211,
	0xFFFD: 0xC212,
	0xFFFD: 0xC213,
	0xFFFD: 0xC214,
	0xFFFD: 0xC215,
	0xFFFD: 0xC216,
	0xFFFD: 0xC217,
	0xFFFD: 0xC218,
	0xFFFD: 0xC219,
	0xFFFD: 0xC21A,
	0xFFFD: 0xC21B,
	0xFFFD: 0xC21C,
	0xFFFD: 0xC21D,
	0xFFFD: 0xC21E,
	0xFFFD: 0xC21F,
	0xFFFD: 0xC220,
	0xFFFD: 0xC221,
	0xFFFD: 0xC222,
	0xFFFD: 0xC223,
	0xFFFD: 0xC224,
	0xFFFD: 0xC225,
	0xFFFD: 0xC226,
	0xFFFD: 0xC227,
	0xFFFD: 0xC228,
	0xFFFD: 0xC229,
	0xFFFD: 0xC22A,
	0xFFFD: 0xC22B,
	0xFFFD: 0xC22C,
	0xFFFD: 0xC22D,
	0xFFFD: 0xC22E,
	0xFFFD: 0xC22F,
	0xFFFD: 0xC230,
	0xFFFD: 0xC231,
	0xFFFD: 0xC232,
	0xFFFD: 0xC233,
	0xFFFD: 0xC234,
	0xFFFD: 0xC235,
	0xFFFD: 0xC236,
	0xFFFD: 0xC237,
	0xFFFD: 0xC238,
	0xFFFD: 0xC239,
	0xFFFD: 0xC23A,
	0xFFFD: 0xC23B,
	0xFFFD: 0xC23C,
	0xFFFD: 0xC23D,
	0xFFFD: 0xC23E,
	0xFFFD: 0xC23F,
	0xFFFD: 0xC240,
	0xFFFD: 0xC241,
	0xFFFD: 0xC242,
	0xFFFD: 0xC243,
	0xFFFD: 0xC244,
	0xFFFD: 0xC245,
	0xFFFD: 0xC246,
	0xFFFD: 0xC247,
	0xFFFD: 0xC248,
	0xFFFD: 0xC249,
	0xFFFD: 0xC24A,
	0xFFFD: 0xC24B,
	0xFFFD: 0xC24C,
	0xFFFD: 0xC24D,
	0xFFFD: 0xC24E,
	0xFFFD: 0xC24F,
	0xFFFD: 0xC250,
	0xFFFD: 0xC251,
	0xFFFD: 0xC252,
	0xFFFD: 0xC253,
	0xFFFD: 0xC254,
	0xFFFD: 0xC255,
	0xFFFD: 0xC256,
	0xFFFD: 0xC257,
	0xFFFD: 0xC258,
	0xFFFD: 0xC259,
	0xFFFD: 0xC25A,
	0xFFFD: 0xC25B,
	0xFFFD: 0xC25C,
	0xFFFD: 0xC25D,
	0xFFFD: 0xC25E,
	0xFFFD: 0xC25F,
	0xFFFD: 0xC260,
	0xFFFD: 0xC261,
	0xFFFD: 0xC262,
	0xFFFD: 0xC263,
	0xFFFD: 0xC264,
	0xFFFD: 0xC265,
	0xFFFD: 0xC266,
	0xFFFD: 0xC267,
	0xFFFD: 0xC268,
	0xFFFD: 0xC269,
	0xFFFD: 0xC26A,
	0xFFFD: 0xC26B,
	0xFFFD: 0xC26C,
	0xFFFD: 0xC26D,
	0xFFFD: 0xC26E,
	0xFFFD: 0xC26F,
	0xFFFD: 0xC270,
	0xFFFD: 0xC271,
	0xFFFD: 0xC272,
	0xFFFD: 0xC273,
	0xFFFD: 0xC274,
	0xFFFD: 0xC275,
	0xFFFD: 0xC276,
	0xFFFD: 0xC277,
	0xFFFD: 0xC278,
	0xFFFD: 0xC279,
	0xFFFD: 0xC27A,
	0xFFFD: 0xC27B,
	0xFFFD: 0xC27C,
	0xFFFD: 0xC27D,
	0xFFFD: 0xC27E,
	0xFFFD: 0xC27F,
	0xFFFD: 0xC280,
	0xFFFD: 0xC281,
	0xFFFD: 0xC282,
	0xFFFD: 0xC283,
	0xFFFD: 0xC284,
	0xFFFD: 0xC285,
	0xFFFD: 0xC286,
	0xFFFD: 0xC287,
	0xFFFD: 0xC288,
	0xFFFD: 0xC289,
	0xFFFD: 0xC28A,
	0xFFFD: 0xC28B,
	0xFFFD: 0xC28C,
	0xFFFD: 0xC28D,
	0xFFFD: 0xC28E,
	0xFFFD: 0xC28F,
	0xFFFD: 0xC290,
	0xFFFD: 0xC291,
	0xFFFD: 0xC292,
	0xFFFD: 0xC293,
	0xFFFD: 0xC294,
	0xFFFD: 0xC295,
	0xFFFD: 0xC296,
	0xFFFD: 0xC297,
	0xFFFD: 0xC298,
	0xFFFD: 0xC299,
	0xFFFD: 0xC29A,
	0xFFFD: 0xC29B,
	0xFFFD: 0xC29C,
	0xFFFD: 0xC29D,
	0xFFFD: 0xC29E,
	0xFFFD: 0xC29F,
	0xFFFD: 0xC2A0,
	0xFFFD: 0xC2A1,
	0xFFFD: 0xC2A2,
	0xFFFD: 0xC2A3,
	0xFFFD: 0xC2A4,
	0xFFFD: 0xC2A5,
	0xFFFD: 0xC2A6,
	0xFFFD: 0xC2A7,
	0xFFFD: 0xC2A8,
	0xFFFD: 0xC2A9,
	0xFFFD: 0xC2AA,
	0xFFFD: 0xC2AB,
	0xFFFD: 0xC2AC,
	0xFFFD: 0xC2AD,
	0xFFFD: 0xC2AE,
	0xFFFD: 0xC2AF,
	0xFFFD: 0xC2B0,
	0xFFFD: 0xC2B1,
	0xFFFD: 0xC2B2,
	0xFFFD: 0xC2B3,
	0xFFFD: 0xC2B4,
	0xFFFD: 0xC2B5,
	0xFFFD: 0xC2B6,
	0xFFFD: 0xC2B7,
	0xFFFD: 0xC2B8,
	0xFFFD: 0xC2B9,
	0xFFFD: 0xC2BA,
	0xFFFD: 0xC2BB,
	0xFFFD: 0xC2BC,
	0xFFFD: 0xC2BD,
	0xFFFD: 0xC2BE,
	0xFFFD: 0xC2BF,
	0xFFFD: 0xC2C0,
	0xFFFD: 0xC2C1,
	0xFFFD: 0xC2C2,
	0xFFFD: 0xC2C3,
	0xFFFD: 0xC2C4,
	0xFFFD: 0xC2C5,
	0xFFFD: 0xC2C6,
	0xFFFD: 0xC2C7,
	0xFFFD: 0xC2C8,
	0xFFFD: 0xC2C9,
	0xFFFD: 0xC2CA,
	0xFFFD: 0xC2CB,
	0xFFFD: 0xC2CC,
	0xFFFD: 0xC2CD,
	0xFFFD: 0xC2CE,
	0xFFFD: 0xC2CF,
	0xFFFD: 0xC2D0,
	0xFFFD: 0xC2D1,
	0xFFFD: 0xC2D2,
	0xFFFD: 0xC2D3,
	0xFFFD: 0xC2D4,
	0xFFFD: 0xC2D5,
	0xFFFD: 0xC2D6,
	0xFFFD: 0xC2D7,
	0xFFFD: 0xC2D8,
	0xFFFD: 0xC2D9,
	0xFFFD: 0xC2DA,
	0xFFFD: 0xC2DB,
	0xFFFD: 0xC2DC,
	0xFFFD: 0xC2DD,
	0xFFFD: 0xC2DE,
	0xFFFD: 0xC2DF,
	0xFFFD: 0xC2E0,
	0xFFFD: 0xC2E1,
	0xFFFD: 0xC2E2,
	0xFFFD: 0xC2E3,
	0xFFFD: 0xC2E4,
	0xFFFD: 0xC2E5,
	0xFFFD: 0xC2E6,
	0xFFFD: 0xC2E7,
	0xFFFD: 0xC2E8,
	0xFFFD: 0xC2E9,
	0xFFFD: 0xC2EA,
	0xFFFD: 0xC2EB,
	0xFFFD: 0xC2EC,
	0xFFFD: 0xC2ED,
	0xFFFD: 0xC2EE,
	0xFFFD: 0xC2EF,
	0xFFFD: 0xC2F0,
	0xFFFD: 0xC2F1,
	0xFFFD: 0xC2F2,
	0xFFFD: 0xC2F3,
	0xFFFD: 0xC2F4,
	0xFFFD: 0xC2F5,
	0xFFFD: 0xC2F6,
	0xFFFD: 0xC2F7,
	0xFFFD: 0xC2F8,
	0xFFFD: 0xC2F9,
	0xFFFD: 0xC2FA,
	0xFFFD: 0xC2FB,
	0xFFFD: 0xC2FC,
	0xFFFD: 0xC2FD,
	0xFFFD: 0xC2FE,
	0xFFFD: 0xC2FF,
	0xFFFD: 0xC300,
	0xFFFD: 0xC301,
	0xFFFD: 0xC302,
	0xFFFD: 0xC303,
	0xFFFD: 0xC304,
	0xFFFD: 0xC305,
	0xFFFD: 0xC306,
	0xFFFD: 0xC307,
	0xFFFD: 0xC308,
	0xFFFD: 0xC309,
	0xFFFD: 0xC30A,
	0xFFFD: 0xC30B,
	0xFFFD: 0xC30C,
	0xFFFD: 0xC30D,
	0xFFFD: 0xC30E,
	0xFFFD: 0xC30F,
	0xFFFD: 0xC310,
	0xFFFD: 0xC311,
	0xFFFD: 0xC312,
	0xFFFD: 0xC313,
	0xFFFD: 0xC314,
	0xFFFD: 0xC315,
	0xFFFD: 0xC316,
	0xFFFD: 0xC317,
	0xFFFD: 0xC318,
	0xFFFD: 0xC319,
	0xFFFD: 0xC31A,
	0xFFFD: 0xC31B,
	0xFFFD: 0xC31C,
	0xFFFD: 0xC31D,
	0xFFFD: 0xC31E,
	0xFFFD: 0xC31F,
	0xFFFD: 0xC320,
	0xFFFD: 0xC321,
	0xFFFD: 0xC322,
	0xFFFD: 0xC323,
	0xFFFD: 0xC324,
	0xFFFD: 0xC325,
	0xFFFD: 0xC326,
	0xFFFD: 0xC327,
	0xFFFD: 0xC328,
	0xFFFD: 0xC329,
	0xFFFD: 0xC32A,
	0xFFFD: 0xC32B,
	0xFFFD: 0xC32C,
	0xFFFD: 0xC32D,
	0xFFFD: 0xC32E,
	0xFFFD: 0xC32F,
	0xFFFD: 0xC330,
	0xFFFD: 0xC331,
	0xFFFD: 0xC332,
	0xFFFD: 0xC333,
	0xFFFD: 0xC334,
	0xFFFD: 0xC335,
	0xFFFD: 0xC336,
	0xFFFD: 0xC337,
	0xFFFD: 0xC338,
	0xFFFD: 0xC339,
	0xFFFD: 0xC33A,
	0xFFFD: 0xC33B,
	0xFFFD: 0xC33C,
	0xFFFD: 0xC33D,
	0xFFFD: 0xC33E,
	0xFFFD: 0xC33F,
	0xFFFD: 0xC340,
	0xFFFD: 0xC341,
	0xFFFD: 0xC342,
	0xFFFD: 0xC343,
	0xFFFD: 0xC344,
	0xFFFD: 0xC345,
	0xFFFD: 0xC346,
	0xFFFD: 0xC347,
	0xFFFD: 0xC348,
	0xFFFD: 0xC349,
	0xFFFD: 0xC34A,
	0xFFFD: 0xC34B,
	0xFFFD: 0xC34C,
	0xFFFD: 0xC34D,
	0xFFFD: 0xC34E,
	0xFFFD: 0xC34F,
	0xFFFD: 0xC350,
	0xFFFD: 0xC351,
	0xFFFD: 0xC352,
	0xFFFD: 0xC353,
	0xFFFD: 0xC354,
	0xFFFD: 0xC355,
	0xFFFD: 0xC356,
	0xFFFD: 0xC357,
	0xFFFD: 0xC358,
	0xFFFD: 0xC359,
	0xFFFD: 0xC35A,
	0xFFFD: 0xC35B,
	0xFFFD: 0xC35C,
	0xFFFD: 0xC35D,
	0xFFFD: 0xC35E,
	0xFFFD: 0xC35F,
	0xFFFD: 0xC360,
	0xFFFD: 0xC361,
	0xFFFD: 0xC362,
	0xFFFD: 0xC363,
	0xFFFD: 0xC364,
	0xFFFD: 0xC365,
	0xFFFD: 0xC366,
	0xFFFD: 0xC367,
	0xFFFD: 0xC368,
	0xFFFD: 0xC369,
	0xFFFD: 0xC36A,
	0xFFFD: 0xC36B,
	0xFFFD: 0xC36C,
	0xFFFD: 0xC36D,
	0xFFFD: 0xC36E,
	0xFFFD: 0xC36F,
	0xFFFD: 0xC370,
	0xFFFD: 0xC371,
	0xFFFD: 0xC372,
	0xFFFD: 0xC373,
	0xFFFD: 0xC374,
	0xFFFD: 0xC375,
	0xFFFD: 0xC376,
	0xFFFD: 0xC377,
	0xFFFD: 0xC378,
	0xFFFD: 0xC379,
	0xFFFD: 0xC37A,
	0xFFFD: 0xC37B,
	0xFFFD: 0xC37C,
	0xFFFD: 0xC37D,
	0xFFFD: 0xC37E,
	0xFFFD: 0xC37F,
	0xFFFD: 0xC380,
	0xFFFD: 0xC381,
	0xFFFD: 0xC382,
	0xFFFD: 0xC383,
	0xFFFD: 0xC384,
	0xFFFD: 0xC385,
	0xFFFD: 0xC386,
	0xFFFD: 0xC387,
	0xFFFD: 0xC388,
	0xFFFD: 0xC389,
	0xFFFD: 0xC38A,
	0xFFFD: 0xC38B,
	0xFFFD: 0xC38C,
	0xFFFD: 0xC38D,
	0xFFFD: 0xC38E,
	0xFFFD: 0xC38F,
	0xFFFD: 0xC390,
	0xFFFD: 0xC391,
	0xFFFD: 0xC392,
	0xFFFD: 0xC393,
	0xFFFD: 0xC394,
	0xFFFD: 0xC395,
	0xFFFD: 0xC396,
	0xFFFD: 0xC397,
	0xFFFD: 0xC398,
	0xFFFD: 0xC399,
	0xFFFD: 0xC39A,
	0xFFFD: 0xC39B,
	0xFFFD: 0xC39C,
	0xFFFD: 0xC39D,
	0xFFFD: 0xC39E,
	0xFFFD: 0xC39F,
	0xFFFD: 0xC3A0,
	0xFFFD: 0xC3A1,
	0xFFFD: 0xC3A2,
	0xFFFD: 0xC3A3,
	0xFFFD: 0xC3A4,
	0xFFFD: 0xC3A5,
	0xFFFD: 0xC3A6,
	0xFFFD: 0xC3A7,
	0xFFFD: 0xC3A8,
	0xFFFD: 0xC3A9,
	0xFFFD: 0xC3AA,
	0xFFFD: 0xC3AB,
	0xFFFD: 0xC3AC,
	0xFFFD: 0xC3AD,
	0xFFFD: 0xC3AE,
	0xFFFD: 0xC3AF,
	0xFFFD: 0xC3B0,
	0xFFFD: 0xC3B1,
	0xFFFD: 0xC3B2,
	0xFFFD: 0xC3B3,
	0xFFFD: 0xC3B4,
	0xFFFD: 0xC3B5,
	0xFFFD: 0xC3B6,
	0xFFFD: 0xC3B7,
	0xFFFD: 0xC3B8,
	0xFFFD: 0xC3B9,
	0xFFFD: 0xC3BA,
	0xFFFD: 0xC3BB,
	0xFFFD: 0xC3BC,
	0xFFFD: 0xC3BD,
	0xFFFD: 0xC3BE,
	0xFFFD: 0xC3BF,
	0xFFFD: 0xC3C0,
	0xFFFD: 0xC3C1,
	0xFFFD: 0xC3C2,
	0xFFFD: 0xC3C3,
	0xFFFD: 0xC3C4,
	0xFFFD: 0xC3C5,
	0xFFFD: 0xC3C6,
	0xFFFD: 0xC3C7,
	0xFFFD: 0xC3C8,
	0xFFFD: 0xC3C9,
	0xFFFD: 0xC3CA,
	0xFFFD: 0xC3CB,
	0xFFFD: 0xC3CC,
	0xFFFD: 0xC3CD,
	0xFFFD: 0xC3CE,
	0xFFFD: 0xC3CF,
	0xFFFD: 0xC3D0,
	0xFFFD: 0xC3D1,
	0xFFFD: 0xC3D2,
	0xFFFD: 0xC3D3,
	0xFFFD: 0xC3D4,
	0xFFFD: 0xC3D5,
	0xFFFD: 0xC3D6,
	0xFFFD: 0xC3D7,
	0xFFFD: 0xC3D8,
	0xFFFD: 0xC3D9,
	0xFFFD: 0xC3DA,
	0xFFFD: 0xC3DB,
	0xFFFD: 0xC3DC,
	0xFFFD: 0xC3DD,
	0xFFFD: 0xC3DE,
	0xFFFD: 0xC3DF,
	0xFFFD: 0xC3E0,
	0xFFFD: 0xC3E1,
	0xFFFD: 0xC3E2,
	0xFFFD: 0xC3E3,
	0xFFFD: 0xC3E4,
	0xFFFD: 0xC3E5,
	0xFFFD: 0xC3E6,
	0xFFFD: 0xC3E7,
	0xFFFD: 0xC3E8,
	0xFFFD: 0xC3E9,
	0xFFFD: 0xC3EA,
	0xFFFD: 0xC3EB,
	0xFFFD: 0xC3EC,
	0xFFFD: 0xC3ED,
	0xFFFD: 0xC3EE,
	0xFFFD: 0xC3EF,
	0xFFFD: 0xC3F0,
	0xFFFD: 0xC3F1,
	0xFFFD: 0xC3F2,
	0xFFFD: 0xC3F3,
	0xFFFD: 0xC3F4,
	0xFFFD: 0xC3F5,
	0xFFFD: 0xC3F6,
	0xFFFD: 0xC3F7,
	0xFFFD: 0xC3F8,
	0xFFFD: 0xC3F9,
	0xFFFD: 0xC3FA,
	0xFFFD: 0xC3FB,
	0xFFFD: 0xC3FC,
	0xFFFD: 0xC3FD,
	0xFFFD: 0xC3FE,
	0xFFFD: 0xC3FF,
	0xFFFD: 0xC400,
	0xFFFD: 0xC401,
	0xFFFD: 0xC402,
	0xFFFD: 0xC403,
	0xFFFD: 0xC404,
	0xFFFD: 0xC405,
	0xFFFD: 0xC406,
	0xFFFD: 0xC407,
	0xFFFD: 0xC408,
	0xFFFD: 0xC409,
	0xFFFD: 0xC40A,
	0xFFFD: 0xC40B,
	0xFFFD: 0xC40C,
	0xFFFD: 0xC40D,
	0xFFFD: 0xC40E,
	0xFFFD: 0xC40F,
	0xFFFD: 0xC410,
	0xFFFD: 0xC411,
	0xFFFD: 0xC412,
	0xFFFD: 0xC413,
	0xFFFD: 0xC414,
	0xFFFD: 0xC415,
	0xFFFD: 0xC416,
	0xFFFD: 0xC417,
	0xFFFD: 0xC418,
	0xFFFD: 0xC419,
	0xFFFD: 0xC41A,
	0xFFFD: 0xC41B,
	0xFFFD: 0xC41C,
	0xFFFD: 0xC41D,
	0xFFFD: 0xC41E,
	0xFFFD: 0xC41F,
	0xFFFD: 0xC420,
	0xFFFD: 0xC421,
	0xFFFD: 0xC422,
	0xFFFD: 0xC423,
	0xFFFD: 0xC424,
	0xFFFD: 0xC425,
	0xFFFD: 0xC426,
	0xFFFD: 0xC427,
	0xFFFD: 0xC428,
	0xFFFD: 0xC429,
	0xFFFD: 0xC42A,
	0xFFFD: 0xC42B,
	0xFFFD: 0xC42C,
	0xFFFD: 0xC42D,
	0xFFFD: 0xC42E,
	0xFFFD: 0xC42F,
	0xFFFD: 0xC430,
	0xFFFD: 0xC431,
	0xFFFD: 0xC432,
	0xFFFD: 0xC433,
	0xFFFD: 0xC434,
	0xFFFD: 0xC435,
	0xFFFD: 0xC436,
	0xFFFD: 0xC437,
	0xFFFD: 0xC438,
	0xFFFD: 0xC439,
	0xFFFD: 0xC43A,
	0xFFFD: 0xC43B,
	0xFFFD: 0xC43C,
	0xFFFD: 0xC43D,
	0xFFFD: 0xC43E,
	0xFFFD: 0xC43F,
	0xFFFD: 0xC440,
	0xFFFD: 0xC441,
	0xFFFD: 0xC442,
	0xFFFD: 0xC443,
	0xFFFD: 0xC444,
	0xFFFD: 0xC445,
	0xFFFD: 0xC446,
	0xFFFD: 0xC447,
	0xFFFD: 0xC448,
	0xFFFD: 0xC449,
	0xFFFD: 0xC44A,
	0xFFFD: 0xC44B,
	0xFFFD: 0xC44C,
	0xFFFD: 0xC44D,
	0xFFFD: 0xC44E,
	0xFFFD: 0xC44F,
	0xFFFD: 0xC450,
	0xFFFD: 0xC451,
	0xFFFD: 0xC452,
	0xFFFD: 0xC453,
	0xFFFD: 0xC454,
	0xFFFD: 0xC455,
	0xFFFD: 0xC456,
	0xFFFD: 0xC457,
	0xFFFD: 0xC458,
	0xFFFD: 0xC459,
	0xFFFD: 0xC45A,
	0xFFFD: 0xC45B,
	0xFFFD: 0xC45C,
	0xFFFD: 0xC45D,
	0xFFFD: 0xC45E,
	0xFFFD: 0xC45F,
	0xFFFD: 0xC460,
	0xFFFD: 0xC461,
	0xFFFD: 0xC462,
	0xFFFD: 0xC463,
	0xFFFD: 0xC464,
	0xFFFD: 0xC465,
	0xFFFD: 0xC466,
	0xFFFD: 0xC467,
	0xFFFD: 0xC468,
	0xFFFD: 0xC469,
	0xFFFD: 0xC46A,
	0xFFFD: 0xC46B,
	0xFFFD: 0xC46C,
	0xFFFD: 0xC46D,
	0xFFFD: 0xC46E,
	0xFFFD: 0xC46F,
	0xFFFD: 0xC470,
	0xFFFD: 0xC471,
	0xFFFD: 0xC472,
	0xFFFD: 0xC473,
	0xFFFD: 0xC474,
	0xFFFD: 0xC475,
	0xFFFD: 0xC476,
	0xFFFD: 0xC477,
	0xFFFD: 0xC478,
	0xFFFD: 0xC479,
	0xFFFD: 0xC47A,
	0xFFFD: 0xC47B,
	0xFFFD: 0xC47C,
	0xFFFD: 0xC47D,
	0xFFFD: 0xC47E,
	0xFFFD: 0xC47F,
	0xFFFD: 0xC480,
	0xFFFD: 0xC481,
	0xFFFD: 0xC482,
	0xFFFD: 0xC483,
	0xFFFD: 0xC484,
	0xFFFD: 0xC485,
	0xFFFD: 0xC486,
	0xFFFD: 0xC487,
	0xFFFD: 0xC488,
	0xFFFD: 0xC489,
	0xFFFD: 0xC48A,
	0xFFFD: 0xC48B,
	0xFFFD: 0xC48C,
	0xFFFD: 0xC48D,
	0xFFFD: 0xC48E,
	0xFFFD: 0xC48F,
	0xFFFD: 0xC490,
	0xFFFD: 0xC491,
	0xFFFD: 0xC492,
	0xFFFD: 0xC493,
	0xFFFD: 0xC494,
	0xFFFD: 0xC495,
	0xFFFD: 0xC496,
	0xFFFD: 0xC497,
	0xFFFD: 0xC498,
	0xFFFD: 0xC499,
	0xFFFD: 0xC49A,
	0xFFFD: 0xC49B,
	0xFFFD: 0xC49C,
	0xFFFD: 0xC49D,
	0xFFFD: 0xC49E,
	0xFFFD: 0xC49F,
	0xFFFD: 0xC4A0,
	0xFFFD: 0xC4A1,
	0xFFFD: 0xC4A2,
	0xFFFD: 0xC4A3,
	0xFFFD: 0xC4A4,
	0xFFFD: 0xC4A5,
	0xFFFD: 0xC4A6,
	0xFFFD: 0xC4A7,
	0xFFFD: 0xC4A8,
	0xFFFD: 0xC4A9,
	0xFFFD: 0xC4AA,
	0xFFFD: 0xC4AB,
	0xFFFD: 0xC4AC,
	0xFFFD: 0xC4AD,
	0xFFFD: 0xC4AE,
	0xFFFD: 0xC4AF,
	0xFFFD: 0xC4B0,
	0xFFFD: 0xC4B1,
	0xFFFD: 0xC4B2,
	0xFFFD: 0xC4B3,
	0xFFFD: 0xC4B4,
	0xFFFD: 0xC4B5,
	0xFFFD: 0xC4B6,
	0xFFFD: 0xC4B7,
	0xFFFD: 0xC4B8,
	0xFFFD: 0xC4B9,
	0xFFFD: 0xC4BA,
	0xFFFD: 0xC4BB,
	0xFFFD: 0xC4BC,
	0xFFFD: 0xC4BD,
	0xFFFD: 0xC4BE,
	0xFFFD: 0xC4BF,
	0xFFFD: 0xC4C0,
	0xFFFD: 0xC4C1,
	0xFFFD: 0xC4C2,
	0xFFFD: 0xC4C3,
	0xFFFD: 0xC4C4,
	0xFFFD: 0xC4C5,
	0xFFFD: 0xC4C6,
	0xFFFD: 0xC4C7,
	0xFFFD: 0xC4C8,
	0xFFFD: 0xC4C9,
	0xFFFD: 0xC4CA,
	0xFFFD: 0xC4CB,
	0xFFFD: 0xC4CC,
	0xFFFD: 0xC4CD,
	0xFFFD: 0xC4CE,
	0xFFFD: 0xC4CF,
	0xFFFD: 0xC4D0,
	0xFFFD: 0xC4D1,
	0xFFFD: 0xC4D2,
	0xFFFD: 0xC4D3,
	0xFFFD: 0xC4D4,
	0xFFFD: 0xC4D5,
	0xFFFD: 0xC4D6,
	0xFFFD: 0xC4D7,
	0xFFFD: 0xC4D8,
	0xFFFD: 0xC4D9,
	0xFFFD: 0xC4DA,
	0xFFFD: 0xC4DB,
	0xFFFD: 0xC4DC,
	0xFFFD: 0xC4DD,
	0xFFFD: 0xC4DE,
	0xFFFD: 0xC4DF,
	0xFFFD: 0xC4E0,
	0xFFFD: 0xC4E1,
	0xFFFD: 0xC4E2,
	0xFFFD: 0xC4E3,
	0xFFFD: 0xC4E4,
	0xFFFD: 0xC4E5,
	0xFFFD: 0xC4E6,
	0xFFFD: 0xC4E7,
	0xFFFD: 0xC4E8,
	0xFFFD: 0xC4E9,
	0xFFFD: 0xC4EA,
	0xFFFD: 0xC4EB,
	0xFFFD: 0xC4EC,
	0xFFFD: 0xC4ED,
	0xFFFD: 0xC4EE,
	0xFFFD: 0xC4EF,
	0xFFFD: 0xC4F0,
	0xFFFD: 0xC4F1,
	0xFFFD: 0xC4F2,
	0xFFFD: 0xC4F3,
	0xFFFD: 0xC4F4,
	0xFFFD: 0xC4F5,
	0xFFFD: 0xC4F6,
	0xFFFD: 0xC4F7,
	0xFFFD: 0xC4F8,
	0xFFFD: 0xC4F9,
	0xFFFD: 0xC4FA,
	0xFFFD: 0xC4FB,
	0xFFFD: 0xC4FC,
	0xFFFD: 0xC4FD,
	0xFFFD: 0xC4FE,
	0xFFFD: 0xC4FF,
	0xFFFD: 0xC500,
	0xFFFD: 0xC501,
	0xFFFD: 0xC502,
	0xFFFD: 0xC503,
	0xFFFD: 0xC504,
	0xFFFD: 0xC505,
	0xFFFD: 0xC506,
	0xFFFD: 0xC507,
	0xFFFD: 0xC508,
	0xFFFD: 0xC509,
	0xFFFD: 0xC50A,
	0xFFFD: 0xC50B,
	0xFFFD: 0xC50C,
	0xFFFD: 0xC50D,
	0xFFFD: 0xC50E,
	0xFFFD: 0xC50F,
	0xFFFD: 0xC510,
	0xFFFD: 0xC511,
	0xFFFD: 0xC512,
	0xFFFD: 0xC513,
	0xFFFD: 0xC514,
	0xFFFD: 0xC515,
	0xFFFD: 0xC516,
	0xFFFD: 0xC517,
	0xFFFD: 0xC518,
	0xFFFD: 0xC519,
	0xFFFD: 0xC51A,
	0xFFFD: 0xC51B,
	0xFFFD: 0xC51C,
	0xFFFD: 0xC51D,
	0xFFFD: 0xC51E,
	0xFFFD: 0xC51F,
	0xFFFD: 0xC520,
	0xFFFD: 0xC521,
	0xFFFD: 0xC522,
	0xFFFD: 0xC523,
	0xFFFD: 0xC524,
	0xFFFD: 0xC525,
	0xFFFD: 0xC526,
	0xFFFD: 0xC527,
	0xFFFD: 0xC528,
	0xFFFD: 0xC529,
	0xFFFD: 0xC52A,
	0xFFFD: 0xC52B,
	0xFFFD: 0xC52C,
	0xFFFD: 0xC52D,
	0xFFFD: 0xC52E,
	0xFFFD: 0xC52F,
	0xFFFD: 0xC530,
	0xFFFD: 0xC531,
	0xFFFD: 0xC532,
	0xFFFD: 0xC533,
	0xFFFD: 0xC534,
	0xFFFD: 0xC535,
	0xFFFD: 0xC536,
	0xFFFD: 0xC537,
	0xFFFD: 0xC538,
	0xFFFD: 0xC539,
	0xFFFD: 0xC53A,
	0xFFFD: 0xC53B,
	0xFFFD: 0xC53C,
	0xFFFD: 0xC53D,
	0xFFFD: 0xC53E,
	0xFFFD: 0xC53F,
	0xFFFD: 0xC540,
	0xFFFD: 0xC541,
	0xFFFD: 0xC542,
	0xFFFD: 0xC543,
	0xFFFD: 0xC544,
	0xFFFD: 0xC545,
	0xFFFD: 0xC546,
	0xFFFD: 0xC547,
	0xFFFD: 0xC548,
	0xFFFD: 0xC549,
	0xFFFD: 0xC54A,
	0xFFFD: 0xC54B,
	0xFFFD: 0xC54C,
	0xFFFD: 0xC54D,
	0xFFFD: 0xC54E,
	0xFFFD: 0xC54F,
	0xFFFD: 0xC550,
	0xFFFD: 0xC551,
	0xFFFD: 0xC552,
	0xFFFD: 0xC553,
	0xFFFD: 0xC554,
	0xFFFD: 0xC555,
	0xFFFD: 0xC556,
	0xFFFD: 0xC557,
	0xFFFD: 0xC558,
	0xFFFD: 0xC559,
	0xFFFD: 0xC55A,
	0xFFFD: 0xC55B,
	0xFFFD: 0xC55C,
	0xFFFD: 0xC55D,
	0xFFFD: 0xC55E,
	0xFFFD: 0xC55F,
	0xFFFD: 0xC560,
	0xFFFD: 0xC561,
	0xFFFD: 0xC562,
	0xFFFD: 0xC563,
	0xFFFD: 0xC564,
	0xFFFD: 0xC565,
	0xFFFD: 0xC566,
	0xFFFD: 0xC567,
	0xFFFD: 0xC568,
	0xFFFD: 0xC569,
	0xFFFD: 0xC56A,
	0xFFFD: 0xC56B,
	0xFFFD: 0xC56C,
	0xFFFD: 0xC56D,
	0xFFFD: 0xC56E,
	0xFFFD: 0xC56F,
	0xFFFD: 0xC570,
	0xFFFD: 0xC571,
	0xFFFD: 0xC572,
	0xFFFD: 0xC573,
	0xFFFD: 0xC574,
	0xFFFD: 0xC575,
	0xFFFD: 0xC576,
	0xFFFD: 0xC577,
	0xFFFD: 0xC578,
	0xFFFD: 0xC579,
	0xFFFD: 0xC57A,
	0xFFFD: 0xC57B,
	0xFFFD: 0xC57C,
	0xFFFD: 0xC57D,
	0xFFFD: 0xC57E,
	0xFFFD: 0xC57F,
	0xFFFD: 0xC580,
	0xFFFD: 0xC581,
	0xFFFD: 0xC582,
	0xFFFD: 0xC583,
	0xFFFD: 0xC584,
	0xFFFD: 0xC585,
	0xFFFD: 0xC586,
	0xFFFD: 0xC587,
	0xFFFD: 0xC588,
	0xFFFD: 0xC589,
	0xFFFD: 0xC58A,
	0xFFFD: 0xC58B,
	0xFFFD: 0xC58C,
	0xFFFD: 0xC58D,
	0xFFFD: 0xC58E,
	0xFFFD: 0xC58F,
	0xFFFD: 0xC590,
	0xFFFD: 0xC591,
	0xFFFD: 0xC592,
	0xFFFD: 0xC593,
	0xFFFD: 0xC594,
	0xFFFD: 0xC595,
	0xFFFD: 0xC596,
	0xFFFD: 0xC597,
	0xFFFD: 0xC598,
	0xFFFD: 0xC599,
	0xFFFD: 0xC59A,
	0xFFFD: 0xC59B,
	0xFFFD: 0xC59C,
	0xFFFD: 0xC59D,
	0xFFFD: 0xC59E,
	0xFFFD: 0xC59F,
	0xFFFD: 0xC5A0,
	0xFFFD: 0xC5A1,
	0xFFFD: 0xC5A2,
	0xFFFD: 0xC5A3,
	0xFFFD: 0xC5A4,
	0xFFFD: 0xC5A5,
	0xFFFD: 0xC5A6,
	0xFFFD: 0xC5A7,
	0xFFFD: 0xC5A8,
	0xFFFD: 0xC5A9,
	0xFFFD: 0xC5AA,
	0xFFFD: 0xC5AB,
	0xFFFD: 0xC5AC,
	0xFFFD: 0xC5AD,
	0xFFFD: 0xC5AE,
	0xFFFD: 0xC5AF,
	0xFFFD: 0xC5B0,
	0xFFFD: 0xC5B1,
	0xFFFD: 0xC5B2,
	0xFFFD: 0xC5B3,
	0xFFFD: 0xC5B4,
	0xFFFD: 0xC5B5,
	0xFFFD: 0xC5B6,
	0xFFFD: 0xC5B7,
	0xFFFD: 0xC5B8,
	0xFFFD: 0xC5B9,
	0xFFFD: 0xC5BA,
	0xFFFD: 0xC5BB,
	0xFFFD: 0xC5BC,
	0xFFFD: 0xC5BD,
	0xFFFD: 0xC5BE,
	0xFFFD: 0xC5BF,
	0xFFFD: 0xC5C0,
	0xFFFD: 0xC5C1,
	0xFFFD: 0xC5C2,
	0xFFFD: 0xC5C3,
	0xFFFD: 0xC5C4,
	0xFFFD: 0xC5C5,
	0xFFFD: 0xC5C6,
	0xFFFD: 0xC5C7,
	0xFFFD: 0xC5C8,
	0xFFFD: 0xC5C9,
	0xFFFD: 0xC5CA,
	0xFFFD: 0xC5CB,
	0xFFFD: 0xC5CC,
	0xFFFD: 0xC5CD,
	0xFFFD: 0xC5CE,
	0xFFFD: 0xC5CF,
	0xFFFD: 0xC5D0,
	0xFFFD: 0xC5D1,
	0xFFFD: 0xC5D2,
	0xFFFD: 0xC5D3,
	0xFFFD: 0xC5D4,
	0xFFFD: 0xC5D5,
	0xFFFD: 0xC5D6,
	0xFFFD: 0xC5D7,
	0xFFFD: 0xC5D8,
	0xFFFD: 0xC5D9,
	0xFFFD: 0xC5DA,
	0xFFFD: 0xC5DB,
	0xFFFD: 0xC5DC,
	0xFFFD: 0xC5DD,
	0xFFFD: 0xC5DE,
	0xFFFD: 0xC5DF,
	0xFFFD: 0xC5E0,
	0xFFFD: 0xC5E1,
	0xFFFD: 0xC5E2,
	0xFFFD: 0xC5E3,
	0xFFFD: 0xC5E4,
	0xFFFD: 0xC5E5,
	0xFFFD: 0xC5E6,
	0xFFFD: 0xC5E7,
	0xFFFD: 0xC5E8,
	0xFFFD: 0xC5E9,
	0xFFFD: 0xC5EA,
	0xFFFD: 0xC5EB,
	0xFFFD: 0xC5EC,
	0xFFFD: 0xC5ED,
	0xFFFD: 0xC5EE,
	0xFFFD: 0xC5EF,
	0xFFFD: 0xC5F0,
	0xFFFD: 0xC5F1,
	0xFFFD: 0xC5F2,
	0xFFFD: 0xC5F3,
	0xFFFD: 0xC5F4,
	0xFFFD: 0xC5F5,
	0xFFFD: 0xC5F6,
	0xFFFD: 0xC5F7,
	0xFFFD: 0xC5F8,
	0xFFFD: 0xC5F9,
	0xFFFD: 0xC5FA,
	0xFFFD: 0xC5FB,
	0xFFFD: 0xC5FC,
	0xFFFD: 0xC5FD,
	0xFFFD: 0xC5FE,
	0xFFFD: 0xC5FF,
	0xFFFD: 0xC600,
	0xFFFD: 0xC601,
	0xFFFD: 0xC602,
	0xFFFD: 0xC603,
	0xFFFD: 0xC604,
	0xFFFD: 0xC605,
	0xFFFD: 0xC606,
	0xFFFD: 0xC607,
	0xFFFD: 0xC608,
	0xFFFD: 0xC609,
	0xFFFD: 0xC60A,
	0xFFFD: 0xC60B,
	0xFFFD: 0xC60C,
	0xFFFD: 0xC60D,
	0xFFFD: 0xC60E,
	0xFFFD: 0xC60F,
	0xFFFD: 0xC610,
	0xFFFD: 0xC611,
	0xFFFD: 0xC612,
	0xFFFD: 0xC613,
	0xFFFD: 0xC614,
	0xFFFD: 0xC615,
	0xFFFD: 0xC616,
	0xFFFD: 0xC617,
	0xFFFD: 0xC618,
	0xFFFD: 0xC619,
	0xFFFD: 0xC61A,
	0xFFFD: 0xC61B,
	0xFFFD: 0xC61C,
	0xFFFD: 0xC61D,
	0xFFFD: 0xC61E,
	0xFFFD: 0xC61F,
	0xFFFD: 0xC620,
	0xFFFD: 0xC621,
	0xFFFD: 0xC622,
	0xFFFD: 0xC623,
	0xFFFD: 0xC624,
	0xFFFD: 0xC625,
	0xFFFD: 0xC626,
	0xFFFD: 0xC627,
	0xFFFD: 0xC628,
	0xFFFD: 0xC629,
	0xFFFD: 0xC62A,
	0xFFFD: 0xC62B,
	0xFFFD: 0xC62C,
	0xFFFD: 0xC62D,
	0xFFFD: 0xC62E,
	0xFFFD: 0xC62F,
	0xFFFD: 0xC630,
	0xFFFD: 0xC631,
	0xFFFD: 0xC632,
	0xFFFD: 0xC633,
	0xFFFD: 0xC634,
	0xFFFD: 0xC635,
	0xFFFD: 0xC636,
	0xFFFD: 0xC637,
	0xFFFD: 0xC638,
	0xFFFD: 0xC639,
	0xFFFD: 0xC63A,
	0xFFFD: 0xC63B,
	0xFFFD: 0xC63C,
	0xFFFD: 0xC63D,
	0xFFFD: 0xC63E,
	0xFFFD: 0xC63F,
	0xFFFD: 0xC640,
	0xFFFD: 0xC641,
	0xFFFD: 0xC642,
	0xFFFD: 0xC643,
	0xFFFD: 0xC644,
	0xFFFD: 0xC645,
	0xFFFD: 0xC646,
	0xFFFD: 0xC647,
	0xFFFD: 0xC648,
	0xFFFD: 0xC649,
	0xFFFD: 0xC64A,
	0xFFFD: 0xC64B,
	0xFFFD: 0xC64C,
	0xFFFD: 0xC64D,
	0xFFFD: 0xC64E,
	0xFFFD: 0xC64F,
	0xFFFD: 0xC650,
	0xFFFD: 0xC651,
	0xFFFD: 0xC652,
	0xFFFD: 0xC653,
	0xFFFD: 0xC654,
	0xFFFD: 0xC655,
	0xFFFD: 0xC656,
	0xFFFD: 0xC657,
	0xFFFD: 0xC658,
	0xFFFD: 0xC659,
	0xFFFD: 0xC65A,
	0xFFFD: 0xC65B,
	0xFFFD: 0xC65C,
	0xFFFD: 0xC65D,
	0xFFFD: 0xC65E,
	0xFFFD: 0xC65F,
	0xFFFD: 0xC660,
	0xFFFD: 0xC661,
	0xFFFD: 0xC662,
	0xFFFD: 0xC663,
	0xFFFD: 0xC664,
	0xFFFD: 0xC665,
	0xFFFD: 0xC666,
	0xFFFD: 0xC667,
	0xFFFD: 0xC668,
	0xFFFD: 0xC669,
	0xFFFD: 0xC66A,
	0xFFFD: 0xC66B,
	0xFFFD: 0xC66C,
	0xFFFD: 0xC66D,
	0xFFFD: 0xC66E,
	0xFFFD: 0xC66F,
	0xFFFD: 0xC670,
	0xFFFD: 0xC671,
	0xFFFD: 0xC672,
	0xFFFD: 0xC673,
	0xFFFD: 0xC674,
	0xFFFD: 0xC675,
	0xFFFD: 0xC676,
	0xFFFD: 0xC677,
	0xFFFD: 0xC678,
	0xFFFD: 0xC679,
	0xFFFD: 0xC67A,
	0xFFFD: 0xC67B,
	0xFFFD: 0xC67C,
	0xFFFD: 0xC67D,
	0xFFFD: 0xC67E,
	0xFFFD: 0xC67F,
	0xFFFD: 0xC680,
	0xFFFD: 0xC681,
	0xFFFD: 0xC682,
	0xFFFD: 0xC683,
	0xFFFD: 0xC684,
	0xFFFD: 0xC685,
	0xFFFD: 0xC686,
	0xFFFD: 0xC687,
	0xFFFD: 0xC688,
	0xFFFD: 0xC689,
	0xFFFD: 0xC68A,
	0xFFFD: 0xC68B,
	0xFFFD: 0xC68C,
	0xFFFD: 0xC68D,
	0xFFFD: 0xC68E,
	0xFFFD: 0xC68F,
	0xFFFD: 0xC690,
	0xFFFD: 0xC691,
	0xFFFD: 0xC692,
	0xFFFD: 0xC693,
	0xFFFD: 0xC694,
	0xFFFD: 0xC695,
	0xFFFD: 0xC696,
	0xFFFD: 0xC697,
	0xFFFD: 0xC698,
	0xFFFD: 0xC699,
	0xFFFD: 0xC69A,
	0xFFFD: 0xC69B,
	0xFFFD: 0xC69C,
	0xFFFD: 0xC69D,
	0xFFFD: 0xC69E,
	0xFFFD: 0xC69F,
	0xFFFD: 0xC6A0,
	0xFFFD: 0xC6A1,
	0xFFFD: 0xC6A2,
	0xFFFD: 0xC6A3,
	0xFFFD: 0xC6A4,
	0xFFFD: 0xC6A5,
	0xFFFD: 0xC6A6,
	0xFFFD: 0xC6A7,
	0xFFFD: 0xC6A8,
	0xFFFD: 0xC6A9,
	0xFFFD: 0xC6AA,
	0xFFFD: 0xC6AB,
	0xFFFD: 0xC6AC,
	0xFFFD: 0xC6AD,
	0xFFFD: 0xC6AE,
	0xFFFD: 0xC6AF,
	0xFFFD: 0xC6B0,
	0xFFFD: 0xC6B1,
	0xFFFD: 0xC6B2,
	0xFFFD: 0xC6B3,
	0xFFFD: 0xC6B4,
	0xFFFD: 0xC6B5,
	0xFFFD: 0xC6B6,
	0xFFFD: 0xC6B7,
	0xFFFD: 0xC6B8,
	0xFFFD: 0xC6B9,
	0xFFFD: 0xC6BA,
	0xFFFD: 0xC6BB,
	0xFFFD: 0xC6BC,
	0xFFFD: 0xC6BD,
	0xFFFD: 0xC6BE,
	0xFFFD: 0xC6BF,
	0xFFFD: 0xC6C0,
	0xFFFD: 0xC6C1,
	0xFFFD: 0xC6C2,
	0xFFFD: 0xC6C3,
	0xFFFD: 0xC6C4,
	0xFFFD: 0xC6C5,
	0xFFFD: 0xC6C6,
	0xFFFD: 0xC6C7,
	0xFFFD: 0xC6C8,
	0xFFFD: 0xC6C9,
	0xFFFD: 0xC6CA,
	0xFFFD: 0xC6CB,
	0xFFFD: 0xC6CC,
	0xFFFD: 0xC6CD,
	0xFFFD: 0xC6CE,
	0xFFFD: 0xC6CF,
	0xFFFD: 0xC6D0,
	0xFFFD: 0xC6D1,
	0xFFFD: 0xC6D2,
	0xFFFD: 0xC6D3,
	0xFFFD: 0xC6D4,
	0xFFFD: 0xC6D5,
	0xFFFD: 0xC6D6,
	0xFFFD: 0xC6D7,
	0xFFFD: 0xC6D8,
	0xFFFD: 0xC6D9,
	0xFFFD: 0xC6DA,
	0xFFFD: 0xC6DB,
	0xFFFD: 0xC6DC,
	0xFFFD: 0xC6DD,
	0xFFFD: 0xC6DE,
	0xFFFD: 0xC6DF,
	0xFFFD: 0xC6E0,
	0xFFFD: 0xC6E1,
	0xFFFD: 0xC6E2,
	0xFFFD: 0xC6E3,
	0xFFFD: 0xC6E4,
	0xFFFD: 0xC6E5,
	0xFFFD: 0xC6E6,
	0xFFFD: 0xC6E7,
	0xFFFD: 0xC6E8,
	0xFFFD: 0xC6E9,
	0xFFFD: 0xC6EA,
	0xFFFD: 0xC6EB,
	0xFFFD: 0xC6EC,
	0xFFFD: 0xC6ED,
	0xFFFD: 0xC6EE,
	0xFFFD: 0xC6EF,
	0xFFFD: 0xC6F0,
	0xFFFD: 0xC6F1,
	0xFFFD: 0xC6F2,
	0xFFFD: 0xC6F3,
	0xFFFD: 0xC6F4,
	0xFFFD: 0xC6F5,
	0xFFFD: 0xC6F6,
	0xFFFD: 0xC6F7,
	0xFFFD: 0xC6F8,
	0xFFFD: 0xC6F9,
	0xFFFD: 0xC6FA,
	0xFFFD: 0xC6FB,
	0xFFFD: 0xC6FC,
	0xFFFD: 0xC6FD,
	0xFFFD: 0xC6FE,
	0xFFFD: 0xC6FF,
	0xFFFD: 0xC700,
	0xFFFD: 0xC701,
	0xFFFD: 0xC702,
	0xFFFD: 0xC703,
	0xFFFD: 0xC704,
	0xFFFD: 0xC705,
	0xFFFD: 0xC706,
	0xFFFD: 0xC707,
	0xFFFD: 0xC708,
	0xFFFD: 0xC709,
	0xFFFD: 0xC70A,
	0xFFFD: 0xC70B,
	0xFFFD: 0xC70C,
	0xFFFD: 0xC70D,
	0xFFFD: 0xC70E,
	0xFFFD: 0xC70F,
	0xFFFD: 0xC710,
	0xFFFD: 0xC711,
	0xFFFD: 0xC712,
	0xFFFD: 0xC713,
	0xFFFD: 0xC714,
	0xFFFD: 0xC715,
	0xFFFD: 0xC716,
	0xFFFD: 0xC717,
	0xFFFD: 0xC718,
	0xFFFD: 0xC719,
	0xFFFD: 0xC71A,
	0xFFFD: 0xC71B,
	0xFFFD: 0xC71C,
	0xFFFD: 0xC71D,
	0xFFFD: 0xC71E,
	0xFFFD: 0xC71F,
	0xFFFD: 0xC720,
	0xFFFD: 0xC721,
	0xFFFD: 0xC722,
	0xFFFD: 0xC723,
	0xFFFD: 0xC724,
	0xFFFD: 0xC725,
	0xFFFD: 0xC726,
	0xFFFD: 0xC727,
	0xFFFD: 0xC728,
	0xFFFD: 0xC729,
	0xFFFD: 0xC72A,
	0xFFFD: 0xC72B,
	0xFFFD: 0xC72C,
	0xFFFD: 0xC72D,
	0xFFFD: 0xC72E,
	0xFFFD: 0xC72F,
	0xFFFD: 0xC730,
	0xFFFD: 0xC731,
	0xFFFD: 0xC732,
	0xFFFD: 0xC733,
	0xFFFD: 0xC734,
	0xFFFD: 0xC735,
	0xFFFD: 0xC736,
	0xFFFD: 0xC737,
	0xFFFD: 0xC738,
	0xFFFD: 0xC739,
	0xFFFD: 0xC73A,
	0xFFFD: 0xC73B,
	0xFFFD: 0xC73C,
	0xFFFD: 0xC73D,
	0xFFFD: 0xC73E,
	0xFFFD: 0xC73F,
	0xFFFD: 0xC740,
	0xFFFD: 0xC741,
	0xFFFD: 0xC742,
	0xFFFD: 0xC743,
	0xFFFD: 0xC744,
	0xFFFD: 0xC745,
	0xFFFD: 0xC746,
	0xFFFD: 0xC747,
	0xFFFD: 0xC748,
	0xFFFD: 0xC749,
	0xFFFD: 0xC74A,
	0xFFFD: 0xC74B,
	0xFFFD: 0xC74C,
	0xFFFD: 0xC74D,
	0xFFFD: 0xC74E,
	0xFFFD: 0xC74F,
	0xFFFD: 0xC750,
	0xFFFD: 0xC751,
	0xFFFD: 0xC752,
	0xFFFD: 0xC753,
	0xFFFD: 0xC754,
	0xFFFD: 0xC755,
	0xFFFD: 0xC756,
	0xFFFD: 0xC757,
	0xFFFD: 0xC758,
	0xFFFD: 0xC759,
	0xFFFD: 0xC75A,
	0xFFFD: 0xC75B,
	0xFFFD: 0xC75C,
	0xFFFD: 0xC75D,
	0xFFFD: 0xC75E,
	0xFFFD: 0xC75F,
	0xFFFD: 0xC760,
	0xFFFD: 0xC761,
	0xFFFD: 0xC762,
	0xFFFD: 0xC763,
	0xFFFD: 0xC764,
	0xFFFD: 0xC765,
	0xFFFD: 0xC766,
	0xFFFD: 0xC767,
	0xFFFD: 0xC768,
	0xFFFD: 0xC769,
	0xFFFD: 0xC76A,
	0xFFFD: 0xC76B,
	0xFFFD: 0xC76C,
	0xFFFD: 0xC76D,
	0xFFFD: 0xC76E,
	0xFFFD: 0xC76F,
	0xFFFD: 0xC770,
	0xFFFD: 0xC771,
	0xFFFD: 0xC772,
	0xFFFD: 0xC773,
	0xFFFD: 0xC774,
	0xFFFD: 0xC775,
	0xFFFD: 0xC776,
	0xFFFD: 0xC777,
	0xFFFD: 0xC778,
	0xFFFD: 0xC779,
	0xFFFD: 0xC77A,
	0xFFFD: 0xC77B,
	0xFFFD: 0xC77C,
	0xFFFD: 0xC77D,
	0xFFFD: 0xC77E,
	0xFFFD: 0xC77F,
	0xFFFD: 0xC780,
	0xFFFD: 0xC781,
	0xFFFD: 0xC782,
	0xFFFD: 0xC783,
	0xFFFD: 0xC784,
	0xFFFD: 0xC785,
	0xFFFD: 0xC786,
	0xFFFD: 0xC787,
	0xFFFD: 0xC788,
	0xFFFD: 0xC789,
	0xFFFD: 0xC78A,
	0xFFFD: 0xC78B,
	0xFFFD: 0xC78C,
	0xFFFD: 0xC78D,
	0xFFFD: 0xC78E,
	0xFFFD: 0xC78F,
	0xFFFD: 0xC790,
	0xFFFD: 0xC791,
	0xFFFD: 0xC792,
	0xFFFD: 0xC793,
	0xFFFD: 0xC794,
	0xFFFD: 0xC795,
	0xFFFD: 0xC796,
	0xFFFD: 0xC797,
	0xFFFD: 0xC798,
	0xFFFD: 0xC799,
	0xFFFD: 0xC79A,
	0xFFFD: 0xC79B,
	0xFFFD: 0xC79C,
	0xFFFD: 0xC79D,
	0xFFFD: 0xC79E,
	0xFFFD: 0xC79F,
	0xFFFD: 0xC7A0,
	0xFFFD: 0xC7A1,
	0xFFFD: 0xC7A2,
	0xFFFD: 0xC7A3,
	0xFFFD: 0xC7A4,
	0xFFFD: 0xC7A5,
	0xFFFD: 0xC7A6,
	0xFFFD: 0xC7A7,
	0xFFFD: 0xC7A8,
	0xFFFD: 0xC7A9,
	0xFFFD: 0xC7AA,
	0xFFFD: 0xC7AB,
	0xFFFD: 0xC7AC,
	0xFFFD: 0xC7AD,
	0xFFFD: 0xC7AE,
	0xFFFD: 0xC7AF,
	0xFFFD: 0xC7B0,
	0xFFFD: 0xC7B1,
	0xFFFD: 0xC7B2,
	0xFFFD: 0xC7B3,
	0xFFFD: 0xC7B4,
	0xFFFD: 0xC7B5,
	0xFFFD: 0xC7B6,
	0xFFFD: 0xC7B7,
	0xFFFD: 0xC7B8,
	0xFFFD: 0xC7B9,
	0xFFFD: 0xC7BA,
	0xFFFD: 0xC7BB,
	0xFFFD: 0xC7BC,
	0xFFFD: 0xC7BD,
	0xFFFD: 0xC7BE,
	0xFFFD: 0xC7BF,
	0xFFFD: 0xC7C0,
	0xFFFD: 0xC7C1,
	0xFFFD: 0xC7C2,
	0xFFFD: 0xC7C3,
	0xFFFD: 0xC7C4,
	0xFFFD: 0xC7C5,
	0xFFFD: 0xC7C6,
	0xFFFD: 0xC7C7,
	0xFFFD: 0xC7C8,
	0xFFFD: 0xC7C9,
	0xFFFD: 0xC7CA,
	0xFFFD: 0xC7CB,
	0xFFFD: 0xC7CC,
	0xFFFD: 0xC7CD,
	0xFFFD: 0xC7CE,
	0xFFFD: 0xC7CF,
	0xFFFD: 0xC7D0,
	0xFFFD: 0xC7D1,
	0xFFFD: 0xC7D2,
	0xFFFD: 0xC7D3,
	0xFFFD: 0xC7D4,
	0xFFFD: 0xC7D5,
	0xFFFD: 0xC7D6,
	0xFFFD: 0xC7D7,
	0xFFFD: 0xC7D8,
	0xFFFD: 0xC7D9,
	0xFFFD: 0xC7DA,
	0xFFFD: 0xC7DB,
	0xFFFD: 0xC7DC,
	0xFFFD: 0xC7DD,
	0xFFFD: 0xC7DE,
	0xFFFD: 0xC7DF,
	0xFFFD: 0xC7E0,
	0xFFFD: 0xC7E1,
	0xFFFD: 0xC7E2,
	0xFFFD: 0xC7E3,
	0xFFFD: 0xC7E4,
	0xFFFD: 0xC7E5,
	0xFFFD: 0xC7E6,
	0xFFFD: 0xC7E7,
	0xFFFD: 0xC7E8,
	0xFFFD: 0xC7E9,
	0xFFFD: 0xC7EA,
	0xFFFD: 0xC7EB,
	0xFFFD: 0xC7EC,
	0xFFFD: 0xC7ED,
	0xFFFD: 0xC7EE,
	0xFFFD: 0xC7EF,
	0xFFFD: 0xC7F0,
	0xFFFD: 0xC7F1,
	0xFFFD: 0xC7F2,
	0xFFFD: 0xC7F3,
	0xFFFD: 0xC7F4,
	0xFFFD: 0xC7F5,
	0xFFFD: 0xC7F6,
	0xFFFD: 0xC7F7,
	0xFFFD: 0xC7F8,
	0xFFFD: 0xC7F9,
	0xFFFD: 0xC7FA,
	0xFFFD: 0xC7FB,
	0xFFFD: 0xC7FC,
	0xFFFD: 0xC7FD,
	0xFFFD: 0xC7FE,
	0xFFFD: 0xC7FF,
	0xFFFD: 0xC800,
	0xFFFD: 0xC801,
	0xFFFD: 0xC802,
	0xFFFD: 0xC803,
	0xFFFD: 0xC804,
	0xFFFD: 0xC805,
	0xFFFD: 0xC806,
	0xFFFD: 0xC807,
	0xFFFD: 0xC808,
	0xFFFD: 0xC809,
	0xFFFD: 0xC80A,
	0xFFFD: 0xC80B,
	0xFFFD: 0xC80C,
	0xFFFD: 0xC80D,
	0xFFFD: 0xC80E,
	0xFFFD: 0xC80F,
	0xFFFD: 0xC810,
	0xFFFD: 0xC811,
	0xFFFD: 0xC812,
	0xFFFD: 0xC813,
	0xFFFD: 0xC814,
	0xFFFD: 0xC815,
	0xFFFD: 0xC816,
	0xFFFD: 0xC817,
	0xFFFD: 0xC818,
	0xFFFD: 0xC819,
	0xFFFD: 0xC81A,
	0xFFFD: 0xC81B,
	0xFFFD: 0xC81C,
	0xFFFD: 0xC81D,
	0xFFFD: 0xC81E,
	0xFFFD: 0xC81F,
	0xFFFD: 0xC820,
	0xFFFD: 0xC821,
	0xFFFD: 0xC822,
	0xFFFD: 0xC823,
	0xFFFD: 0xC824,
	0xFFFD: 0xC825,
	0xFFFD: 0xC826,
	0xFFFD: 0xC827,
	0xFFFD: 0xC828,
	0xFFFD: 0xC829,
	0xFFFD: 0xC82A,
	0xFFFD: 0xC82B,
	0xFFFD: 0xC82C,
	0xFFFD: 0xC82D,
	0xFFFD: 0xC82E,
	0xFFFD: 0xC82F,
	0xFFFD: 0xC830,
	0xFFFD: 0xC831,
	0xFFFD: 0xC832,
	0xFFFD: 0xC833,
	0xFFFD: 0xC834,
	0xFFFD: 0xC835,
	0xFFFD: 0xC836,
	0xFFFD: 0xC837,
	0xFFFD: 0xC838,
	0xFFFD: 0xC839,
	0xFFFD: 0xC83A,
	0xFFFD: 0xC83B,
	0xFFFD: 0xC83C,
	0xFFFD: 0xC83D,
	0xFFFD: 0xC83E,
	0xFFFD: 0xC83F,
	0xFFFD: 0xC840,
	0xFFFD: 0xC841,
	0xFFFD: 0xC842,
	0xFFFD: 0xC843,
	0xFFFD: 0xC844,
	0xFFFD: 0xC845,
	0xFFFD: 0xC846,
	0xFFFD: 0xC847,
	0xFFFD: 0xC848,
	0xFFFD: 0xC849,
	0xFFFD: 0xC84A,
	0xFFFD: 0xC84B,
	0xFFFD: 0xC84C,
	0xFFFD: 0xC84D,
	0xFFFD: 0xC84E,
	0xFFFD: 0xC84F,
	0xFFFD: 0xC850,
	0xFFFD: 0xC851,
	0xFFFD: 0xC852,
	0xFFFD: 0xC853,
	0xFFFD: 0xC854,
	0xFFFD: 0xC855,
	0xFFFD: 0xC856,
	0xFFFD: 0xC857,
	0xFFFD: 0xC858,
	0xFFFD: 0xC859,
	0xFFFD: 0xC85A,
	0xFFFD: 0xC85B,
	0xFFFD: 0xC85C,
	0xFFFD: 0xC85D,
	0xFFFD: 0xC85E,
	0xFFFD: 0xC85F,
	0xFFFD: 0xC860,
	0xFFFD: 0xC861,
	0xFFFD: 0xC862,
	0xFFFD: 0xC863,
	0xFFFD: 0xC864,
	0xFFFD: 0xC865,
	0xFFFD: 0xC866,
	0xFFFD: 0xC867,
	0xFFFD: 0xC868,
	0xFFFD: 0xC869,
	0xFFFD: 0xC86A,
	0xFFFD: 0xC86B,
	0xFFFD: 0xC86C,
	0xFFFD: 0xC86D,
	0xFFFD: 0xC86E,
	0xFFFD: 0xC86F,
	0xFFFD: 0xC870,
	0xFFFD: 0xC871,
	0xFFFD: 0xC872,
	0xFFFD: 0xC873,
	0xFFFD: 0xC874,
	0xFFFD: 0xC875,
	0xFFFD: 0xC876,
	0xFFFD: 0xC877,
	0xFFFD: 0xC878,
	0xFFFD: 0xC879,
	0xFFFD: 0xC87A,
	0xFFFD: 0xC87B,
	0xFFFD: 0xC87C,
	0xFFFD: 0xC87D,
	0xFFFD: 0xC87E,
	0xFFFD: 0xC87F,
	0xFFFD: 0xC880,
	0xFFFD: 0xC881,
	0xFFFD: 0xC882,
	0xFFFD: 0xC883,
	0xFFFD: 0xC884,
	0xFFFD: 0xC885,
	0xFFFD: 0xC886,
	0xFFFD: 0xC887,
	0xFFFD: 0xC888,
	0xFFFD: 0xC889,
	0xFFFD: 0xC88A,
	0xFFFD: 0xC88B,
	0xFFFD: 0xC88C,
	0xFFFD: 0xC88D,
	0xFFFD: 0xC88E,
	0xFFFD: 0xC88F,
	0xFFFD: 0xC890,
	0xFFFD: 0xC891,
	0xFFFD: 0xC892,
	0xFFFD: 0xC893,
	0xFFFD: 0xC894,
	0xFFFD: 0xC895,
	0xFFFD: 0xC896,
	0xFFFD: 0xC897,
	0xFFFD: 0xC898,
	0xFFFD: 0xC899,
	0xFFFD: 0xC89A,
	0xFFFD: 0xC89B,
	0xFFFD: 0xC89C,
	0xFFFD: 0xC89D,
	0xFFFD: 0xC89E,
	0xFFFD: 0xC89F,
	0xFFFD: 0xC8A0,
	0xFFFD: 0xC8A1,
	0xFFFD: 0xC8A2,
	0xFFFD: 0xC8A3,
	0xFFFD: 0xC8A4,
	0xFFFD: 0xC8A5,
	0xFFFD: 0xC8A6,
	0xFFFD: 0xC8A7,
	0xFFFD: 0xC8A8,
	0xFFFD: 0xC8A9,
	0xFFFD: 0xC8AA,
	0xFFFD: 0xC8AB,
	0xFFFD: 0xC8AC,
	0xFFFD: 0xC8AD,
	0xFFFD: 0xC8AE,
	0xFFFD: 0xC8AF,
	0xFFFD: 0xC8B0,
	0xFFFD: 0xC8B1,
	0xFFFD: 0xC8B2,
	0xFFFD: 0xC8B3,
	0xFFFD: 0xC8B4,
	0xFFFD: 0xC8B5,
	0xFFFD: 0xC8B6,
	0xFFFD: 0xC8B7,
	0xFFFD: 0xC8B8,
	0xFFFD: 0xC8B9,
	0xFFFD: 0xC8BA,
	0xFFFD: 0xC8BB,
	0xFFFD: 0xC8BC,
	0xFFFD: 0xC8BD,
	0xFFFD: 0xC8BE,
	0xFFFD: 0xC8BF,
	0xFFFD: 0xC8C0,
	0xFFFD: 0xC8C1,
	0xFFFD: 0xC8C2,
	0xFFFD: 0xC8C3,
	0xFFFD: 0xC8C4,
	0xFFFD: 0xC8C5,
	0xFFFD: 0xC8C6,
	0xFFFD: 0xC8C7,
	0xFFFD: 0xC8C8,
	0xFFFD: 0xC8C9,
	0xFFFD: 0xC8CA,
	0xFFFD: 0xC8CB,
	0xFFFD: 0xC8CC,
	0xFFFD: 0xC8CD,
	0xFFFD: 0xC8CE,
	0xFFFD: 0xC8CF,
	0xFFFD: 0xC8D0,
	0xFFFD: 0xC8D1,
	0xFFFD: 0xC8D2,
	0xFFFD: 0xC8D3,
	0xFFFD: 0xC8D4,
	0xFFFD: 0xC8D5,
	0xFFFD: 0xC8D6,
	0xFFFD: 0xC8D7,
	0xFFFD: 0xC8D8,
	0xFFFD: 0xC8D9,
	0xFFFD: 0xC8DA,
	0xFFFD: 0xC8DB,
	0xFFFD: 0xC8DC,
	0xFFFD: 0xC8DD,
	0xFFFD: 0xC8DE,
	0xFFFD: 0xC8DF,
	0xFFFD: 0xC8E0,
	0xFFFD: 0xC8E1,
	0xFFFD: 0xC8E2,
	0xFFFD: 0xC8E3,
	0xFFFD: 0xC8E4,
	0xFFFD: 0xC8E5,
	0xFFFD: 0xC8E6,
	0xFFFD: 0xC8E7,
	0xFFFD: 0xC8E8,
	0xFFFD: 0xC8E9,
	0xFFFD: 0xC8EA,
	0xFFFD: 0xC8EB,
	0xFFFD: 0xC8EC,
	0xFFFD: 0xC8ED,
	0xFFFD: 0xC8EE,
	0xFFFD: 0xC8EF,
	0xFFFD: 0xC8F0,
	0xFFFD: 0xC8F1,
	0xFFFD: 0xC8F2,
	0xFFFD: 0xC8F3,
	0xFFFD: 0xC8F4,
	0xFFFD: 0xC8F5,
	0xFFFD: 0xC8F6,
	0xFFFD: 0xC8F7,
	0xFFFD: 0xC8F8,
	0xFFFD: 0xC8F9,
	0xFFFD: 0xC8FA,
	0xFFFD: 0xC8FB,
	0xFFFD: 0xC8FC,
	0xFFFD: 0xC8FD,
	0xFFFD: 0xC8FE,
	0xFFFD: 0xC8FF,
	0xFFFD: 0xC900,
	0xFFFD: 0xC901,
	0xFFFD: 0xC902,
	0xFFFD: 0xC903,
	0xFFFD: 0xC904,
	0xFFFD: 0xC905,
	0xFFFD: 0xC906,
	0xFFFD: 0xC907,
	0xFFFD: 0xC908,
	0xFFFD: 0xC909,
	0xFFFD: 0xC90A,
	0xFFFD: 0xC90B,
	0xFFFD: 0xC90C,
	0xFFFD: 0xC90D,
	0xFFFD: 0xC90E,
	0xFFFD: 0xC90F,
	0xFFFD: 0xC910,
	0xFFFD: 0xC911,
	0xFFFD: 0xC912,
	0xFFFD: 0xC913,
	0xFFFD: 0xC914,
	0xFFFD: 0xC915,
	0xFFFD: 0xC916,
	0xFFFD: 0xC917,
	0xFFFD: 0xC918,
	0xFFFD: 0xC919,
	0xFFFD: 0xC91A,
	0xFFFD: 0xC91B,
	0xFFFD: 0xC91C,
	0xFFFD: 0xC91D,
	0xFFFD: 0xC91E,
	0xFFFD: 0xC91F,
	0xFFFD: 0xC920,
	0xFFFD: 0xC921,
	0xFFFD: 0xC922,
	0xFFFD: 0xC923,
	0xFFFD: 0xC924,
	0xFFFD: 0xC925,
	0xFFFD: 0xC926,
	0xFFFD: 0xC927,
	0xFFFD: 0xC928,
	0xFFFD: 0xC929,
	0xFFFD: 0xC92A,
	0xFFFD: 0xC92B,
	0xFFFD: 0xC92C,
	0xFFFD: 0xC92D,
	0xFFFD: 0xC92E,
	0xFFFD: 0xC92F,
	0xFFFD: 0xC930,
	0xFFFD: 0xC931,
	0xFFFD: 0xC932,
	0xFFFD: 0xC933,
	0xFFFD: 0xC934,
	0xFFFD: 0xC935,
	0xFFFD: 0xC936,
	0xFFFD: 0xC937,
	0xFFFD: 0xC938,
	0xFFFD: 0xC939,
	0xFFFD: 0xC93A,
	0xFFFD: 0xC93B,
	0xFFFD: 0xC93C,
	0xFFFD: 0xC93D,
	0xFFFD: 0xC93E,
	0xFFFD: 0xC93F,
	0xFFFD: 0xC940,
	0xFFFD: 0xC941,
	0xFFFD: 0xC942,
	0xFFFD: 0xC943,
	0xFFFD: 0xC944,
	0xFFFD: 0xC945,
	0xFFFD: 0xC946,
	0xFFFD: 0xC947,
	0xFFFD: 0xC948,
	0xFFFD: 0xC949,
	0xFFFD: 0xC94A,
	0xFFFD: 0xC94B,
	0xFFFD: 0xC94C,
	0xFFFD: 0xC94D,
	0xFFFD: 0xC94E,
	0xFFFD: 0xC94F,
	0xFFFD: 0xC950,
	0xFFFD: 0xC951,
	0xFFFD: 0xC952,
	0xFFFD: 0xC953,
	0xFFFD: 0xC954,
	0xFFFD: 0xC955,
	0xFFFD: 0xC956,
	0xFFFD: 0xC957,
	0xFFFD: 0xC958,
	0xFFFD: 0xC959,
	0xFFFD: 0xC95A,
	0xFFFD: 0xC95B,
	0xFFFD: 0xC95C,
	0xFFFD: 0xC95D,
	0xFFFD: 0xC95E,
	0xFFFD: 0xC95F,
	0xFFFD: 0xC960,
	0xFFFD: 0xC961,
	0xFFFD: 0xC962,
	0xFFFD: 0xC963,
	0xFFFD: 0xC964,
	0xFFFD: 0xC965,
	0xFFFD: 0xC966,
	0xFFFD: 0xC967,
	0xFFFD: 0xC968,
	0xFFFD: 0xC969,
	0xFFFD: 0xC96A,
	0xFFFD: 0xC96B,
	0xFFFD: 0xC96C,
	0xFFFD: 0xC96D,
	0xFFFD: 0xC96E,
	0xFFFD: 0xC96F,
	0xFFFD: 0xC970,
	0xFFFD: 0xC971,
	0xFFFD: 0xC972,
	0xFFFD: 0xC973,
	0xFFFD: 0xC974,
	0xFFFD: 0xC975,
	0xFFFD: 0xC976,
	0xFFFD: 0xC977,
	0xFFFD: 0xC978,
	0xFFFD: 0xC979,
	0xFFFD: 0xC97A,
	0xFFFD: 0xC97B,
	0xFFFD: 0xC97C,
	0xFFFD: 0xC97D,
	0xFFFD: 0xC97E,
	0xFFFD: 0xC97F,
	0xFFFD: 0xC980,
	0xFFFD: 0xC981,
	0xFFFD: 0xC982,
	0xFFFD: 0xC983,
	0xFFFD: 0xC984,
	0xFFFD: 0xC985,
	0xFFFD: 0xC986,
	0xFFFD: 0xC987,
	0xFFFD: 0xC988,
	0xFFFD: 0xC989,
	0xFFFD: 0xC98A,
	0xFFFD: 0xC98B,
	0xFFFD: 0xC98C,
	0xFFFD: 0xC98D,
	0xFFFD: 0xC98E,
	0xFFFD: 0xC98F,
	0xFFFD: 0xC990,
	0xFFFD: 0xC991,
	0xFFFD: 0xC992,
	0xFFFD: 0xC993,
	0xFFFD: 0xC994,
	0xFFFD: 0xC995,
	0xFFFD: 0xC996,
	0xFFFD: 0xC997,
	0xFFFD: 0xC998,
	0xFFFD: 0xC999,
	0xFFFD: 0xC99A,
	0xFFFD: 0xC99B,
	0xFFFD: 0xC99C,
	0xFFFD: 0xC99D,
	0xFFFD: 0xC99E,
	0xFFFD: 0xC99F,
	0xFFFD: 0xC9A0,
	0xFFFD: 0xC9A1,
	0xFFFD: 0xC9A2,
	0xFFFD: 0xC9A3,
	0xFFFD: 0xC9A4,
	0xFFFD: 0xC9A5,
	0xFFFD: 0xC9A6,
	0xFFFD: 0xC9A7,
	0xFFFD: 0xC9A8,
	0xFFFD: 0xC9A9,
	0xFFFD: 0xC9AA,
	0xFFFD: 0xC9AB,
	0xFFFD: 0xC9AC,
	0xFFFD: 0xC9AD,
	0xFFFD: 0xC9AE,
	0xFFFD: 0xC9AF,
	0xFFFD: 0xC9B0,
	0xFFFD: 0xC9B1,
	0xFFFD: 0xC9B2,
	0xFFFD: 0xC9B3,
	0xFFFD: 0xC9B4,
	0xFFFD: 0xC9B5,
	0xFFFD: 0xC9B6,
	0xFFFD: 0xC9B7,
	0xFFFD: 0xC9B8,
	0xFFFD: 0xC9B9,
	0xFFFD: 0xC9BA,
	0xFFFD: 0xC9BB,
	0xFFFD: 0xC9BC,
	0xFFFD: 0xC9BD,
	0xFFFD: 0xC9BE,
	0xFFFD: 0xC9BF,
	0xFFFD: 0xC9C0,
	0xFFFD: 0xC9C1,
	0xFFFD: 0xC9C2,
	0xFFFD: 0xC9C3,
	0xFFFD: 0xC9C4,
	0xFFFD: 0xC9C5,
	0xFFFD: 0xC9C6,
	0xFFFD: 0xC9C7,
	0xFFFD: 0xC9C8,
	0xFFFD: 0xC9C9,
	0xFFFD: 0xC9CA,
	0xFFFD: 0xC9CB,
	0xFFFD: 0xC9CC,
	0xFFFD: 0xC9CD,
	0xFFFD: 0xC9CE,
	0xFFFD: 0xC9CF,
	0xFFFD: 0xC9D0,
	0xFFFD: 0xC9D1,
	0xFFFD: 0xC9D2,
	0xFFFD: 0xC9D3,
	0xFFFD: 0xC9D4,
	0xFFFD: 0xC9D5,
	0xFFFD: 0xC9D6,
	0xFFFD: 0xC9D7,
	0xFFFD: 0xC9D8,
	0xFFFD: 0xC9D9,
	0xFFFD: 0xC9DA,
	0xFFFD: 0xC9DB,
	0xFFFD: 0xC9DC,
	0xFFFD: 0xC9DD,
	0xFFFD: 0xC9DE,
	0xFFFD: 0xC9DF,
	0xFFFD: 0xC9E0,
	0xFFFD: 0xC9E1,
	0xFFFD: 0xC9E2,
	0xFFFD: 0xC9E3,
	0xFFFD: 0xC9E4,
	0xFFFD: 0xC9E5,
	0xFFFD: 0xC9E6,
	0xFFFD: 0xC9E7,
	0xFFFD: 0xC9E8,
	0xFFFD: 0xC9E9,
	0xFFFD: 0xC9EA,
	0xFFFD: 0xC9EB,
	0xFFFD: 0xC9EC,
	0xFFFD: 0xC9ED,
	0xFFFD: 0xC9EE,
	0xFFFD: 0xC9EF,
	0xFFFD: 0xC9F0,
	0xFFFD: 0xC9F1,
	0xFFFD: 0xC9F2,
	0xFFFD: 0xC9F3,
	0xFFFD: 0xC9F4,
	0xFFFD: 0xC9F5,
	0xFFFD: 0xC9F6,
	0xFFFD: 0xC9F7,
	0xFFFD: 0xC9F8,
	0xFFFD: 0xC9F9,
	0xFFFD: 0xC9FA,
	0xFFFD: 0xC9FB,
	0xFFFD: 0xC9FC,
	0xFFFD: 0xC9FD,
	0xFFFD: 0xC9FE,
	0xFFFD: 0xC9FF,
	0xFFFD: 0xCA00,
	0xFFFD: 0xCA01,
	0xFFFD: 0xCA02,
	0xFFFD: 0xCA03,
	0xFFFD: 0xCA04,
	0xFFFD: 0xCA05,
	0xFFFD: 0xCA06,
	0xFFFD: 0xCA07,
	0xFFFD: 0xCA08,
	0xFFFD: 0xCA09,
	0xFFFD: 0xCA0A,
	0xFFFD: 0xCA0B,
	0xFFFD: 0xCA0C,
	0xFFFD: 0xCA0D,
	0xFFFD: 0xCA0E,
	0xFFFD: 0xCA0F,
	0xFFFD: 0xCA10,
	0xFFFD: 0xCA11,
	0xFFFD: 0xCA12,
	0xFFFD: 0xCA13,
	0xFFFD: 0xCA14,
	0xFFFD: 0xCA15,
	0xFFFD: 0xCA16,
	0xFFFD: 0xCA17,
	0xFFFD: 0xCA18,
	0xFFFD: 0xCA19,
	0xFFFD: 0xCA1A,
	0xFFFD: 0xCA1B,
	0xFFFD: 0xCA1C,
	0xFFFD: 0xCA1D,
	0xFFFD: 0xCA1E,
	0xFFFD: 0xCA1F,
	0xFFFD: 0xCA20,
	0xFFFD: 0xCA21,
	0xFFFD: 0xCA22,
	0xFFFD: 0xCA23,
	0xFFFD: 0xCA24,
	0xFFFD: 0xCA25,
	0xFFFD: 0xCA26,
	0xFFFD: 0xCA27,
	0xFFFD: 0xCA28,
	0xFFFD: 0xCA29,
	0xFFFD: 0xCA2A,
	0xFFFD: 0xCA2B,
	0xFFFD: 0xCA2C,
	0xFFFD: 0xCA2D,
	0xFFFD: 0xCA2E,
	0xFFFD: 0xCA2F,
	0xFFFD: 0xCA30,
	0xFFFD: 0xCA31,
	0xFFFD: 0xCA32,
	0xFFFD: 0xCA33,
	0xFFFD: 0xCA34,
	0xFFFD: 0xCA35,
	0xFFFD: 0xCA36,
	0xFFFD: 0xCA37,
	0xFFFD: 0xCA38,
	0xFFFD: 0xCA39,
	0xFFFD: 0xCA3A,
	0xFFFD: 0xCA3B,
	0xFFFD: 0xCA3C,
	0xFFFD: 0xCA3D,
	0xFFFD: 0xCA3E,
	0xFFFD: 0xCA3F,
	0xFFFD: 0xCA40,
	0xFFFD: 0xCA41,
	0xFFFD: 0xCA42,
	0xFFFD: 0xCA43,
	0xFFFD: 0xCA44,
	0xFFFD: 0xCA45,
	0xFFFD: 0xCA46,
	0xFFFD: 0xCA47,
	0xFFFD: 0xCA48,
	0xFFFD: 0xCA49,
	0xFFFD: 0xCA4A,
	0xFFFD: 0xCA4B,
	0xFFFD: 0xCA4C,
	0xFFFD: 0xCA4D,
	0xFFFD: 0xCA4E,
	0xFFFD: 0xCA4F,
	0xFFFD: 0xCA50,
	0xFFFD: 0xCA51,
	0xFFFD: 0xCA52,
	0xFFFD: 0xCA53,
	0xFFFD: 0xCA54,
	0xFFFD: 0xCA55,
	0xFFFD: 0xCA56,
	0xFFFD: 0xCA57,
	0xFFFD: 0xCA58,
	0xFFFD: 0xCA59,
	0xFFFD: 0xCA5A,
	0xFFFD: 0xCA5B,
	0xFFFD: 0xCA5C,
	0xFFFD: 0xCA5D,
	0xFFFD: 0xCA5E,
	0xFFFD: 0xCA5F,
	0xFFFD: 0xCA60,
	0xFFFD: 0xCA61,
	0xFFFD: 0xCA62,
	0xFFFD: 0xCA63,
	0xFFFD: 0xCA64,
	0xFFFD: 0xCA65,
	0xFFFD: 0xCA66,
	0xFFFD: 0xCA67,
	0xFFFD: 0xCA68,
	0xFFFD: 0xCA69,
	0xFFFD: 0xCA6A,
	0xFFFD: 0xCA6B,
	0xFFFD: 0xCA6C,
	0xFFFD: 0xCA6D,
	0xFFFD: 0xCA6E,
	0xFFFD: 0xCA6F,
	0xFFFD: 0xCA70,
	0xFFFD: 0xCA71,
	0xFFFD: 0xCA72,
	0xFFFD: 0xCA73,
	0xFFFD: 0xCA74,
	0xFFFD: 0xCA75,
	0xFFFD: 0xCA76,
	0xFFFD: 0xCA77,
	0xFFFD: 0xCA78,
	0xFFFD: 0xCA79,
	0xFFFD: 0xCA7A,
	0xFFFD: 0xCA7B,
	0xFFFD: 0xCA7C,
	0xFFFD: 0xCA7D,
	0xFFFD: 0xCA7E,
	0xFFFD: 0xCA7F,
	0xFFFD: 0xCA80,
	0xFFFD: 0xCA81,
	0xFFFD: 0xCA82,
	0xFFFD: 0xCA83,
	0xFFFD: 0xCA84,
	0xFFFD: 0xCA85,
	0xFFFD: 0xCA86,
	0xFFFD: 0xCA87,
	0xFFFD: 0xCA88,
	0xFFFD: 0xCA89,
	0xFFFD: 0xCA8A,
	0xFFFD: 0xCA8B,
	0xFFFD: 0xCA8C,
	0xFFFD: 0xCA8D,
	0xFFFD: 0xCA8E,
	0xFFFD: 0xCA8F,
	0xFFFD: 0xCA90,
	0xFFFD: 0xCA91,
	0xFFFD: 0xCA92,
	0xFFFD: 0xCA93,
	0xFFFD: 0xCA94,
	0xFFFD: 0xCA95,
	0xFFFD: 0xCA96,
	0xFFFD: 0xCA97,
	0xFFFD: 0xCA98,
	0xFFFD: 0xCA99,
	0xFFFD: 0xCA9A,
	0xFFFD: 0xCA9B,
	0xFFFD: 0xCA9C,
	0xFFFD: 0xCA9D,
	0xFFFD: 0xCA9E,
	0xFFFD: 0xCA9F,
	0xFFFD: 0xCAA0,
	0xFFFD: 0xCAA1,
	0xFFFD: 0xCAA2,
	0xFFFD: 0xCAA3,
	0xFFFD: 0xCAA4,
	0xFFFD: 0xCAA5,
	0xFFFD: 0xCAA6,
	0xFFFD: 0xCAA7,
	0xFFFD: 0xCAA8,
	0xFFFD: 0xCAA9,
	0xFFFD: 0xCAAA,
	0xFFFD: 0xCAAB,
	0xFFFD: 0xCAAC,
	0xFFFD: 0xCAAD,
	0xFFFD: 0xCAAE,
	0xFFFD: 0xCAAF,
	0xFFFD: 0xCAB0,
	0xFFFD: 0xCAB1,
	0xFFFD: 0xCAB2,
	0xFFFD: 0xCAB3,
	0xFFFD: 0xCAB4,
	0xFFFD: 0xCAB5,
	0xFFFD: 0xCAB6,
	0xFFFD: 0xCAB7,
	0xFFFD: 0xCAB8,
	0xFFFD: 0xCAB9,
	0xFFFD: 0xCABA,
	0xFFFD: 0xCABB,
	0xFFFD: 0xCABC,
	0xFFFD: 0xCABD,
	0xFFFD: 0xCABE,
	0xFFFD: 0xCABF,
	0xFFFD: 0xCAC0,
	0xFFFD: 0xCAC1,
	0xFFFD: 0xCAC2,
	0xFFFD: 0xCAC3,
	0xFFFD: 0xCAC4,
	0xFFFD: 0xCAC5,
	0xFFFD: 0xCAC6,
	0xFFFD: 0xCAC7,
	0xFFFD: 0xCAC8,
	0xFFFD: 0xCAC9,
	0xFFFD: 0xCACA,
	0xFFFD: 0xCACB,
	0xFFFD: 0xCACC,
	0xFFFD: 0xCACD,
	0xFFFD: 0xCACE,
	0xFFFD: 0xCACF,
	0xFFFD: 0xCAD0,
	0xFFFD: 0xCAD1,
	0xFFFD: 0xCAD2,
	0xFFFD: 0xCAD3,
	0xFFFD: 0xCAD4,
	0xFFFD: 0xCAD5,
	0xFFFD: 0xCAD6,
	0xFFFD: 0xCAD7,
	0xFFFD: 0xCAD8,
	0xFFFD: 0xCAD9,
	0xFFFD: 0xCADA,
	0xFFFD: 0xCADB,
	0xFFFD: 0xCADC,
	0xFFFD: 0xCADD,
	0xFFFD: 0xCADE,
	0xFFFD: 0xCADF,
	0xFFFD: 0xCAE0,
	0xFFFD: 0xCAE1,
	0xFFFD: 0xCAE2,
	0xFFFD: 0xCAE3,
	0xFFFD: 0xCAE4,
	0xFFFD: 0xCAE5,
	0xFFFD: 0xCAE6,
	0xFFFD: 0xCAE7,
	0xFFFD: 0xCAE8,
	0xFFFD: 0xCAE9,
	0xFFFD: 0xCAEA,
	0xFFFD: 0xCAEB,
	0xFFFD: 0xCAEC,
	0xFFFD: 0xCAED,
	0xFFFD: 0xCAEE,
	0xFFFD: 0xCAEF,
	0xFFFD: 0xCAF0,
	0xFFFD: 0xCAF1,
	0xFFFD: 0xCAF2,
	0xFFFD: 0xCAF3,
	0xFFFD: 0xCAF4,
	0xFFFD: 0xCAF5,
	0xFFFD: 0xCAF6,
	0xFFFD: 0xCAF7,
	0xFFFD: 0xCAF8,
	0xFFFD: 0xCAF9,
	0xFFFD: 0xCAFA,
	0xFFFD: 0xCAFB,
	0xFFFD: 0xCAFC,
	0xFFFD: 0xCAFD,
	0xFFFD: 0xCAFE,
	0xFFFD: 0xCAFF,
	0xFFFD: 0xCB00,
	0xFFFD: 0xCB01,
	0xFFFD: 0xCB02,
	0xFFFD: 0xCB03,
	0xFFFD: 0xCB04,
	0xFFFD: 0xCB05,
	0xFFFD: 0xCB06,
	0xFFFD: 0xCB07,
	0xFFFD: 0xCB08,
	0xFFFD: 0xCB09,
	0xFFFD: 0xCB0A,
	0xFFFD: 0xCB0B,
	0xFFFD: 0xCB0C,
	0xFFFD: 0xCB0D,
	0xFFFD: 0xCB0E,
	0xFFFD: 0xCB0F,
	0xFFFD: 0xCB10,
	0xFFFD: 0xCB11,
	0xFFFD: 0xCB12,
	0xFFFD: 0xCB13,
	0xFFFD: 0xCB14,
	0xFFFD: 0xCB15,
	0xFFFD: 0xCB16,
	0xFFFD: 0xCB17,
	0xFFFD: 0xCB18,
	0xFFFD: 0xCB19,
	0xFFFD: 0xCB1A,
	0xFFFD: 0xCB1B,
	0xFFFD: 0xCB1C,
	0xFFFD: 0xCB1D,
	0xFFFD: 0xCB1E,
	0xFFFD: 0xCB1F,
	0xFFFD: 0xCB20,
	0xFFFD: 0xCB21,
	0xFFFD: 0xCB22,
	0xFFFD: 0xCB23,
	0xFFFD: 0xCB24,
	0xFFFD: 0xCB25,
	0xFFFD: 0xCB26,
	0xFFFD: 0xCB27,
	0xFFFD: 0xCB28,
	0xFFFD: 0xCB29,
	0xFFFD: 0xCB2A,
	0xFFFD: 0xCB2B,
	0xFFFD: 0xCB2C,
	0xFFFD: 0xCB2D,
	0xFFFD: 0xCB2E,
	0xFFFD: 0xCB2F,
	0xFFFD: 0xCB30,
	0xFFFD: 0xCB31,
	0xFFFD: 0xCB32,
	0xFFFD: 0xCB33,
	0xFFFD: 0xCB34,
	0xFFFD: 0xCB35,
	0xFFFD: 0xCB36,
	0xFFFD: 0xCB37,
	0xFFFD: 0xCB38,
	0xFFFD: 0xCB39,
	0xFFFD: 0xCB3A,
	0xFFFD: 0xCB3B,
	0xFFFD: 0xCB3C,
	0xFFFD: 0xCB3D,
	0xFFFD: 0xCB3E,
	0xFFFD: 0xCB3F,
	0xFFFD: 0xCB40,
	0xFFFD: 0xCB41,
	0xFFFD: 0xCB42,
	0xFFFD: 0xCB43,
	0xFFFD: 0xCB44,
	0xFFFD: 0xCB45,
	0xFFFD: 0xCB46,
	0xFFFD: 0xCB47,
	0xFFFD: 0xCB48,
	0xFFFD: 0xCB49,
	0xFFFD: 0xCB4A,
	0xFFFD: 0xCB4B,
	0xFFFD: 0xCB4C,
	0xFFFD: 0xCB4D,
	0xFFFD: 0xCB4E,
	0xFFFD: 0xCB4F,
	0xFFFD: 0xCB50,
	0xFFFD: 0xCB51,
	0xFFFD: 0xCB52,
	0xFFFD: 0xCB53,
	0xFFFD: 0xCB54,
	0xFFFD: 0xCB55,
	0xFFFD: 0xCB56,
	0xFFFD: 0xCB57,
	0xFFFD: 0xCB58,
	0xFFFD: 0xCB59,
	0xFFFD: 0xCB5A,
	0xFFFD: 0xCB5B,
	0xFFFD: 0xCB5C,
	0xFFFD: 0xCB5D,
	0xFFFD: 0xCB5E,
	0xFFFD: 0xCB5F,
	0xFFFD: 0xCB60,
	0xFFFD: 0xCB61,
	0xFFFD: 0xCB62,
	0xFFFD: 0xCB63,
	0xFFFD: 0xCB64,
	0xFFFD: 0xCB65,
	0xFFFD: 0xCB66,
	0xFFFD: 0xCB67,
	0xFFFD: 0xCB68,
	0xFFFD: 0xCB69,
	0xFFFD: 0xCB6A,
	0xFFFD: 0xCB6B,
	0xFFFD: 0xCB6C,
	0xFFFD: 0xCB6D,
	0xFFFD: 0xCB6E,
	0xFFFD: 0xCB6F,
	0xFFFD: 0xCB70,
	0xFFFD: 0xCB71,
	0xFFFD: 0xCB72,
	0xFFFD: 0xCB73,
	0xFFFD: 0xCB74,
	0xFFFD: 0xCB75,
	0xFFFD: 0xCB76,
	0xFFFD: 0xCB77,
	0xFFFD: 0xCB78,
	0xFFFD: 0xCB79,
	0xFFFD: 0xCB7A,
	0xFFFD: 0xCB7B,
	0xFFFD: 0xCB7C,
	0xFFFD: 0xCB7D,
	0xFFFD: 0xCB7E,
	0xFFFD: 0xCB7F,
	0xFFFD: 0xCB80,
	0xFFFD: 0xCB81,
	0xFFFD: 0xCB82,
	0xFFFD: 0xCB83,
	0xFFFD: 0xCB84,
	0xFFFD: 0xCB85,
	0xFFFD: 0xCB86,
	0xFFFD: 0xCB87,
	0xFFFD: 0xCB88,
	0xFFFD: 0xCB89,
	0xFFFD: 0xCB8A,
	0xFFFD: 0xCB8B,
	0xFFFD: 0xCB8C,
	0xFFFD: 0xCB8D,
	0xFFFD: 0xCB8E,
	0xFFFD: 0xCB8F,
	0xFFFD: 0xCB90,
	0xFFFD: 0xCB91,
	0xFFFD: 0xCB92,
	0xFFFD: 0xCB93,
	0xFFFD: 0xCB94,
	0xFFFD: 0xCB95,
	0xFFFD: 0xCB96,
	0xFFFD: 0xCB97,
	0xFFFD: 0xCB98,
	0xFFFD: 0xCB99,
	0xFFFD: 0xCB9A,
	0xFFFD: 0xCB9B,
	0xFFFD: 0xCB9C,
	0xFFFD: 0xCB9D,
	0xFFFD: 0xCB9E,
	0xFFFD: 0xCB9F,
	0xFFFD: 0xCBA0,
	0xFFFD: 0xCBA1,
	0xFFFD: 0xCBA2,
	0xFFFD: 0xCBA3,
	0xFFFD: 0xCBA4,
	0xFFFD: 0xCBA5,
	0xFFFD: 0xCBA6,
	0xFFFD: 0xCBA7,
	0xFFFD: 0xCBA8,
	0xFFFD: 0xCBA9,
	0xFFFD: 0xCBAA,
	0xFFFD: 0xCBAB,
	0xFFFD: 0xCBAC,
	0xFFFD: 0xCBAD,
	0xFFFD: 0xCBAE,
	0xFFFD: 0xCBAF,
	0xFFFD: 0xCBB0,
	0xFFFD: 0xCBB1,
	0xFFFD: 0xCBB2,
	0xFFFD: 0xCBB3,
	0xFFFD: 0xCBB4,
	0xFFFD: 0xCBB5,
	0xFFFD: 0xCBB6,
	0xFFFD: 0xCBB7,
	0xFFFD: 0xCBB8,
	0xFFFD: 0xCBB9,
	0xFFFD: 0xCBBA,
	0xFFFD: 0xCBBB,
	0xFFFD: 0xCBBC,
	0xFFFD: 0xCBBD,
	0xFFFD: 0xCBBE,
	0xFFFD: 0xCBBF,
	0xFFFD: 0xCBC0,
	0xFFFD: 0xCBC1,
	0xFFFD: 0xCBC2,
	0xFFFD: 0xCBC3,
	0xFFFD: 0xCBC4,
	0xFFFD: 0xCBC5,
	0xFFFD: 0xCBC6,
	0xFFFD: 0xCBC7,
	0xFFFD: 0xCBC8,
	0xFFFD: 0xCBC9,
	0xFFFD: 0xCBCA,
	0xFFFD: 0xCBCB,
	0xFFFD: 0xCBCC,
	0xFFFD: 0xCBCD,
	0xFFFD: 0xCBCE,
	0xFFFD: 0xCBCF,
	0xFFFD: 0xCBD0,
	0xFFFD: 0xCBD1,
	0xFFFD: 0xCBD2,
	0xFFFD: 0xCBD3,
	0xFFFD: 0xCBD4,
	0xFFFD: 0xCBD5,
	0xFFFD: 0xCBD6,
	0xFFFD: 0xCBD7,
	0xFFFD: 0xCBD8,
	0xFFFD: 0xCBD9,
	0xFFFD: 0xCBDA,
	0xFFFD: 0xCBDB,
	0xFFFD: 0xCBDC,
	0xFFFD: 0xCBDD,
	0xFFFD: 0xCBDE,
	0xFFFD: 0xCBDF,
	0xFFFD: 0xCBE0,
	0xFFFD: 0xCBE1,
	0xFFFD: 0xCBE2,
	0xFFFD: 0xCBE3,
	0xFFFD: 0xCBE4,
	0xFFFD: 0xCBE5,
	0xFFFD: 0xCBE6,
	0xFFFD: 0xCBE7,
	0xFFFD: 0xCBE8,
	0xFFFD: 0xCBE9,
	0xFFFD: 0xCBEA,
	0xFFFD: 0xCBEB,
	0xFFFD: 0xCBEC,
	0xFFFD: 0xCBED,
	0xFFFD: 0xCBEE,
	0xFFFD: 0xCBEF,
	0xFFFD: 0xCBF0,
	0xFFFD: 0xCBF1,
	0xFFFD: 0xCBF2,
	0xFFFD: 0xCBF3,
	0xFFFD: 0xCBF4,
	0xFFFD: 0xCBF5,
	0xFFFD: 0xCBF6,
	0xFFFD: 0xCBF7,
	0xFFFD: 0xCBF8,
	0xFFFD: 0xCBF9,
	0xFFFD: 0xCBFA,
	0xFFFD: 0xCBFB,
	0xFFFD: 0xCBFC,
	0xFFFD: 0xCBFD,
	0xFFFD: 0xCBFE,
	0xFFFD: 0xCBFF,
	0xFFFD: 0xCC00,
	0xFFFD: 0xCC01,
	0xFFFD: 0xCC02,
	0xFFFD: 0xCC03,
	0xFFFD: 0xCC04,
	0xFFFD: 0xCC05,
	0xFFFD: 0xCC06,
	0xFFFD: 0xCC07,
	0xFFFD: 0xCC08,
	0xFFFD: 0xCC09,
	0xFFFD: 0xCC0A,
	0xFFFD: 0xCC0B,
	0xFFFD: 0xCC0C,
	0xFFFD: 0xCC0D,
	0xFFFD: 0xCC0E,
	0xFFFD: 0xCC0F,
	0xFFFD: 0xCC10,
	0xFFFD: 0xCC11,
	0xFFFD: 0xCC12,
	0xFFFD: 0xCC13,
	0xFFFD: 0xCC14,
	0xFFFD: 0xCC15,
	0xFFFD: 0xCC16,
	0xFFFD: 0xCC17,
	0xFFFD: 0xCC18,
	0xFFFD: 0xCC19,
	0xFFFD: 0xCC1A,
	0xFFFD: 0xCC1B,
	0xFFFD: 0xCC1C,
	0xFFFD: 0xCC1D,
	0xFFFD: 0xCC1E,
	0xFFFD: 0xCC1F,
	0xFFFD: 0xCC20,
	0xFFFD: 0xCC21,
	0xFFFD: 0xCC22,
	0xFFFD: 0xCC23,
	0xFFFD: 0xCC24,
	0xFFFD: 0xCC25,
	0xFFFD: 0xCC26,
	0xFFFD: 0xCC27,
	0xFFFD: 0xCC28,
	0xFFFD: 0xCC29,
	0xFFFD: 0xCC2A,
	0xFFFD: 0xCC2B,
	0xFFFD: 0xCC2C,
	0xFFFD: 0xCC2D,
	0xFFFD: 0xCC2E,
	0xFFFD: 0xCC2F,
	0xFFFD: 0xCC30,
	0xFFFD: 0xCC31,
	0xFFFD: 0xCC32,
	0xFFFD: 0xCC33,
	0xFFFD: 0xCC34,
	0xFFFD: 0xCC35,
	0xFFFD: 0xCC36,
	0xFFFD: 0xCC37,
	0xFFFD: 0xCC38,
	0xFFFD: 0xCC39,
	0xFFFD: 0xCC3A,
	0xFFFD: 0xCC3B,
	0xFFFD: 0xCC3C,
	0xFFFD: 0xCC3D,
	0xFFFD: 0xCC3E,
	0xFFFD: 0xCC3F,
	0xFFFD: 0xCC40,
	0xFFFD: 0xCC41,
	0xFFFD: 0xCC42,
	0xFFFD: 0xCC43,
	0xFFFD: 0xCC44,
	0xFFFD: 0xCC45,
	0xFFFD: 0xCC46,
	0xFFFD: 0xCC47,
	0xFFFD: 0xCC48,
	0xFFFD: 0xCC49,
	0xFFFD: 0xCC4A,
	0xFFFD: 0xCC4B,
	0xFFFD: 0xCC4C,
	0xFFFD: 0xCC4D,
	0xFFFD: 0xCC4E,
	0xFFFD: 0xCC4F,
	0xFFFD: 0xCC50,
	0xFFFD: 0xCC51,
	0xFFFD: 0xCC52,
	0xFFFD: 0xCC53,
	0xFFFD: 0xCC54,
	0xFFFD: 0xCC55,
	0xFFFD: 0xCC56,
	0xFFFD: 0xCC57,
	0xFFFD: 0xCC58,
	0xFFFD: 0xCC59,
	0xFFFD: 0xCC5A,
	0xFFFD: 0xCC5B,
	0xFFFD: 0xCC5C,
	0xFFFD: 0xCC5D,
	0xFFFD: 0xCC5E,
	0xFFFD: 0xCC5F,
	0xFFFD: 0xCC60,
	0xFFFD: 0xCC61,
	0xFFFD: 0xCC62,
	0xFFFD: 0xCC63,
	0xFFFD: 0xCC64,
	0xFFFD: 0xCC65,
	0xFFFD: 0xCC66,
	0xFFFD: 0xCC67,
	0xFFFD: 0xCC68,
	0xFFFD: 0xCC69,
	0xFFFD: 0xCC6A,
	0xFFFD: 0xCC6B,
	0xFFFD: 0xCC6C,
	0xFFFD: 0xCC6D,
	0xFFFD: 0xCC6E,
	0xFFFD: 0xCC6F,
	0xFFFD: 0xCC70,
	0xFFFD: 0xCC71,
	0xFFFD: 0xCC72,
	0xFFFD: 0xCC73,
	0xFFFD: 0xCC74,
	0xFFFD: 0xCC75,
	0xFFFD: 0xCC76,
	0xFFFD: 0xCC77,
	0xFFFD: 0xCC78,
	0xFFFD: 0xCC79,
	0xFFFD: 0xCC7A,
	0xFFFD: 0xCC7B,
	0xFFFD: 0xCC7C,
	0xFFFD: 0xCC7D,
	0xFFFD: 0xCC7E,
	0xFFFD: 0xCC7F,
	0xFFFD: 0xCC80,
	0xFFFD: 0xCC81,
	0xFFFD: 0xCC82,
	0xFFFD: 0xCC83,
	0xFFFD: 0xCC84,
	0xFFFD: 0xCC85,
	0xFFFD: 0xCC86,
	0xFFFD: 0xCC87,
	0xFFFD: 0xCC88,
	0xFFFD: 0xCC89,
	0xFFFD: 0xCC8A,
	0xFFFD: 0xCC8B,
	0xFFFD: 0xCC8C,
	0xFFFD: 0xCC8D,
	0xFFFD: 0xCC8E,
	0xFFFD: 0xCC8F,
	0xFFFD: 0xCC90,
	0xFFFD: 0xCC91,
	0xFFFD: 0xCC92,
	0xFFFD: 0xCC93,
	0xFFFD: 0xCC94,
	0xFFFD: 0xCC95,
	0xFFFD: 0xCC96,
	0xFFFD: 0xCC97,
	0xFFFD: 0xCC98,
	0xFFFD: 0xCC99,
	0xFFFD: 0xCC9A,
	0xFFFD: 0xCC9B,
	0xFFFD: 0xCC9C,
	0xFFFD: 0xCC9D,
	0xFFFD: 0xCC9E,
	0xFFFD: 0xCC9F,
	0xFFFD: 0xCCA0,
	0xFFFD: 0xCCA1,
	0xFFFD: 0xCCA2,
	0xFFFD: 0xCCA3,
	0xFFFD: 0xCCA4,
	0xFFFD: 0xCCA5,
	0xFFFD: 0xCCA6,
	0xFFFD: 0xCCA7,
	0xFFFD: 0xCCA8,
	0xFFFD: 0xCCA9,
	0xFFFD: 0xCCAA,
	0xFFFD: 0xCCAB,
	0xFFFD: 0xCCAC,
	0xFFFD: 0xCCAD,
	0xFFFD: 0xCCAE,
	0xFFFD: 0xCCAF,
	0xFFFD: 0xCCB0,
	0xFFFD: 0xCCB1,
	0xFFFD: 0xCCB2,
	0xFFFD: 0xCCB3,
	0xFFFD: 0xCCB4,
	0xFFFD: 0xCCB5,
	0xFFFD: 0xCCB6,
	0xFFFD: 0xCCB7,
	0xFFFD: 0xCCB8,
	0xFFFD: 0xCCB9,
	0xFFFD: 0xCCBA,
	0xFFFD: 0xCCBB,
	0xFFFD: 0xCCBC,
	0xFFFD: 0xCCBD,
	0xFFFD: 0xCCBE,
	0xFFFD: 0xCCBF,
	0xFFFD: 0xCCC0,
	0xFFFD: 0xCCC1,
	0xFFFD: 0xCCC2,
	0xFFFD: 0xCCC3,
	0xFFFD: 0xCCC4,
	0xFFFD: 0xCCC5,
	0xFFFD: 0xCCC6,
	0xFFFD: 0xCCC7,
	0xFFFD: 0xCCC8,
	0xFFFD: 0xCCC9,
	0xFFFD: 0xCCCA,
	0xFFFD: 0xCCCB,
	0xFFFD: 0xCCCC,
	0xFFFD: 0xCCCD,
	0xFFFD: 0xCCCE,
	0xFFFD: 0xCCCF,
	0xFFFD: 0xCCD0,
	0xFFFD: 0xCCD1,
	0xFFFD: 0xCCD2,
	0xFFFD: 0xCCD3,
	0xFFFD: 0xCCD4,
	0xFFFD: 0xCCD5,
	0xFFFD: 0xCCD6,
	0xFFFD: 0xCCD7,
	0xFFFD: 0xCCD8,
	0xFFFD: 0xCCD9,
	0xFFFD: 0xCCDA,
	0xFFFD: 0xCCDB,
	0xFFFD: 0xCCDC,
	0xFFFD: 0xCCDD,
	0xFFFD: 0xCCDE,
	0xFFFD: 0xCCDF,
	0xFFFD: 0xCCE0,
	0xFFFD: 0xCCE1,
	0xFFFD: 0xCCE2,
	0xFFFD: 0xCCE3,
	0xFFFD: 0xCCE4,
	0xFFFD: 0xCCE5,
	0xFFFD: 0xCCE6,
	0xFFFD: 0xCCE7,
	0xFFFD: 0xCCE8,
	0xFFFD: 0xCCE9,
	0xFFFD: 0xCCEA,
	0xFFFD: 0xCCEB,
	0xFFFD: 0xCCEC,
	0xFFFD: 0xCCED,
	0xFFFD: 0xCCEE,
	0xFFFD: 0xCCEF,
	0xFFFD: 0xCCF0,
	0xFFFD: 0xCCF1,
	0xFFFD: 0xCCF2,
	0xFFFD: 0xCCF3,
	0xFFFD: 0xCCF4,
	0xFFFD: 0xCCF5,
	0xFFFD: 0xCCF6,
	0xFFFD: 0xCCF7,
	0xFFFD: 0xCCF8,
	0xFFFD: 0xCCF9,
	0xFFFD: 0xCCFA,
	0xFFFD: 0xCCFB,
	0xFFFD: 0xCCFC,
	0xFFFD: 0xCCFD,
	0xFFFD: 0xCCFE,
	0xFFFD: 0xCCFF,
	0xFFFD: 0xCD00,
	0xFFFD: 0xCD01,
	0xFFFD: 0xCD02,
	0xFFFD: 0xCD03,
	0xFFFD: 0xCD04,
	0xFFFD: 0xCD05,
	0xFFFD: 0xCD06,
	0xFFFD: 0xCD07,
	0xFFFD: 0xCD08,
	0xFFFD: 0xCD09,
	0xFFFD: 0xCD0A,
	0xFFFD: 0xCD0B,
	0xFFFD: 0xCD0C,
	0xFFFD: 0xCD0D,
	0xFFFD: 0xCD0E,
	0xFFFD: 0xCD0F,
	0xFFFD: 0xCD10,
	0xFFFD: 0xCD11,
	0xFFFD: 0xCD12,
	0xFFFD: 0xCD13,
	0xFFFD: 0xCD14,
	0xFFFD: 0xCD15,
	0xFFFD: 0xCD16,
	0xFFFD: 0xCD17,
	0xFFFD: 0xCD18,
	0xFFFD: 0xCD19,
	0xFFFD: 0xCD1A,
	0xFFFD: 0xCD1B,
	0xFFFD: 0xCD1C,
	0xFFFD: 0xCD1D,
	0xFFFD: 0xCD1E,
	0xFFFD: 0xCD1F,
	0xFFFD: 0xCD20,
	0xFFFD: 0xCD21,
	0xFFFD: 0xCD22,
	0xFFFD: 0xCD23,
	0xFFFD: 0xCD24,
	0xFFFD: 0xCD25,
	0xFFFD: 0xCD26,
	0xFFFD: 0xCD27,
	0xFFFD: 0xCD28,
	0xFFFD: 0xCD29,
	0xFFFD: 0xCD2A,
	0xFFFD: 0xCD2B,
	0xFFFD: 0xCD2C,
	0xFFFD: 0xCD2D,
	0xFFFD: 0xCD2E,
	0xFFFD: 0xCD2F,
	0xFFFD: 0xCD30,
	0xFFFD: 0xCD31,
	0xFFFD: 0xCD32,
	0xFFFD: 0xCD33,
	0xFFFD: 0xCD34,
	0xFFFD: 0xCD35,
	0xFFFD: 0xCD36,
	0xFFFD: 0xCD37,
	0xFFFD: 0xCD38,
	0xFFFD: 0xCD39,
	0xFFFD: 0xCD3A,
	0xFFFD: 0xCD3B,
	0xFFFD: 0xCD3C,
	0xFFFD: 0xCD3D,
	0xFFFD: 0xCD3E,
	0xFFFD: 0xCD3F,
	0xFFFD: 0xCD40,
	0xFFFD: 0xCD41,
	0xFFFD: 0xCD42,
	0xFFFD: 0xCD43,
	0xFFFD: 0xCD44,
	0xFFFD: 0xCD45,
	0xFFFD: 0xCD46,
	0xFFFD: 0xCD47,
	0xFFFD: 0xCD48,
	0xFFFD: 0xCD49,
	0xFFFD: 0xCD4A,
	0xFFFD: 0xCD4B,
	0xFFFD: 0xCD4C,
	0xFFFD: 0xCD4D,
	0xFFFD: 0xCD4E,
	0xFFFD: 0xCD4F,
	0xFFFD: 0xCD50,
	0xFFFD: 0xCD51,
	0xFFFD: 0xCD52,
	0xFFFD: 0xCD53,
	0xFFFD: 0xCD54,
	0xFFFD: 0xCD55,
	0xFFFD: 0xCD56,
	0xFFFD: 0xCD57,
	0xFFFD: 0xCD58,
	0xFFFD: 0xCD59,
	0xFFFD: 0xCD5A,
	0xFFFD: 0xCD5B,
	0xFFFD: 0xCD5C,
	0xFFFD: 0xCD5D,
	0xFFFD: 0xCD5E,
	0xFFFD: 0xCD5F,
	0xFFFD: 0xCD60,
	0xFFFD: 0xCD61,
	0xFFFD: 0xCD62,
	0xFFFD: 0xCD63,
	0xFFFD: 0xCD64,
	0xFFFD: 0xCD65,
	0xFFFD: 0xCD66,
	0xFFFD: 0xCD67,
	0xFFFD: 0xCD68,
	0xFFFD: 0xCD69,
	0xFFFD: 0xCD6A,
	0xFFFD: 0xCD6B,
	0xFFFD: 0xCD6C,
	0xFFFD: 0xCD6D,
	0xFFFD: 0xCD6E,
	0xFFFD: 0xCD6F,
	0xFFFD: 0xCD70,
	0xFFFD: 0xCD71,
	0xFFFD: 0xCD72,
	0xFFFD: 0xCD73,
	0xFFFD: 0xCD74,
	0xFFFD: 0xCD75,
	0xFFFD: 0xCD76,
	0xFFFD: 0xCD77,
	0xFFFD: 0xCD78,
	0xFFFD: 0xCD79,
	0xFFFD: 0xCD7A,
	0xFFFD: 0xCD7B,
	0xFFFD: 0xCD7C,
	0xFFFD: 0xCD7D,
	0xFFFD: 0xCD7E,
	0xFFFD: 0xCD7F,
	0xFFFD: 0xCD80,
	0xFFFD: 0xCD81,
	0xFFFD: 0xCD82,
	0xFFFD: 0xCD83,
	0xFFFD: 0xCD84,
	0xFFFD: 0xCD85,
	0xFFFD: 0xCD86,
	0xFFFD: 0xCD87,
	0xFFFD: 0xCD88,
	0xFFFD: 0xCD89,
	0xFFFD: 0xCD8A,
	0xFFFD: 0xCD8B,
	0xFFFD: 0xCD8C,
	0xFFFD: 0xCD8D,
	0xFFFD: 0xCD8E,
	0xFFFD: 0xCD8F,
	0xFFFD: 0xCD90,
	0xFFFD: 0xCD91,
	0xFFFD: 0xCD92,
	0xFFFD: 0xCD93,
	0xFFFD: 0xCD94,
	0xFFFD: 0xCD95,
	0xFFFD: 0xCD96,
	0xFFFD: 0xCD97,
	0xFFFD: 0xCD98,
	0xFFFD: 0xCD99,
	0xFFFD: 0xCD9A,
	0xFFFD: 0xCD9B,
	0xFFFD: 0xCD9C,
	0xFFFD: 0xCD9D,
	0xFFFD: 0xCD9E,
	0xFFFD: 0xCD9F,
	0xFFFD: 0xCDA0,
	0xFFFD: 0xCDA1,
	0xFFFD: 0xCDA2,
	0xFFFD: 0xCDA3,
	0xFFFD: 0xCDA4,
	0xFFFD: 0xCDA5,
	0xFFFD: 0xCDA6,
	0xFFFD: 0xCDA7,
	0xFFFD: 0xCDA8,
	0xFFFD: 0xCDA9,
	0xFFFD: 0xCDAA,
	0xFFFD: 0xCDAB,
	0xFFFD: 0xCDAC,
	0xFFFD: 0xCDAD,
	0xFFFD: 0xCDAE,
	0xFFFD: 0xCDAF,
	0xFFFD: 0xCDB0,
	0xFFFD: 0xCDB1,
	0xFFFD: 0xCDB2,
	0xFFFD: 0xCDB3,
	0xFFFD: 0xCDB4,
	0xFFFD: 0xCDB5,
	0xFFFD: 0xCDB6,
	0xFFFD: 0xCDB7,
	0xFFFD: 0xCDB8,
	0xFFFD: 0xCDB9,
	0xFFFD: 0xCDBA,
	0xFFFD: 0xCDBB,
	0xFFFD: 0xCDBC,
	0xFFFD: 0xCDBD,
	0xFFFD: 0xCDBE,
	0xFFFD: 0xCDBF,
	0xFFFD: 0xCDC0,
	0xFFFD: 0xCDC1,
	0xFFFD: 0xCDC2,
	0xFFFD: 0xCDC3,
	0xFFFD: 0xCDC4,
	0xFFFD: 0xCDC5,
	0xFFFD: 0xCDC6,
	0xFFFD: 0xCDC7,
	0xFFFD: 0xCDC8,
	0xFFFD: 0xCDC9,
	0xFFFD: 0xCDCA,
	0xFFFD: 0xCDCB,
	0xFFFD: 0xCDCC,
	0xFFFD: 0xCDCD,
	0xFFFD: 0xCDCE,
	0xFFFD: 0xCDCF,
	0xFFFD: 0xCDD0,
	0xFFFD: 0xCDD1,
	0xFFFD: 0xCDD2,
	0xFFFD: 0xCDD3,
	0xFFFD: 0xCDD4,
	0xFFFD: 0xCDD5,
	0xFFFD: 0xCDD6,
	0xFFFD: 0xCDD7,
	0xFFFD: 0xCDD8,
	0xFFFD: 0xCDD9,
	0xFFFD: 0xCDDA,
	0xFFFD: 0xCDDB,
	0xFFFD: 0xCDDC,
	0xFFFD: 0xCDDD,
	0xFFFD: 0xCDDE,
	0xFFFD: 0xCDDF,
	0xFFFD: 0xCDE0,
	0xFFFD: 0xCDE1,
	0xFFFD: 0xCDE2,
	0xFFFD: 0xCDE3,
	0xFFFD: 0xCDE4,
	0xFFFD: 0xCDE5,
	0xFFFD: 0xCDE6,
	0xFFFD: 0xCDE7,
	0xFFFD: 0xCDE8,
	0xFFFD: 0xCDE9,
	0xFFFD: 0xCDEA,
	0xFFFD: 0xCDEB,
	0xFFFD: 0xCDEC,
	0xFFFD: 0xCDED,
	0xFFFD: 0xCDEE,
	0xFFFD: 0xCDEF,
	0xFFFD: 0xCDF0,
	0xFFFD: 0xCDF1,
	0xFFFD: 0xCDF2,
	0xFFFD: 0xCDF3,
	0xFFFD: 0xCDF4,
	0xFFFD: 0xCDF5,
	0xFFFD: 0xCDF6,
	0xFFFD: 0xCDF7,
	0xFFFD: 0xCDF8,
	0xFFFD: 0xCDF9,
	0xFFFD: 0xCDFA,
	0xFFFD: 0xCDFB,
	0xFFFD: 0xCDFC,
	0xFFFD: 0xCDFD,
	0xFFFD: 0xCDFE,
	0xFFFD: 0xCDFF,
	0xFFFD: 0xCE00,
	0xFFFD: 0xCE01,
	0xFFFD: 0xCE02,
	0xFFFD: 0xCE03,
	0xFFFD: 0xCE04,
	0xFFFD: 0xCE05,
	0xFFFD: 0xCE06,
	0xFFFD: 0xCE07,
	0xFFFD: 0xCE08,
	0xFFFD: 0xCE09,
	0xFFFD: 0xCE0A,
	0xFFFD: 0xCE0B,
	0xFFFD: 0xCE0C,
	0xFFFD: 0xCE0D,
	0xFFFD: 0xCE0E,
	0xFFFD: 0xCE0F,
	0xFFFD: 0xCE10,
	0xFFFD: 0xCE11,
	0xFFFD: 0xCE12,
	0xFFFD: 0xCE13,
	0xFFFD: 0xCE14,
	0xFFFD: 0xCE15,
	0xFFFD: 0xCE16,
	0xFFFD: 0xCE17,
	0xFFFD: 0xCE18,
	0xFFFD: 0xCE19,
	0xFFFD: 0xCE1A,
	0xFFFD: 0xCE1B,
	0xFFFD: 0xCE1C,
	0xFFFD: 0xCE1D,
	0xFFFD: 0xCE1E,
	0xFFFD: 0xCE1F,
	0xFFFD: 0xCE20,
	0xFFFD: 0xCE21,
	0xFFFD: 0xCE22,
	0xFFFD: 0xCE23,
	0xFFFD: 0xCE24,
	0xFFFD: 0xCE25,
	0xFFFD: 0xCE26,
	0xFFFD: 0xCE27,
	0xFFFD: 0xCE28,
	0xFFFD: 0xCE29,
	0xFFFD: 0xCE2A,
	0xFFFD: 0xCE2B,
	0xFFFD: 0xCE2C,
	0xFFFD: 0xCE2D,
	0xFFFD: 0xCE2E,
	0xFFFD: 0xCE2F,
	0xFFFD: 0xCE30,
	0xFFFD: 0xCE31,
	0xFFFD: 0xCE32,
	0xFFFD: 0xCE33,
	0xFFFD: 0xCE34,
	0xFFFD: 0xCE35,
	0xFFFD: 0xCE36,
	0xFFFD: 0xCE37,
	0xFFFD: 0xCE38,
	0xFFFD: 0xCE39,
	0xFFFD: 0xCE3A,
	0xFFFD: 0xCE3B,
	0xFFFD: 0xCE3C,
	0xFFFD: 0xCE3D,
	0xFFFD: 0xCE3E,
	0xFFFD: 0xCE3F,
	0xFFFD: 0xCE40,
	0xFFFD: 0xCE41,
	0xFFFD: 0xCE42,
	0xFFFD: 0xCE43,
	0xFFFD: 0xCE44,
	0xFFFD: 0xCE45,
	0xFFFD: 0xCE46,
	0xFFFD: 0xCE47,
	0xFFFD: 0xCE48,
	0xFFFD: 0xCE49,
	0xFFFD: 0xCE4A,
	0xFFFD: 0xCE4B,
	0xFFFD: 0xCE4C,
	0xFFFD: 0xCE4D,
	0xFFFD: 0xCE4E,
	0xFFFD: 0xCE4F,
	0xFFFD: 0xCE50,
	0xFFFD: 0xCE51,
	0xFFFD: 0xCE52,
	0xFFFD: 0xCE53,
	0xFFFD: 0xCE54,
	0xFFFD: 0xCE55,
	0xFFFD: 0xCE56,
	0xFFFD: 0xCE57,
	0xFFFD: 0xCE58,
	0xFFFD: 0xCE59,
	0xFFFD: 0xCE5A,
	0xFFFD: 0xCE5B,
	0xFFFD: 0xCE5C,
	0xFFFD: 0xCE5D,
	0xFFFD: 0xCE5E,
	0xFFFD: 0xCE5F,
	0xFFFD: 0xCE60,
	0xFFFD: 0xCE61,
	0xFFFD: 0xCE62,
	0xFFFD: 0xCE63,
	0xFFFD: 0xCE64,
	0xFFFD: 0xCE65,
	0xFFFD: 0xCE66,
	0xFFFD: 0xCE67,
	0xFFFD: 0xCE68,
	0xFFFD: 0xCE69,
	0xFFFD: 0xCE6A,
	0xFFFD: 0xCE6B,
	0xFFFD: 0xCE6C,
	0xFFFD: 0xCE6D,
	0xFFFD: 0xCE6E,
	0xFFFD: 0xCE6F,
	0xFFFD: 0xCE70,
	0xFFFD: 0xCE71,
	0xFFFD: 0xCE72,
	0xFFFD: 0xCE73,
	0xFFFD: 0xCE74,
	0xFFFD: 0xCE75,
	0xFFFD: 0xCE76,
	0xFFFD: 0xCE77,
	0xFFFD: 0xCE78,
	0xFFFD: 0xCE79,
	0xFFFD: 0xCE7A,
	0xFFFD: 0xCE7B,
	0xFFFD: 0xCE7C,
	0xFFFD: 0xCE7D,
	0xFFFD: 0xCE7E,
	0xFFFD: 0xCE7F,
	0xFFFD: 0xCE80,
	0xFFFD: 0xCE81,
	0xFFFD: 0xCE82,
	0xFFFD: 0xCE83,
	0xFFFD: 0xCE84,
	0xFFFD: 0xCE85,
	0xFFFD: 0xCE86,
	0xFFFD: 0xCE87,
	0xFFFD: 0xCE88,
	0xFFFD: 0xCE89,
	0xFFFD: 0xCE8A,
	0xFFFD: 0xCE8B,
	0xFFFD: 0xCE8C,
	0xFFFD: 0xCE8D,
	0xFFFD: 0xCE8E,
	0xFFFD: 0xCE8F,
	0xFFFD: 0xCE90,
	0xFFFD: 0xCE91,
	0xFFFD: 0xCE92,
	0xFFFD: 0xCE93,
	0xFFFD: 0xCE94,
	0xFFFD: 0xCE95,
	0xFFFD: 0xCE96,
	0xFFFD: 0xCE97,
	0xFFFD: 0xCE98,
	0xFFFD: 0xCE99,
	0xFFFD: 0xCE9A,
	0xFFFD: 0xCE9B,
	0xFFFD: 0xCE9C,
	0xFFFD: 0xCE9D,
	0xFFFD: 0xCE9E,
	0xFFFD: 0xCE9F,
	0xFFFD: 0xCEA0,
	0xFFFD: 0xCEA1,
	0xFFFD: 0xCEA2,
	0xFFFD: 0xCEA3,
	0xFFFD: 0xCEA4,
	0xFFFD: 0xCEA5,
	0xFFFD: 0xCEA6,
	0xFFFD: 0xCEA7,
	0xFFFD: 0xCEA8,
	0xFFFD: 0xCEA9,
	0xFFFD: 0xCEAA,
	0xFFFD: 0xCEAB,
	0xFFFD: 0xCEAC,
	0xFFFD: 0xCEAD,
	0xFFFD: 0xCEAE,
	0xFFFD: 0xCEAF,
	0xFFFD: 0xCEB0,
	0xFFFD: 0xCEB1,
	0xFFFD: 0xCEB2,
	0xFFFD: 0xCEB3,
	0xFFFD: 0xCEB4,
	0xFFFD: 0xCEB5,
	0xFFFD: 0xCEB6,
	0xFFFD: 0xCEB7,
	0xFFFD: 0xCEB8,
	0xFFFD: 0xCEB9,
	0xFFFD: 0xCEBA,
	0xFFFD: 0xCEBB,
	0xFFFD: 0xCEBC,
	0xFFFD: 0xCEBD,
	0xFFFD: 0xCEBE,
	0xFFFD: 0xCEBF,
	0xFFFD: 0xCEC0,
	0xFFFD: 0xCEC1,
	0xFFFD: 0xCEC2,
	0xFFFD: 0xCEC3,
	0xFFFD: 0xCEC4,
	0xFFFD: 0xCEC5,
	0xFFFD: 0xCEC6,
	0xFFFD: 0xCEC7,
	0xFFFD: 0xCEC8,
	0xFFFD: 0xCEC9,
	0xFFFD: 0xCECA,
	0xFFFD: 0xCECB,
	0xFFFD: 0xCECC,
	0xFFFD: 0xCECD,
	0xFFFD: 0xCECE,
	0xFFFD: 0xCECF,
	0xFFFD: 0xCED0,
	0xFFFD: 0xCED1,
	0xFFFD: 0xCED2,
	0xFFFD: 0xCED3,
	0xFFFD: 0xCED4,
	0xFFFD: 0xCED5,
	0xFFFD: 0xCED6,
	0xFFFD: 0xCED7,
	0xFFFD: 0xCED8,
	0xFFFD: 0xCED9,
	0xFFFD: 0xCEDA,
	0xFFFD: 0xCEDB,
	0xFFFD: 0xCEDC,
	0xFFFD: 0xCEDD,
	0xFFFD: 0xCEDE,
	0xFFFD: 0xCEDF,
	0xFFFD: 0xCEE0,
	0xFFFD: 0xCEE1,
	0xFFFD: 0xCEE2,
	0xFFFD: 0xCEE3,
	0xFFFD: 0xCEE4,
	0xFFFD: 0xCEE5,
	0xFFFD: 0xCEE6,
	0xFFFD: 0xCEE7,
	0xFFFD: 0xCEE8,
	0xFFFD: 0xCEE9,
	0xFFFD: 0xCEEA,
	0xFFFD: 0xCEEB,
	0xFFFD: 0xCEEC,
	0xFFFD: 0xCEED,
	0xFFFD: 0xCEEE,
	0xFFFD: 0xCEEF,
	0xFFFD: 0xCEF0,
	0xFFFD: 0xCEF1,
	0xFFFD: 0xCEF2,
	0xFFFD: 0xCEF3,
	0xFFFD: 0xCEF4,
	0xFFFD: 0xCEF5,
	0xFFFD: 0xCEF6,
	0xFFFD: 0xCEF7,
	0xFFFD: 0xCEF8,
	0xFFFD: 0xCEF9,
	0xFFFD: 0xCEFA,
	0xFFFD: 0xCEFB,
	0xFFFD: 0xCEFC,
	0xFFFD: 0xCEFD,
	0xFFFD: 0xCEFE,
	0xFFFD: 0xCEFF,
	0xFFFD: 0xCF00,
	0xFFFD: 0xCF01,
	0xFFFD: 0xCF02,
	0xFFFD: 0xCF03,
	0xFFFD: 0xCF04,
	0xFFFD: 0xCF05,
	0xFFFD: 0xCF06,
	0xFFFD: 0xCF07,
	0xFFFD: 0xCF08,
	0xFFFD: 0xCF09,
	0xFFFD: 0xCF0A,
	0xFFFD: 0xCF0B,
	0xFFFD: 0xCF0C,
	0xFFFD: 0xCF0D,
	0xFFFD: 0xCF0E,
	0xFFFD: 0xCF0F,
	0xFFFD: 0xCF10,
	0xFFFD: 0xCF11,
	0xFFFD: 0xCF12,
	0xFFFD: 0xCF13,
	0xFFFD: 0xCF14,
	0xFFFD: 0xCF15,
	0xFFFD: 0xCF16,
	0xFFFD: 0xCF17,
	0xFFFD: 0xCF18,
	0xFFFD: 0xCF19,
	0xFFFD: 0xCF1A,
	0xFFFD: 0xCF1B,
	0xFFFD: 0xCF1C,
	0xFFFD: 0xCF1D,
	0xFFFD: 0xCF1E,
	0xFFFD: 0xCF1F,
	0xFFFD: 0xCF20,
	0xFFFD: 0xCF21,
	0xFFFD: 0xCF22,
	0xFFFD: 0xCF23,
	0xFFFD: 0xCF24,
	0xFFFD: 0xCF25,
	0xFFFD: 0xCF26,
	0xFFFD: 0xCF27,
	0xFFFD: 0xCF28,
	0xFFFD: 0xCF29,
	0xFFFD: 0xCF2A,
	0xFFFD: 0xCF2B,
	0xFFFD: 0xCF2C,
	0xFFFD: 0xCF2D,
	0xFFFD: 0xCF2E,
	0xFFFD: 0xCF2F,
	0xFFFD: 0xCF30,
	0xFFFD: 0xCF31,
	0xFFFD: 0xCF32,
	0xFFFD: 0xCF33,
	0xFFFD: 0xCF34,
	0xFFFD: 0xCF35,
	0xFFFD: 0xCF36,
	0xFFFD: 0xCF37,
	0xFFFD: 0xCF38,
	0xFFFD: 0xCF39,
	0xFFFD: 0xCF3A,
	0xFFFD: 0xCF3B,
	0xFFFD: 0xCF3C,
	0xFFFD: 0xCF3D,
	0xFFFD: 0xCF3E,
	0xFFFD: 0xCF3F,
	0xFFFD: 0xCF40,
	0xFFFD: 0xCF41,
	0xFFFD: 0xCF42,
	0xFFFD: 0xCF43,
	0xFFFD: 0xCF44,
	0xFFFD: 0xCF45,
	0xFFFD: 0xCF46,
	0xFFFD: 0xCF47,
	0xFFFD: 0xCF48,
	0xFFFD: 0xCF49,
	0xFFFD: 0xCF4A,
	0xFFFD: 0xCF4B,
	0xFFFD: 0xCF4C,
	0xFFFD: 0xCF4D,
	0xFFFD: 0xCF4E,
	0xFFFD: 0xCF4F,
	0xFFFD: 0xCF50,
	0xFFFD: 0xCF51,
	0xFFFD: 0xCF52,
	0xFFFD: 0xCF53,
	0xFFFD: 0xCF54,
	0xFFFD: 0xCF55,
	0xFFFD: 0xCF56,
	0xFFFD: 0xCF57,
	0xFFFD: 0xCF58,
	0xFFFD: 0xCF59,
	0xFFFD: 0xCF5A,
	0xFFFD: 0xCF5B,
	0xFFFD: 0xCF5C,
	0xFFFD: 0xCF5D,
	0xFFFD: 0xCF5E,
	0xFFFD: 0xCF5F,
	0xFFFD: 0xCF60,
	0xFFFD: 0xCF61,
	0xFFFD: 0xCF62,
	0xFFFD: 0xCF63,
	0xFFFD: 0xCF64,
	0xFFFD: 0xCF65,
	0xFFFD: 0xCF66,
	0xFFFD: 0xCF67,
	0xFFFD: 0xCF68,
	0xFFFD: 0xCF69,
	0xFFFD: 0xCF6A,
	0xFFFD: 0xCF6B,
	0xFFFD: 0xCF6C,
	0xFFFD: 0xCF6D,
	0xFFFD: 0xCF6E,
	0xFFFD: 0xCF6F,
	0xFFFD: 0xCF70,
	0xFFFD: 0xCF71,
	0xFFFD: 0xCF72,
	0xFFFD: 0xCF73,
	0xFFFD: 0xCF74,
	0xFFFD: 0xCF75,
	0xFFFD: 0xCF76,
	0xFFFD: 0xCF77,
	0xFFFD: 0xCF78,
	0xFFFD: 0xCF79,
	0xFFFD: 0xCF7A,
	0xFFFD: 0xCF7B,
	0xFFFD: 0xCF7C,
	0xFFFD: 0xCF7D,
	0xFFFD: 0xCF7E,
	0xFFFD: 0xCF7F,
	0xFFFD: 0xCF80,
	0xFFFD: 0xCF81,
	0xFFFD: 0xCF82,
	0xFFFD: 0xCF83,
	0xFFFD: 0xCF84,
	0xFFFD: 0xCF85,
	0xFFFD: 0xCF86,
	0xFFFD: 0xCF87,
	0xFFFD: 0xCF88,
	0xFFFD: 0xCF89,
	0xFFFD: 0xCF8A,
	0xFFFD: 0xCF8B,
	0xFFFD: 0xCF8C,
	0xFFFD: 0xCF8D,
	0xFFFD: 0xCF8E,
	0xFFFD: 0xCF8F,
	0xFFFD: 0xCF90,
	0xFFFD: 0xCF91,
	0xFFFD: 0xCF92,
	0xFFFD: 0xCF93,
	0xFFFD: 0xCF94,
	0xFFFD: 0xCF95,
	0xFFFD: 0xCF96,
	0xFFFD: 0xCF97,
	0xFFFD: 0xCF98,
	0xFFFD: 0xCF99,
	0xFFFD: 0xCF9A,
	0xFFFD: 0xCF9B,
	0xFFFD: 0xCF9C,
	0xFFFD: 0xCF9D,
	0xFFFD: 0xCF9E,
	0xFFFD: 0xCF9F,
	0xFFFD: 0xCFA0,
	0xFFFD: 0xCFA1,
	0xFFFD: 0xCFA2,
	0xFFFD: 0xCFA3,
	0xFFFD: 0xCFA4,
	0xFFFD: 0xCFA5,
	0xFFFD: 0xCFA6,
	0xFFFD: 0xCFA7,
	0xFFFD: 0xCFA8,
	0xFFFD: 0xCFA9,
	0xFFFD: 0xCFAA,
	0xFFFD: 0xCFAB,
	0xFFFD: 0xCFAC,
	0xFFFD: 0xCFAD,
	0xFFFD: 0xCFAE,
	0xFFFD: 0xCFAF,
	0xFFFD: 0xCFB0,
	0xFFFD: 0xCFB1,
	0xFFFD: 0xCFB2,
	0xFFFD: 0xCFB3,
	0xFFFD: 0xCFB4,
	0xFFFD: 0xCFB5,
	0xFFFD: 0xCFB6,
	0xFFFD: 0xCFB7,
	0xFFFD: 0xCFB8,
	0xFFFD: 0xCFB9,
	0xFFFD: 0xCFBA,
	0xFFFD: 0xCFBB,
	0xFFFD: 0xCFBC,
	0xFFFD: 0xCFBD,
	0xFFFD: 0xCFBE,
	0xFFFD: 0xCFBF,
	0xFFFD: 0xCFC0,
	0xFFFD: 0xCFC1,
	0xFFFD: 0xCFC2,
	0xFFFD: 0xCFC3,
	0xFFFD: 0xCFC4,
	0xFFFD: 0xCFC5,
	0xFFFD: 0xCFC6,
	0xFFFD: 0xCFC7,
	0xFFFD: 0xCFC8,
	0xFFFD: 0xCFC9,
	0xFFFD: 0xCFCA,
	0xFFFD: 0xCFCB,
	0xFFFD: 0xCFCC,
	0xFFFD: 0xCFCD,
	0xFFFD: 0xCFCE,
	0xFFFD: 0xCFCF,
	0xFFFD: 0xCFD0,
	0xFFFD: 0xCFD1,
	0xFFFD: 0xCFD2,
	0xFFFD: 0xCFD3,
	0xFFFD: 0xCFD4,
	0xFFFD: 0xCFD5,
	0xFFFD: 0xCFD6,
	0xFFFD: 0xCFD7,
	0xFFFD: 0xCFD8,
	0xFFFD: 0xCFD9,
	0xFFFD: 0xCFDA,
	0xFFFD: 0xCFDB,
	0xFFFD: 0xCFDC,
	0xFFFD: 0xCFDD,
	0xFFFD: 0xCFDE,
	0xFFFD: 0xCFDF,
	0xFFFD: 0xCFE0,
	0xFFFD: 0xCFE1,
	0xFFFD: 0xCFE2,
	0xFFFD: 0xCFE3,
	0xFFFD: 0xCFE4,
	0xFFFD: 0xCFE5,
	0xFFFD: 0xCFE6,
	0xFFFD: 0xCFE7,
	0xFFFD: 0xCFE8,
	0xFFFD: 0xCFE9,
	0xFFFD: 0xCFEA,
	0xFFFD: 0xCFEB,
	0xFFFD: 0xCFEC,
	0xFFFD: 0xCFED,
	0xFFFD: 0xCFEE,
	0xFFFD: 0xCFEF,
	0xFFFD: 0xCFF0,
	0xFFFD: 0xCFF1,
	0xFFFD: 0xCFF2,
	0xFFFD: 0xCFF3,
	0xFFFD: 0xCFF4,
	0xFFFD: 0xCFF5,
	0xFFFD: 0xCFF6,
	0xFFFD: 0xCFF7,
	0xFFFD: 0xCFF8,
	0xFFFD: 0xCFF9,
	0xFFFD: 0xCFFA,
	0xFFFD: 0xCFFB,
	0xFFFD: 0xCFFC,
	0xFFFD: 0xCFFD,
	0xFFFD: 0xCFFE,
	0xFFFD: 0xCFFF,
	0xFFFD: 0xD000,
	0xFFFD: 0xD001,
	0xFFFD: 0xD002,
	0xFFFD: 0xD003,
	0xFFFD: 0xD004,
	0xFFFD: 0xD005,
	0xFFFD: 0xD006,
	0xFFFD: 0xD007,
	0xFFFD: 0xD008,
	0xFFFD: 0xD009,
	0xFFFD: 0xD00A,
	0xFFFD: 0xD00B,
	0xFFFD: 0xD00C,
	0xFFFD: 0xD00D,
	0xFFFD: 0xD00E,
	0xFFFD: 0xD00F,
	0xFFFD: 0xD010,
	0xFFFD: 0xD011,
	0xFFFD: 0xD012,
	0xFFFD: 0xD013,
	0xFFFD: 0xD014,
	0xFFFD: 0xD015,
	0xFFFD: 0xD016,
	0xFFFD: 0xD017,
	0xFFFD: 0xD018,
	0xFFFD: 0xD019,
	0xFFFD: 0xD01A,
	0xFFFD: 0xD01B,
	0xFFFD: 0xD01C,
	0xFFFD: 0xD01D,
	0xFFFD: 0xD01E,
	0xFFFD: 0xD01F,
	0xFFFD: 0xD020,
	0xFFFD: 0xD021,
	0xFFFD: 0xD022,
	0xFFFD: 0xD023,
	0xFFFD: 0xD024,
	0xFFFD: 0xD025,
	0xFFFD: 0xD026,
	0xFFFD: 0xD027,
	0xFFFD: 0xD028,
	0xFFFD: 0xD029,
	0xFFFD: 0xD02A,
	0xFFFD: 0xD02B,
	0xFFFD: 0xD02C,
	0xFFFD: 0xD02D,
	0xFFFD: 0xD02E,
	0xFFFD: 0xD02F,
	0xFFFD: 0xD030,
	0xFFFD: 0xD031,
	0xFFFD: 0xD032,
	0xFFFD: 0xD033,
	0xFFFD: 0xD034,
	0xFFFD: 0xD035,
	0xFFFD: 0xD036,
	0xFFFD: 0xD037,
	0xFFFD: 0xD038,
	0xFFFD: 0xD039,
	0xFFFD: 0xD03A,
	0xFFFD: 0xD03B,
	0xFFFD: 0xD03C,
	0xFFFD: 0xD03D,
	0xFFFD: 0xD03E,
	0xFFFD: 0xD03F,
	0xFFFD: 0xD040,
	0xFFFD: 0xD041,
	0xFFFD: 0xD042,
	0xFFFD: 0xD043,
	0xFFFD: 0xD044,
	0xFFFD: 0xD045,
	0xFFFD: 0xD046,
	0xFFFD: 0xD047,
	0xFFFD: 0xD048,
	0xFFFD: 0xD049,
	0xFFFD: 0xD04A,
	0xFFFD: 0xD04B,
	0xFFFD: 0xD04C,
	0xFFFD: 0xD04D,
	0xFFFD: 0xD04E,
	0xFFFD: 0xD04F,
	0xFFFD: 0xD050,
	0xFFFD: 0xD051,
	0xFFFD: 0xD052,
	0xFFFD: 0xD053,
	0xFFFD: 0xD054,
	0xFFFD: 0xD055,
	0xFFFD: 0xD056,
	0xFFFD: 0xD057,
	0xFFFD: 0xD058,
	0xFFFD: 0xD059,
	0xFFFD: 0xD05A,
	0xFFFD: 0xD05B,
	0xFFFD: 0xD05C,
	0xFFFD: 0xD05D,
	0xFFFD: 0xD05E,
	0xFFFD: 0xD05F,
	0xFFFD: 0xD060,
	0xFFFD: 0xD061,
	0xFFFD: 0xD062,
	0xFFFD: 0xD063,
	0xFFFD: 0xD064,
	0xFFFD: 0xD065,
	0xFFFD: 0xD066,
	0xFFFD: 0xD067,
	0xFFFD: 0xD068,
	0xFFFD: 0xD069,
	0xFFFD: 0xD06A,
	0xFFFD: 0xD06B,
	0xFFFD: 0xD06C,
	0xFFFD: 0xD06D,
	0xFFFD: 0xD06E,
	0xFFFD: 0xD06F,
	0xFFFD: 0xD070,
	0xFFFD: 0xD071,
	0xFFFD: 0xD072,
	0xFFFD: 0xD073,
	0xFFFD: 0xD074,
	0xFFFD: 0xD075,
	0xFFFD: 0xD076,
	0xFFFD: 0xD077,
	0xFFFD: 0xD078,
	0xFFFD: 0xD079,
	0xFFFD: 0xD07A,
	0xFFFD: 0xD07B,
	0xFFFD: 0xD07C,
	0xFFFD: 0xD07D,
	0xFFFD: 0xD07E,
	0xFFFD: 0xD07F,
	0xFFFD: 0xD080,
	0xFFFD: 0xD081,
	0xFFFD: 0xD082,
	0xFFFD: 0xD083,
	0xFFFD: 0xD084,
	0xFFFD: 0xD085,
	0xFFFD: 0xD086,
	0xFFFD: 0xD087,
	0xFFFD: 0xD088,
	0xFFFD: 0xD089,
	0xFFFD: 0xD08A,
	0xFFFD: 0xD08B,
	0xFFFD: 0xD08C,
	0xFFFD: 0xD08D,
	0xFFFD: 0xD08E,
	0xFFFD: 0xD08F,
	0xFFFD: 0xD090,
	0xFFFD: 0xD091,
	0xFFFD: 0xD092,
	0xFFFD: 0xD093,
	0xFFFD: 0xD094,
	0xFFFD: 0xD095,
	0xFFFD: 0xD096,
	0xFFFD: 0xD097,
	0xFFFD: 0xD098,
	0xFFFD: 0xD099,
	0xFFFD: 0xD09A,
	0xFFFD: 0xD09B,
	0xFFFD: 0xD09C,
	0xFFFD: 0xD09D,
	0xFFFD: 0xD09E,
	0xFFFD: 0xD09F,
	0xFFFD: 0xD0A0,
	0xFFFD: 0xD0A1,
	0xFFFD: 0xD0A2,
	0xFFFD: 0xD0A3,
	0xFFFD: 0xD0A4,
	0xFFFD: 0xD0A5,
	0xFFFD: 0xD0A6,
	0xFFFD: 0xD0A7,
	0xFFFD: 0xD0A8,
	0xFFFD: 0xD0A9,
	0xFFFD: 0xD0AA,
	0xFFFD: 0xD0AB,
	0xFFFD: 0xD0AC,
	0xFFFD: 0xD0AD,
	0xFFFD: 0xD0AE,
	0xFFFD: 0xD0AF,
	0xFFFD: 0xD0B0,
	0xFFFD: 0xD0B1,
	0xFFFD: 0xD0B2,
	0xFFFD: 0xD0B3,
	0xFFFD: 0xD0B4,
	0xFFFD: 0xD0B5,
	0xFFFD: 0xD0B6,
	0xFFFD: 0xD0B7,
	0xFFFD: 0xD0B8,
	0xFFFD: 0xD0B9,
	0xFFFD: 0xD0BA,
	0xFFFD: 0xD0BB,
	0xFFFD: 0xD0BC,
	0xFFFD: 0xD0BD,
	0xFFFD: 0xD0BE,
	0xFFFD: 0xD0BF,
	0xFFFD: 0xD0C0,
	0xFFFD: 0xD0C1,
	0xFFFD: 0xD0C2,
	0xFFFD: 0xD0C3,
	0xFFFD: 0xD0C4,
	0xFFFD: 0xD0C5,
	0xFFFD: 0xD0C6,
	0xFFFD: 0xD0C7,
	0xFFFD: 0xD0C8,
	0xFFFD: 0xD0C9,
	0xFFFD: 0xD0CA,
	0xFFFD: 0xD0CB,
	0xFFFD: 0xD0CC,
	0xFFFD: 0xD0CD,
	0xFFFD: 0xD0CE,
	0xFFFD: 0xD0CF,
	0xFFFD: 0xD0D0,
	0xFFFD: 0xD0D1,
	0xFFFD: 0xD0D2,
	0xFFFD: 0xD0D3,
	0xFFFD: 0xD0D4,
	0xFFFD: 0xD0D5,
	0xFFFD: 0xD0D6,
	0xFFFD: 0xD0D7,
	0xFFFD: 0xD0D8,
	0xFFFD: 0xD0D9,
	0xFFFD: 0xD0DA,
	0xFFFD: 0xD0DB,
	0xFFFD: 0xD0DC,
	0xFFFD: 0xD0DD,
	0xFFFD: 0xD0DE,
	0xFFFD: 0xD0DF,
	0xFFFD: 0xD0E0,
	0xFFFD: 0xD0E1,
	0xFFFD: 0xD0E2,
	0xFFFD: 0xD0E3,
	0xFFFD: 0xD0E4,
	0xFFFD: 0xD0E5,
	0xFFFD: 0xD0E6,
	0xFFFD: 0xD0E7,
	0xFFFD: 0xD0E8,
	0xFFFD: 0xD0E9,
	0xFFFD: 0xD0EA,
	0xFFFD: 0xD0EB,
	0xFFFD: 0xD0EC,
	0xFFFD: 0xD0ED,
	0xFFFD: 0xD0EE,
	0xFFFD: 0xD0EF,
	0xFFFD: 0xD0F0,
	0xFFFD: 0xD0F1,
	0xFFFD: 0xD0F2,
	0xFFFD: 0xD0F3,
	0xFFFD: 0xD0F4,
	0xFFFD: 0xD0F5,
	0xFFFD: 0xD0F6,
	0xFFFD: 0xD0F7,
	0xFFFD: 0xD0F8,
	0xFFFD: 0xD0F9,
	0xFFFD: 0xD0FA,
	0xFFFD: 0xD0FB,
	0xFFFD: 0xD0FC,
	0xFFFD: 0xD0FD,
	0xFFFD: 0xD0FE,
	0xFFFD: 0xD0FF,
	0xFFFD: 0xD100,
	0xFFFD: 0xD101,
	0xFFFD: 0xD102,
	0xFFFD: 0xD103,
	0xFFFD: 0xD104,
	0xFFFD: 0xD105,
	0xFFFD: 0xD106,
	0xFFFD: 0xD107,
	0xFFFD: 0xD108,
	0xFFFD: 0xD109,
	0xFFFD: 0xD10A,
	0xFFFD: 0xD10B,
	0xFFFD: 0xD10C,
	0xFFFD: 0xD10D,
	0xFFFD: 0xD10E,
	0xFFFD: 0xD10F,
	0xFFFD: 0xD110,
	0xFFFD: 0xD111,
	0xFFFD: 0xD112,
	0xFFFD: 0xD113,
	0xFFFD: 0xD114,
	0xFFFD: 0xD115,
	0xFFFD: 0xD116,
	0xFFFD: 0xD117,
	0xFFFD: 0xD118,
	0xFFFD: 0xD119,
	0xFFFD: 0xD11A,
	0xFFFD: 0xD11B,
	0xFFFD: 0xD11C,
	0xFFFD: 0xD11D,
	0xFFFD: 0xD11E,
	0xFFFD: 0xD11F,
	0xFFFD: 0xD120,
	0xFFFD: 0xD121,
	0xFFFD: 0xD122,
	0xFFFD: 0xD123,
	0xFFFD: 0xD124,
	0xFFFD: 0xD125,
	0xFFFD: 0xD126,
	0xFFFD: 0xD127,
	0xFFFD: 0xD128,
	0xFFFD: 0xD129,
	0xFFFD: 0xD12A,
	0xFFFD: 0xD12B,
	0xFFFD: 0xD12C,
	0xFFFD: 0xD12D,
	0xFFFD: 0xD12E,
	0xFFFD: 0xD12F,
	0xFFFD: 0xD130,
	0xFFFD: 0xD131,
	0xFFFD: 0xD132,
	0xFFFD: 0xD133,
	0xFFFD: 0xD134,
	0xFFFD: 0xD135,
	0xFFFD: 0xD136,
	0xFFFD: 0xD137,
	0xFFFD: 0xD138,
	0xFFFD: 0xD139,
	0xFFFD: 0xD13A,
	0xFFFD: 0xD13B,
	0xFFFD: 0xD13C,
	0xFFFD: 0xD13D,
	0xFFFD: 0xD13E,
	0xFFFD: 0xD13F,
	0xFFFD: 0xD140,
	0xFFFD: 0xD141,
	0xFFFD: 0xD142,
	0xFFFD: 0xD143,
	0xFFFD: 0xD144,
	0xFFFD: 0xD145,
	0xFFFD: 0xD146,
	0xFFFD: 0xD147,
	0xFFFD: 0xD148,
	0xFFFD: 0xD149,
	0xFFFD: 0xD14A,
	0xFFFD: 0xD14B,
	0xFFFD: 0xD14C,
	0xFFFD: 0xD14D,
	0xFFFD: 0xD14E,
	0xFFFD: 0xD14F,
	0xFFFD: 0xD150,
	0xFFFD: 0xD151,
	0xFFFD: 0xD152,
	0xFFFD: 0xD153,
	0xFFFD: 0xD154,
	0xFFFD: 0xD155,
	0xFFFD: 0xD156,
	0xFFFD: 0xD157,
	0xFFFD: 0xD158,
	0xFFFD: 0xD159,
	0xFFFD: 0xD15A,
	0xFFFD: 0xD15B,
	0xFFFD: 0xD15C,
	0xFFFD: 0xD15D,
	0xFFFD: 0xD15E,
	0xFFFD: 0xD15F,
	0xFFFD: 0xD160,
	0xFFFD: 0xD161,
	0xFFFD: 0xD162,
	0xFFFD: 0xD163,
	0xFFFD: 0xD164,
	0xFFFD: 0xD165,
	0xFFFD: 0xD166,
	0xFFFD: 0xD167,
	0xFFFD: 0xD168,
	0xFFFD: 0xD169,
	0xFFFD: 0xD16A,
	0xFFFD: 0xD16B,
	0xFFFD: 0xD16C,
	0xFFFD: 0xD16D,
	0xFFFD: 0xD16E,
	0xFFFD: 0xD16F,
	0xFFFD: 0xD170,
	0xFFFD: 0xD171,
	0xFFFD: 0xD172,
	0xFFFD: 0xD173,
	0xFFFD: 0xD174,
	0xFFFD: 0xD175,
	0xFFFD: 0xD176,
	0xFFFD: 0xD177,
	0xFFFD: 0xD178,
	0xFFFD: 0xD179,
	0xFFFD: 0xD17A,
	0xFFFD: 0xD17B,
	0xFFFD: 0xD17C,
	0xFFFD: 0xD17D,
	0xFFFD: 0xD17E,
	0xFFFD: 0xD17F,
	0xFFFD: 0xD180,
	0xFFFD: 0xD181,
	0xFFFD: 0xD182,
	0xFFFD: 0xD183,
	0xFFFD: 0xD184,
	0xFFFD: 0xD185,
	0xFFFD: 0xD186,
	0xFFFD: 0xD187,
	0xFFFD: 0xD188,
	0xFFFD: 0xD189,
	0xFFFD: 0xD18A,
	0xFFFD: 0xD18B,
	0xFFFD: 0xD18C,
	0xFFFD: 0xD18D,
	0xFFFD: 0xD18E,
	0xFFFD: 0xD18F,
	0xFFFD: 0xD190,
	0xFFFD: 0xD191,
	0xFFFD: 0xD192,
	0xFFFD: 0xD193,
	0xFFFD: 0xD194,
	0xFFFD: 0xD195,
	0xFFFD: 0xD196,
	0xFFFD: 0xD197,
	0xFFFD: 0xD198,
	0xFFFD: 0xD199,
	0xFFFD: 0xD19A,
	0xFFFD: 0xD19B,
	0xFFFD: 0xD19C,
	0xFFFD: 0xD19D,
	0xFFFD: 0xD19E,
	0xFFFD: 0xD19F,
	0xFFFD: 0xD1A0,
	0xFFFD: 0xD1A1,
	0xFFFD: 0xD1A2,
	0xFFFD: 0xD1A3,
	0xFFFD: 0xD1A4,
	0xFFFD: 0xD1A5,
	0xFFFD: 0xD1A6,
	0xFFFD: 0xD1A7,
	0xFFFD: 0xD1A8,
	0xFFFD: 0xD1A9,
	0xFFFD: 0xD1AA,
	0xFFFD: 0xD1AB,
	0xFFFD: 0xD1AC,
	0xFFFD: 0xD1AD,
	0xFFFD: 0xD1AE,
	0xFFFD: 0xD1AF,
	0xFFFD: 0xD1B0,
	0xFFFD: 0xD1B1,
	0xFFFD: 0xD1B2,
	0xFFFD: 0xD1B3,
	0xFFFD: 0xD1B4,
	0xFFFD: 0xD1B5,
	0xFFFD: 0xD1B6,
	0xFFFD: 0xD1B7,
	0xFFFD: 0xD1B8,
	0xFFFD: 0xD1B9,
	0xFFFD: 0xD1BA,
	0xFFFD: 0xD1BB,
	0xFFFD: 0xD1BC,
	0xFFFD: 0xD1BD,
	0xFFFD: 0xD1BE,
	0xFFFD: 0xD1BF,
	0xFFFD: 0xD1C0,
	0xFFFD: 0xD1C1,
	0xFFFD: 0xD1C2,
	0xFFFD: 0xD1C3,
	0xFFFD: 0xD1C4,
	0xFFFD: 0xD1C5,
	0xFFFD: 0xD1C6,
	0xFFFD: 0xD1C7,
	0xFFFD: 0xD1C8,
	0xFFFD: 0xD1C9,
	0xFFFD: 0xD1CA,
	0xFFFD: 0xD1CB,
	0xFFFD: 0xD1CC,
	0xFFFD: 0xD1CD,
	0xFFFD: 0xD1CE,
	0xFFFD: 0xD1CF,
	0xFFFD: 0xD1D0,
	0xFFFD: 0xD1D1,
	0xFFFD: 0xD1D2,
	0xFFFD: 0xD1D3,
	0xFFFD: 0xD1D4,
	0xFFFD: 0xD1D5,
	0xFFFD: 0xD1D6,
	0xFFFD: 0xD1D7,
	0xFFFD: 0xD1D8,
	0xFFFD: 0xD1D9,
	0xFFFD: 0xD1DA,
	0xFFFD: 0xD1DB,
	0xFFFD: 0xD1DC,
	0xFFFD: 0xD1DD,
	0xFFFD: 0xD1DE,
	0xFFFD: 0xD1DF,
	0xFFFD: 0xD1E0,
	0xFFFD: 0xD1E1,
	0xFFFD: 0xD1E2,
	0xFFFD: 0xD1E3,
	0xFFFD: 0xD1E4,
	0xFFFD: 0xD1E5,
	0xFFFD: 0xD1E6,
	0xFFFD: 0xD1E7,
	0xFFFD: 0xD1E8,
	0xFFFD: 0xD1E9,
	0xFFFD: 0xD1EA,
	0xFFFD: 0xD1EB,
	0xFFFD: 0xD1EC,
	0xFFFD: 0xD1ED,
	0xFFFD: 0xD1EE,
	0xFFFD: 0xD1EF,
	0xFFFD: 0xD1F0,
	0xFFFD: 0xD1F1,
	0xFFFD: 0xD1F2,
	0xFFFD: 0xD1F3,
	0xFFFD: 0xD1F4,
	0xFFFD: 0xD1F5,
	0xFFFD: 0xD1F6,
	0xFFFD: 0xD1F7,
	0xFFFD: 0xD1F8,
	0xFFFD: 0xD1F9,
	0xFFFD: 0xD1FA,
	0xFFFD: 0xD1FB,
	0xFFFD: 0xD1FC,
	0xFFFD: 0xD1FD,
	0xFFFD: 0xD1FE,
	0xFFFD: 0xD1FF,
	0xFFFD: 0xD200,
	0xFFFD: 0xD201,
	0xFFFD: 0xD202,
	0xFFFD: 0xD203,
	0xFFFD: 0xD204,
	0xFFFD: 0xD205,
	0xFFFD: 0xD206,
	0xFFFD: 0xD207,
	0xFFFD: 0xD208,
	0xFFFD: 0xD209,
	0xFFFD: 0xD20A,
	0xFFFD: 0xD20B,
	0xFFFD: 0xD20C,
	0xFFFD: 0xD20D,
	0xFFFD: 0xD20E,
	0xFFFD: 0xD20F,
	0xFFFD: 0xD210,
	0xFFFD: 0xD211,
	0xFFFD: 0xD212,
	0xFFFD: 0xD213,
	0xFFFD: 0xD214,
	0xFFFD: 0xD215,
	0xFFFD: 0xD216,
	0xFFFD: 0xD217,
	0xFFFD: 0xD218,
	0xFFFD: 0xD219,
	0xFFFD: 0xD21A,
	0xFFFD: 0xD21B,
	0xFFFD: 0xD21C,
	0xFFFD: 0xD21D,
	0xFFFD: 0xD21E,
	0xFFFD: 0xD21F,
	0xFFFD: 0xD220,
	0xFFFD: 0xD221,
	0xFFFD: 0xD222,
	0xFFFD: 0xD223,
	0xFFFD: 0xD224,
	0xFFFD: 0xD225,
	0xFFFD: 0xD226,
	0xFFFD: 0xD227,
	0xFFFD: 0xD228,
	0xFFFD: 0xD229,
	0xFFFD: 0xD22A,
	0xFFFD: 0xD22B,
	0xFFFD: 0xD22C,
	0xFFFD: 0xD22D,
	0xFFFD: 0xD22E,
	0xFFFD: 0xD22F,
	0xFFFD: 0xD230,
	0xFFFD: 0xD231,
	0xFFFD: 0xD232,
	0xFFFD: 0xD233,
	0xFFFD: 0xD234,
	0xFFFD: 0xD235,
	0xFFFD: 0xD236,
	0xFFFD: 0xD237,
	0xFFFD: 0xD238,
	0xFFFD: 0xD239,
	0xFFFD: 0xD23A,
	0xFFFD: 0xD23B,
	0xFFFD: 0xD23C,
	0xFFFD: 0xD23D,
	0xFFFD: 0xD23E,
	0xFFFD: 0xD23F,
	0xFFFD: 0xD240,
	0xFFFD: 0xD241,
	0xFFFD: 0xD242,
	0xFFFD: 0xD243,
	0xFFFD: 0xD244,
	0xFFFD: 0xD245,
	0xFFFD: 0xD246,
	0xFFFD: 0xD247,
	0xFFFD: 0xD248,
	0xFFFD: 0xD249,
	0xFFFD: 0xD24A,
	0xFFFD: 0xD24B,
	0xFFFD: 0xD24C,
	0xFFFD: 0xD24D,
	0xFFFD: 0xD24E,
	0xFFFD: 0xD24F,
	0xFFFD: 0xD250,
	0xFFFD: 0xD251,
	0xFFFD: 0xD252,
	0xFFFD: 0xD253,
	0xFFFD: 0xD254,
	0xFFFD: 0xD255,
	0xFFFD: 0xD256,
	0xFFFD: 0xD257,
	0xFFFD: 0xD258,
	0xFFFD: 0xD259,
	0xFFFD: 0xD25A,
	0xFFFD: 0xD25B,
	0xFFFD: 0xD25C,
	0xFFFD: 0xD25D,
	0xFFFD: 0xD25E,
	0xFFFD: 0xD25F,
	0xFFFD: 0xD260,
	0xFFFD: 0xD261,
	0xFFFD: 0xD262,
	0xFFFD: 0xD263,
	0xFFFD: 0xD264,
	0xFFFD: 0xD265,
	0xFFFD: 0xD266,
	0xFFFD: 0xD267,
	0xFFFD: 0xD268,
	0xFFFD: 0xD269,
	0xFFFD: 0xD26A,
	0xFFFD: 0xD26B,
	0xFFFD: 0xD26C,
	0xFFFD: 0xD26D,
	0xFFFD: 0xD26E,
	0xFFFD: 0xD26F,
	0xFFFD: 0xD270,
	0xFFFD: 0xD271,
	0xFFFD: 0xD272,
	0xFFFD: 0xD273,
	0xFFFD: 0xD274,
	0xFFFD: 0xD275,
	0xFFFD: 0xD276,
	0xFFFD: 0xD277,
	0xFFFD: 0xD278,
	0xFFFD: 0xD279,
	0xFFFD: 0xD27A,
	0xFFFD: 0xD27B,
	0xFFFD: 0xD27C,
	0xFFFD: 0xD27D,
	0xFFFD: 0xD27E,
	0xFFFD: 0xD27F,
	0xFFFD: 0xD280,
	0xFFFD: 0xD281,
	0xFFFD: 0xD282,
	0xFFFD: 0xD283,
	0xFFFD: 0xD284,
	0xFFFD: 0xD285,
	0xFFFD: 0xD286,
	0xFFFD: 0xD287,
	0xFFFD: 0xD288,
	0xFFFD: 0xD289,
	0xFFFD: 0xD28A,
	0xFFFD: 0xD28B,
	0xFFFD: 0xD28C,
	0xFFFD: 0xD28D,
	0xFFFD: 0xD28E,
	0xFFFD: 0xD28F,
	0xFFFD: 0xD290,
	0xFFFD: 0xD291,
	0xFFFD: 0xD292,
	0xFFFD: 0xD293,
	0xFFFD: 0xD294,
	0xFFFD: 0xD295,
	0xFFFD: 0xD296,
	0xFFFD: 0xD297,
	0xFFFD: 0xD298,
	0xFFFD: 0xD299,
	0xFFFD: 0xD29A,
	0xFFFD: 0xD29B,
	0xFFFD: 0xD29C,
	0xFFFD: 0xD29D,
	0xFFFD: 0xD29E,
	0xFFFD: 0xD29F,
	0xFFFD: 0xD2A0,
	0xFFFD: 0xD2A1,
	0xFFFD: 0xD2A2,
	0xFFFD: 0xD2A3,
	0xFFFD: 0xD2A4,
	0xFFFD: 0xD2A5,
	0xFFFD: 0xD2A6,
	0xFFFD: 0xD2A7,
	0xFFFD: 0xD2A8,
	0xFFFD: 0xD2A9,
	0xFFFD: 0xD2AA,
	0xFFFD: 0xD2AB,
	0xFFFD: 0xD2AC,
	0xFFFD: 0xD2AD,
	0xFFFD: 0xD2AE,
	0xFFFD: 0xD2AF,
	0xFFFD: 0xD2B0,
	0xFFFD: 0xD2B1,
	0xFFFD: 0xD2B2,
	0xFFFD: 0xD2B3,
	0xFFFD: 0xD2B4,
	0xFFFD: 0xD2B5,
	0xFFFD: 0xD2B6,
	0xFFFD: 0xD2B7,
	0xFFFD: 0xD2B8,
	0xFFFD: 0xD2B9,
	0xFFFD: 0xD2BA,
	0xFFFD: 0xD2BB,
	0xFFFD: 0xD2BC,
	0xFFFD: 0xD2BD,
	0xFFFD: 0xD2BE,
	0xFFFD: 0xD2BF,
	0xFFFD: 0xD2C0,
	0xFFFD: 0xD2C1,
	0xFFFD: 0xD2C2,
	0xFFFD: 0xD2C3,
	0xFFFD: 0xD2C4,
	0xFFFD: 0xD2C5,
	0xFFFD: 0xD2C6,
	0xFFFD: 0xD2C7,
	0xFFFD: 0xD2C8,
	0xFFFD: 0xD2C9,
	0xFFFD: 0xD2CA,
	0xFFFD: 0xD2CB,
	0xFFFD: 0xD2CC,
	0xFFFD: 0xD2CD,
	0xFFFD: 0xD2CE,
	0xFFFD: 0xD2CF,
	0xFFFD: 0xD2D0,
	0xFFFD: 0xD2D1,
	0xFFFD: 0xD2D2,
	0xFFFD: 0xD2D3,
	0xFFFD: 0xD2D4,
	0xFFFD: 0xD2D5,
	0xFFFD: 0xD2D6,
	0xFFFD: 0xD2D7,
	0xFFFD: 0xD2D8,
	0xFFFD: 0xD2D9,
	0xFFFD: 0xD2DA,
	0xFFFD: 0xD2DB,
	0xFFFD: 0xD2DC,
	0xFFFD: 0xD2DD,
	0xFFFD: 0xD2DE,
	0xFFFD: 0xD2DF,
	0xFFFD: 0xD2E0,
	0xFFFD: 0xD2E1,
	0xFFFD: 0xD2E2,
	0xFFFD: 0xD2E3,
	0xFFFD: 0xD2E4,
	0xFFFD: 0xD2E5,
	0xFFFD: 0xD2E6,
	0xFFFD: 0xD2E7,
	0xFFFD: 0xD2E8,
	0xFFFD: 0xD2E9,
	0xFFFD: 0xD2EA,
	0xFFFD: 0xD2EB,
	0xFFFD: 0xD2EC,
	0xFFFD: 0xD2ED,
	0xFFFD: 0xD2EE,
	0xFFFD: 0xD2EF,
	0xFFFD: 0xD2F0,
	0xFFFD: 0xD2F1,
	0xFFFD: 0xD2F2,
	0xFFFD: 0xD2F3,
	0xFFFD: 0xD2F4,
	0xFFFD: 0xD2F5,
	0xFFFD: 0xD2F6,
	0xFFFD: 0xD2F7,
	0xFFFD: 0xD2F8,
	0xFFFD: 0xD2F9,
	0xFFFD: 0xD2FA,
	0xFFFD: 0xD2FB,
	0xFFFD: 0xD2FC,
	0xFFFD: 0xD2FD,
	0xFFFD: 0xD2FE,
	0xFFFD: 0xD2FF,
	0xFFFD: 0xD300,
	0xFFFD: 0xD301,
	0xFFFD: 0xD302,
	0xFFFD: 0xD303,
	0xFFFD: 0xD304,
	0xFFFD: 0xD305,
	0xFFFD: 0xD306,
	0xFFFD: 0xD307,
	0xFFFD: 0xD308,
	0xFFFD: 0xD309,
	0xFFFD: 0xD30A,
	0xFFFD: 0xD30B,
	0xFFFD: 0xD30C,
	0xFFFD: 0xD30D,
	0xFFFD: 0xD30E,
	0xFFFD: 0xD30F,
	0xFFFD: 0xD310,
	0xFFFD: 0xD311,
	0xFFFD: 0xD312,
	0xFFFD: 0xD313,
	0xFFFD: 0xD314,
	0xFFFD: 0xD315,
	0xFFFD: 0xD316,
	0xFFFD: 0xD317,
	0xFFFD: 0xD318,
	0xFFFD: 0xD319,
	0xFFFD: 0xD31A,
	0xFFFD: 0xD31B,
	0xFFFD: 0xD31C,
	0xFFFD: 0xD31D,
	0xFFFD: 0xD31E,
	0xFFFD: 0xD31F,
	0xFFFD: 0xD320,
	0xFFFD: 0xD321,
	0xFFFD: 0xD322,
	0xFFFD: 0xD323,
	0xFFFD: 0xD324,
	0xFFFD: 0xD325,
	0xFFFD: 0xD326,
	0xFFFD: 0xD327,
	0xFFFD: 0xD328,
	0xFFFD: 0xD329,
	0xFFFD: 0xD32A,
	0xFFFD: 0xD32B,
	0xFFFD: 0xD32C,
	0xFFFD: 0xD32D,
	0xFFFD: 0xD32E,
	0xFFFD: 0xD32F,
	0xFFFD: 0xD330,
	0xFFFD: 0xD331,
	0xFFFD: 0xD332,
	0xFFFD: 0xD333,
	0xFFFD: 0xD334,
	0xFFFD: 0xD335,
	0xFFFD: 0xD336,
	0xFFFD: 0xD337,
	0xFFFD: 0xD338,
	0xFFFD: 0xD339,
	0xFFFD: 0xD33A,
	0xFFFD: 0xD33B,
	0xFFFD: 0xD33C,
	0xFFFD: 0xD33D,
	0xFFFD: 0xD33E,
	0xFFFD: 0xD33F,
	0xFFFD: 0xD340,
	0xFFFD: 0xD341,
	0xFFFD: 0xD342,
	0xFFFD: 0xD343,
	0xFFFD: 0xD344,
	0xFFFD: 0xD345,
	0xFFFD: 0xD346,
	0xFFFD: 0xD347,
	0xFFFD: 0xD348,
	0xFFFD: 0xD349,
	0xFFFD: 0xD34A,
	0xFFFD: 0xD34B,
	0xFFFD: 0xD34C,
	0xFFFD: 0xD34D,
	0xFFFD: 0xD34E,
	0xFFFD: 0xD34F,
	0xFFFD: 0xD350,
	0xFFFD: 0xD351,
	0xFFFD: 0xD352,
	0xFFFD: 0xD353,
	0xFFFD: 0xD354,
	0xFFFD: 0xD355,
	0xFFFD: 0xD356,
	0xFFFD: 0xD357,
	0xFFFD: 0xD358,
	0xFFFD: 0xD359,
	0xFFFD: 0xD35A,
	0xFFFD: 0xD35B,
	0xFFFD: 0xD35C,
	0xFFFD: 0xD35D,
	0xFFFD: 0xD35E,
	0xFFFD: 0xD35F,
	0xFFFD: 0xD360,
	0xFFFD: 0xD361,
	0xFFFD: 0xD362,
	0xFFFD: 0xD363,
	0xFFFD: 0xD364,
	0xFFFD: 0xD365,
	0xFFFD: 0xD366,
	0xFFFD: 0xD367,
	0xFFFD: 0xD368,
	0xFFFD: 0xD369,
	0xFFFD: 0xD36A,
	0xFFFD: 0xD36B,
	0xFFFD: 0xD36C,
	0xFFFD: 0xD36D,
	0xFFFD: 0xD36E,
	0xFFFD: 0xD36F,
	0xFFFD: 0xD370,
	0xFFFD: 0xD371,
	0xFFFD: 0xD372,
	0xFFFD: 0xD373,
	0xFFFD: 0xD374,
	0xFFFD: 0xD375,
	0xFFFD: 0xD376,
	0xFFFD: 0xD377,
	0xFFFD: 0xD378,
	0xFFFD: 0xD379,
	0xFFFD: 0xD37A,
	0xFFFD: 0xD37B,
	0xFFFD: 0xD37C,
	0xFFFD: 0xD37D,
	0xFFFD: 0xD37E,
	0xFFFD: 0xD37F,
	0xFFFD: 0xD380,
	0xFFFD: 0xD381,
	0xFFFD: 0xD382,
	0xFFFD: 0xD383,
	0xFFFD: 0xD384,
	0xFFFD: 0xD385,
	0xFFFD: 0xD386,
	0xFFFD: 0xD387,
	0xFFFD: 0xD388,
	0xFFFD: 0xD389,
	0xFFFD: 0xD38A,
	0xFFFD: 0xD38B,
	0xFFFD: 0xD38C,
	0xFFFD: 0xD38D,
	0xFFFD: 0xD38E,
	0xFFFD: 0xD38F,
	0xFFFD: 0xD390,
	0xFFFD: 0xD391,
	0xFFFD: 0xD392,
	0xFFFD: 0xD393,
	0xFFFD: 0xD394,
	0xFFFD: 0xD395,
	0xFFFD: 0xD396,
	0xFFFD: 0xD397,
	0xFFFD: 0xD398,
	0xFFFD: 0xD399,
	0xFFFD: 0xD39A,
	0xFFFD: 0xD39B,
	0xFFFD: 0xD39C,
	0xFFFD: 0xD39D,
	0xFFFD: 0xD39E,
	0xFFFD: 0xD39F,
	0xFFFD: 0xD3A0,
	0xFFFD: 0xD3A1,
	0xFFFD: 0xD3A2,
	0xFFFD: 0xD3A3,
	0xFFFD: 0xD3A4,
	0xFFFD: 0xD3A5,
	0xFFFD: 0xD3A6,
	0xFFFD: 0xD3A7,
	0xFFFD: 0xD3A8,
	0xFFFD: 0xD3A9,
	0xFFFD: 0xD3AA,
	0xFFFD: 0xD3AB,
	0xFFFD: 0xD3AC,
	0xFFFD: 0xD3AD,
	0xFFFD: 0xD3AE,
	0xFFFD: 0xD3AF,
	0xFFFD: 0xD3B0,
	0xFFFD: 0xD3B1,
	0xFFFD: 0xD3B2,
	0xFFFD: 0xD3B3,
	0xFFFD: 0xD3B4,
	0xFFFD: 0xD3B5,
	0xFFFD: 0xD3B6,
	0xFFFD: 0xD3B7,
	0xFFFD: 0xD3B8,
	0xFFFD: 0xD3B9,
	0xFFFD: 0xD3BA,
	0xFFFD: 0xD3BB,
	0xFFFD: 0xD3BC,
	0xFFFD: 0xD3BD,
	0xFFFD: 0xD3BE,
	0xFFFD: 0xD3BF,
	0xFFFD: 0xD3C0,
	0xFFFD: 0xD3C1,
	0xFFFD: 0xD3C2,
	0xFFFD: 0xD3C3,
	0xFFFD: 0xD3C4,
	0xFFFD: 0xD3C5,
	0xFFFD: 0xD3C6,
	0xFFFD: 0xD3C7,
	0xFFFD: 0xD3C8,
	0xFFFD: 0xD3C9,
	0xFFFD: 0xD3CA,
	0xFFFD: 0xD3CB,
	0xFFFD: 0xD3CC,
	0xFFFD: 0xD3CD,
	0xFFFD: 0xD3CE,
	0xFFFD: 0xD3CF,
	0xFFFD: 0xD3D0,
	0xFFFD: 0xD3D1,
	0xFFFD: 0xD3D2,
	0xFFFD: 0xD3D3,
	0xFFFD: 0xD3D4,
	0xFFFD: 0xD3D5,
	0xFFFD: 0xD3D6,
	0xFFFD: 0xD3D7,
	0xFFFD: 0xD3D8,
	0xFFFD: 0xD3D9,
	0xFFFD: 0xD3DA,
	0xFFFD: 0xD3DB,
	0xFFFD: 0xD3DC,
	0xFFFD: 0xD3DD,
	0xFFFD: 0xD3DE,
	0xFFFD: 0xD3DF,
	0xFFFD: 0xD3E0,
	0xFFFD: 0xD3E1,
	0xFFFD: 0xD3E2,
	0xFFFD: 0xD3E3,
	0xFFFD: 0xD3E4,
	0xFFFD: 0xD3E5,
	0xFFFD: 0xD3E6,
	0xFFFD: 0xD3E7,
	0xFFFD: 0xD3E8,
	0xFFFD: 0xD3E9,
	0xFFFD: 0xD3EA,
	0xFFFD: 0xD3EB,
	0xFFFD: 0xD3EC,
	0xFFFD: 0xD3ED,
	0xFFFD: 0xD3EE,
	0xFFFD: 0xD3EF,
	0xFFFD: 0xD3F0,
	0xFFFD: 0xD3F1,
	0xFFFD: 0xD3F2,
	0xFFFD: 0xD3F3,
	0xFFFD: 0xD3F4,
	0xFFFD: 0xD3F5,
	0xFFFD: 0xD3F6,
	0xFFFD: 0xD3F7,
	0xFFFD: 0xD3F8,
	0xFFFD: 0xD3F9,
	0xFFFD: 0xD3FA,
	0xFFFD: 0xD3FB,
	0xFFFD: 0xD3FC,
	0xFFFD: 0xD3FD,
	0xFFFD: 0xD3FE,
	0xFFFD: 0xD3FF,
	0xFFFD: 0xD400,
	0xFFFD: 0xD401,
	0xFFFD: 0xD402,
	0xFFFD: 0xD403,
	0xFFFD: 0xD404,
	0xFFFD: 0xD405,
	0xFFFD: 0xD406,
	0xFFFD: 0xD407,
	0xFFFD: 0xD408,
	0xFFFD: 0xD409,
	0xFFFD: 0xD40A,
	0xFFFD: 0xD40B,
	0xFFFD: 0xD40C,
	0xFFFD: 0xD40D,
	0xFFFD: 0xD40E,
	0xFFFD: 0xD40F,
	0xFFFD: 0xD410,
	0xFFFD: 0xD411,
	0xFFFD: 0xD412,
	0xFFFD: 0xD413,
	0xFFFD: 0xD414,
	0xFFFD: 0xD415,
	0xFFFD: 0xD416,
	0xFFFD: 0xD417,
	0xFFFD: 0xD418,
	0xFFFD: 0xD419,
	0xFFFD: 0xD41A,
	0xFFFD: 0xD41B,
	0xFFFD: 0xD41C,
	0xFFFD: 0xD41D,
	0xFFFD: 0xD41E,
	0xFFFD: 0xD41F,
	0xFFFD: 0xD420,
	0xFFFD: 0xD421,
	0xFFFD: 0xD422,
	0xFFFD: 0xD423,
	0xFFFD: 0xD424,
	0xFFFD: 0xD425,
	0xFFFD: 0xD426,
	0xFFFD: 0xD427,
	0xFFFD: 0xD428,
	0xFFFD: 0xD429,
	0xFFFD: 0xD42A,
	0xFFFD: 0xD42B,
	0xFFFD: 0xD42C,
	0xFFFD: 0xD42D,
	0xFFFD: 0xD42E,
	0xFFFD: 0xD42F,
	0xFFFD: 0xD430,
	0xFFFD: 0xD431,
	0xFFFD: 0xD432,
	0xFFFD: 0xD433,
	0xFFFD: 0xD434,
	0xFFFD: 0xD435,
	0xFFFD: 0xD436,
	0xFFFD: 0xD437,
	0xFFFD: 0xD438,
	0xFFFD: 0xD439,
	0xFFFD: 0xD43A,
	0xFFFD: 0xD43B,
	0xFFFD: 0xD43C,
	0xFFFD: 0xD43D,
	0xFFFD: 0xD43E,
	0xFFFD: 0xD43F,
	0xFFFD: 0xD440,
	0xFFFD: 0xD441,
	0xFFFD: 0xD442,
	0xFFFD: 0xD443,
	0xFFFD: 0xD444,
	0xFFFD: 0xD445,
	0xFFFD: 0xD446,
	0xFFFD: 0xD447,
	0xFFFD: 0xD448,
	0xFFFD: 0xD449,
	0xFFFD: 0xD44A,
	0xFFFD: 0xD44B,
	0xFFFD: 0xD44C,
	0xFFFD: 0xD44D,
	0xFFFD: 0xD44E,
	0xFFFD: 0xD44F,
	0xFFFD: 0xD450,
	0xFFFD: 0xD451,
	0xFFFD: 0xD452,
	0xFFFD: 0xD453,
	0xFFFD: 0xD454,
	0xFFFD: 0xD455,
	0xFFFD: 0xD456,
	0xFFFD: 0xD457,
	0xFFFD: 0xD458,
	0xFFFD: 0xD459,
	0xFFFD: 0xD45A,
	0xFFFD: 0xD45B,
	0xFFFD: 0xD45C,
	0xFFFD: 0xD45D,
	0xFFFD: 0xD45E,
	0xFFFD: 0xD45F,
	0xFFFD: 0xD460,
	0xFFFD: 0xD461,
	0xFFFD: 0xD462,
	0xFFFD: 0xD463,
	0xFFFD: 0xD464,
	0xFFFD: 0xD465,
	0xFFFD: 0xD466,
	0xFFFD: 0xD467,
	0xFFFD: 0xD468,
	0xFFFD: 0xD469,
	0xFFFD: 0xD46A,
	0xFFFD: 0xD46B,
	0xFFFD: 0xD46C,
	0xFFFD: 0xD46D,
	0xFFFD: 0xD46E,
	0xFFFD: 0xD46F,
	0xFFFD: 0xD470,
	0xFFFD: 0xD471,
	0xFFFD: 0xD472,
	0xFFFD: 0xD473,
	0xFFFD: 0xD474,
	0xFFFD: 0xD475,
	0xFFFD: 0xD476,
	0xFFFD: 0xD477,
	0xFFFD: 0xD478,
	0xFFFD: 0xD479,
	0xFFFD: 0xD47A,
	0xFFFD: 0xD47B,
	0xFFFD: 0xD47C,
	0xFFFD: 0xD47D,
	0xFFFD: 0xD47E,
	0xFFFD: 0xD47F,
	0xFFFD: 0xD480,
	0xFFFD: 0xD481,
	0xFFFD: 0xD482,
	0xFFFD: 0xD483,
	0xFFFD: 0xD484,
	0xFFFD: 0xD485,
	0xFFFD: 0xD486,
	0xFFFD: 0xD487,
	0xFFFD: 0xD488,
	0xFFFD: 0xD489,
	0xFFFD: 0xD48A,
	0xFFFD: 0xD48B,
	0xFFFD: 0xD48C,
	0xFFFD: 0xD48D,
	0xFFFD: 0xD48E,
	0xFFFD: 0xD48F,
	0xFFFD: 0xD490,
	0xFFFD: 0xD491,
	0xFFFD: 0xD492,
	0xFFFD: 0xD493,
	0xFFFD: 0xD494,
	0xFFFD: 0xD495,
	0xFFFD: 0xD496,
	0xFFFD: 0xD497,
	0xFFFD: 0xD498,
	0xFFFD: 0xD499,
	0xFFFD: 0xD49A,
	0xFFFD: 0xD49B,
	0xFFFD: 0xD49C,
	0xFFFD: 0xD49D,
	0xFFFD: 0xD49E,
	0xFFFD: 0xD49F,
	0xFFFD: 0xD4A0,
	0xFFFD: 0xD4A1,
	0xFFFD: 0xD4A2,
	0xFFFD: 0xD4A3,
	0xFFFD: 0xD4A4,
	0xFFFD: 0xD4A5,
	0xFFFD: 0xD4A6,
	0xFFFD: 0xD4A7,
	0xFFFD: 0xD4A8,
	0xFFFD: 0xD4A9,
	0xFFFD: 0xD4AA,
	0xFFFD: 0xD4AB,
	0xFFFD: 0xD4AC,
	0xFFFD: 0xD4AD,
	0xFFFD: 0xD4AE,
	0xFFFD: 0xD4AF,
	0xFFFD: 0xD4B0,
	0xFFFD: 0xD4B1,
	0xFFFD: 0xD4B2,
	0xFFFD: 0xD4B3,
	0xFFFD: 0xD4B4,
	0xFFFD: 0xD4B5,
	0xFFFD: 0xD4B6,
	0xFFFD: 0xD4B7,
	0xFFFD: 0xD4B8,
	0xFFFD: 0xD4B9,
	0xFFFD: 0xD4BA,
	0xFFFD: 0xD4BB,
	0xFFFD: 0xD4BC,
	0xFFFD: 0xD4BD,
	0xFFFD: 0xD4BE,
	0xFFFD: 0xD4BF,
	0xFFFD: 0xD4C0,
	0xFFFD: 0xD4C1,
	0xFFFD: 0xD4C2,
	0xFFFD: 0xD4C3,
	0xFFFD: 0xD4C4,
	0xFFFD: 0xD4C5,
	0xFFFD: 0xD4C6,
	0xFFFD: 0xD4C7,
	0xFFFD: 0xD4C8,
	0xFFFD: 0xD4C9,
	0xFFFD: 0xD4CA,
	0xFFFD: 0xD4CB,
	0xFFFD: 0xD4CC,
	0xFFFD: 0xD4CD,
	0xFFFD: 0xD4CE,
	0xFFFD: 0xD4CF,
	0xFFFD: 0xD4D0,
	0xFFFD: 0xD4D1,
	0xFFFD: 0xD4D2,
	0xFFFD: 0xD4D3,
	0xFFFD: 0xD4D4,
	0xFFFD: 0xD4D5,
	0xFFFD: 0xD4D6,
	0xFFFD: 0xD4D7,
	0xFFFD: 0xD4D8,
	0xFFFD: 0xD4D9,
	0xFFFD: 0xD4DA,
	0xFFFD: 0xD4DB,
	0xFFFD: 0xD4DC,
	0xFFFD: 0xD4DD,
	0xFFFD: 0xD4DE,
	0xFFFD: 0xD4DF,
	0xFFFD: 0xD4E0,
	0xFFFD: 0xD4E1,
	0xFFFD: 0xD4E2,
	0xFFFD: 0xD4E3,
	0xFFFD: 0xD4E4,
	0xFFFD: 0xD4E5,
	0xFFFD: 0xD4E6,
	0xFFFD: 0xD4E7,
	0xFFFD: 0xD4E8,
	0xFFFD: 0xD4E9,
	0xFFFD: 0xD4EA,
	0xFFFD: 0xD4EB,
	0xFFFD: 0xD4EC,
	0xFFFD: 0xD4ED,
	0xFFFD: 0xD4EE,
	0xFFFD: 0xD4EF,
	0xFFFD: 0xD4F0,
	0xFFFD: 0xD4F1,
	0xFFFD: 0xD4F2,
	0xFFFD: 0xD4F3,
	0xFFFD: 0xD4F4,
	0xFFFD: 0xD4F5,
	0xFFFD: 0xD4F6,
	0xFFFD: 0xD4F7,
	0xFFFD: 0xD4F8,
	0xFFFD: 0xD4F9,
	0xFFFD: 0xD4FA,
	0xFFFD: 0xD4FB,
	0xFFFD: 0xD4FC,
	0xFFFD: 0xD4FD,
	0xFFFD: 0xD4FE,
	0xFFFD: 0xD4FF,
	0xFFFD: 0xD500,
	0xFFFD: 0xD501,
	0xFFFD: 0xD502,
	0xFFFD: 0xD503,
	0xFFFD: 0xD504,
	0xFFFD: 0xD505,
	0xFFFD: 0xD506,
	0xFFFD: 0xD507,
	0xFFFD: 0xD508,
	0xFFFD: 0xD509,
	0xFFFD: 0xD50A,
	0xFFFD: 0xD50B,
	0xFFFD: 0xD50C,
	0xFFFD: 0xD50D,
	0xFFFD: 0xD50E,
	0xFFFD: 0xD50F,
	0xFFFD: 0xD510,
	0xFFFD: 0xD511,
	0xFFFD: 0xD512,
	0xFFFD: 0xD513,
	0xFFFD: 0xD514,
	0xFFFD: 0xD515,
	0xFFFD: 0xD516,
	0xFFFD: 0xD517,
	0xFFFD: 0xD518,
	0xFFFD: 0xD519,
	0xFFFD: 0xD51A,
	0xFFFD: 0xD51B,
	0xFFFD: 0xD51C,
	0xFFFD: 0xD51D,
	0xFFFD: 0xD51E,
	0xFFFD: 0xD51F,
	0xFFFD: 0xD520,
	0xFFFD: 0xD521,
	0xFFFD: 0xD522,
	0xFFFD: 0xD523,
	0xFFFD: 0xD524,
	0xFFFD: 0xD525,
	0xFFFD: 0xD526,
	0xFFFD: 0xD527,
	0xFFFD: 0xD528,
	0xFFFD: 0xD529,
	0xFFFD: 0xD52A,
	0xFFFD: 0xD52B,
	0xFFFD: 0xD52C,
	0xFFFD: 0xD52D,
	0xFFFD: 0xD52E,
	0xFFFD: 0xD52F,
	0xFFFD: 0xD530,
	0xFFFD: 0xD531,
	0xFFFD: 0xD532,
	0xFFFD: 0xD533,
	0xFFFD: 0xD534,
	0xFFFD: 0xD535,
	0xFFFD: 0xD536,
	0xFFFD: 0xD537,
	0xFFFD: 0xD538,
	0xFFFD: 0xD539,
	0xFFFD: 0xD53A,
	0xFFFD: 0xD53B,
	0xFFFD: 0xD53C,
	0xFFFD: 0xD53D,
	0xFFFD: 0xD53E,
	0xFFFD: 0xD53F,
	0xFFFD: 0xD540,
	0xFFFD: 0xD541,
	0xFFFD: 0xD542,
	0xFFFD: 0xD543,
	0xFFFD: 0xD544,
	0xFFFD: 0xD545,
	0xFFFD: 0xD546,
	0xFFFD: 0xD547,
	0xFFFD: 0xD548,
	0xFFFD: 0xD549,
	0xFFFD: 0xD54A,
	0xFFFD: 0xD54B,
	0xFFFD: 0xD54C,
	0xFFFD: 0xD54D,
	0xFFFD: 0xD54E,
	0xFFFD: 0xD54F,
	0xFFFD: 0xD550,
	0xFFFD: 0xD551,
	0xFFFD: 0xD552,
	0xFFFD: 0xD553,
	0xFFFD: 0xD554,
	0xFFFD: 0xD555,
	0xFFFD: 0xD556,
	0xFFFD: 0xD557,
	0xFFFD: 0xD558,
	0xFFFD: 0xD559,
	0xFFFD: 0xD55A,
	0xFFFD: 0xD55B,
	0xFFFD: 0xD55C,
	0xFFFD: 0xD55D,
	0xFFFD: 0xD55E,
	0xFFFD: 0xD55F,
	0xFFFD: 0xD560,
	0xFFFD: 0xD561,
	0xFFFD: 0xD562,
	0xFFFD: 0xD563,
	0xFFFD: 0xD564,
	0xFFFD: 0xD565,
	0xFFFD: 0xD566,
	0xFFFD: 0xD567,
	0xFFFD: 0xD568,
	0xFFFD: 0xD569,
	0xFFFD: 0xD56A,
	0xFFFD: 0xD56B,
	0xFFFD: 0xD56C,
	0xFFFD: 0xD56D,
	0xFFFD: 0xD56E,
	0xFFFD: 0xD56F,
	0xFFFD: 0xD570,
	0xFFFD: 0xD571,
	0xFFFD: 0xD572,
	0xFFFD: 0xD573,
	0xFFFD: 0xD574,
	0xFFFD: 0xD575,
	0xFFFD: 0xD576,
	0xFFFD: 0xD577,
	0xFFFD: 0xD578,
	0xFFFD: 0xD579,
	0xFFFD: 0xD57A,
	0xFFFD: 0xD57B,
	0xFFFD: 0xD57C,
	0xFFFD: 0xD57D,
	0xFFFD: 0xD57E,
	0xFFFD: 0xD57F,
	0xFFFD: 0xD580,
	0xFFFD: 0xD581,
	0xFFFD: 0xD582,
	0xFFFD: 0xD583,
	0xFFFD: 0xD584,
	0xFFFD: 0xD585,
	0xFFFD: 0xD586,
	0xFFFD: 0xD587,
	0xFFFD: 0xD588,
	0xFFFD: 0xD589,
	0xFFFD: 0xD58A,
	0xFFFD: 0xD58B,
	0xFFFD: 0xD58C,
	0xFFFD: 0xD58D,
	0xFFFD: 0xD58E,
	0xFFFD: 0xD58F,
	0xFFFD: 0xD590,
	0xFFFD: 0xD591,
	0xFFFD: 0xD592,
	0xFFFD: 0xD593,
	0xFFFD: 0xD594,
	0xFFFD: 0xD595,
	0xFFFD: 0xD596,
	0xFFFD: 0xD597,
	0xFFFD: 0xD598,
	0xFFFD: 0xD599,
	0xFFFD: 0xD59A,
	0xFFFD: 0xD59B,
	0xFFFD: 0xD59C,
	0xFFFD: 0xD59D,
	0xFFFD: 0xD59E,
	0xFFFD: 0xD59F,
	0xFFFD: 0xD5A0,
	0xFFFD: 0xD5A1,
	0xFFFD: 0xD5A2,
	0xFFFD: 0xD5A3,
	0xFFFD: 0xD5A4,
	0xFFFD: 0xD5A5,
	0xFFFD: 0xD5A6,
	0xFFFD: 0xD5A7,
	0xFFFD: 0xD5A8,
	0xFFFD: 0xD5A9,
	0xFFFD: 0xD5AA,
	0xFFFD: 0xD5AB,
	0xFFFD: 0xD5AC,
	0xFFFD: 0xD5AD,
	0xFFFD: 0xD5AE,
	0xFFFD: 0xD5AF,
	0xFFFD: 0xD5B0,
	0xFFFD: 0xD5B1,
	0xFFFD: 0xD5B2,
	0xFFFD: 0xD5B3,
	0xFFFD: 0xD5B4,
	0xFFFD: 0xD5B5,
	0xFFFD: 0xD5B6,
	0xFFFD: 0xD5B7,
	0xFFFD: 0xD5B8,
	0xFFFD: 0xD5B9,
	0xFFFD: 0xD5BA,
	0xFFFD: 0xD5BB,
	0xFFFD: 0xD5BC,
	0xFFFD: 0xD5BD,
	0xFFFD: 0xD5BE,
	0xFFFD: 0xD5BF,
	0xFFFD: 0xD5C0,
	0xFFFD: 0xD5C1,
	0xFFFD: 0xD5C2,
	0xFFFD: 0xD5C3,
	0xFFFD: 0xD5C4,
	0xFFFD: 0xD5C5,
	0xFFFD: 0xD5C6,
	0xFFFD: 0xD5C7,
	0xFFFD: 0xD5C8,
	0xFFFD: 0xD5C9,
	0xFFFD: 0xD5CA,
	0xFFFD: 0xD5CB,
	0xFFFD: 0xD5CC,
	0xFFFD: 0xD5CD,
	0xFFFD: 0xD5CE,
	0xFFFD: 0xD5CF,
	0xFFFD: 0xD5D0,
	0xFFFD: 0xD5D1,
	0xFFFD: 0xD5D2,
	0xFFFD: 0xD5D3,
	0xFFFD: 0xD5D4,
	0xFFFD: 0xD5D5,
	0xFFFD: 0xD5D6,
	0xFFFD: 0xD5D7,
	0xFFFD: 0xD5D8,
	0xFFFD: 0xD5D9,
	0xFFFD: 0xD5DA,
	0xFFFD: 0xD5DB,
	0xFFFD: 0xD5DC,
	0xFFFD: 0xD5DD,
	0xFFFD: 0xD5DE,
	0xFFFD: 0xD5DF,
	0xFFFD: 0xD5E0,
	0xFFFD: 0xD5E1,
	0xFFFD: 0xD5E2,
	0xFFFD: 0xD5E3,
	0xFFFD: 0xD5E4,
	0xFFFD: 0xD5E5,
	0xFFFD: 0xD5E6,
	0xFFFD: 0xD5E7,
	0xFFFD: 0xD5E8,
	0xFFFD: 0xD5E9,
	0xFFFD: 0xD5EA,
	0xFFFD: 0xD5EB,
	0xFFFD: 0xD5EC,
	0xFFFD: 0xD5ED,
	0xFFFD: 0xD5EE,
	0xFFFD: 0xD5EF,
	0xFFFD: 0xD5F0,
	0xFFFD: 0xD5F1,
	0xFFFD: 0xD5F2,
	0xFFFD: 0xD5F3,
	0xFFFD: 0xD5F4,
	0xFFFD: 0xD5F5,
	0xFFFD: 0xD5F6,
	0xFFFD: 0xD5F7,
	0xFFFD: 0xD5F8,
	0xFFFD: 0xD5F9,
	0xFFFD: 0xD5FA,
	0xFFFD: 0xD5FB,
	0xFFFD: 0xD5FC,
	0xFFFD: 0xD5FD,
	0xFFFD: 0xD5FE,
	0xFFFD: 0xD5FF,
	0xFFFD: 0xD600,
	0xFFFD: 0xD601,
	0xFFFD: 0xD602,
	0xFFFD: 0xD603,
	0xFFFD: 0xD604,
	0xFFFD: 0xD605,
	0xFFFD: 0xD606,
	0xFFFD: 0xD607,
	0xFFFD: 0xD608,
	0xFFFD: 0xD609,
	0xFFFD: 0xD60A,
	0xFFFD: 0xD60B,
	0xFFFD: 0xD60C,
	0xFFFD: 0xD60D,
	0xFFFD: 0xD60E,
	0xFFFD: 0xD60F,
	0xFFFD: 0xD610,
	0xFFFD: 0xD611,
	0xFFFD: 0xD612,
	0xFFFD: 0xD613,
	0xFFFD: 0xD614,
	0xFFFD: 0xD615,
	0xFFFD: 0xD616,
	0xFFFD: 0xD617,
	0xFFFD: 0xD618,
	0xFFFD: 0xD619,
	0xFFFD: 0xD61A,
	0xFFFD: 0xD61B,
	0xFFFD: 0xD61C,
	0xFFFD: 0xD61D,
	0xFFFD: 0xD61E,
	0xFFFD: 0xD61F,
	0xFFFD: 0xD620,
	0xFFFD: 0xD621,
	0xFFFD: 0xD622,
	0xFFFD: 0xD623,
	0xFFFD: 0xD624,
	0xFFFD: 0xD625,
	0xFFFD: 0xD626,
	0xFFFD: 0xD627,
	0xFFFD: 0xD628,
	0xFFFD: 0xD629,
	0xFFFD: 0xD62A,
	0xFFFD: 0xD62B,
	0xFFFD: 0xD62C,
	0xFFFD: 0xD62D,
	0xFFFD: 0xD62E,
	0xFFFD: 0xD62F,
	0xFFFD: 0xD630,
	0xFFFD: 0xD631,
	0xFFFD: 0xD632,
	0xFFFD: 0xD633,
	0xFFFD: 0xD634,
	0xFFFD: 0xD635,
	0xFFFD: 0xD636,
	0xFFFD: 0xD637,
	0xFFFD: 0xD638,
	0xFFFD: 0xD639,
	0xFFFD: 0xD63A,
	0xFFFD: 0xD63B,
	0xFFFD: 0xD63C,
	0xFFFD: 0xD63D,
	0xFFFD: 0xD63E,
	0xFFFD: 0xD63F,
	0xFFFD: 0xD640,
	0xFFFD: 0xD641,
	0xFFFD: 0xD642,
	0xFFFD: 0xD643,
	0xFFFD: 0xD644,
	0xFFFD: 0xD645,
	0xFFFD: 0xD646,
	0xFFFD: 0xD647,
	0xFFFD: 0xD648,
	0xFFFD: 0xD649,
	0xFFFD: 0xD64A,
	0xFFFD: 0xD64B,
	0xFFFD: 0xD64C,
	0xFFFD: 0xD64D,
	0xFFFD: 0xD64E,
	0xFFFD: 0xD64F,
	0xFFFD: 0xD650,
	0xFFFD: 0xD651,
	0xFFFD: 0xD652,
	0xFFFD: 0xD653,
	0xFFFD: 0xD654,
	0xFFFD: 0xD655,
	0xFFFD: 0xD656,
	0xFFFD: 0xD657,
	0xFFFD: 0xD658,
	0xFFFD: 0xD659,
	0xFFFD: 0xD65A,
	0xFFFD: 0xD65B,
	0xFFFD: 0xD65C,
	0xFFFD: 0xD65D,
	0xFFFD: 0xD65E,
	0xFFFD: 0xD65F,
	0xFFFD: 0xD660,
	0xFFFD: 0xD661,
	0xFFFD: 0xD662,
	0xFFFD: 0xD663,
	0xFFFD: 0xD664,
	0xFFFD: 0xD665,
	0xFFFD: 0xD666,
	0xFFFD: 0xD667,
	0xFFFD: 0xD668,
	0xFFFD: 0xD669,
	0xFFFD: 0xD66A,
	0xFFFD: 0xD66B,
	0xFFFD: 0xD66C,
	0xFFFD: 0xD66D,
	0xFFFD: 0xD66E,
	0xFFFD: 0xD66F,
	0xFFFD: 0xD670,
	0xFFFD: 0xD671,
	0xFFFD: 0xD672,
	0xFFFD: 0xD673,
	0xFFFD: 0xD674,
	0xFFFD: 0xD675,
	0xFFFD: 0xD676,
	0xFFFD: 0xD677,
	0xFFFD: 0xD678,
	0xFFFD: 0xD679,
	0xFFFD: 0xD67A,
	0xFFFD: 0xD67B,
	0xFFFD: 0xD67C,
	0xFFFD: 0xD67D,
	0xFFFD: 0xD67E,
	0xFFFD: 0xD67F,
	0xFFFD: 0xD680,
	0xFFFD: 0xD681,
	0xFFFD: 0xD682,
	0xFFFD: 0xD683,
	0xFFFD: 0xD684,
	0xFFFD: 0xD685,
	0xFFFD: 0xD686,
	0xFFFD: 0xD687,
	0xFFFD: 0xD688,
	0xFFFD: 0xD689,
	0xFFFD: 0xD68A,
	0xFFFD: 0xD68B,
	0xFFFD: 0xD68C,
	0xFFFD: 0xD68D,
	0xFFFD: 0xD68E,
	0xFFFD: 0xD68F,
	0xFFFD: 0xD690,
	0xFFFD: 0xD691,
	0xFFFD: 0xD692,
	0xFFFD: 0xD693,
	0xFFFD: 0xD694,
	0xFFFD: 0xD695,
	0xFFFD: 0xD696,
	0xFFFD: 0xD697,
	0xFFFD: 0xD698,
	0xFFFD: 0xD699,
	0xFFFD: 0xD69A,
	0xFFFD: 0xD69B,
	0xFFFD: 0xD69C,
	0xFFFD: 0xD69D,
	0xFFFD: 0xD69E,
	0xFFFD: 0xD69F,
	0xFFFD: 0xD6A0,
	0xFFFD: 0xD6A1,
	0xFFFD: 0xD6A2,
	0xFFFD: 0xD6A3,
	0xFFFD: 0xD6A4,
	0xFFFD: 0xD6A5,
	0xFFFD: 0xD6A6,
	0xFFFD: 0xD6A7,
	0xFFFD: 0xD6A8,
	0xFFFD: 0xD6A9,
	0xFFFD: 0xD6AA,
	0xFFFD: 0xD6AB,
	0xFFFD: 0xD6AC,
	0xFFFD: 0xD6AD,
	0xFFFD: 0xD6AE,
	0xFFFD: 0xD6AF,
	0xFFFD: 0xD6B0,
	0xFFFD: 0xD6B1,
	0xFFFD: 0xD6B2,
	0xFFFD: 0xD6B3,
	0xFFFD: 0xD6B4,
	0xFFFD: 0xD6B5,
	0xFFFD: 0xD6B6,
	0xFFFD: 0xD6B7,
	0xFFFD: 0xD6B8,
	0xFFFD: 0xD6B9,
	0xFFFD: 0xD6BA,
	0xFFFD: 0xD6BB,
	0xFFFD: 0xD6BC,
	0xFFFD: 0xD6BD,
	0xFFFD: 0xD6BE,
	0xFFFD: 0xD6BF,
	0xFFFD: 0xD6C0,
	0xFFFD: 0xD6C1,
	0xFFFD: 0xD6C2,
	0xFFFD: 0xD6C3,
	0xFFFD: 0xD6C4,
	0xFFFD: 0xD6C5,
	0xFFFD: 0xD6C6,
	0xFFFD: 0xD6C7,
	0xFFFD: 0xD6C8,
	0xFFFD: 0xD6C9,
	0xFFFD: 0xD6CA,
	0xFFFD: 0xD6CB,
	0xFFFD: 0xD6CC,
	0xFFFD: 0xD6CD,
	0xFFFD: 0xD6CE,
	0xFFFD: 0xD6CF,
	0xFFFD: 0xD6D0,
	0xFFFD: 0xD6D1,
	0xFFFD: 0xD6D2,
	0xFFFD: 0xD6D3,
	0xFFFD: 0xD6D4,
	0xFFFD: 0xD6D5,
	0xFFFD: 0xD6D6,
	0xFFFD: 0xD6D7,
	0xFFFD: 0xD6D8,
	0xFFFD: 0xD6D9,
	0xFFFD: 0xD6DA,
	0xFFFD: 0xD6DB,
	0xFFFD: 0xD6DC,
	0xFFFD: 0xD6DD,
	0xFFFD: 0xD6DE,
	0xFFFD: 0xD6DF,
	0xFFFD: 0xD6E0,
	0xFFFD: 0xD6E1,
	0xFFFD: 0xD6E2,
	0xFFFD: 0xD6E3,
	0xFFFD: 0xD6E4,
	0xFFFD: 0xD6E5,
	0xFFFD: 0xD6E6,
	0xFFFD: 0xD6E7,
	0xFFFD: 0xD6E8,
	0xFFFD: 0xD6E9,
	0xFFFD: 0xD6EA,
	0xFFFD: 0xD6EB,
	0xFFFD: 0xD6EC,
	0xFFFD: 0xD6ED,
	0xFFFD: 0xD6EE,
	0xFFFD: 0xD6EF,
	0xFFFD: 0xD6F0,
	0xFFFD: 0xD6F1,
	0xFFFD: 0xD6F2,
	0xFFFD: 0xD6F3,
	0xFFFD: 0xD6F4,
	0xFFFD: 0xD6F5,
	0xFFFD: 0xD6F6,
	0xFFFD: 0xD6F7,
	0xFFFD: 0xD6F8,
	0xFFFD: 0xD6F9,
	0xFFFD: 0xD6FA,
	0xFFFD: 0xD6FB,
	0xFFFD: 0xD6FC,
	0xFFFD: 0xD6FD,
	0xFFFD: 0xD6FE,
	0xFFFD: 0xD6FF,
	0xFFFD: 0xD700,
	0xFFFD: 0xD701,
	0xFFFD: 0xD702,
	0xFFFD: 0xD703,
	0xFFFD: 0xD704,
	0xFFFD: 0xD705,
	0xFFFD: 0xD706,
	0xFFFD: 0xD707,
	0xFFFD: 0xD708,
	0xFFFD: 0xD709,
	0xFFFD: 0xD70A,
	0xFFFD: 0xD70B,
	0xFFFD: 0xD70C,
	0xFFFD: 0xD70D,
	0xFFFD: 0xD70E,
	0xFFFD: 0xD70F,
	0xFFFD: 0xD710,
	0xFFFD: 0xD711,
	0xFFFD: 0xD712,
	0xFFFD: 0xD713,
	0xFFFD: 0xD714,
	0xFFFD: 0xD715,
	0xFFFD: 0xD716,
	0xFFFD: 0xD717,
	0xFFFD: 0xD718,
	0xFFFD: 0xD719,
	0xFFFD: 0xD71A,
	0xFFFD: 0xD71B,
	0xFFFD: 0xD71C,
	0xFFFD: 0xD71D,
	0xFFFD: 0xD71E,
	0xFFFD: 0xD71F,
	0xFFFD: 0xD720,
	0xFFFD: 0xD721,
	0xFFFD: 0xD722,
	0xFFFD: 0xD723,
	0xFFFD: 0xD724,
	0xFFFD: 0xD725,
	0xFFFD: 0xD726,
	0xFFFD: 0xD727,
	0xFFFD: 0xD728,
	0xFFFD: 0xD729,
	0xFFFD: 0xD72A,
	0xFFFD: 0xD72B,
	0xFFFD: 0xD72C,
	0xFFFD: 0xD72D,
	0xFFFD: 0xD72E,
	0xFFFD: 0xD72F,
	0xFFFD: 0xD730,
	0xFFFD: 0xD731,
	0xFFFD: 0xD732,
	0xFFFD: 0xD733,
	0xFFFD: 0xD734,
	0xFFFD: 0xD735,
	0xFFFD: 0xD736,
	0xFFFD: 0xD737,
	0xFFFD: 0xD738,
	0xFFFD: 0xD739,
	0xFFFD: 0xD73A,
	0xFFFD: 0xD73B,
	0xFFFD: 0xD73C,
	0xFFFD: 0xD73D,
	0xFFFD: 0xD73E,
	0xFFFD: 0xD73F,
	0xFFFD: 0xD740,
	0xFFFD: 0xD741,
	0xFFFD: 0xD742,
	0xFFFD: 0xD743,
	0xFFFD: 0xD744,
	0xFFFD: 0xD745,
	0xFFFD: 0xD746,
	0xFFFD: 0xD747,
	0xFFFD: 0xD748,
	0xFFFD: 0xD749,
	0xFFFD: 0xD74A,
	0xFFFD: 0xD74B,
	0xFFFD: 0xD74C,
	0xFFFD: 0xD74D,
	0xFFFD: 0xD74E,
	0xFFFD: 0xD74F,
	0xFFFD: 0xD750,
	0xFFFD: 0xD751,
	0xFFFD: 0xD752,
	0xFFFD: 0xD753,
	0xFFFD: 0xD754,
	0xFFFD: 0xD755,
	0xFFFD: 0xD756,
	0xFFFD: 0xD757,
	0xFFFD: 0xD758,
	0xFFFD: 0xD759,
	0xFFFD: 0xD75A,
	0xFFFD: 0xD75B,
	0xFFFD: 0xD75C,
	0xFFFD: 0xD75D,
	0xFFFD: 0xD75E,
	0xFFFD: 0xD75F,
	0xFFFD: 0xD760,
	0xFFFD: 0xD761,
	0xFFFD: 0xD762,
	0xFFFD: 0xD763,
	0xFFFD: 0xD764,
	0xFFFD: 0xD765,
	0xFFFD: 0xD766,
	0xFFFD: 0xD767,
	0xFFFD: 0xD768,
	0xFFFD: 0xD769,
	0xFFFD: 0xD76A,
	0xFFFD: 0xD76B,
	0xFFFD: 0xD76C,
	0xFFFD: 0xD76D,
	0xFFFD: 0xD76E,
	0xFFFD: 0xD76F,
	0xFFFD: 0xD770,
	0xFFFD: 0xD771,
	0xFFFD: 0xD772,
	0xFFFD: 0xD773,
	0xFFFD: 0xD774,
	0xFFFD: 0xD775,
	0xFFFD: 0xD776,
	0xFFFD: 0xD777,
	0xFFFD: 0xD778,
	0xFFFD: 0xD779,
	0xFFFD: 0xD77A,
	0xFFFD: 0xD77B,
	0xFFFD: 0xD77C,
	0xFFFD: 0xD77D,
	0xFFFD: 0xD77E,
	0xFFFD: 0xD77F,
	0xFFFD: 0xD780,
	0xFFFD: 0xD781,
	0xFFFD: 0xD782,
	0xFFFD: 0xD783,
	0xFFFD: 0xD784,
	0xFFFD: 0xD785,
	0xFFFD: 0xD786,
	0xFFFD: 0xD787,
	0xFFFD: 0xD788,
	0xFFFD: 0xD789,
	0xFFFD: 0xD78A,
	0xFFFD: 0xD78B,
	0xFFFD: 0xD78C,
	0xFFFD: 0xD78D,
	0xFFFD: 0xD78E,
	0xFFFD: 0xD78F,
	0xFFFD: 0xD790,
	0xFFFD: 0xD791,
	0xFFFD: 0xD792,
	0xFFFD: 0xD793,
	0xFFFD: 0xD794,
	0xFFFD: 0xD795,
	0xFFFD: 0xD796,
	0xFFFD: 0xD797,
	0xFFFD: 0xD798,
	0xFFFD: 0xD799,
	0xFFFD: 0xD79A,
	0xFFFD: 0xD79B,
	0xFFFD: 0xD79C,
	0xFFFD: 0xD79D,
	0xFFFD: 0xD79E,
	0xFFFD: 0xD79F,
	0xFFFD: 0xD7A0,
	0xFFFD: 0xD7A1,
	0xFFFD: 0xD7A2,
	0xFFFD: 0xD7A3,
	0xFFFD: 0xD7A4,
	0xFFFD: 0xD7A5,
	0xFFFD: 0xD7A6,
	0xFFFD: 0xD7A7,
	0xFFFD: 0xD7A8,
	0xFFFD: 0xD7A9,
	0xFFFD: 0xD7AA,
	0xFFFD: 0xD7AB,
	0xFFFD: 0xD7AC,
	0xFFFD: 0xD7AD,
	0xFFFD: 0xD7AE,
	0xFFFD: 0xD7AF,
	0xFFFD: 0xD7B0,
	0xFFFD: 0xD7B1,
	0xFFFD: 0xD7B2,
	0xFFFD: 0xD7B3,
	0xFFFD: 0xD7B4,
	0xFFFD: 0xD7B5,
	0xFFFD: 0xD7B6,
	0xFFFD: 0xD7B7,
	0xFFFD: 0xD7B8,
	0xFFFD: 0xD7B9,
	0xFFFD: 0xD7BA,
	0xFFFD: 0xD7BB,
	0xFFFD: 0xD7BC,
	0xFFFD: 0xD7BD,
	0xFFFD: 0xD7BE,
	0xFFFD: 0xD7BF,
	0xFFFD: 0xD7C0,
	0xFFFD: 0xD7C1,
	0xFFFD: 0xD7C2,
	0xFFFD: 0xD7C3,
	0xFFFD: 0xD7C4,
	0xFFFD: 0xD7C5,
	0xFFFD: 0xD7C6,
	0xFFFD: 0xD7C7,
	0xFFFD: 0xD7C8,
	0xFFFD: 0xD7C9,
	0xFFFD: 0xD7CA,
	0xFFFD: 0xD7CB,
	0xFFFD: 0xD7CC,
	0xFFFD: 0xD7CD,
	0xFFFD: 0xD7CE,
	0xFFFD: 0xD7CF,
	0xFFFD: 0xD7D0,
	0xFFFD: 0xD7D1,
	0xFFFD: 0xD7D2,
	0xFFFD: 0xD7D3,
	0xFFFD: 0xD7D4,
	0xFFFD: 0xD7D5,
	0xFFFD: 0xD7D6,
	0xFFFD: 0xD7D7,
	0xFFFD: 0xD7D8,
	0xFFFD: 0xD7D9,
	0xFFFD: 0xD7DA,
	0xFFFD: 0xD7DB,
	0xFFFD: 0xD7DC,
	0xFFFD: 0xD7DD,
	0xFFFD: 0xD7DE,
	0xFFFD: 0xD7DF,
	0xFFFD: 0xD7E0,
	0xFFFD: 0xD7E1,
	0xFFFD: 0xD7E2,
	0xFFFD: 0xD7E3,
	0xFFFD: 0xD7E4,
	0xFFFD: 0xD7E5,
	0xFFFD: 0xD7E6,
	0xFFFD: 0xD7E7,
	0xFFFD: 0xD7E8,
	0xFFFD: 0xD7E9,
	0xFFFD: 0xD7EA,
	0xFFFD: 0xD7EB,
	0xFFFD: 0xD7EC,
	0xFFFD: 0xD7ED,
	0xFFFD: 0xD7EE,
	0xFFFD: 0xD7EF,
	0xFFFD: 0xD7F0,
	0xFFFD: 0xD7F1,
	0xFFFD: 0xD7F2,
	0xFFFD: 0xD7F3,
	0xFFFD: 0xD7F4,
	0xFFFD: 0xD7F5,
	0xFFFD: 0xD7F6,
	0xFFFD: 0xD7F7,
	0xFFFD: 0xD7F8,
	0xFFFD: 0xD7F9,
	0xFFFD: 0xD7FA,
	0xFFFD: 0xD7FB,
	0xFFFD: 0xD7FC,
	0xFFFD: 0xD7FD,
	0xFFFD: 0xD7FE,
	0xFFFD: 0xD7FF,
	0xFFFD: 0xD800,
	0xFFFD: 0xD801,
	0xFFFD: 0xD802,
	0xFFFD: 0xD803,
	0xFFFD: 0xD804,
	0xFFFD: 0xD805,
	0xFFFD: 0xD806,
	0xFFFD: 0xD807,
	0xFFFD: 0xD808,
	0xFFFD: 0xD809,
	0xFFFD: 0xD80A,
	0xFFFD: 0xD80B,
	0xFFFD: 0xD80C,
	0xFFFD: 0xD80D,
	0xFFFD: 0xD80E,
	0xFFFD: 0xD80F,
	0xFFFD: 0xD810,
	0xFFFD: 0xD811,
	0xFFFD: 0xD812,
	0xFFFD: 0xD813,
	0xFFFD: 0xD814,
	0xFFFD: 0xD815,
	0xFFFD: 0xD816,
	0xFFFD: 0xD817,
	0xFFFD: 0xD818,
	0xFFFD: 0xD819,
	0xFFFD: 0xD81A,
	0xFFFD: 0xD81B,
	0xFFFD: 0xD81C,
	0xFFFD: 0xD81D,
	0xFFFD: 0xD81E,
	0xFFFD: 0xD81F,
	0xFFFD: 0xD820,
	0xFFFD: 0xD821,
	0xFFFD: 0xD822,
	0xFFFD: 0xD823,
	0xFFFD: 0xD824,
	0xFFFD: 0xD825,
	0xFFFD: 0xD826,
	0xFFFD: 0xD827,
	0xFFFD: 0xD828,
	0xFFFD: 0xD829,
	0xFFFD: 0xD82A,
	0xFFFD: 0xD82B,
	0xFFFD: 0xD82C,
	0xFFFD: 0xD82D,
	0xFFFD: 0xD82E,
	0xFFFD: 0xD82F,
	0xFFFD: 0xD830,
	0xFFFD: 0xD831,
	0xFFFD: 0xD832,
	0xFFFD: 0xD833,
	0xFFFD: 0xD834,
	0xFFFD: 0xD835,
	0xFFFD: 0xD836,
	0xFFFD: 0xD837,
	0xFFFD: 0xD838,
	0xFFFD: 0xD839,
	0xFFFD: 0xD83A,
	0xFFFD: 0xD83B,
	0xFFFD: 0xD83C,
	0xFFFD: 0xD83D,
	0xFFFD: 0xD83E,
	0xFFFD: 0xD83F,
	0xFFFD: 0xD840,
	0xFFFD: 0xD841,
	0xFFFD: 0xD842,
	0xFFFD: 0xD843,
	0xFFFD: 0xD844,
	0xFFFD: 0xD845,
	0xFFFD: 0xD846,
	0xFFFD: 0xD847,
	0xFFFD: 0xD848,
	0xFFFD: 0xD849,
	0xFFFD: 0xD84A,
	0xFFFD: 0xD84B,
	0xFFFD: 0xD84C,
	0xFFFD: 0xD84D,
	0xFFFD: 0xD84E,
	0xFFFD: 0xD84F,
	0xFFFD: 0xD850,
	0xFFFD: 0xD851,
	0xFFFD: 0xD852,
	0xFFFD: 0xD853,
	0xFFFD: 0xD854,
	0xFFFD: 0xD855,
	0xFFFD: 0xD856,
	0xFFFD: 0xD857,
	0xFFFD: 0xD858,
	0xFFFD: 0xD859,
	0xFFFD: 0xD85A,
	0xFFFD: 0xD85B,
	0xFFFD: 0xD85C,
	0xFFFD: 0xD85D,
	0xFFFD: 0xD85E,
	0xFFFD: 0xD85F,
	0xFFFD: 0xD860,
	0xFFFD: 0xD861,
	0xFFFD: 0xD862,
	0xFFFD: 0xD863,
	0xFFFD: 0xD864,
	0xFFFD: 0xD865,
	0xFFFD: 0xD866,
	0xFFFD: 0xD867,
	0xFFFD: 0xD868,
	0xFFFD: 0xD869,
	0xFFFD: 0xD86A,
	0xFFFD: 0xD86B,
	0xFFFD: 0xD86C,
	0xFFFD: 0xD86D,
	0xFFFD: 0xD86E,
	0xFFFD: 0xD86F,
	0xFFFD: 0xD870,
	0xFFFD: 0xD871,
	0xFFFD: 0xD872,
	0xFFFD: 0xD873,
	0xFFFD: 0xD874,
	0xFFFD: 0xD875,
	0xFFFD: 0xD876,
	0xFFFD: 0xD877,
	0xFFFD: 0xD878,
	0xFFFD: 0xD879,
	0xFFFD: 0xD87A,
	0xFFFD: 0xD87B,
	0xFFFD: 0xD87C,
	0xFFFD: 0xD87D,
	0xFFFD: 0xD87E,
	0xFFFD: 0xD87F,
	0xFFFD: 0xD880,
	0xFFFD: 0xD881,
	0xFFFD: 0xD882,
	0xFFFD: 0xD883,
	0xFFFD: 0xD884,
	0xFFFD: 0xD885,
	0xFFFD: 0xD886,
	0xFFFD: 0xD887,
	0xFFFD: 0xD888,
	0xFFFD: 0xD889,
	0xFFFD: 0xD88A,
	0xFFFD: 0xD88B,
	0xFFFD: 0xD88C,
	0xFFFD: 0xD88D,
	0xFFFD: 0xD88E,
	0xFFFD: 0xD88F,
	0xFFFD: 0xD890,
	0xFFFD: 0xD891,
	0xFFFD: 0xD892,
	0xFFFD: 0xD893,
	0xFFFD: 0xD894,
	0xFFFD: 0xD895,
	0xFFFD: 0xD896,
	0xFFFD: 0xD897,
	0xFFFD: 0xD898,
	0xFFFD: 0xD899,
	0xFFFD: 0xD89A,
	0xFFFD: 0xD89B,
	0xFFFD: 0xD89C,
	0xFFFD: 0xD89D,
	0xFFFD: 0xD89E,
	0xFFFD: 0xD89F,
	0xFFFD: 0xD8A0,
	0xFFFD: 0xD8A1,
	0xFFFD: 0xD8A2,
	0xFFFD: 0xD8A3,
	0xFFFD: 0xD8A4,
	0xFFFD: 0xD8A5,
	0xFFFD: 0xD8A6,
	0xFFFD: 0xD8A7,
	0xFFFD: 0xD8A8,
	0xFFFD: 0xD8A9,
	0xFFFD: 0xD8AA,
	0xFFFD: 0xD8AB,
	0xFFFD: 0xD8AC,
	0xFFFD: 0xD8AD,
	0xFFFD: 0xD8AE,
	0xFFFD: 0xD8AF,
	0xFFFD: 0xD8B0,
	0xFFFD: 0xD8B1,
	0xFFFD: 0xD8B2,
	0xFFFD: 0xD8B3,
	0xFFFD: 0xD8B4,
	0xFFFD: 0xD8B5,
	0xFFFD: 0xD8B6,
	0xFFFD: 0xD8B7,
	0xFFFD: 0xD8B8,
	0xFFFD: 0xD8B9,
	0xFFFD: 0xD8BA,
	0xFFFD: 0xD8BB,
	0xFFFD: 0xD8BC,
	0xFFFD: 0xD8BD,
	0xFFFD: 0xD8BE,
	0xFFFD: 0xD8BF,
	0xFFFD: 0xD8C0,
	0xFFFD: 0xD8C1,
	0xFFFD: 0xD8C2,
	0xFFFD: 0xD8C3,
	0xFFFD: 0xD8C4,
	0xFFFD: 0xD8C5,
	0xFFFD: 0xD8C6,
	0xFFFD: 0xD8C7,
	0xFFFD: 0xD8C8,
	0xFFFD: 0xD8C9,
	0xFFFD: 0xD8CA,
	0xFFFD: 0xD8CB,
	0xFFFD: 0xD8CC,
	0xFFFD: 0xD8CD,
	0xFFFD: 0xD8CE,
	0xFFFD: 0xD8CF,
	0xFFFD: 0xD8D0,
	0xFFFD: 0xD8D1,
	0xFFFD: 0xD8D2,
	0xFFFD: 0xD8D3,
	0xFFFD: 0xD8D4,
	0xFFFD: 0xD8D5,
	0xFFFD: 0xD8D6,
	0xFFFD: 0xD8D7,
	0xFFFD: 0xD8D8,
	0xFFFD: 0xD8D9,
	0xFFFD: 0xD8DA,
	0xFFFD: 0xD8DB,
	0xFFFD: 0xD8DC,
	0xFFFD: 0xD8DD,
	0xFFFD: 0xD8DE,
	0xFFFD: 0xD8DF,
	0xFFFD: 0xD8E0,
	0xFFFD: 0xD8E1,
	0xFFFD: 0xD8E2,
	0xFFFD: 0xD8E3,
	0xFFFD: 0xD8E4,
	0xFFFD: 0xD8E5,
	0xFFFD: 0xD8E6,
	0xFFFD: 0xD8E7,
	0xFFFD: 0xD8E8,
	0xFFFD: 0xD8E9,
	0xFFFD: 0xD8EA,
	0xFFFD: 0xD8EB,
	0xFFFD: 0xD8EC,
	0xFFFD: 0xD8ED,
	0xFFFD: 0xD8EE,
	0xFFFD: 0xD8EF,
	0xFFFD: 0xD8F0,
	0xFFFD: 0xD8F1,
	0xFFFD: 0xD8F2,
	0xFFFD: 0xD8F3,
	0xFFFD: 0xD8F4,
	0xFFFD: 0xD8F5,
	0xFFFD: 0xD8F6,
	0xFFFD: 0xD8F7,
	0xFFFD: 0xD8F8,
	0xFFFD: 0xD8F9,
	0xFFFD: 0xD8FA,
	0xFFFD: 0xD8FB,
	0xFFFD: 0xD8FC,
	0xFFFD: 0xD8FD,
	0xFFFD: 0xD8FE,
	0xFFFD: 0xD8FF,
	0xFFFD: 0xD900,
	0xFFFD: 0xD901,
	0xFFFD: 0xD902,
	0xFFFD: 0xD903,
	0xFFFD: 0xD904,
	0xFFFD: 0xD905,
	0xFFFD: 0xD906,
	0xFFFD: 0xD907,
	0xFFFD: 0xD908,
	0xFFFD: 0xD909,
	0xFFFD: 0xD90A,
	0xFFFD: 0xD90B,
	0xFFFD: 0xD90C,
	0xFFFD: 0xD90D,
	0xFFFD: 0xD90E,
	0xFFFD: 0xD90F,
	0xFFFD: 0xD910,
	0xFFFD: 0xD911,
	0xFFFD: 0xD912,
	0xFFFD: 0xD913,
	0xFFFD: 0xD914,
	0xFFFD: 0xD915,
	0xFFFD: 0xD916,
	0xFFFD: 0xD917,
	0xFFFD: 0xD918,
	0xFFFD: 0xD919,
	0xFFFD: 0xD91A,
	0xFFFD: 0xD91B,
	0xFFFD: 0xD91C,
	0xFFFD: 0xD91D,
	0xFFFD: 0xD91E,
	0xFFFD: 0xD91F,
	0xFFFD: 0xD920,
	0xFFFD: 0xD921,
	0xFFFD: 0xD922,
	0xFFFD: 0xD923,
	0xFFFD: 0xD924,
	0xFFFD: 0xD925,
	0xFFFD: 0xD926,
	0xFFFD: 0xD927,
	0xFFFD: 0xD928,
	0xFFFD: 0xD929,
	0xFFFD: 0xD92A,
	0xFFFD: 0xD92B,
	0xFFFD: 0xD92C,
	0xFFFD: 0xD92D,
	0xFFFD: 0xD92E,
	0xFFFD: 0xD92F,
	0xFFFD: 0xD930,
	0xFFFD: 0xD931,
	0xFFFD: 0xD932,
	0xFFFD: 0xD933,
	0xFFFD: 0xD934,
	0xFFFD: 0xD935,
	0xFFFD: 0xD936,
	0xFFFD: 0xD937,
	0xFFFD: 0xD938,
	0xFFFD: 0xD939,
	0xFFFD: 0xD93A,
	0xFFFD: 0xD93B,
	0xFFFD: 0xD93C,
	0xFFFD: 0xD93D,
	0xFFFD: 0xD93E,
	0xFFFD: 0xD93F,
	0xFFFD: 0xD940,
	0xFFFD: 0xD941,
	0xFFFD: 0xD942,
	0xFFFD: 0xD943,
	0xFFFD: 0xD944,
	0xFFFD: 0xD945,
	0xFFFD: 0xD946,
	0xFFFD: 0xD947,
	0xFFFD: 0xD948,
	0xFFFD: 0xD949,
	0xFFFD: 0xD94A,
	0xFFFD: 0xD94B,
	0xFFFD: 0xD94C,
	0xFFFD: 0xD94D,
	0xFFFD: 0xD94E,
	0xFFFD: 0xD94F,
	0xFFFD: 0xD950,
	0xFFFD: 0xD951,
	0xFFFD: 0xD952,
	0xFFFD: 0xD953,
	0xFFFD: 0xD954,
	0xFFFD: 0xD955,
	0xFFFD: 0xD956,
	0xFFFD: 0xD957,
	0xFFFD: 0xD958,
	0xFFFD: 0xD959,
	0xFFFD: 0xD95A,
	0xFFFD: 0xD95B,
	0xFFFD: 0xD95C,
	0xFFFD: 0xD95D,
	0xFFFD: 0xD95E,
	0xFFFD: 0xD95F,
	0xFFFD: 0xD960,
	0xFFFD: 0xD961,
	0xFFFD: 0xD962,
	0xFFFD: 0xD963,
	0xFFFD: 0xD964,
	0xFFFD: 0xD965,
	0xFFFD: 0xD966,
	0xFFFD: 0xD967,
	0xFFFD: 0xD968,
	0xFFFD: 0xD969,
	0xFFFD: 0xD96A,
	0xFFFD: 0xD96B,
	0xFFFD: 0xD96C,
	0xFFFD: 0xD96D,
	0xFFFD: 0xD96E,
	0xFFFD: 0xD96F,
	0xFFFD: 0xD970,
	0xFFFD: 0xD971,
	0xFFFD: 0xD972,
	0xFFFD: 0xD973,
	0xFFFD: 0xD974,
	0xFFFD: 0xD975,
	0xFFFD: 0xD976,
	0xFFFD: 0xD977,
	0xFFFD: 0xD978,
	0xFFFD: 0xD979,
	0xFFFD: 0xD97A,
	0xFFFD: 0xD97B,
	0xFFFD: 0xD97C,
	0xFFFD: 0xD97D,
	0xFFFD: 0xD97E,
	0xFFFD: 0xD97F,
	0xFFFD: 0xD980,
	0xFFFD: 0xD981,
	0xFFFD: 0xD982,
	0xFFFD: 0xD983,
	0xFFFD: 0xD984,
	0xFFFD: 0xD985,
	0xFFFD: 0xD986,
	0xFFFD: 0xD987,
	0xFFFD: 0xD988,
	0xFFFD: 0xD989,
	0xFFFD: 0xD98A,
	0xFFFD: 0xD98B,
	0xFFFD: 0xD98C,
	0xFFFD: 0xD98D,
	0xFFFD: 0xD98E,
	0xFFFD: 0xD98F,
	0xFFFD: 0xD990,
	0xFFFD: 0xD991,
	0xFFFD: 0xD992,
	0xFFFD: 0xD993,
	0xFFFD: 0xD994,
	0xFFFD: 0xD995,
	0xFFFD: 0xD996,
	0xFFFD: 0xD997,
	0xFFFD: 0xD998,
	0xFFFD: 0xD999,
	0xFFFD: 0xD99A,
	0xFFFD: 0xD99B,
	0xFFFD: 0xD99C,
	0xFFFD: 0xD99D,
	0xFFFD: 0xD99E,
	0xFFFD: 0xD99F,
	0xFFFD: 0xD9A0,
	0xFFFD: 0xD9A1,
	0xFFFD: 0xD9A2,
	0xFFFD: 0xD9A3,
	0xFFFD: 0xD9A4,
	0xFFFD: 0xD9A5,
	0xFFFD: 0xD9A6,
	0xFFFD: 0xD9A7,
	0xFFFD: 0xD9A8,
	0xFFFD: 0xD9A9,
	0xFFFD: 0xD9AA,
	0xFFFD: 0xD9AB,
	0xFFFD: 0xD9AC,
	0xFFFD: 0xD9AD,
	0xFFFD: 0xD9AE,
	0xFFFD: 0xD9AF,
	0xFFFD: 0xD9B0,
	0xFFFD: 0xD9B1,
	0xFFFD: 0xD9B2,
	0xFFFD: 0xD9B3,
	0xFFFD: 0xD9B4,
	0xFFFD: 0xD9B5,
	0xFFFD: 0xD9B6,
	0xFFFD: 0xD9B7,
	0xFFFD: 0xD9B8,
	0xFFFD: 0xD9B9,
	0xFFFD: 0xD9BA,
	0xFFFD: 0xD9BB,
	0xFFFD: 0xD9BC,
	0xFFFD: 0xD9BD,
	0xFFFD: 0xD9BE,
	0xFFFD: 0xD9BF,
	0xFFFD: 0xD9C0,
	0xFFFD: 0xD9C1,
	0xFFFD: 0xD9C2,
	0xFFFD: 0xD9C3,
	0xFFFD: 0xD9C4,
	0xFFFD: 0xD9C5,
	0xFFFD: 0xD9C6,
	0xFFFD: 0xD9C7,
	0xFFFD: 0xD9C8,
	0xFFFD: 0xD9C9,
	0xFFFD: 0xD9CA,
	0xFFFD: 0xD9CB,
	0xFFFD: 0xD9CC,
	0xFFFD: 0xD9CD,
	0xFFFD: 0xD9CE,
	0xFFFD: 0xD9CF,
	0xFFFD: 0xD9D0,
	0xFFFD: 0xD9D1,
	0xFFFD: 0xD9D2,
	0xFFFD: 0xD9D3,
	0xFFFD: 0xD9D4,
	0xFFFD: 0xD9D5,
	0xFFFD: 0xD9D6,
	0xFFFD: 0xD9D7,
	0xFFFD: 0xD9D8,
	0xFFFD: 0xD9D9,
	0xFFFD: 0xD9DA,
	0xFFFD: 0xD9DB,
	0xFFFD: 0xD9DC,
	0xFFFD: 0xD9DD,
	0xFFFD: 0xD9DE,
	0xFFFD: 0xD9DF,
	0xFFFD: 0xD9E0,
	0xFFFD: 0xD9E1,
	0xFFFD: 0xD9E2,
	0xFFFD: 0xD9E3,
	0xFFFD: 0xD9E4,
	0xFFFD: 0xD9E5,
	0xFFFD: 0xD9E6,
	0xFFFD: 0xD9E7,
	0xFFFD: 0xD9E8,
	0xFFFD: 0xD9E9,
	0xFFFD: 0xD9EA,
	0xFFFD: 0xD9EB,
	0xFFFD: 0xD9EC,
	0xFFFD: 0xD9ED,
	0xFFFD: 0xD9EE,
	0xFFFD: 0xD9EF,
	0xFFFD: 0xD9F0,
	0xFFFD: 0xD9F1,
	0xFFFD: 0xD9F2,
	0xFFFD: 0xD9F3,
	0xFFFD: 0xD9F4,
	0xFFFD: 0xD9F5,
	0xFFFD: 0xD9F6,
	0xFFFD: 0xD9F7,
	0xFFFD: 0xD9F8,
	0xFFFD: 0xD9F9,
	0xFFFD: 0xD9FA,
	0xFFFD: 0xD9FB,
	0xFFFD: 0xD9FC,
	0xFFFD: 0xD9FD,
	0xFFFD: 0xD9FE,
	0xFFFD: 0xD9FF,
	0xFFFD: 0xDA00,
	0xFFFD: 0xDA01,
	0xFFFD: 0xDA02,
	0xFFFD: 0xDA03,
	0xFFFD: 0xDA04,
	0xFFFD: 0xDA05,
	0xFFFD: 0xDA06,
	0xFFFD: 0xDA07,
	0xFFFD: 0xDA08,
	0xFFFD: 0xDA09,
	0xFFFD: 0xDA0A,
	0xFFFD: 0xDA0B,
	0xFFFD: 0xDA0C,
	0xFFFD: 0xDA0D,
	0xFFFD: 0xDA0E,
	0xFFFD: 0xDA0F,
	0xFFFD: 0xDA10,
	0xFFFD: 0xDA11,
	0xFFFD: 0xDA12,
	0xFFFD: 0xDA13,
	0xFFFD: 0xDA14,
	0xFFFD: 0xDA15,
	0xFFFD: 0xDA16,
	0xFFFD: 0xDA17,
	0xFFFD: 0xDA18,
	0xFFFD: 0xDA19,
	0xFFFD: 0xDA1A,
	0xFFFD: 0xDA1B,
	0xFFFD: 0xDA1C,
	0xFFFD: 0xDA1D,
	0xFFFD: 0xDA1E,
	0xFFFD: 0xDA1F,
	0xFFFD: 0xDA20,
	0xFFFD: 0xDA21,
	0xFFFD: 0xDA22,
	0xFFFD: 0xDA23,
	0xFFFD: 0xDA24,
	0xFFFD: 0xDA25,
	0xFFFD: 0xDA26,
	0xFFFD: 0xDA27,
	0xFFFD: 0xDA28,
	0xFFFD: 0xDA29,
	0xFFFD: 0xDA2A,
	0xFFFD: 0xDA2B,
	0xFFFD: 0xDA2C,
	0xFFFD: 0xDA2D,
	0xFFFD: 0xDA2E,
	0xFFFD: 0xDA2F,
	0xFFFD: 0xDA30,
	0xFFFD: 0xDA31,
	0xFFFD: 0xDA32,
	0xFFFD: 0xDA33,
	0xFFFD: 0xDA34,
	0xFFFD: 0xDA35,
	0xFFFD: 0xDA36,
	0xFFFD: 0xDA37,
	0xFFFD: 0xDA38,
	0xFFFD: 0xDA39,
	0xFFFD: 0xDA3A,
	0xFFFD: 0xDA3B,
	0xFFFD: 0xDA3C,
	0xFFFD: 0xDA3D,
	0xFFFD: 0xDA3E,
	0xFFFD: 0xDA3F,
	0xFFFD: 0xDA40,
	0xFFFD: 0xDA41,
	0xFFFD: 0xDA42,
	0xFFFD: 0xDA43,
	0xFFFD: 0xDA44,
	0xFFFD: 0xDA45,
	0xFFFD: 0xDA46,
	0xFFFD: 0xDA47,
	0xFFFD: 0xDA48,
	0xFFFD: 0xDA49,
	0xFFFD: 0xDA4A,
	0xFFFD: 0xDA4B,
	0xFFFD: 0xDA4C,
	0xFFFD: 0xDA4D,
	0xFFFD: 0xDA4E,
	0xFFFD: 0xDA4F,
	0xFFFD: 0xDA50,
	0xFFFD: 0xDA51,
	0xFFFD: 0xDA52,
	0xFFFD: 0xDA53,
	0xFFFD: 0xDA54,
	0xFFFD: 0xDA55,
	0xFFFD: 0xDA56,
	0xFFFD: 0xDA57,
	0xFFFD: 0xDA58,
	0xFFFD: 0xDA59,
	0xFFFD: 0xDA5A,
	0xFFFD: 0xDA5B,
	0xFFFD: 0xDA5C,
	0xFFFD: 0xDA5D,
	0xFFFD: 0xDA5E,
	0xFFFD: 0xDA5F,
	0xFFFD: 0xDA60,
	0xFFFD: 0xDA61,
	0xFFFD: 0xDA62,
	0xFFFD: 0xDA63,
	0xFFFD: 0xDA64,
	0xFFFD: 0xDA65,
	0xFFFD: 0xDA66,
	0xFFFD: 0xDA67,
	0xFFFD: 0xDA68,
	0xFFFD: 0xDA69,
	0xFFFD: 0xDA6A,
	0xFFFD: 0xDA6B,
	0xFFFD: 0xDA6C,
	0xFFFD: 0xDA6D,
	0xFFFD: 0xDA6E,
	0xFFFD: 0xDA6F,
	0xFFFD: 0xDA70,
	0xFFFD: 0xDA71,
	0xFFFD: 0xDA72,
	0xFFFD: 0xDA73,
	0xFFFD: 0xDA74,
	0xFFFD: 0xDA75,
	0xFFFD: 0xDA76,
	0xFFFD: 0xDA77,
	0xFFFD: 0xDA78,
	0xFFFD: 0xDA79,
	0xFFFD: 0xDA7A,
	0xFFFD: 0xDA7B,
	0xFFFD: 0xDA7C,
	0xFFFD: 0xDA7D,
	0xFFFD: 0xDA7E,
	0xFFFD: 0xDA7F,
	0xFFFD: 0xDA80,
	0xFFFD: 0xDA81,
	0xFFFD: 0xDA82,
	0xFFFD: 0xDA83,
	0xFFFD: 0xDA84,
	0xFFFD: 0xDA85,
	0xFFFD: 0xDA86,
	0xFFFD: 0xDA87,
	0xFFFD: 0xDA88,
	0xFFFD: 0xDA89,
	0xFFFD: 0xDA8A,
	0xFFFD: 0xDA8B,
	0xFFFD: 0xDA8C,
	0xFFFD: 0xDA8D,
	0xFFFD: 0xDA8E,
	0xFFFD: 0xDA8F,
	0xFFFD: 0xDA90,
	0xFFFD: 0xDA91,
	0xFFFD: 0xDA92,
	0xFFFD: 0xDA93,
	0xFFFD: 0xDA94,
	0xFFFD: 0xDA95,
	0xFFFD: 0xDA96,
	0xFFFD: 0xDA97,
	0xFFFD: 0xDA98,
	0xFFFD: 0xDA99,
	0xFFFD: 0xDA9A,
	0xFFFD: 0xDA9B,
	0xFFFD: 0xDA9C,
	0xFFFD: 0xDA9D,
	0xFFFD: 0xDA9E,
	0xFFFD: 0xDA9F,
	0xFFFD: 0xDAA0,
	0xFFFD: 0xDAA1,
	0xFFFD: 0xDAA2,
	0xFFFD: 0xDAA3,
	0xFFFD: 0xDAA4,
	0xFFFD: 0xDAA5,
	0xFFFD: 0xDAA6,
	0xFFFD: 0xDAA7,
	0xFFFD: 0xDAA8,
	0xFFFD: 0xDAA9,
	0xFFFD: 0xDAAA,
	0xFFFD: 0xDAAB,
	0xFFFD: 0xDAAC,
	0xFFFD: 0xDAAD,
	0xFFFD: 0xDAAE,
	0xFFFD: 0xDAAF,
	0xFFFD: 0xDAB0,
	0xFFFD: 0xDAB1,
	0xFFFD: 0xDAB2,
	0xFFFD: 0xDAB3,
	0xFFFD: 0xDAB4,
	0xFFFD: 0xDAB5,
	0xFFFD: 0xDAB6,
	0xFFFD: 0xDAB7,
	0xFFFD: 0xDAB8,
	0xFFFD: 0xDAB9,
	0xFFFD: 0xDABA,
	0xFFFD: 0xDABB,
	0xFFFD: 0xDABC,
	0xFFFD: 0xDABD,
	0xFFFD: 0xDABE,
	0xFFFD: 0xDABF,
	0xFFFD: 0xDAC0,
	0xFFFD: 0xDAC1,
	0xFFFD: 0xDAC2,
	0xFFFD: 0xDAC3,
	0xFFFD: 0xDAC4,
	0xFFFD: 0xDAC5,
	0xFFFD: 0xDAC6,
	0xFFFD: 0xDAC7,
	0xFFFD: 0xDAC8,
	0xFFFD: 0xDAC9,
	0xFFFD: 0xDACA,
	0xFFFD: 0xDACB,
	0xFFFD: 0xDACC,
	0xFFFD: 0xDACD,
	0xFFFD: 0xDACE,
	0xFFFD: 0xDACF,
	0xFFFD: 0xDAD0,
	0xFFFD: 0xDAD1,
	0xFFFD: 0xDAD2,
	0xFFFD: 0xDAD3,
	0xFFFD: 0xDAD4,
	0xFFFD: 0xDAD5,
	0xFFFD: 0xDAD6,
	0xFFFD: 0xDAD7,
	0xFFFD: 0xDAD8,
	0xFFFD: 0xDAD9,
	0xFFFD: 0xDADA,
	0xFFFD: 0xDADB,
	0xFFFD: 0xDADC,
	0xFFFD: 0xDADD,
	0xFFFD: 0xDADE,
	0xFFFD: 0xDADF,
	0xFFFD: 0xDAE0,
	0xFFFD: 0xDAE1,
	0xFFFD: 0xDAE2,
	0xFFFD: 0xDAE3,
	0xFFFD: 0xDAE4,
	0xFFFD: 0xDAE5,
	0xFFFD: 0xDAE6,
	0xFFFD: 0xDAE7,
	0xFFFD: 0xDAE8,
	0xFFFD: 0xDAE9,
	0xFFFD: 0xDAEA,
	0xFFFD: 0xDAEB,
	0xFFFD: 0xDAEC,
	0xFFFD: 0xDAED,
	0xFFFD: 0xDAEE,
	0xFFFD: 0xDAEF,
	0xFFFD: 0xDAF0,
	0xFFFD: 0xDAF1,
	0xFFFD: 0xDAF2,
	0xFFFD: 0xDAF3,
	0xFFFD: 0xDAF4,
	0xFFFD: 0xDAF5,
	0xFFFD: 0xDAF6,
	0xFFFD: 0xDAF7,
	0xFFFD: 0xDAF8,
	0xFFFD: 0xDAF9,
	0xFFFD: 0xDAFA,
	0xFFFD: 0xDAFB,
	0xFFFD: 0xDAFC,
	0xFFFD: 0xDAFD,
	0xFFFD: 0xDAFE,
	0xFFFD: 0xDAFF,
	0xFFFD: 0xDB00,
	0xFFFD: 0xDB01,
	0xFFFD: 0xDB02,
	0xFFFD: 0xDB03,
	0xFFFD: 0xDB04,
	0xFFFD: 0xDB05,
	0xFFFD: 0xDB06,
	0xFFFD: 0xDB07,
	0xFFFD: 0xDB08,
	0xFFFD: 0xDB09,
	0xFFFD: 0xDB0A,
	0xFFFD: 0xDB0B,
	0xFFFD: 0xDB0C,
	0xFFFD: 0xDB0D,
	0xFFFD: 0xDB0E,
	0xFFFD: 0xDB0F,
	0xFFFD: 0xDB10,
	0xFFFD: 0xDB11,
	0xFFFD: 0xDB12,
	0xFFFD: 0xDB13,
	0xFFFD: 0xDB14,
	0xFFFD: 0xDB15,
	0xFFFD: 0xDB16,
	0xFFFD: 0xDB17,
	0xFFFD: 0xDB18,
	0xFFFD: 0xDB19,
	0xFFFD: 0xDB1A,
	0xFFFD: 0xDB1B,
	0xFFFD: 0xDB1C,
	0xFFFD: 0xDB1D,
	0xFFFD: 0xDB1E,
	0xFFFD: 0xDB1F,
	0xFFFD: 0xDB20,
	0xFFFD: 0xDB21,
	0xFFFD: 0xDB22,
	0xFFFD: 0xDB23,
	0xFFFD: 0xDB24,
	0xFFFD: 0xDB25,
	0xFFFD: 0xDB26,
	0xFFFD: 0xDB27,
	0xFFFD: 0xDB28,
	0xFFFD: 0xDB29,
	0xFFFD: 0xDB2A,
	0xFFFD: 0xDB2B,
	0xFFFD: 0xDB2C,
	0xFFFD: 0xDB2D,
	0xFFFD: 0xDB2E,
	0xFFFD: 0xDB2F,
	0xFFFD: 0xDB30,
	0xFFFD: 0xDB31,
	0xFFFD: 0xDB32,
	0xFFFD: 0xDB33,
	0xFFFD: 0xDB34,
	0xFFFD: 0xDB35,
	0xFFFD: 0xDB36,
	0xFFFD: 0xDB37,
	0xFFFD: 0xDB38,
	0xFFFD: 0xDB39,
	0xFFFD: 0xDB3A,
	0xFFFD: 0xDB3B,
	0xFFFD: 0xDB3C,
	0xFFFD: 0xDB3D,
	0xFFFD: 0xDB3E,
	0xFFFD: 0xDB3F,
	0xFFFD: 0xDB40,
	0xFFFD: 0xDB41,
	0xFFFD: 0xDB42,
	0xFFFD: 0xDB43,
	0xFFFD: 0xDB44,
	0xFFFD: 0xDB45,
	0xFFFD: 0xDB46,
	0xFFFD: 0xDB47,
	0xFFFD: 0xDB48,
	0xFFFD: 0xDB49,
	0xFFFD: 0xDB4A,
	0xFFFD: 0xDB4B,
	0xFFFD: 0xDB4C,
	0xFFFD: 0xDB4D,
	0xFFFD: 0xDB4E,
	0xFFFD: 0xDB4F,
	0xFFFD: 0xDB50,
	0xFFFD: 0xDB51,
	0xFFFD: 0xDB52,
	0xFFFD: 0xDB53,
	0xFFFD: 0xDB54,
	0xFFFD: 0xDB55,
	0xFFFD: 0xDB56,
	0xFFFD: 0xDB57,
	0xFFFD: 0xDB58,
	0xFFFD: 0xDB59,
	0xFFFD: 0xDB5A,
	0xFFFD: 0xDB5B,
	0xFFFD: 0xDB5C,
	0xFFFD: 0xDB5D,
	0xFFFD: 0xDB5E,
	0xFFFD: 0xDB5F,
	0xFFFD: 0xDB60,
	0xFFFD: 0xDB61,
	0xFFFD: 0xDB62,
	0xFFFD: 0xDB63,
	0xFFFD: 0xDB64,
	0xFFFD: 0xDB65,
	0xFFFD: 0xDB66,
	0xFFFD: 0xDB67,
	0xFFFD: 0xDB68,
	0xFFFD: 0xDB69,
	0xFFFD: 0xDB6A,
	0xFFFD: 0xDB6B,
	0xFFFD: 0xDB6C,
	0xFFFD: 0xDB6D,
	0xFFFD: 0xDB6E,
	0xFFFD: 0xDB6F,
	0xFFFD: 0xDB70,
	0xFFFD: 0xDB71,
	0xFFFD: 0xDB72,
	0xFFFD: 0xDB73,
	0xFFFD: 0xDB74,
	0xFFFD: 0xDB75,
	0xFFFD: 0xDB76,
	0xFFFD: 0xDB77,
	0xFFFD: 0xDB78,
	0xFFFD: 0xDB79,
	0xFFFD: 0xDB7A,
	0xFFFD: 0xDB7B,
	0xFFFD: 0xDB7C,
	0xFFFD: 0xDB7D,
	0xFFFD: 0xDB7E,
	0xFFFD: 0xDB7F,
	0xFFFD: 0xDB80,
	0xFFFD: 0xDB81,
	0xFFFD: 0xDB82,
	0xFFFD: 0xDB83,
	0xFFFD: 0xDB84,
	0xFFFD: 0xDB85,
	0xFFFD: 0xDB86,
	0xFFFD: 0xDB87,
	0xFFFD: 0xDB88,
	0xFFFD: 0xDB89,
	0xFFFD: 0xDB8A,
	0xFFFD: 0xDB8B,
	0xFFFD: 0xDB8C,
	0xFFFD: 0xDB8D,
	0xFFFD: 0xDB8E,
	0xFFFD: 0xDB8F,
	0xFFFD: 0xDB90,
	0xFFFD: 0xDB91,
	0xFFFD: 0xDB92,
	0xFFFD: 0xDB93,
	0xFFFD: 0xDB94,
	0xFFFD: 0xDB95,
	0xFFFD: 0xDB96,
	0xFFFD: 0xDB97,
	0xFFFD: 0xDB98,
	0xFFFD: 0xDB99,
	0xFFFD: 0xDB9A,
	0xFFFD: 0xDB9B,
	0xFFFD: 0xDB9C,
	0xFFFD: 0xDB9D,
	0xFFFD: 0xDB9E,
	0xFFFD: 0xDB9F,
	0xFFFD: 0xDBA0,
	0xFFFD: 0xDBA1,
	0xFFFD: 0xDBA2,
	0xFFFD: 0xDBA3,
	0xFFFD: 0xDBA4,
	0xFFFD: 0xDBA5,
	0xFFFD: 0xDBA6,
	0xFFFD: 0xDBA7,
	0xFFFD: 0xDBA8,
	0xFFFD: 0xDBA9,
	0xFFFD: 0xDBAA,
	0xFFFD: 0xDBAB,
	0xFFFD: 0xDBAC,
	0xFFFD: 0xDBAD,
	0xFFFD: 0xDBAE,
	0xFFFD: 0xDBAF,
	0xFFFD: 0xDBB0,
	0xFFFD: 0xDBB1,
	0xFFFD: 0xDBB2,
	0xFFFD: 0xDBB3,
	0xFFFD: 0xDBB4,
	0xFFFD: 0xDBB5,
	0xFFFD: 0xDBB6,
	0xFFFD: 0xDBB7,
	0xFFFD: 0xDBB8,
	0xFFFD: 0xDBB9,
	0xFFFD: 0xDBBA,
	0xFFFD: 0xDBBB,
	0xFFFD: 0xDBBC,
	0xFFFD: 0xDBBD,
	0xFFFD: 0xDBBE,
	0xFFFD: 0xDBBF,
	0xFFFD: 0xDBC0,
	0xFFFD: 0xDBC1,
	0xFFFD: 0xDBC2,
	0xFFFD: 0xDBC3,
	0xFFFD: 0xDBC4,
	0xFFFD: 0xDBC5,
	0xFFFD: 0xDBC6,
	0xFFFD: 0xDBC7,
	0xFFFD: 0xDBC8,
	0xFFFD: 0xDBC9,
	0xFFFD: 0xDBCA,
	0xFFFD: 0xDBCB,
	0xFFFD: 0xDBCC,
	0xFFFD: 0xDBCD,
	0xFFFD: 0xDBCE,
	0xFFFD: 0xDBCF,
	0xFFFD: 0xDBD0,
	0xFFFD: 0xDBD1,
	0xFFFD: 0xDBD2,
	0xFFFD: 0xDBD3,
	0xFFFD: 0xDBD4,
	0xFFFD: 0xDBD5,
	0xFFFD: 0xDBD6,
	0xFFFD: 0xDBD7,
	0xFFFD: 0xDBD8,
	0xFFFD: 0xDBD9,
	0xFFFD: 0xDBDA,
	0xFFFD: 0xDBDB,
	0xFFFD: 0xDBDC,
	0xFFFD: 0xDBDD,
	0xFFFD: 0xDBDE,
	0xFFFD: 0xDBDF,
	0xFFFD: 0xDBE0,
	0xFFFD: 0xDBE1,
	0xFFFD: 0xDBE2,
	0xFFFD: 0xDBE3,
	0xFFFD: 0xDBE4,
	0xFFFD: 0xDBE5,
	0xFFFD: 0xDBE6,
	0xFFFD: 0xDBE7,
	0xFFFD: 0xDBE8,
	0xFFFD: 0xDBE9,
	0xFFFD: 0xDBEA,
	0xFFFD: 0xDBEB,
	0xFFFD: 0xDBEC,
	0xFFFD: 0xDBED,
	0xFFFD: 0xDBEE,
	0xFFFD: 0xDBEF,
	0xFFFD: 0xDBF0,
	0xFFFD: 0xDBF1,
	0xFFFD: 0xDBF2,
	0xFFFD: 0xDBF3,
	0xFFFD: 0xDBF4,
	0xFFFD: 0xDBF5,
	0xFFFD: 0xDBF6,
	0xFFFD: 0xDBF7,
	0xFFFD: 0xDBF8,
	0xFFFD: 0xDBF9,
	0xFFFD: 0xDBFA,
	0xFFFD: 0xDBFB,
	0xFFFD: 0xDBFC,
	0xFFFD: 0xDBFD,
	0xFFFD: 0xDBFE,
	0xFFFD: 0xDBFF,
	0xFFFD: 0xDC00,
	0xFFFD: 0xDC01,
	0xFFFD: 0xDC02,
	0xFFFD: 0xDC03,
	0xFFFD: 0xDC04,
	0xFFFD: 0xDC05,
	0xFFFD: 0xDC06,
	0xFFFD: 0xDC07,
	0xFFFD: 0xDC08,
	0xFFFD: 0xDC09,
	0xFFFD: 0xDC0A,
	0xFFFD: 0xDC0B,
	0xFFFD: 0xDC0C,
	0xFFFD: 0xDC0D,
	0xFFFD: 0xDC0E,
	0xFFFD: 0xDC0F,
	0xFFFD: 0xDC10,
	0xFFFD: 0xDC11,
	0xFFFD: 0xDC12,
	0xFFFD: 0xDC13,
	0xFFFD: 0xDC14,
	0xFFFD: 0xDC15,
	0xFFFD: 0xDC16,
	0xFFFD: 0xDC17,
	0xFFFD: 0xDC18,
	0xFFFD: 0xDC19,
	0xFFFD: 0xDC1A,
	0xFFFD: 0xDC1B,
	0xFFFD: 0xDC1C,
	0xFFFD: 0xDC1D,
	0xFFFD: 0xDC1E,
	0xFFFD: 0xDC1F,
	0xFFFD: 0xDC20,
	0xFFFD: 0xDC21,
	0xFFFD: 0xDC22,
	0xFFFD: 0xDC23,
	0xFFFD: 0xDC24,
	0xFFFD: 0xDC25,
	0xFFFD: 0xDC26,
	0xFFFD: 0xDC27,
	0xFFFD: 0xDC28,
	0xFFFD: 0xDC29,
	0xFFFD: 0xDC2A,
	0xFFFD: 0xDC2B,
	0xFFFD: 0xDC2C,
	0xFFFD: 0xDC2D,
	0xFFFD: 0xDC2E,
	0xFFFD: 0xDC2F,
	0xFFFD: 0xDC30,
	0xFFFD: 0xDC31,
	0xFFFD: 0xDC32,
	0xFFFD: 0xDC33,
	0xFFFD: 0xDC34,
	0xFFFD: 0xDC35,
	0xFFFD: 0xDC36,
	0xFFFD: 0xDC37,
	0xFFFD: 0xDC38,
	0xFFFD: 0xDC39,
	0xFFFD: 0xDC3A,
	0xFFFD: 0xDC3B,
	0xFFFD: 0xDC3C,
	0xFFFD: 0xDC3D,
	0xFFFD: 0xDC3E,
	0xFFFD: 0xDC3F,
	0xFFFD: 0xDC40,
	0xFFFD: 0xDC41,
	0xFFFD: 0xDC42,
	0xFFFD: 0xDC43,
	0xFFFD: 0xDC44,
	0xFFFD: 0xDC45,
	0xFFFD: 0xDC46,
	0xFFFD: 0xDC47,
	0xFFFD: 0xDC48,
	0xFFFD: 0xDC49,
	0xFFFD: 0xDC4A,
	0xFFFD: 0xDC4B,
	0xFFFD: 0xDC4C,
	0xFFFD: 0xDC4D,
	0xFFFD: 0xDC4E,
	0xFFFD: 0xDC4F,
	0xFFFD: 0xDC50,
	0xFFFD: 0xDC51,
	0xFFFD: 0xDC52,
	0xFFFD: 0xDC53,
	0xFFFD: 0xDC54,
	0xFFFD: 0xDC55,
	0xFFFD: 0xDC56,
	0xFFFD: 0xDC57,
	0xFFFD: 0xDC58,
	0xFFFD: 0xDC59,
	0xFFFD: 0xDC5A,
	0xFFFD: 0xDC5B,
	0xFFFD: 0xDC5C,
	0xFFFD: 0xDC5D,
	0xFFFD: 0xDC5E,
	0xFFFD: 0xDC5F,
	0xFFFD: 0xDC60,
	0xFFFD: 0xDC61,
	0xFFFD: 0xDC62,
	0xFFFD: 0xDC63,
	0xFFFD: 0xDC64,
	0xFFFD: 0xDC65,
	0xFFFD: 0xDC66,
	0xFFFD: 0xDC67,
	0xFFFD: 0xDC68,
	0xFFFD: 0xDC69,
	0xFFFD: 0xDC6A,
	0xFFFD: 0xDC6B,
	0xFFFD: 0xDC6C,
	0xFFFD: 0xDC6D,
	0xFFFD: 0xDC6E,
	0xFFFD: 0xDC6F,
	0xFFFD: 0xDC70,
	0xFFFD: 0xDC71,
	0xFFFD: 0xDC72,
	0xFFFD: 0xDC73,
	0xFFFD: 0xDC74,
	0xFFFD: 0xDC75,
	0xFFFD: 0xDC76,
	0xFFFD: 0xDC77,
	0xFFFD: 0xDC78,
	0xFFFD: 0xDC79,
	0xFFFD: 0xDC7A,
	0xFFFD: 0xDC7B,
	0xFFFD: 0xDC7C,
	0xFFFD: 0xDC7D,
	0xFFFD: 0xDC7E,
	0xFFFD: 0xDC7F,
	0xFFFD: 0xDC80,
	0xFFFD: 0xDC81,
	0xFFFD: 0xDC82,
	0xFFFD: 0xDC83,
	0xFFFD: 0xDC84,
	0xFFFD: 0xDC85,
	0xFFFD: 0xDC86,
	0xFFFD: 0xDC87,
	0xFFFD: 0xDC88,
	0xFFFD: 0xDC89,
	0xFFFD: 0xDC8A,
	0xFFFD: 0xDC8B,
	0xFFFD: 0xDC8C,
	0xFFFD: 0xDC8D,
	0xFFFD: 0xDC8E,
	0xFFFD: 0xDC8F,
	0xFFFD: 0xDC90,
	0xFFFD: 0xDC91,
	0xFFFD: 0xDC92,
	0xFFFD: 0xDC93,
	0xFFFD: 0xDC94,
	0xFFFD: 0xDC95,
	0xFFFD: 0xDC96,
	0xFFFD: 0xDC97,
	0xFFFD: 0xDC98,
	0xFFFD: 0xDC99,
	0xFFFD: 0xDC9A,
	0xFFFD: 0xDC9B,
	0xFFFD: 0xDC9C,
	0xFFFD: 0xDC9D,
	0xFFFD: 0xDC9E,
	0xFFFD: 0xDC9F,
	0xFFFD: 0xDCA0,
	0xFFFD: 0xDCA1,
	0xFFFD: 0xDCA2,
	0xFFFD: 0xDCA3,
	0xFFFD: 0xDCA4,
	0xFFFD: 0xDCA5,
	0xFFFD: 0xDCA6,
	0xFFFD: 0xDCA7,
	0xFFFD: 0xDCA8,
	0xFFFD: 0xDCA9,
	0xFFFD: 0xDCAA,
	0xFFFD: 0xDCAB,
	0xFFFD: 0xDCAC,
	0xFFFD: 0xDCAD,
	0xFFFD: 0xDCAE,
	0xFFFD: 0xDCAF,
	0xFFFD: 0xDCB0,
	0xFFFD: 0xDCB1,
	0xFFFD: 0xDCB2,
	0xFFFD: 0xDCB3,
	0xFFFD: 0xDCB4,
	0xFFFD: 0xDCB5,
	0xFFFD: 0xDCB6,
	0xFFFD: 0xDCB7,
	0xFFFD: 0xDCB8,
	0xFFFD: 0xDCB9,
	0xFFFD: 0xDCBA,
	0xFFFD: 0xDCBB,
	0xFFFD: 0xDCBC,
	0xFFFD: 0xDCBD,
	0xFFFD: 0xDCBE,
	0xFFFD: 0xDCBF,
	0xFFFD: 0xDCC0,
	0xFFFD: 0xDCC1,
	0xFFFD: 0xDCC2,
	0xFFFD: 0xDCC3,
	0xFFFD: 0xDCC4,
	0xFFFD: 0xDCC5,
	0xFFFD: 0xDCC6,
	0xFFFD: 0xDCC7,
	0xFFFD: 0xDCC8,
	0xFFFD: 0xDCC9,
	0xFFFD: 0xDCCA,
	0xFFFD: 0xDCCB,
	0xFFFD: 0xDCCC,
	0xFFFD: 0xDCCD,
	0xFFFD: 0xDCCE,
	0xFFFD: 0xDCCF,
	0xFFFD: 0xDCD0,
	0xFFFD: 0xDCD1,
	0xFFFD: 0xDCD2,
	0xFFFD: 0xDCD3,
	0xFFFD: 0xDCD4,
	0xFFFD: 0xDCD5,
	0xFFFD: 0xDCD6,
	0xFFFD: 0xDCD7,
	0xFFFD: 0xDCD8,
	0xFFFD: 0xDCD9,
	0xFFFD: 0xDCDA,
	0xFFFD: 0xDCDB,
	0xFFFD: 0xDCDC,
	0xFFFD: 0xDCDD,
	0xFFFD: 0xDCDE,
	0xFFFD: 0xDCDF,
	0xFFFD: 0xDCE0,
	0xFFFD: 0xDCE1,
	0xFFFD: 0xDCE2,
	0xFFFD: 0xDCE3,
	0xFFFD: 0xDCE4,
	0xFFFD: 0xDCE5,
	0xFFFD: 0xDCE6,
	0xFFFD: 0xDCE7,
	0xFFFD: 0xDCE8,
	0xFFFD: 0xDCE9,
	0xFFFD: 0xDCEA,
	0xFFFD: 0xDCEB,
	0xFFFD: 0xDCEC,
	0xFFFD: 0xDCED,
	0xFFFD: 0xDCEE,
	0xFFFD: 0xDCEF,
	0xFFFD: 0xDCF0,
	0xFFFD: 0xDCF1,
	0xFFFD: 0xDCF2,
	0xFFFD: 0xDCF3,
	0xFFFD: 0xDCF4,
	0xFFFD: 0xDCF5,
	0xFFFD: 0xDCF6,
	0xFFFD: 0xDCF7,
	0xFFFD: 0xDCF8,
	0xFFFD: 0xDCF9,
	0xFFFD: 0xDCFA,
	0xFFFD: 0xDCFB,
	0xFFFD: 0xDCFC,
	0xFFFD: 0xDCFD,
	0xFFFD: 0xDCFE,
	0xFFFD: 0xDCFF,
	0xFFFD: 0xDD00,
	0xFFFD: 0xDD01,
	0xFFFD: 0xDD02,
	0xFFFD: 0xDD03,
	0xFFFD: 0xDD04,
	0xFFFD: 0xDD05,
	0xFFFD: 0xDD06,
	0xFFFD: 0xDD07,
	0xFFFD: 0xDD08,
	0xFFFD: 0xDD09,
	0xFFFD: 0xDD0A,
	0xFFFD: 0xDD0B,
	0xFFFD: 0xDD0C,
	0xFFFD: 0xDD0D,
	0xFFFD: 0xDD0E,
	0xFFFD: 0xDD0F,
	0xFFFD: 0xDD10,
	0xFFFD: 0xDD11,
	0xFFFD: 0xDD12,
	0xFFFD: 0xDD13,
	0xFFFD: 0xDD14,
	0xFFFD: 0xDD15,
	0xFFFD: 0xDD16,
	0xFFFD: 0xDD17,
	0xFFFD: 0xDD18,
	0xFFFD: 0xDD19,
	0xFFFD: 0xDD1A,
	0xFFFD: 0xDD1B,
	0xFFFD: 0xDD1C,
	0xFFFD: 0xDD1D,
	0xFFFD: 0xDD1E,
	0xFFFD: 0xDD1F,
	0xFFFD: 0xDD20,
	0xFFFD: 0xDD21,
	0xFFFD: 0xDD22,
	0xFFFD: 0xDD23,
	0xFFFD: 0xDD24,
	0xFFFD: 0xDD25,
	0xFFFD: 0xDD26,
	0xFFFD: 0xDD27,
	0xFFFD: 0xDD28,
	0xFFFD: 0xDD29,
	0xFFFD: 0xDD2A,
	0xFFFD: 0xDD2B,
	0xFFFD: 0xDD2C,
	0xFFFD: 0xDD2D,
	0xFFFD: 0xDD2E,
	0xFFFD: 0xDD2F,
	0xFFFD: 0xDD30,
	0xFFFD: 0xDD31,
	0xFFFD: 0xDD32,
	0xFFFD: 0xDD33,
	0xFFFD: 0xDD34,
	0xFFFD: 0xDD35,
	0xFFFD: 0xDD36,
	0xFFFD: 0xDD37,
	0xFFFD: 0xDD38,
	0xFFFD: 0xDD39,
	0xFFFD: 0xDD3A,
	0xFFFD: 0xDD3B,
	0xFFFD: 0xDD3C,
	0xFFFD: 0xDD3D,
	0xFFFD: 0xDD3E,
	0xFFFD: 0xDD3F,
	0xFFFD: 0xDD40,
	0xFFFD: 0xDD41,
	0xFFFD: 0xDD42,
	0xFFFD: 0xDD43,
	0xFFFD: 0xDD44,
	0xFFFD: 0xDD45,
	0xFFFD: 0xDD46,
	0xFFFD: 0xDD47,
	0xFFFD: 0xDD48,
	0xFFFD: 0xDD49,
	0xFFFD: 0xDD4A,
	0xFFFD: 0xDD4B,
	0xFFFD: 0xDD4C,
	0xFFFD: 0xDD4D,
	0xFFFD: 0xDD4E,
	0xFFFD: 0xDD4F,
	0xFFFD: 0xDD50,
	0xFFFD: 0xDD51,
	0xFFFD: 0xDD52,
	0xFFFD: 0xDD53,
	0xFFFD: 0xDD54,
	0xFFFD: 0xDD55,
	0xFFFD: 0xDD56,
	0xFFFD: 0xDD57,
	0xFFFD: 0xDD58,
	0xFFFD: 0xDD59,
	0xFFFD: 0xDD5A,
	0xFFFD: 0xDD5B,
	0xFFFD: 0xDD5C,
	0xFFFD: 0xDD5D,
	0xFFFD: 0xDD5E,
	0xFFFD: 0xDD5F,
	0xFFFD: 0xDD60,
	0xFFFD: 0xDD61,
	0xFFFD: 0xDD62,
	0xFFFD: 0xDD63,
	0xFFFD: 0xDD64,
	0xFFFD: 0xDD65,
	0xFFFD: 0xDD66,
	0xFFFD: 0xDD67,
	0xFFFD: 0xDD68,
	0xFFFD: 0xDD69,
	0xFFFD: 0xDD6A,
	0xFFFD: 0xDD6B,
	0xFFFD: 0xDD6C,
	0xFFFD: 0xDD6D,
	0xFFFD: 0xDD6E,
	0xFFFD: 0xDD6F,
	0xFFFD: 0xDD70,
	0xFFFD: 0xDD71,
	0xFFFD: 0xDD72,
	0xFFFD: 0xDD73,
	0xFFFD: 0xDD74,
	0xFFFD: 0xDD75,
	0xFFFD: 0xDD76,
	0xFFFD: 0xDD77,
	0xFFFD: 0xDD78,
	0xFFFD: 0xDD79,
	0xFFFD: 0xDD7A,
	0xFFFD: 0xDD7B,
	0xFFFD: 0xDD7C,
	0xFFFD: 0xDD7D,
	0xFFFD: 0xDD7E,
	0xFFFD: 0xDD7F,
	0xFFFD: 0xDD80,
	0xFFFD: 0xDD81,
	0xFFFD: 0xDD82,
	0xFFFD: 0xDD83,
	0xFFFD: 0xDD84,
	0xFFFD: 0xDD85,
	0xFFFD: 0xDD86,
	0xFFFD: 0xDD87,
	0xFFFD: 0xDD88,
	0xFFFD: 0xDD89,
	0xFFFD: 0xDD8A,
	0xFFFD: 0xDD8B,
	0xFFFD: 0xDD8C,
	0xFFFD: 0xDD8D,
	0xFFFD: 0xDD8E,
	0xFFFD: 0xDD8F,
	0xFFFD: 0xDD90,
	0xFFFD: 0xDD91,
	0xFFFD: 0xDD92,
	0xFFFD: 0xDD93,
	0xFFFD: 0xDD94,
	0xFFFD: 0xDD95,
	0xFFFD: 0xDD96,
	0xFFFD: 0xDD97,
	0xFFFD: 0xDD98,
	0xFFFD: 0xDD99,
	0xFFFD: 0xDD9A,
	0xFFFD: 0xDD9B,
	0xFFFD: 0xDD9C,
	0xFFFD: 0xDD9D,
	0xFFFD: 0xDD9E,
	0xFFFD: 0xDD9F,
	0xFFFD: 0xDDA0,
	0xFFFD: 0xDDA1,
	0xFFFD: 0xDDA2,
	0xFFFD: 0xDDA3,
	0xFFFD: 0xDDA4,
	0xFFFD: 0xDDA5,
	0xFFFD: 0xDDA6,
	0xFFFD: 0xDDA7,
	0xFFFD: 0xDDA8,
	0xFFFD: 0xDDA9,
	0xFFFD: 0xDDAA,
	0xFFFD: 0xDDAB,
	0xFFFD: 0xDDAC,
	0xFFFD: 0xDDAD,
	0xFFFD: 0xDDAE,
	0xFFFD: 0xDDAF,
	0xFFFD: 0xDDB0,
	0xFFFD: 0xDDB1,
	0xFFFD: 0xDDB2,
	0xFFFD: 0xDDB3,
	0xFFFD: 0xDDB4,
	0xFFFD: 0xDDB5,
	0xFFFD: 0xDDB6,
	0xFFFD: 0xDDB7,
	0xFFFD: 0xDDB8,
	0xFFFD: 0xDDB9,
	0xFFFD: 0xDDBA,
	0xFFFD: 0xDDBB,
	0xFFFD: 0xDDBC,
	0xFFFD: 0xDDBD,
	0xFFFD: 0xDDBE,
	0xFFFD: 0xDDBF,
	0xFFFD: 0xDDC0,
	0xFFFD: 0xDDC1,
	0xFFFD: 0xDDC2,
	0xFFFD: 0xDDC3,
	0xFFFD: 0xDDC4,
	0xFFFD: 0xDDC5,
	0xFFFD: 0xDDC6,
	0xFFFD: 0xDDC7,
	0xFFFD: 0xDDC8,
	0xFFFD: 0xDDC9,
	0xFFFD: 0xDDCA,
	0xFFFD: 0xDDCB,
	0xFFFD: 0xDDCC,
	0xFFFD: 0xDDCD,
	0xFFFD: 0xDDCE,
	0xFFFD: 0xDDCF,
	0xFFFD: 0xDDD0,
	0xFFFD: 0xDDD1,
	0xFFFD: 0xDDD2,
	0xFFFD: 0xDDD3,
	0xFFFD: 0xDDD4,
	0xFFFD: 0xDDD5,
	0xFFFD: 0xDDD6,
	0xFFFD: 0xDDD7,
	0xFFFD: 0xDDD8,
	0xFFFD: 0xDDD9,
	0xFFFD: 0xDDDA,
	0xFFFD: 0xDDDB,
	0xFFFD: 0xDDDC,
	0xFFFD: 0xDDDD,
	0xFFFD: 0xDDDE,
	0xFFFD: 0xDDDF,
	0xFFFD: 0xDDE0,
	0xFFFD: 0xDDE1,
	0xFFFD: 0xDDE2,
	0xFFFD: 0xDDE3,
	0xFFFD: 0xDDE4,
	0xFFFD: 0xDDE5,
	0xFFFD: 0xDDE6,
	0xFFFD: 0xDDE7,
	0xFFFD: 0xDDE8,
	0xFFFD: 0xDDE9,
	0xFFFD: 0xDDEA,
	0xFFFD: 0xDDEB,
	0xFFFD: 0xDDEC,
	0xFFFD: 0xDDED,
	0xFFFD: 0xDDEE,
	0xFFFD: 0xDDEF,
	0xFFFD: 0xDDF0,
	0xFFFD: 0xDDF1,
	0xFFFD: 0xDDF2,
	0xFFFD: 0xDDF3,
	0xFFFD: 0xDDF4,
	0xFFFD: 0xDDF5,
	0xFFFD: 0xDDF6,
	0xFFFD: 0xDDF7,
	0xFFFD: 0xDDF8,
	0xFFFD: 0xDDF9,
	0xFFFD: 0xDDFA,
	0xFFFD: 0xDDFB,
	0xFFFD: 0xDDFC,
	0xFFFD: 0xDDFD,
	0xFFFD: 0xDDFE,
	0xFFFD: 0xDDFF,
	0xFFFD: 0xDE00,
	0xFFFD: 0xDE01,
	0xFFFD: 0xDE02,
	0xFFFD: 0xDE03,
	0xFFFD: 0xDE04,
	0xFFFD: 0xDE05,
	0xFFFD: 0xDE06,
	0xFFFD: 0xDE07,
	0xFFFD: 0xDE08,
	0xFFFD: 0xDE09,
	0xFFFD: 0xDE0A,
	0xFFFD: 0xDE0B,
	0xFFFD: 0xDE0C,
	0xFFFD: 0xDE0D,
	0xFFFD: 0xDE0E,
	0xFFFD: 0xDE0F,
	0xFFFD: 0xDE10,
	0xFFFD: 0xDE11,
	0xFFFD: 0xDE12,
	0xFFFD: 0xDE13,
	0xFFFD: 0xDE14,
	0xFFFD: 0xDE15,
	0xFFFD: 0xDE16,
	0xFFFD: 0xDE17,
	0xFFFD: 0xDE18,
	0xFFFD: 0xDE19,
	0xFFFD: 0xDE1A,
	0xFFFD: 0xDE1B,
	0xFFFD: 0xDE1C,
	0xFFFD: 0xDE1D,
	0xFFFD: 0xDE1E,
	0xFFFD: 0xDE1F,
	0xFFFD: 0xDE20,
	0xFFFD: 0xDE21,
	0xFFFD: 0xDE22,
	0xFFFD: 0xDE23,
	0xFFFD: 0xDE24,
	0xFFFD: 0xDE25,
	0xFFFD: 0xDE26,
	0xFFFD: 0xDE27,
	0xFFFD: 0xDE28,
	0xFFFD: 0xDE29,
	0xFFFD: 0xDE2A,
	0xFFFD: 0xDE2B,
	0xFFFD: 0xDE2C,
	0xFFFD: 0xDE2D,
	0xFFFD: 0xDE2E,
	0xFFFD: 0xDE2F,
	0xFFFD: 0xDE30,
	0xFFFD: 0xDE31,
	0xFFFD: 0xDE32,
	0xFFFD: 0xDE33,
	0xFFFD: 0xDE34,
	0xFFFD: 0xDE35,
	0xFFFD: 0xDE36,
	0xFFFD: 0xDE37,
	0xFFFD: 0xDE38,
	0xFFFD: 0xDE39,
	0xFFFD: 0xDE3A,
	0xFFFD: 0xDE3B,
	0xFFFD: 0xDE3C,
	0xFFFD: 0xDE3D,
	0xFFFD: 0xDE3E,
	0xFFFD: 0xDE3F,
	0xFFFD: 0xDE40,
	0xFFFD: 0xDE41,
	0xFFFD: 0xDE42,
	0xFFFD: 0xDE43,
	0xFFFD: 0xDE44,
	0xFFFD: 0xDE45,
	0xFFFD: 0xDE46,
	0xFFFD: 0xDE47,
	0xFFFD: 0xDE48,
	0xFFFD: 0xDE49,
	0xFFFD: 0xDE4A,
	0xFFFD: 0xDE4B,
	0xFFFD: 0xDE4C,
	0xFFFD: 0xDE4D,
	0xFFFD: 0xDE4E,
	0xFFFD: 0xDE4F,
	0xFFFD: 0xDE50,
	0xFFFD: 0xDE51,
	0xFFFD: 0xDE52,
	0xFFFD: 0xDE53,
	0xFFFD: 0xDE54,
	0xFFFD: 0xDE55,
	0xFFFD: 0xDE56,
	0xFFFD: 0xDE57,
	0xFFFD: 0xDE58,
	0xFFFD: 0xDE59,
	0xFFFD: 0xDE5A,
	0xFFFD: 0xDE5B,
	0xFFFD: 0xDE5C,
	0xFFFD: 0xDE5D,
	0xFFFD: 0xDE5E,
	0xFFFD: 0xDE5F,
	0xFFFD: 0xDE60,
	0xFFFD: 0xDE61,
	0xFFFD: 0xDE62,
	0xFFFD: 0xDE63,
	0xFFFD: 0xDE64,
	0xFFFD: 0xDE65,
	0xFFFD: 0xDE66,
	0xFFFD: 0xDE67,
	0xFFFD: 0xDE68,
	0xFFFD: 0xDE69,
	0xFFFD: 0xDE6A,
	0xFFFD: 0xDE6B,
	0xFFFD: 0xDE6C,
	0xFFFD: 0xDE6D,
	0xFFFD: 0xDE6E,
	0xFFFD: 0xDE6F,
	0xFFFD: 0xDE70,
	0xFFFD: 0xDE71,
	0xFFFD: 0xDE72,
	0xFFFD: 0xDE73,
	0xFFFD: 0xDE74,
	0xFFFD: 0xDE75,
	0xFFFD: 0xDE76,
	0xFFFD: 0xDE77,
	0xFFFD: 0xDE78,
	0xFFFD: 0xDE79,
	0xFFFD: 0xDE7A,
	0xFFFD: 0xDE7B,
	0xFFFD: 0xDE7C,
	0xFFFD: 0xDE7D,
	0xFFFD: 0xDE7E,
	0xFFFD: 0xDE7F,
	0xFFFD: 0xDE80,
	0xFFFD: 0xDE81,
	0xFFFD: 0xDE82,
	0xFFFD: 0xDE83,
	0xFFFD: 0xDE84,
	0xFFFD: 0xDE85,
	0xFFFD: 0xDE86,
	0xFFFD: 0xDE87,
	0xFFFD: 0xDE88,
	0xFFFD: 0xDE89,
	0xFFFD: 0xDE8A,
	0xFFFD: 0xDE8B,
	0xFFFD: 0xDE8C,
	0xFFFD: 0xDE8D,
	0xFFFD: 0xDE8E,
	0xFFFD: 0xDE8F,
	0xFFFD: 0xDE90,
	0xFFFD: 0xDE91,
	0xFFFD: 0xDE92,
	0xFFFD: 0xDE93,
	0xFFFD: 0xDE94,
	0xFFFD: 0xDE95,
	0xFFFD: 0xDE96,
	0xFFFD: 0xDE97,
	0xFFFD: 0xDE98,
	0xFFFD: 0xDE99,
	0xFFFD: 0xDE9A,
	0xFFFD: 0xDE9B,
	0xFFFD: 0xDE9C,
	0xFFFD: 0xDE9D,
	0xFFFD: 0xDE9E,
	0xFFFD: 0xDE9F,
	0xFFFD: 0xDEA0,
	0xFFFD: 0xDEA1,
	0xFFFD: 0xDEA2,
	0xFFFD: 0xDEA3,
	0xFFFD: 0xDEA4,
	0xFFFD: 0xDEA5,
	0xFFFD: 0xDEA6,
	0xFFFD: 0xDEA7,
	0xFFFD: 0xDEA8,
	0xFFFD: 0xDEA9,
	0xFFFD: 0xDEAA,
	0xFFFD: 0xDEAB,
	0xFFFD: 0xDEAC,
	0xFFFD: 0xDEAD,
	0xFFFD: 0xDEAE,
	0xFFFD: 0xDEAF,
	0xFFFD: 0xDEB0,
	0xFFFD: 0xDEB1,
	0xFFFD: 0xDEB2,
	0xFFFD: 0xDEB3,
	0xFFFD: 0xDEB4,
	0xFFFD: 0xDEB5,
	0xFFFD: 0xDEB6,
	0xFFFD: 0xDEB7,
	0xFFFD: 0xDEB8,
	0xFFFD: 0xDEB9,
	0xFFFD: 0xDEBA,
	0xFFFD: 0xDEBB,
	0xFFFD: 0xDEBC,
	0xFFFD: 0xDEBD,
	0xFFFD: 0xDEBE,
	0xFFFD: 0xDEBF,
	0xFFFD: 0xDEC0,
	0xFFFD: 0xDEC1,
	0xFFFD: 0xDEC2,
	0xFFFD: 0xDEC3,
	0xFFFD: 0xDEC4,
	0xFFFD: 0xDEC5,
	0xFFFD: 0xDEC6,
	0xFFFD: 0xDEC7,
	0xFFFD: 0xDEC8,
	0xFFFD: 0xDEC9,
	0xFFFD: 0xDECA,
	0xFFFD: 0xDECB,
	0xFFFD: 0xDECC,
	0xFFFD: 0xDECD,
	0xFFFD: 0xDECE,
	0xFFFD: 0xDECF,
	0xFFFD: 0xDED0,
	0xFFFD: 0xDED1,
	0xFFFD: 0xDED2,
	0xFFFD: 0xDED3,
	0xFFFD: 0xDED4,
	0xFFFD: 0xDED5,
	0xFFFD: 0xDED6,
	0xFFFD: 0xDED7,
	0xFFFD: 0xDED8,
	0xFFFD: 0xDED9,
	0xFFFD: 0xDEDA,
	0xFFFD: 0xDEDB,
	0xFFFD: 0xDEDC,
	0xFFFD: 0xDEDD,
	0xFFFD: 0xDEDE,
	0xFFFD: 0xDEDF,
	0xFFFD: 0xDEE0,
	0xFFFD: 0xDEE1,
	0xFFFD: 0xDEE2,
	0xFFFD: 0xDEE3,
	0xFFFD: 0xDEE4,
	0xFFFD: 0xDEE5,
	0xFFFD: 0xDEE6,
	0xFFFD: 0xDEE7,
	0xFFFD: 0xDEE8,
	0xFFFD: 0xDEE9,
	0xFFFD: 0xDEEA,
	0xFFFD: 0xDEEB,
	0xFFFD: 0xDEEC,
	0xFFFD: 0xDEED,
	0xFFFD: 0xDEEE,
	0xFFFD: 0xDEEF,
	0xFFFD: 0xDEF0,
	0xFFFD: 0xDEF1,
	0xFFFD: 0xDEF2,
	0xFFFD: 0xDEF3,
	0xFFFD: 0xDEF4,
	0xFFFD: 0xDEF5,
	0xFFFD: 0xDEF6,
	0xFFFD: 0xDEF7,
	0xFFFD: 0xDEF8,
	0xFFFD: 0xDEF9,
	0xFFFD: 0xDEFA,
	0xFFFD: 0xDEFB,
	0xFFFD: 0xDEFC,
	0xFFFD: 0xDEFD,
	0xFFFD: 0xDEFE,
	0xFFFD: 0xDEFF,
	0xFFFD: 0xDF00,
	0xFFFD: 0xDF01,
	0xFFFD: 0xDF02,
	0xFFFD: 0xDF03,
	0xFFFD: 0xDF04,
	0xFFFD: 0xDF05,
	0xFFFD: 0xDF06,
	0xFFFD: 0xDF07,
	0xFFFD: 0xDF08,
	0xFFFD: 0xDF09,
	0xFFFD: 0xDF0A,
	0xFFFD: 0xDF0B,
	0xFFFD: 0xDF0C,
	0xFFFD: 0xDF0D,
	0xFFFD: 0xDF0E,
	0xFFFD: 0xDF0F,
	0xFFFD: 0xDF10,
	0xFFFD: 0xDF11,
	0xFFFD: 0xDF12,
	0xFFFD: 0xDF13,
	0xFFFD: 0xDF14,
	0xFFFD: 0xDF15,
	0xFFFD: 0xDF16,
	0xFFFD: 0xDF17,
	0xFFFD: 0xDF18,
	0xFFFD: 0xDF19,
	0xFFFD: 0xDF1A,
	0xFFFD: 0xDF1B,
	0xFFFD: 0xDF1C,
	0xFFFD: 0xDF1D,
	0xFFFD: 0xDF1E,
	0xFFFD: 0xDF1F,
	0xFFFD: 0xDF20,
	0xFFFD: 0xDF21,
	0xFFFD: 0xDF22,
	0xFFFD: 0xDF23,
	0xFFFD: 0xDF24,
	0xFFFD: 0xDF25,
	0xFFFD: 0xDF26,
	0xFFFD: 0xDF27,
	0xFFFD: 0xDF28,
	0xFFFD: 0xDF29,
	0xFFFD: 0xDF2A,
	0xFFFD: 0xDF2B,
	0xFFFD: 0xDF2C,
	0xFFFD: 0xDF2D,
	0xFFFD: 0xDF2E,
	0xFFFD: 0xDF2F,
	0xFFFD: 0xDF30,
	0xFFFD: 0xDF31,
	0xFFFD: 0xDF32,
	0xFFFD: 0xDF33,
	0xFFFD: 0xDF34,
	0xFFFD: 0xDF35,
	0xFFFD: 0xDF36,
	0xFFFD: 0xDF37,
	0xFFFD: 0xDF38,
	0xFFFD: 0xDF39,
	0xFFFD: 0xDF3A,
	0xFFFD: 0xDF3B,
	0xFFFD: 0xDF3C,
	0xFFFD: 0xDF3D,
	0xFFFD: 0xDF3E,
	0xFFFD: 0xDF3F,
	0xFFFD: 0xDF40,
	0xFFFD: 0xDF41,
	0xFFFD: 0xDF42,
	0xFFFD: 0xDF43,
	0xFFFD: 0xDF44,
	0xFFFD: 0xDF45,
	0xFFFD: 0xDF46,
	0xFFFD: 0xDF47,
	0xFFFD: 0xDF48,
	0xFFFD: 0xDF49,
	0xFFFD: 0xDF4A,
	0xFFFD: 0xDF4B,
	0xFFFD: 0xDF4C,
	0xFFFD: 0xDF4D,
	0xFFFD: 0xDF4E,
	0xFFFD: 0xDF4F,
	0xFFFD: 0xDF50,
	0xFFFD: 0xDF51,
	0xFFFD: 0xDF52,
	0xFFFD: 0xDF53,
	0xFFFD: 0xDF54,
	0xFFFD: 0xDF55,
	0xFFFD: 0xDF56,
	0xFFFD: 0xDF57,
	0xFFFD: 0xDF58,
	0xFFFD: 0xDF59,
	0xFFFD: 0xDF5A,
	0xFFFD: 0xDF5B,
	0xFFFD: 0xDF5C,
	0xFFFD: 0xDF5D,
	0xFFFD: 0xDF5E,
	0xFFFD: 0xDF5F,
	0xFFFD: 0xDF60,
	0xFFFD: 0xDF61,
	0xFFFD: 0xDF62,
	0xFFFD: 0xDF63,
	0xFFFD: 0xDF64,
	0xFFFD: 0xDF65,
	0xFFFD: 0xDF66,
	0xFFFD: 0xDF67,
	0xFFFD: 0xDF68,
	0xFFFD: 0xDF69,
	0xFFFD: 0xDF6A,
	0xFFFD: 0xDF6B,
	0xFFFD: 0xDF6C,
	0xFFFD: 0xDF6D,
	0xFFFD: 0xDF6E,
	0xFFFD: 0xDF6F,
	0xFFFD: 0xDF70,
	0xFFFD: 0xDF71,
	0xFFFD: 0xDF72,
	0xFFFD: 0xDF73,
	0xFFFD: 0xDF74,
	0xFFFD: 0xDF75,
	0xFFFD: 0xDF76,
	0xFFFD: 0xDF77,
	0xFFFD: 0xDF78,
	0xFFFD: 0xDF79,
	0xFFFD: 0xDF7A,
	0xFFFD: 0xDF7B,
	0xFFFD: 0xDF7C,
	0xFFFD: 0xDF7D,
	0xFFFD: 0xDF7E,
	0xFFFD: 0xDF7F,
	0xFFFD: 0xDF80,
	0xFFFD: 0xDF81,
	0xFFFD: 0xDF82,
	0xFFFD: 0xDF83,
	0xFFFD: 0xDF84,
	0xFFFD: 0xDF85,
	0xFFFD: 0xDF86,
	0xFFFD: 0xDF87,
	0xFFFD: 0xDF88,
	0xFFFD: 0xDF89,
	0xFFFD: 0xDF8A,
	0xFFFD: 0xDF8B,
	0xFFFD: 0xDF8C,
	0xFFFD: 0xDF8D,
	0xFFFD: 0xDF8E,
	0xFFFD: 0xDF8F,
	0xFFFD: 0xDF90,
	0xFFFD: 0xDF91,
	0xFFFD: 0xDF92,
	0xFFFD: 0xDF93,
	0xFFFD: 0xDF94,
	0xFFFD: 0xDF95,
	0xFFFD: 0xDF96,
	0xFFFD: 0xDF97,
	0xFFFD: 0xDF98,
	0xFFFD: 0xDF99,
	0xFFFD: 0xDF9A,
	0xFFFD: 0xDF9B,
	0xFFFD: 0xDF9C,
	0xFFFD: 0xDF9D,
	0xFFFD: 0xDF9E,
	0xFFFD: 0xDF9F,
	0xFFFD: 0xDFA0,
	0xFFFD: 0xDFA1,
	0xFFFD: 0xDFA2,
	0xFFFD: 0xDFA3,
	0xFFFD: 0xDFA4,
	0xFFFD: 0xDFA5,
	0xFFFD: 0xDFA6,
	0xFFFD: 0xDFA7,
	0xFFFD: 0xDFA8,
	0xFFFD: 0xDFA9,
	0xFFFD: 0xDFAA,
	0xFFFD: 0xDFAB,
	0xFFFD: 0xDFAC,
	0xFFFD: 0xDFAD,
	0xFFFD: 0xDFAE,
	0xFFFD: 0xDFAF,
	0xFFFD: 0xDFB0,
	0xFFFD: 0xDFB1,
	0xFFFD: 0xDFB2,
	0xFFFD: 0xDFB3,
	0xFFFD: 0xDFB4,
	0xFFFD: 0xDFB5,
	0xFFFD: 0xDFB6,
	0xFFFD: 0xDFB7,
	0xFFFD: 0xDFB8,
	0xFFFD: 0xDFB9,
	0xFFFD: 0xDFBA,
	0xFFFD: 0xDFBB,
	0xFFFD: 0xDFBC,
	0xFFFD: 0xDFBD,
	0xFFFD: 0xDFBE,
	0xFFFD: 0xDFBF,
	0xFFFD: 0xDFC0,
	0xFFFD: 0xDFC1,
	0xFFFD: 0xDFC2,
	0xFFFD: 0xDFC3,
	0xFFFD: 0xDFC4,
	0xFFFD: 0xDFC5,
	0xFFFD: 0xDFC6,
	0xFFFD: 0xDFC7,
	0xFFFD: 0xDFC8,
	0xFFFD: 0xDFC9,
	0xFFFD: 0xDFCA,
	0xFFFD: 0xDFCB,
	0xFFFD: 0xDFCC,
	0xFFFD: 0xDFCD,
	0xFFFD: 0xDFCE,
	0xFFFD: 0xDFCF,
	0xFFFD: 0xDFD0,
	0xFFFD: 0xDFD1,
	0xFFFD: 0xDFD2,
	0xFFFD: 0xDFD3,
	0xFFFD: 0xDFD4,
	0xFFFD: 0xDFD5,
	0xFFFD: 0xDFD6,
	0xFFFD: 0xDFD7,
	0xFFFD: 0xDFD8,
	0xFFFD: 0xDFD9,
	0xFFFD: 0xDFDA,
	0xFFFD: 0xDFDB,
	0xFFFD: 0xDFDC,
	0xFFFD: 0xDFDD,
	0xFFFD: 0xDFDE,
	0xFFFD: 0xDFDF,
	0xFFFD: 0xDFE0,
	0xFFFD: 0xDFE1,
	0xFFFD: 0xDFE2,
	0xFFFD: 0xDFE3,
	0xFFFD: 0xDFE4,
	0xFFFD: 0xDFE5,
	0xFFFD: 0xDFE6,
	0xFFFD: 0xDFE7,
	0xFFFD: 0xDFE8,
	0xFFFD: 0xDFE9,
	0xFFFD: 0xDFEA,
	0xFFFD: 0xDFEB,
	0xFFFD: 0xDFEC,
	0xFFFD: 0xDFED,
	0xFFFD: 0xDFEE,
	0xFFFD: 0xDFEF,
	0xFFFD: 0xDFF0,
	0xFFFD: 0xDFF1,
	0xFFFD: 0xDFF2,
	0xFFFD: 0xDFF3,
	0xFFFD: 0xDFF4,
	0xFFFD: 0xDFF5,
	0xFFFD: 0xDFF6,
	0xFFFD: 0xDFF7,
	0xFFFD: 0xDFF8,
	0xFFFD: 0xDFF9,
	0xFFFD: 0xDFFA,
	0xFFFD: 0xDFFB,
	0xFFFD: 0xDFFC,
	0xFFFD: 0xDFFD,
	0xFFFD: 0xDFFE,
	0xFFFD: 0xDFFF,
	0xFA40: 0xE000,
	0xFA41: 0xE001,
	0xFA42: 0xE002,
	0xFA43: 0xE003,
	0xFA44: 0xE004,
	0xFA45: 0xE005,
	0xFA46: 0xE006,
	0xFA47: 0xE007,
	0xFA48: 0xE008,
	0xFA49: 0xE009,
	0xFA4A: 0xE00A,
	0xFA4B: 0xE00B,
	0xFA4C: 0xE00C,
	0xFA4D: 0xE00D,
	0xFA4E: 0xE00E,
	0xFA4F: 0xE00F,
	0xFA50: 0xE010,
	0xFA51: 0xE011,
	0xFA52: 0xE012,
	0xFA53: 0xE013,
	0xFA54: 0xE014,
	0xFA55: 0xE015,
	0xFA56: 0xE016,
	0xFA57: 0xE017,
	0xFA58: 0xE018,
	0xFA59: 0xE019,
	0xFA5A: 0xE01A,
	0xFA5B: 0xE01B,
	0xFA5C: 0xE01C,
	0xFA5D: 0xE01D,
	0xFA5E: 0xE01E,
	0xFA5F: 0xE01F,
	0xFA60: 0xE020,
	0xFA61: 0xE021,
	0xFA62: 0xE022,
	0xFA63: 0xE023,
	0xFA64: 0xE024,
	0xFA65: 0xE025,
	0xFA66: 0xE026,
	0xFA67: 0xE027,
	0xFA68: 0xE028,
	0xFA69: 0xE029,
	0xFA6A: 0xE02A,
	0xFA6B: 0xE02B,
	0xFA6C: 0xE02C,
	0xFA6D: 0xE02D,
	0xFA6E: 0xE02E,
	0xFA6F: 0xE02F,
	0xFA70: 0xE030,
	0xFA71: 0xE031,
	0xFA72: 0xE032,
	0xFA73: 0xE033,
	0xFA74: 0xE034,
	0xFA75: 0xE035,
	0xFA76: 0xE036,
	0xFA77: 0xE037,
	0xFA78: 0xE038,
	0xFA79: 0xE039,
	0xFA7A: 0xE03A,
	0xFA7B: 0xE03B,
	0xFA7C: 0xE03C,
	0xFA7D: 0xE03D,
	0xFA7E: 0xE03E,
	0xFAA1: 0xE03F,
	0xFAA2: 0xE040,
	0xFAA3: 0xE041,
	0xFAA4: 0xE042,
	0xFAA5: 0xE043,
	0xFAA6: 0xE044,
	0xFAA7: 0xE045,
	0xFAA8: 0xE046,
	0xFAA9: 0xE047,
	0xFAAA: 0xE048,
	0xFAAB: 0xE049,
	0xFAAC: 0xE04A,
	0xFAAD: 0xE04B,
	0xFAAE: 0xE04C,
	0xFAAF: 0xE04D,
	0xFAB0: 0xE04E,
	0xFAB1: 0xE04F,
	0xFAB2: 0xE050,
	0xFAB3: 0xE051,
	0xFAB4: 0xE052,
	0xFAB5: 0xE053,
	0xFAB6: 0xE054,
	0xFAB7: 0xE055,
	0xFAB8: 0xE056,
	0xFAB9: 0xE057,
	0xFABA: 0xE058,
	0xFABB: 0xE059,
	0xFABC: 0xE05A,
	0xFABD: 0xE05B,
	0xFABE: 0xE05C,
	0xFABF: 0xE05D,
	0xFAC0: 0xE05E,
	0xFAC1: 0xE05F,
	0xFAC2: 0xE060,
	0xFAC3: 0xE061,
	0xFAC4: 0xE062,
	0xFAC5: 0xE063,
	0xFAC6: 0xE064,
	0xFAC7: 0xE065,
	0xFAC8: 0xE066,
	0xFAC9: 0xE067,
	0xFACA: 0xE068,
	0xFACB: 0xE069,
	0xFACC: 0xE06A,
	0xFACD: 0xE06B,
	0xFACE: 0xE06C,
	0xFACF: 0xE06D,
	0xFAD0: 0xE06E,
	0xFAD1: 0xE06F,
	0xFAD2: 0xE070,
	0xFAD3: 0xE071,
	0xFAD4: 0xE072,
	0xFAD5: 0xE073,
	0xFAD6: 0xE074,
	0xFAD7: 0xE075,
	0xFAD8: 0xE076,
	0xFAD9: 0xE077,
	0xFADA: 0xE078,
	0xFADB: 0xE079,
	0xFADC: 0xE07A,
	0xFADD: 0xE07B,
	0xFADE: 0xE07C,
	0xFADF: 0xE07D,
	0xFAE0: 0xE07E,
	0xFAE1: 0xE07F,
	0xFAE2: 0xE080,
	0xFAE3: 0xE081,
	0xFAE4: 0xE082,
	0xFAE5: 0xE083,
	0xFAE6: 0xE084,
	0xFAE7: 0xE085,
	0xFAE8: 0xE086,
	0xFAE9: 0xE087,
	0xFAEA: 0xE088,
	0xFAEB: 0xE089,
	0xFAEC: 0xE08A,
	0xFAED: 0xE08B,
	0xFAEE: 0xE08C,
	0xFAEF: 0xE08D,
	0xFAF0: 0xE08E,
	0xFAF1: 0xE08F,
	0xFAF2: 0xE090,
	0xFAF3: 0xE091,
	0xFAF4: 0xE092,
	0xFAF5: 0xE093,
	0xFAF6: 0xE094,
	0xFAF7: 0xE095,
	0xFAF8: 0xE096,
	0xFAF9: 0xE097,
	0xFAFA: 0xE098,
	0xFAFB: 0xE099,
	0xFAFC: 0xE09A,
	0xFAFD: 0xE09B,
	0xFAFE: 0xE09C,
	0xFB40: 0xE09D,
	0xFB41: 0xE09E,
	0xFB42: 0xE09F,
	0xFB43: 0xE0A0,
	0xFB44: 0xE0A1,
	0xFB45: 0xE0A2,
	0xFB46: 0xE0A3,
	0xFB47: 0xE0A4,
	0xFB48: 0xE0A5,
	0xFB49: 0xE0A6,
	0xFB4A: 0xE0A7,
	0xFB4B: 0xE0A8,
	0xFB4C: 0xE0A9,
	0xFB4D: 0xE0AA,
	0xFB4E: 0xE0AB,
	0xFB4F: 0xE0AC,
	0xFB50: 0xE0AD,
	0xFB51: 0xE0AE,
	0xFB52: 0xE0AF,
	0xFB53: 0xE0B0,
	0xFB54: 0xE0B1,
	0xFB55: 0xE0B2,
	0xFB56: 0xE0B3,
	0xFB57: 0xE0B4,
	0xFB58: 0xE0B5,
	0xFB59: 0xE0B6,
	0xFB5A: 0xE0B7,
	0xFB5B: 0xE0B8,
	0xFB5C: 0xE0B9,
	0xFB5D: 0xE0BA,
	0xFB5E: 0xE0BB,
	0xFB5F: 0xE0BC,
	0xFB60: 0xE0BD,
	0xFB61: 0xE0BE,
	0xFB62: 0xE0BF,
	0xFB63: 0xE0C0,
	0xFB64: 0xE0C1,
	0xFB65: 0xE0C2,
	0xFB66: 0xE0C3,
	0xFB67: 0xE0C4,
	0xFB68: 0xE0C5,
	0xFB69: 0xE0C6,
	0xFB6A: 0xE0C7,
	0xFB6B: 0xE0C8,
	0xFB6C: 0xE0C9,
	0xFB6D: 0xE0CA,
	0xFB6E: 0xE0CB,
	0xFB6F: 0xE0CC,
	0xFB70: 0xE0CD,
	0xFB71: 0xE0CE,
	0xFB72: 0xE0CF,
	0xFB73: 0xE0D0,
	0xFB74: 0xE0D1,
	0xFB75: 0xE0D2,
	0xFB76: 0xE0D3,
	0xFB77: 0xE0D4,
	0xFB78: 0xE0D5,
	0xFB79: 0xE0D6,
	0xFB7A: 0xE0D7,
	0xFB7B: 0xE0D8,
	0xFB7C: 0xE0D9,
	0xFB7D: 0xE0DA,
	0xFB7E: 0xE0DB,
	0xFBA1: 0xE0DC,
	0xFBA2: 0xE0DD,
	0xFBA3: 0xE0DE,
	0xFBA4: 0xE0DF,
	0xFBA5: 0xE0E0,
	0xFBA6: 0xE0E1,
	0xFBA7: 0xE0E2,
	0xFBA8: 0xE0E3,
	0xFBA9: 0xE0E4,
	0xFBAA: 0xE0E5,
	0xFBAB: 0xE0E6,
	0xFBAC: 0xE0E7,
	0xFBAD: 0xE0E8,
	0xFBAE: 0xE0E9,
	0xFBAF: 0xE0EA,
	0xFBB0: 0xE0EB,
	0xFBB1: 0xE0EC,
	0xFBB2: 0xE0ED,
	0xFBB3: 0xE0EE,
	0xFBB4: 0xE0EF,
	0xFBB5: 0xE0F0,
	0xFBB6: 0xE0F1,
	0xFBB7: 0xE0F2,
	0xFBB8: 0xE0F3,
	0xFBB9: 0xE0F4,
	0xFBBA: 0xE0F5,
	0xFBBB: 0xE0F6,
	0xFBBC: 0xE0F7,
	0xFBBD: 0xE0F8,
	0xFBBE: 0xE0F9,
	0xFBBF: 0xE0FA,
	0xFBC0: 0xE0FB,
	0xFBC1: 0xE0FC,
	0xFBC2: 0xE0FD,
	0xFBC3: 0xE0FE,
	0xFBC4: 0xE0FF,
	0xFBC5: 0xE100,
	0xFBC6: 0xE101,
	0xFBC7: 0xE102,
	0xFBC8: 0xE103,
	0xFBC9: 0xE104,
	0xFBCA: 0xE105,
	0xFBCB: 0xE106,
	0xFBCC: 0xE107,
	0xFBCD: 0xE108,
	0xFBCE: 0xE109,
	0xFBCF: 0xE10A,
	0xFBD0: 0xE10B,
	0xFBD1: 0xE10C,
	0xFBD2: 0xE10D,
	0xFBD3: 0xE10E,
	0xFBD4: 0xE10F,
	0xFBD5: 0xE110,
	0xFBD6: 0xE111,
	0xFBD7: 0xE112,
	0xFBD8: 0xE113,
	0xFBD9: 0xE114,
	0xFBDA: 0xE115,
	0xFBDB: 0xE116,
	0xFBDC: 0xE117,
	0xFBDD: 0xE118,
	0xFBDE: 0xE119,
	0xFBDF: 0xE11A,
	0xFBE0: 0xE11B,
	0xFBE1: 0xE11C,
	0xFBE2: 0xE11D,
	0xFBE3: 0xE11E,
	0xFBE4: 0xE11F,
	0xFBE5: 0xE120,
	0xFBE6: 0xE121,
	0xFBE7: 0xE122,
	0xFBE8: 0xE123,
	0xFBE9: 0xE124,
	0xFBEA: 0xE125,
	0xFBEB: 0xE126,
	0xFBEC: 0xE127,
	0xFBED: 0xE128,
	0xFBEE: 0xE129,
	0xFBEF: 0xE12A,
	0xFBF0: 0xE12B,
	0xFBF1: 0xE12C,
	0xFBF2: 0xE12D,
	0xFBF3: 0xE12E,
	0xFBF4: 0xE12F,
	0xFBF5: 0xE130,
	0xFBF6: 0xE131,
	0xFBF7: 0xE132,
	0xFBF8: 0xE133,
	0xFBF9: 0xE134,
	0xFBFA: 0xE135,
	0xFBFB: 0xE136,
	0xFBFC: 0xE137,
	0xFBFD: 0xE138,
	0xFBFE: 0xE139,
	0xFC40: 0xE13A,
	0xFC41: 0xE13B,
	0xFC42: 0xE13C,
	0xFC43: 0xE13D,
	0xFC44: 0xE13E,
	0xFC45: 0xE13F,
	0xFC46: 0xE140,
	0xFC47: 0xE141,
	0xFC48: 0xE142,
	0xFC49: 0xE143,
	0xFC4A: 0xE144,
	0xFC4B: 0xE145,
	0xFC4C: 0xE146,
	0xFC4D: 0xE147,
	0xFC4E: 0xE148,
	0xFC4F: 0xE149,
	0xFC50: 0xE14A,
	0xFC51: 0xE14B,
	0xFC52: 0xE14C,
	0xFC53: 0xE14D,
	0xFC54: 0xE14E,
	0xFC55: 0xE14F,
	0xFC56: 0xE150,
	0xFC57: 0xE151,
	0xFC58: 0xE152,
	0xFC59: 0xE153,
	0xFC5A: 0xE154,
	0xFC5B: 0xE155,
	0xFC5C: 0xE156,
	0xFC5D: 0xE157,
	0xFC5E: 0xE158,
	0xFC5F: 0xE159,
	0xFC60: 0xE15A,
	0xFC61: 0xE15B,
	0xFC62: 0xE15C,
	0xFC63: 0xE15D,
	0xFC64: 0xE15E,
	0xFC65: 0xE15F,
	0xFC66: 0xE160,
	0xFC67: 0xE161,
	0xFC68: 0xE162,
	0xFC69: 0xE163,
	0xFC6A: 0xE164,
	0xFC6B: 0xE165,
	0xFC6C: 0xE166,
	0xFC6D: 0xE167,
	0xFC6E: 0xE168,
	0xFC6F: 0xE169,
	0xFC70: 0xE16A,
	0xFC71: 0xE16B,
	0xFC72: 0xE16C,
	0xFC73: 0xE16D,
	0xFC74: 0xE16E,
	0xFC75: 0xE16F,
	0xFC76: 0xE170,
	0xFC77: 0xE171,
	0xFC78: 0xE172,
	0xFC79: 0xE173,
	0xFC7A: 0xE174,
	0xFC7B: 0xE175,
	0xFC7C: 0xE176,
	0xFC7D: 0xE177,
	0xFC7E: 0xE178,
	0xFCA1: 0xE179,
	0xFCA2: 0xE17A,
	0xFCA3: 0xE17B,
	0xFCA4: 0xE17C,
	0xFCA5: 0xE17D,
	0xFCA6: 0xE17E,
	0xFCA7: 0xE17F,
	0xFCA8: 0xE180,
	0xFCA9: 0xE181,
	0xFCAA: 0xE182,
	0xFCAB: 0xE183,
	0xFCAC: 0xE184,
	0xFCAD: 0xE185,
	0xFCAE: 0xE186,
	0xFCAF: 0xE187,
	0xFCB0: 0xE188,
	0xFCB1: 0xE189,
	0xFCB2: 0xE18A,
	0xFCB3: 0xE18B,
	0xFCB4: 0xE18C,
	0xFCB5: 0xE18D,
	0xFCB6: 0xE18E,
	0xFCB7: 0xE18F,
	0xFCB8: 0xE190,
	0xFCB9: 0xE191,
	0xFCBA: 0xE192,
	0xFCBB: 0xE193,
	0xFCBC: 0xE194,
	0xFCBD: 0xE195,
	0xFCBE: 0xE196,
	0xFCBF: 0xE197,
	0xFCC0: 0xE198,
	0xFCC1: 0xE199,
	0xFCC2: 0xE19A,
	0xFCC3: 0xE19B,
	0xFCC4: 0xE19C,
	0xFCC5: 0xE19D,
	0xFCC6: 0xE19E,
	0xFCC7: 0xE19F,
	0xFCC8: 0xE1A0,
	0xFCC9: 0xE1A1,
	0xFCCA: 0xE1A2,
	0xFCCB: 0xE1A3,
	0xFCCC: 0xE1A4,
	0xFCCD: 0xE1A5,
	0xFCCE: 0xE1A6,
	0xFCCF: 0xE1A7,
	0xFCD0: 0xE1A8,
	0xFCD1: 0xE1A9,
	0xFCD2: 0xE1AA,
	0xFCD3: 0xE1AB,
	0xFCD4: 0xE1AC,
	0xFCD5: 0xE1AD,
	0xFCD6: 0xE1AE,
	0xFCD7: 0xE1AF,
	0xFCD8: 0xE1B0,
	0xFCD9: 0xE1B1,
	0xFCDA: 0xE1B2,
	0xFCDB: 0xE1B3,
	0xFCDC: 0xE1B4,
	0xFCDD: 0xE1B5,
	0xFCDE: 0xE1B6,
	0xFCDF: 0xE1B7,
	0xFCE0: 0xE1B8,
	0xFCE1: 0xE1B9,
	0xFCE2: 0xE1BA,
	0xFCE3: 0xE1BB,
	0xFCE4: 0xE1BC,
	0xFCE5: 0xE1BD,
	0xFCE6: 0xE1BE,
	0xFCE7: 0xE1BF,
	0xFCE8: 0xE1C0,
	0xFCE9: 0xE1C1,
	0xFCEA: 0xE1C2,
	0xFCEB: 0xE1C3,
	0xFCEC: 0xE1C4,
	0xFCED: 0xE1C5,
	0xFCEE: 0xE1C6,
	0xFCEF: 0xE1C7,
	0xFCF0: 0xE1C8,
	0xFCF1: 0xE1C9,
	0xFCF2: 0xE1CA,
	0xFCF3: 0xE1CB,
	0xFCF4: 0xE1CC,
	0xFCF5: 0xE1CD,
	0xFCF6: 0xE1CE,
	0xFCF7: 0xE1CF,
	0xFCF8: 0xE1D0,
	0xFCF9: 0xE1D1,
	0xFCFA: 0xE1D2,
	0xFCFB: 0xE1D3,
	0xFCFC: 0xE1D4,
	0xFCFD: 0xE1D5,
	0xFCFE: 0xE1D6,
	0xFD40: 0xE1D7,
	0xFD41: 0xE1D8,
	0xFD42: 0xE1D9,
	0xFD43: 0xE1DA,
	0xFD44: 0xE1DB,
	0xFD45: 0xE1DC,
	0xFD46: 0xE1DD,
	0xFD47: 0xE1DE,
	0xFD48: 0xE1DF,
	0xFD49: 0xE1E0,
	0xFD4A: 0xE1E1,
	0xFD4B: 0xE1E2,
	0xFD4C: 0xE1E3,
	0xFD4D: 0xE1E4,
	0xFD4E: 0xE1E5,
	0xFD4F: 0xE1E6,
	0xFD50: 0xE1E7,
	0xFD51: 0xE1E8,
	0xFD52: 0xE1E9,
	0xFD53: 0xE1EA,
	0xFD54: 0xE1EB,
	0xFD55: 0xE1EC,
	0xFD56: 0xE1ED,
	0xFD57: 0xE1EE,
	0xFD58: 0xE1EF,
	0xFD59: 0xE1F0,
	0xFD5A: 0xE1F1,
	0xFD5B: 0xE1F2,
	0xFD5C: 0xE1F3,
	0xFD5D: 0xE1F4,
	0xFD5E: 0xE1F5,
	0xFD5F: 0xE1F6,
	0xFD60: 0xE1F7,
	0xFD61: 0xE1F8,
	0xFD62: 0xE1F9,
	0xFD63: 0xE1FA,
	0xFD64: 0xE1FB,
	0xFD65: 0xE1FC,
	0xFD66: 0xE1FD,
	0xFD67: 0xE1FE,
	0xFD68: 0xE1FF,
	0xFD69: 0xE200,
	0xFD6A: 0xE201,
	0xFD6B: 0xE202,
	0xFD6C: 0xE203,
	0xFD6D: 0xE204,
	0xFD6E: 0xE205,
	0xFD6F: 0xE206,
	0xFD70: 0xE207,
	0xFD71: 0xE208,
	0xFD72: 0xE209,
	0xFD73: 0xE20A,
	0xFD74: 0xE20B,
	0xFD75: 0xE20C,
	0xFD76: 0xE20D,
	0xFD77: 0xE20E,
	0xFD78: 0xE20F,
	0xFD79: 0xE210,
	0xFD7A: 0xE211,
	0xFD7B: 0xE212,
	0xFD7C: 0xE213,
	0xFD7D: 0xE214,
	0xFD7E: 0xE215,
	0xFDA1: 0xE216,
	0xFDA2: 0xE217,
	0xFDA3: 0xE218,
	0xFDA4: 0xE219,
	0xFDA5: 0xE21A,
	0xFDA6: 0xE21B,
	0xFDA7: 0xE21C,
	0xFDA8: 0xE21D,
	0xFDA9: 0xE21E,
	0xFDAA: 0xE21F,
	0xFDAB: 0xE220,
	0xFDAC: 0xE221,
	0xFDAD: 0xE222,
	0xFDAE: 0xE223,
	0xFDAF: 0xE224,
	0xFDB0: 0xE225,
	0xFDB1: 0xE226,
	0xFDB2: 0xE227,
	0xFDB3: 0xE228,
	0xFDB4: 0xE229,
	0xFDB5: 0xE22A,
	0xFDB6: 0xE22B,
	0xFDB7: 0xE22C,
	0xFDB8: 0xE22D,
	0xFDB9: 0xE22E,
	0xFDBA: 0xE22F,
	0xFDBB: 0xE230,
	0xFDBC: 0xE231,
	0xFDBD: 0xE232,
	0xFDBE: 0xE233,
	0xFDBF: 0xE234,
	0xFDC0: 0xE235,
	0xFDC1: 0xE236,
	0xFDC2: 0xE237,
	0xFDC3: 0xE238,
	0xFDC4: 0xE239,
	0xFDC5: 0xE23A,
	0xFDC6: 0xE23B,
	0xFDC7: 0xE23C,
	0xFDC8: 0xE23D,
	0xFDC9: 0xE23E,
	0xFDCA: 0xE23F,
	0xFDCB: 0xE240,
	0xFDCC: 0xE241,
	0xFDCD: 0xE242,
	0xFDCE: 0xE243,
	0xFDCF: 0xE244,
	0xFDD0: 0xE245,
	0xFDD1: 0xE246,
	0xFDD2: 0xE247,
	0xFDD3: 0xE248,
	0xFDD4: 0xE249,
	0xFDD5: 0xE24A,
	0xFDD6: 0xE24B,
	0xFDD7: 0xE24C,
	0xFDD8: 0xE24D,
	0xFDD9: 0xE24E,
	0xFDDA: 0xE24F,
	0xFDDB: 0xE250,
	0xFDDC: 0xE251,
	0xFDDD: 0xE252,
	0xFDDE: 0xE253,
	0xFDDF: 0xE254,
	0xFDE0: 0xE255,
	0xFDE1: 0xE256,
	0xFDE2: 0xE257,
	0xFDE3: 0xE258,
	0xFDE4: 0xE259,
	0xFDE5: 0xE25A,
	0xFDE6: 0xE25B,
	0xFDE7: 0xE25C,
	0xFDE8: 0xE25D,
	0xFDE9: 0xE25E,
	0xFDEA: 0xE25F,
	0xFDEB: 0xE260,
	0xFDEC: 0xE261,
	0xFDED: 0xE262,
	0xFDEE: 0xE263,
	0xFDEF: 0xE264,
	0xFDF0: 0xE265,
	0xFDF1: 0xE266,
	0xFDF2: 0xE267,
	0xFDF3: 0xE268,
	0xFDF4: 0xE269,
	0xFDF5: 0xE26A,
	0xFDF6: 0xE26B,
	0xFDF7: 0xE26C,
	0xFDF8: 0xE26D,
	0xFDF9: 0xE26E,
	0xFDFA: 0xE26F,
	0xFDFB: 0xE270,
	0xFDFC: 0xE271,
	0xFDFD: 0xE272,
	0xFDFE: 0xE273,
	0xFE40: 0xE274,
	0xFE41: 0xE275,
	0xFE42: 0xE276,
	0xFE43: 0xE277,
	0xFE44: 0xE278,
	0xFE45: 0xE279,
	0xFE46: 0xE27A,
	0xFE47: 0xE27B,
	0xFE48: 0xE27C,
	0xFE49: 0xE27D,
	0xFE4A: 0xE27E,
	0xFE4B: 0xE27F,
	0xFE4C: 0xE280,
	0xFE4D: 0xE281,
	0xFE4E: 0xE282,
	0xFE4F: 0xE283,
	0xFE50: 0xE284,
	0xFE51: 0xE285,
	0xFE52: 0xE286,
	0xFE53: 0xE287,
	0xFE54: 0xE288,
	0xFE55: 0xE289,
	0xFE56: 0xE28A,
	0xFE57: 0xE28B,
	0xFE58: 0xE28C,
	0xFE59: 0xE28D,
	0xFE5A: 0xE28E,
	0xFE5B: 0xE28F,
	0xFE5C: 0xE290,
	0xFE5D: 0xE291,
	0xFE5E: 0xE292,
	0xFE5F: 0xE293,
	0xFE60: 0xE294,
	0xFE61: 0xE295,
	0xFE62: 0xE296,
	0xFE63: 0xE297,
	0xFE64: 0xE298,
	0xFE65: 0xE299,
	0xFE66: 0xE29A,
	0xFE67: 0xE29B,
	0xFE68: 0xE29C,
	0xFE69: 0xE29D,
	0xFE6A: 0xE29E,
	0xFE6B: 0xE29F,
	0xFE6C: 0xE2A0,
	0xFE6D: 0xE2A1,
	0xFE6E: 0xE2A2,
	0xFE6F: 0xE2A3,
	0xFE70: 0xE2A4,
	0xFE71: 0xE2A5,
	0xFE72: 0xE2A6,
	0xFE73: 0xE2A7,
	0xFE74: 0xE2A8,
	0xFE75: 0xE2A9,
	0xFE76: 0xE2AA,
	0xFE77: 0xE2AB,
	0xFE78: 0xE2AC,
	0xFE79: 0xE2AD,
	0xFE7A: 0xE2AE,
	0xFE7B: 0xE2AF,
	0xFE7C: 0xE2B0,
	0xFE7D: 0xE2B1,
	0xFE7E: 0xE2B2,
	0xFEA1: 0xE2B3,
	0xFEA2: 0xE2B4,
	0xFEA3: 0xE2B5,
	0xFEA4: 0xE2B6,
	0xFEA5: 0xE2B7,
	0xFEA6: 0xE2B8,
	0xFEA7: 0xE2B9,
	0xFEA8: 0xE2BA,
	0xFEA9: 0xE2BB,
	0xFEAA: 0xE2BC,
	0xFEAB: 0xE2BD,
	0xFEAC: 0xE2BE,
	0xFEAD: 0xE2BF,
	0xFEAE: 0xE2C0,
	0xFEAF: 0xE2C1,
	0xFEB0: 0xE2C2,
	0xFEB1: 0xE2C3,
	0xFEB2: 0xE2C4,
	0xFEB3: 0xE2C5,
	0xFEB4: 0xE2C6,
	0xFEB5: 0xE2C7,
	0xFEB6: 0xE2C8,
	0xFEB7: 0xE2C9,
	0xFEB8: 0xE2CA,
	0xFEB9: 0xE2CB,
	0xFEBA: 0xE2CC,
	0xFEBB: 0xE2CD,
	0xFEBC: 0xE2CE,
	0xFEBD: 0xE2CF,
	0xFEBE: 0xE2D0,
	0xFEBF: 0xE2D1,
	0xFEC0: 0xE2D2,
	0xFEC1: 0xE2D3,
	0xFEC2: 0xE2D4,
	0xFEC3: 0xE2D5,
	0xFEC4: 0xE2D6,
	0xFEC5: 0xE2D7,
	0xFEC6: 0xE2D8,
	0xFEC7: 0xE2D9,
	0xFEC8: 0xE2DA,
	0xFEC9: 0xE2DB,
	0xFECA: 0xE2DC,
	0xFECB: 0xE2DD,
	0xFECC: 0xE2DE,
	0xFECD: 0xE2DF,
	0xFECE: 0xE2E0,
	0xFECF: 0xE2E1,
	0xFED0: 0xE2E2,
	0xFED1: 0xE2E3,
	0xFED2: 0xE2E4,
	0xFED3: 0xE2E5,
	0xFED4: 0xE2E6,
	0xFED5: 0xE2E7,
	0xFED6: 0xE2E8,
	0xFED7: 0xE2E9,
	0xFED8: 0xE2EA,
	0xFED9: 0xE2EB,
	0xFEDA: 0xE2EC,
	0xFEDB: 0xE2ED,
	0xFEDC: 0xE2EE,
	0xFEDD: 0xE2EF,
	0xFEDE: 0xE2F0,
	0xFEDF: 0xE2F1,
	0xFEE0: 0xE2F2,
	0xFEE1: 0xE2F3,
	0xFEE2: 0xE2F4,
	0xFEE3: 0xE2F5,
	0xFEE4: 0xE2F6,
	0xFEE5: 0xE2F7,
	0xFEE6: 0xE2F8,
	0xFEE7: 0xE2F9,
	0xFEE8: 0xE2FA,
	0xFEE9: 0xE2FB,
	0xFEEA: 0xE2FC,
	0xFEEB: 0xE2FD,
	0xFEEC: 0xE2FE,
	0xFEED: 0xE2FF,
	0xFEEE: 0xE300,
	0xFEEF: 0xE301,
	0xFEF0: 0xE302,
	0xFEF1: 0xE303,
	0xFEF2: 0xE304,
	0xFEF3: 0xE305,
	0xFEF4: 0xE306,
	0xFEF5: 0xE307,
	0xFEF6: 0xE308,
	0xFEF7: 0xE309,
	0xFEF8: 0xE30A,
	0xFEF9: 0xE30B,
	0xFEFA: 0xE30C,
	0xFEFB: 0xE30D,
	0xFEFC: 0xE30E,
	0xFEFD: 0xE30F,
	0xFEFE: 0xE310,
	0x8E40: 0xE311,
	0x8E41: 0xE312,
	0x8E42: 0xE313,
	0x8E43: 0xE314,
	0x8E44: 0xE315,
	0x8E45: 0xE316,
	0x8E46: 0xE317,
	0x8E47: 0xE318,
	0x8E48: 0xE319,
	0x8E49: 0xE31A,
	0x8E4A: 0xE31B,
	0x8E4B: 0xE31C,
	0x8E4C: 0xE31D,
	0x8E4D: 0xE31E,
	0x8E4E: 0xE31F,
	0x8E4F: 0xE320,
	0x8E50: 0xE321,
	0x8E51: 0xE322,
	0x8E52: 0xE323,
	0x8E53: 0xE324,
	0x8E54: 0xE325,
	0x8E55: 0xE326,
	0x8E56: 0xE327,
	0x8E57: 0xE328,
	0x8E58: 0xE329,
	0x8E59: 0xE32A,
	0x8E5A: 0xE32B,
	0x8E5B: 0xE32C,
	0x8E5C: 0xE32D,
	0x8E5D: 0xE32E,
	0x8E5E: 0xE32F,
	0x8E5F: 0xE330,
	0x8E60: 0xE331,
	0x8E61: 0xE332,
	0x8E62: 0xE333,
	0x8E63: 0xE334,
	0x8E64: 0xE335,
	0x8E65: 0xE336,
	0x8E66: 0xE337,
	0x8E67: 0xE338,
	0x8E68: 0xE339,
	0x8E69: 0xE33A,
	0x8E6A: 0xE33B,
	0x8E6B: 0xE33C,
	0x8E6C: 0xE33D,
	0x8E6D: 0xE33E,
	0x8E6E: 0xE33F,
	0x8E6F: 0xE340,
	0x8E70: 0xE341,
	0x8E71: 0xE342,
	0x8E72: 0xE343,
	0x8E73: 0xE344,
	0x8E74: 0xE345,
	0x8E75: 0xE346,
	0x8E76: 0xE347,
	0x8E77: 0xE348,
	0x8E78: 0xE349,
	0x8E79: 0xE34A,
	0x8E7A: 0xE34B,
	0x8E7B: 0xE34C,
	0x8E7C: 0xE34D,
	0x8E7D: 0xE34E,
	0x8E7E: 0xE34F,
	0x8EA1: 0xE350,
	0x8EA2: 0xE351,
	0x8EA3: 0xE352,
	0x8EA4: 0xE353,
	0x8EA5: 0xE354,
	0x8EA6: 0xE355,
	0x8EA7: 0xE356,
	0x8EA8: 0xE357,
	0x8EA9: 0xE358,
	0x8EAA: 0xE359,
	0x8EAB: 0xE35A,
	0x8EAC: 0xE35B,
	0x8EAD: 0xE35C,
	0x8EAE: 0xE35D,
	0x8EAF: 0xE35E,
	0x8EB0: 0xE35F,
	0x8EB1: 0xE360,
	0x8EB2: 0xE361,
	0x8EB3: 0xE362,
	0x8EB4: 0xE363,
	0x8EB5: 0xE364,
	0x8EB6: 0xE365,
	0x8EB7: 0xE366,
	0x8EB8: 0xE367,
	0x8EB9: 0xE368,
	0x8EBA: 0xE369,
	0x8EBB: 0xE36A,
	0x8EBC: 0xE36B,
	0x8EBD: 0xE36C,
	0x8EBE: 0xE36D,
	0x8EBF: 0xE36E,
	0x8EC0: 0xE36F,
	0x8EC1: 0xE370,
	0x8EC2: 0xE371,
	0x8EC3: 0xE372,
	0x8EC4: 0xE373,
	0x8EC5: 0xE374,
	0x8EC6: 0xE375,
	0x8EC7: 0xE376,
	0x8EC8: 0xE377,
	0x8EC9: 0xE378,
	0x8ECA: 0xE379,
	0x8ECB: 0xE37A,
	0x8ECC: 0xE37B,
	0x8ECD: 0xE37C,
	0x8ECE: 0xE37D,
	0x8ECF: 0xE37E,
	0x8ED0: 0xE37F,
	0x8ED1: 0xE380,
	0x8ED2: 0xE381,
	0x8ED3: 0xE382,
	0x8ED4: 0xE383,
	0x8ED5: 0xE384,
	0x8ED6: 0xE385,
	0x8ED7: 0xE386,
	0x8ED8: 0xE387,
	0x8ED9: 0xE388,
	0x8EDA: 0xE389,
	0x8EDB: 0xE38A,
	0x8EDC: 0xE38B,
	0x8EDD: 0xE38C,
	0x8EDE: 0xE38D,
	0x8EDF: 0xE38E,
	0x8EE0: 0xE38F,
	0x8EE1: 0xE390,
	0x8EE2: 0xE391,
	0x8EE3: 0xE392,
	0x8EE4: 0xE393,
	0x8EE5: 0xE394,
	0x8EE6: 0xE395,
	0x8EE7: 0xE396,
	0x8EE8: 0xE397,
	0x8EE9: 0xE398,
	0x8EEA: 0xE399,
	0x8EEB: 0xE39A,
	0x8EEC: 0xE39B,
	0x8EED: 0xE39C,
	0x8EEE: 0xE39D,
	0x8EEF: 0xE39E,
	0x8EF0: 0xE39F,
	0x8EF1: 0xE3A0,
	0x8EF2: 0xE3A1,
	0x8EF3: 0xE3A2,
	0x8EF4: 0xE3A3,
	0x8EF5: 0xE3A4,
	0x8EF6: 0xE3A5,
	0x8EF7: 0xE3A6,
	0x8EF8: 0xE3A7,
	0x8EF9: 0xE3A8,
	0x8EFA: 0xE3A9,
	0x8EFB: 0xE3AA,
	0x8EFC: 0xE3AB,
	0x8EFD: 0xE3AC,
	0x8EFE: 0xE3AD,
	0x8F40: 0xE3AE,
	0x8F41: 0xE3AF,
	0x8F42: 0xE3B0,
	0x8F43: 0xE3B1,
	0x8F44: 0xE3B2,
	0x8F45: 0xE3B3,
	0x8F46: 0xE3B4,
	0x8F47: 0xE3B5,
	0x8F48: 0xE3B6,
	0x8F49: 0xE3B7,
	0x8F4A: 0xE3B8,
	0x8F4B: 0xE3B9,
	0x8F4C: 0xE3BA,
	0x8F4D: 0xE3BB,
	0x8F4E: 0xE3BC,
	0x8F4F: 0xE3BD,
	0x8F50: 0xE3BE,
	0x8F51: 0xE3BF,
	0x8F52: 0xE3C0,
	0x8F53: 0xE3C1,
	0x8F54: 0xE3C2,
	0x8F55: 0xE3C3,
	0x8F56: 0xE3C4,
	0x8F57: 0xE3C5,
	0x8F58: 0xE3C6,
	0x8F59: 0xE3C7,
	0x8F5A: 0xE3C8,
	0x8F5B: 0xE3C9,
	0x8F5C: 0xE3CA,
	0x8F5D: 0xE3CB,
	0x8F5E: 0xE3CC,
	0x8F5F: 0xE3CD,
	0x8F60: 0xE3CE,
	0x8F61: 0xE3CF,
	0x8F62: 0xE3D0,
	0x8F63: 0xE3D1,
	0x8F64: 0xE3D2,
	0x8F65: 0xE3D3,
	0x8F66: 0xE3D4,
	0x8F67: 0xE3D5,
	0x8F68: 0xE3D6,
	0x8F69: 0xE3D7,
	0x8F6A: 0xE3D8,
	0x8F6B: 0xE3D9,
	0x8F6C: 0xE3DA,
	0x8F6D: 0xE3DB,
	0x8F6E: 0xE3DC,
	0x8F6F: 0xE3DD,
	0x8F70: 0xE3DE,
	0x8F71: 0xE3DF,
	0x8F72: 0xE3E0,
	0x8F73: 0xE3E1,
	0x8F74: 0xE3E2,
	0x8F75: 0xE3E3,
	0x8F76: 0xE3E4,
	0x8F77: 0xE3E5,
	0x8F78: 0xE3E6,
	0x8F79: 0xE3E7,
	0x8F7A: 0xE3E8,
	0x8F7B: 0xE3E9,
	0x8F7C: 0xE3EA,
	0x8F7D: 0xE3EB,
	0x8F7E: 0xE3EC,
	0x8FA1: 0xE3ED,
	0x8FA2: 0xE3EE,
	0x8FA3: 0xE3EF,
	0x8FA4: 0xE3F0,
	0x8FA5: 0xE3F1,
	0x8FA6: 0xE3F2,
	0x8FA7: 0xE3F3,
	0x8FA8: 0xE3F4,
	0x8FA9: 0xE3F5,
	0x8FAA: 0xE3F6,
	0x8FAB: 0xE3F7,
	0x8FAC: 0xE3F8,
	0x8FAD: 0xE3F9,
	0x8FAE: 0xE3FA,
	0x8FAF: 0xE3FB,
	0x8FB0: 0xE3FC,
	0x8FB1: 0xE3FD,
	0x8FB2: 0xE3FE,
	0x8FB3: 0xE3FF,
	0x8FB4: 0xE400,
	0x8FB5: 0xE401,
	0x8FB6: 0xE402,
	0x8FB7: 0xE403,
	0x8FB8: 0xE404,
	0x8FB9: 0xE405,
	0x8FBA: 0xE406,
	0x8FBB: 0xE407,
	0x8FBC: 0xE408,
	0x8FBD: 0xE409,
	0x8FBE: 0xE40A,
	0x8FBF: 0xE40B,
	0x8FC0: 0xE40C,
	0x8FC1: 0xE40D,
	0x8FC2: 0xE40E,
	0x8FC3: 0xE40F,
	0x8FC4: 0xE410,
	0x8FC5: 0xE411,
	0x8FC6: 0xE412,
	0x8FC7: 0xE413,
	0x8FC8: 0xE414,
	0x8FC9: 0xE415,
	0x8FCA: 0xE416,
	0x8FCB: 0xE417,
	0x8FCC: 0xE418,
	0x8FCD: 0xE419,
	0x8FCE: 0xE41A,
	0x8FCF: 0xE41B,
	0x8FD0: 0xE41C,
	0x8FD1: 0xE41D,
	0x8FD2: 0xE41E,
	0x8FD3: 0xE41F,
	0x8FD4: 0xE420,
	0x8FD5: 0xE421,
	0x8FD6: 0xE422,
	0x8FD7: 0xE423,
	0x8FD8: 0xE424,
	0x8FD9: 0xE425,
	0x8FDA: 0xE426,
	0x8FDB: 0xE427,
	0x8FDC: 0xE428,
	0x8FDD: 0xE429,
	0x8FDE: 0xE42A,
	0x8FDF: 0xE42B,
	0x8FE0: 0xE42C,
	0x8FE1: 0xE42D,
	0x8FE2: 0xE42E,
	0x8FE3: 0xE42F,
	0x8FE4: 0xE430,
	0x8FE5: 0xE431,
	0x8FE6: 0xE432,
	0x8FE7: 0xE433,
	0x8FE8: 0xE434,
	0x8FE9: 0xE435,
	0x8FEA: 0xE436,
	0x8FEB: 0xE437,
	0x8FEC: 0xE438,
	0x8FED: 0xE439,
	0x8FEE: 0xE43A,
	0x8FEF: 0xE43B,
	0x8FF0: 0xE43C,
	0x8FF1: 0xE43D,
	0x8FF2: 0xE43E,
	0x8FF3: 0xE43F,
	0x8FF4: 0xE440,
	0x8FF5: 0xE441,
	0x8FF6: 0xE442,
	0x8FF7: 0xE443,
	0x8FF8: 0xE444,
	0x8FF9: 0xE445,
	0x8FFA: 0xE446,
	0x8FFB: 0xE447,
	0x8FFC: 0xE448,
	0x8FFD: 0xE449,
	0x8FFE: 0xE44A,
	0x9040: 0xE44B,
	0x9041: 0xE44C,
	0x9042: 0xE44D,
	0x9043: 0xE44E,
	0x9044: 0xE44F,
	0x9045: 0xE450,
	0x9046: 0xE451,
	0x9047: 0xE452,
	0x9048: 0xE453,
	0x9049: 0xE454,
	0x904A: 0xE455,
	0x904B: 0xE456,
	0x904C: 0xE457,
	0x904D: 0xE458,
	0x904E: 0xE459,
	0x904F: 0xE45A,
	0x9050: 0xE45B,
	0x9051: 0xE45C,
	0x9052: 0xE45D,
	0x9053: 0xE45E,
	0x9054: 0xE45F,
	0x9055: 0xE460,
	0x9056: 0xE461,
	0x9057: 0xE462,
	0x9058: 0xE463,
	0x9059: 0xE464,
	0x905A: 0xE465,
	0x905B: 0xE466,
	0x905C: 0xE467,
	0x905D: 0xE468,
	0x905E: 0xE469,
	0x905F: 0xE46A,
	0x9060: 0xE46B,
	0x9061: 0xE46C,
	0x9062: 0xE46D,
	0x9063: 0xE46E,
	0x9064: 0xE46F,
	0x9065: 0xE470,
	0x9066: 0xE471,
	0x9067: 0xE472,
	0x9068: 0xE473,
	0x9069: 0xE474,
	0x906A: 0xE475,
	0x906B: 0xE476,
	0x906C: 0xE477,
	0x906D: 0xE478,
	0x906E: 0xE479,
	0x906F: 0xE47A,
	0x9070: 0xE47B,
	0x9071: 0xE47C,
	0x9072: 0xE47D,
	0x9073: 0xE47E,
	0x9074: 0xE47F,
	0x9075: 0xE480,
	0x9076: 0xE481,
	0x9077: 0xE482,
	0x9078: 0xE483,
	0x9079: 0xE484,
	0x907A: 0xE485,
	0x907B: 0xE486,
	0x907C: 0xE487,
	0x907D: 0xE488,
	0x907E: 0xE489,
	0x90A1: 0xE48A,
	0x90A2: 0xE48B,
	0x90A3: 0xE48C,
	0x90A4: 0xE48D,
	0x90A5: 0xE48E,
	0x90A6: 0xE48F,
	0x90A7: 0xE490,
	0x90A8: 0xE491,
	0x90A9: 0xE492,
	0x90AA: 0xE493,
	0x90AB: 0xE494,
	0x90AC: 0xE495,
	0x90AD: 0xE496,
	0x90AE: 0xE497,
	0x90AF: 0xE498,
	0x90B0: 0xE499,
	0x90B1: 0xE49A,
	0x90B2: 0xE49B,
	0x90B3: 0xE49C,
	0x90B4: 0xE49D,
	0x90B5: 0xE49E,
	0x90B6: 0xE49F,
	0x90B7: 0xE4A0,
	0x90B8: 0xE4A1,
	0x90B9: 0xE4A2,
	0x90BA: 0xE4A3,
	0x90BB: 0xE4A4,
	0x90BC: 0xE4A5,
	0x90BD: 0xE4A6,
	0x90BE: 0xE4A7,
	0x90BF: 0xE4A8,
	0x90C0: 0xE4A9,
	0x90C1: 0xE4AA,
	0x90C2: 0xE4AB,
	0x90C3: 0xE4AC,
	0x90C4: 0xE4AD,
	0x90C5: 0xE4AE,
	0x90C6: 0xE4AF,
	0x90C7: 0xE4B0,
	0x90C8: 0xE4B1,
	0x90C9: 0xE4B2,
	0x90CA: 0xE4B3,
	0x90CB: 0xE4B4,
	0x90CC: 0xE4B5,
	0x90CD: 0xE4B6,
	0x90CE: 0xE4B7,
	0x90CF: 0xE4B8,
	0x90D0: 0xE4B9,
	0x90D1: 0xE4BA,
	0x90D2: 0xE4BB,
	0x90D3: 0xE4BC,
	0x90D4: 0xE4BD,
	0x90D5: 0xE4BE,
	0x90D6: 0xE4BF,
	0x90D7: 0xE4C0,
	0x90D8: 0xE4C1,
	0x90D9: 0xE4C2,
	0x90DA: 0xE4C3,
	0x90DB: 0xE4C4,
	0x90DC: 0xE4C5,
	0x90DD: 0xE4C6,
	0x90DE: 0xE4C7,
	0x90DF: 0xE4C8,
	0x90E0: 0xE4C9,
	0x90E1: 0xE4CA,
	0x90E2: 0xE4CB,
	0x90E3: 0xE4CC,
	0x90E4: 0xE4CD,
	0x90E5: 0xE4CE,
	0x90E6: 0xE4CF,
	0x90E7: 0xE4D0,
	0x90E8: 0xE4D1,
	0x90E9: 0xE4D2,
	0x90EA: 0xE4D3,
	0x90EB: 0xE4D4,
	0x90EC: 0xE4D5,
	0x90ED: 0xE4D6,
	0x90EE: 0xE4D7,
	0x90EF: 0xE4D8,
	0x90F0: 0xE4D9,
	0x90F1: 0xE4DA,
	0x90F2: 0xE4DB,
	0x90F3: 0xE4DC,
	0x90F4: 0xE4DD,
	0x90F5: 0xE4DE,
	0x90F6: 0xE4DF,
	0x90F7: 0xE4E0,
	0x90F8: 0xE4E1,
	0x90F9: 0xE4E2,
	0x90FA: 0xE4E3,
	0x90FB: 0xE4E4,
	0x90FC: 0xE4E5,
	0x90FD: 0xE4E6,
	0x90FE: 0xE4E7,
	0x9140: 0xE4E8,
	0x9141: 0xE4E9,
	0x9142: 0xE4EA,
	0x9143: 0xE4EB,
	0x9144: 0xE4EC,
	0x9145: 0xE4ED,
	0x9146: 0xE4EE,
	0x9147: 0xE4EF,
	0x9148: 0xE4F0,
	0x9149: 0xE4F1,
	0x914A: 0xE4F2,
	0x914B: 0xE4F3,
	0x914C: 0xE4F4,
	0x914D: 0xE4F5,
	0x914E: 0xE4F6,
	0x914F: 0xE4F7,
	0x9150: 0xE4F8,
	0x9151: 0xE4F9,
	0x9152: 0xE4FA,
	0x9153: 0xE4FB,
	0x9154: 0xE4FC,
	0x9155: 0xE4FD,
	0x9156: 0xE4FE,
	0x9157: 0xE4FF,
	0x9158: 0xE500,
	0x9159: 0xE501,
	0x915A: 0xE502,
	0x915B: 0xE503,
	0x915C: 0xE504,
	0x915D: 0xE505,
	0x915E: 0xE506,
	0x915F: 0xE507,
	0x9160: 0xE508,
	0x9161: 0xE509,
	0x9162: 0xE50A,
	0x9163: 0xE50B,
	0x9164: 0xE50C,
	0x9165: 0xE50D,
	0x9166: 0xE50E,
	0x9167: 0xE50F,
	0x9168: 0xE510,
	0x9169: 0xE511,
	0x916A: 0xE512,
	0x916B: 0xE513,
	0x916C: 0xE514,
	0x916D: 0xE515,
	0x916E: 0xE516,
	0x916F: 0xE517,
	0x9170: 0xE518,
	0x9171: 0xE519,
	0x9172: 0xE51A,
	0x9173: 0xE51B,
	0x9174: 0xE51C,
	0x9175: 0xE51D,
	0x9176: 0xE51E,
	0x9177: 0xE51F,
	0x9178: 0xE520,
	0x9179: 0xE521,
	0x917A: 0xE522,
	0x917B: 0xE523,
	0x917C: 0xE524,
	0x917D: 0xE525,
	0x917E: 0xE526,
	0x91A1: 0xE527,
	0x91A2: 0xE528,
	0x91A3: 0xE529,
	0x91A4: 0xE52A,
	0x91A5: 0xE52B,
	0x91A6: 0xE52C,
	0x91A7: 0xE52D,
	0x91A8: 0xE52E,
	0x91A9: 0xE52F,
	0x91AA: 0xE530,
	0x91AB: 0xE531,
	0x91AC: 0xE532,
	0x91AD: 0xE533,
	0x91AE: 0xE534,
	0x91AF: 0xE535,
	0x91B0: 0xE536,
	0x91B1: 0xE537,
	0x91B2: 0xE538,
	0x91B3: 0xE539,
	0x91B4: 0xE53A,
	0x91B5: 0xE53B,
	0x91B6: 0xE53C,
	0x91B7: 0xE53D,
	0x91B8: 0xE53E,
	0x91B9: 0xE53F,
	0x91BA: 0xE540,
	0x91BB: 0xE541,
	0x91BC: 0xE542,
	0x91BD: 0xE543,
	0x91BE: 0xE544,
	0x91BF: 0xE545,
	0x91C0: 0xE546,
	0x91C1: 0xE547,
	0x91C2: 0xE548,
	0x91C3: 0xE549,
	0x91C4: 0xE54A,
	0x91C5: 0xE54B,
	0x91C6: 0xE54C,
	0x91C7: 0xE54D,
	0x91C8: 0xE54E,
	0x91C9: 0xE54F,
	0x91CA: 0xE550,
	0x91CB: 0xE551,
	0x91CC: 0xE552,
	0x91CD: 0xE553,
	0x91CE: 0xE554,
	0x91CF: 0xE555,
	0x91D0: 0xE556,
	0x91D1: 0xE557,
	0x91D2: 0xE558,
	0x91D3: 0xE559,
	0x91D4: 0xE55A,
	0x91D5: 0xE55B,
	0x91D6: 0xE55C,
	0x91D7: 0xE55D,
	0x91D8: 0xE55E,
	0x91D9: 0xE55F,
	0x91DA: 0xE560,
	0x91DB: 0xE561,
	0x91DC: 0xE562,
	0x91DD: 0xE563,
	0x91DE: 0xE564,
	0x91DF: 0xE565,
	0x91E0: 0xE566,
	0x91E1: 0xE567,
	0x91E2: 0xE568,
	0x91E3: 0xE569,
	0x91E4: 0xE56A,
	0x91E5: 0xE56B,
	0x91E6: 0xE56C,
	0x91E7: 0xE56D,
	0x91E8: 0xE56E,
	0x91E9: 0xE56F,
	0x91EA: 0xE570,
	0x91EB: 0xE571,
	0x91EC: 0xE572,
	0x91ED: 0xE573,
	0x91EE: 0xE574,
	0x91EF: 0xE575,
	0x91F0: 0xE576,
	0x91F1: 0xE577,
	0x91F2: 0xE578,
	0x91F3: 0xE579,
	0x91F4: 0xE57A,
	0x91F5: 0xE57B,
	0x91F6: 0xE57C,
	0x91F7: 0xE57D,
	0x91F8: 0xE57E,
	0x91F9: 0xE57F,
	0x91FA: 0xE580,
	0x91FB: 0xE581,
	0x91FC: 0xE582,
	0x91FD: 0xE583,
	0x91FE: 0xE584,
	0x9240: 0xE585,
	0x9241: 0xE586,
	0x9242: 0xE587,
	0x9243: 0xE588,
	0x9244: 0xE589,
	0x9245: 0xE58A,
	0x9246: 0xE58B,
	0x9247: 0xE58C,
	0x9248: 0xE58D,
	0x9249: 0xE58E,
	0x924A: 0xE58F,
	0x924B: 0xE590,
	0x924C: 0xE591,
	0x924D: 0xE592,
	0x924E: 0xE593,
	0x924F: 0xE594,
	0x9250: 0xE595,
	0x9251: 0xE596,
	0x9252: 0xE597,
	0x9253: 0xE598,
	0x9254: 0xE599,
	0x9255: 0xE59A,
	0x9256: 0xE59B,
	0x9257: 0xE59C,
	0x9258: 0xE59D,
	0x9259: 0xE59E,
	0x925A: 0xE59F,
	0x925B: 0xE5A0,
	0x925C: 0xE5A1,
	0x925D: 0xE5A2,
	0x925E: 0xE5A3,
	0x925F: 0xE5A4,
	0x9260: 0xE5A5,
	0x9261: 0xE5A6,
	0x9262: 0xE5A7,
	0x9263: 0xE5A8,
	0x9264: 0xE5A9,
	0x9265: 0xE5AA,
	0x9266: 0xE5AB,
	0x9267: 0xE5AC,
	0x9268: 0xE5AD,
	0x9269: 0xE5AE,
	0x926A: 0xE5AF,
	0x926B: 0xE5B0,
	0x926C: 0xE5B1,
	0x926D: 0xE5B2,
	0x926E: 0xE5B3,
	0x926F: 0xE5B4,
	0x9270: 0xE5B5,
	0x9271: 0xE5B6,
	0x9272: 0xE5B7,
	0x9273: 0xE5B8,
	0x9274: 0xE5B9,
	0x9275: 0xE5BA,
	0x9276: 0xE5BB,
	0x9277: 0xE5BC,
	0x9278: 0xE5BD,
	0x9279: 0xE5BE,
	0x927A: 0xE5BF,
	0x927B: 0xE5C0,
	0x927C: 0xE5C1,
	0x927D: 0xE5C2,
	0x927E: 0xE5C3,
	0x92A1: 0xE5C4,
	0x92A2: 0xE5C5,
	0x92A3: 0xE5C6,
	0x92A4: 0xE5C7,
	0x92A5: 0xE5C8,
	0x92A6: 0xE5C9,
	0x92A7: 0xE5CA,
	0x92A8: 0xE5CB,
	0x92A9: 0xE5CC,
	0x92AA: 0xE5CD,
	0x92AB: 0xE5CE,
	0x92AC: 0xE5CF,
	0x92AD: 0xE5D0,
	0x92AE: 0xE5D1,
	0x92AF: 0xE5D2,
	0x92B0: 0xE5D3,
	0x92B1: 0xE5D4,
	0x92B2: 0xE5D5,
	0x92B3: 0xE5D6,
	0x92B4: 0xE5D7,
	0x92B5: 0xE5D8,
	0x92B6: 0xE5D9,
	0x92B7: 0xE5DA,
	0x92B8: 0xE5DB,
	0x92B9: 0xE5DC,
	0x92BA: 0xE5DD,
	0x92BB: 0xE5DE,
	0x92BC: 0xE5DF,
	0x92BD: 0xE5E0,
	0x92BE: 0xE5E1,
	0x92BF: 0xE5E2,
	0x92C0: 0xE5E3,
	0x92C1: 0xE5E4,
	0x92C2: 0xE5E5,
	0x92C3: 0xE5E6,
	0x92C4: 0xE5E7,
	0x92C5: 0xE5E8,
	0x92C6: 0xE5E9,
	0x92C7: 0xE5EA,
	0x92C8: 0xE5EB,
	0x92C9: 0xE5EC,
	0x92CA: 0xE5ED,
	0x92CB: 0xE5EE,
	0x92CC: 0xE5EF,
	0x92CD: 0xE5F0,
	0x92CE: 0xE5F1,
	0x92CF: 0xE5F2,
	0x92D0: 0xE5F3,
	0x92D1: 0xE5F4,
	0x92D2: 0xE5F5,
	0x92D3: 0xE5F6,
	0x92D4: 0xE5F7,
	0x92D5: 0xE5F8,
	0x92D6: 0xE5F9,
	0x92D7: 0xE5FA,
	0x92D8: 0xE5FB,
	0x92D9: 0xE5FC,
	0x92DA: 0xE5FD,
	0x92DB: 0xE5FE,
	0x92DC: 0xE5FF,
	0x92DD: 0xE600,
	0x92DE: 0xE601,
	0x92DF: 0xE602,
	0x92E0: 0xE603,
	0x92E1: 0xE604,
	0x92E2: 0xE605,
	0x92E3: 0xE606,
	0x92E4: 0xE607,
	0x92E5: 0xE608,
	0x92E6: 0xE609,
	0x92E7: 0xE60A,
	0x92E8: 0xE60B,
	0x92E9: 0xE60C,
	0x92EA: 0xE60D,
	0x92EB: 0xE60E,
	0x92EC: 0xE60F,
	0x92ED: 0xE610,
	0x92EE: 0xE611,
	0x92EF: 0xE612,
	0x92F0: 0xE613,
	0x92F1: 0xE614,
	0x92F2: 0xE615,
	0x92F3: 0xE616,
	0x92F4: 0xE617,
	0x92F5: 0xE618,
	0x92F6: 0xE619,
	0x92F7: 0xE61A,
	0x92F8: 0xE61B,
	0x92F9: 0xE61C,
	0x92FA: 0xE61D,
	0x92FB: 0xE61E,
	0x92FC: 0xE61F,
	0x92FD: 0xE620,
	0x92FE: 0xE621,
	0x9340: 0xE622,
	0x9341: 0xE623,
	0x9342: 0xE624,
	0x9343: 0xE625,
	0x9344: 0xE626,
	0x9345: 0xE627,
	0x9346: 0xE628,
	0x9347: 0xE629,
	0x9348: 0xE62A,
	0x9349: 0xE62B,
	0x934A: 0xE62C,
	0x934B: 0xE62D,
	0x934C: 0xE62E,
	0x934D: 0xE62F,
	0x934E: 0xE630,
	0x934F: 0xE631,
	0x9350: 0xE632,
	0x9351: 0xE633,
	0x9352: 0xE634,
	0x9353: 0xE635,
	0x9354: 0xE636,
	0x9355: 0xE637,
	0x9356: 0xE638,
	0x9357: 0xE639,
	0x9358: 0xE63A,
	0x9359: 0xE63B,
	0x935A: 0xE63C,
	0x935B: 0xE63D,
	0x935C: 0xE63E,
	0x935D: 0xE63F,
	0x935E: 0xE640,
	0x935F: 0xE641,
	0x9360: 0xE642,
	0x9361: 0xE643,
	0x9362: 0xE644,
	0x9363: 0xE645,
	0x9364: 0xE646,
	0x9365: 0xE647,
	0x9366: 0xE648,
	0x9367: 0xE649,
	0x9368: 0xE64A,
	0x9369: 0xE64B,
	0x936A: 0xE64C,
	0x936B: 0xE64D,
	0x936C: 0xE64E,
	0x936D: 0xE64F,
	0x936E: 0xE650,
	0x936F: 0xE651,
	0x9370: 0xE652,
	0x9371: 0xE653,
	0x9372: 0xE654,
	0x9373: 0xE655,
	0x9374: 0xE656,
	0x9375: 0xE657,
	0x9376: 0xE658,
	0x9377: 0xE659,
	0x9378: 0xE65A,
	0x9379: 0xE65B,
	0x937A: 0xE65C,
	0x937B: 0xE65D,
	0x937C: 0xE65E,
	0x937D: 0xE65F,
	0x937E: 0xE660,
	0x93A1: 0xE661,
	0x93A2: 0xE662,
	0x93A3: 0xE663,
	0x93A4: 0xE664,
	0x93A5: 0xE665,
	0x93A6: 0xE666,
	0x93A7: 0xE667,
	0x93A8: 0xE668,
	0x93A9: 0xE669,
	0x93AA: 0xE66A,
	0x93AB: 0xE66B,
	0x93AC: 0xE66C,
	0x93AD: 0xE66D,
	0x93AE: 0xE66E,
	0x93AF: 0xE66F,
	0x93B0: 0xE670,
	0x93B1: 0xE671,
	0x93B2: 0xE672,
	0x93B3: 0xE673,
	0x93B4: 0xE674,
	0x93B5: 0xE675,
	0x93B6: 0xE676,
	0x93B7: 0xE677,
	0x93B8: 0xE678,
	0x93B9: 0xE679,
	0x93BA: 0xE67A,
	0x93BB: 0xE67B,
	0x93BC: 0xE67C,
	0x93BD: 0xE67D,
	0x93BE: 0xE67E,
	0x93BF: 0xE67F,
	0x93C0: 0xE680,
	0x93C1: 0xE681,
	0x93C2: 0xE682,
	0x93C3: 0xE683,
	0x93C4: 0xE684,
	0x93C5: 0xE685,
	0x93C6: 0xE686,
	0x93C7: 0xE687,
	0x93C8: 0xE688,
	0x93C9: 0xE689,
	0x93CA: 0xE68A,
	0x93CB: 0xE68B,
	0x93CC: 0xE68C,
	0x93CD: 0xE68D,
	0x93CE: 0xE68E,
	0x93CF: 0xE68F,
	0x93D0: 0xE690,
	0x93D1: 0xE691,
	0x93D2: 0xE692,
	0x93D3: 0xE693,
	0x93D4: 0xE694,
	0x93D5: 0xE695,
	0x93D6: 0xE696,
	0x93D7: 0xE697,
	0x93D8: 0xE698,
	0x93D9: 0xE699,
	0x93DA: 0xE69A,
	0x93DB: 0xE69B,
	0x93DC: 0xE69C,
	0x93DD: 0xE69D,
	0x93DE: 0xE69E,
	0x93DF: 0xE69F,
	0x93E0: 0xE6A0,
	0x93E1: 0xE6A1,
	0x93E2: 0xE6A2,
	0x93E3: 0xE6A3,
	0x93E4: 0xE6A4,
	0x93E5: 0xE6A5,
	0x93E6: 0xE6A6,
	0x93E7: 0xE6A7,
	0x93E8: 0xE6A8,
	0x93E9: 0xE6A9,
	0x93EA: 0xE6AA,
	0x93EB: 0xE6AB,
	0x93EC: 0xE6AC,
	0x93ED: 0xE6AD,
	0x93EE: 0xE6AE,
	0x93EF: 0xE6AF,
	0x93F0: 0xE6B0,
	0x93F1: 0xE6B1,
	0x93F2: 0xE6B2,
	0x93F3: 0xE6B3,
	0x93F4: 0xE6B4,
	0x93F5: 0xE6B5,
	0x93F6: 0xE6B6,
	0x93F7: 0xE6B7,
	0x93F8: 0xE6B8,
	0x93F9: 0xE6B9,
	0x93FA: 0xE6BA,
	0x93FB: 0xE6BB,
	0x93FC: 0xE6BC,
	0x93FD: 0xE6BD,
	0x93FE: 0xE6BE,
	0x9440: 0xE6BF,
	0x9441: 0xE6C0,
	0x9442: 0xE6C1,
	0x9443: 0xE6C2,
	0x9444: 0xE6C3,
	0x9445: 0xE6C4,
	0x9446: 0xE6C5,
	0x9447: 0xE6C6,
	0x9448: 0xE6C7,
	0x9449: 0xE6C8,
	0x944A: 0xE6C9,
	0x944B: 0xE6CA,
	0x944C: 0xE6CB,
	0x944D: 0xE6CC,
	0x944E: 0xE6CD,
	0x944F: 0xE6CE,
	0x9450: 0xE6CF,
	0x9451: 0xE6D0,
	0x9452: 0xE6D1,
	0x9453: 0xE6D2,
	0x9454: 0xE6D3,
	0x9455: 0xE6D4,
	0x9456: 0xE6D5,
	0x9457: 0xE6D6,
	0x9458: 0xE6D7,
	0x9459: 0xE6D8,
	0x945A: 0xE6D9,
	0x945B: 0xE6DA,
	0x945C: 0xE6DB,
	0x945D: 0xE6DC,
	0x945E: 0xE6DD,
	0x945F: 0xE6DE,
	0x9460: 0xE6DF,
	0x9461: 0xE6E0,
	0x9462: 0xE6E1,
	0x9463: 0xE6E2,
	0x9464: 0xE6E3,
	0x9465: 0xE6E4,
	0x9466: 0xE6E5,
	0x9467: 0xE6E6,
	0x9468: 0xE6E7,
	0x9469: 0xE6E8,
	0x946A: 0xE6E9,
	0x946B: 0xE6EA,
	0x946C: 0xE6EB,
	0x946D: 0xE6EC,
	0x946E: 0xE6ED,
	0x946F: 0xE6EE,
	0x9470: 0xE6EF,
	0x9471: 0xE6F0,
	0x9472: 0xE6F1,
	0x9473: 0xE6F2,
	0x9474: 0xE6F3,
	0x9475: 0xE6F4,
	0x9476: 0xE6F5,
	0x9477: 0xE6F6,
	0x9478: 0xE6F7,
	0x9479: 0xE6F8,
	0x947A: 0xE6F9,
	0x947B: 0xE6FA,
	0x947C: 0xE6FB,
	0x947D: 0xE6FC,
	0x947E: 0xE6FD,
	0x94A1: 0xE6FE,
	0x94A2: 0xE6FF,
	0x94A3: 0xE700,
	0x94A4: 0xE701,
	0x94A5: 0xE702,
	0x94A6: 0xE703,
	0x94A7: 0xE704,
	0x94A8: 0xE705,
	0x94A9: 0xE706,
	0x94AA: 0xE707,
	0x94AB: 0xE708,
	0x94AC: 0xE709,
	0x94AD: 0xE70A,
	0x94AE: 0xE70B,
	0x94AF: 0xE70C,
	0x94B0: 0xE70D,
	0x94B1: 0xE70E,
	0x94B2: 0xE70F,
	0x94B3: 0xE710,
	0x94B4: 0xE711,
	0x94B5: 0xE712,
	0x94B6: 0xE713,
	0x94B7: 0xE714,
	0x94B8: 0xE715,
	0x94B9: 0xE716,
	0x94BA: 0xE717,
	0x94BB: 0xE718,
	0x94BC: 0xE719,
	0x94BD: 0xE71A,
	0x94BE: 0xE71B,
	0x94BF: 0xE71C,
	0x94C0: 0xE71D,
	0x94C1: 0xE71E,
	0x94C2: 0xE71F,
	0x94C3: 0xE720,
	0x94C4: 0xE721,
	0x94C5: 0xE722,
	0x94C6: 0xE723,
	0x94C7: 0xE724,
	0x94C8: 0xE725,
	0x94C9: 0xE726,
	0x94CA: 0xE727,
	0x94CB: 0xE728,
	0x94CC: 0xE729,
	0x94CD: 0xE72A,
	0x94CE: 0xE72B,
	0x94CF: 0xE72C,
	0x94D0: 0xE72D,
	0x94D1: 0xE72E,
	0x94D2: 0xE72F,
	0x94D3: 0xE730,
	0x94D4: 0xE731,
	0x94D5: 0xE732,
	0x94D6: 0xE733,
	0x94D7: 0xE734,
	0x94D8: 0xE735,
	0x94D9: 0xE736,
	0x94DA: 0xE737,
	0x94DB: 0xE738,
	0x94DC: 0xE739,
	0x94DD: 0xE73A,
	0x94DE: 0xE73B,
	0x94DF: 0xE73C,
	0x94E0: 0xE73D,
	0x94E1: 0xE73E,
	0x94E2: 0xE73F,
	0x94E3: 0xE740,
	0x94E4: 0xE741,
	0x94E5: 0xE742,
	0x94E6: 0xE743,
	0x94E7: 0xE744,
	0x94E8: 0xE745,
	0x94E9: 0xE746,
	0x94EA: 0xE747,
	0x94EB: 0xE748,
	0x94EC: 0xE749,
	0x94ED: 0xE74A,
	0x94EE: 0xE74B,
	0x94EF: 0xE74C,
	0x94F0: 0xE74D,
	0x94F1: 0xE74E,
	0x94F2: 0xE74F,
	0x94F3: 0xE750,
	0x94F4: 0xE751,
	0x94F5: 0xE752,
	0x94F6: 0xE753,
	0x94F7: 0xE754,
	0x94F8: 0xE755,
	0x94F9: 0xE756,
	0x94FA: 0xE757,
	0x94FB: 0xE758,
	0x94FC: 0xE759,
	0x94FD: 0xE75A,
	0x94FE: 0xE75B,
	0x9540: 0xE75C,
	0x9541: 0xE75D,
	0x9542: 0xE75E,
	0x9543: 0xE75F,
	0x9544: 0xE760,
	0x9545: 0xE761,
	0x9546: 0xE762,
	0x9547: 0xE763,
	0x9548: 0xE764,
	0x9549: 0xE765,
	0x954A: 0xE766,
	0x954B: 0xE767,
	0x954C: 0xE768,
	0x954D: 0xE769,
	0x954E: 0xE76A,
	0x954F: 0xE76B,
	0x9550: 0xE76C,
	0x9551: 0xE76D,
	0x9552: 0xE76E,
	0x9553: 0xE76F,
	0x9554: 0xE770,
	0x9555: 0xE771,
	0x9556: 0xE772,
	0x9557: 0xE773,
	0x9558: 0xE774,
	0x9559: 0xE775,
	0x955A: 0xE776,
	0x955B: 0xE777,
	0x955C: 0xE778,
	0x955D: 0xE779,
	0x955E: 0xE77A,
	0x955F: 0xE77B,
	0x9560: 0xE77C,
	0x9561: 0xE77D,
	0x9562: 0xE77E,
	0x9563: 0xE77F,
	0x9564: 0xE780,
	0x9565: 0xE781,
	0x9566: 0xE782,
	0x9567: 0xE783,
	0x9568: 0xE784,
	0x9569: 0xE785,
	0x956A: 0xE786,
	0x956B: 0xE787,
	0x956C: 0xE788,
	0x956D: 0xE789,
	0x956E: 0xE78A,
	0x956F: 0xE78B,
	0x9570: 0xE78C,
	0x9571: 0xE78D,
	0x9572: 0xE78E,
	0x9573: 0xE78F,
	0x9574: 0xE790,
	0x9575: 0xE791,
	0x9576: 0xE792,
	0x9577: 0xE793,
	0x9578: 0xE794,
	0x9579: 0xE795,
	0x957A: 0xE796,
	0x957B: 0xE797,
	0x957C: 0xE798,
	0x957D: 0xE799,
	0x957E: 0xE79A,
	0x95A1: 0xE79B,
	0x95A2: 0xE79C,
	0x95A3: 0xE79D,
	0x95A4: 0xE79E,
	0x95A5: 0xE79F,
	0x95A6: 0xE7A0,
	0x95A7: 0xE7A1,
	0x95A8: 0xE7A2,
	0x95A9: 0xE7A3,
	0x95AA: 0xE7A4,
	0x95AB: 0xE7A5,
	0x95AC: 0xE7A6,
	0x95AD: 0xE7A7,
	0x95AE: 0xE7A8,
	0x95AF: 0xE7A9,
	0x95B0: 0xE7AA,
	0x95B1: 0xE7AB,
	0x95B2: 0xE7AC,
	0x95B3: 0xE7AD,
	0x95B4: 0xE7AE,
	0x95B5: 0xE7AF,
	0x95B6: 0xE7B0,
	0x95B7: 0xE7B1,
	0x95B8: 0xE7B2,
	0x95B9: 0xE7B3,
	0x95BA: 0xE7B4,
	0x95BB: 0xE7B5,
	0x95BC: 0xE7B6,
	0x95BD: 0xE7B7,
	0x95BE: 0xE7B8,
	0x95BF: 0xE7B9,
	0x95C0: 0xE7BA,
	0x95C1: 0xE7BB,
	0x95C2: 0xE7BC,
	0x95C3: 0xE7BD,
	0x95C4: 0xE7BE,
	0x95C5: 0xE7BF,
	0x95C6: 0xE7C0,
	0x95C7: 0xE7C1,
	0x95C8: 0xE7C2,
	0x95C9: 0xE7C3,
	0x95CA: 0xE7C4,
	0x95CB: 0xE7C5,
	0x95CC: 0xE7C6,
	0x95CD: 0xE7C7,
	0x95CE: 0xE7C8,
	0x95CF: 0xE7C9,
	0x95D0: 0xE7CA,
	0x95D1: 0xE7CB,
	0x95D2: 0xE7CC,
	0x95D3: 0xE7CD,
	0x95D4: 0xE7CE,
	0x95D5: 0xE7CF,
	0x95D6: 0xE7D0,
	0x95D7: 0xE7D1,
	0x95D8: 0xE7D2,
	0x95D9: 0xE7D3,
	0x95DA: 0xE7D4,
	0x95DB: 0xE7D5,
	0x95DC: 0xE7D6,
	0x95DD: 0xE7D7,
	0x95DE: 0xE7D8,
	0x95DF: 0xE7D9,
	0x95E0: 0xE7DA,
	0x95E1: 0xE7DB,
	0x95E2: 0xE7DC,
	0x95E3: 0xE7DD,
	0x95E4: 0xE7DE,
	0x95E5: 0xE7DF,
	0x95E6: 0xE7E0,
	0x95E7: 0xE7E1,
	0x95E8: 0xE7E2,
	0x95E9: 0xE7E3,
	0x95EA: 0xE7E4,
	0x95EB: 0xE7E5,
	0x95EC: 0xE7E6,
	0x95ED: 0xE7E7,
	0x95EE: 0xE7E8,
	0x95EF: 0xE7E9,
	0x95F0: 0xE7EA,
	0x95F1: 0xE7EB,
	0x95F2: 0xE7EC,
	0x95F3: 0xE7ED,
	0x95F4: 0xE7EE,
	0x95F5: 0xE7EF,
	0x95F6: 0xE7F0,
	0x95F7: 0xE7F1,
	0x95F8: 0xE7F2,
	0x95F9: 0xE7F3,
	0x95FA: 0xE7F4,
	0x95FB: 0xE7F5,
	0x95FC: 0xE7F6,
	0x95FD: 0xE7F7,
	0x95FE: 0xE7F8,
	0x9640: 0xE7F9,
	0x9641: 0xE7FA,
	0x9642: 0xE7FB,
	0x9643: 0xE7FC,
	0x9644: 0xE7FD,
	0x9645: 0xE7FE,
	0x9646: 0xE7FF,
	0x9647: 0xE800,
	0x9648: 0xE801,
	0x9649: 0xE802,
	0x964A: 0xE803,
	0x964B: 0xE804,
	0x964C: 0xE805,
	0x964D: 0xE806,
	0x964E: 0xE807,
	0x964F: 0xE808,
	0x9650: 0xE809,
	0x9651: 0xE80A,
	0x9652: 0xE80B,
	0x9653: 0xE80C,
	0x9654: 0xE80D,
	0x9655: 0xE80E,
	0x9656: 0xE80F,
	0x9657: 0xE810,
	0x9658: 0xE811,
	0x9659: 0xE812,
	0x965A: 0xE813,
	0x965B: 0xE814,
	0x965C: 0xE815,
	0x965D: 0xE816,
	0x965E: 0xE817,
	0x965F: 0xE818,
	0x9660: 0xE819,
	0x9661: 0xE81A,
	0x9662: 0xE81B,
	0x9663: 0xE81C,
	0x9664: 0xE81D,
	0x9665: 0xE81E,
	0x9666: 0xE81F,
	0x9667: 0xE820,
	0x9668: 0xE821,
	0x9669: 0xE822,
	0x966A: 0xE823,
	0x966B: 0xE824,
	0x966C: 0xE825,
	0x966D: 0xE826,
	0x966E: 0xE827,
	0x966F: 0xE828,
	0x9670: 0xE829,
	0x9671: 0xE82A,
	0x9672: 0xE82B,
	0x9673: 0xE82C,
	0x9674: 0xE82D,
	0x9675: 0xE82E,
	0x9676: 0xE82F,
	0x9677: 0xE830,
	0x9678: 0xE831,
	0x9679: 0xE832,
	0x967A: 0xE833,
	0x967B: 0xE834,
	0x967C: 0xE835,
	0x967D: 0xE836,
	0x967E: 0xE837,
	0x96A1: 0xE838,
	0x96A2: 0xE839,
	0x96A3: 0xE83A,
	0x96A4: 0xE83B,
	0x96A5: 0xE83C,
	0x96A6: 0xE83D,
	0x96A7: 0xE83E,
	0x96A8: 0xE83F,
	0x96A9: 0xE840,
	0x96AA: 0xE841,
	0x96AB: 0xE842,
	0x96AC: 0xE843,
	0x96AD: 0xE844,
	0x96AE: 0xE845,
	0x96AF: 0xE846,
	0x96B0: 0xE847,
	0x96B1: 0xE848,
	0x96B2: 0xE849,
	0x96B3: 0xE84A,
	0x96B4: 0xE84B,
	0x96B5: 0xE84C,
	0x96B6: 0xE84D,
	0x96B7: 0xE84E,
	0x96B8: 0xE84F,
	0x96B9: 0xE850,
	0x96BA: 0xE851,
	0x96BB: 0xE852,
	0x96BC: 0xE853,
	0x96BD: 0xE854,
	0x96BE: 0xE855,
	0x96BF: 0xE856,
	0x96C0: 0xE857,
	0x96C1: 0xE858,
	0x96C2: 0xE859,
	0x96C3: 0xE85A,
	0x96C4: 0xE85B,
	0x96C5: 0xE85C,
	0x96C6: 0xE85D,
	0x96C7: 0xE85E,
	0x96C8: 0xE85F,
	0x96C9: 0xE860,
	0x96CA: 0xE861,
	0x96CB: 0xE862,
	0x96CC: 0xE863,
	0x96CD: 0xE864,
	0x96CE: 0xE865,
	0x96CF: 0xE866,
	0x96D0: 0xE867,
	0x96D1: 0xE868,
	0x96D2: 0xE869,
	0x96D3: 0xE86A,
	0x96D4: 0xE86B,
	0x96D5: 0xE86C,
	0x96D6: 0xE86D,
	0x96D7: 0xE86E,
	0x96D8: 0xE86F,
	0x96D9: 0xE870,
	0x96DA: 0xE871,
	0x96DB: 0xE872,
	0x96DC: 0xE873,
	0x96DD: 0xE874,
	0x96DE: 0xE875,
	0x96DF: 0xE876,
	0x96E0: 0xE877,
	0x96E1: 0xE878,
	0x96E2: 0xE879,
	0x96E3: 0xE87A,
	0x96E4: 0xE87B,
	0x96E5: 0xE87C,
	0x96E6: 0xE87D,
	0x96E7: 0xE87E,
	0x96E8: 0xE87F,
	0x96E9: 0xE880,
	0x96EA: 0xE881,
	0x96EB: 0xE882,
	0x96EC: 0xE883,
	0x96ED: 0xE884,
	0x96EE: 0xE885,
	0x96EF: 0xE886,
	0x96F0: 0xE887,
	0x96F1: 0xE888,
	0x96F2: 0xE889,
	0x96F3: 0xE88A,
	0x96F4: 0xE88B,
	0x96F5: 0xE88C,
	0x96F6: 0xE88D,
	0x96F7: 0xE88E,
	0x96F8: 0xE88F,
	0x96F9: 0xE890,
	0x96FA: 0xE891,
	0x96FB: 0xE892,
	0x96FC: 0xE893,
	0x96FD: 0xE894,
	0x96FE: 0xE895,
	0x9740: 0xE896,
	0x9741: 0xE897,
	0x9742: 0xE898,
	0x9743: 0xE899,
	0x9744: 0xE89A,
	0x9745: 0xE89B,
	0x9746: 0xE89C,
	0x9747: 0xE89D,
	0x9748: 0xE89E,
	0x9749: 0xE89F,
	0x974A: 0xE8A0,
	0x974B: 0xE8A1,
	0x974C: 0xE8A2,
	0x974D: 0xE8A3,
	0x974E: 0xE8A4,
	0x974F: 0xE8A5,
	0x9750: 0xE8A6,
	0x9751: 0xE8A7,
	0x9752: 0xE8A8,
	0x9753: 0xE8A9,
	0x9754: 0xE8AA,
	0x9755: 0xE8AB,
	0x9756: 0xE8AC,
	0x9757: 0xE8AD,
	0x9758: 0xE8AE,
	0x9759: 0xE8AF,
	0x975A: 0xE8B0,
	0x975B: 0xE8B1,
	0x975C: 0xE8B2,
	0x975D: 0xE8B3,
	0x975E: 0xE8B4,
	0x975F: 0xE8B5,
	0x9760: 0xE8B6,
	0x9761: 0xE8B7,
	0x9762: 0xE8B8,
	0x9763: 0xE8B9,
	0x9764: 0xE8BA,
	0x9765: 0xE8BB,
	0x9766: 0xE8BC,
	0x9767: 0xE8BD,
	0x9768: 0xE8BE,
	0x9769: 0xE8BF,
	0x976A: 0xE8C0,
	0x976B: 0xE8C1,
	0x976C: 0xE8C2,
	0x976D: 0xE8C3,
	0x976E: 0xE8C4,
	0x976F: 0xE8C5,
	0x9770: 0xE8C6,
	0x9771: 0xE8C7,
	0x9772: 0xE8C8,
	0x9773: 0xE8C9,
	0x9774: 0xE8CA,
	0x9775: 0xE8CB,
	0x9776: 0xE8CC,
	0x9777: 0xE8CD,
	0x9778: 0xE8CE,
	0x9779: 0xE8CF,
	0x977A: 0xE8D0,
	0x977B: 0xE8D1,
	0x977C: 0xE8D2,
	0x977D: 0xE8D3,
	0x977E: 0xE8D4,
	0x97A1: 0xE8D5,
	0x97A2: 0xE8D6,
	0x97A3: 0xE8D7,
	0x97A4: 0xE8D8,
	0x97A5: 0xE8D9,
	0x97A6: 0xE8DA,
	0x97A7: 0xE8DB,
	0x97A8: 0xE8DC,
	0x97A9: 0xE8DD,
	0x97AA: 0xE8DE,
	0x97AB: 0xE8DF,
	0x97AC: 0xE8E0,
	0x97AD: 0xE8E1,
	0x97AE: 0xE8E2,
	0x97AF: 0xE8E3,
	0x97B0: 0xE8E4,
	0x97B1: 0xE8E5,
	0x97B2: 0xE8E6,
	0x97B3: 0xE8E7,
	0x97B4: 0xE8E8,
	0x97B5: 0xE8E9,
	0x97B6: 0xE8EA,
	0x97B7: 0xE8EB,
	0x97B8: 0xE8EC,
	0x97B9: 0xE8ED,
	0x97BA: 0xE8EE,
	0x97BB: 0xE8EF,
	0x97BC: 0xE8F0,
	0x97BD: 0xE8F1,
	0x97BE: 0xE8F2,
	0x97BF: 0xE8F3,
	0x97C0: 0xE8F4,
	0x97C1: 0xE8F5,
	0x97C2: 0xE8F6,
	0x97C3: 0xE8F7,
	0x97C4: 0xE8F8,
	0x97C5: 0xE8F9,
	0x97C6: 0xE8FA,
	0x97C7: 0xE8FB,
	0x97C8: 0xE8FC,
	0x97C9: 0xE8FD,
	0x97CA: 0xE8FE,
	0x97CB: 0xE8FF,
	0x97CC: 0xE900,
	0x97CD: 0xE901,
	0x97CE: 0xE902,
	0x97CF: 0xE903,
	0x97D0: 0xE904,
	0x97D1: 0xE905,
	0x97D2: 0xE906,
	0x97D3: 0xE907,
	0x97D4: 0xE908,
	0x97D5: 0xE909,
	0x97D6: 0xE90A,
	0x97D7: 0xE90B,
	0x97D8: 0xE90C,
	0x97D9: 0xE90D,
	0x97DA: 0xE90E,
	0x97DB: 0xE90F,
	0x97DC: 0xE910,
	0x97DD: 0xE911,
	0x97DE: 0xE912,
	0x97DF: 0xE913,
	0x97E0: 0xE914,
	0x97E1: 0xE915,
	0x97E2: 0xE916,
	0x97E3: 0xE917,
	0x97E4: 0xE918,
	0x97E5: 0xE919,
	0x97E6: 0xE91A,
	0x97E7: 0xE91B,
	0x97E8: 0xE91C,
	0x97E9: 0xE91D,
	0x97EA: 0xE91E,
	0x97EB: 0xE91F,
	0x97EC: 0xE920,
	0x97ED: 0xE921,
	0x97EE: 0xE922,
	0x97EF: 0xE923,
	0x97F0: 0xE924,
	0x97F1: 0xE925,
	0x97F2: 0xE926,
	0x97F3: 0xE927,
	0x97F4: 0xE928,
	0x97F5: 0xE929,
	0x97F6: 0xE92A,
	0x97F7: 0xE92B,
	0x97F8: 0xE92C,
	0x97F9: 0xE92D,
	0x97FA: 0xE92E,
	0x97FB: 0xE92F,
	0x97FC: 0xE930,
	0x97FD: 0xE931,
	0x97FE: 0xE932,
	0x9840: 0xE933,
	0x9841: 0xE934,
	0x9842: 0xE935,
	0x9843: 0xE936,
	0x9844: 0xE937,
	0x9845: 0xE938,
	0x9846: 0xE939,
	0x9847: 0xE93A,
	0x9848: 0xE93B,
	0x9849: 0xE93C,
	0x984A: 0xE93D,
	0x984B: 0xE93E,
	0x984C: 0xE93F,
	0x984D: 0xE940,
	0x984E: 0xE941,
	0x984F: 0xE942,
	0x9850: 0xE943,
	0x9851: 0xE944,
	0x9852: 0xE945,
	0x9853: 0xE946,
	0x9854: 0xE947,
	0x9855: 0xE948,
	0x9856: 0xE949,
	0x9857: 0xE94A,
	0x9858: 0xE94B,
	0x9859: 0xE94C,
	0x985A: 0xE94D,
	0x985B: 0xE94E,
	0x985C: 0xE94F,
	0x985D: 0xE950,
	0x985E: 0xE951,
	0x985F: 0xE952,
	0x9860: 0xE953,
	0x9861: 0xE954,
	0x9862: 0xE955,
	0x9863: 0xE956,
	0x9864: 0xE957,
	0x9865: 0xE958,
	0x9866: 0xE959,
	0x9867: 0xE95A,
	0x9868: 0xE95B,
	0x9869: 0xE95C,
	0x986A: 0xE95D,
	0x986B: 0xE95E,
	0x986C: 0xE95F,
	0x986D: 0xE960,
	0x986E: 0xE961,
	0x986F: 0xE962,
	0x9870: 0xE963,
	0x9871: 0xE964,
	0x9872: 0xE965,
	0x9873: 0xE966,
	0x9874: 0xE967,
	0x9875: 0xE968,
	0x9876: 0xE969,
	0x9877: 0xE96A,
	0x9878: 0xE96B,
	0x9879: 0xE96C,
	0x987A: 0xE96D,
	0x987B: 0xE96E,
	0x987C: 0xE96F,
	0x987D: 0xE970,
	0x987E: 0xE971,
	0x98A1: 0xE972,
	0x98A2: 0xE973,
	0x98A3: 0xE974,
	0x98A4: 0xE975,
	0x98A5: 0xE976,
	0x98A6: 0xE977,
	0x98A7: 0xE978,
	0x98A8: 0xE979,
	0x98A9: 0xE97A,
	0x98AA: 0xE97B,
	0x98AB: 0xE97C,
	0x98AC: 0xE97D,
	0x98AD: 0xE97E,
	0x98AE: 0xE97F,
	0x98AF: 0xE980,
	0x98B0: 0xE981,
	0x98B1: 0xE982,
	0x98B2: 0xE983,
	0x98B3: 0xE984,
	0x98B4: 0xE985,
	0x98B5: 0xE986,
	0x98B6: 0xE987,
	0x98B7: 0xE988,
	0x98B8: 0xE989,
	0x98B9: 0xE98A,
	0x98BA: 0xE98B,
	0x98BB: 0xE98C,
	0x98BC: 0xE98D,
	0x98BD: 0xE98E,
	0x98BE: 0xE98F,
	0x98BF: 0xE990,
	0x98C0: 0xE991,
	0x98C1: 0xE992,
	0x98C2: 0xE993,
	0x98C3: 0xE994,
	0x98C4: 0xE995,
	0x98C5: 0xE996,
	0x98C6: 0xE997,
	0x98C7: 0xE998,
	0x98C8: 0xE999,
	0x98C9: 0xE99A,
	0x98CA: 0xE99B,
	0x98CB: 0xE99C,
	0x98CC: 0xE99D,
	0x98CD: 0xE99E,
	0x98CE: 0xE99F,
	0x98CF: 0xE9A0,
	0x98D0: 0xE9A1,
	0x98D1: 0xE9A2,
	0x98D2: 0xE9A3,
	0x98D3: 0xE9A4,
	0x98D4: 0xE9A5,
	0x98D5: 0xE9A6,
	0x98D6: 0xE9A7,
	0x98D7: 0xE9A8,
	0x98D8: 0xE9A9,
	0x98D9: 0xE9AA,
	0x98DA: 0xE9AB,
	0x98DB: 0xE9AC,
	0x98DC: 0xE9AD,
	0x98DD: 0xE9AE,
	0x98DE: 0xE9AF,
	0x98DF: 0xE9B0,
	0x98E0: 0xE9B1,
	0x98E1: 0xE9B2,
	0x98E2: 0xE9B3,
	0x98E3: 0xE9B4,
	0x98E4: 0xE9B5,
	0x98E5: 0xE9B6,
	0x98E6: 0xE9B7,
	0x98E7: 0xE9B8,
	0x98E8: 0xE9B9,
	0x98E9: 0xE9BA,
	0x98EA: 0xE9BB,
	0x98EB: 0xE9BC,
	0x98EC: 0xE9BD,
	0x98ED: 0xE9BE,
	0x98EE: 0xE9BF,
	0x98EF: 0xE9C0,
	0x98F0: 0xE9C1,
	0x98F1: 0xE9C2,
	0x98F2: 0xE9C3,
	0x98F3: 0xE9C4,
	0x98F4: 0xE9C5,
	0x98F5: 0xE9C6,
	0x98F6: 0xE9C7,
	0x98F7: 0xE9C8,
	0x98F8: 0xE9C9,
	0x98F9: 0xE9CA,
	0x98FA: 0xE9CB,
	0x98FB: 0xE9CC,
	0x98FC: 0xE9CD,
	0x98FD: 0xE9CE,
	0x98FE: 0xE9CF,
	0x9940: 0xE9D0,
	0x9941: 0xE9D1,
	0x9942: 0xE9D2,
	0x9943: 0xE9D3,
	0x9944: 0xE9D4,
	0x9945: 0xE9D5,
	0x9946: 0xE9D6,
	0x9947: 0xE9D7,
	0x9948: 0xE9D8,
	0x9949: 0xE9D9,
	0x994A: 0xE9DA,
	0x994B: 0xE9DB,
	0x994C: 0xE9DC,
	0x994D: 0xE9DD,
	0x994E: 0xE9DE,
	0x994F: 0xE9DF,
	0x9950: 0xE9E0,
	0x9951: 0xE9E1,
	0x9952: 0xE9E2,
	0x9953: 0xE9E3,
	0x9954: 0xE9E4,
	0x9955: 0xE9E5,
	0x9956: 0xE9E6,
	0x9957: 0xE9E7,
	0x9958: 0xE9E8,
	0x9959: 0xE9E9,
	0x995A: 0xE9EA,
	0x995B: 0xE9EB,
	0x995C: 0xE9EC,
	0x995D: 0xE9ED,
	0x995E: 0xE9EE,
	0x995F: 0xE9EF,
	0x9960: 0xE9F0,
	0x9961: 0xE9F1,
	0x9962: 0xE9F2,
	0x9963: 0xE9F3,
	0x9964: 0xE9F4,
	0x9965: 0xE9F5,
	0x9966: 0xE9F6,
	0x9967: 0xE9F7,
	0x9968: 0xE9F8,
	0x9969: 0xE9F9,
	0x996A: 0xE9FA,
	0x996B: 0xE9FB,
	0x996C: 0xE9FC,
	0x996D: 0xE9FD,
	0x996E: 0xE9FE,
	0x996F: 0xE9FF,
	0x9970: 0xEA00,
	0x9971: 0xEA01,
	0x9972: 0xEA02,
	0x9973: 0xEA03,
	0x9974: 0xEA04,
	0x9975: 0xEA05,
	0x9976: 0xEA06,
	0x9977: 0xEA07,
	0x9978: 0xEA08,
	0x9979: 0xEA09,
	0x997A: 0xEA0A,
	0x997B: 0xEA0B,
	0x997C: 0xEA0C,
	0x997D: 0xEA0D,
	0x997E: 0xEA0E,
	0x99A1: 0xEA0F,
	0x99A2: 0xEA10,
	0x99A3: 0xEA11,
	0x99A4: 0xEA12,
	0x99A5: 0xEA13,
	0x99A6: 0xEA14,
	0x99A7: 0xEA15,
	0x99A8: 0xEA16,
	0x99A9: 0xEA17,
	0x99AA: 0xEA18,
	0x99AB: 0xEA19,
	0x99AC: 0xEA1A,
	0x99AD: 0xEA1B,
	0x99AE: 0xEA1C,
	0x99AF: 0xEA1D,
	0x99B0: 0xEA1E,
	0x99B1: 0xEA1F,
	0x99B2: 0xEA20,
	0x99B3: 0xEA21,
	0x99B4: 0xEA22,
	0x99B5: 0xEA23,
	0x99B6: 0xEA24,
	0x99B7: 0xEA25,
	0x99B8: 0xEA26,
	0x99B9: 0xEA27,
	0x99BA: 0xEA28,
	0x99BB: 0xEA29,
	0x99BC: 0xEA2A,
	0x99BD: 0xEA2B,
	0x99BE: 0xEA2C,
	0x99BF: 0xEA2D,
	0x99C0: 0xEA2E,
	0x99C1: 0xEA2F,
	0x99C2: 0xEA30,
	0x99C3: 0xEA31,
	0x99C4: 0xEA32,
	0x99C5: 0xEA33,
	0x99C6: 0xEA34,
	0x99C7: 0xEA35,
	0x99C8: 0xEA36,
	0x99C9: 0xEA37,
	0x99CA: 0xEA38,
	0x99CB: 0xEA39,
	0x99CC: 0xEA3A,
	0x99CD: 0xEA3B,
	0x99CE: 0xEA3C,
	0x99CF: 0xEA3D,
	0x99D0: 0xEA3E,
	0x99D1: 0xEA3F,
	0x99D2: 0xEA40,
	0x99D3: 0xEA41,
	0x99D4: 0xEA42,
	0x99D5: 0xEA43,
	0x99D6: 0xEA44,
	0x99D7: 0xEA45,
	0x99D8: 0xEA46,
	0x99D9: 0xEA47,
	0x99DA: 0xEA48,
	0x99DB: 0xEA49,
	0x99DC: 0xEA4A,
	0x99DD: 0xEA4B,
	0x99DE: 0xEA4C,
	0x99DF: 0xEA4D,
	0x99E0: 0xEA4E,
	0x99E1: 0xEA4F,
	0x99E2: 0xEA50,
	0x99E3: 0xEA51,
	0x99E4: 0xEA52,
	0x99E5: 0xEA53,
	0x99E6: 0xEA54,
	0x99E7: 0xEA55,
	0x99E8: 0xEA56,
	0x99E9: 0xEA57,
	0x99EA: 0xEA58,
	0x99EB: 0xEA59,
	0x99EC: 0xEA5A,
	0x99ED: 0xEA5B,
	0x99EE: 0xEA5C,
	0x99EF: 0xEA5D,
	0x99F0: 0xEA5E,
	0x99F1: 0xEA5F,
	0x99F2: 0xEA60,
	0x99F3: 0xEA61,
	0x99F4: 0xEA62,
	0x99F5: 0xEA63,
	0x99F6: 0xEA64,
	0x99F7: 0xEA65,
	0x99F8: 0xEA66,
	0x99F9: 0xEA67,
	0x99FA: 0xEA68,
	0x99FB: 0xEA69,
	0x99FC: 0xEA6A,
	0x99FD: 0xEA6B,
	0x99FE: 0xEA6C,
	0x9A40: 0xEA6D,
	0x9A41: 0xEA6E,
	0x9A42: 0xEA6F,
	0x9A43: 0xEA70,
	0x9A44: 0xEA71,
	0x9A45: 0xEA72,
	0x9A46: 0xEA73,
	0x9A47: 0xEA74,
	0x9A48: 0xEA75,
	0x9A49: 0xEA76,
	0x9A4A: 0xEA77,
	0x9A4B: 0xEA78,
	0x9A4C: 0xEA79,
	0x9A4D: 0xEA7A,
	0x9A4E: 0xEA7B,
	0x9A4F: 0xEA7C,
	0x9A50: 0xEA7D,
	0x9A51: 0xEA7E,
	0x9A52: 0xEA7F,
	0x9A53: 0xEA80,
	0x9A54: 0xEA81,
	0x9A55: 0xEA82,
	0x9A56: 0xEA83,
	0x9A57: 0xEA84,
	0x9A58: 0xEA85,
	0x9A59: 0xEA86,
	0x9A5A: 0xEA87,
	0x9A5B: 0xEA88,
	0x9A5C: 0xEA89,
	0x9A5D: 0xEA8A,
	0x9A5E: 0xEA8B,
	0x9A5F: 0xEA8C,
	0x9A60: 0xEA8D,
	0x9A61: 0xEA8E,
	0x9A62: 0xEA8F,
	0x9A63: 0xEA90,
	0x9A64: 0xEA91,
	0x9A65: 0xEA92,
	0x9A66: 0xEA93,
	0x9A67: 0xEA94,
	0x9A68: 0xEA95,
	0x9A69: 0xEA96,
	0x9A6A: 0xEA97,
	0x9A6B: 0xEA98,
	0x9A6C: 0xEA99,
	0x9A6D: 0xEA9A,
	0x9A6E: 0xEA9B,
	0x9A6F: 0xEA9C,
	0x9A70: 0xEA9D,
	0x9A71: 0xEA9E,
	0x9A72: 0xEA9F,
	0x9A73: 0xEAA0,
	0x9A74: 0xEAA1,
	0x9A75: 0xEAA2,
	0x9A76: 0xEAA3,
	0x9A77: 0xEAA4,
	0x9A78: 0xEAA5,
	0x9A79: 0xEAA6,
	0x9A7A: 0xEAA7,
	0x9A7B: 0xEAA8,
	0x9A7C: 0xEAA9,
	0x9A7D: 0xEAAA,
	0x9A7E: 0xEAAB,
	0x9AA1: 0xEAAC,
	0x9AA2: 0xEAAD,
	0x9AA3: 0xEAAE,
	0x9AA4: 0xEAAF,
	0x9AA5: 0xEAB0,
	0x9AA6: 0xEAB1,
	0x9AA7: 0xEAB2,
	0x9AA8: 0xEAB3,
	0x9AA9: 0xEAB4,
	0x9AAA: 0xEAB5,
	0x9AAB: 0xEAB6,
	0x9AAC: 0xEAB7,
	0x9AAD: 0xEAB8,
	0x9AAE: 0xEAB9,
	0x9AAF: 0xEABA,
	0x9AB0: 0xEABB,
	0x9AB1: 0xEABC,
	0x9AB2: 0xEABD,
	0x9AB3: 0xEABE,
	0x9AB4: 0xEABF,
	0x9AB5: 0xEAC0,
	0x9AB6: 0xEAC1,
	0x9AB7: 0xEAC2,
	0x9AB8: 0xEAC3,
	0x9AB9: 0xEAC4,
	0x9ABA: 0xEAC5,
	0x9ABB: 0xEAC6,
	0x9ABC: 0xEAC7,
	0x9ABD: 0xEAC8,
	0x9ABE: 0xEAC9,
	0x9ABF: 0xEACA,
	0x9AC0: 0xEACB,
	0x9AC1: 0xEACC,
	0x9AC2: 0xEACD,
	0x9AC3: 0xEACE,
	0x9AC4: 0xEACF,
	0x9AC5: 0xEAD0,
	0x9AC6: 0xEAD1,
	0x9AC7: 0xEAD2,
	0x9AC8: 0xEAD3,
	0x9AC9: 0xEAD4,
	0x9ACA: 0xEAD5,
	0x9ACB: 0xEAD6,
	0x9ACC: 0xEAD7,
	0x9ACD: 0xEAD8,
	0x9ACE: 0xEAD9,
	0x9ACF: 0xEADA,
	0x9AD0: 0xEADB,
	0x9AD1: 0xEADC,
	0x9AD2: 0xEADD,
	0x9AD3: 0xEADE,
	0x9AD4: 0xEADF,
	0x9AD5: 0xEAE0,
	0x9AD6: 0xEAE1,
	0x9AD7: 0xEAE2,
	0x9AD8: 0xEAE3,
	0x9AD9: 0xEAE4,
	0x9ADA: 0xEAE5,
	0x9ADB: 0xEAE6,
	0x9ADC: 0xEAE7,
	0x9ADD: 0xEAE8,
	0x9ADE: 0xEAE9,
	0x9ADF: 0xEAEA,
	0x9AE0: 0xEAEB,
	0x9AE1: 0xEAEC,
	0x9AE2: 0xEAED,
	0x9AE3: 0xEAEE,
	0x9AE4: 0xEAEF,
	0x9AE5: 0xEAF0,
	0x9AE6: 0xEAF1,
	0x9AE7: 0xEAF2,
	0x9AE8: 0xEAF3,
	0x9AE9: 0xEAF4,
	0x9AEA: 0xEAF5,
	0x9AEB: 0xEAF6,
	0x9AEC: 0xEAF7,
	0x9AED: 0xEAF8,
	0x9AEE: 0xEAF9,
	0x9AEF: 0xEAFA,
	0x9AF0: 0xEAFB,
	0x9AF1: 0xEAFC,
	0x9AF2: 0xEAFD,
	0x9AF3: 0xEAFE,
	0x9AF4: 0xEAFF,
	0x9AF5: 0xEB00,
	0x9AF6: 0xEB01,
	0x9AF7: 0xEB02,
	0x9AF8: 0xEB03,
	0x9AF9: 0xEB04,
	0x9AFA: 0xEB05,
	0x9AFB: 0xEB06,
	0x9AFC: 0xEB07,
	0x9AFD: 0xEB08,
	0x9AFE: 0xEB09,
	0x9B40: 0xEB0A,
	0x9B41: 0xEB0B,
	0x9B42: 0xEB0C,
	0x9B43: 0xEB0D,
	0x9B44: 0xEB0E,
	0x9B45: 0xEB0F,
	0x9B46: 0xEB10,
	0x9B47: 0xEB11,
	0x9B48: 0xEB12,
	0x9B49: 0xEB13,
	0x9B4A: 0xEB14,
	0x9B4B: 0xEB15,
	0x9B4C: 0xEB16,
	0x9B4D: 0xEB17,
	0x9B4E: 0xEB18,
	0x9B4F: 0xEB19,
	0x9B50: 0xEB1A,
	0x9B51: 0xEB1B,
	0x9B52: 0xEB1C,
	0x9B53: 0xEB1D,
	0x9B54: 0xEB1E,
	0x9B55: 0xEB1F,
	0x9B56: 0xEB20,
	0x9B57: 0xEB21,
	0x9B58: 0xEB22,
	0x9B59: 0xEB23,
	0x9B5A: 0xEB24,
	0x9B5B: 0xEB25,
	0x9B5C: 0xEB26,
	0x9B5D: 0xEB27,
	0x9B5E: 0xEB28,
	0x9B5F: 0xEB29,
	0x9B60: 0xEB2A,
	0x9B61: 0xEB2B,
	0x9B62: 0xEB2C,
	0x9B63: 0xEB2D,
	0x9B64: 0xEB2E,
	0x9B65: 0xEB2F,
	0x9B66: 0xEB30,
	0x9B67: 0xEB31,
	0x9B68: 0xEB32,
	0x9B69: 0xEB33,
	0x9B6A: 0xEB34,
	0x9B6B: 0xEB35,
	0x9B6C: 0xEB36,
	0x9B6D: 0xEB37,
	0x9B6E: 0xEB38,
	0x9B6F: 0xEB39,
	0x9B70: 0xEB3A,
	0x9B71: 0xEB3B,
	0x9B72: 0xEB3C,
	0x9B73: 0xEB3D,
	0x9B74: 0xEB3E,
	0x9B75: 0xEB3F,
	0x9B76: 0xEB40,
	0x9B77: 0xEB41,
	0x9B78: 0xEB42,
	0x9B79: 0xEB43,
	0x9B7A: 0xEB44,
	0x9B7B: 0xEB45,
	0x9B7C: 0xEB46,
	0x9B7D: 0xEB47,
	0x9B7E: 0xEB48,
	0x9BA1: 0xEB49,
	0x9BA2: 0xEB4A,
	0x9BA3: 0xEB4B,
	0x9BA4: 0xEB4C,
	0x9BA5: 0xEB4D,
	0x9BA6: 0xEB4E,
	0x9BA7: 0xEB4F,
	0x9BA8: 0xEB50,
	0x9BA9: 0xEB51,
	0x9BAA: 0xEB52,
	0x9BAB: 0xEB53,
	0x9BAC: 0xEB54,
	0x9BAD: 0xEB55,
	0x9BAE: 0xEB56,
	0x9BAF: 0xEB57,
	0x9BB0: 0xEB58,
	0x9BB1: 0xEB59,
	0x9BB2: 0xEB5A,
	0x9BB3: 0xEB5B,
	0x9BB4: 0xEB5C,
	0x9BB5: 0xEB5D,
	0x9BB6: 0xEB5E,
	0x9BB7: 0xEB5F,
	0x9BB8: 0xEB60,
	0x9BB9: 0xEB61,
	0x9BBA: 0xEB62,
	0x9BBB: 0xEB63,
	0x9BBC: 0xEB64,
	0x9BBD: 0xEB65,
	0x9BBE: 0xEB66,
	0x9BBF: 0xEB67,
	0x9BC0: 0xEB68,
	0x9BC1: 0xEB69,
	0x9BC2: 0xEB6A,
	0x9BC3: 0xEB6B,
	0x9BC4: 0xEB6C,
	0x9BC5: 0xEB6D,
	0x9BC6: 0xEB6E,
	0x9BC7: 0xEB6F,
	0x9BC8: 0xEB70,
	0x9BC9: 0xEB71,
	0x9BCA: 0xEB72,
	0x9BCB: 0xEB73,
	0x9BCC: 0xEB74,
	0x9BCD: 0xEB75,
	0x9BCE: 0xEB76,
	0x9BCF: 0xEB77,
	0x9BD0: 0xEB78,
	0x9BD1: 0xEB79,
	0x9BD2: 0xEB7A,
	0x9BD3: 0xEB7B,
	0x9BD4: 0xEB7C,
	0x9BD5: 0xEB7D,
	0x9BD6: 0xEB7E,
	0x9BD7: 0xEB7F,
	0x9BD8: 0xEB80,
	0x9BD9: 0xEB81,
	0x9BDA: 0xEB82,
	0x9BDB: 0xEB83,
	0x9BDC: 0xEB84,
	0x9BDD: 0xEB85,
	0x9BDE: 0xEB86,
	0x9BDF: 0xEB87,
	0x9BE0: 0xEB88,
	0x9BE1: 0xEB89,
	0x9BE2: 0xEB8A,
	0x9BE3: 0xEB8B,
	0x9BE4: 0xEB8C,
	0x9BE5: 0xEB8D,
	0x9BE6: 0xEB8E,
	0x9BE7: 0xEB8F,
	0x9BE8: 0xEB90,
	0x9BE9: 0xEB91,
	0x9BEA: 0xEB92,
	0x9BEB: 0xEB93,
	0x9BEC: 0xEB94,
	0x9BED: 0xEB95,
	0x9BEE: 0xEB96,
	0x9BEF: 0xEB97,
	0x9BF0: 0xEB98,
	0x9BF1: 0xEB99,
	0x9BF2: 0xEB9A,
	0x9BF3: 0xEB9B,
	0x9BF4: 0xEB9C,
	0x9BF5: 0xEB9D,
	0x9BF6: 0xEB9E,
	0x9BF7: 0xEB9F,
	0x9BF8: 0xEBA0,
	0x9BF9: 0xEBA1,
	0x9BFA: 0xEBA2,
	0x9BFB: 0xEBA3,
	0x9BFC: 0xEBA4,
	0x9BFD: 0xEBA5,
	0x9BFE: 0xEBA6,
	0x9C40: 0xEBA7,
	0x9C41: 0xEBA8,
	0x9C42: 0xEBA9,
	0x9C43: 0xEBAA,
	0x9C44: 0xEBAB,
	0x9C45: 0xEBAC,
	0x9C46: 0xEBAD,
	0x9C47: 0xEBAE,
	0x9C48: 0xEBAF,
	0x9C49: 0xEBB0,
	0x9C4A: 0xEBB1,
	0x9C4B: 0xEBB2,
	0x9C4C: 0xEBB3,
	0x9C4D: 0xEBB4,
	0x9C4E: 0xEBB5,
	0x9C4F: 0xEBB6,
	0x9C50: 0xEBB7,
	0x9C51: 0xEBB8,
	0x9C52: 0xEBB9,
	0x9C53: 0xEBBA,
	0x9C54: 0xEBBB,
	0x9C55: 0xEBBC,
	0x9C56: 0xEBBD,
	0x9C57: 0xEBBE,
	0x9C58: 0xEBBF,
	0x9C59: 0xEBC0,
	0x9C5A: 0xEBC1,
	0x9C5B: 0xEBC2,
	0x9C5C: 0xEBC3,
	0x9C5D: 0xEBC4,
	0x9C5E: 0xEBC5,
	0x9C5F: 0xEBC6,
	0x9C60: 0xEBC7,
	0x9C61: 0xEBC8,
	0x9C62: 0xEBC9,
	0x9C63: 0xEBCA,
	0x9C64: 0xEBCB,
	0x9C65: 0xEBCC,
	0x9C66: 0xEBCD,
	0x9C67: 0xEBCE,
	0x9C68: 0xEBCF,
	0x9C69: 0xEBD0,
	0x9C6A: 0xEBD1,
	0x9C6B: 0xEBD2,
	0x9C6C: 0xEBD3,
	0x9C6D: 0xEBD4,
	0x9C6E: 0xEBD5,
	0x9C6F: 0xEBD6,
	0x9C70: 0xEBD7,
	0x9C71: 0xEBD8,
	0x9C72: 0xEBD9,
	0x9C73: 0xEBDA,
	0x9C74: 0xEBDB,
	0x9C75: 0xEBDC,
	0x9C76: 0xEBDD,
	0x9C77: 0xEBDE,
	0x9C78: 0xEBDF,
	0x9C79: 0xEBE0,
	0x9C7A: 0xEBE1,
	0x9C7B: 0xEBE2,
	0x9C7C: 0xEBE3,
	0x9C7D: 0xEBE4,
	0x9C7E: 0xEBE5,
	0x9CA1: 0xEBE6,
	0x9CA2: 0xEBE7,
	0x9CA3: 0xEBE8,
	0x9CA4: 0xEBE9,
	0x9CA5: 0xEBEA,
	0x9CA6: 0xEBEB,
	0x9CA7: 0xEBEC,
	0x9CA8: 0xEBED,
	0x9CA9: 0xEBEE,
	0x9CAA: 0xEBEF,
	0x9CAB: 0xEBF0,
	0x9CAC: 0xEBF1,
	0x9CAD: 0xEBF2,
	0x9CAE: 0xEBF3,
	0x9CAF: 0xEBF4,
	0x9CB0: 0xEBF5,
	0x9CB1: 0xEBF6,
	0x9CB2: 0xEBF7,
	0x9CB3: 0xEBF8,
	0x9CB4: 0xEBF9,
	0x9CB5: 0xEBFA,
	0x9CB6: 0xEBFB,
	0x9CB7: 0xEBFC,
	0x9CB8: 0xEBFD,
	0x9CB9: 0xEBFE,
	0x9CBA: 0xEBFF,
	0x9CBB: 0xEC00,
	0x9CBC: 0xEC01,
	0x9CBD: 0xEC02,
	0x9CBE: 0xEC03,
	0x9CBF: 0xEC04,
	0x9CC0: 0xEC05,
	0x9CC1: 0xEC06,
	0x9CC2: 0xEC07,
	0x9CC3: 0xEC08,
	0x9CC4: 0xEC09,
	0x9CC5: 0xEC0A,
	0x9CC6: 0xEC0B,
	0x9CC7: 0xEC0C,
	0x9CC8: 0xEC0D,
	0x9CC9: 0xEC0E,
	0x9CCA: 0xEC0F,
	0x9CCB: 0xEC10,
	0x9CCC: 0xEC11,
	0x9CCD: 0xEC12,
	0x9CCE: 0xEC13,
	0x9CCF: 0xEC14,
	0x9CD0: 0xEC15,
	0x9CD1: 0xEC16,
	0x9CD2: 0xEC17,
	0x9CD3: 0xEC18,
	0x9CD4: 0xEC19,
	0x9CD5: 0xEC1A,
	0x9CD6: 0xEC1B,
	0x9CD7: 0xEC1C,
	0x9CD8: 0xEC1D,
	0x9CD9: 0xEC1E,
	0x9CDA: 0xEC1F,
	0x9CDB: 0xEC20,
	0x9CDC: 0xEC21,
	0x9CDD: 0xEC22,
	0x9CDE: 0xEC23,
	0x9CDF: 0xEC24,
	0x9CE0: 0xEC25,
	0x9CE1: 0xEC26,
	0x9CE2: 0xEC27,
	0x9CE3: 0xEC28,
	0x9CE4: 0xEC29,
	0x9CE5: 0xEC2A,
	0x9CE6: 0xEC2B,
	0x9CE7: 0xEC2C,
	0x9CE8: 0xEC2D,
	0x9CE9: 0xEC2E,
	0x9CEA: 0xEC2F,
	0x9CEB: 0xEC30,
	0x9CEC: 0xEC31,
	0x9CED: 0xEC32,
	0x9CEE: 0xEC33,
	0x9CEF: 0xEC34,
	0x9CF0: 0xEC35,
	0x9CF1: 0xEC36,
	0x9CF2: 0xEC37,
	0x9CF3: 0xEC38,
	0x9CF4: 0xEC39,
	0x9CF5: 0xEC3A,
	0x9CF6: 0xEC3B,
	0x9CF7: 0xEC3C,
	0x9CF8: 0xEC3D,
	0x9CF9: 0xEC3E,
	0x9CFA: 0xEC3F,
	0x9CFB: 0xEC40,
	0x9CFC: 0xEC41,
	0x9CFD: 0xEC42,
	0x9CFE: 0xEC43,
	0x9D40: 0xEC44,
	0x9D41: 0xEC45,
	0x9D42: 0xEC46,
	0x9D43: 0xEC47,
	0x9D44: 0xEC48,
	0x9D45: 0xEC49,
	0x9D46: 0xEC4A,
	0x9D47: 0xEC4B,
	0x9D48: 0xEC4C,
	0x9D49: 0xEC4D,
	0x9D4A: 0xEC4E,
	0x9D4B: 0xEC4F,
	0x9D4C: 0xEC50,
	0x9D4D: 0xEC51,
	0x9D4E: 0xEC52,
	0x9D4F: 0xEC53,
	0x9D50: 0xEC54,
	0x9D51: 0xEC55,
	0x9D52: 0xEC56,
	0x9D53: 0xEC57,
	0x9D54: 0xEC58,
	0x9D55: 0xEC59,
	0x9D56: 0xEC5A,
	0x9D57: 0xEC5B,
	0x9D58: 0xEC5C,
	0x9D59: 0xEC5D,
	0x9D5A: 0xEC5E,
	0x9D5B: 0xEC5F,
	0x9D5C: 0xEC60,
	0x9D5D: 0xEC61,
	0x9D5E: 0xEC62,
	0x9D5F: 0xEC63,
	0x9D60: 0xEC64,
	0x9D61: 0xEC65,
	0x9D62: 0xEC66,
	0x9D63: 0xEC67,
	0x9D64: 0xEC68,
	0x9D65: 0xEC69,
	0x9D66: 0xEC6A,
	0x9D67: 0xEC6B,
	0x9D68: 0xEC6C,
	0x9D69: 0xEC6D,
	0x9D6A: 0xEC6E,
	0x9D6B: 0xEC6F,
	0x9D6C: 0xEC70,
	0x9D6D: 0xEC71,
	0x9D6E: 0xEC72,
	0x9D6F: 0xEC73,
	0x9D70: 0xEC74,
	0x9D71: 0xEC75,
	0x9D72: 0xEC76,
	0x9D73: 0xEC77,
	0x9D74: 0xEC78,
	0x9D75: 0xEC79,
	0x9D76: 0xEC7A,
	0x9D77: 0xEC7B,
	0x9D78: 0xEC7C,
	0x9D79: 0xEC7D,
	0x9D7A: 0xEC7E,
	0x9D7B: 0xEC7F,
	0x9D7C: 0xEC80,
	0x9D7D: 0xEC81,
	0x9D7E: 0xEC82,
	0x9DA1: 0xEC83,
	0x9DA2: 0xEC84,
	0x9DA3: 0xEC85,
	0x9DA4: 0xEC86,
	0x9DA5: 0xEC87,
	0x9DA6: 0xEC88,
	0x9DA7: 0xEC89,
	0x9DA8: 0xEC8A,
	0x9DA9: 0xEC8B,
	0x9DAA: 0xEC8C,
	0x9DAB: 0xEC8D,
	0x9DAC: 0xEC8E,
	0x9DAD: 0xEC8F,
	0x9DAE: 0xEC90,
	0x9DAF: 0xEC91,
	0x9DB0: 0xEC92,
	0x9DB1: 0xEC93,
	0x9DB2: 0xEC94,
	0x9DB3: 0xEC95,
	0x9DB4: 0xEC96,
	0x9DB5: 0xEC97,
	0x9DB6: 0xEC98,
	0x9DB7: 0xEC99,
	0x9DB8: 0xEC9A,
	0x9DB9: 0xEC9B,
	0x9DBA: 0xEC9C,
	0x9DBB: 0xEC9D,
	0x9DBC: 0xEC9E,
	0x9DBD: 0xEC9F,
	0x9DBE: 0xECA0,
	0x9DBF: 0xECA1,
	0x9DC0: 0xECA2,
	0x9DC1: 0xECA3,
	0x9DC2: 0xECA4,
	0x9DC3: 0xECA5,
	0x9DC4: 0xECA6,
	0x9DC5: 0xECA7,
	0x9DC6: 0xECA8,
	0x9DC7: 0xECA9,
	0x9DC8: 0xECAA,
	0x9DC9: 0xECAB,
	0x9DCA: 0xECAC,
	0x9DCB: 0xECAD,
	0x9DCC: 0xECAE,
	0x9DCD: 0xECAF,
	0x9DCE: 0xECB0,
	0x9DCF: 0xECB1,
	0x9DD0: 0xECB2,
	0x9DD1: 0xECB3,
	0x9DD2: 0xECB4,
	0x9DD3: 0xECB5,
	0x9DD4: 0xECB6,
	0x9DD5: 0xECB7,
	0x9DD6: 0xECB8,
	0x9DD7: 0xECB9,
	0x9DD8: 0xECBA,
	0x9DD9: 0xECBB,
	0x9DDA: 0xECBC,
	0x9DDB: 0xECBD,
	0x9DDC: 0xECBE,
	0x9DDD: 0xECBF,
	0x9DDE: 0xECC0,
	0x9DDF: 0xECC1,
	0x9DE0: 0xECC2,
	0x9DE1: 0xECC3,
	0x9DE2: 0xECC4,
	0x9DE3: 0xECC5,
	0x9DE4: 0xECC6,
	0x9DE5: 0xECC7,
	0x9DE6: 0xECC8,
	0x9DE7: 0xECC9,
	0x9DE8: 0xECCA,
	0x9DE9: 0xECCB,
	0x9DEA: 0xECCC,
	0x9DEB: 0xECCD,
	0x9DEC: 0xECCE,
	0x9DED: 0xECCF,
	0x9DEE: 0xECD0,
	0x9DEF: 0xECD1,
	0x9DF0: 0xECD2,
	0x9DF1: 0xECD3,
	0x9DF2: 0xECD4,
	0x9DF3: 0xECD5,
	0x9DF4: 0xECD6,
	0x9DF5: 0xECD7,
	0x9DF6: 0xECD8,
	0x9DF7: 0xECD9,
	0x9DF8: 0xECDA,
	0x9DF9: 0xECDB,
	0x9DFA: 0xECDC,
	0x9DFB: 0xECDD,
	0x9DFC: 0xECDE,
	0x9DFD: 0xECDF,
	0x9DFE: 0xECE0,
	0x9E40: 0xECE1,
	0x9E41: 0xECE2,
	0x9E42: 0xECE3,
	0x9E43: 0xECE4,
	0x9E44: 0xECE5,
	0x9E45: 0xECE6,
	0x9E46: 0xECE7,
	0x9E47: 0xECE8,
	0x9E48: 0xECE9,
	0x9E49: 0xECEA,
	0x9E4A: 0xECEB,
	0x9E4B: 0xECEC,
	0x9E4C: 0xECED,
	0x9E4D: 0xECEE,
	0x9E4E: 0xECEF,
	0x9E4F: 0xECF0,
	0x9E50: 0xECF1,
	0x9E51: 0xECF2,
	0x9E52: 0xECF3,
	0x9E53: 0xECF4,
	0x9E54: 0xECF5,
	0x9E55: 0xECF6,
	0x9E56: 0xECF7,
	0x9E57: 0xECF8,
	0x9E58: 0xECF9,
	0x9E59: 0xECFA,
	0x9E5A: 0xECFB,
	0x9E5B: 0xECFC,
	0x9E5C: 0xECFD,
	0x9E5D: 0xECFE,
	0x9E5E: 0xECFF,
	0x9E5F: 0xED00,
	0x9E60: 0xED01,
	0x9E61: 0xED02,
	0x9E62: 0xED03,
	0x9E63: 0xED04,
	0x9E64: 0xED05,
	0x9E65: 0xED06,
	0x9E66: 0xED07,
	0x9E67: 0xED08,
	0x9E68: 0xED09,
	0x9E69: 0xED0A,
	0x9E6A: 0xED0B,
	0x9E6B: 0xED0C,
	0x9E6C: 0xED0D,
	0x9E6D: 0xED0E,
	0x9E6E: 0xED0F,
	0x9E6F: 0xED10,
	0x9E70: 0xED11,
	0x9E71: 0xED12,
	0x9E72: 0xED13,
	0x9E73: 0xED14,
	0x9E74: 0xED15,
	0x9E75: 0xED16,
	0x9E76: 0xED17,
	0x9E77: 0xED18,
	0x9E78: 0xED19,
	0x9E79: 0xED1A,
	0x9E7A: 0xED1B,
	0x9E7B: 0xED1C,
	0x9E7C: 0xED1D,
	0x9E7D: 0xED1E,
	0x9E7E: 0xED1F,
	0x9EA1: 0xED20,
	0x9EA2: 0xED21,
	0x9EA3: 0xED22,
	0x9EA4: 0xED23,
	0x9EA5: 0xED24,
	0x9EA6: 0xED25,
	0x9EA7: 0xED26,
	0x9EA8: 0xED27,
	0x9EA9: 0xED28,
	0x9EAA: 0xED29,
	0x9EAB: 0xED2A,
	0x9EAC: 0xED2B,
	0x9EAD: 0xED2C,
	0x9EAE: 0xED2D,
	0x9EAF: 0xED2E,
	0x9EB0: 0xED2F,
	0x9EB1: 0xED30,
	0x9EB2: 0xED31,
	0x9EB3: 0xED32,
	0x9EB4: 0xED33,
	0x9EB5: 0xED34,
	0x9EB6: 0xED35,
	0x9EB7: 0xED36,
	0x9EB8: 0xED37,
	0x9EB9: 0xED38,
	0x9EBA: 0xED39,
	0x9EBB: 0xED3A,
	0x9EBC: 0xED3B,
	0x9EBD: 0xED3C,
	0x9EBE: 0xED3D,
	0x9EBF: 0xED3E,
	0x9EC0: 0xED3F,
	0x9EC1: 0xED40,
	0x9EC2: 0xED41,
	0x9EC3: 0xED42,
	0x9EC4: 0xED43,
	0x9EC5: 0xED44,
	0x9EC6: 0xED45,
	0x9EC7: 0xED46,
	0x9EC8: 0xED47,
	0x9EC9: 0xED48,
	0x9ECA: 0xED49,
	0x9ECB: 0xED4A,
	0x9ECC: 0xED4B,
	0x9ECD: 0xED4C,
	0x9ECE: 0xED4D,
	0x9ECF: 0xED4E,
	0x9ED0: 0xED4F,
	0x9ED1: 0xED50,
	0x9ED2: 0xED51,
	0x9ED3: 0xED52,
	0x9ED4: 0xED53,
	0x9ED5: 0xED54,
	0x9ED6: 0xED55,
	0x9ED7: 0xED56,
	0x9ED8: 0xED57,
	0x9ED9: 0xED58,
	0x9EDA: 0xED59,
	0x9EDB: 0xED5A,
	0x9EDC: 0xED5B,
	0x9EDD: 0xED5C,
	0x9EDE: 0xED5D,
	0x9EDF: 0xED5E,
	0x9EE0: 0xED5F,
	0x9EE1: 0xED60,
	0x9EE2: 0xED61,
	0x9EE3: 0xED62,
	0x9EE4: 0xED63,
	0x9EE5: 0xED64,
	0x9EE6: 0xED65,
	0x9EE7: 0xED66,
	0x9EE8: 0xED67,
	0x9EE9: 0xED68,
	0x9EEA: 0xED69,
	0x9EEB: 0xED6A,
	0x9EEC: 0xED6B,
	0x9EED: 0xED6C,
	0x9EEE: 0xED6D,
	0x9EEF: 0xED6E,
	0x9EF0: 0xED6F,
	0x9EF1: 0xED70,
	0x9EF2: 0xED71,
	0x9EF3: 0xED72,
	0x9EF4: 0xED73,
	0x9EF5: 0xED74,
	0x9EF6: 0xED75,
	0x9EF7: 0xED76,
	0x9EF8: 0xED77,
	0x9EF9: 0xED78,
	0x9EFA: 0xED79,
	0x9EFB: 0xED7A,
	0x9EFC: 0xED7B,
	0x9EFD: 0xED7C,
	0x9EFE: 0xED7D,
	0x9F40: 0xED7E,
	0x9F41: 0xED7F,
	0x9F42: 0xED80,
	0x9F43: 0xED81,
	0x9F44: 0xED82,
	0x9F45: 0xED83,
	0x9F46: 0xED84,
	0x9F47: 0xED85,
	0x9F48: 0xED86,
	0x9F49: 0xED87,
	0x9F4A: 0xED88,
	0x9F4B: 0xED89,
	0x9F4C: 0xED8A,
	0x9F4D: 0xED8B,
	0x9F4E: 0xED8C,
	0x9F4F: 0xED8D,
	0x9F50: 0xED8E,
	0x9F51: 0xED8F,
	0x9F52: 0xED90,
	0x9F53: 0xED91,
	0x9F54: 0xED92,
	0x9F55: 0xED93,
	0x9F56: 0xED94,
	0x9F57: 0xED95,
	0x9F58: 0xED96,
	0x9F59: 0xED97,
	0x9F5A: 0xED98,
	0x9F5B: 0xED99,
	0x9F5C: 0xED9A,
	0x9F5D: 0xED9B,
	0x9F5E: 0xED9C,
	0x9F5F: 0xED9D,
	0x9F60: 0xED9E,
	0x9F61: 0xED9F,
	0x9F62: 0xEDA0,
	0x9F63: 0xEDA1,
	0x9F64: 0xEDA2,
	0x9F65: 0xEDA3,
	0x9F66: 0xEDA4,
	0x9F67: 0xEDA5,
	0x9F68: 0xEDA6,
	0x9F69: 0xEDA7,
	0x9F6A: 0xEDA8,
	0x9F6B: 0xEDA9,
	0x9F6C: 0xEDAA,
	0x9F6D: 0xEDAB,
	0x9F6E: 0xEDAC,
	0x9F6F: 0xEDAD,
	0x9F70: 0xEDAE,
	0x9F71: 0xEDAF,
	0x9F72: 0xEDB0,
	0x9F73: 0xEDB1,
	0x9F74: 0xEDB2,
	0x9F75: 0xEDB3,
	0x9F76: 0xEDB4,
	0x9F77: 0xEDB5,
	0x9F78: 0xEDB6,
	0x9F79: 0xEDB7,
	0x9F7A: 0xEDB8,
	0x9F7B: 0xEDB9,
	0x9F7C: 0xEDBA,
	0x9F7D: 0xEDBB,
	0x9F7E: 0xEDBC,
	0x9FA1: 0xEDBD,
	0x9FA2: 0xEDBE,
	0x9FA3: 0xEDBF,
	0x9FA4: 0xEDC0,
	0x9FA5: 0xEDC1,
	0x9FA6: 0xEDC2,
	0x9FA7: 0xEDC3,
	0x9FA8: 0xEDC4,
	0x9FA9: 0xEDC5,
	0x9FAA: 0xEDC6,
	0x9FAB: 0xEDC7,
	0x9FAC: 0xEDC8,
	0x9FAD: 0xEDC9,
	0x9FAE: 0xEDCA,
	0x9FAF: 0xEDCB,
	0x9FB0: 0xEDCC,
	0x9FB1: 0xEDCD,
	0x9FB2: 0xEDCE,
	0x9FB3: 0xEDCF,
	0x9FB4: 0xEDD0,
	0x9FB5: 0xEDD1,
	0x9FB6: 0xEDD2,
	0x9FB7: 0xEDD3,
	0x9FB8: 0xEDD4,
	0x9FB9: 0xEDD5,
	0x9FBA: 0xEDD6,
	0x9FBB: 0xEDD7,
	0x9FBC: 0xEDD8,
	0x9FBD: 0xEDD9,
	0x9FBE: 0xEDDA,
	0x9FBF: 0xEDDB,
	0x9FC0: 0xEDDC,
	0x9FC1: 0xEDDD,
	0x9FC2: 0xEDDE,
	0x9FC3: 0xEDDF,
	0x9FC4: 0xEDE0,
	0x9FC5: 0xEDE1,
	0x9FC6: 0xEDE2,
	0x9FC7: 0xEDE3,
	0x9FC8: 0xEDE4,
	0x9FC9: 0xEDE5,
	0x9FCA: 0xEDE6,
	0x9FCB: 0xEDE7,
	0x9FCC: 0xEDE8,
	0x9FCD: 0xEDE9,
	0x9FCE: 0xEDEA,
	0x9FCF: 0xEDEB,
	0x9FD0: 0xEDEC,
	0x9FD1: 0xEDED,
	0x9FD2: 0xEDEE,
	0x9FD3: 0xEDEF,
	0x9FD4: 0xEDF0,
	0x9FD5: 0xEDF1,
	0x9FD6: 0xEDF2,
	0x9FD7: 0xEDF3,
	0x9FD8: 0xEDF4,
	0x9FD9: 0xEDF5,
	0x9FDA: 0xEDF6,
	0x9FDB: 0xEDF7,
	0x9FDC: 0xEDF8,
	0x9FDD: 0xEDF9,
	0x9FDE: 0xEDFA,
	0x9FDF: 0xEDFB,
	0x9FE0: 0xEDFC,
	0x9FE1: 0xEDFD,
	0x9FE2: 0xEDFE,
	0x9FE3: 0xEDFF,
	0x9FE4: 0xEE00,
	0x9FE5: 0xEE01,
	0x9FE6: 0xEE02,
	0x9FE7: 0xEE03,
	0x9FE8: 0xEE04,
	0x9FE9: 0xEE05,
	0x9FEA: 0xEE06,
	0x9FEB: 0xEE07,
	0x9FEC: 0xEE08,
	0x9FED: 0xEE09,
	0x9FEE: 0xEE0A,
	0x9FEF: 0xEE0B,
	0x9FF0: 0xEE0C,
	0x9FF1: 0xEE0D,
	0x9FF2: 0xEE0E,
	0x9FF3: 0xEE0F,
	0x9FF4: 0xEE10,
	0x9FF5: 0xEE11,
	0x9FF6: 0xEE12,
	0x9FF7: 0xEE13,
	0x9FF8: 0xEE14,
	0x9FF9: 0xEE15,
	0x9FFA: 0xEE16,
	0x9FFB: 0xEE17,
	0x9FFC: 0xEE18,
	0x9FFD: 0xEE19,
	0x9FFE: 0xEE1A,
	0xA040: 0xEE1B,
	0xA041: 0xEE1C,
	0xA042: 0xEE1D,
	0xA043: 0xEE1E,
	0xA044: 0xEE1F,
	0xA045: 0xEE20,
	0xA046: 0xEE21,
	0xA047: 0xEE22,
	0xA048: 0xEE23,
	0xA049: 0xEE24,
	0xA04A: 0xEE25,
	0xA04B: 0xEE26,
	0xA04C: 0xEE27,
	0xA04D: 0xEE28,
	0xA04E: 0xEE29,
	0xA04F: 0xEE2A,
	0xA050: 0xEE2B,
	0xA051: 0xEE2C,
	0xA052: 0xEE2D,
	0xA053: 0xEE2E,
	0xA054: 0xEE2F,
	0xA055: 0xEE30,
	0xA056: 0xEE31,
	0xA057: 0xEE32,
	0xA058: 0xEE33,
	0xA059: 0xEE34,
	0xA05A: 0xEE35,
	0xA05B: 0xEE36,
	0xA05C: 0xEE37,
	0xA05D: 0xEE38,
	0xA05E: 0xEE39,
	0xA05F: 0xEE3A,
	0xA060: 0xEE3B,
	0xA061: 0xEE3C,
	0xA062: 0xEE3D,
	0xA063: 0xEE3E,
	0xA064: 0xEE3F,
	0xA065: 0xEE40,
	0xA066: 0xEE41,
	0xA067: 0xEE42,
	0xA068: 0xEE43,
	0xA069: 0xEE44,
	0xA06A: 0xEE45,
	0xA06B: 0xEE46,
	0xA06C: 0xEE47,
	0xA06D: 0xEE48,
	0xA06E: 0xEE49,
	0xA06F: 0xEE4A,
	0xA070: 0xEE4B,
	0xA071: 0xEE4C,
	0xA072: 0xEE4D,
	0xA073: 0xEE4E,
	0xA074: 0xEE4F,
	0xA075: 0xEE50,
	0xA076: 0xEE51,
	0xA077: 0xEE52,
	0xA078: 0xEE53,
	0xA079: 0xEE54,
	0xA07A: 0xEE55,
	0xA07B: 0xEE56,
	0xA07C: 0xEE57,
	0xA07D: 0xEE58,
	0xA07E: 0xEE59,
	0xA0A1: 0xEE5A,
	0xA0A2: 0xEE5B,
	0xA0A3: 0xEE5C,
	0xA0A4: 0xEE5D,
	0xA0A5: 0xEE5E,
	0xA0A6: 0xEE5F,
	0xA0A7: 0xEE60,
	0xA0A8: 0xEE61,
	0xA0A9: 0xEE62,
	0xA0AA: 0xEE63,
	0xA0AB: 0xEE64,
	0xA0AC: 0xEE65,
	0xA0AD: 0xEE66,
	0xA0AE: 0xEE67,
	0xA0AF: 0xEE68,
	0xA0B0: 0xEE69,
	0xA0B1: 0xEE6A,
	0xA0B2: 0xEE6B,
	0xA0B3: 0xEE6C,
	0xA0B4: 0xEE6D,
	0xA0B5: 0xEE6E,
	0xA0B6: 0xEE6F,
	0xA0B7: 0xEE70,
	0xA0B8: 0xEE71,
	0xA0B9: 0xEE72,
	0xA0BA: 0xEE73,
	0xA0BB: 0xEE74,
	0xA0BC: 0xEE75,
	0xA0BD: 0xEE76,
	0xA0BE: 0xEE77,
	0xA0BF: 0xEE78,
	0xA0C0: 0xEE79,
	0xA0C1: 0xEE7A,
	0xA0C2: 0xEE7B,
	0xA0C3: 0xEE7C,
	0xA0C4: 0xEE7D,
	0xA0C5: 0xEE7E,
	0xA0C6: 0xEE7F,
	0xA0C7: 0xEE80,
	0xA0C8: 0xEE81,
	0xA0C9: 0xEE82,
	0xA0CA: 0xEE83,
	0xA0CB: 0xEE84,
	0xA0CC: 0xEE85,
	0xA0CD: 0xEE86,
	0xA0CE: 0xEE87,
	0xA0CF: 0xEE88,
	0xA0D0: 0xEE89,
	0xA0D1: 0xEE8A,
	0xA0D2: 0xEE8B,
	0xA0D3: 0xEE8C,
	0xA0D4: 0xEE8D,
	0xA0D5: 0xEE8E,
	0xA0D6: 0xEE8F,
	0xA0D7: 0xEE90,
	0xA0D8: 0xEE91,
	0xA0D9: 0xEE92,
	0xA0DA: 0xEE93,
	0xA0DB: 0xEE94,
	0xA0DC: 0xEE95,
	0xA0DD: 0xEE96,
	0xA0DE: 0xEE97,
	0xA0DF: 0xEE98,
	0xA0E0: 0xEE99,
	0xA0E1: 0xEE9A,
	0xA0E2: 0xEE9B,
	0xA0E3: 0xEE9C,
	0xA0E4: 0xEE9D,
	0xA0E5: 0xEE9E,
	0xA0E6: 0xEE9F,
	0xA0E7: 0xEEA0,
	0xA0E8: 0xEEA1,
	0xA0E9: 0xEEA2,
	0xA0EA: 0xEEA3,
	0xA0EB: 0xEEA4,
	0xA0EC: 0xEEA5,
	0xA0ED: 0xEEA6,
	0xA0EE: 0xEEA7,
	0xA0EF: 0xEEA8,
	0xA0F0: 0xEEA9,
	0xA0F1: 0xEEAA,
	0xA0F2: 0xEEAB,
	0xA0F3: 0xEEAC,
	0xA0F4: 0xEEAD,
	0xA0F5: 0xEEAE,
	0xA0F6: 0xEEAF,
	0xA0F7: 0xEEB0,
	0xA0F8: 0xEEB1,
	0xA0F9: 0xEEB2,
	0xA0FA: 0xEEB3,
	0xA0FB: 0xEEB4,
	0xA0FC: 0xEEB5,
	0xA0FD: 0xEEB6,
	0xA0FE: 0xEEB7,
	0x8140: 0xEEB8,
	0x8141: 0xEEB9,
	0x8142: 0xEEBA,
	0x8143: 0xEEBB,
	0x8144: 0xEEBC,
	0x8145: 0xEEBD,
	0x8146: 0xEEBE,
	0x8147: 0xEEBF,
	0x8148: 0xEEC0,
	0x8149: 0xEEC1,
	0x814A: 0xEEC2,
	0x814B: 0xEEC3,
	0x814C: 0xEEC4,
	0x814D: 0xEEC5,
	0x814E: 0xEEC6,
	0x814F: 0xEEC7,
	0x8150: 0xEEC8,
	0x8151: 0xEEC9,
	0x8152: 0xEECA,
	0x8153: 0xEECB,
	0x8154: 0xEECC,
	0x8155: 0xEECD,
	0x8156: 0xEECE,
	0x8157: 0xEECF,
	0x8158: 0xEED0,
	0x8159: 0xEED1,
	0x815A: 0xEED2,
	0x815B: 0xEED3,
	0x815C: 0xEED4,
	0x815D: 0xEED5,
	0x815E: 0xEED6,
	0x815F: 0xEED7,
	0x8160: 0xEED8,
	0x8161: 0xEED9,
	0x8162: 0xEEDA,
	0x8163: 0xEEDB,
	0x8164: 0xEEDC,
	0x8165: 0xEEDD,
	0x8166: 0xEEDE,
	0x8167: 0xEEDF,
	0x8168: 0xEEE0,
	0x8169: 0xEEE1,
	0x816A: 0xEEE2,
	0x816B: 0xEEE3,
	0x816C: 0xEEE4,
	0x816D: 0xEEE5,
	0x816E: 0xEEE6,
	0x816F: 0xEEE7,
	0x8170: 0xEEE8,
	0x8171: 0xEEE9,
	0x8172: 0xEEEA,
	0x8173: 0xEEEB,
	0x8174: 0xEEEC,
	0x8175: 0xEEED,
	0x8176: 0xEEEE,
	0x8177: 0xEEEF,
	0x8178: 0xEEF0,
	0x8179: 0xEEF1,
	0x817A: 0xEEF2,
	0x817B: 0xEEF3,
	0x817C: 0xEEF4,
	0x817D: 0xEEF5,
	0x817E: 0xEEF6,
	0x81A1: 0xEEF7,
	0x81A2: 0xEEF8,
	0x81A3: 0xEEF9,
	0x81A4: 0xEEFA,
	0x81A5: 0xEEFB,
	0x81A6: 0xEEFC,
	0x81A7: 0xEEFD,
	0x81A8: 0xEEFE,
	0x81A9: 0xEEFF,
	0x81AA: 0xEF00,
	0x81AB: 0xEF01,
	0x81AC: 0xEF02,
	0x81AD: 0xEF03,
	0x81AE: 0xEF04,
	0x81AF: 0xEF05,
	0x81B0: 0xEF06,
	0x81B1: 0xEF07,
	0x81B2: 0xEF08,
	0x81B3: 0xEF09,
	0x81B4: 0xEF0A,
	0x81B5: 0xEF0B,
	0x81B6: 0xEF0C,
	0x81B7: 0xEF0D,
	0x81B8: 0xEF0E,
	0x81B9: 0xEF0F,
	0x81BA: 0xEF10,
	0x81BB: 0xEF11,
	0x81BC: 0xEF12,
	0x81BD: 0xEF13,
	0x81BE: 0xEF14,
	0x81BF: 0xEF15,
	0x81C0: 0xEF16,
	0x81C1: 0xEF17,
	0x81C2: 0xEF18,
	0x81C3: 0xEF19,
	0x81C4: 0xEF1A,
	0x81C5: 0xEF1B,
	0x81C6: 0xEF1C,
	0x81C7: 0xEF1D,
	0x81C8: 0xEF1E,
	0x81C9: 0xEF1F,
	0x81CA: 0xEF20,
	0x81CB: 0xEF21,
	0x81CC: 0xEF22,
	0x81CD: 0xEF23,
	0x81CE: 0xEF24,
	0x81CF: 0xEF25,
	0x81D0: 0xEF26,
	0x81D1: 0xEF27,
	0x81D2: 0xEF28,
	0x81D3: 0xEF29,
	0x81D4: 0xEF2A,
	0x81D5: 0xEF2B,
	0x81D6: 0xEF2C,
	0x81D7: 0xEF2D,
	0x81D8: 0xEF2E,
	0x81D9: 0xEF2F,
	0x81DA: 0xEF30,
	0x81DB: 0xEF31,
	0x81DC: 0xEF32,
	0x81DD: 0xEF33,
	0x81DE: 0xEF34,
	0x81DF: 0xEF35,
	0x81E0: 0xEF36,
	0x81E1: 0xEF37,
	0x81E2: 0xEF38,
	0x81E3: 0xEF39,
	0x81E4: 0xEF3A,
	0x81E5: 0xEF3B,
	0x81E6: 0xEF3C,
	0x81E7: 0xEF3D,
	0x81E8: 0xEF3E,
	0x81E9: 0xEF3F,
	0x81EA: 0xEF40,
	0x81EB: 0xEF41,
	0x81EC: 0xEF42,
	0x81ED: 0xEF43,
	0x81EE: 0xEF44,
	0x81EF: 0xEF45,
	0x81F0: 0xEF46,
	0x81F1: 0xEF47,
	0x81F2: 0xEF48,
	0x81F3: 0xEF49,
	0x81F4: 0xEF4A,
	0x81F5: 0xEF4B,
	0x81F6: 0xEF4C,
	0x81F7: 0xEF4D,
	0x81F8: 0xEF4E,
	0x81F9: 0xEF4F,
	0x81FA: 0xEF50,
	0x81FB: 0xEF51,
	0x81FC: 0xEF52,
	0x81FD: 0xEF53,
	0x81FE: 0xEF54,
	0x8240: 0xEF55,
	0x8241: 0xEF56,
	0x8242: 0xEF57,
	0x8243: 0xEF58,
	0x8244: 0xEF59,
	0x8245: 0xEF5A,
	0x8246: 0xEF5B,
	0x8247: 0xEF5C,
	0x8248: 0xEF5D,
	0x8249: 0xEF5E,
	0x824A: 0xEF5F,
	0x824B: 0xEF60,
	0x824C: 0xEF61,
	0x824D: 0xEF62,
	0x824E: 0xEF63,
	0x824F: 0xEF64,
	0x8250: 0xEF65,
	0x8251: 0xEF66,
	0x8252: 0xEF67,
	0x8253: 0xEF68,
	0x8254: 0xEF69,
	0x8255: 0xEF6A,
	0x8256: 0xEF6B,
	0x8257: 0xEF6C,
	0x8258: 0xEF6D,
	0x8259: 0xEF6E,
	0x825A: 0xEF6F,
	0x825B: 0xEF70,
	0x825C: 0xEF71,
	0x825D: 0xEF72,
	0x825E: 0xEF73,
	0x825F: 0xEF74,
	0x8260: 0xEF75,
	0x8261: 0xEF76,
	0x8262: 0xEF77,
	0x8263: 0xEF78,
	0x8264: 0xEF79,
	0x8265: 0xEF7A,
	0x8266: 0xEF7B,
	0x8267: 0xEF7C,
	0x8268: 0xEF7D,
	0x8269: 0xEF7E,
	0x826A: 0xEF7F,
	0x826B: 0xEF80,
	0x826C: 0xEF81,
	0x826D: 0xEF82,
	0x826E: 0xEF83,
	0x826F: 0xEF84,
	0x8270: 0xEF85,
	0x8271: 0xEF86,
	0x8272: 0xEF87,
	0x8273: 0xEF88,
	0x8274: 0xEF89,
	0x8275: 0xEF8A,
	0x8276: 0xEF8B,
	0x8277: 0xEF8C,
	0x8278: 0xEF8D,
	0x8279: 0xEF8E,
	0x827A: 0xEF8F,
	0x827B: 0xEF90,
	0x827C: 0xEF91,
	0x827D: 0xEF92,
	0x827E: 0xEF93,
	0x82A1: 0xEF94,
	0x82A2: 0xEF95,
	0x82A3: 0xEF96,
	0x82A4: 0xEF97,
	0x82A5: 0xEF98,
	0x82A6: 0xEF99,
	0x82A7: 0xEF9A,
	0x82A8: 0xEF9B,
	0x82A9: 0xEF9C,
	0x82AA: 0xEF9D,
	0x82AB: 0xEF9E,
	0x82AC: 0xEF9F,
	0x82AD: 0xEFA0,
	0x82AE: 0xEFA1,
	0x82AF: 0xEFA2,
	0x82B0: 0xEFA3,
	0x82B1: 0xEFA4,
	0x82B2: 0xEFA5,
	0x82B3: 0xEFA6,
	0x82B4: 0xEFA7,
	0x82B5: 0xEFA8,
	0x82B6: 0xEFA9,
	0x82B7: 0xEFAA,
	0x82B8: 0xEFAB,
	0x82B9: 0xEFAC,
	0x82BA: 0xEFAD,
	0x82BB: 0xEFAE,
	0x82BC: 0xEFAF,
	0x82BD: 0xEFB0,
	0x82BE: 0xEFB1,
	0x82BF: 0xEFB2,
	0x82C0: 0xEFB3,
	0x82C1: 0xEFB4,
	0x82C2: 0xEFB5,
	0x82C3: 0xEFB6,
	0x82C4: 0xEFB7,
	0x82C5: 0xEFB8,
	0x82C6: 0xEFB9,
	0x82C7: 0xEFBA,
	0x82C8: 0xEFBB,
	0x82C9: 0xEFBC,
	0x82CA: 0xEFBD,
	0x82CB: 0xEFBE,
	0x82CC: 0xEFBF,
	0x82CD: 0xEFC0,
	0x82CE: 0xEFC1,
	0x82CF: 0xEFC2,
	0x82D0: 0xEFC3,
	0x82D1: 0xEFC4,
	0x82D2: 0xEFC5,
	0x82D3: 0xEFC6,
	0x82D4: 0xEFC7,
	0x82D5: 0xEFC8,
	0x82D6: 0xEFC9,
	0x82D7: 0xEFCA,
	0x82D8: 0xEFCB,
	0x82D9: 0xEFCC,
	0x82DA: 0xEFCD,
	0x82DB: 0xEFCE,
	0x82DC: 0xEFCF,
	0x82DD: 0xEFD0,
	0x82DE: 0xEFD1,
	0x82DF: 0xEFD2,
	0x82E0: 0xEFD3,
	0x82E1: 0xEFD4,
	0x82E2: 0xEFD5,
	0x82E3: 0xEFD6,
	0x82E4: 0xEFD7,
	0x82E5: 0xEFD8,
	0x82E6: 0xEFD9,
	0x82E7: 0xEFDA,
	0x82E8: 0xEFDB,
	0x82E9: 0xEFDC,
	0x82EA: 0xEFDD,
	0x82EB: 0xEFDE,
	0x82EC: 0xEFDF,
	0x82ED: 0xEFE0,
	0x82EE: 0xEFE1,
	0x82EF: 0xEFE2,
	0x82F0: 0xEFE3,
	0x82F1: 0xEFE4,
	0x82F2: 0xEFE5,
	0x82F3: 0xEFE6,
	0x82F4: 0xEFE7,
	0x82F5: 0xEFE8,
	0x82F6: 0xEFE9,
	0x82F7: 0xEFEA,
	0x82F8: 0xEFEB,
	0x82F9: 0xEFEC,
	0x82FA: 0xEFED,
	0x82FB: 0xEFEE,
	0x82FC: 0xEFEF,
	0x82FD: 0xEFF0,
	0x82FE: 0xEFF1,
	0x8340: 0xEFF2,
	0x8341: 0xEFF3,
	0x8342: 0xEFF4,
	0x8343: 0xEFF5,
	0x8344: 0xEFF6,
	0x8345: 0xEFF7,
	0x8346: 0xEFF8,
	0x8347: 0xEFF9,
	0x8348: 0xEFFA,
	0x8349: 0xEFFB,
	0x834A: 0xEFFC,
	0x834B: 0xEFFD,
	0x834C: 0xEFFE,
	0x834D: 0xEFFF,
	0x834E: 0xF000,
	0x834F: 0xF001,
	0x8350: 0xF002,
	0x8351: 0xF003,
	0x8352: 0xF004,
	0x8353: 0xF005,
	0x8354: 0xF006,
	0x8355: 0xF007,
	0x8356: 0xF008,
	0x8357: 0xF009,
	0x8358: 0xF00A,
	0x8359: 0xF00B,
	0x835A: 0xF00C,
	0x835B: 0xF00D,
	0x835C: 0xF00E,
	0x835D: 0xF00F,
	0x835E: 0xF010,
	0x835F: 0xF011,
	0x8360: 0xF012,
	0x8361: 0xF013,
	0x8362: 0xF014,
	0x8363: 0xF015,
	0x8364: 0xF016,
	0x8365: 0xF017,
	0x8366: 0xF018,
	0x8367: 0xF019,
	0x8368: 0xF01A,
	0x8369: 0xF01B,
	0x836A: 0xF01C,
	0x836B: 0xF01D,
	0x836C: 0xF01E,
	0x836D: 0xF01F,
	0x836E: 0xF020,
	0x836F: 0xF021,
	0x8370: 0xF022,
	0x8371: 0xF023,
	0x8372: 0xF024,
	0x8373: 0xF025,
	0x8374: 0xF026,
	0x8375: 0xF027,
	0x8376: 0xF028,
	0x8377: 0xF029,
	0x8378: 0xF02A,
	0x8379: 0xF02B,
	0x837A: 0xF02C,
	0x837B: 0xF02D,
	0x837C: 0xF02E,
	0x837D: 0xF02F,
	0x837E: 0xF030,
	0x83A1: 0xF031,
	0x83A2: 0xF032,
	0x83A3: 0xF033,
	0x83A4: 0xF034,
	0x83A5: 0xF035,
	0x83A6: 0xF036,
	0x83A7: 0xF037,
	0x83A8: 0xF038,
	0x83A9: 0xF039,
	0x83AA: 0xF03A,
	0x83AB: 0xF03B,
	0x83AC: 0xF03C,
	0x83AD: 0xF03D,
	0x83AE: 0xF03E,
	0x83AF: 0xF03F,
	0x83B0: 0xF040,
	0x83B1: 0xF041,
	0x83B2: 0xF042,
	0x83B3: 0xF043,
	0x83B4: 0xF044,
	0x83B5: 0xF045,
	0x83B6: 0xF046,
	0x83B7: 0xF047,
	0x83B8: 0xF048,
	0x83B9: 0xF049,
	0x83BA: 0xF04A,
	0x83BB: 0xF04B,
	0x83BC: 0xF04C,
	0x83BD: 0xF04D,
	0x83BE: 0xF04E,
	0x83BF: 0xF04F,
	0x83C0: 0xF050,
	0x83C1: 0xF051,
	0x83C2: 0xF052,
	0x83C3: 0xF053,
	0x83C4: 0xF054,
	0x83C5: 0xF055,
	0x83C6: 0xF056,
	0x83C7: 0xF057,
	0x83C8: 0xF058,
	0x83C9: 0xF059,
	0x83CA: 0xF05A,
	0x83CB: 0xF05B,
	0x83CC: 0xF05C,
	0x83CD: 0xF05D,
	0x83CE: 0xF05E,
	0x83CF: 0xF05F,
	0x83D0: 0xF060,
	0x83D1: 0xF061,
	0x83D2: 0xF062,
	0x83D3: 0xF063,
	0x83D4: 0xF064,
	0x83D5: 0xF065,
	0x83D6: 0xF066,
	0x83D7: 0xF067,
	0x83D8: 0xF068,
	0x83D9: 0xF069,
	0x83DA: 0xF06A,
	0x83DB: 0xF06B,
	0x83DC: 0xF06C,
	0x83DD: 0xF06D,
	0x83DE: 0xF06E,
	0x83DF: 0xF06F,
	0x83E0: 0xF070,
	0x83E1: 0xF071,
	0x83E2: 0xF072,
	0x83E3: 0xF073,
	0x83E4: 0xF074,
	0x83E5: 0xF075,
	0x83E6: 0xF076,
	0x83E7: 0xF077,
	0x83E8: 0xF078,
	0x83E9: 0xF079,
	0x83EA: 0xF07A,
	0x83EB: 0xF07B,
	0x83EC: 0xF07C,
	0x83ED: 0xF07D,
	0x83EE: 0xF07E,
	0x83EF: 0xF07F,
	0x83F0: 0xF080,
	0x83F1: 0xF081,
	0x83F2: 0xF082,
	0x83F3: 0xF083,
	0x83F4: 0xF084,
	0x83F5: 0xF085,
	0x83F6: 0xF086,
	0x83F7: 0xF087,
	0x83F8: 0xF088,
	0x83F9: 0xF089,
	0x83FA: 0xF08A,
	0x83FB: 0xF08B,
	0x83FC: 0xF08C,
	0x83FD: 0xF08D,
	0x83FE: 0xF08E,
	0x8440: 0xF08F,
	0x8441: 0xF090,
	0x8442: 0xF091,
	0x8443: 0xF092,
	0x8444: 0xF093,
	0x8445: 0xF094,
	0x8446: 0xF095,
	0x8447: 0xF096,
	0x8448: 0xF097,
	0x8449: 0xF098,
	0x844A: 0xF099,
	0x844B: 0xF09A,
	0x844C: 0xF09B,
	0x844D: 0xF09C,
	0x844E: 0xF09D,
	0x844F: 0xF09E,
	0x8450: 0xF09F,
	0x8451: 0xF0A0,
	0x8452: 0xF0A1,
	0x8453: 0xF0A2,
	0x8454: 0xF0A3,
	0x8455: 0xF0A4,
	0x8456: 0xF0A5,
	0x8457: 0xF0A6,
	0x8458: 0xF0A7,
	0x8459: 0xF0A8,
	0x845A: 0xF0A9,
	0x845B: 0xF0AA,
	0x845C: 0xF0AB,
	0x845D: 0xF0AC,
	0x845E: 0xF0AD,
	0x845F: 0xF0AE,
	0x8460: 0xF0AF,
	0x8461: 0xF0B0,
	0x8462: 0xF0B1,
	0x8463: 0xF0B2,
	0x8464: 0xF0B3,
	0x8465: 0xF0B4,
	0x8466: 0xF0B5,
	0x8467: 0xF0B6,
	0x8468: 0xF0B7,
	0x8469: 0xF0B8,
	0x846A: 0xF0B9,
	0x846B: 0xF0BA,
	0x846C: 0xF0BB,
	0x846D: 0xF0BC,
	0x846E: 0xF0BD,
	0x846F: 0xF0BE,
	0x8470: 0xF0BF,
	0x8471: 0xF0C0,
	0x8472: 0xF0C1,
	0x8473: 0xF0C2,
	0x8474: 0xF0C3,
	0x8475: 0xF0C4,
	0x8476: 0xF0C5,
	0x8477: 0xF0C6,
	0x8478: 0xF0C7,
	0x8479: 0xF0C8,
	0x847A: 0xF0C9,
	0x847B: 0xF0CA,
	0x847C: 0xF0CB,
	0x847D: 0xF0CC,
	0x847E: 0xF0CD,
	0x84A1: 0xF0CE,
	0x84A2: 0xF0CF,
	0x84A3: 0xF0D0,
	0x84A4: 0xF0D1,
	0x84A5: 0xF0D2,
	0x84A6: 0xF0D3,
	0x84A7: 0xF0D4,
	0x84A8: 0xF0D5,
	0x84A9: 0xF0D6,
	0x84AA: 0xF0D7,
	0x84AB: 0xF0D8,
	0x84AC: 0xF0D9,
	0x84AD: 0xF0DA,
	0x84AE: 0xF0DB,
	0x84AF: 0xF0DC,
	0x84B0: 0xF0DD,
	0x84B1: 0xF0DE,
	0x84B2: 0xF0DF,
	0x84B3: 0xF0E0,
	0x84B4: 0xF0E1,
	0x84B5: 0xF0E2,
	0x84B6: 0xF0E3,
	0x84B7: 0xF0E4,
	0x84B8: 0xF0E5,
	0x84B9: 0xF0E6,
	0x84BA: 0xF0E7,
	0x84BB: 0xF0E8,
	0x84BC: 0xF0E9,
	0x84BD: 0xF0EA,
	0x84BE: 0xF0EB,
	0x84BF: 0xF0EC,
	0x84C0: 0xF0ED,
	0x84C1: 0xF0EE,
	0x84C2: 0xF0EF,
	0x84C3: 0xF0F0,
	0x84C4: 0xF0F1,
	0x84C5: 0xF0F2,
	0x84C6: 0xF0F3,
	0x84C7: 0xF0F4,
	0x84C8: 0xF0F5,
	0x84C9: 0xF0F6,
	0x84CA: 0xF0F7,
	0x84CB: 0xF0F8,
	0x84CC: 0xF0F9,
	0x84CD: 0xF0FA,
	0x84CE: 0xF0FB,
	0x84CF: 0xF0FC,
	0x84D0: 0xF0FD,
	0x84D1: 0xF0FE,
	0x84D2: 0xF0FF,
	0x84D3: 0xF100,
	0x84D4: 0xF101,
	0x84D5: 0xF102,
	0x84D6: 0xF103,
	0x84D7: 0xF104,
	0x84D8: 0xF105,
	0x84D9: 0xF106,
	0x84DA: 0xF107,
	0x84DB: 0xF108,
	0x84DC: 0xF109,
	0x84DD: 0xF10A,
	0x84DE: 0xF10B,
	0x84DF: 0xF10C,
	0x84E0: 0xF10D,
	0x84E1: 0xF10E,
	0x84E2: 0xF10F,
	0x84E3: 0xF110,
	0x84E4: 0xF111,
	0x84E5: 0xF112,
	0x84E6: 0xF113,
	0x84E7: 0xF114,
	0x84E8: 0xF115,
	0x84E9: 0xF116,
	0x84EA: 0xF117,
	0x84EB: 0xF118,
	0x84EC: 0xF119,
	0x84ED: 0xF11A,
	0x84EE: 0xF11B,
	0x84EF: 0xF11C,
	0x84F0: 0xF11D,
	0x84F1: 0xF11E,
	0x84F2: 0xF11F,
	0x84F3: 0xF120,
	0x84F4: 0xF121,
	0x84F5: 0xF122,
	0x84F6: 0xF123,
	0x84F7: 0xF124,
	0x84F8: 0xF125,
	0x84F9: 0xF126,
	0x84FA: 0xF127,
	0x84FB: 0xF128,
	0x84FC: 0xF129,
	0x84FD: 0xF12A,
	0x84FE: 0xF12B,
	0x8540: 0xF12C,
	0x8541: 0xF12D,
	0x8542: 0xF12E,
	0x8543: 0xF12F,
	0x8544: 0xF130,
	0x8545: 0xF131,
	0x8546: 0xF132,
	0x8547: 0xF133,
	0x8548: 0xF134,
	0x8549: 0xF135,
	0x854A: 0xF136,
	0x854B: 0xF137,
	0x854C: 0xF138,
	0x854D: 0xF139,
	0x854E: 0xF13A,
	0x854F: 0xF13B,
	0x8550: 0xF13C,
	0x8551: 0xF13D,
	0x8552: 0xF13E,
	0x8553: 0xF13F,
	0x8554: 0xF140,
	0x8555: 0xF141,
	0x8556: 0xF142,
	0x8557: 0xF143,
	0x8558: 0xF144,
	0x8559: 0xF145,
	0x855A: 0xF146,
	0x855B: 0xF147,
	0x855C: 0xF148,
	0x855D: 0xF149,
	0x855E: 0xF14A,
	0x855F: 0xF14B,
	0x8560: 0xF14C,
	0x8561: 0xF14D,
	0x8562: 0xF14E,
	0x8563: 0xF14F,
	0x8564: 0xF150,
	0x8565: 0xF151,
	0x8566: 0xF152,
	0x8567: 0xF153,
	0x8568: 0xF154,
	0x8569: 0xF155,
	0x856A: 0xF156,
	0x856B: 0xF157,
	0x856C: 0xF158,
	0x856D: 0xF159,
	0x856E: 0xF15A,
	0x856F: 0xF15B,
	0x8570: 0xF15C,
	0x8571: 0xF15D,
	0x8572: 0xF15E,
	0x8573: 0xF15F,
	0x8574: 0xF160,
	0x8575: 0xF161,
	0x8576: 0xF162,
	0x8577: 0xF163,
	0x8578: 0xF164,
	0x8579: 0xF165,
	0x857A: 0xF166,
	0x857B: 0xF167,
	0x857C: 0xF168,
	0x857D: 0xF169,
	0x857E: 0xF16A,
	0x85A1: 0xF16B,
	0x85A2: 0xF16C,
	0x85A3: 0xF16D,
	0x85A4: 0xF16E,
	0x85A5: 0xF16F,
	0x85A6: 0xF170,
	0x85A7: 0xF171,
	0x85A8: 0xF172,
	0x85A9: 0xF173,
	0x85AA: 0xF174,
	0x85AB: 0xF175,
	0x85AC: 0xF176,
	0x85AD: 0xF177,
	0x85AE: 0xF178,
	0x85AF: 0xF179,
	0x85B0: 0xF17A,
	0x85B1: 0xF17B,
	0x85B2: 0xF17C,
	0x85B3: 0xF17D,
	0x85B4: 0xF17E,
	0x85B5: 0xF17F,
	0x85B6: 0xF180,
	0x85B7: 0xF181,
	0x85B8: 0xF182,
	0x85B9: 0xF183,
	0x85BA: 0xF184,
	0x85BB: 0xF185,
	0x85BC: 0xF186,
	0x85BD: 0xF187,
	0x85BE: 0xF188,
	0x85BF: 0xF189,
	0x85C0: 0xF18A,
	0x85C1: 0xF18B,
	0x85C2: 0xF18C,
	0x85C3: 0xF18D,
	0x85C4: 0xF18E,
	0x85C5: 0xF18F,
	0x85C6: 0xF190,
	0x85C7: 0xF191,
	0x85C8: 0xF192,
	0x85C9: 0xF193,
	0x85CA: 0xF194,
	0x85CB: 0xF195,
	0x85CC: 0xF196,
	0x85CD: 0xF197,
	0x85CE: 0xF198,
	0x85CF: 0xF199,
	0x85D0: 0xF19A,
	0x85D1: 0xF19B,
	0x85D2: 0xF19C,
	0x85D3: 0xF19D,
	0x85D4: 0xF19E,
	0x85D5: 0xF19F,
	0x85D6: 0xF1A0,
	0x85D7: 0xF1A1,
	0x85D8: 0xF1A2,
	0x85D9: 0xF1A3,
	0x85DA: 0xF1A4,
	0x85DB: 0xF1A5,
	0x85DC: 0xF1A6,
	0x85DD: 0xF1A7,
	0x85DE: 0xF1A8,
	0x85DF: 0xF1A9,
	0x85E0: 0xF1AA,
	0x85E1: 0xF1AB,
	0x85E2: 0xF1AC,
	0x85E3: 0xF1AD,
	0x85E4: 0xF1AE,
	0x85E5: 0xF1AF,
	0x85E6: 0xF1B0,
	0x85E7: 0xF1B1,
	0x85E8: 0xF1B2,
	0x85E9: 0xF1B3,
	0x85EA: 0xF1B4,
	0x85EB: 0xF1B5,
	0x85EC: 0xF1B6,
	0x85ED: 0xF1B7,
	0x85EE: 0xF1B8,
	0x85EF: 0xF1B9,
	0x85F0: 0xF1BA,
	0x85F1: 0xF1BB,
	0x85F2: 0xF1BC,
	0x85F3: 0xF1BD,
	0x85F4: 0xF1BE,
	0x85F5: 0xF1BF,
	0x85F6: 0xF1C0,
	0x85F7: 0xF1C1,
	0x85F8: 0xF1C2,
	0x85F9: 0xF1C3,
	0x85FA: 0xF1C4,
	0x85FB: 0xF1C5,
	0x85FC: 0xF1C6,
	0x85FD: 0xF1C7,
	0x85FE: 0xF1C8,
	0x8640: 0xF1C9,
	0x8641: 0xF1CA,
	0x8642: 0xF1CB,
	0x8643: 0xF1CC,
	0x8644: 0xF1CD,
	0x8645: 0xF1CE,
	0x8646: 0xF1CF,
	0x8647: 0xF1D0,
	0x8648: 0xF1D1,
	0x8649: 0xF1D2,
	0x864A: 0xF1D3,
	0x864B: 0xF1D4,
	0x864C: 0xF1D5,
	0x864D: 0xF1D6,
	0x864E: 0xF1D7,
	0x864F: 0xF1D8,
	0x8650: 0xF1D9,
	0x8651: 0xF1DA,
	0x8652: 0xF1DB,
	0x8653: 0xF1DC,
	0x8654: 0xF1DD,
	0x8655: 0xF1DE,
	0x8656: 0xF1DF,
	0x8657: 0xF1E0,
	0x8658: 0xF1E1,
	0x8659: 0xF1E2,
	0x865A: 0xF1E3,
	0x865B: 0xF1E4,
	0x865C: 0xF1E5,
	0x865D: 0xF1E6,
	0x865E: 0xF1E7,
	0x865F: 0xF1E8,
	0x8660: 0xF1E9,
	0x8661: 0xF1EA,
	0x8662: 0xF1EB,
	0x8663: 0xF1EC,
	0x8664: 0xF1ED,
	0x8665: 0xF1EE,
	0x8666: 0xF1EF,
	0x8667: 0xF1F0,
	0x8668: 0xF1F1,
	0x8669: 0xF1F2,
	0x866A: 0xF1F3,
	0x866B: 0xF1F4,
	0x866C: 0xF1F5,
	0x866D: 0xF1F6,
	0x866E: 0xF1F7,
	0x866F: 0xF1F8,
	0x8670: 0xF1F9,
	0x8671: 0xF1FA,
	0x8672: 0xF1FB,
	0x8673: 0xF1FC,
	0x8674: 0xF1FD,
	0x8675: 0xF1FE,
	0x8676: 0xF1FF,
	0x8677: 0xF200,
	0x8678: 0xF201,
	0x8679: 0xF202,
	0x867A: 0xF203,
	0x867B: 0xF204,
	0x867C: 0xF205,
	0x867D: 0xF206,
	0x867E: 0xF207,
	0x86A1: 0xF208,
	0x86A2: 0xF209,
	0x86A3: 0xF20A,
	0x86A4: 0xF20B,
	0x86A5: 0xF20C,
	0x86A6: 0xF20D,
	0x86A7: 0xF20E,
	0x86A8: 0xF20F,
	0x86A9: 0xF210,
	0x86AA: 0xF211,
	0x86AB: 0xF212,
	0x86AC: 0xF213,
	0x86AD: 0xF214,
	0x86AE: 0xF215,
	0x86AF: 0xF216,
	0x86B0: 0xF217,
	0x86B1: 0xF218,
	0x86B2: 0xF219,
	0x86B3: 0xF21A,
	0x86B4: 0xF21B,
	0x86B5: 0xF21C,
	0x86B6: 0xF21D,
	0x86B7: 0xF21E,
	0x86B8: 0xF21F,
	0x86B9: 0xF220,
	0x86BA: 0xF221,
	0x86BB: 0xF222,
	0x86BC: 0xF223,
	0x86BD: 0xF224,
	0x86BE: 0xF225,
	0x86BF: 0xF226,
	0x86C0: 0xF227,
	0x86C1: 0xF228,
	0x86C2: 0xF229,
	0x86C3: 0xF22A,
	0x86C4: 0xF22B,
	0x86C5: 0xF22C,
	0x86C6: 0xF22D,
	0x86C7: 0xF22E,
	0x86C8: 0xF22F,
	0x86C9: 0xF230,
	0x86CA: 0xF231,
	0x86CB: 0xF232,
	0x86CC: 0xF233,
	0x86CD: 0xF234,
	0x86CE: 0xF235,
	0x86CF: 0xF236,
	0x86D0: 0xF237,
	0x86D1: 0xF238,
	0x86D2: 0xF239,
	0x86D3: 0xF23A,
	0x86D4: 0xF23B,
	0x86D5: 0xF23C,
	0x86D6: 0xF23D,
	0x86D7: 0xF23E,
	0x86D8: 0xF23F,
	0x86D9: 0xF240,
	0x86DA: 0xF241,
	0x86DB: 0xF242,
	0x86DC: 0xF243,
	0x86DD: 0xF244,
	0x86DE: 0xF245,
	0x86DF: 0xF246,
	0x86E0: 0xF247,
	0x86E1: 0xF248,
	0x86E2: 0xF249,
	0x86E3: 0xF24A,
	0x86E4: 0xF24B,
	0x86E5: 0xF24C,
	0x86E6: 0xF24D,
	0x86E7: 0xF24E,
	0x86E8: 0xF24F,
	0x86E9: 0xF250,
	0x86EA: 0xF251,
	0x86EB: 0xF252,
	0x86EC: 0xF253,
	0x86ED: 0xF254,
	0x86EE: 0xF255,
	0x86EF: 0xF256,
	0x86F0: 0xF257,
	0x86F1: 0xF258,
	0x86F2: 0xF259,
	0x86F3: 0xF25A,
	0x86F4: 0xF25B,
	0x86F5: 0xF25C,
	0x86F6: 0xF25D,
	0x86F7: 0xF25E,
	0x86F8: 0xF25F,
	0x86F9: 0xF260,
	0x86FA: 0xF261,
	0x86FB: 0xF262,
	0x86FC: 0xF263,
	0x86FD: 0xF264,
	0x86FE: 0xF265,
	0x8740: 0xF266,
	0x8741: 0xF267,
	0x8742: 0xF268,
	0x8743: 0xF269,
	0x8744: 0xF26A,
	0x8745: 0xF26B,
	0x8746: 0xF26C,
	0x8747: 0xF26D,
	0x8748: 0xF26E,
	0x8749: 0xF26F,
	0x874A: 0xF270,
	0x874B: 0xF271,
	0x874C: 0xF272,
	0x874D: 0xF273,
	0x874E: 0xF274,
	0x874F: 0xF275,
	0x8750: 0xF276,
	0x8751: 0xF277,
	0x8752: 0xF278,
	0x8753: 0xF279,
	0x8754: 0xF27A,
	0x8755: 0xF27B,
	0x8756: 0xF27C,
	0x8757: 0xF27D,
	0x8758: 0xF27E,
	0x8759: 0xF27F,
	0x875A: 0xF280,
	0x875B: 0xF281,
	0x875C: 0xF282,
	0x875D: 0xF283,
	0x875E: 0xF284,
	0x875F: 0xF285,
	0x8760: 0xF286,
	0x8761: 0xF287,
	0x8762: 0xF288,
	0x8763: 0xF289,
	0x8764: 0xF28A,
	0x8765: 0xF28B,
	0x8766: 0xF28C,
	0x8767: 0xF28D,
	0x8768: 0xF28E,
	0x8769: 0xF28F,
	0x876A: 0xF290,
	0x876B: 0xF291,
	0x876C: 0xF292,
	0x876D: 0xF293,
	0x876E: 0xF294,
	0x876F: 0xF295,
	0x8770: 0xF296,
	0x8771: 0xF297,
	0x8772: 0xF298,
	0x8773: 0xF299,
	0x8774: 0xF29A,
	0x8775: 0xF29B,
	0x8776: 0xF29C,
	0x8777: 0xF29D,
	0x8778: 0xF29E,
	0x8779: 0xF29F,
	0x877A: 0xF2A0,
	0x877B: 0xF2A1,
	0x877C: 0xF2A2,
	0x877D: 0xF2A3,
	0x877E: 0xF2A4,
	0x87A1: 0xF2A5,
	0x87A2: 0xF2A6,
	0x87A3: 0xF2A7,
	0x87A4: 0xF2A8,
	0x87A5: 0xF2A9,
	0x87A6: 0xF2AA,
	0x87A7: 0xF2AB,
	0x87A8: 0xF2AC,
	0x87A9: 0xF2AD,
	0x87AA: 0xF2AE,
	0x87AB: 0xF2AF,
	0x87AC: 0xF2B0,
	0x87AD: 0xF2B1,
	0x87AE: 0xF2B2,
	0x87AF: 0xF2B3,
	0x87B0: 0xF2B4,
	0x87B1: 0xF2B5,
	0x87B2: 0xF2B6,
	0x87B3: 0xF2B7,
	0x87B4: 0xF2B8,
	0x87B5: 0xF2B9,
	0x87B6: 0xF2BA,
	0x87B7: 0xF2BB,
	0x87B8: 0xF2BC,
	0x87B9: 0xF2BD,
	0x87BA: 0xF2BE,
	0x87BB: 0xF2BF,
	0x87BC: 0xF2C0,
	0x87BD: 0xF2C1,
	0x87BE: 0xF2C2,
	0x87BF: 0xF2C3,
	0x87C0: 0xF2C4,
	0x87C1: 0xF2C5,
	0x87C2: 0xF2C6,
	0x87C3: 0xF2C7,
	0x87C4: 0xF2C8,
	0x87C5: 0xF2C9,
	0x87C6: 0xF2CA,
	0x87C7: 0xF2CB,
	0x87C8: 0xF2CC,
	0x87C9: 0xF2CD,
	0x87CA: 0xF2CE,
	0x87CB: 0xF2CF,
	0x87CC: 0xF2D0,
	0x87CD: 0xF2D1,
	0x87CE: 0xF2D2,
	0x87CF: 0xF2D3,
	0x87D0: 0xF2D4,
	0x87D1: 0xF2D5,
	0x87D2: 0xF2D6,
	0x87D3: 0xF2D7,
	0x87D4: 0xF2D8,
	0x87D5: 0xF2D9,
	0x87D6: 0xF2DA,
	0x87D7: 0xF2DB,
	0x87D8: 0xF2DC,
	0x87D9: 0xF2DD,
	0x87DA: 0xF2DE,
	0x87DB: 0xF2DF,
	0x87DC: 0xF2E0,
	0x87DD: 0xF2E1,
	0x87DE: 0xF2E2,
	0x87DF: 0xF2E3,
	0x87E0: 0xF2E4,
	0x87E1: 0xF2E5,
	0x87E2: 0xF2E6,
	0x87E3: 0xF2E7,
	0x87E4: 0xF2E8,
	0x87E5: 0xF2E9,
	0x87E6: 0xF2EA,
	0x87E7: 0xF2EB,
	0x87E8: 0xF2EC,
	0x87E9: 0xF2ED,
	0x87EA: 0xF2EE,
	0x87EB: 0xF2EF,
	0x87EC: 0xF2F0,
	0x87ED: 0xF2F1,
	0x87EE: 0xF2F2,
	0x87EF: 0xF2F3,
	0x87F0: 0xF2F4,
	0x87F1: 0xF2F5,
	0x87F2: 0xF2F6,
	0x87F3: 0xF2F7,
	0x87F4: 0xF2F8,
	0x87F5: 0xF2F9,
	0x87F6: 0xF2FA,
	0x87F7: 0xF2FB,
	0x87F8: 0xF2FC,
	0x87F9: 0xF2FD,
	0x87FA: 0xF2FE,
	0x87FB: 0xF2FF,
	0x87FC: 0xF300,
	0x87FD: 0xF301,
	0x87FE: 0xF302,
	0x8840: 0xF303,
	0x8841: 0xF304,
	0x8842: 0xF305,
	0x8843: 0xF306,
	0x8844: 0xF307,
	0x8845: 0xF308,
	0x8846: 0xF309,
	0x8847: 0xF30A,
	0x8848: 0xF30B,
	0x8849: 0xF30C,
	0x884A: 0xF30D,
	0x884B: 0xF30E,
	0x884C: 0xF30F,
	0x884D: 0xF310,
	0x884E: 0xF311,
	0x884F: 0xF312,
	0x8850: 0xF313,
	0x8851: 0xF314,
	0x8852: 0xF315,
	0x8853: 0xF316,
	0x8854: 0xF317,
	0x8855: 0xF318,
	0x8856: 0xF319,
	0x8857: 0xF31A,
	0x8858: 0xF31B,
	0x8859: 0xF31C,
	0x885A: 0xF31D,
	0x885B: 0xF31E,
	0x885C: 0xF31F,
	0x885D: 0xF320,
	0x885E: 0xF321,
	0x885F: 0xF322,
	0x8860: 0xF323,
	0x8861: 0xF324,
	0x8862: 0xF325,
	0x8863: 0xF326,
	0x8864: 0xF327,
	0x8865: 0xF328,
	0x8866: 0xF329,
	0x8867: 0xF32A,
	0x8868: 0xF32B,
	0x8869: 0xF32C,
	0x886A: 0xF32D,
	0x886B: 0xF32E,
	0x886C: 0xF32F,
	0x886D: 0xF330,
	0x886E: 0xF331,
	0x886F: 0xF332,
	0x8870: 0xF333,
	0x8871: 0xF334,
	0x8872: 0xF335,
	0x8873: 0xF336,
	0x8874: 0xF337,
	0x8875: 0xF338,
	0x8876: 0xF339,
	0x8877: 0xF33A,
	0x8878: 0xF33B,
	0x8879: 0xF33C,
	0x887A: 0xF33D,
	0x887B: 0xF33E,
	0x887C: 0xF33F,
	0x887D: 0xF340,
	0x887E: 0xF341,
	0x88A1: 0xF342,
	0x88A2: 0xF343,
	0x88A3: 0xF344,
	0x88A4: 0xF345,
	0x88A5: 0xF346,
	0x88A6: 0xF347,
	0x88A7: 0xF348,
	0x88A8: 0xF349,
	0x88A9: 0xF34A,
	0x88AA: 0xF34B,
	0x88AB: 0xF34C,
	0x88AC: 0xF34D,
	0x88AD: 0xF34E,
	0x88AE: 0xF34F,
	0x88AF: 0xF350,
	0x88B0: 0xF351,
	0x88B1: 0xF352,
	0x88B2: 0xF353,
	0x88B3: 0xF354,
	0x88B4: 0xF355,
	0x88B5: 0xF356,
	0x88B6: 0xF357,
	0x88B7: 0xF358,
	0x88B8: 0xF359,
	0x88B9: 0xF35A,
	0x88BA: 0xF35B,
	0x88BB: 0xF35C,
	0x88BC: 0xF35D,
	0x88BD: 0xF35E,
	0x88BE: 0xF35F,
	0x88BF: 0xF360,
	0x88C0: 0xF361,
	0x88C1: 0xF362,
	0x88C2: 0xF363,
	0x88C3: 0xF364,
	0x88C4: 0xF365,
	0x88C5: 0xF366,
	0x88C6: 0xF367,
	0x88C7: 0xF368,
	0x88C8: 0xF369,
	0x88C9: 0xF36A,
	0x88CA: 0xF36B,
	0x88CB: 0xF36C,
	0x88CC: 0xF36D,
	0x88CD: 0xF36E,
	0x88CE: 0xF36F,
	0x88CF: 0xF370,
	0x88D0: 0xF371,
	0x88D1: 0xF372,
	0x88D2: 0xF373,
	0x88D3: 0xF374,
	0x88D4: 0xF375,
	0x88D5: 0xF376,
	0x88D6: 0xF377,
	0x88D7: 0xF378,
	0x88D8: 0xF379,
	0x88D9: 0xF37A,
	0x88DA: 0xF37B,
	0x88DB: 0xF37C,
	0x88DC: 0xF37D,
	0x88DD: 0xF37E,
	0x88DE: 0xF37F,
	0x88DF: 0xF380,
	0x88E0: 0xF381,
	0x88E1: 0xF382,
	0x88E2: 0xF383,
	0x88E3: 0xF384,
	0x88E4: 0xF385,
	0x88E5: 0xF386,
	0x88E6: 0xF387,
	0x88E7: 0xF388,
	0x88E8: 0xF389,
	0x88E9: 0xF38A,
	0x88EA: 0xF38B,
	0x88EB: 0xF38C,
	0x88EC: 0xF38D,
	0x88ED: 0xF38E,
	0x88EE: 0xF38F,
	0x88EF: 0xF390,
	0x88F0: 0xF391,
	0x88F1: 0xF392,
	0x88F2: 0xF393,
	0x88F3: 0xF394,
	0x88F4: 0xF395,
	0x88F5: 0xF396,
	0x88F6: 0xF397,
	0x88F7: 0xF398,
	0x88F8: 0xF399,
	0x88F9: 0xF39A,
	0x88FA: 0xF39B,
	0x88FB: 0xF39C,
	0x88FC: 0xF39D,
	0x88FD: 0xF39E,
	0x88FE: 0xF39F,
	0x8940: 0xF3A0,
	0x8941: 0xF3A1,
	0x8942: 0xF3A2,
	0x8943: 0xF3A3,
	0x8944: 0xF3A4,
	0x8945: 0xF3A5,
	0x8946: 0xF3A6,
	0x8947: 0xF3A7,
	0x8948: 0xF3A8,
	0x8949: 0xF3A9,
	0x894A: 0xF3AA,
	0x894B: 0xF3AB,
	0x894C: 0xF3AC,
	0x894D: 0xF3AD,
	0x894E: 0xF3AE,
	0x894F: 0xF3AF,
	0x8950: 0xF3B0,
	0x8951: 0xF3B1,
	0x8952: 0xF3B2,
	0x8953: 0xF3B3,
	0x8954: 0xF3B4,
	0x8955: 0xF3B5,
	0x8956: 0xF3B6,
	0x8957: 0xF3B7,
	0x8958: 0xF3B8,
	0x8959: 0xF3B9,
	0x895A: 0xF3BA,
	0x895B: 0xF3BB,
	0x895C: 0xF3BC,
	0x895D: 0xF3BD,
	0x895E: 0xF3BE,
	0x895F: 0xF3BF,
	0x8960: 0xF3C0,
	0x8961: 0xF3C1,
	0x8962: 0xF3C2,
	0x8963: 0xF3C3,
	0x8964: 0xF3C4,
	0x8965: 0xF3C5,
	0x8966: 0xF3C6,
	0x8967: 0xF3C7,
	0x8968: 0xF3C8,
	0x8969: 0xF3C9,
	0x896A: 0xF3CA,
	0x896B: 0xF3CB,
	0x896C: 0xF3CC,
	0x896D: 0xF3CD,
	0x896E: 0xF3CE,
	0x896F: 0xF3CF,
	0x8970: 0xF3D0,
	0x8971: 0xF3D1,
	0x8972: 0xF3D2,
	0x8973: 0xF3D3,
	0x8974: 0xF3D4,
	0x8975: 0xF3D5,
	0x8976: 0xF3D6,
	0x8977: 0xF3D7,
	0x8978: 0xF3D8,
	0x8979: 0xF3D9,
	0x897A: 0xF3DA,
	0x897B: 0xF3DB,
	0x897C: 0xF3DC,
	0x897D: 0xF3DD,
	0x897E: 0xF3DE,
	0x89A1: 0xF3DF,
	0x89A2: 0xF3E0,
	0x89A3: 0xF3E1,
	0x89A4: 0xF3E2,
	0x89A5: 0xF3E3,
	0x89A6: 0xF3E4,
	0x89A7: 0xF3E5,
	0x89A8: 0xF3E6,
	0x89A9: 0xF3E7,
	0x89AA: 0xF3E8,
	0x89AB: 0xF3E9,
	0x89AC: 0xF3EA,
	0x89AD: 0xF3EB,
	0x89AE: 0xF3EC,
	0x89AF: 0xF3ED,
	0x89B0: 0xF3EE,
	0x89B1: 0xF3EF,
	0x89B2: 0xF3F0,
	0x89B3: 0xF3F1,
	0x89B4: 0xF3F2,
	0x89B5: 0xF3F3,
	0x89B6: 0xF3F4,
	0x89B7: 0xF3F5,
	0x89B8: 0xF3F6,
	0x89B9: 0xF3F7,
	0x89BA: 0xF3F8,
	0x89BB: 0xF3F9,
	0x89BC: 0xF3FA,
	0x89BD: 0xF3FB,
	0x89BE: 0xF3FC,
	0x89BF: 0xF3FD,
	0x89C0: 0xF3FE,
	0x89C1: 0xF3FF,
	0x89C2: 0xF400,
	0x89C3: 0xF401,
	0x89C4: 0xF402,
	0x89C5: 0xF403,
	0x89C6: 0xF404,
	0x89C7: 0xF405,
	0x89C8: 0xF406,
	0x89C9: 0xF407,
	0x89CA: 0xF408,
	0x89CB: 0xF409,
	0x89CC: 0xF40A,
	0x89CD: 0xF40B,
	0x89CE: 0xF40C,
	0x89CF: 0xF40D,
	0x89D0: 0xF40E,
	0x89D1: 0xF40F,
	0x89D2: 0xF410,
	0x89D3: 0xF411,
	0x89D4: 0xF412,
	0x89D5: 0xF413,
	0x89D6: 0xF414,
	0x89D7: 0xF415,
	0x89D8: 0xF416,
	0x89D9: 0xF417,
	0x89DA: 0xF418,
	0x89DB: 0xF419,
	0x89DC: 0xF41A,
	0x89DD: 0xF41B,
	0x89DE: 0xF41C,
	0x89DF: 0xF41D,
	0x89E0: 0xF41E,
	0x89E1: 0xF41F,
	0x89E2: 0xF420,
	0x89E3: 0xF421,
	0x89E4: 0xF422,
	0x89E5: 0xF423,
	0x89E6: 0xF424,
	0x89E7: 0xF425,
	0x89E8: 0xF426,
	0x89E9: 0xF427,
	0x89EA: 0xF428,
	0x89EB: 0xF429,
	0x89EC: 0xF42A,
	0x89ED: 0xF42B,
	0x89EE: 0xF42C,
	0x89EF: 0xF42D,
	0x89F0: 0xF42E,
	0x89F1: 0xF42F,
	0x89F2: 0xF430,
	0x89F3: 0xF431,
	0x89F4: 0xF432,
	0x89F5: 0xF433,
	0x89F6: 0xF434,
	0x89F7: 0xF435,
	0x89F8: 0xF436,
	0x89F9: 0xF437,
	0x89FA: 0xF438,
	0x89FB: 0xF439,
	0x89FC: 0xF43A,
	0x89FD: 0xF43B,
	0x89FE: 0xF43C,
	0x8A40: 0xF43D,
	0x8A41: 0xF43E,
	0x8A42: 0xF43F,
	0x8A43: 0xF440,
	0x8A44: 0xF441,
	0x8A45: 0xF442,
	0x8A46: 0xF443,
	0x8A47: 0xF444,
	0x8A48: 0xF445,
	0x8A49: 0xF446,
	0x8A4A: 0xF447,
	0x8A4B: 0xF448,
	0x8A4C: 0xF449,
	0x8A4D: 0xF44A,
	0x8A4E: 0xF44B,
	0x8A4F: 0xF44C,
	0x8A50: 0xF44D,
	0x8A51: 0xF44E,
	0x8A52: 0xF44F,
	0x8A53: 0xF450,
	0x8A54: 0xF451,
	0x8A55: 0xF452,
	0x8A56: 0xF453,
	0x8A57: 0xF454,
	0x8A58: 0xF455,
	0x8A59: 0xF456,
	0x8A5A: 0xF457,
	0x8A5B: 0xF458,
	0x8A5C: 0xF459,
	0x8A5D: 0xF45A,
	0x8A5E: 0xF45B,
	0x8A5F: 0xF45C,
	0x8A60: 0xF45D,
	0x8A61: 0xF45E,
	0x8A62: 0xF45F,
	0x8A63: 0xF460,
	0x8A64: 0xF461,
	0x8A65: 0xF462,
	0x8A66: 0xF463,
	0x8A67: 0xF464,
	0x8A68: 0xF465,
	0x8A69: 0xF466,
	0x8A6A: 0xF467,
	0x8A6B: 0xF468,
	0x8A6C: 0xF469,
	0x8A6D: 0xF46A,
	0x8A6E: 0xF46B,
	0x8A6F: 0xF46C,
	0x8A70: 0xF46D,
	0x8A71: 0xF46E,
	0x8A72: 0xF46F,
	0x8A73: 0xF470,
	0x8A74: 0xF471,
	0x8A75: 0xF472,
	0x8A76: 0xF473,
	0x8A77: 0xF474,
	0x8A78: 0xF475,
	0x8A79: 0xF476,
	0x8A7A: 0xF477,
	0x8A7B: 0xF478,
	0x8A7C: 0xF479,
	0x8A7D: 0xF47A,
	0x8A7E: 0xF47B,
	0x8AA1: 0xF47C,
	0x8AA2: 0xF47D,
	0x8AA3: 0xF47E,
	0x8AA4: 0xF47F,
	0x8AA5: 0xF480,
	0x8AA6: 0xF481,
	0x8AA7: 0xF482,
	0x8AA8: 0xF483,
	0x8AA9: 0xF484,
	0x8AAA: 0xF485,
	0x8AAB: 0xF486,
	0x8AAC: 0xF487,
	0x8AAD: 0xF488,
	0x8AAE: 0xF489,
	0x8AAF: 0xF48A,
	0x8AB0: 0xF48B,
	0x8AB1: 0xF48C,
	0x8AB2: 0xF48D,
	0x8AB3: 0xF48E,
	0x8AB4: 0xF48F,
	0x8AB5: 0xF490,
	0x8AB6: 0xF491,
	0x8AB7: 0xF492,
	0x8AB8: 0xF493,
	0x8AB9: 0xF494,
	0x8ABA: 0xF495,
	0x8ABB: 0xF496,
	0x8ABC: 0xF497,
	0x8ABD: 0xF498,
	0x8ABE: 0xF499,
	0x8ABF: 0xF49A,
	0x8AC0: 0xF49B,
	0x8AC1: 0xF49C,
	0x8AC2: 0xF49D,
	0x8AC3: 0xF49E,
	0x8AC4: 0xF49F,
	0x8AC5: 0xF4A0,
	0x8AC6: 0xF4A1,
	0x8AC7: 0xF4A2,
	0x8AC8: 0xF4A3,
	0x8AC9: 0xF4A4,
	0x8ACA: 0xF4A5,
	0x8ACB: 0xF4A6,
	0x8ACC: 0xF4A7,
	0x8ACD: 0xF4A8,
	0x8ACE: 0xF4A9,
	0x8ACF: 0xF4AA,
	0x8AD0: 0xF4AB,
	0x8AD1: 0xF4AC,
	0x8AD2: 0xF4AD,
	0x8AD3: 0xF4AE,
	0x8AD4: 0xF4AF,
	0x8AD5: 0xF4B0,
	0x8AD6: 0xF4B1,
	0x8AD7: 0xF4B2,
	0x8AD8: 0xF4B3,
	0x8AD9: 0xF4B4,
	0x8ADA: 0xF4B5,
	0x8ADB: 0xF4B6,
	0x8ADC: 0xF4B7,
	0x8ADD: 0xF4B8,
	0x8ADE: 0xF4B9,
	0x8ADF: 0xF4BA,
	0x8AE0: 0xF4BB,
	0x8AE1: 0xF4BC,
	0x8AE2: 0xF4BD,
	0x8AE3: 0xF4BE,
	0x8AE4: 0xF4BF,
	0x8AE5: 0xF4C0,
	0x8AE6: 0xF4C1,
	0x8AE7: 0xF4C2,
	0x8AE8: 0xF4C3,
	0x8AE9: 0xF4C4,
	0x8AEA: 0xF4C5,
	0x8AEB: 0xF4C6,
	0x8AEC: 0xF4C7,
	0x8AED: 0xF4C8,
	0x8AEE: 0xF4C9,
	0x8AEF: 0xF4CA,
	0x8AF0: 0xF4CB,
	0x8AF1: 0xF4CC,
	0x8AF2: 0xF4CD,
	0x8AF3: 0xF4CE,
	0x8AF4: 0xF4CF,
	0x8AF5: 0xF4D0,
	0x8AF6: 0xF4D1,
	0x8AF7: 0xF4D2,
	0x8AF8: 0xF4D3,
	0x8AF9: 0xF4D4,
	0x8AFA: 0xF4D5,
	0x8AFB: 0xF4D6,
	0x8AFC: 0xF4D7,
	0x8AFD: 0xF4D8,
	0x8AFE: 0xF4D9,
	0x8B40: 0xF4DA,
	0x8B41: 0xF4DB,
	0x8B42: 0xF4DC,
	0x8B43: 0xF4DD,
	0x8B44: 0xF4DE,
	0x8B45: 0xF4DF,
	0x8B46: 0xF4E0,
	0x8B47: 0xF4E1,
	0x8B48: 0xF4E2,
	0x8B49: 0xF4E3,
	0x8B4A: 0xF4E4,
	0x8B4B: 0xF4E5,
	0x8B4C: 0xF4E6,
	0x8B4D: 0xF4E7,
	0x8B4E: 0xF4E8,
	0x8B4F: 0xF4E9,
	0x8B50: 0xF4EA,
	0x8B51: 0xF4EB,
	0x8B52: 0xF4EC,
	0x8B53: 0xF4ED,
	0x8B54: 0xF4EE,
	0x8B55: 0xF4EF,
	0x8B56: 0xF4F0,
	0x8B57: 0xF4F1,
	0x8B58: 0xF4F2,
	0x8B59: 0xF4F3,
	0x8B5A: 0xF4F4,
	0x8B5B: 0xF4F5,
	0x8B5C: 0xF4F6,
	0x8B5D: 0xF4F7,
	0x8B5E: 0xF4F8,
	0x8B5F: 0xF4F9,
	0x8B60: 0xF4FA,
	0x8B61: 0xF4FB,
	0x8B62: 0xF4FC,
	0x8B63: 0xF4FD,
	0x8B64: 0xF4FE,
	0x8B65: 0xF4FF,
	0x8B66: 0xF500,
	0x8B67: 0xF501,
	0x8B68: 0xF502,
	0x8B69: 0xF503,
	0x8B6A: 0xF504,
	0x8B6B: 0xF505,
	0x8B6C: 0xF506,
	0x8B6D: 0xF507,
	0x8B6E: 0xF508,
	0x8B6F: 0xF509,
	0x8B70: 0xF50A,
	0x8B71: 0xF50B,
	0x8B72: 0xF50C,
	0x8B73: 0xF50D,
	0x8B74: 0xF50E,
	0x8B75: 0xF50F,
	0x8B76: 0xF510,
	0x8B77: 0xF511,
	0x8B78: 0xF512,
	0x8B79: 0xF513,
	0x8B7A: 0xF514,
	0x8B7B: 0xF515,
	0x8B7C: 0xF516,
	0x8B7D: 0xF517,
	0x8B7E: 0xF518,
	0x8BA1: 0xF519,
	0x8BA2: 0xF51A,
	0x8BA3: 0xF51B,
	0x8BA4: 0xF51C,
	0x8BA5: 0xF51D,
	0x8BA6: 0xF51E,
	0x8BA7: 0xF51F,
	0x8BA8: 0xF520,
	0x8BA9: 0xF521,
	0x8BAA: 0xF522,
	0x8BAB: 0xF523,
	0x8BAC: 0xF524,
	0x8BAD: 0xF525,
	0x8BAE: 0xF526,
	0x8BAF: 0xF527,
	0x8BB0: 0xF528,
	0x8BB1: 0xF529,
	0x8BB2: 0xF52A,
	0x8BB3: 0xF52B,
	0x8BB4: 0xF52C,
	0x8BB5: 0xF52D,
	0x8BB6: 0xF52E,
	0x8BB7: 0xF52F,
	0x8BB8: 0xF530,
	0x8BB9: 0xF531,
	0x8BBA: 0xF532,
	0x8BBB: 0xF533,
	0x8BBC: 0xF534,
	0x8BBD: 0xF535,
	0x8BBE: 0xF536,
	0x8BBF: 0xF537,
	0x8BC0: 0xF538,
	0x8BC1: 0xF539,
	0x8BC2: 0xF53A,
	0x8BC3: 0xF53B,
	0x8BC4: 0xF53C,
	0x8BC5: 0xF53D,
	0x8BC6: 0xF53E,
	0x8BC7: 0xF53F,
	0x8BC8: 0xF540,
	0x8BC9: 0xF541,
	0x8BCA: 0xF542,
	0x8BCB: 0xF543,
	0x8BCC: 0xF544,
	0x8BCD: 0xF545,
	0x8BCE: 0xF546,
	0x8BCF: 0xF547,
	0x8BD0: 0xF548,
	0x8BD1: 0xF549,
	0x8BD2: 0xF54A,
	0x8BD3: 0xF54B,
	0x8BD4: 0xF54C,
	0x8BD5: 0xF54D,
	0x8BD6: 0xF54E,
	0x8BD7: 0xF54F,
	0x8BD8: 0xF550,
	0x8BD9: 0xF551,
	0x8BDA: 0xF552,
	0x8BDB: 0xF553,
	0x8BDC: 0xF554,
	0x8BDD: 0xF555,
	0x8BDE: 0xF556,
	0x8BDF: 0xF557,
	0x8BE0: 0xF558,
	0x8BE1: 0xF559,
	0x8BE2: 0xF55A,
	0x8BE3: 0xF55B,
	0x8BE4: 0xF55C,
	0x8BE5: 0xF55D,
	0x8BE6: 0xF55E,
	0x8BE7: 0xF55F,
	0x8BE8: 0xF560,
	0x8BE9: 0xF561,
	0x8BEA: 0xF562,
	0x8BEB: 0xF563,
	0x8BEC: 0xF564,
	0x8BED: 0xF565,
	0x8BEE: 0xF566,
	0x8BEF: 0xF567,
	0x8BF0: 0xF568,
	0x8BF1: 0xF569,
	0x8BF2: 0xF56A,
	0x8BF3: 0xF56B,
	0x8BF4: 0xF56C,
	0x8BF5: 0xF56D,
	0x8BF6: 0xF56E,
	0x8BF7: 0xF56F,
	0x8BF8: 0xF570,
	0x8BF9: 0xF571,
	0x8BFA: 0xF572,
	0x8BFB: 0xF573,
	0x8BFC: 0xF574,
	0x8BFD: 0xF575,
	0x8BFE: 0xF576,
	0x8C40: 0xF577,
	0x8C41: 0xF578,
	0x8C42: 0xF579,
	0x8C43: 0xF57A,
	0x8C44: 0xF57B,
	0x8C45: 0xF57C,
	0x8C46: 0xF57D,
	0x8C47: 0xF57E,
	0x8C48: 0xF57F,
	0x8C49: 0xF580,
	0x8C4A: 0xF581,
	0x8C4B: 0xF582,
	0x8C4C: 0xF583,
	0x8C4D: 0xF584,
	0x8C4E: 0xF585,
	0x8C4F: 0xF586,
	0x8C50: 0xF587,
	0x8C51: 0xF588,
	0x8C52: 0xF589,
	0x8C53: 0xF58A,
	0x8C54: 0xF58B,
	0x8C55: 0xF58C,
	0x8C56: 0xF58D,
	0x8C57: 0xF58E,
	0x8C58: 0xF58F,
	0x8C59: 0xF590,
	0x8C5A: 0xF591,
	0x8C5B: 0xF592,
	0x8C5C: 0xF593,
	0x8C5D: 0xF594,
	0x8C5E: 0xF595,
	0x8C5F: 0xF596,
	0x8C60: 0xF597,
	0x8C61: 0xF598,
	0x8C62: 0xF599,
	0x8C63: 0xF59A,
	0x8C64: 0xF59B,
	0x8C65: 0xF59C,
	0x8C66: 0xF59D,
	0x8C67: 0xF59E,
	0x8C68: 0xF59F,
	0x8C69: 0xF5A0,
	0x8C6A: 0xF5A1,
	0x8C6B: 0xF5A2,
	0x8C6C: 0xF5A3,
	0x8C6D: 0xF5A4,
	0x8C6E: 0xF5A5,
	0x8C6F: 0xF5A6,
	0x8C70: 0xF5A7,
	0x8C71: 0xF5A8,
	0x8C72: 0xF5A9,
	0x8C73: 0xF5AA,
	0x8C74: 0xF5AB,
	0x8C75: 0xF5AC,
	0x8C76: 0xF5AD,
	0x8C77: 0xF5AE,
	0x8C78: 0xF5AF,
	0x8C79: 0xF5B0,
	0x8C7A: 0xF5B1,
	0x8C7B: 0xF5B2,
	0x8C7C: 0xF5B3,
	0x8C7D: 0xF5B4,
	0x8C7E: 0xF5B5,
	0x8CA1: 0xF5B6,
	0x8CA2: 0xF5B7,
	0x8CA3: 0xF5B8,
	0x8CA4: 0xF5B9,
	0x8CA5: 0xF5BA,
	0x8CA6: 0xF5BB,
	0x8CA7: 0xF5BC,
	0x8CA8: 0xF5BD,
	0x8CA9: 0xF5BE,
	0x8CAA: 0xF5BF,
	0x8CAB: 0xF5C0,
	0x8CAC: 0xF5C1,
	0x8CAD: 0xF5C2,
	0x8CAE: 0xF5C3,
	0x8CAF: 0xF5C4,
	0x8CB0: 0xF5C5,
	0x8CB1: 0xF5C6,
	0x8CB2: 0xF5C7,
	0x8CB3: 0xF5C8,
	0x8CB4: 0xF5C9,
	0x8CB5: 0xF5CA,
	0x8CB6: 0xF5CB,
	0x8CB7: 0xF5CC,
	0x8CB8: 0xF5CD,
	0x8CB9: 0xF5CE,
	0x8CBA: 0xF5CF,
	0x8CBB: 0xF5D0,
	0x8CBC: 0xF5D1,
	0x8CBD: 0xF5D2,
	0x8CBE: 0xF5D3,
	0x8CBF: 0xF5D4,
	0x8CC0: 0xF5D5,
	0x8CC1: 0xF5D6,
	0x8CC2: 0xF5D7,
	0x8CC3: 0xF5D8,
	0x8CC4: 0xF5D9,
	0x8CC5: 0xF5DA,
	0x8CC6: 0xF5DB,
	0x8CC7: 0xF5DC,
	0x8CC8: 0xF5DD,
	0x8CC9: 0xF5DE,
	0x8CCA: 0xF5DF,
	0x8CCB: 0xF5E0,
	0x8CCC: 0xF5E1,
	0x8CCD: 0xF5E2,
	0x8CCE: 0xF5E3,
	0x8CCF: 0xF5E4,
	0x8CD0: 0xF5E5,
	0x8CD1: 0xF5E6,
	0x8CD2: 0xF5E7,
	0x8CD3: 0xF5E8,
	0x8CD4: 0xF5E9,
	0x8CD5: 0xF5EA,
	0x8CD6: 0xF5EB,
	0x8CD7: 0xF5EC,
	0x8CD8: 0xF5ED,
	0x8CD9: 0xF5EE,
	0x8CDA: 0xF5EF,
	0x8CDB: 0xF5F0,
	0x8CDC: 0xF5F1,
	0x8CDD: 0xF5F2,
	0x8CDE: 0xF5F3,
	0x8CDF: 0xF5F4,
	0x8CE0: 0xF5F5,
	0x8CE1: 0xF5F6,
	0x8CE2: 0xF5F7,
	0x8CE3: 0xF5F8,
	0x8CE4: 0xF5F9,
	0x8CE5: 0xF5FA,
	0x8CE6: 0xF5FB,
	0x8CE7: 0xF5FC,
	0x8CE8: 0xF5FD,
	0x8CE9: 0xF5FE,
	0x8CEA: 0xF5FF,
	0x8CEB: 0xF600,
	0x8CEC: 0xF601,
	0x8CED: 0xF602,
	0x8CEE: 0xF603,
	0x8CEF: 0xF604,
	0x8CF0: 0xF605,
	0x8CF1: 0xF606,
	0x8CF2: 0xF607,
	0x8CF3: 0xF608,
	0x8CF4: 0xF609,
	0x8CF5: 0xF60A,
	0x8CF6: 0xF60B,
	0x8CF7: 0xF60C,
	0x8CF8: 0xF60D,
	0x8CF9: 0xF60E,
	0x8CFA: 0xF60F,
	0x8CFB: 0xF610,
	0x8CFC: 0xF611,
	0x8CFD: 0xF612,
	0x8CFE: 0xF613,
	0x8D40: 0xF614,
	0x8D41: 0xF615,
	0x8D42: 0xF616,
	0x8D43: 0xF617,
	0x8D44: 0xF618,
	0x8D45: 0xF619,
	0x8D46: 0xF61A,
	0x8D47: 0xF61B,
	0x8D48: 0xF61C,
	0x8D49: 0xF61D,
	0x8D4A: 0xF61E,
	0x8D4B: 0xF61F,
	0x8D4C: 0xF620,
	0x8D4D: 0xF621,
	0x8D4E: 0xF622,
	0x8D4F: 0xF623,
	0x8D50: 0xF624,
	0x8D51: 0xF625,
	0x8D52: 0xF626,
	0x8D53: 0xF627,
	0x8D54: 0xF628,
	0x8D55: 0xF629,
	0x8D56: 0xF62A,
	0x8D57: 0xF62B,
	0x8D58: 0xF62C,
	0x8D59: 0xF62D,
	0x8D5A: 0xF62E,
	0x8D5B: 0xF62F,
	0x8D5C: 0xF630,
	0x8D5D: 0xF631,
	0x8D5E: 0xF632,
	0x8D5F: 0xF633,
	0x8D60: 0xF634,
	0x8D61: 0xF635,
	0x8D62: 0xF636,
	0x8D63: 0xF637,
	0x8D64: 0xF638,
	0x8D65: 0xF639,
	0x8D66: 0xF63A,
	0x8D67: 0xF63B,
	0x8D68: 0xF63C,
	0x8D69: 0xF63D,
	0x8D6A: 0xF63E,
	0x8D6B: 0xF63F,
	0x8D6C: 0xF640,
	0x8D6D: 0xF641,
	0x8D6E: 0xF642,
	0x8D6F: 0xF643,
	0x8D70: 0xF644,
	0x8D71: 0xF645,
	0x8D72: 0xF646,
	0x8D73: 0xF647,
	0x8D74: 0xF648,
	0x8D75: 0xF649,
	0x8D76: 0xF64A,
	0x8D77: 0xF64B,
	0x8D78: 0xF64C,
	0x8D79: 0xF64D,
	0x8D7A: 0xF64E,
	0x8D7B: 0xF64F,
	0x8D7C: 0xF650,
	0x8D7D: 0xF651,
	0x8D7E: 0xF652,
	0x8DA1: 0xF653,
	0x8DA2: 0xF654,
	0x8DA3: 0xF655,
	0x8DA4: 0xF656,
	0x8DA5: 0xF657,
	0x8DA6: 0xF658,
	0x8DA7: 0xF659,
	0x8DA8: 0xF65A,
	0x8DA9: 0xF65B,
	0x8DAA: 0xF65C,
	0x8DAB: 0xF65D,
	0x8DAC: 0xF65E,
	0x8DAD: 0xF65F,
	0x8DAE: 0xF660,
	0x8DAF: 0xF661,
	0x8DB0: 0xF662,
	0x8DB1: 0xF663,
	0x8DB2: 0xF664,
	0x8DB3: 0xF665,
	0x8DB4: 0xF666,
	0x8DB5: 0xF667,
	0x8DB6: 0xF668,
	0x8DB7: 0xF669,
	0x8DB8: 0xF66A,
	0x8DB9: 0xF66B,
	0x8DBA: 0xF66C,
	0x8DBB: 0xF66D,
	0x8DBC: 0xF66E,
	0x8DBD: 0xF66F,
	0x8DBE: 0xF670,
	0x8DBF: 0xF671,
	0x8DC0: 0xF672,
	0x8DC1: 0xF673,
	0x8DC2: 0xF674,
	0x8DC3: 0xF675,
	0x8DC4: 0xF676,
	0x8DC5: 0xF677,
	0x8DC6: 0xF678,
	0x8DC7: 0xF679,
	0x8DC8: 0xF67A,
	0x8DC9: 0xF67B,
	0x8DCA: 0xF67C,
	0x8DCB: 0xF67D,
	0x8DCC: 0xF67E,
	0x8DCD: 0xF67F,
	0x8DCE: 0xF680,
	0x8DCF: 0xF681,
	0x8DD0: 0xF682,
	0x8DD1: 0xF683,
	0x8DD2: 0xF684,
	0x8DD3: 0xF685,
	0x8DD4: 0xF686,
	0x8DD5: 0xF687,
	0x8DD6: 0xF688,
	0x8DD7: 0xF689,
	0x8DD8: 0xF68A,
	0x8DD9: 0xF68B,
	0x8DDA: 0xF68C,
	0x8DDB: 0xF68D,
	0x8DDC: 0xF68E,
	0x8DDD: 0xF68F,
	0x8DDE: 0xF690,
	0x8DDF: 0xF691,
	0x8DE0: 0xF692,
	0x8DE1: 0xF693,
	0x8DE2: 0xF694,
	0x8DE3: 0xF695,
	0x8DE4: 0xF696,
	0x8DE5: 0xF697,
	0x8DE6: 0xF698,
	0x8DE7: 0xF699,
	0x8DE8: 0xF69A,
	0x8DE9: 0xF69B,
	0x8DEA: 0xF69C,
	0x8DEB: 0xF69D,
	0x8DEC: 0xF69E,
	0x8DED: 0xF69F,
	0x8DEE: 0xF6A0,
	0x8DEF: 0xF6A1,
	0x8DF0: 0xF6A2,
	0x8DF1: 0xF6A3,
	0x8DF2: 0xF6A4,
	0x8DF3: 0xF6A5,
	0x8DF4: 0xF6A6,
	0x8DF5: 0xF6A7,
	0x8DF6: 0xF6A8,
	0x8DF7: 0xF6A9,
	0x8DF8: 0xF6AA,
	0x8DF9: 0xF6AB,
	0x8DFA: 0xF6AC,
	0x8DFB: 0xF6AD,
	0x8DFC: 0xF6AE,
	0x8DFD: 0xF6AF,
	0x8DFE: 0xF6B0,
	0xC6A1: 0xF6B1,
	0xC6A2: 0xF6B2,
	0xC6A3: 0xF6B3,
	0xC6A4: 0xF6B4,
	0xC6A5: 0xF6B5,
	0xC6A6: 0xF6B6,
	0xC6A7: 0xF6B7,
	0xC6A8: 0xF6B8,
	0xC6A9: 0xF6B9,
	0xC6AA: 0xF6BA,
	0xC6AB: 0xF6BB,
	0xC6AC: 0xF6BC,
	0xC6AD: 0xF6BD,
	0xC6AE: 0xF6BE,
	0xC6AF: 0xF6BF,
	0xC6B0: 0xF6C0,
	0xC6B1: 0xF6C1,
	0xC6B2: 0xF6C2,
	0xC6B3: 0xF6C3,
	0xC6B4: 0xF6C4,
	0xC6B5: 0xF6C5,
	0xC6B6: 0xF6C6,
	0xC6B7: 0xF6C7,
	0xC6B8: 0xF6C8,
	0xC6B9: 0xF6C9,
	0xC6BA: 0xF6CA,
	0xC6BB: 0xF6CB,
	0xC6BC: 0xF6CC,
	0xC6BD: 0xF6CD,
	0xC6BE: 0xF6CE,
	0xC6BF: 0xF6CF,
	0xC6C0: 0xF6D0,
	0xC6C1: 0xF6D1,
	0xC6C2: 0xF6D2,
	0xC6C3: 0xF6D3,
	0xC6C4: 0xF6D4,
	0xC6C5: 0xF6D5,
	0xC6C6: 0xF6D6,
	0xC6C7: 0xF6D7,
	0xC6C8: 0xF6D8,
	0xC6C9: 0xF6D9,
	0xC6CA: 0xF6DA,
	0xC6CB: 0xF6DB,
	0xC6CC: 0xF6DC,
	0xC6CD: 0xF6DD,
	0xC6CE: 0xF6DE,
	0xC6CF: 0xF6DF,
	0xC6D0: 0xF6E0,
	0xC6D1: 0xF6E1,
	0xC6D2: 0xF6E2,
	0xC6D3: 0xF6E3,
	0xC6D4: 0xF6E4,
	0xC6D5: 0xF6E5,
	0xC6D6: 0xF6E6,
	0xC6D7: 0xF6E7,
	0xC6D8: 0xF6E8,
	0xC6D9: 0xF6E9,
	0xC6DA: 0xF6EA,
	0xC6DB: 0xF6EB,
	0xC6DC: 0xF6EC,
	0xC6DD: 0xF6ED,
	0xC6DE: 0xF6EE,
	0xC6DF: 0xF6EF,
	0xC6E0: 0xF6F0,
	0xC6E1: 0xF6F1,
	0xC6E2: 0xF6F2,
	0xC6E3: 0xF6F3,
	0xC6E4: 0xF6F4,
	0xC6E5: 0xF6F5,
	0xC6E6: 0xF6F6,
	0xC6E7: 0xF6F7,
	0xC6E8: 0xF6F8,
	0xC6E9: 0xF6F9,
	0xC6EA: 0xF6FA,
	0xC6EB: 0xF6FB,
	0xC6EC: 0xF6FC,
	0xC6ED: 0xF6FD,
	0xC6EE: 0xF6FE,
	0xC6EF: 0xF6FF,
	0xC6F0: 0xF700,
	0xC6F1: 0xF701,
	0xC6F2: 0xF702,
	0xC6F3: 0xF703,
	0xC6F4: 0xF704,
	0xC6F5: 0xF705,
	0xC6F6: 0xF706,
	0xC6F7: 0xF707,
	0xC6F8: 0xF708,
	0xC6F9: 0xF709,
	0xC6FA: 0xF70A,
	0xC6FB: 0xF70B,
	0xC6FC: 0xF70C,
	0xC6FD: 0xF70D,
	0xC6FE: 0xF70E,
	0xC740: 0xF70F,
	0xC741: 0xF710,
	0xC742: 0xF711,
	0xC743: 0xF712,
	0xC744: 0xF713,
	0xC745: 0xF714,
	0xC746: 0xF715,
	0xC747: 0xF716,
	0xC748: 0xF717,
	0xC749: 0xF718,
	0xC74A: 0xF719,
	0xC74B: 0xF71A,
	0xC74C: 0xF71B,
	0xC74D: 0xF71C,
	0xC74E: 0xF71D,
	0xC74F: 0xF71E,
	0xC750: 0xF71F,
	0xC751: 0xF720,
	0xC752: 0xF721,
	0xC753: 0xF722,
	0xC754: 0xF723,
	0xC755: 0xF724,
	0xC756: 0xF725,
	0xC757: 0xF726,
	0xC758: 0xF727,
	0xC759: 0xF728,
	0xC75A: 0xF729,
	0xC75B: 0xF72A,
	0xC75C: 0xF72B,
	0xC75D: 0xF72C,
	0xC75E: 0xF72D,
	0xC75F: 0xF72E,
	0xC760: 0xF72F,
	0xC761: 0xF730,
	0xC762: 0xF731,
	0xC763: 0xF732,
	0xC764: 0xF733,
	0xC765: 0xF734,
	0xC766: 0xF735,
	0xC767: 0xF736,
	0xC768: 0xF737,
	0xC769: 0xF738,
	0xC76A: 0xF739,
	0xC76B: 0xF73A,
	0xC76C: 0xF73B,
	0xC76D: 0xF73C,
	0xC76E: 0xF73D,
	0xC76F: 0xF73E,
	0xC770: 0xF73F,
	0xC771: 0xF740,
	0xC772: 0xF741,
	0xC773: 0xF742,
	0xC774: 0xF743,
	0xC775: 0xF744,
	0xC776: 0xF745,
	0xC777: 0xF746,
	0xC778: 0xF747,
	0xC779: 0xF748,
	0xC77A: 0xF749,
	0xC77B: 0xF74A,
	0xC77C: 0xF74B,
	0xC77D: 0xF74C,
	0xC77E: 0xF74D,
	0xC7A1: 0xF74E,
	0xC7A2: 0xF74F,
	0xC7A3: 0xF750,
	0xC7A4: 0xF751,
	0xC7A5: 0xF752,
	0xC7A6: 0xF753,
	0xC7A7: 0xF754,
	0xC7A8: 0xF755,
	0xC7A9: 0xF756,
	0xC7AA: 0xF757,
	0xC7AB: 0xF758,
	0xC7AC: 0xF759,
	0xC7AD: 0xF75A,
	0xC7AE: 0xF75B,
	0xC7AF: 0xF75C,
	0xC7B0: 0xF75D,
	0xC7B1: 0xF75E,
	0xC7B2: 0xF75F,
	0xC7B3: 0xF760,
	0xC7B4: 0xF761,
	0xC7B5: 0xF762,
	0xC7B6: 0xF763,
	0xC7B7: 0xF764,
	0xC7B8: 0xF765,
	0xC7B9: 0xF766,
	0xC7BA: 0xF767,
	0xC7BB: 0xF768,
	0xC7BC: 0xF769,
	0xC7BD: 0xF76A,
	0xC7BE: 0xF76B,
	0xC7BF: 0xF76C,
	0xC7C0: 0xF76D,
	0xC7C1: 0xF76E,
	0xC7C2: 0xF76F,
	0xC7C3: 0xF770,
	0xC7C4: 0xF771,
	0xC7C5: 0xF772,
	0xC7C6: 0xF773,
	0xC7C7: 0xF774,
	0xC7C8: 0xF775,
	0xC7C9: 0xF776,
	0xC7CA: 0xF777,
	0xC7CB: 0xF778,
	0xC7CC: 0xF779,
	0xC7CD: 0xF77A,
	0xC7CE: 0xF77B,
	0xC7CF: 0xF77C,
	0xC7D0: 0xF77D,
	0xC7D1: 0xF77E,
	0xC7D2: 0xF77F,
	0xC7D3: 0xF780,
	0xC7D4: 0xF781,
	0xC7D5: 0xF782,
	0xC7D6: 0xF783,
	0xC7D7: 0xF784,
	0xC7D8: 0xF785,
	0xC7D9: 0xF786,
	0xC7DA: 0xF787,
	0xC7DB: 0xF788,
	0xC7DC: 0xF789,
	0xC7DD: 0xF78A,
	0xC7DE: 0xF78B,
	0xC7DF: 0xF78C,
	0xC7E0: 0xF78D,
	0xC7E1: 0xF78E,
	0xC7E2: 0xF78F,
	0xC7E3: 0xF790,
	0xC7E4: 0xF791,
	0xC7E5: 0xF792,
	0xC7E6: 0xF793,
	0xC7E7: 0xF794,
	0xC7E8: 0xF795,
	0xC7E9: 0xF796,
	0xC7EA: 0xF797,
	0xC7EB: 0xF798,
	0xC7EC: 0xF799,
	0xC7ED: 0xF79A,
	0xC7EE: 0xF79B,
	0xC7EF: 0xF79C,
	0xC7F0: 0xF79D,
	0xC7F1: 0xF79E,
	0xC7F2: 0xF79F,
	0xC7F3: 0xF7A0,
	0xC7F4: 0xF7A1,
	0xC7F5: 0xF7A2,
	0xC7F6: 0xF7A3,
	0xC7F7: 0xF7A4,
	0xC7F8: 0xF7A5,
	0xC7F9: 0xF7A6,
	0xC7FA: 0xF7A7,
	0xC7FB: 0xF7A8,
	0xC7FC: 0xF7A9,
	0xC7FD: 0xF7AA,
	0xC7FE: 0xF7AB,
	0xC840: 0xF7AC,
	0xC841: 0xF7AD,
	0xC842: 0xF7AE,
	0xC843: 0xF7AF,
	0xC844: 0xF7B0,
	0xC845: 0xF7B1,
	0xC846: 0xF7B2,
	0xC847: 0xF7B3,
	0xC848: 0xF7B4,
	0xC849: 0xF7B5,
	0xC84A: 0xF7B6,
	0xC84B: 0xF7B7,
	0xC84C: 0xF7B8,
	0xC84D: 0xF7B9,
	0xC84E: 0xF7BA,
	0xC84F: 0xF7BB,
	0xC850: 0xF7BC,
	0xC851: 0xF7BD,
	0xC852: 0xF7BE,
	0xC853: 0xF7BF,
	0xC854: 0xF7C0,
	0xC855: 0xF7C1,
	0xC856: 0xF7C2,
	0xC857: 0xF7C3,
	0xC858: 0xF7C4,
	0xC859: 0xF7C5,
	0xC85A: 0xF7C6,
	0xC85B: 0xF7C7,
	0xC85C: 0xF7C8,
	0xC85D: 0xF7C9,
	0xC85E: 0xF7CA,
	0xC85F: 0xF7CB,
	0xC860: 0xF7CC,
	0xC861: 0xF7CD,
	0xC862: 0xF7CE,
	0xC863: 0xF7CF,
	0xC864: 0xF7D0,
	0xC865: 0xF7D1,
	0xC866: 0xF7D2,
	0xC867: 0xF7D3,
	0xC868: 0xF7D4,
	0xC869: 0xF7D5,
	0xC86A: 0xF7D6,
	0xC86B: 0xF7D7,
	0xC86C: 0xF7D8,
	0xC86D: 0xF7D9,
	0xC86E: 0xF7DA,
	0xC86F: 0xF7DB,
	0xC870: 0xF7DC,
	0xC871: 0xF7DD,
	0xC872: 0xF7DE,
	0xC873: 0xF7DF,
	0xC874: 0xF7E0,
	0xC875: 0xF7E1,
	0xC876: 0xF7E2,
	0xC877: 0xF7E3,
	0xC878: 0xF7E4,
	0xC879: 0xF7E5,
	0xC87A: 0xF7E6,
	0xC87B: 0xF7E7,
	0xC87C: 0xF7E8,
	0xC87D: 0xF7E9,
	0xC87E: 0xF7EA,
	0xC8A1: 0xF7EB,
	0xC8A2: 0xF7EC,
	0xC8A3: 0xF7ED,
	0xC8A4: 0xF7EE,
	0xC8A5: 0xF7EF,
	0xC8A6: 0xF7F0,
	0xC8A7: 0xF7F1,
	0xC8A8: 0xF7F2,
	0xC8A9: 0xF7F3,
	0xC8AA: 0xF7F4,
	0xC8AB: 0xF7F5,
	0xC8AC: 0xF7F6,
	0xC8AD: 0xF7F7,
	0xC8AE: 0xF7F8,
	0xC8AF: 0xF7F9,
	0xC8B0: 0xF7FA,
	0xC8B1: 0xF7FB,
	0xC8B2: 0xF7FC,
	0xC8B3: 0xF7FD,
	0xC8B4: 0xF7FE,
	0xC8B5: 0xF7FF,
	0xC8B6: 0xF800,
	0xC8B7: 0xF801,
	0xC8B8: 0xF802,
	0xC8B9: 0xF803,
	0xC8BA: 0xF804,
	0xC8BB: 0xF805,
	0xC8BC: 0xF806,
	0xC8BD: 0xF807,
	0xC8BE: 0xF808,
	0xC8BF: 0xF809,
	0xC8C0: 0xF80A,
	0xC8C1: 0xF80B,
	0xC8C2: 0xF80C,
	0xC8C3: 0xF80D,
	0xC8C4: 0xF80E,
	0xC8C5: 0xF80F,
	0xC8C6: 0xF810,
	0xC8C7: 0xF811,
	0xC8C8: 0xF812,
	0xC8C9: 0xF813,
	0xC8CA: 0xF814,
	0xC8CB: 0xF815,
	0xC8CC: 0xF816,
	0xC8CD: 0xF817,
	0xC8CE: 0xF818,
	0xC8CF: 0xF819,
	0xC8D0: 0xF81A,
	0xC8D1: 0xF81B,
	0xC8D2: 0xF81C,
	0xC8D3: 0xF81D,
	0xC8D4: 0xF81E,
	0xC8D5: 0xF81F,
	0xC8D6: 0xF820,
	0xC8D7: 0xF821,
	0xC8D8: 0xF822,
	0xC8D9: 0xF823,
	0xC8DA: 0xF824,
	0xC8DB: 0xF825,
	0xC8DC: 0xF826,
	0xC8DD: 0xF827,
	0xC8DE: 0xF828,
	0xC8DF: 0xF829,
	0xC8E0: 0xF82A,
	0xC8E1: 0xF82B,
	0xC8E2: 0xF82C,
	0xC8E3: 0xF82D,
	0xC8E4: 0xF82E,
	0xC8E5: 0xF82F,
	0xC8E6: 0xF830,
	0xC8E7: 0xF831,
	0xC8E8: 0xF832,
	0xC8E9: 0xF833,
	0xC8EA: 0xF834,
	0xC8EB: 0xF835,
	0xC8EC: 0xF836,
	0xC8ED: 0xF837,
	0xC8EE: 0xF838,
	0xC8EF: 0xF839,
	0xC8F0: 0xF83A,
	0xC8F1: 0xF83B,
	0xC8F2: 0xF83C,
	0xC8F3: 0xF83D,
	0xC8F4: 0xF83E,
	0xC8F5: 0xF83F,
	0xC8F6: 0xF840,
	0xC8F7: 0xF841,
	0xC8F8: 0xF842,
	0xC8F9: 0xF843,
	0xC8FA: 0xF844,
	0xC8FB: 0xF845,
	0xC8FC: 0xF846,
	0xC8FD: 0xF847,
	0xC8FE: 0xF848,
	0xA3E2: 0xF849,
	0xA3E3: 0xF84A,
	0xA3E4: 0xF84B,
	0xA3E5: 0xF84C,
	0xA3E6: 0xF84D,
	0xA3E7: 0xF84E,
	0xA3E8: 0xF84F,
	0xA3E9: 0xF850,
	0xA3EA: 0xF851,
	0xA3EB: 0xF852,
	0xA3EC: 0xF853,
	0xA3ED: 0xF854,
	0xA3EE: 0xF855,
	0xA3EF: 0xF856,
	0xA3F0: 0xF857,
	0xA3F1: 0xF858,
	0xA3F2: 0xF859,
	0xA3F3: 0xF85A,
	0xA3F4: 0xF85B,
	0xA3F5: 0xF85C,
	0xA3F6: 0xF85D,
	0xA3F7: 0xF85E,
	0xA3F8: 0xF85F,
	0xA3F9: 0xF860,
	0xA3FA: 0xF861,
	0xA3FB: 0xF862,
	0xA3FC: 0xF863,
	0xA3FD: 0xF864,
	0xA3FE: 0xF865,
	0xC6DE: 0xF866,
	0xC6DF: 0xF867,
	0xFFFD: 0xF868,
	0xFFFD: 0xF869,
	0xFFFD: 0xF86A,
	0xFFFD: 0xF86B,
	0xFFFD: 0xF86C,
	0xFFFD: 0xF86D,
	0xFFFD: 0xF86E,
	0xFFFD: 0xF86F,
	0xFFFD: 0xF870,
	0xFFFD: 0xF871,
	0xFFFD: 0xF872,
	0xFFFD: 0xF873,
	0xFFFD: 0xF874,
	0xFFFD: 0xF875,
	0xFFFD: 0xF876,
	0xFFFD: 0xF877,
	0xFFFD: 0xF878,
	0xFFFD: 0xF879,
	0xFFFD: 0xF87A,
	0xFFFD: 0xF87B,
	0xFFFD: 0xF87C,
	0xFFFD: 0xF87D,
	0xFFFD: 0xF87E,
	0xFFFD: 0xF87F,
	0xFFFD: 0xF880,
	0xFFFD: 0xF881,
	0xFFFD: 0xF882,
	0xFFFD: 0xF883,
	0xFFFD: 0xF884,
	0xFFFD: 0xF885,
	0xFFFD: 0xF886,
	0xFFFD: 0xF887,
	0xFFFD: 0xF888,
	0xFFFD: 0xF889,
	0xFFFD: 0xF88A,
	0xFFFD: 0xF88B,
	0xFFFD: 0xF88C,
	0xFFFD: 0xF88D,
	0xFFFD: 0xF88E,
	0xFFFD: 0xF88F,
	0xFFFD: 0xF890,
	0xFFFD: 0xF891,
	0xFFFD: 0xF892,
	0xFFFD: 0xF893,
	0xFFFD: 0xF894,
	0xFFFD: 0xF895,
	0xFFFD: 0xF896,
	0xFFFD: 0xF897,
	0xFFFD: 0xF898,
	0xFFFD: 0xF899,
	0xFFFD: 0xF89A,
	0xFFFD: 0xF89B,
	0xFFFD: 0xF89C,
	0xFFFD: 0xF89D,
	0xFFFD: 0xF89E,
	0xFFFD: 0xF89F,
	0xFFFD: 0xF8A0,
	0xFFFD: 0xF8A1,
	0xFFFD: 0xF8A2,
	0xFFFD: 0xF8A3,
	0xFFFD: 0xF8A4,
	0xFFFD: 0xF8A5,
	0xFFFD: 0xF8A6,
	0xFFFD: 0xF8A7,
	0xFFFD: 0xF8A8,
	0xFFFD: 0xF8A9,
	0xFFFD: 0xF8AA,
	0xFFFD: 0xF8AB,
	0xFFFD: 0xF8AC,
	0xFFFD: 0xF8AD,
	0xFFFD: 0xF8AE,
	0xFFFD: 0xF8AF,
	0xFFFD: 0xF8B0,
	0xFFFD: 0xF8B1,
	0xFFFD: 0xF8B2,
	0xFFFD: 0xF8B3,
	0xFFFD: 0xF8B4,
	0xFFFD: 0xF8B5,
	0xFFFD: 0xF8B6,
	0xFFFD: 0xF8B7,
	0xFFFD: 0xF8B8,
	0xFFFD: 0xF8B9,
	0xFFFD: 0xF8BA,
	0xFFFD: 0xF8BB,
	0xFFFD: 0xF8BC,
	0xFFFD: 0xF8BD,
	0xFFFD: 0xF8BE,
	0xFFFD: 0xF8BF,
	0xFFFD: 0xF8C0,
	0xFFFD: 0xF8C1,
	0xFFFD: 0xF8C2,
	0xFFFD: 0xF8C3,
	0xFFFD: 0xF8C4,
	0xFFFD: 0xF8C5,
	0xFFFD: 0xF8C6,
	0xFFFD: 0xF8C7,
	0xFFFD: 0xF8C8,
	0xFFFD: 0xF8C9,
	0xFFFD: 0xF8CA,
	0xFFFD: 0xF8CB,
	0xFFFD: 0xF8CC,
	0xFFFD: 0xF8CD,
	0xFFFD: 0xF8CE,
	0xFFFD: 0xF8CF,
	0xFFFD: 0xF8D0,
	0xFFFD: 0xF8D1,
	0xFFFD: 0xF8D2,
	0xFFFD: 0xF8D3,
	0xFFFD: 0xF8D4,
	0xFFFD: 0xF8D5,
	0xFFFD: 0xF8D6,
	0xFFFD: 0xF8D7,
	0xFFFD: 0xF8D8,
	0xFFFD: 0xF8D9,
	0xFFFD: 0xF8DA,
	0xFFFD: 0xF8DB,
	0xFFFD: 0xF8DC,
	0xFFFD: 0xF8DD,
	0xFFFD: 0xF8DE,
	0xFFFD: 0xF8DF,
	0xFFFD: 0xF8E0,
	0xFFFD: 0xF8E1,
	0xFFFD: 0xF8E2,
	0xFFFD: 0xF8E3,
	0xFFFD: 0xF8E4,
	0xFFFD: 0xF8E5,
	0xFFFD: 0xF8E6,
	0xFFFD: 0xF8E7,
	0xFFFD: 0xF8E8,
	0xFFFD: 0xF8E9,
	0xFFFD: 0xF8EA,
	0xFFFD: 0xF8EB,
	0xFFFD: 0xF8EC,
	0xFFFD: 0xF8ED,
	0xFFFD: 0xF8EE,
	0xFFFD: 0xF8EF,
	0xFFFD: 0xF8F0,
	0xFFFD: 0xF8F1,
	0xFFFD: 0xF8F2,
	0xFFFD: 0xF8F3,
	0xFFFD: 0xF8F4,
	0xFFFD: 0xF8F5,
	0xFFFD: 0xF8F6,
	0xFFFD: 0xF8F7,
	0x00FF: 0xF8F8,
	0xFFFD: 0xF8F9,
	0xFFFD: 0xF8FA,
	0xFFFD: 0xF8FB,
	0xFFFD: 0xF8FC,
	0xFFFD: 0xF8FD,
	0xFFFD: 0xF8FE,
	0xFFFD: 0xF8FF,
	0xB05A: 0xF900,
	0xA7F3: 0xF901,
	0xA8AE: 0xF902,
	0xB8EB: 0xF903,
	0xB7C6: 0xF904,
	0xA6EA: 0xF905,
	0xA579: 0xF906,
	0xC074: 0xF907,
	0xC074: 0xF908,
	0xABB4: 0xF909,
	0xAAF7: 0xF90A,
	0xB3E2: 0xF90B,
	0xA960: 0xF90C,
	0xC369: 0xF90D,
	0xC4EE: 0xF90E,
	0xC3B9: 0xF90F,
	0xC5DA: 0xF910,
	0xC1B3: 0xF911,
	0xBB72: 0xF912,
	0xC5DE: 0xF913,
	0xBCD6: 0xF914,
	0xACA5: 0xF915,
	0xAF4F: 0xF916,
	0xAF5F: 0xF917,
	0xB8A8: 0xF918,
	0xB954: 0xF919,
	0xC064: 0xF91A,
	0xB6C3: 0xF91B,
	0xA75A: 0xF91C,
	0xC4E6: 0xF91D,
	0xC4EA: 0xF91E,
	0xC4F5: 0xF91F,
	0xC67D: 0xF920,
	0xB450: 0xF921,
	0xC0DD: 0xF922,
	0xC2C5: 0xF923,
	0xC4B0: 0xF924,
	0xA9D4: 0xF925,
	0xC3BE: 0xF926,
	0xC4FA: 0xF927,
	0xB459: 0xF928,
	0xAED4: 0xF929,
	0xAEF6: 0xF92A,
	0xAF54: 0xF92B,
	0xADA6: 0xF92C,
	0xA8D3: 0xF92D,
	0xA74E: 0xF92E,
	0xB3D2: 0xF92F,
	0xBEDB: 0xF930,
	0xC372: 0xF931,
	0xC46C: 0xF932,
	0xBF63: 0xF933,
	0xA6D1: 0xF934,
	0xC4AA: 0xF935,
	0xB8B8: 0xF936,
	0xB8F4: 0xF937,
	0xC553: 0xF938,
	0xBE7C: 0xF939,
	0xC64F: 0xF93A,
	0xB84C: 0xF93B,
	0xB853: 0xF93C,
	0xBAF1: 0xF93D,
	0xDB77: 0xF93E,
	0xBFFD: 0xF93F,
	0xB3C0: 0xF940,
	0xBDD7: 0xF941,
	0xC362: 0xF942,
	0xA7CB: 0xF943,
	0xC5A2: 0xF944,
	0xC5A4: 0xF945,
	0xA863: 0xF946,
	0xBD55: 0xF947,
	0xB8EF: 0xF948,
	0xB970: 0xF949,
	0xC253: 0xF94A,
	0xB9F0: 0xF94B,
	0xBCD3: 0xF94C,
	0xB25C: 0xF94D,
	0xBA7C: 0xF94E,
	0xB2D6: 0xF94F,
	0xC15C: 0xF950,
	0xADAE: 0xF951,
	0xB0C7: 0xF952,
	0xA6D8: 0xF953,
	0xBBFE: 0xF954,
	0xADE2: 0xF955,
	0xB857: 0xF956,
	0xBAF0: 0xF957,
	0xB5D9: 0xF958,
	0xB3AE: 0xF959,
	0xC5AA: 0xF95A,
	0xCED4: 0xF95B,
	0xBCD6: 0xF95C,
	0xBFD5: 0xF95D,
	0xA4A6: 0xF95E,
	0xB9E7: 0xF95F,
	0xABE3: 0xF960,
	0xB276: 0xF961,
	0xB2A7: 0xF962,
	0xA55F: 0xF963,
	0xEDA8: 0xF964,
	0xAB4B: 0xF965,
	0xB45F: 0xF966,
	0xA4A3: 0xF967,
	0xAA63: 0xF968,
	0xBCC6: 0xF969,
	0xAFC1: 0xF96A,
	0xB0D1: 0xF96B,
	0xB6EB: 0xF96C,
	0xACD9: 0xF96D,
	0xB8AD: 0xF96E,
	0xBBA1: 0xF96F,
	0xB1FE: 0xF970,
	0xA8B0: 0xF971,
	0xA848: 0xF972,
	0xAC42: 0xF973,
	0xAD59: 0xF974,
	0xB1B0: 0xF975,
	0xB2A4: 0xF976,
	0xAB47: 0xF977,
	0xA8E2: 0xF978,
	0x845B: 0xF979,
	0xB1E7: 0xF97A,
	0xC2B3: 0xF97B,
	0xA87D: 0xF97C,
	0xBDCC: 0xF97D,
	0xB671: 0xF97E,
	0xC079: 0xF97F,
	0xA766: 0xF980,
	0xA46B: 0xF981,
	0xC366: 0xF982,
	0xAEC8: 0xF983,
	0xC26F: 0xF984,
	0xC472: 0xF985,
	0xBE5B: 0xF986,
	0xC67A: 0xF987,
	0xC452: 0xF988,
	0xBEA4: 0xF989,
	0xA44F: 0xF98A,
	0xBEE4: 0xF98B,
	0xBEFA: 0xF98C,
	0xF765: 0xF98D,
	0xA67E: 0xF98E,
	0xBCA6: 0xF98F,
	0xC5CA: 0xF990,
	0xBCBF: 0xF991,
	0xBAA7: 0xF992,
	0xB7D2: 0xF993,
	0xE6A3: 0xF994,
	0x9DCE: 0xF995,
	0xBD6D: 0xF996,
	0xC170: 0xF997,
	0xBDFB: 0xF998,
	0xBDAC: 0xF999,
	0xB373: 0xF99A,
	0xC1E5: 0xF99B,
	0xA643: 0xF99C,
	0xA648: 0xF99D,
	0xAB7C: 0xF99E,
	0xAF50: 0xF99F,
	0xB5F5: 0xF9A0,
	0xBBA1: 0xF9A1,
	0xB747: 0xF9A2,
	0xA9C0: 0xF9A3,
	0xB1C9: 0xF9A4,
	0xC0D4: 0xF9A5,
	0xC3AE: 0xF9A6,
	0xC279: 0xF9A7,
	0xA54F: 0xF9A8,
	0xCBF1: 0xF9A9,
	0xB9E7: 0xF9AA,
	0xC0AD: 0xF9AB,
	0xCCB0: 0xF9AC,
	0xACC2: 0xF9AD,
	0xBCFC: 0xF9AE,
	0xB2DC: 0xF9AF,
	0xB2E2: 0xF9B0,
	0xB961: 0xF9B1,
	0xB973: 0xF9B2,
	0xC646: 0xF9B3,
	0xBBE2: 0xF9B4,
	0xA8D2: 0xF9B5,
	0xC2A7: 0xF9B6,
	0xC4BF: 0xF9B7,
	0xC1F5: 0xF9B8,
	0xB463: 0xF9B9,
	0xA446: 0xF9BA,
	0xB9B1: 0xF9BB,
	0xBC64: 0xF9BC,
	0xA7BF: 0xF9BD,
	0xAEC6: 0xF9BE,
	0xBCD6: 0xF9BF,
	0xBF52: 0xF9C0,
	0xC0F8: 0xF9C1,
	0xE764: 0xF9C2,
	0xBFF1: 0xF9C3,
	0xC073: 0xF9C4,
	0xB777: 0xF9C5,
	0xA8BF: 0xF9C6,
	0xBC42: 0xF9C7,
	0xCCD8: 0xF9C8,
	0xAC68: 0xF9C9,
	0xAC79: 0xF9CA,
	0xB7C8: 0xF9CB,
	0xAF5B: 0xF9CC,
	0xAF64: 0xF9CD,
	0xB2B8: 0xF9CE,
	0xAFC3: 0xF9CF,
	0xC3FE: 0xF9D0,
	0xA4BB: 0xF9D1,
	0xBCAE: 0xF9D2,
	0xB3B0: 0xF9D3,
	0xADDB: 0xF9D4,
	0xB15B: 0xF9D5,
	0xB25F: 0xF9D6,
	0xBDFC: 0xF9D7,
	0xABDF: 0xF9D8,
	0xB758: 0xF9D9,
	0xAEDF: 0xF9DA,
	0xB276: 0xF9DB,
	0xB6A9: 0xF9DC,
	0xA751: 0xF9DD,
	0xA64F: 0xF9DE,
	0xBC69: 0xF9DF,
	0xA9F6: 0xF9E0,
	0xA7F5: 0xF9E1,
	0xB1F9: 0xF9E2,
	0xAA64: 0xF9E3,
	0xB27A: 0xF9E4,
	0xB567: 0xF9E5,
	0xBFA9: 0xF9E6,
	0xF9D8: 0xF9E7,
	0xB8CC: 0xF9E8,
	0xA8BD: 0xF9E9,
	0xC2F7: 0xF9EA,
	0xB0CE: 0xF9EB,
	0xB7C4: 0xF9EC,
	0xA75B: 0xF9ED,
	0xBF4D: 0xF9EE,
	0xBF5A: 0xF9EF,
	0xC4A9: 0xF9F0,
	0x95F9: 0xF9F1,
	0xC5EC: 0xF9F2,
	0xC5EF: 0xF9F3,
	0xAA4C: 0xF9F4,
	0xB24F: 0xF9F5,
	0xC17B: 0xF9F6,
	0xA5DF: 0xF9F7,
	0xB2C1: 0xF9F8,
	0xB2C9: 0xF9F9,
	0xAAAC: 0xF9FA,
	0xAAA5: 0xF9FB,
	0xC3D1: 0xF9FC,
	0xA4B0: 0xF9FD,
	0xAFF9: 0xF9FE,
	0xA8EB: 0xF9FF,
	0xA4C1: 0xFA00,
	0xABD7: 0xFA01,
	0xA9DD: 0xFA02,
	0xBF7D: 0xFA03,
	0xA676: 0xFA04,
	0xAC7D: 0xFA05,
	0xBCC9: 0xFA06,
	0xBFE7: 0xFA07,
	0xA6E6: 0xFA08,
	0xADB0: 0xFA09,
	0xA8A3: 0xFA0A,
	0xB9F8: 0xFA0B,
	0xC94A: 0xFA0C,
	0xDDFC: 0xFA0D,
	0x9877: 0xFA0E,
	0x9878: 0xFA0F,
	0xB6EF: 0xFA10,
	0x9879: 0xFA11,
	0xB4B8: 0xFA12,
	0x987A: 0xFA13,
	0x987B: 0xFA14,
	0xE8F9: 0xFA15,
	0x95BD: 0xFA16,
	0xAF71: 0xFA17,
	0x987C: 0xFA18,
	0xAFAB: 0xFA19,
	0xB2BB: 0xFA1A,
	0xBAD6: 0xFA1B,
	0xB974: 0xFA1C,
	0xBAEB: 0xFA1D,
	0xA6D0: 0xFA1E,
	0x987D: 0xFA1F,
	0x987E: 0xFA20,
	0x98A1: 0xFA21,
	0xBDD1: 0xFA22,
	0x98A2: 0xFA23,
	0x98A3: 0xFA24,
	0xB668: 0xFA25,
	0xB3A3: 0xFA26,
	0x98A4: 0xFA27,
	0x98A5: 0xFA28,
	0x98A6: 0xFA29,
	0xB6BA: 0xFA2A,
	0xB97D: 0xFA2B,
	0xC05D: 0xFA2C,
	0xC562: 0xFA2D,
	0xFFFD: 0xFA2E,
	0xFFFD: 0xFA2F,
	0xAB56: 0xFA30,
	0xB9AC: 0xFA31,
	0xA74B: 0xFA32,
	0xAB6A: 0xFA33,
	0xB6D4: 0xFA34,
	0xA8F5: 0xFA35,
	0xB3DC: 0xFA36,
	0xB9C4: 0xFA37,
	0xBEB9: 0xFA38,
	0x9459: 0xFA39,
	0xBEA5: 0xFA3A,
	0xBC68: 0xFA3B,
	0xC94B: 0xFA3C,
	0xAEAC: 0xFA3D,
	0xB46E: 0xFA3E,
	0xBCA8: 0xFA3F,
	0xC367: 0xFA40,
	0xB1D3: 0xFA41,
	0xAC4A: 0xFA42,
	0xB4BB: 0xFA43,
	0xB1F6: 0xFA44,
	0xAEFC: 0xFA45,
	0xB25A: 0xFA46,
	0xBA7E: 0xFA47,
	0xB54E: 0xFA48,
	0x9C70: 0xFA49,
	0xB55A: 0xFA4A,
	0xB84F: 0xFA4B,
	0xAAC0: 0xFA4C,
	0xACE7: 0xFA4D,
	0xACE8: 0xFA4E,
	0xAFA7: 0xFA4F,
	0xAFAA: 0xFA50,
	0xAFAC: 0xFA51,
	0xBAD7: 0xFA52,
	0xBAD5: 0xFA53,
	0xBD5C: 0xFA54,
	0xACF0: 0xFA55,
	0xB860: 0xFA56,
	0xBD6D: 0xFA57,
	0xBFA7: 0xFA58,
	0xC163: 0xFA59,
	0xB870: 0xFA5A,
	0xAACC: 0xFA5B,
	0xAFE4: 0xFA5C,
	0x9CD2: 0xFA5D,
	0x9CD2: 0xFA5E,
	0xB5DB: 0xFA5F,
	0xBDC5: 0xFA60,
	0xB5F8: 0xFA61,
	0xBFD6: 0xFA62,
	0xC2D4: 0xFA63,
	0xBBAB: 0xFA64,
	0xC3D8: 0xFA65,
	0x9CE0: 0xFA66,
	0xB668: 0xFA67,
	0xC3F8: 0xFA68,
	0xC554: 0xFA69,
	0xC057: 0xFA6A,
	0xFFFD: 0xFA6B,
	0xFFFD: 0xFA6C,
	0xFFFD: 0xFA6D,
	0xFFFD: 0xFA6E,
	0xFFFD: 0xFA6F,
	0xFFFD: 0xFA70,
	0xFFFD: 0xFA71,
	0xFFFD: 0xFA72,
	0xFFFD: 0xFA73,
	0xFFFD: 0xFA74,
	0xFFFD: 0xFA75,
	0xFFFD: 0xFA76,
	0xFFFD: 0xFA77,
	0xFFFD: 0xFA78,
	0xFFFD: 0xFA79,
	0xFFFD: 0xFA7A,
	0xFFFD: 0xFA7B,
	0xFFFD: 0xFA7C,
	0xFFFD: 0xFA7D,
	0xFFFD: 0xFA7E,
	0xFFFD: 0xFA7F,
	0xFFFD: 0xFA80,
	0xFFFD: 0xFA81,
	0xFFFD: 0xFA82,
	0xFFFD: 0xFA83,
	0xFFFD: 0xFA84,
	0xFFFD: 0xFA85,
	0xFFFD: 0xFA86,
	0xFFFD: 0xFA87,
	0xFFFD: 0xFA88,
	0xFFFD: 0xFA89,
	0xFFFD: 0xFA8A,
	0xFFFD: 0xFA8B,
	0xFFFD: 0xFA8C,
	0xFFFD: 0xFA8D,
	0xFFFD: 0xFA8E,
	0xFFFD: 0xFA8F,
	0xFFFD: 0xFA90,
	0xFFFD: 0xFA91,
	0xFFFD: 0xFA92,
	0xFFFD: 0xFA93,
	0xFFFD: 0xFA94,
	0xFFFD: 0xFA95,
	0xFFFD: 0xFA96,
	0xFFFD: 0xFA97,
	0xFFFD: 0xFA98,
	0xFFFD: 0xFA99,
	0xFFFD: 0xFA9A,
	0xFFFD: 0xFA9B,
	0xFFFD: 0xFA9C,
	0xFFFD: 0xFA9D,
	0xFFFD: 0xFA9E,
	0xFFFD: 0xFA9F,
	0xFFFD: 0xFAA0,
	0xFFFD: 0xFAA1,
	0xFFFD: 0xFAA2,
	0xFFFD: 0xFAA3,
	0xFFFD: 0xFAA4,
	0xFFFD: 0xFAA5,
	0xFFFD: 0xFAA6,
	0xFFFD: 0xFAA7,
	0xFFFD: 0xFAA8,
	0xFFFD: 0xFAA9,
	0xFFFD: 0xFAAA,
	0xFFFD: 0xFAAB,
	0xFFFD: 0xFAAC,
	0xFFFD: 0xFAAD,
	0xFFFD: 0xFAAE,
	0xFFFD: 0xFAAF,
	0xFFFD: 0xFAB0,
	0xFFFD: 0xFAB1,
	0xFFFD: 0xFAB2,
	0xFFFD: 0xFAB3,
	0xFFFD: 0xFAB4,
	0xFFFD: 0xFAB5,
	0xFFFD: 0xFAB6,
	0xFFFD: 0xFAB7,
	0xFFFD: 0xFAB8,
	0xFFFD: 0xFAB9,
	0xFFFD: 0xFABA,
	0xFFFD: 0xFABB,
	0xFFFD: 0xFABC,
	0xFFFD: 0xFABD,
	0xFFFD: 0xFABE,
	0xFFFD: 0xFABF,
	0xFFFD: 0xFAC0,
	0xFFFD: 0xFAC1,
	0xFFFD: 0xFAC2,
	0xFFFD: 0xFAC3,
	0xFFFD: 0xFAC4,
	0xFFFD: 0xFAC5,
	0xFFFD: 0xFAC6,
	0xFFFD: 0xFAC7,
	0xFFFD: 0xFAC8,
	0xFFFD: 0xFAC9,
	0xFFFD: 0xFACA,
	0xFFFD: 0xFACB,
	0xFFFD: 0xFACC,
	0xFFFD: 0xFACD,
	0xFFFD: 0xFACE,
	0xFFFD: 0xFACF,
	0xFFFD: 0xFAD0,
	0xFFFD: 0xFAD1,
	0xFFFD: 0xFAD2,
	0xFFFD: 0xFAD3,
	0xFFFD: 0xFAD4,
	0xFFFD: 0xFAD5,
	0xFFFD: 0xFAD6,
	0xFFFD: 0xFAD7,
	0xFFFD: 0xFAD8,
	0xFFFD: 0xFAD9,
	0xFFFD: 0xFADA,
	0xFFFD: 0xFADB,
	0xFFFD: 0xFADC,
	0xFFFD: 0xFADD,
	0xFFFD: 0xFADE,
	0xFFFD: 0xFADF,
	0xFFFD: 0xFAE0,
	0xFFFD: 0xFAE1,
	0xFFFD: 0xFAE2,
	0xFFFD: 0xFAE3,
	0xFFFD: 0xFAE4,
	0xFFFD: 0xFAE5,
	0xFFFD: 0xFAE6,
	0xFFFD: 0xFAE7,
	0xFFFD: 0xFAE8,
	0xFFFD: 0xFAE9,
	0xFFFD: 0xFAEA,
	0xFFFD: 0xFAEB,
	0xFFFD: 0xFAEC,
	0xFFFD: 0xFAED,
	0xFFFD: 0xFAEE,
	0xFFFD: 0xFAEF,
	0xFFFD: 0xFAF0,
	0xFFFD: 0xFAF1,
	0xFFFD: 0xFAF2,
	0xFFFD: 0xFAF3,
	0xFFFD: 0xFAF4,
	0xFFFD: 0xFAF5,
	0xFFFD: 0xFAF6,
	0xFFFD: 0xFAF7,
	0xFFFD: 0xFAF8,
	0xFFFD: 0xFAF9,
	0xFFFD: 0xFAFA,
	0xFFFD: 0xFAFB,
	0xFFFD: 0xFAFC,
	0xFFFD: 0xFAFD,
	0xFFFD: 0xFAFE,
	0xFFFD: 0xFAFF,
	0xFFFD: 0xFB00,
	0xFFFD: 0xFB01,
	0xFFFD: 0xFB02,
	0xFFFD: 0xFB03,
	0xFFFD: 0xFB04,
	0xFFFD: 0xFB05,
	0xFFFD: 0xFB06,
	0xFFFD: 0xFB07,
	0xFFFD: 0xFB08,
	0xFFFD: 0xFB09,
	0xFFFD: 0xFB0A,
	0xFFFD: 0xFB0B,
	0xFFFD: 0xFB0C,
	0xFFFD: 0xFB0D,
	0xFFFD: 0xFB0E,
	0xFFFD: 0xFB0F,
	0xFFFD: 0xFB10,
	0xFFFD: 0xFB11,
	0xFFFD: 0xFB12,
	0xFFFD: 0xFB13,
	0xFFFD: 0xFB14,
	0xFFFD: 0xFB15,
	0xFFFD: 0xFB16,
	0xFFFD: 0xFB17,
	0xFFFD: 0xFB18,
	0xFFFD: 0xFB19,
	0xFFFD: 0xFB1A,
	0xFFFD: 0xFB1B,
	0xFFFD: 0xFB1C,
	0xFFFD: 0xFB1D,
	0xFFFD: 0xFB1E,
	0xFFFD: 0xFB1F,
	0xFFFD: 0xFB20,
	0xFFFD: 0xFB21,
	0xFFFD: 0xFB22,
	0xFFFD: 0xFB23,
	0xFFFD: 0xFB24,
	0xFFFD: 0xFB25,
	0xFFFD: 0xFB26,
	0xFFFD: 0xFB27,
	0xFFFD: 0xFB28,
	0xFFFD: 0xFB29,
	0xFFFD: 0xFB2A,
	0xFFFD: 0xFB2B,
	0xFFFD: 0xFB2C,
	0xFFFD: 0xFB2D,
	0xFFFD: 0xFB2E,
	0xFFFD: 0xFB2F,
	0xFFFD: 0xFB30,
	0xFFFD: 0xFB31,
	0xFFFD: 0xFB32,
	0xFFFD: 0xFB33,
	0xFFFD: 0xFB34,
	0xFFFD: 0xFB35,
	0xFFFD: 0xFB36,
	0xFFFD: 0xFB37,
	0xFFFD: 0xFB38,
	0xFFFD: 0xFB39,
	0xFFFD: 0xFB3A,
	0xFFFD: 0xFB3B,
	0xFFFD: 0xFB3C,
	0xFFFD: 0xFB3D,
	0xFFFD: 0xFB3E,
	0xFFFD: 0xFB3F,
	0xFFFD: 0xFB40,
	0xFFFD: 0xFB41,
	0xFFFD: 0xFB42,
	0xFFFD: 0xFB43,
	0xFFFD: 0xFB44,
	0xFFFD: 0xFB45,
	0xFFFD: 0xFB46,
	0xFFFD: 0xFB47,
	0xFFFD: 0xFB48,
	0xFFFD: 0xFB49,
	0xFFFD: 0xFB4A,
	0xFFFD: 0xFB4B,
	0xFFFD: 0xFB4C,
	0xFFFD: 0xFB4D,
	0xFFFD: 0xFB4E,
	0xFFFD: 0xFB4F,
	0xFFFD: 0xFB50,
	0xFFFD: 0xFB51,
	0xFFFD: 0xFB52,
	0xFFFD: 0xFB53,
	0xFFFD: 0xFB54,
	0xFFFD: 0xFB55,
	0xFFFD: 0xFB56,
	0xFFFD: 0xFB57,
	0xFFFD: 0xFB58,
	0xFFFD: 0xFB59,
	0xFFFD: 0xFB5A,
	0xFFFD: 0xFB5B,
	0xFFFD: 0xFB5C,
	0xFFFD: 0xFB5D,
	0xFFFD: 0xFB5E,
	0xFFFD: 0xFB5F,
	0xFFFD: 0xFB60,
	0xFFFD: 0xFB61,
	0xFFFD: 0xFB62,
	0xFFFD: 0xFB63,
	0xFFFD: 0xFB64,
	0xFFFD: 0xFB65,
	0xFFFD: 0xFB66,
	0xFFFD: 0xFB67,
	0xFFFD: 0xFB68,
	0xFFFD: 0xFB69,
	0xFFFD: 0xFB6A,
	0xFFFD: 0xFB6B,
	0xFFFD: 0xFB6C,
	0xFFFD: 0xFB6D,
	0xFFFD: 0xFB6E,
	0xFFFD: 0xFB6F,
	0xFFFD: 0xFB70,
	0xFFFD: 0xFB71,
	0xFFFD: 0xFB72,
	0xFFFD: 0xFB73,
	0xFFFD: 0xFB74,
	0xFFFD: 0xFB75,
	0xFFFD: 0xFB76,
	0xFFFD: 0xFB77,
	0xFFFD: 0xFB78,
	0xFFFD: 0xFB79,
	0xFFFD: 0xFB7A,
	0xFFFD: 0xFB7B,
	0xFFFD: 0xFB7C,
	0xFFFD: 0xFB7D,
	0xFFFD: 0xFB7E,
	0xFFFD: 0xFB7F,
	0xFFFD: 0xFB80,
	0xFFFD: 0xFB81,
	0xFFFD: 0xFB82,
	0xFFFD: 0xFB83,
	0xFFFD: 0xFB84,
	0xFFFD: 0xFB85,
	0xFFFD: 0xFB86,
	0xFFFD: 0xFB87,
	0xFFFD: 0xFB88,
	0xFFFD: 0xFB89,
	0xFFFD: 0xFB8A,
	0xFFFD: 0xFB8B,
	0xFFFD: 0xFB8C,
	0xFFFD: 0xFB8D,
	0xFFFD: 0xFB8E,
	0xFFFD: 0xFB8F,
	0xFFFD: 0xFB90,
	0xFFFD: 0xFB91,
	0xFFFD: 0xFB92,
	0xFFFD: 0xFB93,
	0xFFFD: 0xFB94,
	0xFFFD: 0xFB95,
	0xFFFD: 0xFB96,
	0xFFFD: 0xFB97,
	0xFFFD: 0xFB98,
	0xFFFD: 0xFB99,
	0xFFFD: 0xFB9A,
	0xFFFD: 0xFB9B,
	0xFFFD: 0xFB9C,
	0xFFFD: 0xFB9D,
	0xFFFD: 0xFB9E,
	0xFFFD: 0xFB9F,
	0xFFFD: 0xFBA0,
	0xFFFD: 0xFBA1,
	0xFFFD: 0xFBA2,
	0xFFFD: 0xFBA3,
	0xFFFD: 0xFBA4,
	0xFFFD: 0xFBA5,
	0xFFFD: 0xFBA6,
	0xFFFD: 0xFBA7,
	0xFFFD: 0xFBA8,
	0xFFFD: 0xFBA9,
	0xFFFD: 0xFBAA,
	0xFFFD: 0xFBAB,
	0xFFFD: 0xFBAC,
	0xFFFD: 0xFBAD,
	0xFFFD: 0xFBAE,
	0xFFFD: 0xFBAF,
	0xFFFD: 0xFBB0,
	0xFFFD: 0xFBB1,
	0xFFFD: 0xFBB2,
	0xFFFD: 0xFBB3,
	0xFFFD: 0xFBB4,
	0xFFFD: 0xFBB5,
	0xFFFD: 0xFBB6,
	0xFFFD: 0xFBB7,
	0xFFFD: 0xFBB8,
	0xFFFD: 0xFBB9,
	0xFFFD: 0xFBBA,
	0xFFFD: 0xFBBB,
	0xFFFD: 0xFBBC,
	0xFFFD: 0xFBBD,
	0xFFFD: 0xFBBE,
	0xFFFD: 0xFBBF,
	0xFFFD: 0xFBC0,
	0xFFFD: 0xFBC1,
	0xFFFD: 0xFBC2,
	0xFFFD: 0xFBC3,
	0xFFFD: 0xFBC4,
	0xFFFD: 0xFBC5,
	0xFFFD: 0xFBC6,
	0xFFFD: 0xFBC7,
	0xFFFD: 0xFBC8,
	0xFFFD: 0xFBC9,
	0xFFFD: 0xFBCA,
	0xFFFD: 0xFBCB,
	0xFFFD: 0xFBCC,
	0xFFFD: 0xFBCD,
	0xFFFD: 0xFBCE,
	0xFFFD: 0xFBCF,
	0xFFFD: 0xFBD0,
	0xFFFD: 0xFBD1,
	0xFFFD: 0xFBD2,
	0xFFFD: 0xFBD3,
	0xFFFD: 0xFBD4,
	0xFFFD: 0xFBD5,
	0xFFFD: 0xFBD6,
	0xFFFD: 0xFBD7,
	0xFFFD: 0xFBD8,
	0xFFFD: 0xFBD9,
	0xFFFD: 0xFBDA,
	0xFFFD: 0xFBDB,
	0xFFFD: 0xFBDC,
	0xFFFD: 0xFBDD,
	0xFFFD: 0xFBDE,
	0xFFFD: 0xFBDF,
	0xFFFD: 0xFBE0,
	0xFFFD: 0xFBE1,
	0xFFFD: 0xFBE2,
	0xFFFD: 0xFBE3,
	0xFFFD: 0xFBE4,
	0xFFFD: 0xFBE5,
	0xFFFD: 0xFBE6,
	0xFFFD: 0xFBE7,
	0xFFFD: 0xFBE8,
	0xFFFD: 0xFBE9,
	0xFFFD: 0xFBEA,
	0xFFFD: 0xFBEB,
	0xFFFD: 0xFBEC,
	0xFFFD: 0xFBED,
	0xFFFD: 0xFBEE,
	0xFFFD: 0xFBEF,
	0xFFFD: 0xFBF0,
	0xFFFD: 0xFBF1,
	0xFFFD: 0xFBF2,
	0xFFFD: 0xFBF3,
	0xFFFD: 0xFBF4,
	0xFFFD: 0xFBF5,
	0xFFFD: 0xFBF6,
	0xFFFD: 0xFBF7,
	0xFFFD: 0xFBF8,
	0xFFFD: 0xFBF9,
	0xFFFD: 0xFBFA,
	0xFFFD: 0xFBFB,
	0xFFFD: 0xFBFC,
	0xFFFD: 0xFBFD,
	0xFFFD: 0xFBFE,
	0xFFFD: 0xFBFF,
	0xFFFD: 0xFC00,
	0xFFFD: 0xFC01,
	0xFFFD: 0xFC02,
	0xFFFD: 0xFC03,
	0xFFFD: 0xFC04,
	0xFFFD: 0xFC05,
	0xFFFD: 0xFC06,
	0xFFFD: 0xFC07,
	0xFFFD: 0xFC08,
	0xFFFD: 0xFC09,
	0xFFFD: 0xFC0A,
	0xFFFD: 0xFC0B,
	0xFFFD: 0xFC0C,
	0xFFFD: 0xFC0D,
	0xFFFD: 0xFC0E,
	0xFFFD: 0xFC0F,
	0xFFFD: 0xFC10,
	0xFFFD: 0xFC11,
	0xFFFD: 0xFC12,
	0xFFFD: 0xFC13,
	0xFFFD: 0xFC14,
	0xFFFD: 0xFC15,
	0xFFFD: 0xFC16,
	0xFFFD: 0xFC17,
	0xFFFD: 0xFC18,
	0xFFFD: 0xFC19,
	0xFFFD: 0xFC1A,
	0xFFFD: 0xFC1B,
	0xFFFD: 0xFC1C,
	0xFFFD: 0xFC1D,
	0xFFFD: 0xFC1E,
	0xFFFD: 0xFC1F,
	0xFFFD: 0xFC20,
	0xFFFD: 0xFC21,
	0xFFFD: 0xFC22,
	0xFFFD: 0xFC23,
	0xFFFD: 0xFC24,
	0xFFFD: 0xFC25,
	0xFFFD: 0xFC26,
	0xFFFD: 0xFC27,
	0xFFFD: 0xFC28,
	0xFFFD: 0xFC29,
	0xFFFD: 0xFC2A,
	0xFFFD: 0xFC2B,
	0xFFFD: 0xFC2C,
	0xFFFD: 0xFC2D,
	0xFFFD: 0xFC2E,
	0xFFFD: 0xFC2F,
	0xFFFD: 0xFC30,
	0xFFFD: 0xFC31,
	0xFFFD: 0xFC32,
	0xFFFD: 0xFC33,
	0xFFFD: 0xFC34,
	0xFFFD: 0xFC35,
	0xFFFD: 0xFC36,
	0xFFFD: 0xFC37,
	0xFFFD: 0xFC38,
	0xFFFD: 0xFC39,
	0xFFFD: 0xFC3A,
	0xFFFD: 0xFC3B,
	0xFFFD: 0xFC3C,
	0xFFFD: 0xFC3D,
	0xFFFD: 0xFC3E,
	0xFFFD: 0xFC3F,
	0xFFFD: 0xFC40,
	0xFFFD: 0xFC41,
	0xFFFD: 0xFC42,
	0xFFFD: 0xFC43,
	0xFFFD: 0xFC44,
	0xFFFD: 0xFC45,
	0xFFFD: 0xFC46,
	0xFFFD: 0xFC47,
	0xFFFD: 0xFC48,
	0xFFFD: 0xFC49,
	0xFFFD: 0xFC4A,
	0xFFFD: 0xFC4B,
	0xFFFD: 0xFC4C,
	0xFFFD: 0xFC4D,
	0xFFFD: 0xFC4E,
	0xFFFD: 0xFC4F,
	0xFFFD: 0xFC50,
	0xFFFD: 0xFC51,
	0xFFFD: 0xFC52,
	0xFFFD: 0xFC53,
	0xFFFD: 0xFC54,
	0xFFFD: 0xFC55,
	0xFFFD: 0xFC56,
	0xFFFD: 0xFC57,
	0xFFFD: 0xFC58,
	0xFFFD: 0xFC59,
	0xFFFD: 0xFC5A,
	0xFFFD: 0xFC5B,
	0xFFFD: 0xFC5C,
	0xFFFD: 0xFC5D,
	0xFFFD: 0xFC5E,
	0xFFFD: 0xFC5F,
	0xFFFD: 0xFC60,
	0xFFFD: 0xFC61,
	0xFFFD: 0xFC62,
	0xFFFD: 0xFC63,
	0xFFFD: 0xFC64,
	0xFFFD: 0xFC65,
	0xFFFD: 0xFC66,
	0xFFFD: 0xFC67,
	0xFFFD: 0xFC68,
	0xFFFD: 0xFC69,
	0xFFFD: 0xFC6A,
	0xFFFD: 0xFC6B,
	0xFFFD: 0xFC6C,
	0xFFFD: 0xFC6D,
	0xFFFD: 0xFC6E,
	0xFFFD: 0xFC6F,
	0xFFFD: 0xFC70,
	0xFFFD: 0xFC71,
	0xFFFD: 0xFC72,
	0xFFFD: 0xFC73,
	0xFFFD: 0xFC74,
	0xFFFD: 0xFC75,
	0xFFFD: 0xFC76,
	0xFFFD: 0xFC77,
	0xFFFD: 0xFC78,
	0xFFFD: 0xFC79,
	0xFFFD: 0xFC7A,
	0xFFFD: 0xFC7B,
	0xFFFD: 0xFC7C,
	0xFFFD: 0xFC7D,
	0xFFFD: 0xFC7E,
	0xFFFD: 0xFC7F,
	0xFFFD: 0xFC80,
	0xFFFD: 0xFC81,
	0xFFFD: 0xFC82,
	0xFFFD: 0xFC83,
	0xFFFD: 0xFC84,
	0xFFFD: 0xFC85,
	0xFFFD: 0xFC86,
	0xFFFD: 0xFC87,
	0xFFFD: 0xFC88,
	0xFFFD: 0xFC89,
	0xFFFD: 0xFC8A,
	0xFFFD: 0xFC8B,
	0xFFFD: 0xFC8C,
	0xFFFD: 0xFC8D,
	0xFFFD: 0xFC8E,
	0xFFFD: 0xFC8F,
	0xFFFD: 0xFC90,
	0xFFFD: 0xFC91,
	0xFFFD: 0xFC92,
	0xFFFD: 0xFC93,
	0xFFFD: 0xFC94,
	0xFFFD: 0xFC95,
	0xFFFD: 0xFC96,
	0xFFFD: 0xFC97,
	0xFFFD: 0xFC98,
	0xFFFD: 0xFC99,
	0xFFFD: 0xFC9A,
	0xFFFD: 0xFC9B,
	0xFFFD: 0xFC9C,
	0xFFFD: 0xFC9D,
	0xFFFD: 0xFC9E,
	0xFFFD: 0xFC9F,
	0xFFFD: 0xFCA0,
	0xFFFD: 0xFCA1,
	0xFFFD: 0xFCA2,
	0xFFFD: 0xFCA3,
	0xFFFD: 0xFCA4,
	0xFFFD: 0xFCA5,
	0xFFFD: 0xFCA6,
	0xFFFD: 0xFCA7,
	0xFFFD: 0xFCA8,
	0xFFFD: 0xFCA9,
	0xFFFD: 0xFCAA,
	0xFFFD: 0xFCAB,
	0xFFFD: 0xFCAC,
	0xFFFD: 0xFCAD,
	0xFFFD: 0xFCAE,
	0xFFFD: 0xFCAF,
	0xFFFD: 0xFCB0,
	0xFFFD: 0xFCB1,
	0xFFFD: 0xFCB2,
	0xFFFD: 0xFCB3,
	0xFFFD: 0xFCB4,
	0xFFFD: 0xFCB5,
	0xFFFD: 0xFCB6,
	0xFFFD: 0xFCB7,
	0xFFFD: 0xFCB8,
	0xFFFD: 0xFCB9,
	0xFFFD: 0xFCBA,
	0xFFFD: 0xFCBB,
	0xFFFD: 0xFCBC,
	0xFFFD: 0xFCBD,
	0xFFFD: 0xFCBE,
	0xFFFD: 0xFCBF,
	0xFFFD: 0xFCC0,
	0xFFFD: 0xFCC1,
	0xFFFD: 0xFCC2,
	0xFFFD: 0xFCC3,
	0xFFFD: 0xFCC4,
	0xFFFD: 0xFCC5,
	0xFFFD: 0xFCC6,
	0xFFFD: 0xFCC7,
	0xFFFD: 0xFCC8,
	0xFFFD: 0xFCC9,
	0xFFFD: 0xFCCA,
	0xFFFD: 0xFCCB,
	0xFFFD: 0xFCCC,
	0xFFFD: 0xFCCD,
	0xFFFD: 0xFCCE,
	0xFFFD: 0xFCCF,
	0xFFFD: 0xFCD0,
	0xFFFD: 0xFCD1,
	0xFFFD: 0xFCD2,
	0xFFFD: 0xFCD3,
	0xFFFD: 0xFCD4,
	0xFFFD: 0xFCD5,
	0xFFFD: 0xFCD6,
	0xFFFD: 0xFCD7,
	0xFFFD: 0xFCD8,
	0xFFFD: 0xFCD9,
	0xFFFD: 0xFCDA,
	0xFFFD: 0xFCDB,
	0xFFFD: 0xFCDC,
	0xFFFD: 0xFCDD,
	0xFFFD: 0xFCDE,
	0xFFFD: 0xFCDF,
	0xFFFD: 0xFCE0,
	0xFFFD: 0xFCE1,
	0xFFFD: 0xFCE2,
	0xFFFD: 0xFCE3,
	0xFFFD: 0xFCE4,
	0xFFFD: 0xFCE5,
	0xFFFD: 0xFCE6,
	0xFFFD: 0xFCE7,
	0xFFFD: 0xFCE8,
	0xFFFD: 0xFCE9,
	0xFFFD: 0xFCEA,
	0xFFFD: 0xFCEB,
	0xFFFD: 0xFCEC,
	0xFFFD: 0xFCED,
	0xFFFD: 0xFCEE,
	0xFFFD: 0xFCEF,
	0xFFFD: 0xFCF0,
	0xFFFD: 0xFCF1,
	0xFFFD: 0xFCF2,
	0xFFFD: 0xFCF3,
	0xFFFD: 0xFCF4,
	0xFFFD: 0xFCF5,
	0xFFFD: 0xFCF6,
	0xFFFD: 0xFCF7,
	0xFFFD: 0xFCF8,
	0xFFFD: 0xFCF9,
	0xFFFD: 0xFCFA,
	0xFFFD: 0xFCFB,
	0xFFFD: 0xFCFC,
	0xFFFD: 0xFCFD,
	0xFFFD: 0xFCFE,
	0xFFFD: 0xFCFF,
	0xFFFD: 0xFD00,
	0xFFFD: 0xFD01,
	0xFFFD: 0xFD02,
	0xFFFD: 0xFD03,
	0xFFFD: 0xFD04,
	0xFFFD: 0xFD05,
	0xFFFD: 0xFD06,
	0xFFFD: 0xFD07,
	0xFFFD: 0xFD08,
	0xFFFD: 0xFD09,
	0xFFFD: 0xFD0A,
	0xFFFD: 0xFD0B,
	0xFFFD: 0xFD0C,
	0xFFFD: 0xFD0D,
	0xFFFD: 0xFD0E,
	0xFFFD: 0xFD0F,
	0xFFFD: 0xFD10,
	0xFFFD: 0xFD11,
	0xFFFD: 0xFD12,
	0xFFFD: 0xFD13,
	0xFFFD: 0xFD14,
	0xFFFD: 0xFD15,
	0xFFFD: 0xFD16,
	0xFFFD: 0xFD17,
	0xFFFD: 0xFD18,
	0xFFFD: 0xFD19,
	0xFFFD: 0xFD1A,
	0xFFFD: 0xFD1B,
	0xFFFD: 0xFD1C,
	0xFFFD: 0xFD1D,
	0xFFFD: 0xFD1E,
	0xFFFD: 0xFD1F,
	0xFFFD: 0xFD20,
	0xFFFD: 0xFD21,
	0xFFFD: 0xFD22,
	0xFFFD: 0xFD23,
	0xFFFD: 0xFD24,
	0xFFFD: 0xFD25,
	0xFFFD: 0xFD26,
	0xFFFD: 0xFD27,
	0xFFFD: 0xFD28,
	0xFFFD: 0xFD29,
	0xFFFD: 0xFD2A,
	0xFFFD: 0xFD2B,
	0xFFFD: 0xFD2C,
	0xFFFD: 0xFD2D,
	0xFFFD: 0xFD2E,
	0xFFFD: 0xFD2F,
	0xFFFD: 0xFD30,
	0xFFFD: 0xFD31,
	0xFFFD: 0xFD32,
	0xFFFD: 0xFD33,
	0xFFFD: 0xFD34,
	0xFFFD: 0xFD35,
	0xFFFD: 0xFD36,
	0xFFFD: 0xFD37,
	0xFFFD: 0xFD38,
	0xFFFD: 0xFD39,
	0xFFFD: 0xFD3A,
	0xFFFD: 0xFD3B,
	0xFFFD: 0xFD3C,
	0xFFFD: 0xFD3D,
	0xFFFD: 0xFD3E,
	0xFFFD: 0xFD3F,
	0xFFFD: 0xFD40,
	0xFFFD: 0xFD41,
	0xFFFD: 0xFD42,
	0xFFFD: 0xFD43,
	0xFFFD: 0xFD44,
	0xFFFD: 0xFD45,
	0xFFFD: 0xFD46,
	0xFFFD: 0xFD47,
	0xFFFD: 0xFD48,
	0xFFFD: 0xFD49,
	0xFFFD: 0xFD4A,
	0xFFFD: 0xFD4B,
	0xFFFD: 0xFD4C,
	0xFFFD: 0xFD4D,
	0xFFFD: 0xFD4E,
	0xFFFD: 0xFD4F,
	0xFFFD: 0xFD50,
	0xFFFD: 0xFD51,
	0xFFFD: 0xFD52,
	0xFFFD: 0xFD53,
	0xFFFD: 0xFD54,
	0xFFFD: 0xFD55,
	0xFFFD: 0xFD56,
	0xFFFD: 0xFD57,
	0xFFFD: 0xFD58,
	0xFFFD: 0xFD59,
	0xFFFD: 0xFD5A,
	0xFFFD: 0xFD5B,
	0xFFFD: 0xFD5C,
	0xFFFD: 0xFD5D,
	0xFFFD: 0xFD5E,
	0xFFFD: 0xFD5F,
	0xFFFD: 0xFD60,
	0xFFFD: 0xFD61,
	0xFFFD: 0xFD62,
	0xFFFD: 0xFD63,
	0xFFFD: 0xFD64,
	0xFFFD: 0xFD65,
	0xFFFD: 0xFD66,
	0xFFFD: 0xFD67,
	0xFFFD: 0xFD68,
	0xFFFD: 0xFD69,
	0xFFFD: 0xFD6A,
	0xFFFD: 0xFD6B,
	0xFFFD: 0xFD6C,
	0xFFFD: 0xFD6D,
	0xFFFD: 0xFD6E,
	0xFFFD: 0xFD6F,
	0xFFFD: 0xFD70,
	0xFFFD: 0xFD71,
	0xFFFD: 0xFD72,
	0xFFFD: 0xFD73,
	0xFFFD: 0xFD74,
	0xFFFD: 0xFD75,
	0xFFFD: 0xFD76,
	0xFFFD: 0xFD77,
	0xFFFD: 0xFD78,
	0xFFFD: 0xFD79,
	0xFFFD: 0xFD7A,
	0xFFFD: 0xFD7B,
	0xFFFD: 0xFD7C,
	0xFFFD: 0xFD7D,
	0xFFFD: 0xFD7E,
	0xFFFD: 0xFD7F,
	0xFFFD: 0xFD80,
	0xFFFD: 0xFD81,
	0xFFFD: 0xFD82,
	0xFFFD: 0xFD83,
	0xFFFD: 0xFD84,
	0xFFFD: 0xFD85,
	0xFFFD: 0xFD86,
	0xFFFD: 0xFD87,
	0xFFFD: 0xFD88,
	0xFFFD: 0xFD89,
	0xFFFD: 0xFD8A,
	0xFFFD: 0xFD8B,
	0xFFFD: 0xFD8C,
	0xFFFD: 0xFD8D,
	0xFFFD: 0xFD8E,
	0xFFFD: 0xFD8F,
	0xFFFD: 0xFD90,
	0xFFFD: 0xFD91,
	0xFFFD: 0xFD92,
	0xFFFD: 0xFD93,
	0xFFFD: 0xFD94,
	0xFFFD: 0xFD95,
	0xFFFD: 0xFD96,
	0xFFFD: 0xFD97,
	0xFFFD: 0xFD98,
	0xFFFD: 0xFD99,
	0xFFFD: 0xFD9A,
	0xFFFD: 0xFD9B,
	0xFFFD: 0xFD9C,
	0xFFFD: 0xFD9D,
	0xFFFD: 0xFD9E,
	0xFFFD: 0xFD9F,
	0xFFFD: 0xFDA0,
	0xFFFD: 0xFDA1,
	0xFFFD: 0xFDA2,
	0xFFFD: 0xFDA3,
	0xFFFD: 0xFDA4,
	0xFFFD: 0xFDA5,
	0xFFFD: 0xFDA6,
	0xFFFD: 0xFDA7,
	0xFFFD: 0xFDA8,
	0xFFFD: 0xFDA9,
	0xFFFD: 0xFDAA,
	0xFFFD: 0xFDAB,
	0xFFFD: 0xFDAC,
	0xFFFD: 0xFDAD,
	0xFFFD: 0xFDAE,
	0xFFFD: 0xFDAF,
	0xFFFD: 0xFDB0,
	0xFFFD: 0xFDB1,
	0xFFFD: 0xFDB2,
	0xFFFD: 0xFDB3,
	0xFFFD: 0xFDB4,
	0xFFFD: 0xFDB5,
	0xFFFD: 0xFDB6,
	0xFFFD: 0xFDB7,
	0xFFFD: 0xFDB8,
	0xFFFD: 0xFDB9,
	0xFFFD: 0xFDBA,
	0xFFFD: 0xFDBB,
	0xFFFD: 0xFDBC,
	0xFFFD: 0xFDBD,
	0xFFFD: 0xFDBE,
	0xFFFD: 0xFDBF,
	0xFFFD: 0xFDC0,
	0xFFFD: 0xFDC1,
	0xFFFD: 0xFDC2,
	0xFFFD: 0xFDC3,
	0xFFFD: 0xFDC4,
	0xFFFD: 0xFDC5,
	0xFFFD: 0xFDC6,
	0xFFFD: 0xFDC7,
	0xFFFD: 0xFDC8,
	0xFFFD: 0xFDC9,
	0xFFFD: 0xFDCA,
	0xFFFD: 0xFDCB,
	0xFFFD: 0xFDCC,
	0xFFFD: 0xFDCD,
	0xFFFD: 0xFDCE,
	0xFFFD: 0xFDCF,
	0xFFFD: 0xFDD0,
	0xFFFD: 0xFDD1,
	0xFFFD: 0xFDD2,
	0xFFFD: 0xFDD3,
	0xFFFD: 0xFDD4,
	0xFFFD: 0xFDD5,
	0xFFFD: 0xFDD6,
	0xFFFD: 0xFDD7,
	0xFFFD: 0xFDD8,
	0xFFFD: 0xFDD9,
	0xFFFD: 0xFDDA,
	0xFFFD: 0xFDDB,
	0xFFFD: 0xFDDC,
	0xFFFD: 0xFDDD,
	0xFFFD: 0xFDDE,
	0xFFFD: 0xFDDF,
	0xFFFD: 0xFDE0,
	0xFFFD: 0xFDE1,
	0xFFFD: 0xFDE2,
	0xFFFD: 0xFDE3,
	0xFFFD: 0xFDE4,
	0xFFFD: 0xFDE5,
	0xFFFD: 0xFDE6,
	0xFFFD: 0xFDE7,
	0xFFFD: 0xFDE8,
	0xFFFD: 0xFDE9,
	0xFFFD: 0xFDEA,
	0xFFFD: 0xFDEB,
	0xFFFD: 0xFDEC,
	0xFFFD: 0xFDED,
	0xFFFD: 0xFDEE,
	0xFFFD: 0xFDEF,
	0xFFFD: 0xFDF0,
	0xFFFD: 0xFDF1,
	0xFFFD: 0xFDF2,
	0xFFFD: 0xFDF3,
	0xFFFD: 0xFDF4,
	0xFFFD: 0xFDF5,
	0xFFFD: 0xFDF6,
	0xFFFD: 0xFDF7,
	0xFFFD: 0xFDF8,
	0xFFFD: 0xFDF9,
	0xFFFD: 0xFDFA,
	0xFFFD: 0xFDFB,
	0xFFFD: 0xFDFC,
	0xFFFD: 0xFDFD,
	0xFFFD: 0xFDFE,
	0xFFFD: 0xFDFF,
	0xFFFD: 0xFE00,
	0xFFFD: 0xFE01,
	0xFFFD: 0xFE02,
	0xFFFD: 0xFE03,
	0xFFFD: 0xFE04,
	0xFFFD: 0xFE05,
	0xFFFD: 0xFE06,
	0xFFFD: 0xFE07,
	0xFFFD: 0xFE08,
	0xFFFD: 0xFE09,
	0xFFFD: 0xFE0A,
	0xFFFD: 0xFE0B,
	0xFFFD: 0xFE0C,
	0xFFFD: 0xFE0D,
	0xFFFD: 0xFE0E,
	0xFFFD: 0xFE0F,
	0xFFFD: 0xFE10,
	0xFFFD: 0xFE11,
	0xFFFD: 0xFE12,
	0xFFFD: 0xFE13,
	0xFFFD: 0xFE14,
	0xFFFD: 0xFE15,
	0xFFFD: 0xFE16,
	0xFFFD: 0xFE17,
	0xFFFD: 0xFE18,
	0xFFFD: 0xFE19,
	0xFFFD: 0xFE1A,
	0xFFFD: 0xFE1B,
	0xFFFD: 0xFE1C,
	0xFFFD: 0xFE1D,
	0xFFFD: 0xFE1E,
	0xFFFD: 0xFE1F,
	0xFFFD: 0xFE20,
	0xFFFD: 0xFE21,
	0xFFFD: 0xFE22,
	0xFFFD: 0xFE23,
	0xFFFD: 0xFE24,
	0xFFFD: 0xFE25,
	0xFFFD: 0xFE26,
	0xFFFD: 0xFE27,
	0xFFFD: 0xFE28,
	0xFFFD: 0xFE29,
	0xFFFD: 0xFE2A,
	0xFFFD: 0xFE2B,
	0xFFFD: 0xFE2C,
	0xFFFD: 0xFE2D,
	0xFFFD: 0xFE2E,
	0xFFFD: 0xFE2F,
	0xA14A: 0xFE30,
	0xA157: 0xFE31,
	0xFFFD: 0xFE32,
	0xA159: 0xFE33,
	0xA15B: 0xFE34,
	0xA15F: 0xFE35,
	0xA160: 0xFE36,
	0xA163: 0xFE37,
	0xA164: 0xFE38,
	0xA167: 0xFE39,
	0xA168: 0xFE3A,
	0xA16B: 0xFE3B,
	0xA16C: 0xFE3C,
	0xA16F: 0xFE3D,
	0xA170: 0xFE3E,
	0xA173: 0xFE3F,
	0xA174: 0xFE40,
	0xA177: 0xFE41,
	0xA178: 0xFE42,
	0xA17B: 0xFE43,
	0xA17C: 0xFE44,
	0xFFFD: 0xFE45,
	0xFFFD: 0xFE46,
	0xFFFD: 0xFE47,
	0xFFFD: 0xFE48,
	0xA1C6: 0xFE49,
	0xA1C7: 0xFE4A,
	0xA1CA: 0xFE4B,
	0xA1CB: 0xFE4C,
	0xA1C8: 0xFE4D,
	0xA1C9: 0xFE4E,
	0xA15C: 0xFE4F,
	0xA14D: 0xFE50,
	0xA14E: 0xFE51,
	0xA14F: 0xFE52,
	0xFFFD: 0xFE53,
	0xA151: 0xFE54,
	0xA152: 0xFE55,
	0xA153: 0xFE56,
	0xA154: 0xFE57,
	0xFFFD: 0xFE58,
	0xA17D: 0xFE59,
	0xA17E: 0xFE5A,
	0xA1A1: 0xFE5B,
	0xA1A2: 0xFE5C,
	0xA1A3: 0xFE5D,
	0xA1A4: 0xFE5E,
	0xA1CC: 0xFE5F,
	0xA1CD: 0xFE60,
	0xA1CE: 0xFE61,
	0xA1DE: 0xFE62,
	0xA1DF: 0xFE63,
	0xA1E0: 0xFE64,
	0xA1E1: 0xFE65,
	0xA1E2: 0xFE66,
	0xFFFD: 0xFE67,
	0xA242: 0xFE68,
	0xA24C: 0xFE69,
	0xA24D: 0xFE6A,
	0xA24E: 0xFE6B,
	0xFFFD: 0xFE6C,
	0xFFFD: 0xFE6D,
	0xFFFD: 0xFE6E,
	0xFFFD: 0xFE6F,
	0xFFFD: 0xFE70,
	0xFFFD: 0xFE71,
	0xFFFD: 0xFE72,
	0xFFFD: 0xFE73,
	0xFFFD: 0xFE74,
	0xFFFD: 0xFE75,
	0xFFFD: 0xFE76,
	0xFFFD: 0xFE77,
	0xFFFD: 0xFE78,
	0xFFFD: 0xFE79,
	0xFFFD: 0xFE7A,
	0xFFFD: 0xFE7B,
	0xFFFD: 0xFE7C,
	0xFFFD: 0xFE7D,
	0xFFFD: 0xFE7E,
	0xFFFD: 0xFE7F,
	0xFFFD: 0xFE80,
	0xFFFD: 0xFE81,
	0xFFFD: 0xFE82,
	0xFFFD: 0xFE83,
	0xFFFD: 0xFE84,
	0xFFFD: 0xFE85,
	0xFFFD: 0xFE86,
	0xFFFD: 0xFE87,
	0xFFFD: 0xFE88,
	0xFFFD: 0xFE89,
	0xFFFD: 0xFE8A,
	0xFFFD: 0xFE8B,
	0xFFFD: 0xFE8C,
	0xFFFD: 0xFE8D,
	0xFFFD: 0xFE8E,
	0xFFFD: 0xFE8F,
	0xFFFD: 0xFE90,
	0xFFFD: 0xFE91,
	0xFFFD: 0xFE92,
	0xFFFD: 0xFE93,
	0xFFFD: 0xFE94,
	0xFFFD: 0xFE95,
	0xFFFD: 0xFE96,
	0xFFFD: 0xFE97,
	0xFFFD: 0xFE98,
	0xFFFD: 0xFE99,
	0xFFFD: 0xFE9A,
	0xFFFD: 0xFE9B,
	0xFFFD: 0xFE9C,
	0xFFFD: 0xFE9D,
	0xFFFD: 0xFE9E,
	0xFFFD: 0xFE9F,
	0xFFFD: 0xFEA0,
	0xFFFD: 0xFEA1,
	0xFFFD: 0xFEA2,
	0xFFFD: 0xFEA3,
	0xFFFD: 0xFEA4,
	0xFFFD: 0xFEA5,
	0xFFFD: 0xFEA6,
	0xFFFD: 0xFEA7,
	0xFFFD: 0xFEA8,
	0xFFFD: 0xFEA9,
	0xFFFD: 0xFEAA,
	0xFFFD: 0xFEAB,
	0xFFFD: 0xFEAC,
	0xFFFD: 0xFEAD,
	0xFFFD: 0xFEAE,
	0xFFFD: 0xFEAF,
	0xFFFD: 0xFEB0,
	0xFFFD: 0xFEB1,
	0xFFFD: 0xFEB2,
	0xFFFD: 0xFEB3,
	0xFFFD: 0xFEB4,
	0xFFFD: 0xFEB5,
	0xFFFD: 0xFEB6,
	0xFFFD: 0xFEB7,
	0xFFFD: 0xFEB8,
	0xFFFD: 0xFEB9,
	0xFFFD: 0xFEBA,
	0xFFFD: 0xFEBB,
	0xFFFD: 0xFEBC,
	0xFFFD: 0xFEBD,
	0xFFFD: 0xFEBE,
	0xFFFD: 0xFEBF,
	0xFFFD: 0xFEC0,
	0xFFFD: 0xFEC1,
	0xFFFD: 0xFEC2,
	0xFFFD: 0xFEC3,
	0xFFFD: 0xFEC4,
	0xFFFD: 0xFEC5,
	0xFFFD: 0xFEC6,
	0xFFFD: 0xFEC7,
	0xFFFD: 0xFEC8,
	0xFFFD: 0xFEC9,
	0xFFFD: 0xFECA,
	0xFFFD: 0xFECB,
	0xFFFD: 0xFECC,
	0xFFFD: 0xFECD,
	0xFFFD: 0xFECE,
	0xFFFD: 0xFECF,
	0xFFFD: 0xFED0,
	0xFFFD: 0xFED1,
	0xFFFD: 0xFED2,
	0xFFFD: 0xFED3,
	0xFFFD: 0xFED4,
	0xFFFD: 0xFED5,
	0xFFFD: 0xFED6,
	0xFFFD: 0xFED7,
	0xFFFD: 0xFED8,
	0xFFFD: 0xFED9,
	0xFFFD: 0xFEDA,
	0xFFFD: 0xFEDB,
	0xFFFD: 0xFEDC,
	0xFFFD: 0xFEDD,
	0xFFFD: 0xFEDE,
	0xFFFD: 0xFEDF,
	0xFFFD: 0xFEE0,
	0xFFFD: 0xFEE1,
	0xFFFD: 0xFEE2,
	0xFFFD: 0xFEE3,
	0xFFFD: 0xFEE4,
	0xFFFD: 0xFEE5,
	0xFFFD: 0xFEE6,
	0xFFFD: 0xFEE7,
	0xFFFD: 0xFEE8,
	0xFFFD: 0xFEE9,
	0xFFFD: 0xFEEA,
	0xFFFD: 0xFEEB,
	0xFFFD: 0xFEEC,
	0xFFFD: 0xFEED,
	0xFFFD: 0xFEEE,
	0xFFFD: 0xFEEF,
	0xFFFD: 0xFEF0,
	0xFFFD: 0xFEF1,
	0xFFFD: 0xFEF2,
	0xFFFD: 0xFEF3,
	0xFFFD: 0xFEF4,
	0xFFFD: 0xFEF5,
	0xFFFD: 0xFEF6,
	0xFFFD: 0xFEF7,
	0xFFFD: 0xFEF8,
	0xFFFD: 0xFEF9,
	0xFFFD: 0xFEFA,
	0xFFFD: 0xFEFB,
	0xFFFD: 0xFEFC,
	0xFFFD: 0xFEFD,
	0xFFFD: 0xFEFE,
	0xFFFD: 0xFEFF,
	0xFFFD: 0xFF00,
	0xA149: 0xFF01,
	0xC8D0: 0xFF02,
	0xA1AD: 0xFF03,
	0xA243: 0xFF04,
	0xA248: 0xFF05,
	0xA1AE: 0xFF06,
	0x91C2: 0xFF07,
	0xA15D: 0xFF08,
	0xA15E: 0xFF09,
	0xA1AF: 0xFF0A,
	0xA1CF: 0xFF0B,
	0xA141: 0xFF0C,
	0xA1D0: 0xFF0D,
	0xA144: 0xFF0E,
	0xA1FE: 0xFF0F,
	0xA2AF: 0xFF10,
	0xA2B0: 0xFF11,
	0xA2B1: 0xFF12,
	0xA2B2: 0xFF13,
	0xA2B3: 0xFF14,
	0xA2B4: 0xFF15,
	0xA2B5: 0xFF16,
	0xA2B6: 0xFF17,
	0xA2B7: 0xFF18,
	0xA2B8: 0xFF19,
	0xA147: 0xFF1A,
	0xA146: 0xFF1B,
	0xA1D5: 0xFF1C,
	0xA1D7: 0xFF1D,
	0xA1D6: 0xFF1E,
	0xA148: 0xFF1F,
	0xA249: 0xFF20,
	0xA2CF: 0xFF21,
	0xA2D0: 0xFF22,
	0xA2D1: 0xFF23,
	0xA2D2: 0xFF24,
	0xA2D3: 0xFF25,
	0xA2D4: 0xFF26,
	0xA2D5: 0xFF27,
	0xA2D6: 0xFF28,
	0xA2D7: 0xFF29,
	0xA2D8: 0xFF2A,
	0xA2D9: 0xFF2B,
	0xA2DA: 0xFF2C,
	0xA2DB: 0xFF2D,
	0xA2DC: 0xFF2E,
	0xA2DD: 0xFF2F,
	0xA2DE: 0xFF30,
	0xA2DF: 0xFF31,
	0xA2E0: 0xFF32,
	0xA2E1: 0xFF33,
	0xA2E2: 0xFF34,
	0xA2E3: 0xFF35,
	0xA2E4: 0xFF36,
	0xA2E5: 0xFF37,
	0xA2E6: 0xFF38,
	0xA2E7: 0xFF39,
	0xA2E8: 0xFF3A,
	0xC6E4: 0xFF3B,
	0xA240: 0xFF3C,
	0xC6E5: 0xFF3D,
	0x5E20: 0xFF3E,
	0xA1C4: 0xFF3F,
	0xA1AB: 0xFF40,
	0xA2E9: 0xFF41,
	0xA2EA: 0xFF42,
	0xA2EB: 0xFF43,
	0xA2EC: 0xFF44,
	0xA2ED: 0xFF45,
	0xA2EE: 0xFF46,
	0xA2EF: 0xFF47,
	0xA2F0: 0xFF48,
	0xA2F1: 0xFF49,
	0xA2F2: 0xFF4A,
	0xA2F3: 0xFF4B,
	0xA2F4: 0xFF4C,
	0xA2F5: 0xFF4D,
	0xA2F6: 0xFF4E,
	0xA2F7: 0xFF4F,
	0xA2F8: 0xFF50,
	0xA2F9: 0xFF51,
	0xA2FA: 0xFF52,
	0xA2FB: 0xFF53,
	0xA2FC: 0xFF54,
	0xA2FD: 0xFF55,
	0xA2FE: 0xFF56,
	0xA340: 0xFF57,
	0xA341: 0xFF58,
	0xA342: 0xFF59,
	0xA343: 0xFF5A,
	0xA161: 0xFF5B,
	0xA155: 0xFF5C,
	0xA162: 0xFF5D,
	0xA1E3: 0xFF5E,
	0xFFFD: 0xFF5F,
	0xFFFD: 0xFF60,
	0xC8B9: 0xFF61,
	0xC8BA: 0xFF62,
	0xC8BB: 0xFF63,
	0xC8BC: 0xFF64,
	0xC8BD: 0xFF65,
	0xC8BE: 0xFF66,
	0xC8BF: 0xFF67,
	0xC8C0: 0xFF68,
	0xC8C1: 0xFF69,
	0xC8C2: 0xFF6A,
	0xC8C3: 0xFF6B,
	0xC8C4: 0xFF6C,
	0xC8C5: 0xFF6D,
	0xC8C6: 0xFF6E,
	0xC8C7: 0xFF6F,
	0xC8C8: 0xFF70,
	0xC8C9: 0xFF71,
	0xC8CA: 0xFF72,
	0xC8CB: 0xFF73,
	0xC8CC: 0xFF74,
	0xC8D4: 0xFF75,
	0xC8D5: 0xFF76,
	0xC8D6: 0xFF77,
	0xC8D7: 0xFF78,
	0xC8D8: 0xFF79,
	0xC8D9: 0xFF7A,
	0xC8DA: 0xFF7B,
	0xC8DB: 0xFF7C,
	0xC8DC: 0xFF7D,
	0xC8DD: 0xFF7E,
	0xC8DE: 0xFF7F,
	0xC8DF: 0xFF80,
	0xC8E0: 0xFF81,
	0xC8E1: 0xFF82,
	0xC8E2: 0xFF83,
	0xC8E3: 0xFF84,
	0xC8E4: 0xFF85,
	0xC8E5: 0xFF86,
	0xC8E6: 0xFF87,
	0xC8E7: 0xFF88,
	0xC8E8: 0xFF89,
	0xC8E9: 0xFF8A,
	0xC8EA: 0xFF8B,
	0xC8EB: 0xFF8C,
	0xC8EC: 0xFF8D,
	0xC8ED: 0xFF8E,
	0xC8EE: 0xFF8F,
	0xC8EF: 0xFF90,
	0xC8F0: 0xFF91,
	0xC8F1: 0xFF92,
	0xC8F2: 0xFF93,
	0xC8F3: 0xFF94,
	0xC8F4: 0xFF95,
	0xC8F5: 0xFF96,
	0xC8F6: 0xFF97,
	0xC8F7: 0xFF98,
	0xC8F8: 0xFF99,
	0xC8F9: 0xFF9A,
	0xC8FA: 0xFF9B,
	0xC8FB: 0xFF9C,
	0xC8FC: 0xFF9D,
	0xC8FD: 0xFF9E,
	0xC8FE: 0xFF9F,
	0xFFFD: 0xFFA0,
	0xFFFD: 0xFFA1,
	0xFFFD: 0xFFA2,
	0xFFFD: 0xFFA3,
	0xFFFD: 0xFFA4,
	0xFFFD: 0xFFA5,
	0xFFFD: 0xFFA6,
	0xFFFD: 0xFFA7,
	0xFFFD: 0xFFA8,
	0xFFFD: 0xFFA9,
	0xFFFD: 0xFFAA,
	0xFFFD: 0xFFAB,
	0xFFFD: 0xFFAC,
	0xFFFD: 0xFFAD,
	0xFFFD: 0xFFAE,
	0xFFFD: 0xFFAF,
	0xFFFD: 0xFFB0,
	0xFFFD: 0xFFB1,
	0xFFFD: 0xFFB2,
	0xFFFD: 0xFFB3,
	0xFFFD: 0xFFB4,
	0xFFFD: 0xFFB5,
	0xFFFD: 0xFFB6,
	0xFFFD: 0xFFB7,
	0xFFFD: 0xFFB8,
	0xFFFD: 0xFFB9,
	0xFFFD: 0xFFBA,
	0xFFFD: 0xFFBB,
	0xFFFD: 0xFFBC,
	0xFFFD: 0xFFBD,
	0xFFFD: 0xFFBE,
	0xFFFD: 0xFFBF,
	0xFFFD: 0xFFC0,
	0xFFFD: 0xFFC1,
	0xFFFD: 0xFFC2,
	0xFFFD: 0xFFC3,
	0xFFFD: 0xFFC4,
	0xFFFD: 0xFFC5,
	0xFFFD: 0xFFC6,
	0xFFFD: 0xFFC7,
	0xFFFD: 0xFFC8,
	0xFFFD: 0xFFC9,
	0xFFFD: 0xFFCA,
	0xFFFD: 0xFFCB,
	0xFFFD: 0xFFCC,
	0xFFFD: 0xFFCD,
	0xFFFD: 0xFFCE,
	0xFFFD: 0xFFCF,
	0xFFFD: 0xFFD0,
	0xFFFD: 0xFFD1,
	0xFFFD: 0xFFD2,
	0xFFFD: 0xFFD3,
	0xFFFD: 0xFFD4,
	0xFFFD: 0xFFD5,
	0xFFFD: 0xFFD6,
	0xFFFD: 0xFFD7,
	0xFFFD: 0xFFD8,
	0xFFFD: 0xFFD9,
	0xFFFD: 0xFFDA,
	0xFFFD: 0xFFDB,
	0xFFFD: 0xFFDC,
	0xFFFD: 0xFFDD,
	0xFFFD: 0xFFDE,
	0xFFFD: 0xFFDF,
	0xA246: 0xFFE0,
	0xA247: 0xFFE1,
	0xC8CD: 0xFFE2,
	0xA1C3: 0xFFE3,
	0xC8CE: 0xFFE4,
	0xA244: 0xFFE5,
	0xFFFD: 0xFFE6,
	0xFFFD: 0xFFE7,
	0xA278: 0xFFE8,
	0xA1F6: 0xFFE9,
	0xA1F4: 0xFFEA,
	0xA1F7: 0xFFEB,
	0xA1F5: 0xFFEC,
	0xA1BD: 0xFFED,
	0xA1B3: 0xFFEE,
	0xFFFD: 0xFFEF,
	0xFFFD: 0xFFF0,
	0xFFFD: 0xFFF1,
	0xFFFD: 0xFFF2,
	0xFFFD: 0xFFF3,
	0xFFFD: 0xFFF4,
	0xFFFD: 0xFFF5,
	0xFFFD: 0xFFF6,
	0xFFFD: 0xFFF7,
	0xFFFD: 0xFFF8,
	0xFFFD: 0xFFF9,
	0xFFFD: 0xFFFA,
	0xFFFD: 0xFFFB,
	0xFFFD: 0xFFFC,
	0xFFFD: 0xFFFD,
	0xFFFD: 0xFFFE,
	0xFFFD: 0xFFFF,
}

### Encoding Map

encoding_map = { 
	0x0081: 0xFFFD,
	0x0082: 0xFFFD,
	0x0083: 0xFFFD,
	0x0084: 0xFFFD,
	0x0085: 0xFFFD,
	0x0086: 0xFFFD,
	0x0087: 0xFFFD,
	0x0088: 0xFFFD,
	0x0089: 0xFFFD,
	0x008A: 0xFFFD,
	0x008B: 0xFFFD,
	0x008C: 0xFFFD,
	0x008D: 0xFFFD,
	0x008E: 0xFFFD,
	0x008F: 0xFFFD,
	0x0090: 0xFFFD,
	0x0091: 0xFFFD,
	0x0092: 0xFFFD,
	0x0093: 0xFFFD,
	0x0094: 0xFFFD,
	0x0095: 0xFFFD,
	0x0096: 0xFFFD,
	0x0097: 0xFFFD,
	0x0098: 0xFFFD,
	0x0099: 0xFFFD,
	0x009A: 0xFFFD,
	0x009B: 0xFFFD,
	0x009C: 0xFFFD,
	0x009D: 0xFFFD,
	0x009E: 0xFFFD,
	0x009F: 0xFFFD,
	0x00A0: 0xFFFD,
	0x00A1: 0xA0DF,
	0x00A2: 0xA246,
	0x00A3: 0xA247,
	0x00A4: 0xA0FC,
	0x00A5: 0xA244,
	0x00A6: 0x7C20,
	0x00A7: 0xA1B1,
	0x00A8: 0xC6D8,
	0x00A9: 0x6320,
	0x00AA: 0xA0DE,
	0x00AB: 0xFFFD,
	0x00AC: 0xFFFD,
	0x00AD: 0x2D20,
	0x00AE: 0x97FB,
	0x00AF: 0xA1C2,
	0x00B0: 0xA258,
	0x00B1: 0xA1D3,
	0x00B2: 0x3220,
	0x00B3: 0x3320,
	0x00B4: 0xA1AC,
	0x00B5: 0xA367,
	0x00B6: 0x91F8,
	0x00B7: 0xA150,
	0x00B8: 0xA0FB,
	0x00B9: 0x3120,
	0x00BA: 0xA0EE,
	0x00BB: 0xFFFD,
	0x00BC: 0xFEB3,
	0x00BD: 0xFEB0,
	0x00BE: 0xFEB4,
	0x00BF: 0xA0EF,
	0x00C0: 0xA0A7,
	0x00C1: 0xA0AC,
	0x00C2: 0xA0F6,
	0x00C3: 0xA0BE,
	0x00C4: 0xA0B6,
	0x00C5: 0xA0D6,
	0x00C6: 0xA0BB,
	0x00C7: 0xA0BC,
	0x00C8: 0xA0A8,
	0x00C9: 0xA0D7,
	0x00CA: 0xA0F7,
	0x00CB: 0xA0B7,
	0x00CC: 0xA0A9,
	0x00CD: 0xA0AD,
	0x00CE: 0xA0F8,
	0x00CF: 0xA0B8,
	0x00D0: 0xA0DA,
	0x00D1: 0xA0BD,
	0x00D2: 0xA0AA,
	0x00D3: 0xA0AE,
	0x00D4: 0xA0F9,
	0x00D5: 0xA0BF,
	0x00D6: 0xA0B9,
	0x00D7: 0xA1D1,
	0x00D8: 0xA0D9,
	0x00D9: 0xA0AB,
	0x00DA: 0xA0AF,
	0x00DB: 0xA0FA,
	0x00DC: 0xA0BA,
	0x00DD: 0x5920,
	0x00DE: 0xA0DC,
	0x00DF: 0xA0DD,
	0x00E0: 0xA0E0,
	0x00E1: 0xA0C0,
	0x00E2: 0xA0F0,
	0x00E3: 0xA0CE,
	0x00E4: 0xA0C6,
	0x00E5: 0xA0E6,
	0x00E6: 0xA0CB,
	0x00E7: 0xA0CC,
	0x00E8: 0xA0E1,
	0x00E9: 0xA0C1,
	0x00EA: 0xA0F1,
	0x00EB: 0xA0C7,
	0x00EC: 0xA0E2,
	0x00ED: 0xA0C2,
	0x00EE: 0xA0F2,
	0x00EF: 0xA0C8,
	0x00F0: 0xA0EA,
	0x00F1: 0xA0CD,
	0x00F2: 0xA0E3,
	0x00F3: 0xA0C3,
	0x00F4: 0xA0F3,
	0x00F5: 0xA0CF,
	0x00F6: 0xA0C9,
	0x00F7: 0xA1D2,
	0x00F8: 0xA0E9,
	0x00F9: 0xA0E4,
	0x00FA: 0xA0C4,
	0x00FB: 0xA0F4,
	0x00FC: 0xA0CA,
	0x00FD: 0x7920,
	0x00FE: 0xA0EC,
	0x00FF: 0xA0ED,
	0x0100: 0xFFFD,
	0x0101: 0xA0B0,
	0x0102: 0xFFFD,
	0x0103: 0xFFFD,
	0x0104: 0xFFFD,
	0x0105: 0xFFFD,
	0x0106: 0xFFFD,
	0x0107: 0xFFFD,
	0x0108: 0xFFFD,
	0x0109: 0xFFFD,
	0x010A: 0xFFFD,
	0x010B: 0xFFFD,
	0x010C: 0xFFFD,
	0x010D: 0xFFFD,
	0x010E: 0xFFFD,
	0x010F: 0xFFFD,
	0x0110: 0xFFFD,
	0x0111: 0xFFFD,
	0x0112: 0xFFFD,
	0x0113: 0xA0B1,
	0x0114: 0xFFFD,
	0x0115: 0xFFFD,
	0x0116: 0xFFFD,
	0x0117: 0xFFFD,
	0x0118: 0xFFFD,
	0x0119: 0xFFFD,
	0x011A: 0xFFFD,
	0x011B: 0xA0D1,
	0x011C: 0xFFFD,
	0x011D: 0xFFFD,
	0x011E: 0xFFFD,
	0x011F: 0xFFFD,
	0x0120: 0xFFFD,
	0x0121: 0xFFFD,
	0x0122: 0xFFFD,
	0x0123: 0xFFFD,
	0x0124: 0xFFFD,
	0x0125: 0xFFFD,
	0x0126: 0xFFFD,
	0x0127: 0xFFFD,
	0x0128: 0xFFFD,
	0x0129: 0xFFFD,
	0x012A: 0xFFFD,
	0x012B: 0xA0B2,
	0x012C: 0xFFFD,
	0x012D: 0xFFFD,
	0x012E: 0xFFFD,
	0x012F: 0xFFFD,
	0x0130: 0xFFFD,
	0x0131: 0xFFFD,
	0x0132: 0xFFFD,
	0x0133: 0xFFFD,
	0x0134: 0xFFFD,
	0x0135: 0xFFFD,
	0x0136: 0xFFFD,
	0x0137: 0xFFFD,
	0x0138: 0xFFFD,
	0x0139: 0xFFFD,
	0x013A: 0xFFFD,
	0x013B: 0xFFFD,
	0x013C: 0xFFFD,
	0x013D: 0xFFFD,
	0x013E: 0xFFFD,
	0x013F: 0xFFFD,
	0x0140: 0xFFFD,
	0x0141: 0xFFFD,
	0x0142: 0xFFFD,
	0x0143: 0xFFFD,
	0x0144: 0xFFFD,
	0x0145: 0xFFFD,
	0x0146: 0xFFFD,
	0x0147: 0xFFFD,
	0x0148: 0xFFFD,
	0x0149: 0xFFFD,
	0x014A: 0x9BD5,
	0x014B: 0xFFFD,
	0x014C: 0xFFFD,
	0x014D: 0xA0B3,
	0x014E: 0xFFFD,
	0x014F: 0xFFFD,
	0x0150: 0xFFFD,
	0x0151: 0xFFFD,
	0x0152: 0xFFFD,
	0x0153: 0x9BE5,
	0x0154: 0xFFFD,
	0x0155: 0xFFFD,
	0x0156: 0xFFFD,
	0x0157: 0xFFFD,
	0x0158: 0xFFFD,
	0x0159: 0xFFFD,
	0x015A: 0xFFFD,
	0x015B: 0xFFFD,
	0x015C: 0xFFFD,
	0x015D: 0xFFFD,
	0x015E: 0xFFFD,
	0x015F: 0xFFFD,
	0x0160: 0xFFFD,
	0x0161: 0xFFFD,
	0x0162: 0xFFFD,
	0x0163: 0xFFFD,
	0x0164: 0xFFFD,
	0x0165: 0xFFFD,
	0x0166: 0xFFFD,
	0x0167: 0xFFFD,
	0x0168: 0xFFFD,
	0x0169: 0xFFFD,
	0x016A: 0xFFFD,
	0x016B: 0xA0B4,
	0x016C: 0xFFFD,
	0x016D: 0xFFFD,
	0x016E: 0xFFFD,
	0x016F: 0xFFFD,
	0x0170: 0xFFFD,
	0x0171: 0xFFFD,
	0x0172: 0xFFFD,
	0x0173: 0xFFFD,
	0x0174: 0xFFFD,
	0x0175: 0xFFFD,
	0x0176: 0xFFFD,
	0x0177: 0xFFFD,
	0x0178: 0xFFFD,
	0x0179: 0xFFFD,
	0x017A: 0xFFFD,
	0x017B: 0xFFFD,
	0x017C: 0xFFFD,
	0x017D: 0xFFFD,
	0x017E: 0xFFFD,
	0x017F: 0xFFFD,
	0x0180: 0xFFFD,
	0x0181: 0xFFFD,
	0x0182: 0xFFFD,
	0x0183: 0xFFFD,
	0x0184: 0xFFFD,
	0x0185: 0xFFFD,
	0x0186: 0xFFFD,
	0x0187: 0xFFFD,
	0x0188: 0xFFFD,
	0x0189: 0xFFFD,
	0x018A: 0xFFFD,
	0x018B: 0xFFFD,
	0x018C: 0xFFFD,
	0x018D: 0xFFFD,
	0x018E: 0xFFFD,
	0x018F: 0xFFFD,
	0x0190: 0xFFFD,
	0x0191: 0xFFFD,
	0x0192: 0xA0FE,
	0x0193: 0xFFFD,
	0x0194: 0xFFFD,
	0x0195: 0xFFFD,
	0x0196: 0xFFFD,
	0x0197: 0xFFFD,
	0x0198: 0xFFFD,
	0x0199: 0xFFFD,
	0x019A: 0xFFFD,
	0x019B: 0xFFFD,
	0x019C: 0xFFFD,
	0x019D: 0xFFFD,
	0x019E: 0xFFFD,
	0x019F: 0xFFFD,
	0x01A0: 0xFFFD,
	0x01A1: 0xFFFD,
	0x01A2: 0xFFFD,
	0x01A3: 0xFFFD,
	0x01A4: 0xFFFD,
	0x01A5: 0xFFFD,
	0x01A6: 0xFFFD,
	0x01A7: 0xFFFD,
	0x01A8: 0xFFFD,
	0x01A9: 0xFFFD,
	0x01AA: 0xFFFD,
	0x01AB: 0xFFFD,
	0x01AC: 0xFFFD,
	0x01AD: 0xFFFD,
	0x01AE: 0xFFFD,
	0x01AF: 0xFFFD,
	0x01B0: 0xFFFD,
	0x01B1: 0xFFFD,
	0x01B2: 0xFFFD,
	0x01B3: 0xFFFD,
	0x01B4: 0xFFFD,
	0x01B5: 0xFFFD,
	0x01B6: 0xFFFD,
	0x01B7: 0xFFFD,
	0x01B8: 0xFFFD,
	0x01B9: 0xFFFD,
	0x01BA: 0xFFFD,
	0x01BB: 0xFFFD,
	0x01BC: 0xFFFD,
	0x01BD: 0xFFFD,
	0x01BE: 0xFFFD,
	0x01BF: 0xFFFD,
	0x01C0: 0xFFFD,
	0x01C1: 0xFFFD,
	0x01C2: 0xFFFD,
	0x01C3: 0xFFFD,
	0x01C4: 0xFFFD,
	0x01C5: 0xFFFD,
	0x01C6: 0xFFFD,
	0x01C7: 0xFFFD,
	0x01C8: 0xFFFD,
	0x01C9: 0xFFFD,
	0x01CA: 0xFFFD,
	0x01CB: 0xFFFD,
	0x01CC: 0xFFFD,
	0x01CD: 0xFFFD,
	0x01CE: 0xA0D0,
	0x01CF: 0xFFFD,
	0x01D0: 0xA0D2,
	0x01D1: 0xFFFD,
	0x01D2: 0xA0D3,
	0x01D3: 0xFFFD,
	0x01D4: 0xA0D4,
	0x01D5: 0xFFFD,
	0x01D6: 0xA0B5,
	0x01D7: 0xFFFD,
	0x01D8: 0xA0C5,
	0x01D9: 0xFFFD,
	0x01DA: 0xA0D5,
	0x01DB: 0xFFFD,
	0x01DC: 0xA0E5,
	0x01DD: 0xFFFD,
	0x01DE: 0xFFFD,
	0x01DF: 0xFFFD,
	0x01E0: 0xFFFD,
	0x01E1: 0xFFFD,
	0x01E2: 0xFFFD,
	0x01E3: 0xFFFD,
	0x01E4: 0xFFFD,
	0x01E5: 0xFFFD,
	0x01E6: 0xFFFD,
	0x01E7: 0xFFFD,
	0x01E8: 0xFFFD,
	0x01E9: 0xFFFD,
	0x01EA: 0xFFFD,
	0x01EB: 0xFFFD,
	0x01EC: 0xFFFD,
	0x01ED: 0xFFFD,
	0x01EE: 0xFFFD,
	0x01EF: 0xFFFD,
	0x01F0: 0xFFFD,
	0x01F1: 0xFFFD,
	0x01F2: 0xFFFD,
	0x01F3: 0xFFFD,
	0x01F4: 0xFFFD,
	0x01F5: 0xFFFD,
	0x01F6: 0xFFFD,
	0x01F7: 0xFFFD,
	0x01F8: 0xFFFD,
	0x01F9: 0xFFFD,
	0x01FA: 0xFFFD,
	0x01FB: 0xFFFD,
	0x01FC: 0xFFFD,
	0x01FD: 0xFFFD,
	0x01FE: 0xFFFD,
	0x01FF: 0xFFFD,
	0x0200: 0xFFFD,
	0x0201: 0xFFFD,
	0x0202: 0xFFFD,
	0x0203: 0xFFFD,
	0x0204: 0xFFFD,
	0x0205: 0xFFFD,
	0x0206: 0xFFFD,
	0x0207: 0xFFFD,
	0x0208: 0xFFFD,
	0x0209: 0xFFFD,
	0x020A: 0xFFFD,
	0x020B: 0xFFFD,
	0x020C: 0xFFFD,
	0x020D: 0xFFFD,
	0x020E: 0xFFFD,
	0x020F: 0xFFFD,
	0x0210: 0xFFFD,
	0x0211: 0xFFFD,
	0x0212: 0xFFFD,
	0x0213: 0xFFFD,
	0x0214: 0xFFFD,
	0x0215: 0xFFFD,
	0x0216: 0xFFFD,
	0x0217: 0xFFFD,
	0x0218: 0xFFFD,
	0x0219: 0xFFFD,
	0x021A: 0xFFFD,
	0x021B: 0xFFFD,
	0x021C: 0xFFFD,
	0x021D: 0xFFFD,
	0x021E: 0xFFFD,
	0x021F: 0xFFFD,
	0x0220: 0xFFFD,
	0x0221: 0xFFFD,
	0x0222: 0xFFFD,
	0x0223: 0xFFFD,
	0x0224: 0xFFFD,
	0x0225: 0xFFFD,
	0x0226: 0xFFFD,
	0x0227: 0xFFFD,
	0x0228: 0xFFFD,
	0x0229: 0xFFFD,
	0x022A: 0xFFFD,
	0x022B: 0xFFFD,
	0x022C: 0xFFFD,
	0x022D: 0xFFFD,
	0x022E: 0xFFFD,
	0x022F: 0xFFFD,
	0x0230: 0xFFFD,
	0x0231: 0xFFFD,
	0x0232: 0xFFFD,
	0x0233: 0xFFFD,
	0x0234: 0xFFFD,
	0x0235: 0xFFFD,
	0x0236: 0xFFFD,
	0x0237: 0xFFFD,
	0x0238: 0xFFFD,
	0x0239: 0xFFFD,
	0x023A: 0xFFFD,
	0x023B: 0xFFFD,
	0x023C: 0xFFFD,
	0x023D: 0xFFFD,
	0x023E: 0xFFFD,
	0x023F: 0xFFFD,
	0x0240: 0xFFFD,
	0x0241: 0xFFFD,
	0x0242: 0xFFFD,
	0x0243: 0xFFFD,
	0x0244: 0xFFFD,
	0x0245: 0xFFFD,
	0x0246: 0xFFFD,
	0x0247: 0xFFFD,
	0x0248: 0xFFFD,
	0x0249: 0xFFFD,
	0x024A: 0xFFFD,
	0x024B: 0xFFFD,
	0x024C: 0xFFFD,
	0x024D: 0xFFFD,
	0x024E: 0xFFFD,
	0x024F: 0xFFFD,
	0x0250: 0xFFFD,
	0x0251: 0x9BCB,
	0x0252: 0x9BE6,
	0x0253: 0xFFFD,
	0x0254: 0x9BCC,
	0x0255: 0xFFFD,
	0x0256: 0xFFFD,
	0x0257: 0xFFFD,
	0x0258: 0xFFFD,
	0x0259: 0x9BCF,
	0x025A: 0x9BD0,
	0x025B: 0x9BC8,
	0x025C: 0x9BD1,
	0x025D: 0x9BCE,
	0x025E: 0xFFFD,
	0x025F: 0xFFFD,
	0x0260: 0xFFFD,
	0x0261: 0x9BD2,
	0x0262: 0xFFFD,
	0x0263: 0xFFFD,
	0x0264: 0xFFFD,
	0x0265: 0xFFFD,
	0x0266: 0xFFFD,
	0x0267: 0xFFFD,
	0x0268: 0xFFFD,
	0x0269: 0xFFFD,
	0x026A: 0x9BC7,
	0x026B: 0xFFFD,
	0x026C: 0xFFFD,
	0x026D: 0xFFFD,
	0x026E: 0xFFFD,
	0x026F: 0x9BE0,
	0x0270: 0xFFFD,
	0x0271: 0xFFFD,
	0x0272: 0xFFFD,
	0x0273: 0xFFFD,
	0x0274: 0xFFFD,
	0x0275: 0x9BD7,
	0x0276: 0xFFFD,
	0x0277: 0xFFFD,
	0x0278: 0x9BE1,
	0x0279: 0xFFFD,
	0x027A: 0xFFFD,
	0x027B: 0xFFFD,
	0x027C: 0xFFFD,
	0x027D: 0xFFFD,
	0x027E: 0xFFFD,
	0x027F: 0xFFFD,
	0x0280: 0xFFFD,
	0x0281: 0xFFFD,
	0x0282: 0xFFFD,
	0x0283: 0x9BD9,
	0x0284: 0xFFFD,
	0x0285: 0xFFFD,
	0x0286: 0xFFFD,
	0x0287: 0x9BE2,
	0x0288: 0xFFFD,
	0x0289: 0xFFFD,
	0x028A: 0x9BCD,
	0x028B: 0xFFFD,
	0x028C: 0x9BCA,
	0x028D: 0xFFFD,
	0x028E: 0xFFFD,
	0x028F: 0xFFFD,
	0x0290: 0xFFFD,
	0x0291: 0xFFFD,
	0x0292: 0x9BDA,
	0x0293: 0xFFFD,
	0x0294: 0xFFFD,
	0x0295: 0xFFFD,
	0x0296: 0xFFFD,
	0x0297: 0xFFFD,
	0x0298: 0xFFFD,
	0x0299: 0xFFFD,
	0x029A: 0xFFFD,
	0x029B: 0xFFFD,
	0x029C: 0xFFFD,
	0x029D: 0xFFFD,
	0x029E: 0xFFFD,
	0x029F: 0xFFFD,
	0x02A0: 0xFFFD,
	0x02A1: 0xFFFD,
	0x02A2: 0xFFFD,
	0x02A3: 0xFFFD,
	0x02A4: 0x9BDC,
	0x02A5: 0xFFFD,
	0x02A6: 0xFFFD,
	0x02A7: 0x9BDB,
	0x02A8: 0xFFFD,
	0x02A9: 0xFFFD,
	0x02AA: 0xFFFD,
	0x02AB: 0xFFFD,
	0x02AC: 0xFFFD,
	0x02AD: 0xFFFD,
	0x02AE: 0xFFFD,
	0x02AF: 0xFFFD,
	0x02B0: 0xFFFD,
	0x02B1: 0xFFFD,
	0x02B2: 0xFFFD,
	0x02B3: 0xFFFD,
	0x02B4: 0xFFFD,
	0x02B5: 0xFFFD,
	0x02B6: 0xFFFD,
	0x02B7: 0xFFFD,
	0x02B8: 0xFFFD,
	0x02B9: 0xFFFD,
	0x02BA: 0xFFFD,
	0x02BB: 0xFFFD,
	0x02BC: 0xFFFD,
	0x02BD: 0xFFFD,
	0x02BE: 0xFFFD,
	0x02BF: 0xFFFD,
	0x02C0: 0xFFFD,
	0x02C1: 0xFFFD,
	0x02C2: 0xFFFD,
	0x02C3: 0xFFFD,
	0x02C4: 0xFFFD,
	0x02C5: 0xFFFD,
	0x02C6: 0xC6D9,
	0x02C7: 0xA3BE,
	0x02C8: 0xFFFD,
	0x02C9: 0xA3BC,
	0x02CA: 0xA3BD,
	0x02CB: 0xA3BF,
	0x02CC: 0xFFFD,
	0x02CD: 0xA1C5,
	0x02CE: 0xFFFD,
	0x02CF: 0x9BE9,
	0x02D0: 0xFFFD,
	0x02D1: 0xFFFD,
	0x02D2: 0xFFFD,
	0x02D3: 0xFFFD,
	0x02D4: 0xFFFD,
	0x02D5: 0xFFFD,
	0x02D6: 0xFFFD,
	0x02D7: 0xFFFD,
	0x02D8: 0xFFFD,
	0x02D9: 0xA3BB,
	0x02DA: 0xFFFD,
	0x02DB: 0xFFFD,
	0x02DC: 0xFFFD,
	0x02DD: 0xFFFD,
	0x02DE: 0xFFFD,
	0x02DF: 0xFFFD,
	0x02E0: 0xFFFD,
	0x02E1: 0xFFFD,
	0x02E2: 0xFFFD,
	0x02E3: 0xFFFD,
	0x02E4: 0xFFFD,
	0x02E5: 0xFFFD,
	0x02E6: 0xFFFD,
	0x02E7: 0xFFFD,
	0x02E8: 0xFFFD,
	0x02E9: 0xFFFD,
	0x02EA: 0xFFFD,
	0x02EB: 0xFFFD,
	0x02EC: 0xFFFD,
	0x02ED: 0xFFFD,
	0x02EE: 0xFFFD,
	0x02EF: 0xFFFD,
	0x02F0: 0xFFFD,
	0x02F1: 0xFFFD,
	0x02F2: 0xFFFD,
	0x02F3: 0xFFFD,
	0x02F4: 0xFFFD,
	0x02F5: 0xFFFD,
	0x02F6: 0xFFFD,
	0x02F7: 0xFFFD,
	0x02F8: 0xFFFD,
	0x02F9: 0xFFFD,
	0x02FA: 0xFFFD,
	0x02FB: 0xFFFD,
	0x02FC: 0xFFFD,
	0x02FD: 0xFFFD,
	0x02FE: 0xFFFD,
	0x02FF: 0xFFFD,
	0x0300: 0xFFFD,
	0x0301: 0xFFFD,
	0x0302: 0xFFFD,
	0x0303: 0xFFFD,
	0x0304: 0xFFFD,
	0x0305: 0xFFFD,
	0x0306: 0xFFFD,
	0x0307: 0xFFFD,
	0x0308: 0xFFFD,
	0x0309: 0xFFFD,
	0x030A: 0xFFFD,
	0x030B: 0xFFFD,
	0x030C: 0xFFFD,
	0x030D: 0xFFFD,
	0x030E: 0xFFFD,
	0x030F: 0xFFFD,
	0x0310: 0xFFFD,
	0x0311: 0xFFFD,
	0x0312: 0xFFFD,
	0x0313: 0xFFFD,
	0x0314: 0xFFFD,
	0x0315: 0xFFFD,
	0x0316: 0xFFFD,
	0x0317: 0xFFFD,
	0x0318: 0xFFFD,
	0x0319: 0xFFFD,
	0x031A: 0xFFFD,
	0x031B: 0xFFFD,
	0x031C: 0xFFFD,
	0x031D: 0xFFFD,
	0x031E: 0xFFFD,
	0x031F: 0xFFFD,
	0x0320: 0xFFFD,
	0x0321: 0xFFFD,
	0x0322: 0xFFFD,
	0x0323: 0xFFFD,
	0x0324: 0xFFFD,
	0x0325: 0xFFFD,
	0x0326: 0xFFFD,
	0x0327: 0xFFFD,
	0x0328: 0xFFFD,
	0x0329: 0xFFFD,
	0x032A: 0xFFFD,
	0x032B: 0xFFFD,
	0x032C: 0xFFFD,
	0x032D: 0xFFFD,
	0x032E: 0xFFFD,
	0x032F: 0xFFFD,
	0x0330: 0xFFFD,
	0x0331: 0xFFFD,
	0x0332: 0xFFFD,
	0x0333: 0xFFFD,
	0x0334: 0xFFFD,
	0x0335: 0xFFFD,
	0x0336: 0xFFFD,
	0x0337: 0xFFFD,
	0x0338: 0xFFFD,
	0x0339: 0xFFFD,
	0x033A: 0xFFFD,
	0x033B: 0xFFFD,
	0x033C: 0xFFFD,
	0x033D: 0xFFFD,
	0x033E: 0xFFFD,
	0x033F: 0xFFFD,
	0x0340: 0xFFFD,
	0x0341: 0xFFFD,
	0x0342: 0xFFFD,
	0x0343: 0xFFFD,
	0x0344: 0xFFFD,
	0x0345: 0xFFFD,
	0x0346: 0xFFFD,
	0x0347: 0xFFFD,
	0x0348: 0xFFFD,
	0x0349: 0xFFFD,
	0x034A: 0xFFFD,
	0x034B: 0xFFFD,
	0x034C: 0xFFFD,
	0x034D: 0xFFFD,
	0x034E: 0xFFFD,
	0x034F: 0xFFFD,
	0x0350: 0xFFFD,
	0x0351: 0xFFFD,
	0x0352: 0xFFFD,
	0x0353: 0xFFFD,
	0x0354: 0xFFFD,
	0x0355: 0xFFFD,
	0x0356: 0xFFFD,
	0x0357: 0xFFFD,
	0x0358: 0xFFFD,
	0x0359: 0xFFFD,
	0x035A: 0xFFFD,
	0x035B: 0xFFFD,
	0x035C: 0xFFFD,
	0x035D: 0xFFFD,
	0x035E: 0xFFFD,
	0x035F: 0xFFFD,
	0x0360: 0xFFFD,
	0x0361: 0xFFFD,
	0x0362: 0xFFFD,
	0x0363: 0xFFFD,
	0x0364: 0xFFFD,
	0x0365: 0xFFFD,
	0x0366: 0xFFFD,
	0x0367: 0xFFFD,
	0x0368: 0xFFFD,
	0x0369: 0xFFFD,
	0x036A: 0xFFFD,
	0x036B: 0xFFFD,
	0x036C: 0xFFFD,
	0x036D: 0xFFFD,
	0x036E: 0xFFFD,
	0x036F: 0xFFFD,
	0x0370: 0xFFFD,
	0x0371: 0xFFFD,
	0x0372: 0xFFFD,
	0x0373: 0xFFFD,
	0x0374: 0xFFFD,
	0x0375: 0xFFFD,
	0x0376: 0xFFFD,
	0x0377: 0xFFFD,
	0x0378: 0xFFFD,
	0x0379: 0xFFFD,
	0x037A: 0xFFFD,
	0x037B: 0xFFFD,
	0x037C: 0xFFFD,
	0x037D: 0xFFFD,
	0x037E: 0xFFFD,
	0x037F: 0xFFFD,
	0x0380: 0xFFFD,
	0x0381: 0xFFFD,
	0x0382: 0xFFFD,
	0x0383: 0xFFFD,
	0x0384: 0xFFFD,
	0x0385: 0xFFFD,
	0x0386: 0xFFFD,
	0x0387: 0xFFFD,
	0x0388: 0xFFFD,
	0x0389: 0xFFFD,
	0x038A: 0xFFFD,
	0x038B: 0xFFFD,
	0x038C: 0xFFFD,
	0x038D: 0xFFFD,
	0x038E: 0xFFFD,
	0x038F: 0xFFFD,
	0x0390: 0xFFFD,
	0x0391: 0xA344,
	0x0392: 0xA345,
	0x0393: 0xA346,
	0x0394: 0xA347,
	0x0395: 0xA348,
	0x0396: 0xA349,
	0x0397: 0xA34A,
	0x0398: 0xA34B,
	0x0399: 0xA34C,
	0x039A: 0xA34D,
	0x039B: 0xA34E,
	0x039C: 0xA34F,
	0x039D: 0xA350,
	0x039E: 0xA351,
	0x039F: 0xA352,
	0x03A0: 0xA353,
	0x03A1: 0xA354,
	0x03A2: 0xFFFD,
	0x03A3: 0xA355,
	0x03A4: 0xA356,
	0x03A5: 0xA357,
	0x03A6: 0xA358,
	0x03A7: 0xA359,
	0x03A8: 0xA35A,
	0x03A9: 0xA35B,
	0x03AA: 0xFFFD,
	0x03AB: 0xFFFD,
	0x03AC: 0xFFFD,
	0x03AD: 0xFFFD,
	0x03AE: 0xFFFD,
	0x03AF: 0xFFFD,
	0x03B0: 0xFFFD,
	0x03B1: 0xA35C,
	0x03B2: 0xA35D,
	0x03B3: 0xA35E,
	0x03B4: 0xA35F,
	0x03B5: 0xA360,
	0x03B6: 0xA361,
	0x03B7: 0xA362,
	0x03B8: 0xA363,
	0x03B9: 0xA364,
	0x03BA: 0xA365,
	0x03BB: 0xA366,
	0x03BC: 0xA367,
	0x03BD: 0xA368,
	0x03BE: 0xA369,
	0x03BF: 0xA36A,
	0x03C0: 0xA36B,
	0x03C1: 0xA36C,
	0x03C2: 0xFFFD,
	0x03C3: 0xA36D,
	0x03C4: 0xA36E,
	0x03C5: 0xA36F,
	0x03C6: 0xA370,
	0x03C7: 0xA371,
	0x03C8: 0xA372,
	0x03C9: 0xA373,
	0x03CA: 0xFFFD,
	0x03CB: 0xFFFD,
	0x03CC: 0xFFFD,
	0x03CD: 0xFFFD,
	0x03CE: 0xFFFD,
	0x03CF: 0xFFFD,
	0x03D0: 0xFFFD,
	0x03D1: 0xFFFD,
	0x03D2: 0xFFFD,
	0x03D3: 0xFFFD,
	0x03D4: 0xFFFD,
	0x03D5: 0xFFFD,
	0x03D6: 0xFFFD,
	0x03D7: 0xFFFD,
	0x03D8: 0xFFFD,
	0x03D9: 0xFFFD,
	0x03DA: 0xFFFD,
	0x03DB: 0xFFFD,
	0x03DC: 0xFFFD,
	0x03DD: 0xFFFD,
	0x03DE: 0xFFFD,
	0x03DF: 0xFFFD,
	0x03E0: 0xFFFD,
	0x03E1: 0xFFFD,
	0x03E2: 0xFFFD,
	0x03E3: 0xFFFD,
	0x03E4: 0xFFFD,
	0x03E5: 0xFFFD,
	0x03E6: 0xFFFD,
	0x03E7: 0xFFFD,
	0x03E8: 0xFFFD,
	0x03E9: 0xFFFD,
	0x03EA: 0xFFFD,
	0x03EB: 0xFFFD,
	0x03EC: 0xFFFD,
	0x03ED: 0xFFFD,
	0x03EE: 0xFFFD,
	0x03EF: 0xFFFD,
	0x03F0: 0xFFFD,
	0x03F1: 0xFFFD,
	0x03F2: 0xFFFD,
	0x03F3: 0xFFFD,
	0x03F4: 0xFFFD,
	0x03F5: 0xFFFD,
	0x03F6: 0xFFFD,
	0x03F7: 0xFFFD,
	0x03F8: 0xFFFD,
	0x03F9: 0xFFFD,
	0x03FA: 0xFFFD,
	0x03FB: 0xFFFD,
	0x03FC: 0xFFFD,
	0x03FD: 0xFFFD,
	0x03FE: 0xFFFD,
	0x03FF: 0xFFFD,
	0x0400: 0xFFFD,
	0x0401: 0xC7F9,
	0x0402: 0xFFFD,
	0x0403: 0xFFFD,
	0x0404: 0xFFFD,
	0x0405: 0xFFFD,
	0x0406: 0xFFFD,
	0x0407: 0xFFFD,
	0x0408: 0xFFFD,
	0x0409: 0xFFFD,
	0x040A: 0xFFFD,
	0x040B: 0xFFFD,
	0x040C: 0xFFFD,
	0x040D: 0xFFFD,
	0x040E: 0xFFFD,
	0x040F: 0xFFFD,
	0x0410: 0xC7F3,
	0x0411: 0xC7F4,
	0x0412: 0xC7F5,
	0x0413: 0xC7F6,
	0x0414: 0xC7F7,
	0x0415: 0xC7F8,
	0x0416: 0xC7FA,
	0x0417: 0xC7FB,
	0x0418: 0xC7FC,
	0x0419: 0xC7FD,
	0x041A: 0xC7FE,
	0x041B: 0xC840,
	0x041C: 0xC841,
	0x041D: 0xC842,
	0x041E: 0xC843,
	0x041F: 0xC844,
	0x0420: 0xC845,
	0x0421: 0xC846,
	0x0422: 0xC847,
	0x0423: 0xC848,
	0x0424: 0xC849,
	0x0425: 0xC84A,
	0x0426: 0xC84B,
	0x0427: 0xC84C,
	0x0428: 0xC84D,
	0x0429: 0xC84E,
	0x042A: 0xC84F,
	0x042B: 0xC850,
	0x042C: 0xC851,
	0x042D: 0xC852,
	0x042E: 0xC853,
	0x042F: 0xC854,
	0x0430: 0xC855,
	0x0431: 0xC856,
	0x0432: 0xC857,
	0x0433: 0xC858,
	0x0434: 0xC859,
	0x0435: 0xC85A,
	0x0436: 0xC85C,
	0x0437: 0xC85D,
	0x0438: 0xC85E,
	0x0439: 0xC85F,
	0x043A: 0xC860,
	0x043B: 0xC861,
	0x043C: 0xC862,
	0x043D: 0xC863,
	0x043E: 0xC864,
	0x043F: 0xC865,
	0x0440: 0xC866,
	0x0441: 0xC867,
	0x0442: 0xC868,
	0x0443: 0xC869,
	0x0444: 0xC86A,
	0x0445: 0xC86B,
	0x0446: 0xC86C,
	0x0447: 0xC86D,
	0x0448: 0xC86E,
	0x0449: 0xC86F,
	0x044A: 0xC870,
	0x044B: 0xC871,
	0x044C: 0xC872,
	0x044D: 0xC873,
	0x044E: 0xC874,
	0x044F: 0xC875,
	0x0450: 0xFFFD,
	0x0451: 0xC85B,
	0x0452: 0xFFFD,
	0x0453: 0xFFFD,
	0x0454: 0xFFFD,
	0x0455: 0xFFFD,
	0x0456: 0xFFFD,
	0x0457: 0xFFFD,
	0x0458: 0xFFFD,
	0x0459: 0xFFFD,
	0x045A: 0xFFFD,
	0x045B: 0xFFFD,
	0x045C: 0xFFFD,
	0x045D: 0xFFFD,
	0x045E: 0xFFFD,
	0x045F: 0xFFFD,
	0x0460: 0xFFFD,
	0x0461: 0xFFFD,
	0x0462: 0xFFFD,
	0x0463: 0xFFFD,
	0x0464: 0xFFFD,
	0x0465: 0xFFFD,
	0x0466: 0xFFFD,
	0x0467: 0xFFFD,
	0x0468: 0xFFFD,
	0x0469: 0xFFFD,
	0x046A: 0xFFFD,
	0x046B: 0xFFFD,
	0x046C: 0xFFFD,
	0x046D: 0xFFFD,
	0x046E: 0xFFFD,
	0x046F: 0xFFFD,
	0x0470: 0xFFFD,
	0x0471: 0xFFFD,
	0x0472: 0xFFFD,
	0x0473: 0xFFFD,
	0x0474: 0xFFFD,
	0x0475: 0xFFFD,
	0x0476: 0xFFFD,
	0x0477: 0xFFFD,
	0x0478: 0xFFFD,
	0x0479: 0xFFFD,
	0x047A: 0xFFFD,
	0x047B: 0xFFFD,
	0x047C: 0xFFFD,
	0x047D: 0xFFFD,
	0x047E: 0xFFFD,
	0x047F: 0xFFFD,
	0x0480: 0xFFFD,
	0x0481: 0xFFFD,
	0x0482: 0xFFFD,
	0x0483: 0xFFFD,
	0x0484: 0xFFFD,
	0x0485: 0xFFFD,
	0x0486: 0xFFFD,
	0x0487: 0xFFFD,
	0x0488: 0xFFFD,
	0x0489: 0xFFFD,
	0x048A: 0xFFFD,
	0x048B: 0xFFFD,
	0x048C: 0xFFFD,
	0x048D: 0xFFFD,
	0x048E: 0xFFFD,
	0x048F: 0xFFFD,
	0x0490: 0xFFFD,
	0x0491: 0xFFFD,
	0x0492: 0xFFFD,
	0x0493: 0xFFFD,
	0x0494: 0xFFFD,
	0x0495: 0xFFFD,
	0x0496: 0xFFFD,
	0x0497: 0xFFFD,
	0x0498: 0xFFFD,
	0x0499: 0xFFFD,
	0x049A: 0xFFFD,
	0x049B: 0xFFFD,
	0x049C: 0xFFFD,
	0x049D: 0xFFFD,
	0x049E: 0xFFFD,
	0x049F: 0xFFFD,
	0x04A0: 0xFFFD,
	0x04A1: 0xFFFD,
	0x04A2: 0xFFFD,
	0x04A3: 0xFFFD,
	0x04A4: 0xFFFD,
	0x04A5: 0xFFFD,
	0x04A6: 0xFFFD,
	0x04A7: 0xFFFD,
	0x04A8: 0xFFFD,
	0x04A9: 0xFFFD,
	0x04AA: 0xFFFD,
	0x04AB: 0xFFFD,
	0x04AC: 0xFFFD,
	0x04AD: 0xFFFD,
	0x04AE: 0xFFFD,
	0x04AF: 0xFFFD,
	0x04B0: 0xFFFD,
	0x04B1: 0xFFFD,
	0x04B2: 0xFFFD,
	0x04B3: 0xFFFD,
	0x04B4: 0xFFFD,
	0x04B5: 0xFFFD,
	0x04B6: 0xFFFD,
	0x04B7: 0xFFFD,
	0x04B8: 0xFFFD,
	0x04B9: 0xFFFD,
	0x04BA: 0xFFFD,
	0x04BB: 0xFFFD,
	0x04BC: 0xFFFD,
	0x04BD: 0xFFFD,
	0x04BE: 0xFFFD,
	0x04BF: 0xFFFD,
	0x04C0: 0xFFFD,
	0x04C1: 0xFFFD,
	0x04C2: 0xFFFD,
	0x04C3: 0xFFFD,
	0x04C4: 0xFFFD,
	0x04C5: 0xFFFD,
	0x04C6: 0xFFFD,
	0x04C7: 0xFFFD,
	0x04C8: 0xFFFD,
	0x04C9: 0xFFFD,
	0x04CA: 0xFFFD,
	0x04CB: 0xFFFD,
	0x04CC: 0xFFFD,
	0x04CD: 0xFFFD,
	0x04CE: 0xFFFD,
	0x04CF: 0xFFFD,
	0x04D0: 0xFFFD,
	0x04D1: 0xFFFD,
	0x04D2: 0xFFFD,
	0x04D3: 0xFFFD,
	0x04D4: 0xFFFD,
	0x04D5: 0xFFFD,
	0x04D6: 0xFFFD,
	0x04D7: 0xFFFD,
	0x04D8: 0xFFFD,
	0x04D9: 0xFFFD,
	0x04DA: 0xFFFD,
	0x04DB: 0xFFFD,
	0x04DC: 0xFFFD,
	0x04DD: 0xFFFD,
	0x04DE: 0xFFFD,
	0x04DF: 0xFFFD,
	0x04E0: 0xFFFD,
	0x04E1: 0xFFFD,
	0x04E2: 0xFFFD,
	0x04E3: 0xFFFD,
	0x04E4: 0xFFFD,
	0x04E5: 0xFFFD,
	0x04E6: 0xFFFD,
	0x04E7: 0xFFFD,
	0x04E8: 0xFFFD,
	0x04E9: 0xFFFD,
	0x04EA: 0xFFFD,
	0x04EB: 0xFFFD,
	0x04EC: 0xFFFD,
	0x04ED: 0xFFFD,
	0x04EE: 0xFFFD,
	0x04EF: 0xFFFD,
	0x04F0: 0xFFFD,
	0x04F1: 0xFFFD,
	0x04F2: 0xFFFD,
	0x04F3: 0xFFFD,
	0x04F4: 0xFFFD,
	0x04F5: 0xFFFD,
	0x04F6: 0xFFFD,
	0x04F7: 0xFFFD,
	0x04F8: 0xFFFD,
	0x04F9: 0xFFFD,
	0x04FA: 0xFFFD,
	0x04FB: 0xFFFD,
	0x04FC: 0xFFFD,
	0x04FD: 0xFFFD,
	0x04FE: 0xFFFD,
	0x04FF: 0xFFFD,
	0x0500: 0xFFFD,
	0x0501: 0xFFFD,
	0x0502: 0xFFFD,
	0x0503: 0xFFFD,
	0x0504: 0xFFFD,
	0x0505: 0xFFFD,
	0x0506: 0xFFFD,
	0x0507: 0xFFFD,
	0x0508: 0xFFFD,
	0x0509: 0xFFFD,
	0x050A: 0xFFFD,
	0x050B: 0xFFFD,
	0x050C: 0xFFFD,
	0x050D: 0xFFFD,
	0x050E: 0xFFFD,
	0x050F: 0xFFFD,
	0x0510: 0xFFFD,
	0x0511: 0xFFFD,
	0x0512: 0xFFFD,
	0x0513: 0xFFFD,
	0x0514: 0xFFFD,
	0x0515: 0xFFFD,
	0x0516: 0xFFFD,
	0x0517: 0xFFFD,
	0x0518: 0xFFFD,
	0x0519: 0xFFFD,
	0x051A: 0xFFFD,
	0x051B: 0xFFFD,
	0x051C: 0xFFFD,
	0x051D: 0xFFFD,
	0x051E: 0xFFFD,
	0x051F: 0xFFFD,
	0x0520: 0xFFFD,
	0x0521: 0xFFFD,
	0x0522: 0xFFFD,
	0x0523: 0xFFFD,
	0x0524: 0xFFFD,
	0x0525: 0xFFFD,
	0x0526: 0xFFFD,
	0x0527: 0xFFFD,
	0x0528: 0xFFFD,
	0x0529: 0xFFFD,
	0x052A: 0xFFFD,
	0x052B: 0xFFFD,
	0x052C: 0xFFFD,
	0x052D: 0xFFFD,
	0x052E: 0xFFFD,
	0x052F: 0xFFFD,
	0x0530: 0xFFFD,
	0x0531: 0xFFFD,
	0x0532: 0xFFFD,
	0x0533: 0xFFFD,
	0x0534: 0xFFFD,
	0x0535: 0xFFFD,
	0x0536: 0xFFFD,
	0x0537: 0xFFFD,
	0x0538: 0xFFFD,
	0x0539: 0xFFFD,
	0x053A: 0xFFFD,
	0x053B: 0xFFFD,
	0x053C: 0xFFFD,
	0x053D: 0xFFFD,
	0x053E: 0xFFFD,
	0x053F: 0xFFFD,
	0x0540: 0xFFFD,
	0x0541: 0xFFFD,
	0x0542: 0xFFFD,
	0x0543: 0xFFFD,
	0x0544: 0xFFFD,
	0x0545: 0xFFFD,
	0x0546: 0xFFFD,
	0x0547: 0xFFFD,
	0x0548: 0xFFFD,
	0x0549: 0xFFFD,
	0x054A: 0xFFFD,
	0x054B: 0xFFFD,
	0x054C: 0xFFFD,
	0x054D: 0xFFFD,
	0x054E: 0xFFFD,
	0x054F: 0xFFFD,
	0x0550: 0xFFFD,
	0x0551: 0xFFFD,
	0x0552: 0xFFFD,
	0x0553: 0xFFFD,
	0x0554: 0xFFFD,
	0x0555: 0xFFFD,
	0x0556: 0xFFFD,
	0x0557: 0xFFFD,
	0x0558: 0xFFFD,
	0x0559: 0xFFFD,
	0x055A: 0xFFFD,
	0x055B: 0xFFFD,
	0x055C: 0xFFFD,
	0x055D: 0xFFFD,
	0x055E: 0xFFFD,
	0x055F: 0xFFFD,
	0x0560: 0xFFFD,
	0x0561: 0xFFFD,
	0x0562: 0xFFFD,
	0x0563: 0xFFFD,
	0x0564: 0xFFFD,
	0x0565: 0xFFFD,
	0x0566: 0xFFFD,
	0x0567: 0xFFFD,
	0x0568: 0xFFFD,
	0x0569: 0xFFFD,
	0x056A: 0xFFFD,
	0x056B: 0xFFFD,
	0x056C: 0xFFFD,
	0x056D: 0xFFFD,
	0x056E: 0xFFFD,
	0x056F: 0xFFFD,
	0x0570: 0xFFFD,
	0x0571: 0xFFFD,
	0x0572: 0xFFFD,
	0x0573: 0xFFFD,
	0x0574: 0xFFFD,
	0x0575: 0xFFFD,
	0x0576: 0xFFFD,
	0x0577: 0xFFFD,
	0x0578: 0xFFFD,
	0x0579: 0xFFFD,
	0x057A: 0xFFFD,
	0x057B: 0xFFFD,
	0x057C: 0xFFFD,
	0x057D: 0xFFFD,
	0x057E: 0xFFFD,
	0x057F: 0xFFFD,
	0x0580: 0xFFFD,
	0x0581: 0xFFFD,
	0x0582: 0xFFFD,
	0x0583: 0xFFFD,
	0x0584: 0xFFFD,
	0x0585: 0xFFFD,
	0x0586: 0xFFFD,
	0x0587: 0xFFFD,
	0x0588: 0xFFFD,
	0x0589: 0xFFFD,
	0x058A: 0xFFFD,
	0x058B: 0xFFFD,
	0x058C: 0xFFFD,
	0x058D: 0xFFFD,
	0x058E: 0xFFFD,
	0x058F: 0xFFFD,
	0x0590: 0xFFFD,
	0x0591: 0xFFFD,
	0x0592: 0xFFFD,
	0x0593: 0xFFFD,
	0x0594: 0xFFFD,
	0x0595: 0xFFFD,
	0x0596: 0xFFFD,
	0x0597: 0xFFFD,
	0x0598: 0xFFFD,
	0x0599: 0xFFFD,
	0x059A: 0xFFFD,
	0x059B: 0xFFFD,
	0x059C: 0xFFFD,
	0x059D: 0xFFFD,
	0x059E: 0xFFFD,
	0x059F: 0xFFFD,
	0x05A0: 0xFFFD,
	0x05A1: 0xFFFD,
	0x05A2: 0xFFFD,
	0x05A3: 0xFFFD,
	0x05A4: 0xFFFD,
	0x05A5: 0xFFFD,
	0x05A6: 0xFFFD,
	0x05A7: 0xFFFD,
	0x05A8: 0xFFFD,
	0x05A9: 0xFFFD,
	0x05AA: 0xFFFD,
	0x05AB: 0xFFFD,
	0x05AC: 0xFFFD,
	0x05AD: 0xFFFD,
	0x05AE: 0xFFFD,
	0x05AF: 0xFFFD,
	0x05B0: 0xFFFD,
	0x05B1: 0xFFFD,
	0x05B2: 0xFFFD,
	0x05B3: 0xFFFD,
	0x05B4: 0xFFFD,
	0x05B5: 0xFFFD,
	0x05B6: 0xFFFD,
	0x05B7: 0xFFFD,
	0x05B8: 0xFFFD,
	0x05B9: 0xFFFD,
	0x05BA: 0xFFFD,
	0x05BB: 0xFFFD,
	0x05BC: 0xFFFD,
	0x05BD: 0xFFFD,
	0x05BE: 0xFFFD,
	0x05BF: 0xFFFD,
	0x05C0: 0xFFFD,
	0x05C1: 0xFFFD,
	0x05C2: 0xFFFD,
	0x05C3: 0xFFFD,
	0x05C4: 0xFFFD,
	0x05C5: 0xFFFD,
	0x05C6: 0xFFFD,
	0x05C7: 0xFFFD,
	0x05C8: 0xFFFD,
	0x05C9: 0xFFFD,
	0x05CA: 0xFFFD,
	0x05CB: 0xFFFD,
	0x05CC: 0xFFFD,
	0x05CD: 0xFFFD,
	0x05CE: 0xFFFD,
	0x05CF: 0xFFFD,
	0x05D0: 0xFFFD,
	0x05D1: 0xFFFD,
	0x05D2: 0xFFFD,
	0x05D3: 0xFFFD,
	0x05D4: 0xFFFD,
	0x05D5: 0xFFFD,
	0x05D6: 0xFFFD,
	0x05D7: 0xFFFD,
	0x05D8: 0xFFFD,
	0x05D9: 0xFFFD,
	0x05DA: 0xFFFD,
	0x05DB: 0xFFFD,
	0x05DC: 0xFFFD,
	0x05DD: 0xFFFD,
	0x05DE: 0xFFFD,
	0x05DF: 0xFFFD,
	0x05E0: 0xFFFD,
	0x05E1: 0xFFFD,
	0x05E2: 0xFFFD,
	0x05E3: 0xFFFD,
	0x05E4: 0xFFFD,
	0x05E5: 0xFFFD,
	0x05E6: 0xFFFD,
	0x05E7: 0xFFFD,
	0x05E8: 0xFFFD,
	0x05E9: 0xFFFD,
	0x05EA: 0xFFFD,
	0x05EB: 0xFFFD,
	0x05EC: 0xFFFD,
	0x05ED: 0xFFFD,
	0x05EE: 0xFFFD,
	0x05EF: 0xFFFD,
	0x05F0: 0xFFFD,
	0x05F1: 0xFFFD,
	0x05F2: 0xFFFD,
	0x05F3: 0xFFFD,
	0x05F4: 0xFFFD,
	0x05F5: 0xFFFD,
	0x05F6: 0xFFFD,
	0x05F7: 0xFFFD,
	0x05F8: 0xFFFD,
	0x05F9: 0xFFFD,
	0x05FA: 0xFFFD,
	0x05FB: 0xFFFD,
	0x05FC: 0xFFFD,
	0x05FD: 0xFFFD,
	0x05FE: 0xFFFD,
	0x05FF: 0xFFFD,
	0x0600: 0xFFFD,
	0x0601: 0xFFFD,
	0x0602: 0xFFFD,
	0x0603: 0xFFFD,
	0x0604: 0xFFFD,
	0x0605: 0xFFFD,
	0x0606: 0xFFFD,
	0x0607: 0xFFFD,
	0x0608: 0xFFFD,
	0x0609: 0xFFFD,
	0x060A: 0xFFFD,
	0x060B: 0xFFFD,
	0x060C: 0xFFFD,
	0x060D: 0xFFFD,
	0x060E: 0xFFFD,
	0x060F: 0xFFFD,
	0x0610: 0xFFFD,
	0x0611: 0xFFFD,
	0x0612: 0xFFFD,
	0x0613: 0xFFFD,
	0x0614: 0xFFFD,
	0x0615: 0xFFFD,
	0x0616: 0xFFFD,
	0x0617: 0xFFFD,
	0x0618: 0xFFFD,
	0x0619: 0xFFFD,
	0x061A: 0xFFFD,
	0x061B: 0xFFFD,
	0x061C: 0xFFFD,
	0x061D: 0xFFFD,
	0x061E: 0xFFFD,
	0x061F: 0xFFFD,
	0x0620: 0xFFFD,
	0x0621: 0xFFFD,
	0x0622: 0xFFFD,
	0x0623: 0xFFFD,
	0x0624: 0xFFFD,
	0x0625: 0xFFFD,
	0x0626: 0xFFFD,
	0x0627: 0xFFFD,
	0x0628: 0xFFFD,
	0x0629: 0xFFFD,
	0x062A: 0xFFFD,
	0x062B: 0xFFFD,
	0x062C: 0xFFFD,
	0x062D: 0xFFFD,
	0x062E: 0xFFFD,
	0x062F: 0xFFFD,
	0x0630: 0xFFFD,
	0x0631: 0xFFFD,
	0x0632: 0xFFFD,
	0x0633: 0xFFFD,
	0x0634: 0xFFFD,
	0x0635: 0xFFFD,
	0x0636: 0xFFFD,
	0x0637: 0xFFFD,
	0x0638: 0xFFFD,
	0x0639: 0xFFFD,
	0x063A: 0xFFFD,
	0x063B: 0xFFFD,
	0x063C: 0xFFFD,
	0x063D: 0xFFFD,
	0x063E: 0xFFFD,
	0x063F: 0xFFFD,
	0x0640: 0xFFFD,
	0x0641: 0xFFFD,
	0x0642: 0xFFFD,
	0x0643: 0xFFFD,
	0x0644: 0xFFFD,
	0x0645: 0xFFFD,
	0x0646: 0xFFFD,
	0x0647: 0xFFFD,
	0x0648: 0xFFFD,
	0x0649: 0xFFFD,
	0x064A: 0xFFFD,
	0x064B: 0xFFFD,
	0x064C: 0xFFFD,
	0x064D: 0xFFFD,
	0x064E: 0xFFFD,
	0x064F: 0xFFFD,
	0x0650: 0xFFFD,
	0x0651: 0xFFFD,
	0x0652: 0xFFFD,
	0x0653: 0xFFFD,
	0x0654: 0xFFFD,
	0x0655: 0xFFFD,
	0x0656: 0xFFFD,
	0x0657: 0xFFFD,
	0x0658: 0xFFFD,
	0x0659: 0xFFFD,
	0x065A: 0xFFFD,
	0x065B: 0xFFFD,
	0x065C: 0xFFFD,
	0x065D: 0xFFFD,
	0x065E: 0xFFFD,
	0x065F: 0xFFFD,
	0x0660: 0xFFFD,
	0x0661: 0xFFFD,
	0x0662: 0xFFFD,
	0x0663: 0xFFFD,
	0x0664: 0xFFFD,
	0x0665: 0xFFFD,
	0x0666: 0xFFFD,
	0x0667: 0xFFFD,
	0x0668: 0xFFFD,
	0x0669: 0xFFFD,
	0x066A: 0xFFFD,
	0x066B: 0xFFFD,
	0x066C: 0xFFFD,
	0x066D: 0xFFFD,
	0x066E: 0xFFFD,
	0x066F: 0xFFFD,
	0x0670: 0xFFFD,
	0x0671: 0xFFFD,
	0x0672: 0xFFFD,
	0x0673: 0xFFFD,
	0x0674: 0xFFFD,
	0x0675: 0xFFFD,
	0x0676: 0xFFFD,
	0x0677: 0xFFFD,
	0x0678: 0xFFFD,
	0x0679: 0xFFFD,
	0x067A: 0xFFFD,
	0x067B: 0xFFFD,
	0x067C: 0xFFFD,
	0x067D: 0xFFFD,
	0x067E: 0xFFFD,
	0x067F: 0xFFFD,
	0x0680: 0xFFFD,
	0x0681: 0xFFFD,
	0x0682: 0xFFFD,
	0x0683: 0xFFFD,
	0x0684: 0xFFFD,
	0x0685: 0xFFFD,
	0x0686: 0xFFFD,
	0x0687: 0xFFFD,
	0x0688: 0xFFFD,
	0x0689: 0xFFFD,
	0x068A: 0xFFFD,
	0x068B: 0xFFFD,
	0x068C: 0xFFFD,
	0x068D: 0xFFFD,
	0x068E: 0xFFFD,
	0x068F: 0xFFFD,
	0x0690: 0xFFFD,
	0x0691: 0xFFFD,
	0x0692: 0xFFFD,
	0x0693: 0xFFFD,
	0x0694: 0xFFFD,
	0x0695: 0xFFFD,
	0x0696: 0xFFFD,
	0x0697: 0xFFFD,
	0x0698: 0xFFFD,
	0x0699: 0xFFFD,
	0x069A: 0xFFFD,
	0x069B: 0xFFFD,
	0x069C: 0xFFFD,
	0x069D: 0xFFFD,
	0x069E: 0xFFFD,
	0x069F: 0xFFFD,
	0x06A0: 0xFFFD,
	0x06A1: 0xFFFD,
	0x06A2: 0xFFFD,
	0x06A3: 0xFFFD,
	0x06A4: 0xFFFD,
	0x06A5: 0xFFFD,
	0x06A6: 0xFFFD,
	0x06A7: 0xFFFD,
	0x06A8: 0xFFFD,
	0x06A9: 0xFFFD,
	0x06AA: 0xFFFD,
	0x06AB: 0xFFFD,
	0x06AC: 0xFFFD,
	0x06AD: 0xFFFD,
	0x06AE: 0xFFFD,
	0x06AF: 0xFFFD,
	0x06B0: 0xFFFD,
	0x06B1: 0xFFFD,
	0x06B2: 0xFFFD,
	0x06B3: 0xFFFD,
	0x06B4: 0xFFFD,
	0x06B5: 0xFFFD,
	0x06B6: 0xFFFD,
	0x06B7: 0xFFFD,
	0x06B8: 0xFFFD,
	0x06B9: 0xFFFD,
	0x06BA: 0xFFFD,
	0x06BB: 0xFFFD,
	0x06BC: 0xFFFD,
	0x06BD: 0xFFFD,
	0x06BE: 0xFFFD,
	0x06BF: 0xFFFD,
	0x06C0: 0xFFFD,
	0x06C1: 0xFFFD,
	0x06C2: 0xFFFD,
	0x06C3: 0xFFFD,
	0x06C4: 0xFFFD,
	0x06C5: 0xFFFD,
	0x06C6: 0xFFFD,
	0x06C7: 0xFFFD,
	0x06C8: 0xFFFD,
	0x06C9: 0xFFFD,
	0x06CA: 0xFFFD,
	0x06CB: 0xFFFD,
	0x06CC: 0xFFFD,
	0x06CD: 0xFFFD,
	0x06CE: 0xFFFD,
	0x06CF: 0xFFFD,
	0x06D0: 0xFFFD,
	0x06D1: 0xFFFD,
	0x06D2: 0xFFFD,
	0x06D3: 0xFFFD,
	0x06D4: 0xFFFD,
	0x06D5: 0xFFFD,
	0x06D6: 0xFFFD,
	0x06D7: 0xFFFD,
	0x06D8: 0xFFFD,
	0x06D9: 0xFFFD,
	0x06DA: 0xFFFD,
	0x06DB: 0xFFFD,
	0x06DC: 0xFFFD,
	0x06DD: 0xFFFD,
	0x06DE: 0xFFFD,
	0x06DF: 0xFFFD,
	0x06E0: 0xFFFD,
	0x06E1: 0xFFFD,
	0x06E2: 0xFFFD,
	0x06E3: 0xFFFD,
	0x06E4: 0xFFFD,
	0x06E5: 0xFFFD,
	0x06E6: 0xFFFD,
	0x06E7: 0xFFFD,
	0x06E8: 0xFFFD,
	0x06E9: 0xFFFD,
	0x06EA: 0xFFFD,
	0x06EB: 0xFFFD,
	0x06EC: 0xFFFD,
	0x06ED: 0xFFFD,
	0x06EE: 0xFFFD,
	0x06EF: 0xFFFD,
	0x06F0: 0xFFFD,
	0x06F1: 0xFFFD,
	0x06F2: 0xFFFD,
	0x06F3: 0xFFFD,
	0x06F4: 0xFFFD,
	0x06F5: 0xFFFD,
	0x06F6: 0xFFFD,
	0x06F7: 0xFFFD,
	0x06F8: 0xFFFD,
	0x06F9: 0xFFFD,
	0x06FA: 0xFFFD,
	0x06FB: 0xFFFD,
	0x06FC: 0xFFFD,
	0x06FD: 0xFFFD,
	0x06FE: 0xFFFD,
	0x06FF: 0xFFFD,
	0x0700: 0xFFFD,
	0x0701: 0xFFFD,
	0x0702: 0xFFFD,
	0x0703: 0xFFFD,
	0x0704: 0xFFFD,
	0x0705: 0xFFFD,
	0x0706: 0xFFFD,
	0x0707: 0xFFFD,
	0x0708: 0xFFFD,
	0x0709: 0xFFFD,
	0x070A: 0xFFFD,
	0x070B: 0xFFFD,
	0x070C: 0xFFFD,
	0x070D: 0xFFFD,
	0x070E: 0xFFFD,
	0x070F: 0xFFFD,
	0x0710: 0xFFFD,
	0x0711: 0xFFFD,
	0x0712: 0xFFFD,
	0x0713: 0xFFFD,
	0x0714: 0xFFFD,
	0x0715: 0xFFFD,
	0x0716: 0xFFFD,
	0x0717: 0xFFFD,
	0x0718: 0xFFFD,
	0x0719: 0xFFFD,
	0x071A: 0xFFFD,
	0x071B: 0xFFFD,
	0x071C: 0xFFFD,
	0x071D: 0xFFFD,
	0x071E: 0xFFFD,
	0x071F: 0xFFFD,
	0x0720: 0xFFFD,
	0x0721: 0xFFFD,
	0x0722: 0xFFFD,
	0x0723: 0xFFFD,
	0x0724: 0xFFFD,
	0x0725: 0xFFFD,
	0x0726: 0xFFFD,
	0x0727: 0xFFFD,
	0x0728: 0xFFFD,
	0x0729: 0xFFFD,
	0x072A: 0xFFFD,
	0x072B: 0xFFFD,
	0x072C: 0xFFFD,
	0x072D: 0xFFFD,
	0x072E: 0xFFFD,
	0x072F: 0xFFFD,
	0x0730: 0xFFFD,
	0x0731: 0xFFFD,
	0x0732: 0xFFFD,
	0x0733: 0xFFFD,
	0x0734: 0xFFFD,
	0x0735: 0xFFFD,
	0x0736: 0xFFFD,
	0x0737: 0xFFFD,
	0x0738: 0xFFFD,
	0x0739: 0xFFFD,
	0x073A: 0xFFFD,
	0x073B: 0xFFFD,
	0x073C: 0xFFFD,
	0x073D: 0xFFFD,
	0x073E: 0xFFFD,
	0x073F: 0xFFFD,
	0x0740: 0xFFFD,
	0x0741: 0xFFFD,
	0x0742: 0xFFFD,
	0x0743: 0xFFFD,
	0x0744: 0xFFFD,
	0x0745: 0xFFFD,
	0x0746: 0xFFFD,
	0x0747: 0xFFFD,
	0x0748: 0xFFFD,
	0x0749: 0xFFFD,
	0x074A: 0xFFFD,
	0x074B: 0xFFFD,
	0x074C: 0xFFFD,
	0x074D: 0xFFFD,
	0x074E: 0xFFFD,
	0x074F: 0xFFFD,
	0x0750: 0xFFFD,
	0x0751: 0xFFFD,
	0x0752: 0xFFFD,
	0x0753: 0xFFFD,
	0x0754: 0xFFFD,
	0x0755: 0xFFFD,
	0x0756: 0xFFFD,
	0x0757: 0xFFFD,
	0x0758: 0xFFFD,
	0x0759: 0xFFFD,
	0x075A: 0xFFFD,
	0x075B: 0xFFFD,
	0x075C: 0xFFFD,
	0x075D: 0xFFFD,
	0x075E: 0xFFFD,
	0x075F: 0xFFFD,
	0x0760: 0xFFFD,
	0x0761: 0xFFFD,
	0x0762: 0xFFFD,
	0x0763: 0xFFFD,
	0x0764: 0xFFFD,
	0x0765: 0xFFFD,
	0x0766: 0xFFFD,
	0x0767: 0xFFFD,
	0x0768: 0xFFFD,
	0x0769: 0xFFFD,
	0x076A: 0xFFFD,
	0x076B: 0xFFFD,
	0x076C: 0xFFFD,
	0x076D: 0xFFFD,
	0x076E: 0xFFFD,
	0x076F: 0xFFFD,
	0x0770: 0xFFFD,
	0x0771: 0xFFFD,
	0x0772: 0xFFFD,
	0x0773: 0xFFFD,
	0x0774: 0xFFFD,
	0x0775: 0xFFFD,
	0x0776: 0xFFFD,
	0x0777: 0xFFFD,
	0x0778: 0xFFFD,
	0x0779: 0xFFFD,
	0x077A: 0xFFFD,
	0x077B: 0xFFFD,
	0x077C: 0xFFFD,
	0x077D: 0xFFFD,
	0x077E: 0xFFFD,
	0x077F: 0xFFFD,
	0x0780: 0xFFFD,
	0x0781: 0xFFFD,
	0x0782: 0xFFFD,
	0x0783: 0xFFFD,
	0x0784: 0xFFFD,
	0x0785: 0xFFFD,
	0x0786: 0xFFFD,
	0x0787: 0xFFFD,
	0x0788: 0xFFFD,
	0x0789: 0xFFFD,
	0x078A: 0xFFFD,
	0x078B: 0xFFFD,
	0x078C: 0xFFFD,
	0x078D: 0xFFFD,
	0x078E: 0xFFFD,
	0x078F: 0xFFFD,
	0x0790: 0xFFFD,
	0x0791: 0xFFFD,
	0x0792: 0xFFFD,
	0x0793: 0xFFFD,
	0x0794: 0xFFFD,
	0x0795: 0xFFFD,
	0x0796: 0xFFFD,
	0x0797: 0xFFFD,
	0x0798: 0xFFFD,
	0x0799: 0xFFFD,
	0x079A: 0xFFFD,
	0x079B: 0xFFFD,
	0x079C: 0xFFFD,
	0x079D: 0xFFFD,
	0x079E: 0xFFFD,
	0x079F: 0xFFFD,
	0x07A0: 0xFFFD,
	0x07A1: 0xFFFD,
	0x07A2: 0xFFFD,
	0x07A3: 0xFFFD,
	0x07A4: 0xFFFD,
	0x07A5: 0xFFFD,
	0x07A6: 0xFFFD,
	0x07A7: 0xFFFD,
	0x07A8: 0xFFFD,
	0x07A9: 0xFFFD,
	0x07AA: 0xFFFD,
	0x07AB: 0xFFFD,
	0x07AC: 0xFFFD,
	0x07AD: 0xFFFD,
	0x07AE: 0xFFFD,
	0x07AF: 0xFFFD,
	0x07B0: 0xFFFD,
	0x07B1: 0xFFFD,
	0x07B2: 0xFFFD,
	0x07B3: 0xFFFD,
	0x07B4: 0xFFFD,
	0x07B5: 0xFFFD,
	0x07B6: 0xFFFD,
	0x07B7: 0xFFFD,
	0x07B8: 0xFFFD,
	0x07B9: 0xFFFD,
	0x07BA: 0xFFFD,
	0x07BB: 0xFFFD,
	0x07BC: 0xFFFD,
	0x07BD: 0xFFFD,
	0x07BE: 0xFFFD,
	0x07BF: 0xFFFD,
	0x07C0: 0xFFFD,
	0x07C1: 0xFFFD,
	0x07C2: 0xFFFD,
	0x07C3: 0xFFFD,
	0x07C4: 0xFFFD,
	0x07C5: 0xFFFD,
	0x07C6: 0xFFFD,
	0x07C7: 0xFFFD,
	0x07C8: 0xFFFD,
	0x07C9: 0xFFFD,
	0x07CA: 0xFFFD,
	0x07CB: 0xFFFD,
	0x07CC: 0xFFFD,
	0x07CD: 0xFFFD,
	0x07CE: 0xFFFD,
	0x07CF: 0xFFFD,
	0x07D0: 0xFFFD,
	0x07D1: 0xFFFD,
	0x07D2: 0xFFFD,
	0x07D3: 0xFFFD,
	0x07D4: 0xFFFD,
	0x07D5: 0xFFFD,
	0x07D6: 0xFFFD,
	0x07D7: 0xFFFD,
	0x07D8: 0xFFFD,
	0x07D9: 0xFFFD,
	0x07DA: 0xFFFD,
	0x07DB: 0xFFFD,
	0x07DC: 0xFFFD,
	0x07DD: 0xFFFD,
	0x07DE: 0xFFFD,
	0x07DF: 0xFFFD,
	0x07E0: 0xFFFD,
	0x07E1: 0xFFFD,
	0x07E2: 0xFFFD,
	0x07E3: 0xFFFD,
	0x07E4: 0xFFFD,
	0x07E5: 0xFFFD,
	0x07E6: 0xFFFD,
	0x07E7: 0xFFFD,
	0x07E8: 0xFFFD,
	0x07E9: 0xFFFD,
	0x07EA: 0xFFFD,
	0x07EB: 0xFFFD,
	0x07EC: 0xFFFD,
	0x07ED: 0xFFFD,
	0x07EE: 0xFFFD,
	0x07EF: 0xFFFD,
	0x07F0: 0xFFFD,
	0x07F1: 0xFFFD,
	0x07F2: 0xFFFD,
	0x07F3: 0xFFFD,
	0x07F4: 0xFFFD,
	0x07F5: 0xFFFD,
	0x07F6: 0xFFFD,
	0x07F7: 0xFFFD,
	0x07F8: 0xFFFD,
	0x07F9: 0xFFFD,
	0x07FA: 0xFFFD,
	0x07FB: 0xFFFD,
	0x07FC: 0xFFFD,
	0x07FD: 0xFFFD,
	0x07FE: 0xFFFD,
	0x07FF: 0xFFFD,
	0x0800: 0xFFFD,
	0x0801: 0xFFFD,
	0x0802: 0xFFFD,
	0x0803: 0xFFFD,
	0x0804: 0xFFFD,
	0x0805: 0xFFFD,
	0x0806: 0xFFFD,
	0x0807: 0xFFFD,
	0x0808: 0xFFFD,
	0x0809: 0xFFFD,
	0x080A: 0xFFFD,
	0x080B: 0xFFFD,
	0x080C: 0xFFFD,
	0x080D: 0xFFFD,
	0x080E: 0xFFFD,
	0x080F: 0xFFFD,
	0x0810: 0xFFFD,
	0x0811: 0xFFFD,
	0x0812: 0xFFFD,
	0x0813: 0xFFFD,
	0x0814: 0xFFFD,
	0x0815: 0xFFFD,
	0x0816: 0xFFFD,
	0x0817: 0xFFFD,
	0x0818: 0xFFFD,
	0x0819: 0xFFFD,
	0x081A: 0xFFFD,
	0x081B: 0xFFFD,
	0x081C: 0xFFFD,
	0x081D: 0xFFFD,
	0x081E: 0xFFFD,
	0x081F: 0xFFFD,
	0x0820: 0xFFFD,
	0x0821: 0xFFFD,
	0x0822: 0xFFFD,
	0x0823: 0xFFFD,
	0x0824: 0xFFFD,
	0x0825: 0xFFFD,
	0x0826: 0xFFFD,
	0x0827: 0xFFFD,
	0x0828: 0xFFFD,
	0x0829: 0xFFFD,
	0x082A: 0xFFFD,
	0x082B: 0xFFFD,
	0x082C: 0xFFFD,
	0x082D: 0xFFFD,
	0x082E: 0xFFFD,
	0x082F: 0xFFFD,
	0x0830: 0xFFFD,
	0x0831: 0xFFFD,
	0x0832: 0xFFFD,
	0x0833: 0xFFFD,
	0x0834: 0xFFFD,
	0x0835: 0xFFFD,
	0x0836: 0xFFFD,
	0x0837: 0xFFFD,
	0x0838: 0xFFFD,
	0x0839: 0xFFFD,
	0x083A: 0xFFFD,
	0x083B: 0xFFFD,
	0x083C: 0xFFFD,
	0x083D: 0xFFFD,
	0x083E: 0xFFFD,
	0x083F: 0xFFFD,
	0x0840: 0xFFFD,
	0x0841: 0xFFFD,
	0x0842: 0xFFFD,
	0x0843: 0xFFFD,
	0x0844: 0xFFFD,
	0x0845: 0xFFFD,
	0x0846: 0xFFFD,
	0x0847: 0xFFFD,
	0x0848: 0xFFFD,
	0x0849: 0xFFFD,
	0x084A: 0xFFFD,
	0x084B: 0xFFFD,
	0x084C: 0xFFFD,
	0x084D: 0xFFFD,
	0x084E: 0xFFFD,
	0x084F: 0xFFFD,
	0x0850: 0xFFFD,
	0x0851: 0xFFFD,
	0x0852: 0xFFFD,
	0x0853: 0xFFFD,
	0x0854: 0xFFFD,
	0x0855: 0xFFFD,
	0x0856: 0xFFFD,
	0x0857: 0xFFFD,
	0x0858: 0xFFFD,
	0x0859: 0xFFFD,
	0x085A: 0xFFFD,
	0x085B: 0xFFFD,
	0x085C: 0xFFFD,
	0x085D: 0xFFFD,
	0x085E: 0xFFFD,
	0x085F: 0xFFFD,
	0x0860: 0xFFFD,
	0x0861: 0xFFFD,
	0x0862: 0xFFFD,
	0x0863: 0xFFFD,
	0x0864: 0xFFFD,
	0x0865: 0xFFFD,
	0x0866: 0xFFFD,
	0x0867: 0xFFFD,
	0x0868: 0xFFFD,
	0x0869: 0xFFFD,
	0x086A: 0xFFFD,
	0x086B: 0xFFFD,
	0x086C: 0xFFFD,
	0x086D: 0xFFFD,
	0x086E: 0xFFFD,
	0x086F: 0xFFFD,
	0x0870: 0xFFFD,
	0x0871: 0xFFFD,
	0x0872: 0xFFFD,
	0x0873: 0xFFFD,
	0x0874: 0xFFFD,
	0x0875: 0xFFFD,
	0x0876: 0xFFFD,
	0x0877: 0xFFFD,
	0x0878: 0xFFFD,
	0x0879: 0xFFFD,
	0x087A: 0xFFFD,
	0x087B: 0xFFFD,
	0x087C: 0xFFFD,
	0x087D: 0xFFFD,
	0x087E: 0xFFFD,
	0x087F: 0xFFFD,
	0x0880: 0xFFFD,
	0x0881: 0xFFFD,
	0x0882: 0xFFFD,
	0x0883: 0xFFFD,
	0x0884: 0xFFFD,
	0x0885: 0xFFFD,
	0x0886: 0xFFFD,
	0x0887: 0xFFFD,
	0x0888: 0xFFFD,
	0x0889: 0xFFFD,
	0x088A: 0xFFFD,
	0x088B: 0xFFFD,
	0x088C: 0xFFFD,
	0x088D: 0xFFFD,
	0x088E: 0xFFFD,
	0x088F: 0xFFFD,
	0x0890: 0xFFFD,
	0x0891: 0xFFFD,
	0x0892: 0xFFFD,
	0x0893: 0xFFFD,
	0x0894: 0xFFFD,
	0x0895: 0xFFFD,
	0x0896: 0xFFFD,
	0x0897: 0xFFFD,
	0x0898: 0xFFFD,
	0x0899: 0xFFFD,
	0x089A: 0xFFFD,
	0x089B: 0xFFFD,
	0x089C: 0xFFFD,
	0x089D: 0xFFFD,
	0x089E: 0xFFFD,
	0x089F: 0xFFFD,
	0x08A0: 0xFFFD,
	0x08A1: 0xFFFD,
	0x08A2: 0xFFFD,
	0x08A3: 0xFFFD,
	0x08A4: 0xFFFD,
	0x08A5: 0xFFFD,
	0x08A6: 0xFFFD,
	0x08A7: 0xFFFD,
	0x08A8: 0xFFFD,
	0x08A9: 0xFFFD,
	0x08AA: 0xFFFD,
	0x08AB: 0xFFFD,
	0x08AC: 0xFFFD,
	0x08AD: 0xFFFD,
	0x08AE: 0xFFFD,
	0x08AF: 0xFFFD,
	0x08B0: 0xFFFD,
	0x08B1: 0xFFFD,
	0x08B2: 0xFFFD,
	0x08B3: 0xFFFD,
	0x08B4: 0xFFFD,
	0x08B5: 0xFFFD,
	0x08B6: 0xFFFD,
	0x08B7: 0xFFFD,
	0x08B8: 0xFFFD,
	0x08B9: 0xFFFD,
	0x08BA: 0xFFFD,
	0x08BB: 0xFFFD,
	0x08BC: 0xFFFD,
	0x08BD: 0xFFFD,
	0x08BE: 0xFFFD,
	0x08BF: 0xFFFD,
	0x08C0: 0xFFFD,
	0x08C1: 0xFFFD,
	0x08C2: 0xFFFD,
	0x08C3: 0xFFFD,
	0x08C4: 0xFFFD,
	0x08C5: 0xFFFD,
	0x08C6: 0xFFFD,
	0x08C7: 0xFFFD,
	0x08C8: 0xFFFD,
	0x08C9: 0xFFFD,
	0x08CA: 0xFFFD,
	0x08CB: 0xFFFD,
	0x08CC: 0xFFFD,
	0x08CD: 0xFFFD,
	0x08CE: 0xFFFD,
	0x08CF: 0xFFFD,
	0x08D0: 0xFFFD,
	0x08D1: 0xFFFD,
	0x08D2: 0xFFFD,
	0x08D3: 0xFFFD,
	0x08D4: 0xFFFD,
	0x08D5: 0xFFFD,
	0x08D6: 0xFFFD,
	0x08D7: 0xFFFD,
	0x08D8: 0xFFFD,
	0x08D9: 0xFFFD,
	0x08DA: 0xFFFD,
	0x08DB: 0xFFFD,
	0x08DC: 0xFFFD,
	0x08DD: 0xFFFD,
	0x08DE: 0xFFFD,
	0x08DF: 0xFFFD,
	0x08E0: 0xFFFD,
	0x08E1: 0xFFFD,
	0x08E2: 0xFFFD,
	0x08E3: 0xFFFD,
	0x08E4: 0xFFFD,
	0x08E5: 0xFFFD,
	0x08E6: 0xFFFD,
	0x08E7: 0xFFFD,
	0x08E8: 0xFFFD,
	0x08E9: 0xFFFD,
	0x08EA: 0xFFFD,
	0x08EB: 0xFFFD,
	0x08EC: 0xFFFD,
	0x08ED: 0xFFFD,
	0x08EE: 0xFFFD,
	0x08EF: 0xFFFD,
	0x08F0: 0xFFFD,
	0x08F1: 0xFFFD,
	0x08F2: 0xFFFD,
	0x08F3: 0xFFFD,
	0x08F4: 0xFFFD,
	0x08F5: 0xFFFD,
	0x08F6: 0xFFFD,
	0x08F7: 0xFFFD,
	0x08F8: 0xFFFD,
	0x08F9: 0xFFFD,
	0x08FA: 0xFFFD,
	0x08FB: 0xFFFD,
	0x08FC: 0xFFFD,
	0x08FD: 0xFFFD,
	0x08FE: 0xFFFD,
	0x08FF: 0xFFFD,
	0x0900: 0xFFFD,
	0x0901: 0xFFFD,
	0x0902: 0xFFFD,
	0x0903: 0xFFFD,
	0x0904: 0xFFFD,
	0x0905: 0xFFFD,
	0x0906: 0xFFFD,
	0x0907: 0xFFFD,
	0x0908: 0xFFFD,
	0x0909: 0xFFFD,
	0x090A: 0xFFFD,
	0x090B: 0xFFFD,
	0x090C: 0xFFFD,
	0x090D: 0xFFFD,
	0x090E: 0xFFFD,
	0x090F: 0xFFFD,
	0x0910: 0xFFFD,
	0x0911: 0xFFFD,
	0x0912: 0xFFFD,
	0x0913: 0xFFFD,
	0x0914: 0xFFFD,
	0x0915: 0xFFFD,
	0x0916: 0xFFFD,
	0x0917: 0xFFFD,
	0x0918: 0xFFFD,
	0x0919: 0xFFFD,
	0x091A: 0xFFFD,
	0x091B: 0xFFFD,
	0x091C: 0xFFFD,
	0x091D: 0xFFFD,
	0x091E: 0xFFFD,
	0x091F: 0xFFFD,
	0x0920: 0xFFFD,
	0x0921: 0xFFFD,
	0x0922: 0xFFFD,
	0x0923: 0xFFFD,
	0x0924: 0xFFFD,
	0x0925: 0xFFFD,
	0x0926: 0xFFFD,
	0x0927: 0xFFFD,
	0x0928: 0xFFFD,
	0x0929: 0xFFFD,
	0x092A: 0xFFFD,
	0x092B: 0xFFFD,
	0x092C: 0xFFFD,
	0x092D: 0xFFFD,
	0x092E: 0xFFFD,
	0x092F: 0xFFFD,
	0x0930: 0xFFFD,
	0x0931: 0xFFFD,
	0x0932: 0xFFFD,
	0x0933: 0xFFFD,
	0x0934: 0xFFFD,
	0x0935: 0xFFFD,
	0x0936: 0xFFFD,
	0x0937: 0xFFFD,
	0x0938: 0xFFFD,
	0x0939: 0xFFFD,
	0x093A: 0xFFFD,
	0x093B: 0xFFFD,
	0x093C: 0xFFFD,
	0x093D: 0xFFFD,
	0x093E: 0xFFFD,
	0x093F: 0xFFFD,
	0x0940: 0xFFFD,
	0x0941: 0xFFFD,
	0x0942: 0xFFFD,
	0x0943: 0xFFFD,
	0x0944: 0xFFFD,
	0x0945: 0xFFFD,
	0x0946: 0xFFFD,
	0x0947: 0xFFFD,
	0x0948: 0xFFFD,
	0x0949: 0xFFFD,
	0x094A: 0xFFFD,
	0x094B: 0xFFFD,
	0x094C: 0xFFFD,
	0x094D: 0xFFFD,
	0x094E: 0xFFFD,
	0x094F: 0xFFFD,
	0x0950: 0xFFFD,
	0x0951: 0xFFFD,
	0x0952: 0xFFFD,
	0x0953: 0xFFFD,
	0x0954: 0xFFFD,
	0x0955: 0xFFFD,
	0x0956: 0xFFFD,
	0x0957: 0xFFFD,
	0x0958: 0xFFFD,
	0x0959: 0xFFFD,
	0x095A: 0xFFFD,
	0x095B: 0xFFFD,
	0x095C: 0xFFFD,
	0x095D: 0xFFFD,
	0x095E: 0xFFFD,
	0x095F: 0xFFFD,
	0x0960: 0xFFFD,
	0x0961: 0xFFFD,
	0x0962: 0xFFFD,
	0x0963: 0xFFFD,
	0x0964: 0xFFFD,
	0x0965: 0xFFFD,
	0x0966: 0xFFFD,
	0x0967: 0xFFFD,
	0x0968: 0xFFFD,
	0x0969: 0xFFFD,
	0x096A: 0xFFFD,
	0x096B: 0xFFFD,
	0x096C: 0xFFFD,
	0x096D: 0xFFFD,
	0x096E: 0xFFFD,
	0x096F: 0xFFFD,
	0x0970: 0xFFFD,
	0x0971: 0xFFFD,
	0x0972: 0xFFFD,
	0x0973: 0xFFFD,
	0x0974: 0xFFFD,
	0x0975: 0xFFFD,
	0x0976: 0xFFFD,
	0x0977: 0xFFFD,
	0x0978: 0xFFFD,
	0x0979: 0xFFFD,
	0x097A: 0xFFFD,
	0x097B: 0xFFFD,
	0x097C: 0xFFFD,
	0x097D: 0xFFFD,
	0x097E: 0xFFFD,
	0x097F: 0xFFFD,
	0x0980: 0xFFFD,
	0x0981: 0xFFFD,
	0x0982: 0xFFFD,
	0x0983: 0xFFFD,
	0x0984: 0xFFFD,
	0x0985: 0xFFFD,
	0x0986: 0xFFFD,
	0x0987: 0xFFFD,
	0x0988: 0xFFFD,
	0x0989: 0xFFFD,
	0x098A: 0xFFFD,
	0x098B: 0xFFFD,
	0x098C: 0xFFFD,
	0x098D: 0xFFFD,
	0x098E: 0xFFFD,
	0x098F: 0xFFFD,
	0x0990: 0xFFFD,
	0x0991: 0xFFFD,
	0x0992: 0xFFFD,
	0x0993: 0xFFFD,
	0x0994: 0xFFFD,
	0x0995: 0xFFFD,
	0x0996: 0xFFFD,
	0x0997: 0xFFFD,
	0x0998: 0xFFFD,
	0x0999: 0xFFFD,
	0x099A: 0xFFFD,
	0x099B: 0xFFFD,
	0x099C: 0xFFFD,
	0x099D: 0xFFFD,
	0x099E: 0xFFFD,
	0x099F: 0xFFFD,
	0x09A0: 0xFFFD,
	0x09A1: 0xFFFD,
	0x09A2: 0xFFFD,
	0x09A3: 0xFFFD,
	0x09A4: 0xFFFD,
	0x09A5: 0xFFFD,
	0x09A6: 0xFFFD,
	0x09A7: 0xFFFD,
	0x09A8: 0xFFFD,
	0x09A9: 0xFFFD,
	0x09AA: 0xFFFD,
	0x09AB: 0xFFFD,
	0x09AC: 0xFFFD,
	0x09AD: 0xFFFD,
	0x09AE: 0xFFFD,
	0x09AF: 0xFFFD,
	0x09B0: 0xFFFD,
	0x09B1: 0xFFFD,
	0x09B2: 0xFFFD,
	0x09B3: 0xFFFD,
	0x09B4: 0xFFFD,
	0x09B5: 0xFFFD,
	0x09B6: 0xFFFD,
	0x09B7: 0xFFFD,
	0x09B8: 0xFFFD,
	0x09B9: 0xFFFD,
	0x09BA: 0xFFFD,
	0x09BB: 0xFFFD,
	0x09BC: 0xFFFD,
	0x09BD: 0xFFFD,
	0x09BE: 0xFFFD,
	0x09BF: 0xFFFD,
	0x09C0: 0xFFFD,
	0x09C1: 0xFFFD,
	0x09C2: 0xFFFD,
	0x09C3: 0xFFFD,
	0x09C4: 0xFFFD,
	0x09C5: 0xFFFD,
	0x09C6: 0xFFFD,
	0x09C7: 0xFFFD,
	0x09C8: 0xFFFD,
	0x09C9: 0xFFFD,
	0x09CA: 0xFFFD,
	0x09CB: 0xFFFD,
	0x09CC: 0xFFFD,
	0x09CD: 0xFFFD,
	0x09CE: 0xFFFD,
	0x09CF: 0xFFFD,
	0x09D0: 0xFFFD,
	0x09D1: 0xFFFD,
	0x09D2: 0xFFFD,
	0x09D3: 0xFFFD,
	0x09D4: 0xFFFD,
	0x09D5: 0xFFFD,
	0x09D6: 0xFFFD,
	0x09D7: 0xFFFD,
	0x09D8: 0xFFFD,
	0x09D9: 0xFFFD,
	0x09DA: 0xFFFD,
	0x09DB: 0xFFFD,
	0x09DC: 0xFFFD,
	0x09DD: 0xFFFD,
	0x09DE: 0xFFFD,
	0x09DF: 0xFFFD,
	0x09E0: 0xFFFD,
	0x09E1: 0xFFFD,
	0x09E2: 0xFFFD,
	0x09E3: 0xFFFD,
	0x09E4: 0xFFFD,
	0x09E5: 0xFFFD,
	0x09E6: 0xFFFD,
	0x09E7: 0xFFFD,
	0x09E8: 0xFFFD,
	0x09E9: 0xFFFD,
	0x09EA: 0xFFFD,
	0x09EB: 0xFFFD,
	0x09EC: 0xFFFD,
	0x09ED: 0xFFFD,
	0x09EE: 0xFFFD,
	0x09EF: 0xFFFD,
	0x09F0: 0xFFFD,
	0x09F1: 0xFFFD,
	0x09F2: 0xFFFD,
	0x09F3: 0xFFFD,
	0x09F4: 0xFFFD,
	0x09F5: 0xFFFD,
	0x09F6: 0xFFFD,
	0x09F7: 0xFFFD,
	0x09F8: 0xFFFD,
	0x09F9: 0xFFFD,
	0x09FA: 0xFFFD,
	0x09FB: 0xFFFD,
	0x09FC: 0xFFFD,
	0x09FD: 0xFFFD,
	0x09FE: 0xFFFD,
	0x09FF: 0xFFFD,
	0x0A00: 0xFFFD,
	0x0A01: 0xFFFD,
	0x0A02: 0xFFFD,
	0x0A03: 0xFFFD,
	0x0A04: 0xFFFD,
	0x0A05: 0xFFFD,
	0x0A06: 0xFFFD,
	0x0A07: 0xFFFD,
	0x0A08: 0xFFFD,
	0x0A09: 0xFFFD,
	0x0A0A: 0xFFFD,
	0x0A0B: 0xFFFD,
	0x0A0C: 0xFFFD,
	0x0A0D: 0xFFFD,
	0x0A0E: 0xFFFD,
	0x0A0F: 0xFFFD,
	0x0A10: 0xFFFD,
	0x0A11: 0xFFFD,
	0x0A12: 0xFFFD,
	0x0A13: 0xFFFD,
	0x0A14: 0xFFFD,
	0x0A15: 0xFFFD,
	0x0A16: 0xFFFD,
	0x0A17: 0xFFFD,
	0x0A18: 0xFFFD,
	0x0A19: 0xFFFD,
	0x0A1A: 0xFFFD,
	0x0A1B: 0xFFFD,
	0x0A1C: 0xFFFD,
	0x0A1D: 0xFFFD,
	0x0A1E: 0xFFFD,
	0x0A1F: 0xFFFD,
	0x0A20: 0xFFFD,
	0x0A21: 0xFFFD,
	0x0A22: 0xFFFD,
	0x0A23: 0xFFFD,
	0x0A24: 0xFFFD,
	0x0A25: 0xFFFD,
	0x0A26: 0xFFFD,
	0x0A27: 0xFFFD,
	0x0A28: 0xFFFD,
	0x0A29: 0xFFFD,
	0x0A2A: 0xFFFD,
	0x0A2B: 0xFFFD,
	0x0A2C: 0xFFFD,
	0x0A2D: 0xFFFD,
	0x0A2E: 0xFFFD,
	0x0A2F: 0xFFFD,
	0x0A30: 0xFFFD,
	0x0A31: 0xFFFD,
	0x0A32: 0xFFFD,
	0x0A33: 0xFFFD,
	0x0A34: 0xFFFD,
	0x0A35: 0xFFFD,
	0x0A36: 0xFFFD,
	0x0A37: 0xFFFD,
	0x0A38: 0xFFFD,
	0x0A39: 0xFFFD,
	0x0A3A: 0xFFFD,
	0x0A3B: 0xFFFD,
	0x0A3C: 0xFFFD,
	0x0A3D: 0xFFFD,
	0x0A3E: 0xFFFD,
	0x0A3F: 0xFFFD,
	0x0A40: 0xFFFD,
	0x0A41: 0xFFFD,
	0x0A42: 0xFFFD,
	0x0A43: 0xFFFD,
	0x0A44: 0xFFFD,
	0x0A45: 0xFFFD,
	0x0A46: 0xFFFD,
	0x0A47: 0xFFFD,
	0x0A48: 0xFFFD,
	0x0A49: 0xFFFD,
	0x0A4A: 0xFFFD,
	0x0A4B: 0xFFFD,
	0x0A4C: 0xFFFD,
	0x0A4D: 0xFFFD,
	0x0A4E: 0xFFFD,
	0x0A4F: 0xFFFD,
	0x0A50: 0xFFFD,
	0x0A51: 0xFFFD,
	0x0A52: 0xFFFD,
	0x0A53: 0xFFFD,
	0x0A54: 0xFFFD,
	0x0A55: 0xFFFD,
	0x0A56: 0xFFFD,
	0x0A57: 0xFFFD,
	0x0A58: 0xFFFD,
	0x0A59: 0xFFFD,
	0x0A5A: 0xFFFD,
	0x0A5B: 0xFFFD,
	0x0A5C: 0xFFFD,
	0x0A5D: 0xFFFD,
	0x0A5E: 0xFFFD,
	0x0A5F: 0xFFFD,
	0x0A60: 0xFFFD,
	0x0A61: 0xFFFD,
	0x0A62: 0xFFFD,
	0x0A63: 0xFFFD,
	0x0A64: 0xFFFD,
	0x0A65: 0xFFFD,
	0x0A66: 0xFFFD,
	0x0A67: 0xFFFD,
	0x0A68: 0xFFFD,
	0x0A69: 0xFFFD,
	0x0A6A: 0xFFFD,
	0x0A6B: 0xFFFD,
	0x0A6C: 0xFFFD,
	0x0A6D: 0xFFFD,
	0x0A6E: 0xFFFD,
	0x0A6F: 0xFFFD,
	0x0A70: 0xFFFD,
	0x0A71: 0xFFFD,
	0x0A72: 0xFFFD,
	0x0A73: 0xFFFD,
	0x0A74: 0xFFFD,
	0x0A75: 0xFFFD,
	0x0A76: 0xFFFD,
	0x0A77: 0xFFFD,
	0x0A78: 0xFFFD,
	0x0A79: 0xFFFD,
	0x0A7A: 0xFFFD,
	0x0A7B: 0xFFFD,
	0x0A7C: 0xFFFD,
	0x0A7D: 0xFFFD,
	0x0A7E: 0xFFFD,
	0x0A7F: 0xFFFD,
	0x0A80: 0xFFFD,
	0x0A81: 0xFFFD,
	0x0A82: 0xFFFD,
	0x0A83: 0xFFFD,
	0x0A84: 0xFFFD,
	0x0A85: 0xFFFD,
	0x0A86: 0xFFFD,
	0x0A87: 0xFFFD,
	0x0A88: 0xFFFD,
	0x0A89: 0xFFFD,
	0x0A8A: 0xFFFD,
	0x0A8B: 0xFFFD,
	0x0A8C: 0xFFFD,
	0x0A8D: 0xFFFD,
	0x0A8E: 0xFFFD,
	0x0A8F: 0xFFFD,
	0x0A90: 0xFFFD,
	0x0A91: 0xFFFD,
	0x0A92: 0xFFFD,
	0x0A93: 0xFFFD,
	0x0A94: 0xFFFD,
	0x0A95: 0xFFFD,
	0x0A96: 0xFFFD,
	0x0A97: 0xFFFD,
	0x0A98: 0xFFFD,
	0x0A99: 0xFFFD,
	0x0A9A: 0xFFFD,
	0x0A9B: 0xFFFD,
	0x0A9C: 0xFFFD,
	0x0A9D: 0xFFFD,
	0x0A9E: 0xFFFD,
	0x0A9F: 0xFFFD,
	0x0AA0: 0xFFFD,
	0x0AA1: 0xFFFD,
	0x0AA2: 0xFFFD,
	0x0AA3: 0xFFFD,
	0x0AA4: 0xFFFD,
	0x0AA5: 0xFFFD,
	0x0AA6: 0xFFFD,
	0x0AA7: 0xFFFD,
	0x0AA8: 0xFFFD,
	0x0AA9: 0xFFFD,
	0x0AAA: 0xFFFD,
	0x0AAB: 0xFFFD,
	0x0AAC: 0xFFFD,
	0x0AAD: 0xFFFD,
	0x0AAE: 0xFFFD,
	0x0AAF: 0xFFFD,
	0x0AB0: 0xFFFD,
	0x0AB1: 0xFFFD,
	0x0AB2: 0xFFFD,
	0x0AB3: 0xFFFD,
	0x0AB4: 0xFFFD,
	0x0AB5: 0xFFFD,
	0x0AB6: 0xFFFD,
	0x0AB7: 0xFFFD,
	0x0AB8: 0xFFFD,
	0x0AB9: 0xFFFD,
	0x0ABA: 0xFFFD,
	0x0ABB: 0xFFFD,
	0x0ABC: 0xFFFD,
	0x0ABD: 0xFFFD,
	0x0ABE: 0xFFFD,
	0x0ABF: 0xFFFD,
	0x0AC0: 0xFFFD,
	0x0AC1: 0xFFFD,
	0x0AC2: 0xFFFD,
	0x0AC3: 0xFFFD,
	0x0AC4: 0xFFFD,
	0x0AC5: 0xFFFD,
	0x0AC6: 0xFFFD,
	0x0AC7: 0xFFFD,
	0x0AC8: 0xFFFD,
	0x0AC9: 0xFFFD,
	0x0ACA: 0xFFFD,
	0x0ACB: 0xFFFD,
	0x0ACC: 0xFFFD,
	0x0ACD: 0xFFFD,
	0x0ACE: 0xFFFD,
	0x0ACF: 0xFFFD,
	0x0AD0: 0xFFFD,
	0x0AD1: 0xFFFD,
	0x0AD2: 0xFFFD,
	0x0AD3: 0xFFFD,
	0x0AD4: 0xFFFD,
	0x0AD5: 0xFFFD,
	0x0AD6: 0xFFFD,
	0x0AD7: 0xFFFD,
	0x0AD8: 0xFFFD,
	0x0AD9: 0xFFFD,
	0x0ADA: 0xFFFD,
	0x0ADB: 0xFFFD,
	0x0ADC: 0xFFFD,
	0x0ADD: 0xFFFD,
	0x0ADE: 0xFFFD,
	0x0ADF: 0xFFFD,
	0x0AE0: 0xFFFD,
	0x0AE1: 0xFFFD,
	0x0AE2: 0xFFFD,
	0x0AE3: 0xFFFD,
	0x0AE4: 0xFFFD,
	0x0AE5: 0xFFFD,
	0x0AE6: 0xFFFD,
	0x0AE7: 0xFFFD,
	0x0AE8: 0xFFFD,
	0x0AE9: 0xFFFD,
	0x0AEA: 0xFFFD,
	0x0AEB: 0xFFFD,
	0x0AEC: 0xFFFD,
	0x0AED: 0xFFFD,
	0x0AEE: 0xFFFD,
	0x0AEF: 0xFFFD,
	0x0AF0: 0xFFFD,
	0x0AF1: 0xFFFD,
	0x0AF2: 0xFFFD,
	0x0AF3: 0xFFFD,
	0x0AF4: 0xFFFD,
	0x0AF5: 0xFFFD,
	0x0AF6: 0xFFFD,
	0x0AF7: 0xFFFD,
	0x0AF8: 0xFFFD,
	0x0AF9: 0xFFFD,
	0x0AFA: 0xFFFD,
	0x0AFB: 0xFFFD,
	0x0AFC: 0xFFFD,
	0x0AFD: 0xFFFD,
	0x0AFE: 0xFFFD,
	0x0AFF: 0xFFFD,
	0x0B00: 0xFFFD,
	0x0B01: 0xFFFD,
	0x0B02: 0xFFFD,
	0x0B03: 0xFFFD,
	0x0B04: 0xFFFD,
	0x0B05: 0xFFFD,
	0x0B06: 0xFFFD,
	0x0B07: 0xFFFD,
	0x0B08: 0xFFFD,
	0x0B09: 0xFFFD,
	0x0B0A: 0xFFFD,
	0x0B0B: 0xFFFD,
	0x0B0C: 0xFFFD,
	0x0B0D: 0xFFFD,
	0x0B0E: 0xFFFD,
	0x0B0F: 0xFFFD,
	0x0B10: 0xFFFD,
	0x0B11: 0xFFFD,
	0x0B12: 0xFFFD,
	0x0B13: 0xFFFD,
	0x0B14: 0xFFFD,
	0x0B15: 0xFFFD,
	0x0B16: 0xFFFD,
	0x0B17: 0xFFFD,
	0x0B18: 0xFFFD,
	0x0B19: 0xFFFD,
	0x0B1A: 0xFFFD,
	0x0B1B: 0xFFFD,
	0x0B1C: 0xFFFD,
	0x0B1D: 0xFFFD,
	0x0B1E: 0xFFFD,
	0x0B1F: 0xFFFD,
	0x0B20: 0xFFFD,
	0x0B21: 0xFFFD,
	0x0B22: 0xFFFD,
	0x0B23: 0xFFFD,
	0x0B24: 0xFFFD,
	0x0B25: 0xFFFD,
	0x0B26: 0xFFFD,
	0x0B27: 0xFFFD,
	0x0B28: 0xFFFD,
	0x0B29: 0xFFFD,
	0x0B2A: 0xFFFD,
	0x0B2B: 0xFFFD,
	0x0B2C: 0xFFFD,
	0x0B2D: 0xFFFD,
	0x0B2E: 0xFFFD,
	0x0B2F: 0xFFFD,
	0x0B30: 0xFFFD,
	0x0B31: 0xFFFD,
	0x0B32: 0xFFFD,
	0x0B33: 0xFFFD,
	0x0B34: 0xFFFD,
	0x0B35: 0xFFFD,
	0x0B36: 0xFFFD,
	0x0B37: 0xFFFD,
	0x0B38: 0xFFFD,
	0x0B39: 0xFFFD,
	0x0B3A: 0xFFFD,
	0x0B3B: 0xFFFD,
	0x0B3C: 0xFFFD,
	0x0B3D: 0xFFFD,
	0x0B3E: 0xFFFD,
	0x0B3F: 0xFFFD,
	0x0B40: 0xFFFD,
	0x0B41: 0xFFFD,
	0x0B42: 0xFFFD,
	0x0B43: 0xFFFD,
	0x0B44: 0xFFFD,
	0x0B45: 0xFFFD,
	0x0B46: 0xFFFD,
	0x0B47: 0xFFFD,
	0x0B48: 0xFFFD,
	0x0B49: 0xFFFD,
	0x0B4A: 0xFFFD,
	0x0B4B: 0xFFFD,
	0x0B4C: 0xFFFD,
	0x0B4D: 0xFFFD,
	0x0B4E: 0xFFFD,
	0x0B4F: 0xFFFD,
	0x0B50: 0xFFFD,
	0x0B51: 0xFFFD,
	0x0B52: 0xFFFD,
	0x0B53: 0xFFFD,
	0x0B54: 0xFFFD,
	0x0B55: 0xFFFD,
	0x0B56: 0xFFFD,
	0x0B57: 0xFFFD,
	0x0B58: 0xFFFD,
	0x0B59: 0xFFFD,
	0x0B5A: 0xFFFD,
	0x0B5B: 0xFFFD,
	0x0B5C: 0xFFFD,
	0x0B5D: 0xFFFD,
	0x0B5E: 0xFFFD,
	0x0B5F: 0xFFFD,
	0x0B60: 0xFFFD,
	0x0B61: 0xFFFD,
	0x0B62: 0xFFFD,
	0x0B63: 0xFFFD,
	0x0B64: 0xFFFD,
	0x0B65: 0xFFFD,
	0x0B66: 0xFFFD,
	0x0B67: 0xFFFD,
	0x0B68: 0xFFFD,
	0x0B69: 0xFFFD,
	0x0B6A: 0xFFFD,
	0x0B6B: 0xFFFD,
	0x0B6C: 0xFFFD,
	0x0B6D: 0xFFFD,
	0x0B6E: 0xFFFD,
	0x0B6F: 0xFFFD,
	0x0B70: 0xFFFD,
	0x0B71: 0xFFFD,
	0x0B72: 0xFFFD,
	0x0B73: 0xFFFD,
	0x0B74: 0xFFFD,
	0x0B75: 0xFFFD,
	0x0B76: 0xFFFD,
	0x0B77: 0xFFFD,
	0x0B78: 0xFFFD,
	0x0B79: 0xFFFD,
	0x0B7A: 0xFFFD,
	0x0B7B: 0xFFFD,
	0x0B7C: 0xFFFD,
	0x0B7D: 0xFFFD,
	0x0B7E: 0xFFFD,
	0x0B7F: 0xFFFD,
	0x0B80: 0xFFFD,
	0x0B81: 0xFFFD,
	0x0B82: 0xFFFD,
	0x0B83: 0xFFFD,
	0x0B84: 0xFFFD,
	0x0B85: 0xFFFD,
	0x0B86: 0xFFFD,
	0x0B87: 0xFFFD,
	0x0B88: 0xFFFD,
	0x0B89: 0xFFFD,
	0x0B8A: 0xFFFD,
	0x0B8B: 0xFFFD,
	0x0B8C: 0xFFFD,
	0x0B8D: 0xFFFD,
	0x0B8E: 0xFFFD,
	0x0B8F: 0xFFFD,
	0x0B90: 0xFFFD,
	0x0B91: 0xFFFD,
	0x0B92: 0xFFFD,
	0x0B93: 0xFFFD,
	0x0B94: 0xFFFD,
	0x0B95: 0xFFFD,
	0x0B96: 0xFFFD,
	0x0B97: 0xFFFD,
	0x0B98: 0xFFFD,
	0x0B99: 0xFFFD,
	0x0B9A: 0xFFFD,
	0x0B9B: 0xFFFD,
	0x0B9C: 0xFFFD,
	0x0B9D: 0xFFFD,
	0x0B9E: 0xFFFD,
	0x0B9F: 0xFFFD,
	0x0BA0: 0xFFFD,
	0x0BA1: 0xFFFD,
	0x0BA2: 0xFFFD,
	0x0BA3: 0xFFFD,
	0x0BA4: 0xFFFD,
	0x0BA5: 0xFFFD,
	0x0BA6: 0xFFFD,
	0x0BA7: 0xFFFD,
	0x0BA8: 0xFFFD,
	0x0BA9: 0xFFFD,
	0x0BAA: 0xFFFD,
	0x0BAB: 0xFFFD,
	0x0BAC: 0xFFFD,
	0x0BAD: 0xFFFD,
	0x0BAE: 0xFFFD,
	0x0BAF: 0xFFFD,
	0x0BB0: 0xFFFD,
	0x0BB1: 0xFFFD,
	0x0BB2: 0xFFFD,
	0x0BB3: 0xFFFD,
	0x0BB4: 0xFFFD,
	0x0BB5: 0xFFFD,
	0x0BB6: 0xFFFD,
	0x0BB7: 0xFFFD,
	0x0BB8: 0xFFFD,
	0x0BB9: 0xFFFD,
	0x0BBA: 0xFFFD,
	0x0BBB: 0xFFFD,
	0x0BBC: 0xFFFD,
	0x0BBD: 0xFFFD,
	0x0BBE: 0xFFFD,
	0x0BBF: 0xFFFD,
	0x0BC0: 0xFFFD,
	0x0BC1: 0xFFFD,
	0x0BC2: 0xFFFD,
	0x0BC3: 0xFFFD,
	0x0BC4: 0xFFFD,
	0x0BC5: 0xFFFD,
	0x0BC6: 0xFFFD,
	0x0BC7: 0xFFFD,
	0x0BC8: 0xFFFD,
	0x0BC9: 0xFFFD,
	0x0BCA: 0xFFFD,
	0x0BCB: 0xFFFD,
	0x0BCC: 0xFFFD,
	0x0BCD: 0xFFFD,
	0x0BCE: 0xFFFD,
	0x0BCF: 0xFFFD,
	0x0BD0: 0xFFFD,
	0x0BD1: 0xFFFD,
	0x0BD2: 0xFFFD,
	0x0BD3: 0xFFFD,
	0x0BD4: 0xFFFD,
	0x0BD5: 0xFFFD,
	0x0BD6: 0xFFFD,
	0x0BD7: 0xFFFD,
	0x0BD8: 0xFFFD,
	0x0BD9: 0xFFFD,
	0x0BDA: 0xFFFD,
	0x0BDB: 0xFFFD,
	0x0BDC: 0xFFFD,
	0x0BDD: 0xFFFD,
	0x0BDE: 0xFFFD,
	0x0BDF: 0xFFFD,
	0x0BE0: 0xFFFD,
	0x0BE1: 0xFFFD,
	0x0BE2: 0xFFFD,
	0x0BE3: 0xFFFD,
	0x0BE4: 0xFFFD,
	0x0BE5: 0xFFFD,
	0x0BE6: 0xFFFD,
	0x0BE7: 0xFFFD,
	0x0BE8: 0xFFFD,
	0x0BE9: 0xFFFD,
	0x0BEA: 0xFFFD,
	0x0BEB: 0xFFFD,
	0x0BEC: 0xFFFD,
	0x0BED: 0xFFFD,
	0x0BEE: 0xFFFD,
	0x0BEF: 0xFFFD,
	0x0BF0: 0xFFFD,
	0x0BF1: 0xFFFD,
	0x0BF2: 0xFFFD,
	0x0BF3: 0xFFFD,
	0x0BF4: 0xFFFD,
	0x0BF5: 0xFFFD,
	0x0BF6: 0xFFFD,
	0x0BF7: 0xFFFD,
	0x0BF8: 0xFFFD,
	0x0BF9: 0xFFFD,
	0x0BFA: 0xFFFD,
	0x0BFB: 0xFFFD,
	0x0BFC: 0xFFFD,
	0x0BFD: 0xFFFD,
	0x0BFE: 0xFFFD,
	0x0BFF: 0xFFFD,
	0x0C00: 0xFFFD,
	0x0C01: 0xFFFD,
	0x0C02: 0xFFFD,
	0x0C03: 0xFFFD,
	0x0C04: 0xFFFD,
	0x0C05: 0xFFFD,
	0x0C06: 0xFFFD,
	0x0C07: 0xFFFD,
	0x0C08: 0xFFFD,
	0x0C09: 0xFFFD,
	0x0C0A: 0xFFFD,
	0x0C0B: 0xFFFD,
	0x0C0C: 0xFFFD,
	0x0C0D: 0xFFFD,
	0x0C0E: 0xFFFD,
	0x0C0F: 0xFFFD,
	0x0C10: 0xFFFD,
	0x0C11: 0xFFFD,
	0x0C12: 0xFFFD,
	0x0C13: 0xFFFD,
	0x0C14: 0xFFFD,
	0x0C15: 0xFFFD,
	0x0C16: 0xFFFD,
	0x0C17: 0xFFFD,
	0x0C18: 0xFFFD,
	0x0C19: 0xFFFD,
	0x0C1A: 0xFFFD,
	0x0C1B: 0xFFFD,
	0x0C1C: 0xFFFD,
	0x0C1D: 0xFFFD,
	0x0C1E: 0xFFFD,
	0x0C1F: 0xFFFD,
	0x0C20: 0xFFFD,
	0x0C21: 0xFFFD,
	0x0C22: 0xFFFD,
	0x0C23: 0xFFFD,
	0x0C24: 0xFFFD,
	0x0C25: 0xFFFD,
	0x0C26: 0xFFFD,
	0x0C27: 0xFFFD,
	0x0C28: 0xFFFD,
	0x0C29: 0xFFFD,
	0x0C2A: 0xFFFD,
	0x0C2B: 0xFFFD,
	0x0C2C: 0xFFFD,
	0x0C2D: 0xFFFD,
	0x0C2E: 0xFFFD,
	0x0C2F: 0xFFFD,
	0x0C30: 0xFFFD,
	0x0C31: 0xFFFD,
	0x0C32: 0xFFFD,
	0x0C33: 0xFFFD,
	0x0C34: 0xFFFD,
	0x0C35: 0xFFFD,
	0x0C36: 0xFFFD,
	0x0C37: 0xFFFD,
	0x0C38: 0xFFFD,
	0x0C39: 0xFFFD,
	0x0C3A: 0xFFFD,
	0x0C3B: 0xFFFD,
	0x0C3C: 0xFFFD,
	0x0C3D: 0xFFFD,
	0x0C3E: 0xFFFD,
	0x0C3F: 0xFFFD,
	0x0C40: 0xFFFD,
	0x0C41: 0xFFFD,
	0x0C42: 0xFFFD,
	0x0C43: 0xFFFD,
	0x0C44: 0xFFFD,
	0x0C45: 0xFFFD,
	0x0C46: 0xFFFD,
	0x0C47: 0xFFFD,
	0x0C48: 0xFFFD,
	0x0C49: 0xFFFD,
	0x0C4A: 0xFFFD,
	0x0C4B: 0xFFFD,
	0x0C4C: 0xFFFD,
	0x0C4D: 0xFFFD,
	0x0C4E: 0xFFFD,
	0x0C4F: 0xFFFD,
	0x0C50: 0xFFFD,
	0x0C51: 0xFFFD,
	0x0C52: 0xFFFD,
	0x0C53: 0xFFFD,
	0x0C54: 0xFFFD,
	0x0C55: 0xFFFD,
	0x0C56: 0xFFFD,
	0x0C57: 0xFFFD,
	0x0C58: 0xFFFD,
	0x0C59: 0xFFFD,
	0x0C5A: 0xFFFD,
	0x0C5B: 0xFFFD,
	0x0C5C: 0xFFFD,
	0x0C5D: 0xFFFD,
	0x0C5E: 0xFFFD,
	0x0C5F: 0xFFFD,
	0x0C60: 0xFFFD,
	0x0C61: 0xFFFD,
	0x0C62: 0xFFFD,
	0x0C63: 0xFFFD,
	0x0C64: 0xFFFD,
	0x0C65: 0xFFFD,
	0x0C66: 0xFFFD,
	0x0C67: 0xFFFD,
	0x0C68: 0xFFFD,
	0x0C69: 0xFFFD,
	0x0C6A: 0xFFFD,
	0x0C6B: 0xFFFD,
	0x0C6C: 0xFFFD,
	0x0C6D: 0xFFFD,
	0x0C6E: 0xFFFD,
	0x0C6F: 0xFFFD,
	0x0C70: 0xFFFD,
	0x0C71: 0xFFFD,
	0x0C72: 0xFFFD,
	0x0C73: 0xFFFD,
	0x0C74: 0xFFFD,
	0x0C75: 0xFFFD,
	0x0C76: 0xFFFD,
	0x0C77: 0xFFFD,
	0x0C78: 0xFFFD,
	0x0C79: 0xFFFD,
	0x0C7A: 0xFFFD,
	0x0C7B: 0xFFFD,
	0x0C7C: 0xFFFD,
	0x0C7D: 0xFFFD,
	0x0C7E: 0xFFFD,
	0x0C7F: 0xFFFD,
	0x0C80: 0xFFFD,
	0x0C81: 0xFFFD,
	0x0C82: 0xFFFD,
	0x0C83: 0xFFFD,
	0x0C84: 0xFFFD,
	0x0C85: 0xFFFD,
	0x0C86: 0xFFFD,
	0x0C87: 0xFFFD,
	0x0C88: 0xFFFD,
	0x0C89: 0xFFFD,
	0x0C8A: 0xFFFD,
	0x0C8B: 0xFFFD,
	0x0C8C: 0xFFFD,
	0x0C8D: 0xFFFD,
	0x0C8E: 0xFFFD,
	0x0C8F: 0xFFFD,
	0x0C90: 0xFFFD,
	0x0C91: 0xFFFD,
	0x0C92: 0xFFFD,
	0x0C93: 0xFFFD,
	0x0C94: 0xFFFD,
	0x0C95: 0xFFFD,
	0x0C96: 0xFFFD,
	0x0C97: 0xFFFD,
	0x0C98: 0xFFFD,
	0x0C99: 0xFFFD,
	0x0C9A: 0xFFFD,
	0x0C9B: 0xFFFD,
	0x0C9C: 0xFFFD,
	0x0C9D: 0xFFFD,
	0x0C9E: 0xFFFD,
	0x0C9F: 0xFFFD,
	0x0CA0: 0xFFFD,
	0x0CA1: 0xFFFD,
	0x0CA2: 0xFFFD,
	0x0CA3: 0xFFFD,
	0x0CA4: 0xFFFD,
	0x0CA5: 0xFFFD,
	0x0CA6: 0xFFFD,
	0x0CA7: 0xFFFD,
	0x0CA8: 0xFFFD,
	0x0CA9: 0xFFFD,
	0x0CAA: 0xFFFD,
	0x0CAB: 0xFFFD,
	0x0CAC: 0xFFFD,
	0x0CAD: 0xFFFD,
	0x0CAE: 0xFFFD,
	0x0CAF: 0xFFFD,
	0x0CB0: 0xFFFD,
	0x0CB1: 0xFFFD,
	0x0CB2: 0xFFFD,
	0x0CB3: 0xFFFD,
	0x0CB4: 0xFFFD,
	0x0CB5: 0xFFFD,
	0x0CB6: 0xFFFD,
	0x0CB7: 0xFFFD,
	0x0CB8: 0xFFFD,
	0x0CB9: 0xFFFD,
	0x0CBA: 0xFFFD,
	0x0CBB: 0xFFFD,
	0x0CBC: 0xFFFD,
	0x0CBD: 0xFFFD,
	0x0CBE: 0xFFFD,
	0x0CBF: 0xFFFD,
	0x0CC0: 0xFFFD,
	0x0CC1: 0xFFFD,
	0x0CC2: 0xFFFD,
	0x0CC3: 0xFFFD,
	0x0CC4: 0xFFFD,
	0x0CC5: 0xFFFD,
	0x0CC6: 0xFFFD,
	0x0CC7: 0xFFFD,
	0x0CC8: 0xFFFD,
	0x0CC9: 0xFFFD,
	0x0CCA: 0xFFFD,
	0x0CCB: 0xFFFD,
	0x0CCC: 0xFFFD,
	0x0CCD: 0xFFFD,
	0x0CCE: 0xFFFD,
	0x0CCF: 0xFFFD,
	0x0CD0: 0xFFFD,
	0x0CD1: 0xFFFD,
	0x0CD2: 0xFFFD,
	0x0CD3: 0xFFFD,
	0x0CD4: 0xFFFD,
	0x0CD5: 0xFFFD,
	0x0CD6: 0xFFFD,
	0x0CD7: 0xFFFD,
	0x0CD8: 0xFFFD,
	0x0CD9: 0xFFFD,
	0x0CDA: 0xFFFD,
	0x0CDB: 0xFFFD,
	0x0CDC: 0xFFFD,
	0x0CDD: 0xFFFD,
	0x0CDE: 0xFFFD,
	0x0CDF: 0xFFFD,
	0x0CE0: 0xFFFD,
	0x0CE1: 0xFFFD,
	0x0CE2: 0xFFFD,
	0x0CE3: 0xFFFD,
	0x0CE4: 0xFFFD,
	0x0CE5: 0xFFFD,
	0x0CE6: 0xFFFD,
	0x0CE7: 0xFFFD,
	0x0CE8: 0xFFFD,
	0x0CE9: 0xFFFD,
	0x0CEA: 0xFFFD,
	0x0CEB: 0xFFFD,
	0x0CEC: 0xFFFD,
	0x0CED: 0xFFFD,
	0x0CEE: 0xFFFD,
	0x0CEF: 0xFFFD,
	0x0CF0: 0xFFFD,
	0x0CF1: 0xFFFD,
	0x0CF2: 0xFFFD,
	0x0CF3: 0xFFFD,
	0x0CF4: 0xFFFD,
	0x0CF5: 0xFFFD,
	0x0CF6: 0xFFFD,
	0x0CF7: 0xFFFD,
	0x0CF8: 0xFFFD,
	0x0CF9: 0xFFFD,
	0x0CFA: 0xFFFD,
	0x0CFB: 0xFFFD,
	0x0CFC: 0xFFFD,
	0x0CFD: 0xFFFD,
	0x0CFE: 0xFFFD,
	0x0CFF: 0xFFFD,
	0x0D00: 0xFFFD,
	0x0D01: 0xFFFD,
	0x0D02: 0xFFFD,
	0x0D03: 0xFFFD,
	0x0D04: 0xFFFD,
	0x0D05: 0xFFFD,
	0x0D06: 0xFFFD,
	0x0D07: 0xFFFD,
	0x0D08: 0xFFFD,
	0x0D09: 0xFFFD,
	0x0D0A: 0xFFFD,
	0x0D0B: 0xFFFD,
	0x0D0C: 0xFFFD,
	0x0D0D: 0xFFFD,
	0x0D0E: 0xFFFD,
	0x0D0F: 0xFFFD,
	0x0D10: 0xFFFD,
	0x0D11: 0xFFFD,
	0x0D12: 0xFFFD,
	0x0D13: 0xFFFD,
	0x0D14: 0xFFFD,
	0x0D15: 0xFFFD,
	0x0D16: 0xFFFD,
	0x0D17: 0xFFFD,
	0x0D18: 0xFFFD,
	0x0D19: 0xFFFD,
	0x0D1A: 0xFFFD,
	0x0D1B: 0xFFFD,
	0x0D1C: 0xFFFD,
	0x0D1D: 0xFFFD,
	0x0D1E: 0xFFFD,
	0x0D1F: 0xFFFD,
	0x0D20: 0xFFFD,
	0x0D21: 0xFFFD,
	0x0D22: 0xFFFD,
	0x0D23: 0xFFFD,
	0x0D24: 0xFFFD,
	0x0D25: 0xFFFD,
	0x0D26: 0xFFFD,
	0x0D27: 0xFFFD,
	0x0D28: 0xFFFD,
	0x0D29: 0xFFFD,
	0x0D2A: 0xFFFD,
	0x0D2B: 0xFFFD,
	0x0D2C: 0xFFFD,
	0x0D2D: 0xFFFD,
	0x0D2E: 0xFFFD,
	0x0D2F: 0xFFFD,
	0x0D30: 0xFFFD,
	0x0D31: 0xFFFD,
	0x0D32: 0xFFFD,
	0x0D33: 0xFFFD,
	0x0D34: 0xFFFD,
	0x0D35: 0xFFFD,
	0x0D36: 0xFFFD,
	0x0D37: 0xFFFD,
	0x0D38: 0xFFFD,
	0x0D39: 0xFFFD,
	0x0D3A: 0xFFFD,
	0x0D3B: 0xFFFD,
	0x0D3C: 0xFFFD,
	0x0D3D: 0xFFFD,
	0x0D3E: 0xFFFD,
	0x0D3F: 0xFFFD,
	0x0D40: 0xFFFD,
	0x0D41: 0xFFFD,
	0x0D42: 0xFFFD,
	0x0D43: 0xFFFD,
	0x0D44: 0xFFFD,
	0x0D45: 0xFFFD,
	0x0D46: 0xFFFD,
	0x0D47: 0xFFFD,
	0x0D48: 0xFFFD,
	0x0D49: 0xFFFD,
	0x0D4A: 0xFFFD,
	0x0D4B: 0xFFFD,
	0x0D4C: 0xFFFD,
	0x0D4D: 0xFFFD,
	0x0D4E: 0xFFFD,
	0x0D4F: 0xFFFD,
	0x0D50: 0xFFFD,
	0x0D51: 0xFFFD,
	0x0D52: 0xFFFD,
	0x0D53: 0xFFFD,
	0x0D54: 0xFFFD,
	0x0D55: 0xFFFD,
	0x0D56: 0xFFFD,
	0x0D57: 0xFFFD,
	0x0D58: 0xFFFD,
	0x0D59: 0xFFFD,
	0x0D5A: 0xFFFD,
	0x0D5B: 0xFFFD,
	0x0D5C: 0xFFFD,
	0x0D5D: 0xFFFD,
	0x0D5E: 0xFFFD,
	0x0D5F: 0xFFFD,
	0x0D60: 0xFFFD,
	0x0D61: 0xFFFD,
	0x0D62: 0xFFFD,
	0x0D63: 0xFFFD,
	0x0D64: 0xFFFD,
	0x0D65: 0xFFFD,
	0x0D66: 0xFFFD,
	0x0D67: 0xFFFD,
	0x0D68: 0xFFFD,
	0x0D69: 0xFFFD,
	0x0D6A: 0xFFFD,
	0x0D6B: 0xFFFD,
	0x0D6C: 0xFFFD,
	0x0D6D: 0xFFFD,
	0x0D6E: 0xFFFD,
	0x0D6F: 0xFFFD,
	0x0D70: 0xFFFD,
	0x0D71: 0xFFFD,
	0x0D72: 0xFFFD,
	0x0D73: 0xFFFD,
	0x0D74: 0xFFFD,
	0x0D75: 0xFFFD,
	0x0D76: 0xFFFD,
	0x0D77: 0xFFFD,
	0x0D78: 0xFFFD,
	0x0D79: 0xFFFD,
	0x0D7A: 0xFFFD,
	0x0D7B: 0xFFFD,
	0x0D7C: 0xFFFD,
	0x0D7D: 0xFFFD,
	0x0D7E: 0xFFFD,
	0x0D7F: 0xFFFD,
	0x0D80: 0xFFFD,
	0x0D81: 0xFFFD,
	0x0D82: 0xFFFD,
	0x0D83: 0xFFFD,
	0x0D84: 0xFFFD,
	0x0D85: 0xFFFD,
	0x0D86: 0xFFFD,
	0x0D87: 0xFFFD,
	0x0D88: 0xFFFD,
	0x0D89: 0xFFFD,
	0x0D8A: 0xFFFD,
	0x0D8B: 0xFFFD,
	0x0D8C: 0xFFFD,
	0x0D8D: 0xFFFD,
	0x0D8E: 0xFFFD,
	0x0D8F: 0xFFFD,
	0x0D90: 0xFFFD,
	0x0D91: 0xFFFD,
	0x0D92: 0xFFFD,
	0x0D93: 0xFFFD,
	0x0D94: 0xFFFD,
	0x0D95: 0xFFFD,
	0x0D96: 0xFFFD,
	0x0D97: 0xFFFD,
	0x0D98: 0xFFFD,
	0x0D99: 0xFFFD,
	0x0D9A: 0xFFFD,
	0x0D9B: 0xFFFD,
	0x0D9C: 0xFFFD,
	0x0D9D: 0xFFFD,
	0x0D9E: 0xFFFD,
	0x0D9F: 0xFFFD,
	0x0DA0: 0xFFFD,
	0x0DA1: 0xFFFD,
	0x0DA2: 0xFFFD,
	0x0DA3: 0xFFFD,
	0x0DA4: 0xFFFD,
	0x0DA5: 0xFFFD,
	0x0DA6: 0xFFFD,
	0x0DA7: 0xFFFD,
	0x0DA8: 0xFFFD,
	0x0DA9: 0xFFFD,
	0x0DAA: 0xFFFD,
	0x0DAB: 0xFFFD,
	0x0DAC: 0xFFFD,
	0x0DAD: 0xFFFD,
	0x0DAE: 0xFFFD,
	0x0DAF: 0xFFFD,
	0x0DB0: 0xFFFD,
	0x0DB1: 0xFFFD,
	0x0DB2: 0xFFFD,
	0x0DB3: 0xFFFD,
	0x0DB4: 0xFFFD,
	0x0DB5: 0xFFFD,
	0x0DB6: 0xFFFD,
	0x0DB7: 0xFFFD,
	0x0DB8: 0xFFFD,
	0x0DB9: 0xFFFD,
	0x0DBA: 0xFFFD,
	0x0DBB: 0xFFFD,
	0x0DBC: 0xFFFD,
	0x0DBD: 0xFFFD,
	0x0DBE: 0xFFFD,
	0x0DBF: 0xFFFD,
	0x0DC0: 0xFFFD,
	0x0DC1: 0xFFFD,
	0x0DC2: 0xFFFD,
	0x0DC3: 0xFFFD,
	0x0DC4: 0xFFFD,
	0x0DC5: 0xFFFD,
	0x0DC6: 0xFFFD,
	0x0DC7: 0xFFFD,
	0x0DC8: 0xFFFD,
	0x0DC9: 0xFFFD,
	0x0DCA: 0xFFFD,
	0x0DCB: 0xFFFD,
	0x0DCC: 0xFFFD,
	0x0DCD: 0xFFFD,
	0x0DCE: 0xFFFD,
	0x0DCF: 0xFFFD,
	0x0DD0: 0xFFFD,
	0x0DD1: 0xFFFD,
	0x0DD2: 0xFFFD,
	0x0DD3: 0xFFFD,
	0x0DD4: 0xFFFD,
	0x0DD5: 0xFFFD,
	0x0DD6: 0xFFFD,
	0x0DD7: 0xFFFD,
	0x0DD8: 0xFFFD,
	0x0DD9: 0xFFFD,
	0x0DDA: 0xFFFD,
	0x0DDB: 0xFFFD,
	0x0DDC: 0xFFFD,
	0x0DDD: 0xFFFD,
	0x0DDE: 0xFFFD,
	0x0DDF: 0xFFFD,
	0x0DE0: 0xFFFD,
	0x0DE1: 0xFFFD,
	0x0DE2: 0xFFFD,
	0x0DE3: 0xFFFD,
	0x0DE4: 0xFFFD,
	0x0DE5: 0xFFFD,
	0x0DE6: 0xFFFD,
	0x0DE7: 0xFFFD,
	0x0DE8: 0xFFFD,
	0x0DE9: 0xFFFD,
	0x0DEA: 0xFFFD,
	0x0DEB: 0xFFFD,
	0x0DEC: 0xFFFD,
	0x0DED: 0xFFFD,
	0x0DEE: 0xFFFD,
	0x0DEF: 0xFFFD,
	0x0DF0: 0xFFFD,
	0x0DF1: 0xFFFD,
	0x0DF2: 0xFFFD,
	0x0DF3: 0xFFFD,
	0x0DF4: 0xFFFD,
	0x0DF5: 0xFFFD,
	0x0DF6: 0xFFFD,
	0x0DF7: 0xFFFD,
	0x0DF8: 0xFFFD,
	0x0DF9: 0xFFFD,
	0x0DFA: 0xFFFD,
	0x0DFB: 0xFFFD,
	0x0DFC: 0xFFFD,
	0x0DFD: 0xFFFD,
	0x0DFE: 0xFFFD,
	0x0DFF: 0xFFFD,
	0x0E00: 0xFFFD,
	0x0E01: 0xFFFD,
	0x0E02: 0xFFFD,
	0x0E03: 0xFFFD,
	0x0E04: 0xFFFD,
	0x0E05: 0xFFFD,
	0x0E06: 0xFFFD,
	0x0E07: 0xFFFD,
	0x0E08: 0xFFFD,
	0x0E09: 0xFFFD,
	0x0E0A: 0xFFFD,
	0x0E0B: 0xFFFD,
	0x0E0C: 0xFFFD,
	0x0E0D: 0xFFFD,
	0x0E0E: 0xFFFD,
	0x0E0F: 0xFFFD,
	0x0E10: 0xFFFD,
	0x0E11: 0xFFFD,
	0x0E12: 0xFFFD,
	0x0E13: 0xFFFD,
	0x0E14: 0xFFFD,
	0x0E15: 0xFFFD,
	0x0E16: 0xFFFD,
	0x0E17: 0xFFFD,
	0x0E18: 0xFFFD,
	0x0E19: 0xFFFD,
	0x0E1A: 0xFFFD,
	0x0E1B: 0xFFFD,
	0x0E1C: 0xFFFD,
	0x0E1D: 0xFFFD,
	0x0E1E: 0xFFFD,
	0x0E1F: 0xFFFD,
	0x0E20: 0xFFFD,
	0x0E21: 0xFFFD,
	0x0E22: 0xFFFD,
	0x0E23: 0xFFFD,
	0x0E24: 0xFFFD,
	0x0E25: 0xFFFD,
	0x0E26: 0xFFFD,
	0x0E27: 0xFFFD,
	0x0E28: 0xFFFD,
	0x0E29: 0xFFFD,
	0x0E2A: 0xFFFD,
	0x0E2B: 0xFFFD,
	0x0E2C: 0xFFFD,
	0x0E2D: 0xFFFD,
	0x0E2E: 0xFFFD,
	0x0E2F: 0xFFFD,
	0x0E30: 0xFFFD,
	0x0E31: 0xFFFD,
	0x0E32: 0xFFFD,
	0x0E33: 0xFFFD,
	0x0E34: 0xFFFD,
	0x0E35: 0xFFFD,
	0x0E36: 0xFFFD,
	0x0E37: 0xFFFD,
	0x0E38: 0xFFFD,
	0x0E39: 0xFFFD,
	0x0E3A: 0xFFFD,
	0x0E3B: 0xFFFD,
	0x0E3C: 0xFFFD,
	0x0E3D: 0xFFFD,
	0x0E3E: 0xFFFD,
	0x0E3F: 0xFFFD,
	0x0E40: 0xFFFD,
	0x0E41: 0xFFFD,
	0x0E42: 0xFFFD,
	0x0E43: 0xFFFD,
	0x0E44: 0xFFFD,
	0x0E45: 0xFFFD,
	0x0E46: 0xFFFD,
	0x0E47: 0xFFFD,
	0x0E48: 0xFFFD,
	0x0E49: 0xFFFD,
	0x0E4A: 0xFFFD,
	0x0E4B: 0xFFFD,
	0x0E4C: 0xFFFD,
	0x0E4D: 0xFFFD,
	0x0E4E: 0xFFFD,
	0x0E4F: 0xFFFD,
	0x0E50: 0xFFFD,
	0x0E51: 0xFFFD,
	0x0E52: 0xFFFD,
	0x0E53: 0xFFFD,
	0x0E54: 0xFFFD,
	0x0E55: 0xFFFD,
	0x0E56: 0xFFFD,
	0x0E57: 0xFFFD,
	0x0E58: 0xFFFD,
	0x0E59: 0xFFFD,
	0x0E5A: 0xFFFD,
	0x0E5B: 0xFFFD,
	0x0E5C: 0xFFFD,
	0x0E5D: 0xFFFD,
	0x0E5E: 0xFFFD,
	0x0E5F: 0xFFFD,
	0x0E60: 0xFFFD,
	0x0E61: 0xFFFD,
	0x0E62: 0xFFFD,
	0x0E63: 0xFFFD,
	0x0E64: 0xFFFD,
	0x0E65: 0xFFFD,
	0x0E66: 0xFFFD,
	0x0E67: 0xFFFD,
	0x0E68: 0xFFFD,
	0x0E69: 0xFFFD,
	0x0E6A: 0xFFFD,
	0x0E6B: 0xFFFD,
	0x0E6C: 0xFFFD,
	0x0E6D: 0xFFFD,
	0x0E6E: 0xFFFD,
	0x0E6F: 0xFFFD,
	0x0E70: 0xFFFD,
	0x0E71: 0xFFFD,
	0x0E72: 0xFFFD,
	0x0E73: 0xFFFD,
	0x0E74: 0xFFFD,
	0x0E75: 0xFFFD,
	0x0E76: 0xFFFD,
	0x0E77: 0xFFFD,
	0x0E78: 0xFFFD,
	0x0E79: 0xFFFD,
	0x0E7A: 0xFFFD,
	0x0E7B: 0xFFFD,
	0x0E7C: 0xFFFD,
	0x0E7D: 0xFFFD,
	0x0E7E: 0xFFFD,
	0x0E7F: 0xFFFD,
	0x0E80: 0xFFFD,
	0x0E81: 0xFFFD,
	0x0E82: 0xFFFD,
	0x0E83: 0xFFFD,
	0x0E84: 0xFFFD,
	0x0E85: 0xFFFD,
	0x0E86: 0xFFFD,
	0x0E87: 0xFFFD,
	0x0E88: 0xFFFD,
	0x0E89: 0xFFFD,
	0x0E8A: 0xFFFD,
	0x0E8B: 0xFFFD,
	0x0E8C: 0xFFFD,
	0x0E8D: 0xFFFD,
	0x0E8E: 0xFFFD,
	0x0E8F: 0xFFFD,
	0x0E90: 0xFFFD,
	0x0E91: 0xFFFD,
	0x0E92: 0xFFFD,
	0x0E93: 0xFFFD,
	0x0E94: 0xFFFD,
	0x0E95: 0xFFFD,
	0x0E96: 0xFFFD,
	0x0E97: 0xFFFD,
	0x0E98: 0xFFFD,
	0x0E99: 0xFFFD,
	0x0E9A: 0xFFFD,
	0x0E9B: 0xFFFD,
	0x0E9C: 0xFFFD,
	0x0E9D: 0xFFFD,
	0x0E9E: 0xFFFD,
	0x0E9F: 0xFFFD,
	0x0EA0: 0xFFFD,
	0x0EA1: 0xFFFD,
	0x0EA2: 0xFFFD,
	0x0EA3: 0xFFFD,
	0x0EA4: 0xFFFD,
	0x0EA5: 0xFFFD,
	0x0EA6: 0xFFFD,
	0x0EA7: 0xFFFD,
	0x0EA8: 0xFFFD,
	0x0EA9: 0xFFFD,
	0x0EAA: 0xFFFD,
	0x0EAB: 0xFFFD,
	0x0EAC: 0xFFFD,
	0x0EAD: 0xFFFD,
	0x0EAE: 0xFFFD,
	0x0EAF: 0xFFFD,
	0x0EB0: 0xFFFD,
	0x0EB1: 0xFFFD,
	0x0EB2: 0xFFFD,
	0x0EB3: 0xFFFD,
	0x0EB4: 0xFFFD,
	0x0EB5: 0xFFFD,
	0x0EB6: 0xFFFD,
	0x0EB7: 0xFFFD,
	0x0EB8: 0xFFFD,
	0x0EB9: 0xFFFD,
	0x0EBA: 0xFFFD,
	0x0EBB: 0xFFFD,
	0x0EBC: 0xFFFD,
	0x0EBD: 0xFFFD,
	0x0EBE: 0xFFFD,
	0x0EBF: 0xFFFD,
	0x0EC0: 0xFFFD,
	0x0EC1: 0xFFFD,
	0x0EC2: 0xFFFD,
	0x0EC3: 0xFFFD,
	0x0EC4: 0xFFFD,
	0x0EC5: 0xFFFD,
	0x0EC6: 0xFFFD,
	0x0EC7: 0xFFFD,
	0x0EC8: 0xFFFD,
	0x0EC9: 0xFFFD,
	0x0ECA: 0xFFFD,
	0x0ECB: 0xFFFD,
	0x0ECC: 0xFFFD,
	0x0ECD: 0xFFFD,
	0x0ECE: 0xFFFD,
	0x0ECF: 0xFFFD,
	0x0ED0: 0xFFFD,
	0x0ED1: 0xFFFD,
	0x0ED2: 0xFFFD,
	0x0ED3: 0xFFFD,
	0x0ED4: 0xFFFD,
	0x0ED5: 0xFFFD,
	0x0ED6: 0xFFFD,
	0x0ED7: 0xFFFD,
	0x0ED8: 0xFFFD,
	0x0ED9: 0xFFFD,
	0x0EDA: 0xFFFD,
	0x0EDB: 0xFFFD,
	0x0EDC: 0xFFFD,
	0x0EDD: 0xFFFD,
	0x0EDE: 0xFFFD,
	0x0EDF: 0xFFFD,
	0x0EE0: 0xFFFD,
	0x0EE1: 0xFFFD,
	0x0EE2: 0xFFFD,
	0x0EE3: 0xFFFD,
	0x0EE4: 0xFFFD,
	0x0EE5: 0xFFFD,
	0x0EE6: 0xFFFD,
	0x0EE7: 0xFFFD,
	0x0EE8: 0xFFFD,
	0x0EE9: 0xFFFD,
	0x0EEA: 0xFFFD,
	0x0EEB: 0xFFFD,
	0x0EEC: 0xFFFD,
	0x0EED: 0xFFFD,
	0x0EEE: 0xFFFD,
	0x0EEF: 0xFFFD,
	0x0EF0: 0xFFFD,
	0x0EF1: 0xFFFD,
	0x0EF2: 0xFFFD,
	0x0EF3: 0xFFFD,
	0x0EF4: 0xFFFD,
	0x0EF5: 0xFFFD,
	0x0EF6: 0xFFFD,
	0x0EF7: 0xFFFD,
	0x0EF8: 0xFFFD,
	0x0EF9: 0xFFFD,
	0x0EFA: 0xFFFD,
	0x0EFB: 0xFFFD,
	0x0EFC: 0xFFFD,
	0x0EFD: 0xFFFD,
	0x0EFE: 0xFFFD,
	0x0EFF: 0xFFFD,
	0x0F00: 0xFFFD,
	0x0F01: 0xFFFD,
	0x0F02: 0xFFFD,
	0x0F03: 0xFFFD,
	0x0F04: 0xFFFD,
	0x0F05: 0xFFFD,
	0x0F06: 0xFFFD,
	0x0F07: 0xFFFD,
	0x0F08: 0xFFFD,
	0x0F09: 0xFFFD,
	0x0F0A: 0xFFFD,
	0x0F0B: 0xFFFD,
	0x0F0C: 0xFFFD,
	0x0F0D: 0xFFFD,
	0x0F0E: 0xFFFD,
	0x0F0F: 0xFFFD,
	0x0F10: 0xFFFD,
	0x0F11: 0xFFFD,
	0x0F12: 0xFFFD,
	0x0F13: 0xFFFD,
	0x0F14: 0xFFFD,
	0x0F15: 0xFFFD,
	0x0F16: 0xFFFD,
	0x0F17: 0xFFFD,
	0x0F18: 0xFFFD,
	0x0F19: 0xFFFD,
	0x0F1A: 0xFFFD,
	0x0F1B: 0xFFFD,
	0x0F1C: 0xFFFD,
	0x0F1D: 0xFFFD,
	0x0F1E: 0xFFFD,
	0x0F1F: 0xFFFD,
	0x0F20: 0xFFFD,
	0x0F21: 0xFFFD,
	0x0F22: 0xFFFD,
	0x0F23: 0xFFFD,
	0x0F24: 0xFFFD,
	0x0F25: 0xFFFD,
	0x0F26: 0xFFFD,
	0x0F27: 0xFFFD,
	0x0F28: 0xFFFD,
	0x0F29: 0xFFFD,
	0x0F2A: 0xFFFD,
	0x0F2B: 0xFFFD,
	0x0F2C: 0xFFFD,
	0x0F2D: 0xFFFD,
	0x0F2E: 0xFFFD,
	0x0F2F: 0xFFFD,
	0x0F30: 0xFFFD,
	0x0F31: 0xFFFD,
	0x0F32: 0xFFFD,
	0x0F33: 0xFFFD,
	0x0F34: 0xFFFD,
	0x0F35: 0xFFFD,
	0x0F36: 0xFFFD,
	0x0F37: 0xFFFD,
	0x0F38: 0xFFFD,
	0x0F39: 0xFFFD,
	0x0F3A: 0xFFFD,
	0x0F3B: 0xFFFD,
	0x0F3C: 0xFFFD,
	0x0F3D: 0xFFFD,
	0x0F3E: 0xFFFD,
	0x0F3F: 0xFFFD,
	0x0F40: 0xFFFD,
	0x0F41: 0xFFFD,
	0x0F42: 0xFFFD,
	0x0F43: 0xFFFD,
	0x0F44: 0xFFFD,
	0x0F45: 0xFFFD,
	0x0F46: 0xFFFD,
	0x0F47: 0xFFFD,
	0x0F48: 0xFFFD,
	0x0F49: 0xFFFD,
	0x0F4A: 0xFFFD,
	0x0F4B: 0xFFFD,
	0x0F4C: 0xFFFD,
	0x0F4D: 0xFFFD,
	0x0F4E: 0xFFFD,
	0x0F4F: 0xFFFD,
	0x0F50: 0xFFFD,
	0x0F51: 0xFFFD,
	0x0F52: 0xFFFD,
	0x0F53: 0xFFFD,
	0x0F54: 0xFFFD,
	0x0F55: 0xFFFD,
	0x0F56: 0xFFFD,
	0x0F57: 0xFFFD,
	0x0F58: 0xFFFD,
	0x0F59: 0xFFFD,
	0x0F5A: 0xFFFD,
	0x0F5B: 0xFFFD,
	0x0F5C: 0xFFFD,
	0x0F5D: 0xFFFD,
	0x0F5E: 0xFFFD,
	0x0F5F: 0xFFFD,
	0x0F60: 0xFFFD,
	0x0F61: 0xFFFD,
	0x0F62: 0xFFFD,
	0x0F63: 0xFFFD,
	0x0F64: 0xFFFD,
	0x0F65: 0xFFFD,
	0x0F66: 0xFFFD,
	0x0F67: 0xFFFD,
	0x0F68: 0xFFFD,
	0x0F69: 0xFFFD,
	0x0F6A: 0xFFFD,
	0x0F6B: 0xFFFD,
	0x0F6C: 0xFFFD,
	0x0F6D: 0xFFFD,
	0x0F6E: 0xFFFD,
	0x0F6F: 0xFFFD,
	0x0F70: 0xFFFD,
	0x0F71: 0xFFFD,
	0x0F72: 0xFFFD,
	0x0F73: 0xFFFD,
	0x0F74: 0xFFFD,
	0x0F75: 0xFFFD,
	0x0F76: 0xFFFD,
	0x0F77: 0xFFFD,
	0x0F78: 0xFFFD,
	0x0F79: 0xFFFD,
	0x0F7A: 0xFFFD,
	0x0F7B: 0xFFFD,
	0x0F7C: 0xFFFD,
	0x0F7D: 0xFFFD,
	0x0F7E: 0xFFFD,
	0x0F7F: 0xFFFD,
	0x0F80: 0xFFFD,
	0x0F81: 0xFFFD,
	0x0F82: 0xFFFD,
	0x0F83: 0xFFFD,
	0x0F84: 0xFFFD,
	0x0F85: 0xFFFD,
	0x0F86: 0xFFFD,
	0x0F87: 0xFFFD,
	0x0F88: 0xFFFD,
	0x0F89: 0xFFFD,
	0x0F8A: 0xFFFD,
	0x0F8B: 0xFFFD,
	0x0F8C: 0xFFFD,
	0x0F8D: 0xFFFD,
	0x0F8E: 0xFFFD,
	0x0F8F: 0xFFFD,
	0x0F90: 0xFFFD,
	0x0F91: 0xFFFD,
	0x0F92: 0xFFFD,
	0x0F93: 0xFFFD,
	0x0F94: 0xFFFD,
	0x0F95: 0xFFFD,
	0x0F96: 0xFFFD,
	0x0F97: 0xFFFD,
	0x0F98: 0xFFFD,
	0x0F99: 0xFFFD,
	0x0F9A: 0xFFFD,
	0x0F9B: 0xFFFD,
	0x0F9C: 0xFFFD,
	0x0F9D: 0xFFFD,
	0x0F9E: 0xFFFD,
	0x0F9F: 0xFFFD,
	0x0FA0: 0xFFFD,
	0x0FA1: 0xFFFD,
	0x0FA2: 0xFFFD,
	0x0FA3: 0xFFFD,
	0x0FA4: 0xFFFD,
	0x0FA5: 0xFFFD,
	0x0FA6: 0xFFFD,
	0x0FA7: 0xFFFD,
	0x0FA8: 0xFFFD,
	0x0FA9: 0xFFFD,
	0x0FAA: 0xFFFD,
	0x0FAB: 0xFFFD,
	0x0FAC: 0xFFFD,
	0x0FAD: 0xFFFD,
	0x0FAE: 0xFFFD,
	0x0FAF: 0xFFFD,
	0x0FB0: 0xFFFD,
	0x0FB1: 0xFFFD,
	0x0FB2: 0xFFFD,
	0x0FB3: 0xFFFD,
	0x0FB4: 0xFFFD,
	0x0FB5: 0xFFFD,
	0x0FB6: 0xFFFD,
	0x0FB7: 0xFFFD,
	0x0FB8: 0xFFFD,
	0x0FB9: 0xFFFD,
	0x0FBA: 0xFFFD,
	0x0FBB: 0xFFFD,
	0x0FBC: 0xFFFD,
	0x0FBD: 0xFFFD,
	0x0FBE: 0xFFFD,
	0x0FBF: 0xFFFD,
	0x0FC0: 0xFFFD,
	0x0FC1: 0xFFFD,
	0x0FC2: 0xFFFD,
	0x0FC3: 0xFFFD,
	0x0FC4: 0xFFFD,
	0x0FC5: 0xFFFD,
	0x0FC6: 0xFFFD,
	0x0FC7: 0xFFFD,
	0x0FC8: 0xFFFD,
	0x0FC9: 0xFFFD,
	0x0FCA: 0xFFFD,
	0x0FCB: 0xFFFD,
	0x0FCC: 0xFFFD,
	0x0FCD: 0xFFFD,
	0x0FCE: 0xFFFD,
	0x0FCF: 0xFFFD,
	0x0FD0: 0xFFFD,
	0x0FD1: 0xFFFD,
	0x0FD2: 0xFFFD,
	0x0FD3: 0xFFFD,
	0x0FD4: 0xFFFD,
	0x0FD5: 0xFFFD,
	0x0FD6: 0xFFFD,
	0x0FD7: 0xFFFD,
	0x0FD8: 0xFFFD,
	0x0FD9: 0xFFFD,
	0x0FDA: 0xFFFD,
	0x0FDB: 0xFFFD,
	0x0FDC: 0xFFFD,
	0x0FDD: 0xFFFD,
	0x0FDE: 0xFFFD,
	0x0FDF: 0xFFFD,
	0x0FE0: 0xFFFD,
	0x0FE1: 0xFFFD,
	0x0FE2: 0xFFFD,
	0x0FE3: 0xFFFD,
	0x0FE4: 0xFFFD,
	0x0FE5: 0xFFFD,
	0x0FE6: 0xFFFD,
	0x0FE7: 0xFFFD,
	0x0FE8: 0xFFFD,
	0x0FE9: 0xFFFD,
	0x0FEA: 0xFFFD,
	0x0FEB: 0xFFFD,
	0x0FEC: 0xFFFD,
	0x0FED: 0xFFFD,
	0x0FEE: 0xFFFD,
	0x0FEF: 0xFFFD,
	0x0FF0: 0xFFFD,
	0x0FF1: 0xFFFD,
	0x0FF2: 0xFFFD,
	0x0FF3: 0xFFFD,
	0x0FF4: 0xFFFD,
	0x0FF5: 0xFFFD,
	0x0FF6: 0xFFFD,
	0x0FF7: 0xFFFD,
	0x0FF8: 0xFFFD,
	0x0FF9: 0xFFFD,
	0x0FFA: 0xFFFD,
	0x0FFB: 0xFFFD,
	0x0FFC: 0xFFFD,
	0x0FFD: 0xFFFD,
	0x0FFE: 0xFFFD,
	0x0FFF: 0xFFFD,
	0x1000: 0xFFFD,
	0x1001: 0xFFFD,
	0x1002: 0xFFFD,
	0x1003: 0xFFFD,
	0x1004: 0xFFFD,
	0x1005: 0xFFFD,
	0x1006: 0xFFFD,
	0x1007: 0xFFFD,
	0x1008: 0xFFFD,
	0x1009: 0xFFFD,
	0x100A: 0xFFFD,
	0x100B: 0xFFFD,
	0x100C: 0xFFFD,
	0x100D: 0xFFFD,
	0x100E: 0xFFFD,
	0x100F: 0xFFFD,
	0x1010: 0xFFFD,
	0x1011: 0xFFFD,
	0x1012: 0xFFFD,
	0x1013: 0xFFFD,
	0x1014: 0xFFFD,
	0x1015: 0xFFFD,
	0x1016: 0xFFFD,
	0x1017: 0xFFFD,
	0x1018: 0xFFFD,
	0x1019: 0xFFFD,
	0x101A: 0xFFFD,
	0x101B: 0xFFFD,
	0x101C: 0xFFFD,
	0x101D: 0xFFFD,
	0x101E: 0xFFFD,
	0x101F: 0xFFFD,
	0x1020: 0xFFFD,
	0x1021: 0xFFFD,
	0x1022: 0xFFFD,
	0x1023: 0xFFFD,
	0x1024: 0xFFFD,
	0x1025: 0xFFFD,
	0x1026: 0xFFFD,
	0x1027: 0xFFFD,
	0x1028: 0xFFFD,
	0x1029: 0xFFFD,
	0x102A: 0xFFFD,
	0x102B: 0xFFFD,
	0x102C: 0xFFFD,
	0x102D: 0xFFFD,
	0x102E: 0xFFFD,
	0x102F: 0xFFFD,
	0x1030: 0xFFFD,
	0x1031: 0xFFFD,
	0x1032: 0xFFFD,
	0x1033: 0xFFFD,
	0x1034: 0xFFFD,
	0x1035: 0xFFFD,
	0x1036: 0xFFFD,
	0x1037: 0xFFFD,
	0x1038: 0xFFFD,
	0x1039: 0xFFFD,
	0x103A: 0xFFFD,
	0x103B: 0xFFFD,
	0x103C: 0xFFFD,
	0x103D: 0xFFFD,
	0x103E: 0xFFFD,
	0x103F: 0xFFFD,
	0x1040: 0xFFFD,
	0x1041: 0xFFFD,
	0x1042: 0xFFFD,
	0x1043: 0xFFFD,
	0x1044: 0xFFFD,
	0x1045: 0xFFFD,
	0x1046: 0xFFFD,
	0x1047: 0xFFFD,
	0x1048: 0xFFFD,
	0x1049: 0xFFFD,
	0x104A: 0xFFFD,
	0x104B: 0xFFFD,
	0x104C: 0xFFFD,
	0x104D: 0xFFFD,
	0x104E: 0xFFFD,
	0x104F: 0xFFFD,
	0x1050: 0xFFFD,
	0x1051: 0xFFFD,
	0x1052: 0xFFFD,
	0x1053: 0xFFFD,
	0x1054: 0xFFFD,
	0x1055: 0xFFFD,
	0x1056: 0xFFFD,
	0x1057: 0xFFFD,
	0x1058: 0xFFFD,
	0x1059: 0xFFFD,
	0x105A: 0xFFFD,
	0x105B: 0xFFFD,
	0x105C: 0xFFFD,
	0x105D: 0xFFFD,
	0x105E: 0xFFFD,
	0x105F: 0xFFFD,
	0x1060: 0xFFFD,
	0x1061: 0xFFFD,
	0x1062: 0xFFFD,
	0x1063: 0xFFFD,
	0x1064: 0xFFFD,
	0x1065: 0xFFFD,
	0x1066: 0xFFFD,
	0x1067: 0xFFFD,
	0x1068: 0xFFFD,
	0x1069: 0xFFFD,
	0x106A: 0xFFFD,
	0x106B: 0xFFFD,
	0x106C: 0xFFFD,
	0x106D: 0xFFFD,
	0x106E: 0xFFFD,
	0x106F: 0xFFFD,
	0x1070: 0xFFFD,
	0x1071: 0xFFFD,
	0x1072: 0xFFFD,
	0x1073: 0xFFFD,
	0x1074: 0xFFFD,
	0x1075: 0xFFFD,
	0x1076: 0xFFFD,
	0x1077: 0xFFFD,
	0x1078: 0xFFFD,
	0x1079: 0xFFFD,
	0x107A: 0xFFFD,
	0x107B: 0xFFFD,
	0x107C: 0xFFFD,
	0x107D: 0xFFFD,
	0x107E: 0xFFFD,
	0x107F: 0xFFFD,
	0x1080: 0xFFFD,
	0x1081: 0xFFFD,
	0x1082: 0xFFFD,
	0x1083: 0xFFFD,
	0x1084: 0xFFFD,
	0x1085: 0xFFFD,
	0x1086: 0xFFFD,
	0x1087: 0xFFFD,
	0x1088: 0xFFFD,
	0x1089: 0xFFFD,
	0x108A: 0xFFFD,
	0x108B: 0xFFFD,
	0x108C: 0xFFFD,
	0x108D: 0xFFFD,
	0x108E: 0xFFFD,
	0x108F: 0xFFFD,
	0x1090: 0xFFFD,
	0x1091: 0xFFFD,
	0x1092: 0xFFFD,
	0x1093: 0xFFFD,
	0x1094: 0xFFFD,
	0x1095: 0xFFFD,
	0x1096: 0xFFFD,
	0x1097: 0xFFFD,
	0x1098: 0xFFFD,
	0x1099: 0xFFFD,
	0x109A: 0xFFFD,
	0x109B: 0xFFFD,
	0x109C: 0xFFFD,
	0x109D: 0xFFFD,
	0x109E: 0xFFFD,
	0x109F: 0xFFFD,
	0x10A0: 0xFFFD,
	0x10A1: 0xFFFD,
	0x10A2: 0xFFFD,
	0x10A3: 0xFFFD,
	0x10A4: 0xFFFD,
	0x10A5: 0xFFFD,
	0x10A6: 0xFFFD,
	0x10A7: 0xFFFD,
	0x10A8: 0xFFFD,
	0x10A9: 0xFFFD,
	0x10AA: 0xFFFD,
	0x10AB: 0xFFFD,
	0x10AC: 0xFFFD,
	0x10AD: 0xFFFD,
	0x10AE: 0xFFFD,
	0x10AF: 0xFFFD,
	0x10B0: 0xFFFD,
	0x10B1: 0xFFFD,
	0x10B2: 0xFFFD,
	0x10B3: 0xFFFD,
	0x10B4: 0xFFFD,
	0x10B5: 0xFFFD,
	0x10B6: 0xFFFD,
	0x10B7: 0xFFFD,
	0x10B8: 0xFFFD,
	0x10B9: 0xFFFD,
	0x10BA: 0xFFFD,
	0x10BB: 0xFFFD,
	0x10BC: 0xFFFD,
	0x10BD: 0xFFFD,
	0x10BE: 0xFFFD,
	0x10BF: 0xFFFD,
	0x10C0: 0xFFFD,
	0x10C1: 0xFFFD,
	0x10C2: 0xFFFD,
	0x10C3: 0xFFFD,
	0x10C4: 0xFFFD,
	0x10C5: 0xFFFD,
	0x10C6: 0xFFFD,
	0x10C7: 0xFFFD,
	0x10C8: 0xFFFD,
	0x10C9: 0xFFFD,
	0x10CA: 0xFFFD,
	0x10CB: 0xFFFD,
	0x10CC: 0xFFFD,
	0x10CD: 0xFFFD,
	0x10CE: 0xFFFD,
	0x10CF: 0xFFFD,
	0x10D0: 0xFFFD,
	0x10D1: 0xFFFD,
	0x10D2: 0xFFFD,
	0x10D3: 0xFFFD,
	0x10D4: 0xFFFD,
	0x10D5: 0xFFFD,
	0x10D6: 0xFFFD,
	0x10D7: 0xFFFD,
	0x10D8: 0xFFFD,
	0x10D9: 0xFFFD,
	0x10DA: 0xFFFD,
	0x10DB: 0xFFFD,
	0x10DC: 0xFFFD,
	0x10DD: 0xFFFD,
	0x10DE: 0xFFFD,
	0x10DF: 0xFFFD,
	0x10E0: 0xFFFD,
	0x10E1: 0xFFFD,
	0x10E2: 0xFFFD,
	0x10E3: 0xFFFD,
	0x10E4: 0xFFFD,
	0x10E5: 0xFFFD,
	0x10E6: 0xFFFD,
	0x10E7: 0xFFFD,
	0x10E8: 0xFFFD,
	0x10E9: 0xFFFD,
	0x10EA: 0xFFFD,
	0x10EB: 0xFFFD,
	0x10EC: 0xFFFD,
	0x10ED: 0xFFFD,
	0x10EE: 0xFFFD,
	0x10EF: 0xFFFD,
	0x10F0: 0xFFFD,
	0x10F1: 0xFFFD,
	0x10F2: 0xFFFD,
	0x10F3: 0xFFFD,
	0x10F4: 0xFFFD,
	0x10F5: 0xFFFD,
	0x10F6: 0xFFFD,
	0x10F7: 0xFFFD,
	0x10F8: 0xFFFD,
	0x10F9: 0xFFFD,
	0x10FA: 0xFFFD,
	0x10FB: 0xFFFD,
	0x10FC: 0xFFFD,
	0x10FD: 0xFFFD,
	0x10FE: 0xFFFD,
	0x10FF: 0xFFFD,
	0x1100: 0xFFFD,
	0x1101: 0xFFFD,
	0x1102: 0xFFFD,
	0x1103: 0xFFFD,
	0x1104: 0xFFFD,
	0x1105: 0xFFFD,
	0x1106: 0xFFFD,
	0x1107: 0xFFFD,
	0x1108: 0xFFFD,
	0x1109: 0xFFFD,
	0x110A: 0xFFFD,
	0x110B: 0xFFFD,
	0x110C: 0xFFFD,
	0x110D: 0xFFFD,
	0x110E: 0xFFFD,
	0x110F: 0xFFFD,
	0x1110: 0xFFFD,
	0x1111: 0xFFFD,
	0x1112: 0xFFFD,
	0x1113: 0xFFFD,
	0x1114: 0xFFFD,
	0x1115: 0xFFFD,
	0x1116: 0xFFFD,
	0x1117: 0xFFFD,
	0x1118: 0xFFFD,
	0x1119: 0xFFFD,
	0x111A: 0xFFFD,
	0x111B: 0xFFFD,
	0x111C: 0xFFFD,
	0x111D: 0xFFFD,
	0x111E: 0xFFFD,
	0x111F: 0xFFFD,
	0x1120: 0xFFFD,
	0x1121: 0xFFFD,
	0x1122: 0xFFFD,
	0x1123: 0xFFFD,
	0x1124: 0xFFFD,
	0x1125: 0xFFFD,
	0x1126: 0xFFFD,
	0x1127: 0xFFFD,
	0x1128: 0xFFFD,
	0x1129: 0xFFFD,
	0x112A: 0xFFFD,
	0x112B: 0xFFFD,
	0x112C: 0xFFFD,
	0x112D: 0xFFFD,
	0x112E: 0xFFFD,
	0x112F: 0xFFFD,
	0x1130: 0xFFFD,
	0x1131: 0xFFFD,
	0x1132: 0xFFFD,
	0x1133: 0xFFFD,
	0x1134: 0xFFFD,
	0x1135: 0xFFFD,
	0x1136: 0xFFFD,
	0x1137: 0xFFFD,
	0x1138: 0xFFFD,
	0x1139: 0xFFFD,
	0x113A: 0xFFFD,
	0x113B: 0xFFFD,
	0x113C: 0xFFFD,
	0x113D: 0xFFFD,
	0x113E: 0xFFFD,
	0x113F: 0xFFFD,
	0x1140: 0xFFFD,
	0x1141: 0xFFFD,
	0x1142: 0xFFFD,
	0x1143: 0xFFFD,
	0x1144: 0xFFFD,
	0x1145: 0xFFFD,
	0x1146: 0xFFFD,
	0x1147: 0xFFFD,
	0x1148: 0xFFFD,
	0x1149: 0xFFFD,
	0x114A: 0xFFFD,
	0x114B: 0xFFFD,
	0x114C: 0xFFFD,
	0x114D: 0xFFFD,
	0x114E: 0xFFFD,
	0x114F: 0xFFFD,
	0x1150: 0xFFFD,
	0x1151: 0xFFFD,
	0x1152: 0xFFFD,
	0x1153: 0xFFFD,
	0x1154: 0xFFFD,
	0x1155: 0xFFFD,
	0x1156: 0xFFFD,
	0x1157: 0xFFFD,
	0x1158: 0xFFFD,
	0x1159: 0xFFFD,
	0x115A: 0xFFFD,
	0x115B: 0xFFFD,
	0x115C: 0xFFFD,
	0x115D: 0xFFFD,
	0x115E: 0xFFFD,
	0x115F: 0xFFFD,
	0x1160: 0xFFFD,
	0x1161: 0xFFFD,
	0x1162: 0xFFFD,
	0x1163: 0xFFFD,
	0x1164: 0xFFFD,
	0x1165: 0xFFFD,
	0x1166: 0xFFFD,
	0x1167: 0xFFFD,
	0x1168: 0xFFFD,
	0x1169: 0xFFFD,
	0x116A: 0xFFFD,
	0x116B: 0xFFFD,
	0x116C: 0xFFFD,
	0x116D: 0xFFFD,
	0x116E: 0xFFFD,
	0x116F: 0xFFFD,
	0x1170: 0xFFFD,
	0x1171: 0xFFFD,
	0x1172: 0xFFFD,
	0x1173: 0xFFFD,
	0x1174: 0xFFFD,
	0x1175: 0xFFFD,
	0x1176: 0xFFFD,
	0x1177: 0xFFFD,
	0x1178: 0xFFFD,
	0x1179: 0xFFFD,
	0x117A: 0xFFFD,
	0x117B: 0xFFFD,
	0x117C: 0xFFFD,
	0x117D: 0xFFFD,
	0x117E: 0xFFFD,
	0x117F: 0xFFFD,
	0x1180: 0xFFFD,
	0x1181: 0xFFFD,
	0x1182: 0xFFFD,
	0x1183: 0xFFFD,
	0x1184: 0xFFFD,
	0x1185: 0xFFFD,
	0x1186: 0xFFFD,
	0x1187: 0xFFFD,
	0x1188: 0xFFFD,
	0x1189: 0xFFFD,
	0x118A: 0xFFFD,
	0x118B: 0xFFFD,
	0x118C: 0xFFFD,
	0x118D: 0xFFFD,
	0x118E: 0xFFFD,
	0x118F: 0xFFFD,
	0x1190: 0xFFFD,
	0x1191: 0xFFFD,
	0x1192: 0xFFFD,
	0x1193: 0xFFFD,
	0x1194: 0xFFFD,
	0x1195: 0xFFFD,
	0x1196: 0xFFFD,
	0x1197: 0xFFFD,
	0x1198: 0xFFFD,
	0x1199: 0xFFFD,
	0x119A: 0xFFFD,
	0x119B: 0xFFFD,
	0x119C: 0xFFFD,
	0x119D: 0xFFFD,
	0x119E: 0xFFFD,
	0x119F: 0xFFFD,
	0x11A0: 0xFFFD,
	0x11A1: 0xFFFD,
	0x11A2: 0xFFFD,
	0x11A3: 0xFFFD,
	0x11A4: 0xFFFD,
	0x11A5: 0xFFFD,
	0x11A6: 0xFFFD,
	0x11A7: 0xFFFD,
	0x11A8: 0xFFFD,
	0x11A9: 0xFFFD,
	0x11AA: 0xFFFD,
	0x11AB: 0xFFFD,
	0x11AC: 0xFFFD,
	0x11AD: 0xFFFD,
	0x11AE: 0xFFFD,
	0x11AF: 0xFFFD,
	0x11B0: 0xFFFD,
	0x11B1: 0xFFFD,
	0x11B2: 0xFFFD,
	0x11B3: 0xFFFD,
	0x11B4: 0xFFFD,
	0x11B5: 0xFFFD,
	0x11B6: 0xFFFD,
	0x11B7: 0xFFFD,
	0x11B8: 0xFFFD,
	0x11B9: 0xFFFD,
	0x11BA: 0xFFFD,
	0x11BB: 0xFFFD,
	0x11BC: 0xFFFD,
	0x11BD: 0xFFFD,
	0x11BE: 0xFFFD,
	0x11BF: 0xFFFD,
	0x11C0: 0xFFFD,
	0x11C1: 0xFFFD,
	0x11C2: 0xFFFD,
	0x11C3: 0xFFFD,
	0x11C4: 0xFFFD,
	0x11C5: 0xFFFD,
	0x11C6: 0xFFFD,
	0x11C7: 0xFFFD,
	0x11C8: 0xFFFD,
	0x11C9: 0xFFFD,
	0x11CA: 0xFFFD,
	0x11CB: 0xFFFD,
	0x11CC: 0xFFFD,
	0x11CD: 0xFFFD,
	0x11CE: 0xFFFD,
	0x11CF: 0xFFFD,
	0x11D0: 0xFFFD,
	0x11D1: 0xFFFD,
	0x11D2: 0xFFFD,
	0x11D3: 0xFFFD,
	0x11D4: 0xFFFD,
	0x11D5: 0xFFFD,
	0x11D6: 0xFFFD,
	0x11D7: 0xFFFD,
	0x11D8: 0xFFFD,
	0x11D9: 0xFFFD,
	0x11DA: 0xFFFD,
	0x11DB: 0xFFFD,
	0x11DC: 0xFFFD,
	0x11DD: 0xFFFD,
	0x11DE: 0xFFFD,
	0x11DF: 0xFFFD,
	0x11E0: 0xFFFD,
	0x11E1: 0xFFFD,
	0x11E2: 0xFFFD,
	0x11E3: 0xFFFD,
	0x11E4: 0xFFFD,
	0x11E5: 0xFFFD,
	0x11E6: 0xFFFD,
	0x11E7: 0xFFFD,
	0x11E8: 0xFFFD,
	0x11E9: 0xFFFD,
	0x11EA: 0xFFFD,
	0x11EB: 0xFFFD,
	0x11EC: 0xFFFD,
	0x11ED: 0xFFFD,
	0x11EE: 0xFFFD,
	0x11EF: 0xFFFD,
	0x11F0: 0xFFFD,
	0x11F1: 0xFFFD,
	0x11F2: 0xFFFD,
	0x11F3: 0xFFFD,
	0x11F4: 0xFFFD,
	0x11F5: 0xFFFD,
	0x11F6: 0xFFFD,
	0x11F7: 0xFFFD,
	0x11F8: 0xFFFD,
	0x11F9: 0xFFFD,
	0x11FA: 0xFFFD,
	0x11FB: 0xFFFD,
	0x11FC: 0xFFFD,
	0x11FD: 0xFFFD,
	0x11FE: 0xFFFD,
	0x11FF: 0xFFFD,
	0x1200: 0xFFFD,
	0x1201: 0xFFFD,
	0x1202: 0xFFFD,
	0x1203: 0xFFFD,
	0x1204: 0xFFFD,
	0x1205: 0xFFFD,
	0x1206: 0xFFFD,
	0x1207: 0xFFFD,
	0x1208: 0xFFFD,
	0x1209: 0xFFFD,
	0x120A: 0xFFFD,
	0x120B: 0xFFFD,
	0x120C: 0xFFFD,
	0x120D: 0xFFFD,
	0x120E: 0xFFFD,
	0x120F: 0xFFFD,
	0x1210: 0xFFFD,
	0x1211: 0xFFFD,
	0x1212: 0xFFFD,
	0x1213: 0xFFFD,
	0x1214: 0xFFFD,
	0x1215: 0xFFFD,
	0x1216: 0xFFFD,
	0x1217: 0xFFFD,
	0x1218: 0xFFFD,
	0x1219: 0xFFFD,
	0x121A: 0xFFFD,
	0x121B: 0xFFFD,
	0x121C: 0xFFFD,
	0x121D: 0xFFFD,
	0x121E: 0xFFFD,
	0x121F: 0xFFFD,
	0x1220: 0xFFFD,
	0x1221: 0xFFFD,
	0x1222: 0xFFFD,
	0x1223: 0xFFFD,
	0x1224: 0xFFFD,
	0x1225: 0xFFFD,
	0x1226: 0xFFFD,
	0x1227: 0xFFFD,
	0x1228: 0xFFFD,
	0x1229: 0xFFFD,
	0x122A: 0xFFFD,
	0x122B: 0xFFFD,
	0x122C: 0xFFFD,
	0x122D: 0xFFFD,
	0x122E: 0xFFFD,
	0x122F: 0xFFFD,
	0x1230: 0xFFFD,
	0x1231: 0xFFFD,
	0x1232: 0xFFFD,
	0x1233: 0xFFFD,
	0x1234: 0xFFFD,
	0x1235: 0xFFFD,
	0x1236: 0xFFFD,
	0x1237: 0xFFFD,
	0x1238: 0xFFFD,
	0x1239: 0xFFFD,
	0x123A: 0xFFFD,
	0x123B: 0xFFFD,
	0x123C: 0xFFFD,
	0x123D: 0xFFFD,
	0x123E: 0xFFFD,
	0x123F: 0xFFFD,
	0x1240: 0xFFFD,
	0x1241: 0xFFFD,
	0x1242: 0xFFFD,
	0x1243: 0xFFFD,
	0x1244: 0xFFFD,
	0x1245: 0xFFFD,
	0x1246: 0xFFFD,
	0x1247: 0xFFFD,
	0x1248: 0xFFFD,
	0x1249: 0xFFFD,
	0x124A: 0xFFFD,
	0x124B: 0xFFFD,
	0x124C: 0xFFFD,
	0x124D: 0xFFFD,
	0x124E: 0xFFFD,
	0x124F: 0xFFFD,
	0x1250: 0xFFFD,
	0x1251: 0xFFFD,
	0x1252: 0xFFFD,
	0x1253: 0xFFFD,
	0x1254: 0xFFFD,
	0x1255: 0xFFFD,
	0x1256: 0xFFFD,
	0x1257: 0xFFFD,
	0x1258: 0xFFFD,
	0x1259: 0xFFFD,
	0x125A: 0xFFFD,
	0x125B: 0xFFFD,
	0x125C: 0xFFFD,
	0x125D: 0xFFFD,
	0x125E: 0xFFFD,
	0x125F: 0xFFFD,
	0x1260: 0xFFFD,
	0x1261: 0xFFFD,
	0x1262: 0xFFFD,
	0x1263: 0xFFFD,
	0x1264: 0xFFFD,
	0x1265: 0xFFFD,
	0x1266: 0xFFFD,
	0x1267: 0xFFFD,
	0x1268: 0xFFFD,
	0x1269: 0xFFFD,
	0x126A: 0xFFFD,
	0x126B: 0xFFFD,
	0x126C: 0xFFFD,
	0x126D: 0xFFFD,
	0x126E: 0xFFFD,
	0x126F: 0xFFFD,
	0x1270: 0xFFFD,
	0x1271: 0xFFFD,
	0x1272: 0xFFFD,
	0x1273: 0xFFFD,
	0x1274: 0xFFFD,
	0x1275: 0xFFFD,
	0x1276: 0xFFFD,
	0x1277: 0xFFFD,
	0x1278: 0xFFFD,
	0x1279: 0xFFFD,
	0x127A: 0xFFFD,
	0x127B: 0xFFFD,
	0x127C: 0xFFFD,
	0x127D: 0xFFFD,
	0x127E: 0xFFFD,
	0x127F: 0xFFFD,
	0x1280: 0xFFFD,
	0x1281: 0xFFFD,
	0x1282: 0xFFFD,
	0x1283: 0xFFFD,
	0x1284: 0xFFFD,
	0x1285: 0xFFFD,
	0x1286: 0xFFFD,
	0x1287: 0xFFFD,
	0x1288: 0xFFFD,
	0x1289: 0xFFFD,
	0x128A: 0xFFFD,
	0x128B: 0xFFFD,
	0x128C: 0xFFFD,
	0x128D: 0xFFFD,
	0x128E: 0xFFFD,
	0x128F: 0xFFFD,
	0x1290: 0xFFFD,
	0x1291: 0xFFFD,
	0x1292: 0xFFFD,
	0x1293: 0xFFFD,
	0x1294: 0xFFFD,
	0x1295: 0xFFFD,
	0x1296: 0xFFFD,
	0x1297: 0xFFFD,
	0x1298: 0xFFFD,
	0x1299: 0xFFFD,
	0x129A: 0xFFFD,
	0x129B: 0xFFFD,
	0x129C: 0xFFFD,
	0x129D: 0xFFFD,
	0x129E: 0xFFFD,
	0x129F: 0xFFFD,
	0x12A0: 0xFFFD,
	0x12A1: 0xFFFD,
	0x12A2: 0xFFFD,
	0x12A3: 0xFFFD,
	0x12A4: 0xFFFD,
	0x12A5: 0xFFFD,
	0x12A6: 0xFFFD,
	0x12A7: 0xFFFD,
	0x12A8: 0xFFFD,
	0x12A9: 0xFFFD,
	0x12AA: 0xFFFD,
	0x12AB: 0xFFFD,
	0x12AC: 0xFFFD,
	0x12AD: 0xFFFD,
	0x12AE: 0xFFFD,
	0x12AF: 0xFFFD,
	0x12B0: 0xFFFD,
	0x12B1: 0xFFFD,
	0x12B2: 0xFFFD,
	0x12B3: 0xFFFD,
	0x12B4: 0xFFFD,
	0x12B5: 0xFFFD,
	0x12B6: 0xFFFD,
	0x12B7: 0xFFFD,
	0x12B8: 0xFFFD,
	0x12B9: 0xFFFD,
	0x12BA: 0xFFFD,
	0x12BB: 0xFFFD,
	0x12BC: 0xFFFD,
	0x12BD: 0xFFFD,
	0x12BE: 0xFFFD,
	0x12BF: 0xFFFD,
	0x12C0: 0xFFFD,
	0x12C1: 0xFFFD,
	0x12C2: 0xFFFD,
	0x12C3: 0xFFFD,
	0x12C4: 0xFFFD,
	0x12C5: 0xFFFD,
	0x12C6: 0xFFFD,
	0x12C7: 0xFFFD,
	0x12C8: 0xFFFD,
	0x12C9: 0xFFFD,
	0x12CA: 0xFFFD,
	0x12CB: 0xFFFD,
	0x12CC: 0xFFFD,
	0x12CD: 0xFFFD,
	0x12CE: 0xFFFD,
	0x12CF: 0xFFFD,
	0x12D0: 0xFFFD,
	0x12D1: 0xFFFD,
	0x12D2: 0xFFFD,
	0x12D3: 0xFFFD,
	0x12D4: 0xFFFD,
	0x12D5: 0xFFFD,
	0x12D6: 0xFFFD,
	0x12D7: 0xFFFD,
	0x12D8: 0xFFFD,
	0x12D9: 0xFFFD,
	0x12DA: 0xFFFD,
	0x12DB: 0xFFFD,
	0x12DC: 0xFFFD,
	0x12DD: 0xFFFD,
	0x12DE: 0xFFFD,
	0x12DF: 0xFFFD,
	0x12E0: 0xFFFD,
	0x12E1: 0xFFFD,
	0x12E2: 0xFFFD,
	0x12E3: 0xFFFD,
	0x12E4: 0xFFFD,
	0x12E5: 0xFFFD,
	0x12E6: 0xFFFD,
	0x12E7: 0xFFFD,
	0x12E8: 0xFFFD,
	0x12E9: 0xFFFD,
	0x12EA: 0xFFFD,
	0x12EB: 0xFFFD,
	0x12EC: 0xFFFD,
	0x12ED: 0xFFFD,
	0x12EE: 0xFFFD,
	0x12EF: 0xFFFD,
	0x12F0: 0xFFFD,
	0x12F1: 0xFFFD,
	0x12F2: 0xFFFD,
	0x12F3: 0xFFFD,
	0x12F4: 0xFFFD,
	0x12F5: 0xFFFD,
	0x12F6: 0xFFFD,
	0x12F7: 0xFFFD,
	0x12F8: 0xFFFD,
	0x12F9: 0xFFFD,
	0x12FA: 0xFFFD,
	0x12FB: 0xFFFD,
	0x12FC: 0xFFFD,
	0x12FD: 0xFFFD,
	0x12FE: 0xFFFD,
	0x12FF: 0xFFFD,
	0x1300: 0xFFFD,
	0x1301: 0xFFFD,
	0x1302: 0xFFFD,
	0x1303: 0xFFFD,
	0x1304: 0xFFFD,
	0x1305: 0xFFFD,
	0x1306: 0xFFFD,
	0x1307: 0xFFFD,
	0x1308: 0xFFFD,
	0x1309: 0xFFFD,
	0x130A: 0xFFFD,
	0x130B: 0xFFFD,
	0x130C: 0xFFFD,
	0x130D: 0xFFFD,
	0x130E: 0xFFFD,
	0x130F: 0xFFFD,
	0x1310: 0xFFFD,
	0x1311: 0xFFFD,
	0x1312: 0xFFFD,
	0x1313: 0xFFFD,
	0x1314: 0xFFFD,
	0x1315: 0xFFFD,
	0x1316: 0xFFFD,
	0x1317: 0xFFFD,
	0x1318: 0xFFFD,
	0x1319: 0xFFFD,
	0x131A: 0xFFFD,
	0x131B: 0xFFFD,
	0x131C: 0xFFFD,
	0x131D: 0xFFFD,
	0x131E: 0xFFFD,
	0x131F: 0xFFFD,
	0x1320: 0xFFFD,
	0x1321: 0xFFFD,
	0x1322: 0xFFFD,
	0x1323: 0xFFFD,
	0x1324: 0xFFFD,
	0x1325: 0xFFFD,
	0x1326: 0xFFFD,
	0x1327: 0xFFFD,
	0x1328: 0xFFFD,
	0x1329: 0xFFFD,
	0x132A: 0xFFFD,
	0x132B: 0xFFFD,
	0x132C: 0xFFFD,
	0x132D: 0xFFFD,
	0x132E: 0xFFFD,
	0x132F: 0xFFFD,
	0x1330: 0xFFFD,
	0x1331: 0xFFFD,
	0x1332: 0xFFFD,
	0x1333: 0xFFFD,
	0x1334: 0xFFFD,
	0x1335: 0xFFFD,
	0x1336: 0xFFFD,
	0x1337: 0xFFFD,
	0x1338: 0xFFFD,
	0x1339: 0xFFFD,
	0x133A: 0xFFFD,
	0x133B: 0xFFFD,
	0x133C: 0xFFFD,
	0x133D: 0xFFFD,
	0x133E: 0xFFFD,
	0x133F: 0xFFFD,
	0x1340: 0xFFFD,
	0x1341: 0xFFFD,
	0x1342: 0xFFFD,
	0x1343: 0xFFFD,
	0x1344: 0xFFFD,
	0x1345: 0xFFFD,
	0x1346: 0xFFFD,
	0x1347: 0xFFFD,
	0x1348: 0xFFFD,
	0x1349: 0xFFFD,
	0x134A: 0xFFFD,
	0x134B: 0xFFFD,
	0x134C: 0xFFFD,
	0x134D: 0xFFFD,
	0x134E: 0xFFFD,
	0x134F: 0xFFFD,
	0x1350: 0xFFFD,
	0x1351: 0xFFFD,
	0x1352: 0xFFFD,
	0x1353: 0xFFFD,
	0x1354: 0xFFFD,
	0x1355: 0xFFFD,
	0x1356: 0xFFFD,
	0x1357: 0xFFFD,
	0x1358: 0xFFFD,
	0x1359: 0xFFFD,
	0x135A: 0xFFFD,
	0x135B: 0xFFFD,
	0x135C: 0xFFFD,
	0x135D: 0xFFFD,
	0x135E: 0xFFFD,
	0x135F: 0xFFFD,
	0x1360: 0xFFFD,
	0x1361: 0xFFFD,
	0x1362: 0xFFFD,
	0x1363: 0xFFFD,
	0x1364: 0xFFFD,
	0x1365: 0xFFFD,
	0x1366: 0xFFFD,
	0x1367: 0xFFFD,
	0x1368: 0xFFFD,
	0x1369: 0xFFFD,
	0x136A: 0xFFFD,
	0x136B: 0xFFFD,
	0x136C: 0xFFFD,
	0x136D: 0xFFFD,
	0x136E: 0xFFFD,
	0x136F: 0xFFFD,
	0x1370: 0xFFFD,
	0x1371: 0xFFFD,
	0x1372: 0xFFFD,
	0x1373: 0xFFFD,
	0x1374: 0xFFFD,
	0x1375: 0xFFFD,
	0x1376: 0xFFFD,
	0x1377: 0xFFFD,
	0x1378: 0xFFFD,
	0x1379: 0xFFFD,
	0x137A: 0xFFFD,
	0x137B: 0xFFFD,
	0x137C: 0xFFFD,
	0x137D: 0xFFFD,
	0x137E: 0xFFFD,
	0x137F: 0xFFFD,
	0x1380: 0xFFFD,
	0x1381: 0xFFFD,
	0x1382: 0xFFFD,
	0x1383: 0xFFFD,
	0x1384: 0xFFFD,
	0x1385: 0xFFFD,
	0x1386: 0xFFFD,
	0x1387: 0xFFFD,
	0x1388: 0xFFFD,
	0x1389: 0xFFFD,
	0x138A: 0xFFFD,
	0x138B: 0xFFFD,
	0x138C: 0xFFFD,
	0x138D: 0xFFFD,
	0x138E: 0xFFFD,
	0x138F: 0xFFFD,
	0x1390: 0xFFFD,
	0x1391: 0xFFFD,
	0x1392: 0xFFFD,
	0x1393: 0xFFFD,
	0x1394: 0xFFFD,
	0x1395: 0xFFFD,
	0x1396: 0xFFFD,
	0x1397: 0xFFFD,
	0x1398: 0xFFFD,
	0x1399: 0xFFFD,
	0x139A: 0xFFFD,
	0x139B: 0xFFFD,
	0x139C: 0xFFFD,
	0x139D: 0xFFFD,
	0x139E: 0xFFFD,
	0x139F: 0xFFFD,
	0x13A0: 0xFFFD,
	0x13A1: 0xFFFD,
	0x13A2: 0xFFFD,
	0x13A3: 0xFFFD,
	0x13A4: 0xFFFD,
	0x13A5: 0xFFFD,
	0x13A6: 0xFFFD,
	0x13A7: 0xFFFD,
	0x13A8: 0xFFFD,
	0x13A9: 0xFFFD,
	0x13AA: 0xFFFD,
	0x13AB: 0xFFFD,
	0x13AC: 0xFFFD,
	0x13AD: 0xFFFD,
	0x13AE: 0xFFFD,
	0x13AF: 0xFFFD,
	0x13B0: 0xFFFD,
	0x13B1: 0xFFFD,
	0x13B2: 0xFFFD,
	0x13B3: 0xFFFD,
	0x13B4: 0xFFFD,
	0x13B5: 0xFFFD,
	0x13B6: 0xFFFD,
	0x13B7: 0xFFFD,
	0x13B8: 0xFFFD,
	0x13B9: 0xFFFD,
	0x13BA: 0xFFFD,
	0x13BB: 0xFFFD,
	0x13BC: 0xFFFD,
	0x13BD: 0xFFFD,
	0x13BE: 0xFFFD,
	0x13BF: 0xFFFD,
	0x13C0: 0xFFFD,
	0x13C1: 0xFFFD,
	0x13C2: 0xFFFD,
	0x13C3: 0xFFFD,
	0x13C4: 0xFFFD,
	0x13C5: 0xFFFD,
	0x13C6: 0xFFFD,
	0x13C7: 0xFFFD,
	0x13C8: 0xFFFD,
	0x13C9: 0xFFFD,
	0x13CA: 0xFFFD,
	0x13CB: 0xFFFD,
	0x13CC: 0xFFFD,
	0x13CD: 0xFFFD,
	0x13CE: 0xFFFD,
	0x13CF: 0xFFFD,
	0x13D0: 0xFFFD,
	0x13D1: 0xFFFD,
	0x13D2: 0xFFFD,
	0x13D3: 0xFFFD,
	0x13D4: 0xFFFD,
	0x13D5: 0xFFFD,
	0x13D6: 0xFFFD,
	0x13D7: 0xFFFD,
	0x13D8: 0xFFFD,
	0x13D9: 0xFFFD,
	0x13DA: 0xFFFD,
	0x13DB: 0xFFFD,
	0x13DC: 0xFFFD,
	0x13DD: 0xFFFD,
	0x13DE: 0xFFFD,
	0x13DF: 0xFFFD,
	0x13E0: 0xFFFD,
	0x13E1: 0xFFFD,
	0x13E2: 0xFFFD,
	0x13E3: 0xFFFD,
	0x13E4: 0xFFFD,
	0x13E5: 0xFFFD,
	0x13E6: 0xFFFD,
	0x13E7: 0xFFFD,
	0x13E8: 0xFFFD,
	0x13E9: 0xFFFD,
	0x13EA: 0xFFFD,
	0x13EB: 0xFFFD,
	0x13EC: 0xFFFD,
	0x13ED: 0xFFFD,
	0x13EE: 0xFFFD,
	0x13EF: 0xFFFD,
	0x13F0: 0xFFFD,
	0x13F1: 0xFFFD,
	0x13F2: 0xFFFD,
	0x13F3: 0xFFFD,
	0x13F4: 0xFFFD,
	0x13F5: 0xFFFD,
	0x13F6: 0xFFFD,
	0x13F7: 0xFFFD,
	0x13F8: 0xFFFD,
	0x13F9: 0xFFFD,
	0x13FA: 0xFFFD,
	0x13FB: 0xFFFD,
	0x13FC: 0xFFFD,
	0x13FD: 0xFFFD,
	0x13FE: 0xFFFD,
	0x13FF: 0xFFFD,
	0x1400: 0xFFFD,
	0x1401: 0xFFFD,
	0x1402: 0xFFFD,
	0x1403: 0xFFFD,
	0x1404: 0xFFFD,
	0x1405: 0xFFFD,
	0x1406: 0xFFFD,
	0x1407: 0xFFFD,
	0x1408: 0xFFFD,
	0x1409: 0xFFFD,
	0x140A: 0xFFFD,
	0x140B: 0xFFFD,
	0x140C: 0xFFFD,
	0x140D: 0xFFFD,
	0x140E: 0xFFFD,
	0x140F: 0xFFFD,
	0x1410: 0xFFFD,
	0x1411: 0xFFFD,
	0x1412: 0xFFFD,
	0x1413: 0xFFFD,
	0x1414: 0xFFFD,
	0x1415: 0xFFFD,
	0x1416: 0xFFFD,
	0x1417: 0xFFFD,
	0x1418: 0xFFFD,
	0x1419: 0xFFFD,
	0x141A: 0xFFFD,
	0x141B: 0xFFFD,
	0x141C: 0xFFFD,
	0x141D: 0xFFFD,
	0x141E: 0xFFFD,
	0x141F: 0xFFFD,
	0x1420: 0xFFFD,
	0x1421: 0xFFFD,
	0x1422: 0xFFFD,
	0x1423: 0xFFFD,
	0x1424: 0xFFFD,
	0x1425: 0xFFFD,
	0x1426: 0xFFFD,
	0x1427: 0xFFFD,
	0x1428: 0xFFFD,
	0x1429: 0xFFFD,
	0x142A: 0xFFFD,
	0x142B: 0xFFFD,
	0x142C: 0xFFFD,
	0x142D: 0xFFFD,
	0x142E: 0xFFFD,
	0x142F: 0xFFFD,
	0x1430: 0xFFFD,
	0x1431: 0xFFFD,
	0x1432: 0xFFFD,
	0x1433: 0xFFFD,
	0x1434: 0xFFFD,
	0x1435: 0xFFFD,
	0x1436: 0xFFFD,
	0x1437: 0xFFFD,
	0x1438: 0xFFFD,
	0x1439: 0xFFFD,
	0x143A: 0xFFFD,
	0x143B: 0xFFFD,
	0x143C: 0xFFFD,
	0x143D: 0xFFFD,
	0x143E: 0xFFFD,
	0x143F: 0xFFFD,
	0x1440: 0xFFFD,
	0x1441: 0xFFFD,
	0x1442: 0xFFFD,
	0x1443: 0xFFFD,
	0x1444: 0xFFFD,
	0x1445: 0xFFFD,
	0x1446: 0xFFFD,
	0x1447: 0xFFFD,
	0x1448: 0xFFFD,
	0x1449: 0xFFFD,
	0x144A: 0xFFFD,
	0x144B: 0xFFFD,
	0x144C: 0xFFFD,
	0x144D: 0xFFFD,
	0x144E: 0xFFFD,
	0x144F: 0xFFFD,
	0x1450: 0xFFFD,
	0x1451: 0xFFFD,
	0x1452: 0xFFFD,
	0x1453: 0xFFFD,
	0x1454: 0xFFFD,
	0x1455: 0xFFFD,
	0x1456: 0xFFFD,
	0x1457: 0xFFFD,
	0x1458: 0xFFFD,
	0x1459: 0xFFFD,
	0x145A: 0xFFFD,
	0x145B: 0xFFFD,
	0x145C: 0xFFFD,
	0x145D: 0xFFFD,
	0x145E: 0xFFFD,
	0x145F: 0xFFFD,
	0x1460: 0xFFFD,
	0x1461: 0xFFFD,
	0x1462: 0xFFFD,
	0x1463: 0xFFFD,
	0x1464: 0xFFFD,
	0x1465: 0xFFFD,
	0x1466: 0xFFFD,
	0x1467: 0xFFFD,
	0x1468: 0xFFFD,
	0x1469: 0xFFFD,
	0x146A: 0xFFFD,
	0x146B: 0xFFFD,
	0x146C: 0xFFFD,
	0x146D: 0xFFFD,
	0x146E: 0xFFFD,
	0x146F: 0xFFFD,
	0x1470: 0xFFFD,
	0x1471: 0xFFFD,
	0x1472: 0xFFFD,
	0x1473: 0xFFFD,
	0x1474: 0xFFFD,
	0x1475: 0xFFFD,
	0x1476: 0xFFFD,
	0x1477: 0xFFFD,
	0x1478: 0xFFFD,
	0x1479: 0xFFFD,
	0x147A: 0xFFFD,
	0x147B: 0xFFFD,
	0x147C: 0xFFFD,
	0x147D: 0xFFFD,
	0x147E: 0xFFFD,
	0x147F: 0xFFFD,
	0x1480: 0xFFFD,
	0x1481: 0xFFFD,
	0x1482: 0xFFFD,
	0x1483: 0xFFFD,
	0x1484: 0xFFFD,
	0x1485: 0xFFFD,
	0x1486: 0xFFFD,
	0x1487: 0xFFFD,
	0x1488: 0xFFFD,
	0x1489: 0xFFFD,
	0x148A: 0xFFFD,
	0x148B: 0xFFFD,
	0x148C: 0xFFFD,
	0x148D: 0xFFFD,
	0x148E: 0xFFFD,
	0x148F: 0xFFFD,
	0x1490: 0xFFFD,
	0x1491: 0xFFFD,
	0x1492: 0xFFFD,
	0x1493: 0xFFFD,
	0x1494: 0xFFFD,
	0x1495: 0xFFFD,
	0x1496: 0xFFFD,
	0x1497: 0xFFFD,
	0x1498: 0xFFFD,
	0x1499: 0xFFFD,
	0x149A: 0xFFFD,
	0x149B: 0xFFFD,
	0x149C: 0xFFFD,
	0x149D: 0xFFFD,
	0x149E: 0xFFFD,
	0x149F: 0xFFFD,
	0x14A0: 0xFFFD,
	0x14A1: 0xFFFD,
	0x14A2: 0xFFFD,
	0x14A3: 0xFFFD,
	0x14A4: 0xFFFD,
	0x14A5: 0xFFFD,
	0x14A6: 0xFFFD,
	0x14A7: 0xFFFD,
	0x14A8: 0xFFFD,
	0x14A9: 0xFFFD,
	0x14AA: 0xFFFD,
	0x14AB: 0xFFFD,
	0x14AC: 0xFFFD,
	0x14AD: 0xFFFD,
	0x14AE: 0xFFFD,
	0x14AF: 0xFFFD,
	0x14B0: 0xFFFD,
	0x14B1: 0xFFFD,
	0x14B2: 0xFFFD,
	0x14B3: 0xFFFD,
	0x14B4: 0xFFFD,
	0x14B5: 0xFFFD,
	0x14B6: 0xFFFD,
	0x14B7: 0xFFFD,
	0x14B8: 0xFFFD,
	0x14B9: 0xFFFD,
	0x14BA: 0xFFFD,
	0x14BB: 0xFFFD,
	0x14BC: 0xFFFD,
	0x14BD: 0xFFFD,
	0x14BE: 0xFFFD,
	0x14BF: 0xFFFD,
	0x14C0: 0xFFFD,
	0x14C1: 0xFFFD,
	0x14C2: 0xFFFD,
	0x14C3: 0xFFFD,
	0x14C4: 0xFFFD,
	0x14C5: 0xFFFD,
	0x14C6: 0xFFFD,
	0x14C7: 0xFFFD,
	0x14C8: 0xFFFD,
	0x14C9: 0xFFFD,
	0x14CA: 0xFFFD,
	0x14CB: 0xFFFD,
	0x14CC: 0xFFFD,
	0x14CD: 0xFFFD,
	0x14CE: 0xFFFD,
	0x14CF: 0xFFFD,
	0x14D0: 0xFFFD,
	0x14D1: 0xFFFD,
	0x14D2: 0xFFFD,
	0x14D3: 0xFFFD,
	0x14D4: 0xFFFD,
	0x14D5: 0xFFFD,
	0x14D6: 0xFFFD,
	0x14D7: 0xFFFD,
	0x14D8: 0xFFFD,
	0x14D9: 0xFFFD,
	0x14DA: 0xFFFD,
	0x14DB: 0xFFFD,
	0x14DC: 0xFFFD,
	0x14DD: 0xFFFD,
	0x14DE: 0xFFFD,
	0x14DF: 0xFFFD,
	0x14E0: 0xFFFD,
	0x14E1: 0xFFFD,
	0x14E2: 0xFFFD,
	0x14E3: 0xFFFD,
	0x14E4: 0xFFFD,
	0x14E5: 0xFFFD,
	0x14E6: 0xFFFD,
	0x14E7: 0xFFFD,
	0x14E8: 0xFFFD,
	0x14E9: 0xFFFD,
	0x14EA: 0xFFFD,
	0x14EB: 0xFFFD,
	0x14EC: 0xFFFD,
	0x14ED: 0xFFFD,
	0x14EE: 0xFFFD,
	0x14EF: 0xFFFD,
	0x14F0: 0xFFFD,
	0x14F1: 0xFFFD,
	0x14F2: 0xFFFD,
	0x14F3: 0xFFFD,
	0x14F4: 0xFFFD,
	0x14F5: 0xFFFD,
	0x14F6: 0xFFFD,
	0x14F7: 0xFFFD,
	0x14F8: 0xFFFD,
	0x14F9: 0xFFFD,
	0x14FA: 0xFFFD,
	0x14FB: 0xFFFD,
	0x14FC: 0xFFFD,
	0x14FD: 0xFFFD,
	0x14FE: 0xFFFD,
	0x14FF: 0xFFFD,
	0x1500: 0xFFFD,
	0x1501: 0xFFFD,
	0x1502: 0xFFFD,
	0x1503: 0xFFFD,
	0x1504: 0xFFFD,
	0x1505: 0xFFFD,
	0x1506: 0xFFFD,
	0x1507: 0xFFFD,
	0x1508: 0xFFFD,
	0x1509: 0xFFFD,
	0x150A: 0xFFFD,
	0x150B: 0xFFFD,
	0x150C: 0xFFFD,
	0x150D: 0xFFFD,
	0x150E: 0xFFFD,
	0x150F: 0xFFFD,
	0x1510: 0xFFFD,
	0x1511: 0xFFFD,
	0x1512: 0xFFFD,
	0x1513: 0xFFFD,
	0x1514: 0xFFFD,
	0x1515: 0xFFFD,
	0x1516: 0xFFFD,
	0x1517: 0xFFFD,
	0x1518: 0xFFFD,
	0x1519: 0xFFFD,
	0x151A: 0xFFFD,
	0x151B: 0xFFFD,
	0x151C: 0xFFFD,
	0x151D: 0xFFFD,
	0x151E: 0xFFFD,
	0x151F: 0xFFFD,
	0x1520: 0xFFFD,
	0x1521: 0xFFFD,
	0x1522: 0xFFFD,
	0x1523: 0xFFFD,
	0x1524: 0xFFFD,
	0x1525: 0xFFFD,
	0x1526: 0xFFFD,
	0x1527: 0xFFFD,
	0x1528: 0xFFFD,
	0x1529: 0xFFFD,
	0x152A: 0xFFFD,
	0x152B: 0xFFFD,
	0x152C: 0xFFFD,
	0x152D: 0xFFFD,
	0x152E: 0xFFFD,
	0x152F: 0xFFFD,
	0x1530: 0xFFFD,
	0x1531: 0xFFFD,
	0x1532: 0xFFFD,
	0x1533: 0xFFFD,
	0x1534: 0xFFFD,
	0x1535: 0xFFFD,
	0x1536: 0xFFFD,
	0x1537: 0xFFFD,
	0x1538: 0xFFFD,
	0x1539: 0xFFFD,
	0x153A: 0xFFFD,
	0x153B: 0xFFFD,
	0x153C: 0xFFFD,
	0x153D: 0xFFFD,
	0x153E: 0xFFFD,
	0x153F: 0xFFFD,
	0x1540: 0xFFFD,
	0x1541: 0xFFFD,
	0x1542: 0xFFFD,
	0x1543: 0xFFFD,
	0x1544: 0xFFFD,
	0x1545: 0xFFFD,
	0x1546: 0xFFFD,
	0x1547: 0xFFFD,
	0x1548: 0xFFFD,
	0x1549: 0xFFFD,
	0x154A: 0xFFFD,
	0x154B: 0xFFFD,
	0x154C: 0xFFFD,
	0x154D: 0xFFFD,
	0x154E: 0xFFFD,
	0x154F: 0xFFFD,
	0x1550: 0xFFFD,
	0x1551: 0xFFFD,
	0x1552: 0xFFFD,
	0x1553: 0xFFFD,
	0x1554: 0xFFFD,
	0x1555: 0xFFFD,
	0x1556: 0xFFFD,
	0x1557: 0xFFFD,
	0x1558: 0xFFFD,
	0x1559: 0xFFFD,
	0x155A: 0xFFFD,
	0x155B: 0xFFFD,
	0x155C: 0xFFFD,
	0x155D: 0xFFFD,
	0x155E: 0xFFFD,
	0x155F: 0xFFFD,
	0x1560: 0xFFFD,
	0x1561: 0xFFFD,
	0x1562: 0xFFFD,
	0x1563: 0xFFFD,
	0x1564: 0xFFFD,
	0x1565: 0xFFFD,
	0x1566: 0xFFFD,
	0x1567: 0xFFFD,
	0x1568: 0xFFFD,
	0x1569: 0xFFFD,
	0x156A: 0xFFFD,
	0x156B: 0xFFFD,
	0x156C: 0xFFFD,
	0x156D: 0xFFFD,
	0x156E: 0xFFFD,
	0x156F: 0xFFFD,
	0x1570: 0xFFFD,
	0x1571: 0xFFFD,
	0x1572: 0xFFFD,
	0x1573: 0xFFFD,
	0x1574: 0xFFFD,
	0x1575: 0xFFFD,
	0x1576: 0xFFFD,
	0x1577: 0xFFFD,
	0x1578: 0xFFFD,
	0x1579: 0xFFFD,
	0x157A: 0xFFFD,
	0x157B: 0xFFFD,
	0x157C: 0xFFFD,
	0x157D: 0xFFFD,
	0x157E: 0xFFFD,
	0x157F: 0xFFFD,
	0x1580: 0xFFFD,
	0x1581: 0xFFFD,
	0x1582: 0xFFFD,
	0x1583: 0xFFFD,
	0x1584: 0xFFFD,
	0x1585: 0xFFFD,
	0x1586: 0xFFFD,
	0x1587: 0xFFFD,
	0x1588: 0xFFFD,
	0x1589: 0xFFFD,
	0x158A: 0xFFFD,
	0x158B: 0xFFFD,
	0x158C: 0xFFFD,
	0x158D: 0xFFFD,
	0x158E: 0xFFFD,
	0x158F: 0xFFFD,
	0x1590: 0xFFFD,
	0x1591: 0xFFFD,
	0x1592: 0xFFFD,
	0x1593: 0xFFFD,
	0x1594: 0xFFFD,
	0x1595: 0xFFFD,
	0x1596: 0xFFFD,
	0x1597: 0xFFFD,
	0x1598: 0xFFFD,
	0x1599: 0xFFFD,
	0x159A: 0xFFFD,
	0x159B: 0xFFFD,
	0x159C: 0xFFFD,
	0x159D: 0xFFFD,
	0x159E: 0xFFFD,
	0x159F: 0xFFFD,
	0x15A0: 0xFFFD,
	0x15A1: 0xFFFD,
	0x15A2: 0xFFFD,
	0x15A3: 0xFFFD,
	0x15A4: 0xFFFD,
	0x15A5: 0xFFFD,
	0x15A6: 0xFFFD,
	0x15A7: 0xFFFD,
	0x15A8: 0xFFFD,
	0x15A9: 0xFFFD,
	0x15AA: 0xFFFD,
	0x15AB: 0xFFFD,
	0x15AC: 0xFFFD,
	0x15AD: 0xFFFD,
	0x15AE: 0xFFFD,
	0x15AF: 0xFFFD,
	0x15B0: 0xFFFD,
	0x15B1: 0xFFFD,
	0x15B2: 0xFFFD,
	0x15B3: 0xFFFD,
	0x15B4: 0xFFFD,
	0x15B5: 0xFFFD,
	0x15B6: 0xFFFD,
	0x15B7: 0xFFFD,
	0x15B8: 0xFFFD,
	0x15B9: 0xFFFD,
	0x15BA: 0xFFFD,
	0x15BB: 0xFFFD,
	0x15BC: 0xFFFD,
	0x15BD: 0xFFFD,
	0x15BE: 0xFFFD,
	0x15BF: 0xFFFD,
	0x15C0: 0xFFFD,
	0x15C1: 0xFFFD,
	0x15C2: 0xFFFD,
	0x15C3: 0xFFFD,
	0x15C4: 0xFFFD,
	0x15C5: 0xFFFD,
	0x15C6: 0xFFFD,
	0x15C7: 0xFFFD,
	0x15C8: 0xFFFD,
	0x15C9: 0xFFFD,
	0x15CA: 0xFFFD,
	0x15CB: 0xFFFD,
	0x15CC: 0xFFFD,
	0x15CD: 0xFFFD,
	0x15CE: 0xFFFD,
	0x15CF: 0xFFFD,
	0x15D0: 0xFFFD,
	0x15D1: 0xFFFD,
	0x15D2: 0xFFFD,
	0x15D3: 0xFFFD,
	0x15D4: 0xFFFD,
	0x15D5: 0xFFFD,
	0x15D6: 0xFFFD,
	0x15D7: 0xFFFD,
	0x15D8: 0xFFFD,
	0x15D9: 0xFFFD,
	0x15DA: 0xFFFD,
	0x15DB: 0xFFFD,
	0x15DC: 0xFFFD,
	0x15DD: 0xFFFD,
	0x15DE: 0xFFFD,
	0x15DF: 0xFFFD,
	0x15E0: 0xFFFD,
	0x15E1: 0xFFFD,
	0x15E2: 0xFFFD,
	0x15E3: 0xFFFD,
	0x15E4: 0xFFFD,
	0x15E5: 0xFFFD,
	0x15E6: 0xFFFD,
	0x15E7: 0xFFFD,
	0x15E8: 0xFFFD,
	0x15E9: 0xFFFD,
	0x15EA: 0xFFFD,
	0x15EB: 0xFFFD,
	0x15EC: 0xFFFD,
	0x15ED: 0xFFFD,
	0x15EE: 0xFFFD,
	0x15EF: 0xFFFD,
	0x15F0: 0xFFFD,
	0x15F1: 0xFFFD,
	0x15F2: 0xFFFD,
	0x15F3: 0xFFFD,
	0x15F4: 0xFFFD,
	0x15F5: 0xFFFD,
	0x15F6: 0xFFFD,
	0x15F7: 0xFFFD,
	0x15F8: 0xFFFD,
	0x15F9: 0xFFFD,
	0x15FA: 0xFFFD,
	0x15FB: 0xFFFD,
	0x15FC: 0xFFFD,
	0x15FD: 0xFFFD,
	0x15FE: 0xFFFD,
	0x15FF: 0xFFFD,
	0x1600: 0xFFFD,
	0x1601: 0xFFFD,
	0x1602: 0xFFFD,
	0x1603: 0xFFFD,
	0x1604: 0xFFFD,
	0x1605: 0xFFFD,
	0x1606: 0xFFFD,
	0x1607: 0xFFFD,
	0x1608: 0xFFFD,
	0x1609: 0xFFFD,
	0x160A: 0xFFFD,
	0x160B: 0xFFFD,
	0x160C: 0xFFFD,
	0x160D: 0xFFFD,
	0x160E: 0xFFFD,
	0x160F: 0xFFFD,
	0x1610: 0xFFFD,
	0x1611: 0xFFFD,
	0x1612: 0xFFFD,
	0x1613: 0xFFFD,
	0x1614: 0xFFFD,
	0x1615: 0xFFFD,
	0x1616: 0xFFFD,
	0x1617: 0xFFFD,
	0x1618: 0xFFFD,
	0x1619: 0xFFFD,
	0x161A: 0xFFFD,
	0x161B: 0xFFFD,
	0x161C: 0xFFFD,
	0x161D: 0xFFFD,
	0x161E: 0xFFFD,
	0x161F: 0xFFFD,
	0x1620: 0xFFFD,
	0x1621: 0xFFFD,
	0x1622: 0xFFFD,
	0x1623: 0xFFFD,
	0x1624: 0xFFFD,
	0x1625: 0xFFFD,
	0x1626: 0xFFFD,
	0x1627: 0xFFFD,
	0x1628: 0xFFFD,
	0x1629: 0xFFFD,
	0x162A: 0xFFFD,
	0x162B: 0xFFFD,
	0x162C: 0xFFFD,
	0x162D: 0xFFFD,
	0x162E: 0xFFFD,
	0x162F: 0xFFFD,
	0x1630: 0xFFFD,
	0x1631: 0xFFFD,
	0x1632: 0xFFFD,
	0x1633: 0xFFFD,
	0x1634: 0xFFFD,
	0x1635: 0xFFFD,
	0x1636: 0xFFFD,
	0x1637: 0xFFFD,
	0x1638: 0xFFFD,
	0x1639: 0xFFFD,
	0x163A: 0xFFFD,
	0x163B: 0xFFFD,
	0x163C: 0xFFFD,
	0x163D: 0xFFFD,
	0x163E: 0xFFFD,
	0x163F: 0xFFFD,
	0x1640: 0xFFFD,
	0x1641: 0xFFFD,
	0x1642: 0xFFFD,
	0x1643: 0xFFFD,
	0x1644: 0xFFFD,
	0x1645: 0xFFFD,
	0x1646: 0xFFFD,
	0x1647: 0xFFFD,
	0x1648: 0xFFFD,
	0x1649: 0xFFFD,
	0x164A: 0xFFFD,
	0x164B: 0xFFFD,
	0x164C: 0xFFFD,
	0x164D: 0xFFFD,
	0x164E: 0xFFFD,
	0x164F: 0xFFFD,
	0x1650: 0xFFFD,
	0x1651: 0xFFFD,
	0x1652: 0xFFFD,
	0x1653: 0xFFFD,
	0x1654: 0xFFFD,
	0x1655: 0xFFFD,
	0x1656: 0xFFFD,
	0x1657: 0xFFFD,
	0x1658: 0xFFFD,
	0x1659: 0xFFFD,
	0x165A: 0xFFFD,
	0x165B: 0xFFFD,
	0x165C: 0xFFFD,
	0x165D: 0xFFFD,
	0x165E: 0xFFFD,
	0x165F: 0xFFFD,
	0x1660: 0xFFFD,
	0x1661: 0xFFFD,
	0x1662: 0xFFFD,
	0x1663: 0xFFFD,
	0x1664: 0xFFFD,
	0x1665: 0xFFFD,
	0x1666: 0xFFFD,
	0x1667: 0xFFFD,
	0x1668: 0xFFFD,
	0x1669: 0xFFFD,
	0x166A: 0xFFFD,
	0x166B: 0xFFFD,
	0x166C: 0xFFFD,
	0x166D: 0xFFFD,
	0x166E: 0xFFFD,
	0x166F: 0xFFFD,
	0x1670: 0xFFFD,
	0x1671: 0xFFFD,
	0x1672: 0xFFFD,
	0x1673: 0xFFFD,
	0x1674: 0xFFFD,
	0x1675: 0xFFFD,
	0x1676: 0xFFFD,
	0x1677: 0xFFFD,
	0x1678: 0xFFFD,
	0x1679: 0xFFFD,
	0x167A: 0xFFFD,
	0x167B: 0xFFFD,
	0x167C: 0xFFFD,
	0x167D: 0xFFFD,
	0x167E: 0xFFFD,
	0x167F: 0xFFFD,
	0x1680: 0xFFFD,
	0x1681: 0xFFFD,
	0x1682: 0xFFFD,
	0x1683: 0xFFFD,
	0x1684: 0xFFFD,
	0x1685: 0xFFFD,
	0x1686: 0xFFFD,
	0x1687: 0xFFFD,
	0x1688: 0xFFFD,
	0x1689: 0xFFFD,
	0x168A: 0xFFFD,
	0x168B: 0xFFFD,
	0x168C: 0xFFFD,
	0x168D: 0xFFFD,
	0x168E: 0xFFFD,
	0x168F: 0xFFFD,
	0x1690: 0xFFFD,
	0x1691: 0xFFFD,
	0x1692: 0xFFFD,
	0x1693: 0xFFFD,
	0x1694: 0xFFFD,
	0x1695: 0xFFFD,
	0x1696: 0xFFFD,
	0x1697: 0xFFFD,
	0x1698: 0xFFFD,
	0x1699: 0xFFFD,
	0x169A: 0xFFFD,
	0x169B: 0xFFFD,
	0x169C: 0xFFFD,
	0x169D: 0xFFFD,
	0x169E: 0xFFFD,
	0x169F: 0xFFFD,
	0x16A0: 0xFFFD,
	0x16A1: 0xFFFD,
	0x16A2: 0xFFFD,
	0x16A3: 0xFFFD,
	0x16A4: 0xFFFD,
	0x16A5: 0xFFFD,
	0x16A6: 0xFFFD,
	0x16A7: 0xFFFD,
	0x16A8: 0xFFFD,
	0x16A9: 0xFFFD,
	0x16AA: 0xFFFD,
	0x16AB: 0xFFFD,
	0x16AC: 0xFFFD,
	0x16AD: 0xFFFD,
	0x16AE: 0xFFFD,
	0x16AF: 0xFFFD,
	0x16B0: 0xFFFD,
	0x16B1: 0xFFFD,
	0x16B2: 0xFFFD,
	0x16B3: 0xFFFD,
	0x16B4: 0xFFFD,
	0x16B5: 0xFFFD,
	0x16B6: 0xFFFD,
	0x16B7: 0xFFFD,
	0x16B8: 0xFFFD,
	0x16B9: 0xFFFD,
	0x16BA: 0xFFFD,
	0x16BB: 0xFFFD,
	0x16BC: 0xFFFD,
	0x16BD: 0xFFFD,
	0x16BE: 0xFFFD,
	0x16BF: 0xFFFD,
	0x16C0: 0xFFFD,
	0x16C1: 0xFFFD,
	0x16C2: 0xFFFD,
	0x16C3: 0xFFFD,
	0x16C4: 0xFFFD,
	0x16C5: 0xFFFD,
	0x16C6: 0xFFFD,
	0x16C7: 0xFFFD,
	0x16C8: 0xFFFD,
	0x16C9: 0xFFFD,
	0x16CA: 0xFFFD,
	0x16CB: 0xFFFD,
	0x16CC: 0xFFFD,
	0x16CD: 0xFFFD,
	0x16CE: 0xFFFD,
	0x16CF: 0xFFFD,
	0x16D0: 0xFFFD,
	0x16D1: 0xFFFD,
	0x16D2: 0xFFFD,
	0x16D3: 0xFFFD,
	0x16D4: 0xFFFD,
	0x16D5: 0xFFFD,
	0x16D6: 0xFFFD,
	0x16D7: 0xFFFD,
	0x16D8: 0xFFFD,
	0x16D9: 0xFFFD,
	0x16DA: 0xFFFD,
	0x16DB: 0xFFFD,
	0x16DC: 0xFFFD,
	0x16DD: 0xFFFD,
	0x16DE: 0xFFFD,
	0x16DF: 0xFFFD,
	0x16E0: 0xFFFD,
	0x16E1: 0xFFFD,
	0x16E2: 0xFFFD,
	0x16E3: 0xFFFD,
	0x16E4: 0xFFFD,
	0x16E5: 0xFFFD,
	0x16E6: 0xFFFD,
	0x16E7: 0xFFFD,
	0x16E8: 0xFFFD,
	0x16E9: 0xFFFD,
	0x16EA: 0xFFFD,
	0x16EB: 0xFFFD,
	0x16EC: 0xFFFD,
	0x16ED: 0xFFFD,
	0x16EE: 0xFFFD,
	0x16EF: 0xFFFD,
	0x16F0: 0xFFFD,
	0x16F1: 0xFFFD,
	0x16F2: 0xFFFD,
	0x16F3: 0xFFFD,
	0x16F4: 0xFFFD,
	0x16F5: 0xFFFD,
	0x16F6: 0xFFFD,
	0x16F7: 0xFFFD,
	0x16F8: 0xFFFD,
	0x16F9: 0xFFFD,
	0x16FA: 0xFFFD,
	0x16FB: 0xFFFD,
	0x16FC: 0xFFFD,
	0x16FD: 0xFFFD,
	0x16FE: 0xFFFD,
	0x16FF: 0xFFFD,
	0x1700: 0xFFFD,
	0x1701: 0xFFFD,
	0x1702: 0xFFFD,
	0x1703: 0xFFFD,
	0x1704: 0xFFFD,
	0x1705: 0xFFFD,
	0x1706: 0xFFFD,
	0x1707: 0xFFFD,
	0x1708: 0xFFFD,
	0x1709: 0xFFFD,
	0x170A: 0xFFFD,
	0x170B: 0xFFFD,
	0x170C: 0xFFFD,
	0x170D: 0xFFFD,
	0x170E: 0xFFFD,
	0x170F: 0xFFFD,
	0x1710: 0xFFFD,
	0x1711: 0xFFFD,
	0x1712: 0xFFFD,
	0x1713: 0xFFFD,
	0x1714: 0xFFFD,
	0x1715: 0xFFFD,
	0x1716: 0xFFFD,
	0x1717: 0xFFFD,
	0x1718: 0xFFFD,
	0x1719: 0xFFFD,
	0x171A: 0xFFFD,
	0x171B: 0xFFFD,
	0x171C: 0xFFFD,
	0x171D: 0xFFFD,
	0x171E: 0xFFFD,
	0x171F: 0xFFFD,
	0x1720: 0xFFFD,
	0x1721: 0xFFFD,
	0x1722: 0xFFFD,
	0x1723: 0xFFFD,
	0x1724: 0xFFFD,
	0x1725: 0xFFFD,
	0x1726: 0xFFFD,
	0x1727: 0xFFFD,
	0x1728: 0xFFFD,
	0x1729: 0xFFFD,
	0x172A: 0xFFFD,
	0x172B: 0xFFFD,
	0x172C: 0xFFFD,
	0x172D: 0xFFFD,
	0x172E: 0xFFFD,
	0x172F: 0xFFFD,
	0x1730: 0xFFFD,
	0x1731: 0xFFFD,
	0x1732: 0xFFFD,
	0x1733: 0xFFFD,
	0x1734: 0xFFFD,
	0x1735: 0xFFFD,
	0x1736: 0xFFFD,
	0x1737: 0xFFFD,
	0x1738: 0xFFFD,
	0x1739: 0xFFFD,
	0x173A: 0xFFFD,
	0x173B: 0xFFFD,
	0x173C: 0xFFFD,
	0x173D: 0xFFFD,
	0x173E: 0xFFFD,
	0x173F: 0xFFFD,
	0x1740: 0xFFFD,
	0x1741: 0xFFFD,
	0x1742: 0xFFFD,
	0x1743: 0xFFFD,
	0x1744: 0xFFFD,
	0x1745: 0xFFFD,
	0x1746: 0xFFFD,
	0x1747: 0xFFFD,
	0x1748: 0xFFFD,
	0x1749: 0xFFFD,
	0x174A: 0xFFFD,
	0x174B: 0xFFFD,
	0x174C: 0xFFFD,
	0x174D: 0xFFFD,
	0x174E: 0xFFFD,
	0x174F: 0xFFFD,
	0x1750: 0xFFFD,
	0x1751: 0xFFFD,
	0x1752: 0xFFFD,
	0x1753: 0xFFFD,
	0x1754: 0xFFFD,
	0x1755: 0xFFFD,
	0x1756: 0xFFFD,
	0x1757: 0xFFFD,
	0x1758: 0xFFFD,
	0x1759: 0xFFFD,
	0x175A: 0xFFFD,
	0x175B: 0xFFFD,
	0x175C: 0xFFFD,
	0x175D: 0xFFFD,
	0x175E: 0xFFFD,
	0x175F: 0xFFFD,
	0x1760: 0xFFFD,
	0x1761: 0xFFFD,
	0x1762: 0xFFFD,
	0x1763: 0xFFFD,
	0x1764: 0xFFFD,
	0x1765: 0xFFFD,
	0x1766: 0xFFFD,
	0x1767: 0xFFFD,
	0x1768: 0xFFFD,
	0x1769: 0xFFFD,
	0x176A: 0xFFFD,
	0x176B: 0xFFFD,
	0x176C: 0xFFFD,
	0x176D: 0xFFFD,
	0x176E: 0xFFFD,
	0x176F: 0xFFFD,
	0x1770: 0xFFFD,
	0x1771: 0xFFFD,
	0x1772: 0xFFFD,
	0x1773: 0xFFFD,
	0x1774: 0xFFFD,
	0x1775: 0xFFFD,
	0x1776: 0xFFFD,
	0x1777: 0xFFFD,
	0x1778: 0xFFFD,
	0x1779: 0xFFFD,
	0x177A: 0xFFFD,
	0x177B: 0xFFFD,
	0x177C: 0xFFFD,
	0x177D: 0xFFFD,
	0x177E: 0xFFFD,
	0x177F: 0xFFFD,
	0x1780: 0xFFFD,
	0x1781: 0xFFFD,
	0x1782: 0xFFFD,
	0x1783: 0xFFFD,
	0x1784: 0xFFFD,
	0x1785: 0xFFFD,
	0x1786: 0xFFFD,
	0x1787: 0xFFFD,
	0x1788: 0xFFFD,
	0x1789: 0xFFFD,
	0x178A: 0xFFFD,
	0x178B: 0xFFFD,
	0x178C: 0xFFFD,
	0x178D: 0xFFFD,
	0x178E: 0xFFFD,
	0x178F: 0xFFFD,
	0x1790: 0xFFFD,
	0x1791: 0xFFFD,
	0x1792: 0xFFFD,
	0x1793: 0xFFFD,
	0x1794: 0xFFFD,
	0x1795: 0xFFFD,
	0x1796: 0xFFFD,
	0x1797: 0xFFFD,
	0x1798: 0xFFFD,
	0x1799: 0xFFFD,
	0x179A: 0xFFFD,
	0x179B: 0xFFFD,
	0x179C: 0xFFFD,
	0x179D: 0xFFFD,
	0x179E: 0xFFFD,
	0x179F: 0xFFFD,
	0x17A0: 0xFFFD,
	0x17A1: 0xFFFD,
	0x17A2: 0xFFFD,
	0x17A3: 0xFFFD,
	0x17A4: 0xFFFD,
	0x17A5: 0xFFFD,
	0x17A6: 0xFFFD,
	0x17A7: 0xFFFD,
	0x17A8: 0xFFFD,
	0x17A9: 0xFFFD,
	0x17AA: 0xFFFD,
	0x17AB: 0xFFFD,
	0x17AC: 0xFFFD,
	0x17AD: 0xFFFD,
	0x17AE: 0xFFFD,
	0x17AF: 0xFFFD,
	0x17B0: 0xFFFD,
	0x17B1: 0xFFFD,
	0x17B2: 0xFFFD,
	0x17B3: 0xFFFD,
	0x17B4: 0xFFFD,
	0x17B5: 0xFFFD,
	0x17B6: 0xFFFD,
	0x17B7: 0xFFFD,
	0x17B8: 0xFFFD,
	0x17B9: 0xFFFD,
	0x17BA: 0xFFFD,
	0x17BB: 0xFFFD,
	0x17BC: 0xFFFD,
	0x17BD: 0xFFFD,
	0x17BE: 0xFFFD,
	0x17BF: 0xFFFD,
	0x17C0: 0xFFFD,
	0x17C1: 0xFFFD,
	0x17C2: 0xFFFD,
	0x17C3: 0xFFFD,
	0x17C4: 0xFFFD,
	0x17C5: 0xFFFD,
	0x17C6: 0xFFFD,
	0x17C7: 0xFFFD,
	0x17C8: 0xFFFD,
	0x17C9: 0xFFFD,
	0x17CA: 0xFFFD,
	0x17CB: 0xFFFD,
	0x17CC: 0xFFFD,
	0x17CD: 0xFFFD,
	0x17CE: 0xFFFD,
	0x17CF: 0xFFFD,
	0x17D0: 0xFFFD,
	0x17D1: 0xFFFD,
	0x17D2: 0xFFFD,
	0x17D3: 0xFFFD,
	0x17D4: 0xFFFD,
	0x17D5: 0xFFFD,
	0x17D6: 0xFFFD,
	0x17D7: 0xFFFD,
	0x17D8: 0xFFFD,
	0x17D9: 0xFFFD,
	0x17DA: 0xFFFD,
	0x17DB: 0xFFFD,
	0x17DC: 0xFFFD,
	0x17DD: 0xFFFD,
	0x17DE: 0xFFFD,
	0x17DF: 0xFFFD,
	0x17E0: 0xFFFD,
	0x17E1: 0xFFFD,
	0x17E2: 0xFFFD,
	0x17E3: 0xFFFD,
	0x17E4: 0xFFFD,
	0x17E5: 0xFFFD,
	0x17E6: 0xFFFD,
	0x17E7: 0xFFFD,
	0x17E8: 0xFFFD,
	0x17E9: 0xFFFD,
	0x17EA: 0xFFFD,
	0x17EB: 0xFFFD,
	0x17EC: 0xFFFD,
	0x17ED: 0xFFFD,
	0x17EE: 0xFFFD,
	0x17EF: 0xFFFD,
	0x17F0: 0xFFFD,
	0x17F1: 0xFFFD,
	0x17F2: 0xFFFD,
	0x17F3: 0xFFFD,
	0x17F4: 0xFFFD,
	0x17F5: 0xFFFD,
	0x17F6: 0xFFFD,
	0x17F7: 0xFFFD,
	0x17F8: 0xFFFD,
	0x17F9: 0xFFFD,
	0x17FA: 0xFFFD,
	0x17FB: 0xFFFD,
	0x17FC: 0xFFFD,
	0x17FD: 0xFFFD,
	0x17FE: 0xFFFD,
	0x17FF: 0xFFFD,
	0x1800: 0xFFFD,
	0x1801: 0xFFFD,
	0x1802: 0xFFFD,
	0x1803: 0xFFFD,
	0x1804: 0xFFFD,
	0x1805: 0xFFFD,
	0x1806: 0xFFFD,
	0x1807: 0xFFFD,
	0x1808: 0xFFFD,
	0x1809: 0xFFFD,
	0x180A: 0xFFFD,
	0x180B: 0xFFFD,
	0x180C: 0xFFFD,
	0x180D: 0xFFFD,
	0x180E: 0xFFFD,
	0x180F: 0xFFFD,
	0x1810: 0xFFFD,
	0x1811: 0xFFFD,
	0x1812: 0xFFFD,
	0x1813: 0xFFFD,
	0x1814: 0xFFFD,
	0x1815: 0xFFFD,
	0x1816: 0xFFFD,
	0x1817: 0xFFFD,
	0x1818: 0xFFFD,
	0x1819: 0xFFFD,
	0x181A: 0xFFFD,
	0x181B: 0xFFFD,
	0x181C: 0xFFFD,
	0x181D: 0xFFFD,
	0x181E: 0xFFFD,
	0x181F: 0xFFFD,
	0x1820: 0xFFFD,
	0x1821: 0xFFFD,
	0x1822: 0xFFFD,
	0x1823: 0xFFFD,
	0x1824: 0xFFFD,
	0x1825: 0xFFFD,
	0x1826: 0xFFFD,
	0x1827: 0xFFFD,
	0x1828: 0xFFFD,
	0x1829: 0xFFFD,
	0x182A: 0xFFFD,
	0x182B: 0xFFFD,
	0x182C: 0xFFFD,
	0x182D: 0xFFFD,
	0x182E: 0xFFFD,
	0x182F: 0xFFFD,
	0x1830: 0xFFFD,
	0x1831: 0xFFFD,
	0x1832: 0xFFFD,
	0x1833: 0xFFFD,
	0x1834: 0xFFFD,
	0x1835: 0xFFFD,
	0x1836: 0xFFFD,
	0x1837: 0xFFFD,
	0x1838: 0xFFFD,
	0x1839: 0xFFFD,
	0x183A: 0xFFFD,
	0x183B: 0xFFFD,
	0x183C: 0xFFFD,
	0x183D: 0xFFFD,
	0x183E: 0xFFFD,
	0x183F: 0xFFFD,
	0x1840: 0xFFFD,
	0x1841: 0xFFFD,
	0x1842: 0xFFFD,
	0x1843: 0xFFFD,
	0x1844: 0xFFFD,
	0x1845: 0xFFFD,
	0x1846: 0xFFFD,
	0x1847: 0xFFFD,
	0x1848: 0xFFFD,
	0x1849: 0xFFFD,
	0x184A: 0xFFFD,
	0x184B: 0xFFFD,
	0x184C: 0xFFFD,
	0x184D: 0xFFFD,
	0x184E: 0xFFFD,
	0x184F: 0xFFFD,
	0x1850: 0xFFFD,
	0x1851: 0xFFFD,
	0x1852: 0xFFFD,
	0x1853: 0xFFFD,
	0x1854: 0xFFFD,
	0x1855: 0xFFFD,
	0x1856: 0xFFFD,
	0x1857: 0xFFFD,
	0x1858: 0xFFFD,
	0x1859: 0xFFFD,
	0x185A: 0xFFFD,
	0x185B: 0xFFFD,
	0x185C: 0xFFFD,
	0x185D: 0xFFFD,
	0x185E: 0xFFFD,
	0x185F: 0xFFFD,
	0x1860: 0xFFFD,
	0x1861: 0xFFFD,
	0x1862: 0xFFFD,
	0x1863: 0xFFFD,
	0x1864: 0xFFFD,
	0x1865: 0xFFFD,
	0x1866: 0xFFFD,
	0x1867: 0xFFFD,
	0x1868: 0xFFFD,
	0x1869: 0xFFFD,
	0x186A: 0xFFFD,
	0x186B: 0xFFFD,
	0x186C: 0xFFFD,
	0x186D: 0xFFFD,
	0x186E: 0xFFFD,
	0x186F: 0xFFFD,
	0x1870: 0xFFFD,
	0x1871: 0xFFFD,
	0x1872: 0xFFFD,
	0x1873: 0xFFFD,
	0x1874: 0xFFFD,
	0x1875: 0xFFFD,
	0x1876: 0xFFFD,
	0x1877: 0xFFFD,
	0x1878: 0xFFFD,
	0x1879: 0xFFFD,
	0x187A: 0xFFFD,
	0x187B: 0xFFFD,
	0x187C: 0xFFFD,
	0x187D: 0xFFFD,
	0x187E: 0xFFFD,
	0x187F: 0xFFFD,
	0x1880: 0xFFFD,
	0x1881: 0xFFFD,
	0x1882: 0xFFFD,
	0x1883: 0xFFFD,
	0x1884: 0xFFFD,
	0x1885: 0xFFFD,
	0x1886: 0xFFFD,
	0x1887: 0xFFFD,
	0x1888: 0xFFFD,
	0x1889: 0xFFFD,
	0x188A: 0xFFFD,
	0x188B: 0xFFFD,
	0x188C: 0xFFFD,
	0x188D: 0xFFFD,
	0x188E: 0xFFFD,
	0x188F: 0xFFFD,
	0x1890: 0xFFFD,
	0x1891: 0xFFFD,
	0x1892: 0xFFFD,
	0x1893: 0xFFFD,
	0x1894: 0xFFFD,
	0x1895: 0xFFFD,
	0x1896: 0xFFFD,
	0x1897: 0xFFFD,
	0x1898: 0xFFFD,
	0x1899: 0xFFFD,
	0x189A: 0xFFFD,
	0x189B: 0xFFFD,
	0x189C: 0xFFFD,
	0x189D: 0xFFFD,
	0x189E: 0xFFFD,
	0x189F: 0xFFFD,
	0x18A0: 0xFFFD,
	0x18A1: 0xFFFD,
	0x18A2: 0xFFFD,
	0x18A3: 0xFFFD,
	0x18A4: 0xFFFD,
	0x18A5: 0xFFFD,
	0x18A6: 0xFFFD,
	0x18A7: 0xFFFD,
	0x18A8: 0xFFFD,
	0x18A9: 0xFFFD,
	0x18AA: 0xFFFD,
	0x18AB: 0xFFFD,
	0x18AC: 0xFFFD,
	0x18AD: 0xFFFD,
	0x18AE: 0xFFFD,
	0x18AF: 0xFFFD,
	0x18B0: 0xFFFD,
	0x18B1: 0xFFFD,
	0x18B2: 0xFFFD,
	0x18B3: 0xFFFD,
	0x18B4: 0xFFFD,
	0x18B5: 0xFFFD,
	0x18B6: 0xFFFD,
	0x18B7: 0xFFFD,
	0x18B8: 0xFFFD,
	0x18B9: 0xFFFD,
	0x18BA: 0xFFFD,
	0x18BB: 0xFFFD,
	0x18BC: 0xFFFD,
	0x18BD: 0xFFFD,
	0x18BE: 0xFFFD,
	0x18BF: 0xFFFD,
	0x18C0: 0xFFFD,
	0x18C1: 0xFFFD,
	0x18C2: 0xFFFD,
	0x18C3: 0xFFFD,
	0x18C4: 0xFFFD,
	0x18C5: 0xFFFD,
	0x18C6: 0xFFFD,
	0x18C7: 0xFFFD,
	0x18C8: 0xFFFD,
	0x18C9: 0xFFFD,
	0x18CA: 0xFFFD,
	0x18CB: 0xFFFD,
	0x18CC: 0xFFFD,
	0x18CD: 0xFFFD,
	0x18CE: 0xFFFD,
	0x18CF: 0xFFFD,
	0x18D0: 0xFFFD,
	0x18D1: 0xFFFD,
	0x18D2: 0xFFFD,
	0x18D3: 0xFFFD,
	0x18D4: 0xFFFD,
	0x18D5: 0xFFFD,
	0x18D6: 0xFFFD,
	0x18D7: 0xFFFD,
	0x18D8: 0xFFFD,
	0x18D9: 0xFFFD,
	0x18DA: 0xFFFD,
	0x18DB: 0xFFFD,
	0x18DC: 0xFFFD,
	0x18DD: 0xFFFD,
	0x18DE: 0xFFFD,
	0x18DF: 0xFFFD,
	0x18E0: 0xFFFD,
	0x18E1: 0xFFFD,
	0x18E2: 0xFFFD,
	0x18E3: 0xFFFD,
	0x18E4: 0xFFFD,
	0x18E5: 0xFFFD,
	0x18E6: 0xFFFD,
	0x18E7: 0xFFFD,
	0x18E8: 0xFFFD,
	0x18E9: 0xFFFD,
	0x18EA: 0xFFFD,
	0x18EB: 0xFFFD,
	0x18EC: 0xFFFD,
	0x18ED: 0xFFFD,
	0x18EE: 0xFFFD,
	0x18EF: 0xFFFD,
	0x18F0: 0xFFFD,
	0x18F1: 0xFFFD,
	0x18F2: 0xFFFD,
	0x18F3: 0xFFFD,
	0x18F4: 0xFFFD,
	0x18F5: 0xFFFD,
	0x18F6: 0xFFFD,
	0x18F7: 0xFFFD,
	0x18F8: 0xFFFD,
	0x18F9: 0xFFFD,
	0x18FA: 0xFFFD,
	0x18FB: 0xFFFD,
	0x18FC: 0xFFFD,
	0x18FD: 0xFFFD,
	0x18FE: 0xFFFD,
	0x18FF: 0xFFFD,
	0x1900: 0xFFFD,
	0x1901: 0xFFFD,
	0x1902: 0xFFFD,
	0x1903: 0xFFFD,
	0x1904: 0xFFFD,
	0x1905: 0xFFFD,
	0x1906: 0xFFFD,
	0x1907: 0xFFFD,
	0x1908: 0xFFFD,
	0x1909: 0xFFFD,
	0x190A: 0xFFFD,
	0x190B: 0xFFFD,
	0x190C: 0xFFFD,
	0x190D: 0xFFFD,
	0x190E: 0xFFFD,
	0x190F: 0xFFFD,
	0x1910: 0xFFFD,
	0x1911: 0xFFFD,
	0x1912: 0xFFFD,
	0x1913: 0xFFFD,
	0x1914: 0xFFFD,
	0x1915: 0xFFFD,
	0x1916: 0xFFFD,
	0x1917: 0xFFFD,
	0x1918: 0xFFFD,
	0x1919: 0xFFFD,
	0x191A: 0xFFFD,
	0x191B: 0xFFFD,
	0x191C: 0xFFFD,
	0x191D: 0xFFFD,
	0x191E: 0xFFFD,
	0x191F: 0xFFFD,
	0x1920: 0xFFFD,
	0x1921: 0xFFFD,
	0x1922: 0xFFFD,
	0x1923: 0xFFFD,
	0x1924: 0xFFFD,
	0x1925: 0xFFFD,
	0x1926: 0xFFFD,
	0x1927: 0xFFFD,
	0x1928: 0xFFFD,
	0x1929: 0xFFFD,
	0x192A: 0xFFFD,
	0x192B: 0xFFFD,
	0x192C: 0xFFFD,
	0x192D: 0xFFFD,
	0x192E: 0xFFFD,
	0x192F: 0xFFFD,
	0x1930: 0xFFFD,
	0x1931: 0xFFFD,
	0x1932: 0xFFFD,
	0x1933: 0xFFFD,
	0x1934: 0xFFFD,
	0x1935: 0xFFFD,
	0x1936: 0xFFFD,
	0x1937: 0xFFFD,
	0x1938: 0xFFFD,
	0x1939: 0xFFFD,
	0x193A: 0xFFFD,
	0x193B: 0xFFFD,
	0x193C: 0xFFFD,
	0x193D: 0xFFFD,
	0x193E: 0xFFFD,
	0x193F: 0xFFFD,
	0x1940: 0xFFFD,
	0x1941: 0xFFFD,
	0x1942: 0xFFFD,
	0x1943: 0xFFFD,
	0x1944: 0xFFFD,
	0x1945: 0xFFFD,
	0x1946: 0xFFFD,
	0x1947: 0xFFFD,
	0x1948: 0xFFFD,
	0x1949: 0xFFFD,
	0x194A: 0xFFFD,
	0x194B: 0xFFFD,
	0x194C: 0xFFFD,
	0x194D: 0xFFFD,
	0x194E: 0xFFFD,
	0x194F: 0xFFFD,
	0x1950: 0xFFFD,
	0x1951: 0xFFFD,
	0x1952: 0xFFFD,
	0x1953: 0xFFFD,
	0x1954: 0xFFFD,
	0x1955: 0xFFFD,
	0x1956: 0xFFFD,
	0x1957: 0xFFFD,
	0x1958: 0xFFFD,
	0x1959: 0xFFFD,
	0x195A: 0xFFFD,
	0x195B: 0xFFFD,
	0x195C: 0xFFFD,
	0x195D: 0xFFFD,
	0x195E: 0xFFFD,
	0x195F: 0xFFFD,
	0x1960: 0xFFFD,
	0x1961: 0xFFFD,
	0x1962: 0xFFFD,
	0x1963: 0xFFFD,
	0x1964: 0xFFFD,
	0x1965: 0xFFFD,
	0x1966: 0xFFFD,
	0x1967: 0xFFFD,
	0x1968: 0xFFFD,
	0x1969: 0xFFFD,
	0x196A: 0xFFFD,
	0x196B: 0xFFFD,
	0x196C: 0xFFFD,
	0x196D: 0xFFFD,
	0x196E: 0xFFFD,
	0x196F: 0xFFFD,
	0x1970: 0xFFFD,
	0x1971: 0xFFFD,
	0x1972: 0xFFFD,
	0x1973: 0xFFFD,
	0x1974: 0xFFFD,
	0x1975: 0xFFFD,
	0x1976: 0xFFFD,
	0x1977: 0xFFFD,
	0x1978: 0xFFFD,
	0x1979: 0xFFFD,
	0x197A: 0xFFFD,
	0x197B: 0xFFFD,
	0x197C: 0xFFFD,
	0x197D: 0xFFFD,
	0x197E: 0xFFFD,
	0x197F: 0xFFFD,
	0x1980: 0xFFFD,
	0x1981: 0xFFFD,
	0x1982: 0xFFFD,
	0x1983: 0xFFFD,
	0x1984: 0xFFFD,
	0x1985: 0xFFFD,
	0x1986: 0xFFFD,
	0x1987: 0xFFFD,
	0x1988: 0xFFFD,
	0x1989: 0xFFFD,
	0x198A: 0xFFFD,
	0x198B: 0xFFFD,
	0x198C: 0xFFFD,
	0x198D: 0xFFFD,
	0x198E: 0xFFFD,
	0x198F: 0xFFFD,
	0x1990: 0xFFFD,
	0x1991: 0xFFFD,
	0x1992: 0xFFFD,
	0x1993: 0xFFFD,
	0x1994: 0xFFFD,
	0x1995: 0xFFFD,
	0x1996: 0xFFFD,
	0x1997: 0xFFFD,
	0x1998: 0xFFFD,
	0x1999: 0xFFFD,
	0x199A: 0xFFFD,
	0x199B: 0xFFFD,
	0x199C: 0xFFFD,
	0x199D: 0xFFFD,
	0x199E: 0xFFFD,
	0x199F: 0xFFFD,
	0x19A0: 0xFFFD,
	0x19A1: 0xFFFD,
	0x19A2: 0xFFFD,
	0x19A3: 0xFFFD,
	0x19A4: 0xFFFD,
	0x19A5: 0xFFFD,
	0x19A6: 0xFFFD,
	0x19A7: 0xFFFD,
	0x19A8: 0xFFFD,
	0x19A9: 0xFFFD,
	0x19AA: 0xFFFD,
	0x19AB: 0xFFFD,
	0x19AC: 0xFFFD,
	0x19AD: 0xFFFD,
	0x19AE: 0xFFFD,
	0x19AF: 0xFFFD,
	0x19B0: 0xFFFD,
	0x19B1: 0xFFFD,
	0x19B2: 0xFFFD,
	0x19B3: 0xFFFD,
	0x19B4: 0xFFFD,
	0x19B5: 0xFFFD,
	0x19B6: 0xFFFD,
	0x19B7: 0xFFFD,
	0x19B8: 0xFFFD,
	0x19B9: 0xFFFD,
	0x19BA: 0xFFFD,
	0x19BB: 0xFFFD,
	0x19BC: 0xFFFD,
	0x19BD: 0xFFFD,
	0x19BE: 0xFFFD,
	0x19BF: 0xFFFD,
	0x19C0: 0xFFFD,
	0x19C1: 0xFFFD,
	0x19C2: 0xFFFD,
	0x19C3: 0xFFFD,
	0x19C4: 0xFFFD,
	0x19C5: 0xFFFD,
	0x19C6: 0xFFFD,
	0x19C7: 0xFFFD,
	0x19C8: 0xFFFD,
	0x19C9: 0xFFFD,
	0x19CA: 0xFFFD,
	0x19CB: 0xFFFD,
	0x19CC: 0xFFFD,
	0x19CD: 0xFFFD,
	0x19CE: 0xFFFD,
	0x19CF: 0xFFFD,
	0x19D0: 0xFFFD,
	0x19D1: 0xFFFD,
	0x19D2: 0xFFFD,
	0x19D3: 0xFFFD,
	0x19D4: 0xFFFD,
	0x19D5: 0xFFFD,
	0x19D6: 0xFFFD,
	0x19D7: 0xFFFD,
	0x19D8: 0xFFFD,
	0x19D9: 0xFFFD,
	0x19DA: 0xFFFD,
	0x19DB: 0xFFFD,
	0x19DC: 0xFFFD,
	0x19DD: 0xFFFD,
	0x19DE: 0xFFFD,
	0x19DF: 0xFFFD,
	0x19E0: 0xFFFD,
	0x19E1: 0xFFFD,
	0x19E2: 0xFFFD,
	0x19E3: 0xFFFD,
	0x19E4: 0xFFFD,
	0x19E5: 0xFFFD,
	0x19E6: 0xFFFD,
	0x19E7: 0xFFFD,
	0x19E8: 0xFFFD,
	0x19E9: 0xFFFD,
	0x19EA: 0xFFFD,
	0x19EB: 0xFFFD,
	0x19EC: 0xFFFD,
	0x19ED: 0xFFFD,
	0x19EE: 0xFFFD,
	0x19EF: 0xFFFD,
	0x19F0: 0xFFFD,
	0x19F1: 0xFFFD,
	0x19F2: 0xFFFD,
	0x19F3: 0xFFFD,
	0x19F4: 0xFFFD,
	0x19F5: 0xFFFD,
	0x19F6: 0xFFFD,
	0x19F7: 0xFFFD,
	0x19F8: 0xFFFD,
	0x19F9: 0xFFFD,
	0x19FA: 0xFFFD,
	0x19FB: 0xFFFD,
	0x19FC: 0xFFFD,
	0x19FD: 0xFFFD,
	0x19FE: 0xFFFD,
	0x19FF: 0xFFFD,
	0x1A00: 0xFFFD,
	0x1A01: 0xFFFD,
	0x1A02: 0xFFFD,
	0x1A03: 0xFFFD,
	0x1A04: 0xFFFD,
	0x1A05: 0xFFFD,
	0x1A06: 0xFFFD,
	0x1A07: 0xFFFD,
	0x1A08: 0xFFFD,
	0x1A09: 0xFFFD,
	0x1A0A: 0xFFFD,
	0x1A0B: 0xFFFD,
	0x1A0C: 0xFFFD,
	0x1A0D: 0xFFFD,
	0x1A0E: 0xFFFD,
	0x1A0F: 0xFFFD,
	0x1A10: 0xFFFD,
	0x1A11: 0xFFFD,
	0x1A12: 0xFFFD,
	0x1A13: 0xFFFD,
	0x1A14: 0xFFFD,
	0x1A15: 0xFFFD,
	0x1A16: 0xFFFD,
	0x1A17: 0xFFFD,
	0x1A18: 0xFFFD,
	0x1A19: 0xFFFD,
	0x1A1A: 0xFFFD,
	0x1A1B: 0xFFFD,
	0x1A1C: 0xFFFD,
	0x1A1D: 0xFFFD,
	0x1A1E: 0xFFFD,
	0x1A1F: 0xFFFD,
	0x1A20: 0xFFFD,
	0x1A21: 0xFFFD,
	0x1A22: 0xFFFD,
	0x1A23: 0xFFFD,
	0x1A24: 0xFFFD,
	0x1A25: 0xFFFD,
	0x1A26: 0xFFFD,
	0x1A27: 0xFFFD,
	0x1A28: 0xFFFD,
	0x1A29: 0xFFFD,
	0x1A2A: 0xFFFD,
	0x1A2B: 0xFFFD,
	0x1A2C: 0xFFFD,
	0x1A2D: 0xFFFD,
	0x1A2E: 0xFFFD,
	0x1A2F: 0xFFFD,
	0x1A30: 0xFFFD,
	0x1A31: 0xFFFD,
	0x1A32: 0xFFFD,
	0x1A33: 0xFFFD,
	0x1A34: 0xFFFD,
	0x1A35: 0xFFFD,
	0x1A36: 0xFFFD,
	0x1A37: 0xFFFD,
	0x1A38: 0xFFFD,
	0x1A39: 0xFFFD,
	0x1A3A: 0xFFFD,
	0x1A3B: 0xFFFD,
	0x1A3C: 0xFFFD,
	0x1A3D: 0xFFFD,
	0x1A3E: 0xFFFD,
	0x1A3F: 0xFFFD,
	0x1A40: 0xFFFD,
	0x1A41: 0xFFFD,
	0x1A42: 0xFFFD,
	0x1A43: 0xFFFD,
	0x1A44: 0xFFFD,
	0x1A45: 0xFFFD,
	0x1A46: 0xFFFD,
	0x1A47: 0xFFFD,
	0x1A48: 0xFFFD,
	0x1A49: 0xFFFD,
	0x1A4A: 0xFFFD,
	0x1A4B: 0xFFFD,
	0x1A4C: 0xFFFD,
	0x1A4D: 0xFFFD,
	0x1A4E: 0xFFFD,
	0x1A4F: 0xFFFD,
	0x1A50: 0xFFFD,
	0x1A51: 0xFFFD,
	0x1A52: 0xFFFD,
	0x1A53: 0xFFFD,
	0x1A54: 0xFFFD,
	0x1A55: 0xFFFD,
	0x1A56: 0xFFFD,
	0x1A57: 0xFFFD,
	0x1A58: 0xFFFD,
	0x1A59: 0xFFFD,
	0x1A5A: 0xFFFD,
	0x1A5B: 0xFFFD,
	0x1A5C: 0xFFFD,
	0x1A5D: 0xFFFD,
	0x1A5E: 0xFFFD,
	0x1A5F: 0xFFFD,
	0x1A60: 0xFFFD,
	0x1A61: 0xFFFD,
	0x1A62: 0xFFFD,
	0x1A63: 0xFFFD,
	0x1A64: 0xFFFD,
	0x1A65: 0xFFFD,
	0x1A66: 0xFFFD,
	0x1A67: 0xFFFD,
	0x1A68: 0xFFFD,
	0x1A69: 0xFFFD,
	0x1A6A: 0xFFFD,
	0x1A6B: 0xFFFD,
	0x1A6C: 0xFFFD,
	0x1A6D: 0xFFFD,
	0x1A6E: 0xFFFD,
	0x1A6F: 0xFFFD,
	0x1A70: 0xFFFD,
	0x1A71: 0xFFFD,
	0x1A72: 0xFFFD,
	0x1A73: 0xFFFD,
	0x1A74: 0xFFFD,
	0x1A75: 0xFFFD,
	0x1A76: 0xFFFD,
	0x1A77: 0xFFFD,
	0x1A78: 0xFFFD,
	0x1A79: 0xFFFD,
	0x1A7A: 0xFFFD,
	0x1A7B: 0xFFFD,
	0x1A7C: 0xFFFD,
	0x1A7D: 0xFFFD,
	0x1A7E: 0xFFFD,
	0x1A7F: 0xFFFD,
	0x1A80: 0xFFFD,
	0x1A81: 0xFFFD,
	0x1A82: 0xFFFD,
	0x1A83: 0xFFFD,
	0x1A84: 0xFFFD,
	0x1A85: 0xFFFD,
	0x1A86: 0xFFFD,
	0x1A87: 0xFFFD,
	0x1A88: 0xFFFD,
	0x1A89: 0xFFFD,
	0x1A8A: 0xFFFD,
	0x1A8B: 0xFFFD,
	0x1A8C: 0xFFFD,
	0x1A8D: 0xFFFD,
	0x1A8E: 0xFFFD,
	0x1A8F: 0xFFFD,
	0x1A90: 0xFFFD,
	0x1A91: 0xFFFD,
	0x1A92: 0xFFFD,
	0x1A93: 0xFFFD,
	0x1A94: 0xFFFD,
	0x1A95: 0xFFFD,
	0x1A96: 0xFFFD,
	0x1A97: 0xFFFD,
	0x1A98: 0xFFFD,
	0x1A99: 0xFFFD,
	0x1A9A: 0xFFFD,
	0x1A9B: 0xFFFD,
	0x1A9C: 0xFFFD,
	0x1A9D: 0xFFFD,
	0x1A9E: 0xFFFD,
	0x1A9F: 0xFFFD,
	0x1AA0: 0xFFFD,
	0x1AA1: 0xFFFD,
	0x1AA2: 0xFFFD,
	0x1AA3: 0xFFFD,
	0x1AA4: 0xFFFD,
	0x1AA5: 0xFFFD,
	0x1AA6: 0xFFFD,
	0x1AA7: 0xFFFD,
	0x1AA8: 0xFFFD,
	0x1AA9: 0xFFFD,
	0x1AAA: 0xFFFD,
	0x1AAB: 0xFFFD,
	0x1AAC: 0xFFFD,
	0x1AAD: 0xFFFD,
	0x1AAE: 0xFFFD,
	0x1AAF: 0xFFFD,
	0x1AB0: 0xFFFD,
	0x1AB1: 0xFFFD,
	0x1AB2: 0xFFFD,
	0x1AB3: 0xFFFD,
	0x1AB4: 0xFFFD,
	0x1AB5: 0xFFFD,
	0x1AB6: 0xFFFD,
	0x1AB7: 0xFFFD,
	0x1AB8: 0xFFFD,
	0x1AB9: 0xFFFD,
	0x1ABA: 0xFFFD,
	0x1ABB: 0xFFFD,
	0x1ABC: 0xFFFD,
	0x1ABD: 0xFFFD,
	0x1ABE: 0xFFFD,
	0x1ABF: 0xFFFD,
	0x1AC0: 0xFFFD,
	0x1AC1: 0xFFFD,
	0x1AC2: 0xFFFD,
	0x1AC3: 0xFFFD,
	0x1AC4: 0xFFFD,
	0x1AC5: 0xFFFD,
	0x1AC6: 0xFFFD,
	0x1AC7: 0xFFFD,
	0x1AC8: 0xFFFD,
	0x1AC9: 0xFFFD,
	0x1ACA: 0xFFFD,
	0x1ACB: 0xFFFD,
	0x1ACC: 0xFFFD,
	0x1ACD: 0xFFFD,
	0x1ACE: 0xFFFD,
	0x1ACF: 0xFFFD,
	0x1AD0: 0xFFFD,
	0x1AD1: 0xFFFD,
	0x1AD2: 0xFFFD,
	0x1AD3: 0xFFFD,
	0x1AD4: 0xFFFD,
	0x1AD5: 0xFFFD,
	0x1AD6: 0xFFFD,
	0x1AD7: 0xFFFD,
	0x1AD8: 0xFFFD,
	0x1AD9: 0xFFFD,
	0x1ADA: 0xFFFD,
	0x1ADB: 0xFFFD,
	0x1ADC: 0xFFFD,
	0x1ADD: 0xFFFD,
	0x1ADE: 0xFFFD,
	0x1ADF: 0xFFFD,
	0x1AE0: 0xFFFD,
	0x1AE1: 0xFFFD,
	0x1AE2: 0xFFFD,
	0x1AE3: 0xFFFD,
	0x1AE4: 0xFFFD,
	0x1AE5: 0xFFFD,
	0x1AE6: 0xFFFD,
	0x1AE7: 0xFFFD,
	0x1AE8: 0xFFFD,
	0x1AE9: 0xFFFD,
	0x1AEA: 0xFFFD,
	0x1AEB: 0xFFFD,
	0x1AEC: 0xFFFD,
	0x1AED: 0xFFFD,
	0x1AEE: 0xFFFD,
	0x1AEF: 0xFFFD,
	0x1AF0: 0xFFFD,
	0x1AF1: 0xFFFD,
	0x1AF2: 0xFFFD,
	0x1AF3: 0xFFFD,
	0x1AF4: 0xFFFD,
	0x1AF5: 0xFFFD,
	0x1AF6: 0xFFFD,
	0x1AF7: 0xFFFD,
	0x1AF8: 0xFFFD,
	0x1AF9: 0xFFFD,
	0x1AFA: 0xFFFD,
	0x1AFB: 0xFFFD,
	0x1AFC: 0xFFFD,
	0x1AFD: 0xFFFD,
	0x1AFE: 0xFFFD,
	0x1AFF: 0xFFFD,
	0x1B00: 0xFFFD,
	0x1B01: 0xFFFD,
	0x1B02: 0xFFFD,
	0x1B03: 0xFFFD,
	0x1B04: 0xFFFD,
	0x1B05: 0xFFFD,
	0x1B06: 0xFFFD,
	0x1B07: 0xFFFD,
	0x1B08: 0xFFFD,
	0x1B09: 0xFFFD,
	0x1B0A: 0xFFFD,
	0x1B0B: 0xFFFD,
	0x1B0C: 0xFFFD,
	0x1B0D: 0xFFFD,
	0x1B0E: 0xFFFD,
	0x1B0F: 0xFFFD,
	0x1B10: 0xFFFD,
	0x1B11: 0xFFFD,
	0x1B12: 0xFFFD,
	0x1B13: 0xFFFD,
	0x1B14: 0xFFFD,
	0x1B15: 0xFFFD,
	0x1B16: 0xFFFD,
	0x1B17: 0xFFFD,
	0x1B18: 0xFFFD,
	0x1B19: 0xFFFD,
	0x1B1A: 0xFFFD,
	0x1B1B: 0xFFFD,
	0x1B1C: 0xFFFD,
	0x1B1D: 0xFFFD,
	0x1B1E: 0xFFFD,
	0x1B1F: 0xFFFD,
	0x1B20: 0xFFFD,
	0x1B21: 0xFFFD,
	0x1B22: 0xFFFD,
	0x1B23: 0xFFFD,
	0x1B24: 0xFFFD,
	0x1B25: 0xFFFD,
	0x1B26: 0xFFFD,
	0x1B27: 0xFFFD,
	0x1B28: 0xFFFD,
	0x1B29: 0xFFFD,
	0x1B2A: 0xFFFD,
	0x1B2B: 0xFFFD,
	0x1B2C: 0xFFFD,
	0x1B2D: 0xFFFD,
	0x1B2E: 0xFFFD,
	0x1B2F: 0xFFFD,
	0x1B30: 0xFFFD,
	0x1B31: 0xFFFD,
	0x1B32: 0xFFFD,
	0x1B33: 0xFFFD,
	0x1B34: 0xFFFD,
	0x1B35: 0xFFFD,
	0x1B36: 0xFFFD,
	0x1B37: 0xFFFD,
	0x1B38: 0xFFFD,
	0x1B39: 0xFFFD,
	0x1B3A: 0xFFFD,
	0x1B3B: 0xFFFD,
	0x1B3C: 0xFFFD,
	0x1B3D: 0xFFFD,
	0x1B3E: 0xFFFD,
	0x1B3F: 0xFFFD,
	0x1B40: 0xFFFD,
	0x1B41: 0xFFFD,
	0x1B42: 0xFFFD,
	0x1B43: 0xFFFD,
	0x1B44: 0xFFFD,
	0x1B45: 0xFFFD,
	0x1B46: 0xFFFD,
	0x1B47: 0xFFFD,
	0x1B48: 0xFFFD,
	0x1B49: 0xFFFD,
	0x1B4A: 0xFFFD,
	0x1B4B: 0xFFFD,
	0x1B4C: 0xFFFD,
	0x1B4D: 0xFFFD,
	0x1B4E: 0xFFFD,
	0x1B4F: 0xFFFD,
	0x1B50: 0xFFFD,
	0x1B51: 0xFFFD,
	0x1B52: 0xFFFD,
	0x1B53: 0xFFFD,
	0x1B54: 0xFFFD,
	0x1B55: 0xFFFD,
	0x1B56: 0xFFFD,
	0x1B57: 0xFFFD,
	0x1B58: 0xFFFD,
	0x1B59: 0xFFFD,
	0x1B5A: 0xFFFD,
	0x1B5B: 0xFFFD,
	0x1B5C: 0xFFFD,
	0x1B5D: 0xFFFD,
	0x1B5E: 0xFFFD,
	0x1B5F: 0xFFFD,
	0x1B60: 0xFFFD,
	0x1B61: 0xFFFD,
	0x1B62: 0xFFFD,
	0x1B63: 0xFFFD,
	0x1B64: 0xFFFD,
	0x1B65: 0xFFFD,
	0x1B66: 0xFFFD,
	0x1B67: 0xFFFD,
	0x1B68: 0xFFFD,
	0x1B69: 0xFFFD,
	0x1B6A: 0xFFFD,
	0x1B6B: 0xFFFD,
	0x1B6C: 0xFFFD,
	0x1B6D: 0xFFFD,
	0x1B6E: 0xFFFD,
	0x1B6F: 0xFFFD,
	0x1B70: 0xFFFD,
	0x1B71: 0xFFFD,
	0x1B72: 0xFFFD,
	0x1B73: 0xFFFD,
	0x1B74: 0xFFFD,
	0x1B75: 0xFFFD,
	0x1B76: 0xFFFD,
	0x1B77: 0xFFFD,
	0x1B78: 0xFFFD,
	0x1B79: 0xFFFD,
	0x1B7A: 0xFFFD,
	0x1B7B: 0xFFFD,
	0x1B7C: 0xFFFD,
	0x1B7D: 0xFFFD,
	0x1B7E: 0xFFFD,
	0x1B7F: 0xFFFD,
	0x1B80: 0xFFFD,
	0x1B81: 0xFFFD,
	0x1B82: 0xFFFD,
	0x1B83: 0xFFFD,
	0x1B84: 0xFFFD,
	0x1B85: 0xFFFD,
	0x1B86: 0xFFFD,
	0x1B87: 0xFFFD,
	0x1B88: 0xFFFD,
	0x1B89: 0xFFFD,
	0x1B8A: 0xFFFD,
	0x1B8B: 0xFFFD,
	0x1B8C: 0xFFFD,
	0x1B8D: 0xFFFD,
	0x1B8E: 0xFFFD,
	0x1B8F: 0xFFFD,
	0x1B90: 0xFFFD,
	0x1B91: 0xFFFD,
	0x1B92: 0xFFFD,
	0x1B93: 0xFFFD,
	0x1B94: 0xFFFD,
	0x1B95: 0xFFFD,
	0x1B96: 0xFFFD,
	0x1B97: 0xFFFD,
	0x1B98: 0xFFFD,
	0x1B99: 0xFFFD,
	0x1B9A: 0xFFFD,
	0x1B9B: 0xFFFD,
	0x1B9C: 0xFFFD,
	0x1B9D: 0xFFFD,
	0x1B9E: 0xFFFD,
	0x1B9F: 0xFFFD,
	0x1BA0: 0xFFFD,
	0x1BA1: 0xFFFD,
	0x1BA2: 0xFFFD,
	0x1BA3: 0xFFFD,
	0x1BA4: 0xFFFD,
	0x1BA5: 0xFFFD,
	0x1BA6: 0xFFFD,
	0x1BA7: 0xFFFD,
	0x1BA8: 0xFFFD,
	0x1BA9: 0xFFFD,
	0x1BAA: 0xFFFD,
	0x1BAB: 0xFFFD,
	0x1BAC: 0xFFFD,
	0x1BAD: 0xFFFD,
	0x1BAE: 0xFFFD,
	0x1BAF: 0xFFFD,
	0x1BB0: 0xFFFD,
	0x1BB1: 0xFFFD,
	0x1BB2: 0xFFFD,
	0x1BB3: 0xFFFD,
	0x1BB4: 0xFFFD,
	0x1BB5: 0xFFFD,
	0x1BB6: 0xFFFD,
	0x1BB7: 0xFFFD,
	0x1BB8: 0xFFFD,
	0x1BB9: 0xFFFD,
	0x1BBA: 0xFFFD,
	0x1BBB: 0xFFFD,
	0x1BBC: 0xFFFD,
	0x1BBD: 0xFFFD,
	0x1BBE: 0xFFFD,
	0x1BBF: 0xFFFD,
	0x1BC0: 0xFFFD,
	0x1BC1: 0xFFFD,
	0x1BC2: 0xFFFD,
	0x1BC3: 0xFFFD,
	0x1BC4: 0xFFFD,
	0x1BC5: 0xFFFD,
	0x1BC6: 0xFFFD,
	0x1BC7: 0xFFFD,
	0x1BC8: 0xFFFD,
	0x1BC9: 0xFFFD,
	0x1BCA: 0xFFFD,
	0x1BCB: 0xFFFD,
	0x1BCC: 0xFFFD,
	0x1BCD: 0xFFFD,
	0x1BCE: 0xFFFD,
	0x1BCF: 0xFFFD,
	0x1BD0: 0xFFFD,
	0x1BD1: 0xFFFD,
	0x1BD2: 0xFFFD,
	0x1BD3: 0xFFFD,
	0x1BD4: 0xFFFD,
	0x1BD5: 0xFFFD,
	0x1BD6: 0xFFFD,
	0x1BD7: 0xFFFD,
	0x1BD8: 0xFFFD,
	0x1BD9: 0xFFFD,
	0x1BDA: 0xFFFD,
	0x1BDB: 0xFFFD,
	0x1BDC: 0xFFFD,
	0x1BDD: 0xFFFD,
	0x1BDE: 0xFFFD,
	0x1BDF: 0xFFFD,
	0x1BE0: 0xFFFD,
	0x1BE1: 0xFFFD,
	0x1BE2: 0xFFFD,
	0x1BE3: 0xFFFD,
	0x1BE4: 0xFFFD,
	0x1BE5: 0xFFFD,
	0x1BE6: 0xFFFD,
	0x1BE7: 0xFFFD,
	0x1BE8: 0xFFFD,
	0x1BE9: 0xFFFD,
	0x1BEA: 0xFFFD,
	0x1BEB: 0xFFFD,
	0x1BEC: 0xFFFD,
	0x1BED: 0xFFFD,
	0x1BEE: 0xFFFD,
	0x1BEF: 0xFFFD,
	0x1BF0: 0xFFFD,
	0x1BF1: 0xFFFD,
	0x1BF2: 0xFFFD,
	0x1BF3: 0xFFFD,
	0x1BF4: 0xFFFD,
	0x1BF5: 0xFFFD,
	0x1BF6: 0xFFFD,
	0x1BF7: 0xFFFD,
	0x1BF8: 0xFFFD,
	0x1BF9: 0xFFFD,
	0x1BFA: 0xFFFD,
	0x1BFB: 0xFFFD,
	0x1BFC: 0xFFFD,
	0x1BFD: 0xFFFD,
	0x1BFE: 0xFFFD,
	0x1BFF: 0xFFFD,
	0x1C00: 0xFFFD,
	0x1C01: 0xFFFD,
	0x1C02: 0xFFFD,
	0x1C03: 0xFFFD,
	0x1C04: 0xFFFD,
	0x1C05: 0xFFFD,
	0x1C06: 0xFFFD,
	0x1C07: 0xFFFD,
	0x1C08: 0xFFFD,
	0x1C09: 0xFFFD,
	0x1C0A: 0xFFFD,
	0x1C0B: 0xFFFD,
	0x1C0C: 0xFFFD,
	0x1C0D: 0xFFFD,
	0x1C0E: 0xFFFD,
	0x1C0F: 0xFFFD,
	0x1C10: 0xFFFD,
	0x1C11: 0xFFFD,
	0x1C12: 0xFFFD,
	0x1C13: 0xFFFD,
	0x1C14: 0xFFFD,
	0x1C15: 0xFFFD,
	0x1C16: 0xFFFD,
	0x1C17: 0xFFFD,
	0x1C18: 0xFFFD,
	0x1C19: 0xFFFD,
	0x1C1A: 0xFFFD,
	0x1C1B: 0xFFFD,
	0x1C1C: 0xFFFD,
	0x1C1D: 0xFFFD,
	0x1C1E: 0xFFFD,
	0x1C1F: 0xFFFD,
	0x1C20: 0xFFFD,
	0x1C21: 0xFFFD,
	0x1C22: 0xFFFD,
	0x1C23: 0xFFFD,
	0x1C24: 0xFFFD,
	0x1C25: 0xFFFD,
	0x1C26: 0xFFFD,
	0x1C27: 0xFFFD,
	0x1C28: 0xFFFD,
	0x1C29: 0xFFFD,
	0x1C2A: 0xFFFD,
	0x1C2B: 0xFFFD,
	0x1C2C: 0xFFFD,
	0x1C2D: 0xFFFD,
	0x1C2E: 0xFFFD,
	0x1C2F: 0xFFFD,
	0x1C30: 0xFFFD,
	0x1C31: 0xFFFD,
	0x1C32: 0xFFFD,
	0x1C33: 0xFFFD,
	0x1C34: 0xFFFD,
	0x1C35: 0xFFFD,
	0x1C36: 0xFFFD,
	0x1C37: 0xFFFD,
	0x1C38: 0xFFFD,
	0x1C39: 0xFFFD,
	0x1C3A: 0xFFFD,
	0x1C3B: 0xFFFD,
	0x1C3C: 0xFFFD,
	0x1C3D: 0xFFFD,
	0x1C3E: 0xFFFD,
	0x1C3F: 0xFFFD,
	0x1C40: 0xFFFD,
	0x1C41: 0xFFFD,
	0x1C42: 0xFFFD,
	0x1C43: 0xFFFD,
	0x1C44: 0xFFFD,
	0x1C45: 0xFFFD,
	0x1C46: 0xFFFD,
	0x1C47: 0xFFFD,
	0x1C48: 0xFFFD,
	0x1C49: 0xFFFD,
	0x1C4A: 0xFFFD,
	0x1C4B: 0xFFFD,
	0x1C4C: 0xFFFD,
	0x1C4D: 0xFFFD,
	0x1C4E: 0xFFFD,
	0x1C4F: 0xFFFD,
	0x1C50: 0xFFFD,
	0x1C51: 0xFFFD,
	0x1C52: 0xFFFD,
	0x1C53: 0xFFFD,
	0x1C54: 0xFFFD,
	0x1C55: 0xFFFD,
	0x1C56: 0xFFFD,
	0x1C57: 0xFFFD,
	0x1C58: 0xFFFD,
	0x1C59: 0xFFFD,
	0x1C5A: 0xFFFD,
	0x1C5B: 0xFFFD,
	0x1C5C: 0xFFFD,
	0x1C5D: 0xFFFD,
	0x1C5E: 0xFFFD,
	0x1C5F: 0xFFFD,
	0x1C60: 0xFFFD,
	0x1C61: 0xFFFD,
	0x1C62: 0xFFFD,
	0x1C63: 0xFFFD,
	0x1C64: 0xFFFD,
	0x1C65: 0xFFFD,
	0x1C66: 0xFFFD,
	0x1C67: 0xFFFD,
	0x1C68: 0xFFFD,
	0x1C69: 0xFFFD,
	0x1C6A: 0xFFFD,
	0x1C6B: 0xFFFD,
	0x1C6C: 0xFFFD,
	0x1C6D: 0xFFFD,
	0x1C6E: 0xFFFD,
	0x1C6F: 0xFFFD,
	0x1C70: 0xFFFD,
	0x1C71: 0xFFFD,
	0x1C72: 0xFFFD,
	0x1C73: 0xFFFD,
	0x1C74: 0xFFFD,
	0x1C75: 0xFFFD,
	0x1C76: 0xFFFD,
	0x1C77: 0xFFFD,
	0x1C78: 0xFFFD,
	0x1C79: 0xFFFD,
	0x1C7A: 0xFFFD,
	0x1C7B: 0xFFFD,
	0x1C7C: 0xFFFD,
	0x1C7D: 0xFFFD,
	0x1C7E: 0xFFFD,
	0x1C7F: 0xFFFD,
	0x1C80: 0xFFFD,
	0x1C81: 0xFFFD,
	0x1C82: 0xFFFD,
	0x1C83: 0xFFFD,
	0x1C84: 0xFFFD,
	0x1C85: 0xFFFD,
	0x1C86: 0xFFFD,
	0x1C87: 0xFFFD,
	0x1C88: 0xFFFD,
	0x1C89: 0xFFFD,
	0x1C8A: 0xFFFD,
	0x1C8B: 0xFFFD,
	0x1C8C: 0xFFFD,
	0x1C8D: 0xFFFD,
	0x1C8E: 0xFFFD,
	0x1C8F: 0xFFFD,
	0x1C90: 0xFFFD,
	0x1C91: 0xFFFD,
	0x1C92: 0xFFFD,
	0x1C93: 0xFFFD,
	0x1C94: 0xFFFD,
	0x1C95: 0xFFFD,
	0x1C96: 0xFFFD,
	0x1C97: 0xFFFD,
	0x1C98: 0xFFFD,
	0x1C99: 0xFFFD,
	0x1C9A: 0xFFFD,
	0x1C9B: 0xFFFD,
	0x1C9C: 0xFFFD,
	0x1C9D: 0xFFFD,
	0x1C9E: 0xFFFD,
	0x1C9F: 0xFFFD,
	0x1CA0: 0xFFFD,
	0x1CA1: 0xFFFD,
	0x1CA2: 0xFFFD,
	0x1CA3: 0xFFFD,
	0x1CA4: 0xFFFD,
	0x1CA5: 0xFFFD,
	0x1CA6: 0xFFFD,
	0x1CA7: 0xFFFD,
	0x1CA8: 0xFFFD,
	0x1CA9: 0xFFFD,
	0x1CAA: 0xFFFD,
	0x1CAB: 0xFFFD,
	0x1CAC: 0xFFFD,
	0x1CAD: 0xFFFD,
	0x1CAE: 0xFFFD,
	0x1CAF: 0xFFFD,
	0x1CB0: 0xFFFD,
	0x1CB1: 0xFFFD,
	0x1CB2: 0xFFFD,
	0x1CB3: 0xFFFD,
	0x1CB4: 0xFFFD,
	0x1CB5: 0xFFFD,
	0x1CB6: 0xFFFD,
	0x1CB7: 0xFFFD,
	0x1CB8: 0xFFFD,
	0x1CB9: 0xFFFD,
	0x1CBA: 0xFFFD,
	0x1CBB: 0xFFFD,
	0x1CBC: 0xFFFD,
	0x1CBD: 0xFFFD,
	0x1CBE: 0xFFFD,
	0x1CBF: 0xFFFD,
	0x1CC0: 0xFFFD,
	0x1CC1: 0xFFFD,
	0x1CC2: 0xFFFD,
	0x1CC3: 0xFFFD,
	0x1CC4: 0xFFFD,
	0x1CC5: 0xFFFD,
	0x1CC6: 0xFFFD,
	0x1CC7: 0xFFFD,
	0x1CC8: 0xFFFD,
	0x1CC9: 0xFFFD,
	0x1CCA: 0xFFFD,
	0x1CCB: 0xFFFD,
	0x1CCC: 0xFFFD,
	0x1CCD: 0xFFFD,
	0x1CCE: 0xFFFD,
	0x1CCF: 0xFFFD,
	0x1CD0: 0xFFFD,
	0x1CD1: 0xFFFD,
	0x1CD2: 0xFFFD,
	0x1CD3: 0xFFFD,
	0x1CD4: 0xFFFD,
	0x1CD5: 0xFFFD,
	0x1CD6: 0xFFFD,
	0x1CD7: 0xFFFD,
	0x1CD8: 0xFFFD,
	0x1CD9: 0xFFFD,
	0x1CDA: 0xFFFD,
	0x1CDB: 0xFFFD,
	0x1CDC: 0xFFFD,
	0x1CDD: 0xFFFD,
	0x1CDE: 0xFFFD,
	0x1CDF: 0xFFFD,
	0x1CE0: 0xFFFD,
	0x1CE1: 0xFFFD,
	0x1CE2: 0xFFFD,
	0x1CE3: 0xFFFD,
	0x1CE4: 0xFFFD,
	0x1CE5: 0xFFFD,
	0x1CE6: 0xFFFD,
	0x1CE7: 0xFFFD,
	0x1CE8: 0xFFFD,
	0x1CE9: 0xFFFD,
	0x1CEA: 0xFFFD,
	0x1CEB: 0xFFFD,
	0x1CEC: 0xFFFD,
	0x1CED: 0xFFFD,
	0x1CEE: 0xFFFD,
	0x1CEF: 0xFFFD,
	0x1CF0: 0xFFFD,
	0x1CF1: 0xFFFD,
	0x1CF2: 0xFFFD,
	0x1CF3: 0xFFFD,
	0x1CF4: 0xFFFD,
	0x1CF5: 0xFFFD,
	0x1CF6: 0xFFFD,
	0x1CF7: 0xFFFD,
	0x1CF8: 0xFFFD,
	0x1CF9: 0xFFFD,
	0x1CFA: 0xFFFD,
	0x1CFB: 0xFFFD,
	0x1CFC: 0xFFFD,
	0x1CFD: 0xFFFD,
	0x1CFE: 0xFFFD,
	0x1CFF: 0xFFFD,
	0x1D00: 0xFFFD,
	0x1D01: 0xFFFD,
	0x1D02: 0xFFFD,
	0x1D03: 0xFFFD,
	0x1D04: 0xFFFD,
	0x1D05: 0xFFFD,
	0x1D06: 0xFFFD,
	0x1D07: 0xFFFD,
	0x1D08: 0xFFFD,
	0x1D09: 0xFFFD,
	0x1D0A: 0xFFFD,
	0x1D0B: 0xFFFD,
	0x1D0C: 0xFFFD,
	0x1D0D: 0xFFFD,
	0x1D0E: 0xFFFD,
	0x1D0F: 0xFFFD,
	0x1D10: 0xFFFD,
	0x1D11: 0xFFFD,
	0x1D12: 0xFFFD,
	0x1D13: 0xFFFD,
	0x1D14: 0xFFFD,
	0x1D15: 0xFFFD,
	0x1D16: 0xFFFD,
	0x1D17: 0xFFFD,
	0x1D18: 0xFFFD,
	0x1D19: 0xFFFD,
	0x1D1A: 0xFFFD,
	0x1D1B: 0xFFFD,
	0x1D1C: 0xFFFD,
	0x1D1D: 0xFFFD,
	0x1D1E: 0xFFFD,
	0x1D1F: 0xFFFD,
	0x1D20: 0xFFFD,
	0x1D21: 0xFFFD,
	0x1D22: 0xFFFD,
	0x1D23: 0xFFFD,
	0x1D24: 0xFFFD,
	0x1D25: 0xFFFD,
	0x1D26: 0xFFFD,
	0x1D27: 0xFFFD,
	0x1D28: 0xFFFD,
	0x1D29: 0xFFFD,
	0x1D2A: 0xFFFD,
	0x1D2B: 0xFFFD,
	0x1D2C: 0xFFFD,
	0x1D2D: 0xFFFD,
	0x1D2E: 0xFFFD,
	0x1D2F: 0xFFFD,
	0x1D30: 0xFFFD,
	0x1D31: 0xFFFD,
	0x1D32: 0xFFFD,
	0x1D33: 0xFFFD,
	0x1D34: 0xFFFD,
	0x1D35: 0xFFFD,
	0x1D36: 0xFFFD,
	0x1D37: 0xFFFD,
	0x1D38: 0xFFFD,
	0x1D39: 0xFFFD,
	0x1D3A: 0xFFFD,
	0x1D3B: 0xFFFD,
	0x1D3C: 0xFFFD,
	0x1D3D: 0xFFFD,
	0x1D3E: 0xFFFD,
	0x1D3F: 0xFFFD,
	0x1D40: 0xFFFD,
	0x1D41: 0xFFFD,
	0x1D42: 0xFFFD,
	0x1D43: 0xFFFD,
	0x1D44: 0xFFFD,
	0x1D45: 0xFFFD,
	0x1D46: 0xFFFD,
	0x1D47: 0xFFFD,
	0x1D48: 0xFFFD,
	0x1D49: 0xFFFD,
	0x1D4A: 0xFFFD,
	0x1D4B: 0xFFFD,
	0x1D4C: 0xFFFD,
	0x1D4D: 0xFFFD,
	0x1D4E: 0xFFFD,
	0x1D4F: 0xFFFD,
	0x1D50: 0xFFFD,
	0x1D51: 0xFFFD,
	0x1D52: 0xFFFD,
	0x1D53: 0xFFFD,
	0x1D54: 0xFFFD,
	0x1D55: 0xFFFD,
	0x1D56: 0xFFFD,
	0x1D57: 0xFFFD,
	0x1D58: 0xFFFD,
	0x1D59: 0xFFFD,
	0x1D5A: 0xFFFD,
	0x1D5B: 0xFFFD,
	0x1D5C: 0xFFFD,
	0x1D5D: 0xFFFD,
	0x1D5E: 0xFFFD,
	0x1D5F: 0xFFFD,
	0x1D60: 0xFFFD,
	0x1D61: 0xFFFD,
	0x1D62: 0xFFFD,
	0x1D63: 0xFFFD,
	0x1D64: 0xFFFD,
	0x1D65: 0xFFFD,
	0x1D66: 0xFFFD,
	0x1D67: 0xFFFD,
	0x1D68: 0xFFFD,
	0x1D69: 0xFFFD,
	0x1D6A: 0xFFFD,
	0x1D6B: 0xFFFD,
	0x1D6C: 0xFFFD,
	0x1D6D: 0xFFFD,
	0x1D6E: 0xFFFD,
	0x1D6F: 0xFFFD,
	0x1D70: 0xFFFD,
	0x1D71: 0xFFFD,
	0x1D72: 0xFFFD,
	0x1D73: 0xFFFD,
	0x1D74: 0xFFFD,
	0x1D75: 0xFFFD,
	0x1D76: 0xFFFD,
	0x1D77: 0xFFFD,
	0x1D78: 0xFFFD,
	0x1D79: 0xFFFD,
	0x1D7A: 0xFFFD,
	0x1D7B: 0xFFFD,
	0x1D7C: 0xFFFD,
	0x1D7D: 0xFFFD,
	0x1D7E: 0xFFFD,
	0x1D7F: 0xFFFD,
	0x1D80: 0xFFFD,
	0x1D81: 0xFFFD,
	0x1D82: 0xFFFD,
	0x1D83: 0xFFFD,
	0x1D84: 0xFFFD,
	0x1D85: 0xFFFD,
	0x1D86: 0xFFFD,
	0x1D87: 0xFFFD,
	0x1D88: 0xFFFD,
	0x1D89: 0xFFFD,
	0x1D8A: 0xFFFD,
	0x1D8B: 0xFFFD,
	0x1D8C: 0xFFFD,
	0x1D8D: 0xFFFD,
	0x1D8E: 0xFFFD,
	0x1D8F: 0xFFFD,
	0x1D90: 0xFFFD,
	0x1D91: 0xFFFD,
	0x1D92: 0xFFFD,
	0x1D93: 0xFFFD,
	0x1D94: 0xFFFD,
	0x1D95: 0xFFFD,
	0x1D96: 0xFFFD,
	0x1D97: 0xFFFD,
	0x1D98: 0xFFFD,
	0x1D99: 0xFFFD,
	0x1D9A: 0xFFFD,
	0x1D9B: 0xFFFD,
	0x1D9C: 0xFFFD,
	0x1D9D: 0xFFFD,
	0x1D9E: 0xFFFD,
	0x1D9F: 0xFFFD,
	0x1DA0: 0xFFFD,
	0x1DA1: 0xFFFD,
	0x1DA2: 0xFFFD,
	0x1DA3: 0xFFFD,
	0x1DA4: 0xFFFD,
	0x1DA5: 0xFFFD,
	0x1DA6: 0xFFFD,
	0x1DA7: 0xFFFD,
	0x1DA8: 0xFFFD,
	0x1DA9: 0xFFFD,
	0x1DAA: 0xFFFD,
	0x1DAB: 0xFFFD,
	0x1DAC: 0xFFFD,
	0x1DAD: 0xFFFD,
	0x1DAE: 0xFFFD,
	0x1DAF: 0xFFFD,
	0x1DB0: 0xFFFD,
	0x1DB1: 0xFFFD,
	0x1DB2: 0xFFFD,
	0x1DB3: 0xFFFD,
	0x1DB4: 0xFFFD,
	0x1DB5: 0xFFFD,
	0x1DB6: 0xFFFD,
	0x1DB7: 0xFFFD,
	0x1DB8: 0xFFFD,
	0x1DB9: 0xFFFD,
	0x1DBA: 0xFFFD,
	0x1DBB: 0xFFFD,
	0x1DBC: 0xFFFD,
	0x1DBD: 0xFFFD,
	0x1DBE: 0xFFFD,
	0x1DBF: 0xFFFD,
	0x1DC0: 0xFFFD,
	0x1DC1: 0xFFFD,
	0x1DC2: 0xFFFD,
	0x1DC3: 0xFFFD,
	0x1DC4: 0xFFFD,
	0x1DC5: 0xFFFD,
	0x1DC6: 0xFFFD,
	0x1DC7: 0xFFFD,
	0x1DC8: 0xFFFD,
	0x1DC9: 0xFFFD,
	0x1DCA: 0xFFFD,
	0x1DCB: 0xFFFD,
	0x1DCC: 0xFFFD,
	0x1DCD: 0xFFFD,
	0x1DCE: 0xFFFD,
	0x1DCF: 0xFFFD,
	0x1DD0: 0xFFFD,
	0x1DD1: 0xFFFD,
	0x1DD2: 0xFFFD,
	0x1DD3: 0xFFFD,
	0x1DD4: 0xFFFD,
	0x1DD5: 0xFFFD,
	0x1DD6: 0xFFFD,
	0x1DD7: 0xFFFD,
	0x1DD8: 0xFFFD,
	0x1DD9: 0xFFFD,
	0x1DDA: 0xFFFD,
	0x1DDB: 0xFFFD,
	0x1DDC: 0xFFFD,
	0x1DDD: 0xFFFD,
	0x1DDE: 0xFFFD,
	0x1DDF: 0xFFFD,
	0x1DE0: 0xFFFD,
	0x1DE1: 0xFFFD,
	0x1DE2: 0xFFFD,
	0x1DE3: 0xFFFD,
	0x1DE4: 0xFFFD,
	0x1DE5: 0xFFFD,
	0x1DE6: 0xFFFD,
	0x1DE7: 0xFFFD,
	0x1DE8: 0xFFFD,
	0x1DE9: 0xFFFD,
	0x1DEA: 0xFFFD,
	0x1DEB: 0xFFFD,
	0x1DEC: 0xFFFD,
	0x1DED: 0xFFFD,
	0x1DEE: 0xFFFD,
	0x1DEF: 0xFFFD,
	0x1DF0: 0xFFFD,
	0x1DF1: 0xFFFD,
	0x1DF2: 0xFFFD,
	0x1DF3: 0xFFFD,
	0x1DF4: 0xFFFD,
	0x1DF5: 0xFFFD,
	0x1DF6: 0xFFFD,
	0x1DF7: 0xFFFD,
	0x1DF8: 0xFFFD,
	0x1DF9: 0xFFFD,
	0x1DFA: 0xFFFD,
	0x1DFB: 0xFFFD,
	0x1DFC: 0xFFFD,
	0x1DFD: 0xFFFD,
	0x1DFE: 0xFFFD,
	0x1DFF: 0xFFFD,
	0x1E00: 0xFFFD,
	0x1E01: 0xFFFD,
	0x1E02: 0xFFFD,
	0x1E03: 0xFFFD,
	0x1E04: 0xFFFD,
	0x1E05: 0xFFFD,
	0x1E06: 0xFFFD,
	0x1E07: 0xFFFD,
	0x1E08: 0xFFFD,
	0x1E09: 0xFFFD,
	0x1E0A: 0xFFFD,
	0x1E0B: 0xFFFD,
	0x1E0C: 0xFFFD,
	0x1E0D: 0xFFFD,
	0x1E0E: 0xFFFD,
	0x1E0F: 0xFFFD,
	0x1E10: 0xFFFD,
	0x1E11: 0xFFFD,
	0x1E12: 0xFFFD,
	0x1E13: 0xFFFD,
	0x1E14: 0xFFFD,
	0x1E15: 0xFFFD,
	0x1E16: 0xFFFD,
	0x1E17: 0xFFFD,
	0x1E18: 0xFFFD,
	0x1E19: 0xFFFD,
	0x1E1A: 0xFFFD,
	0x1E1B: 0xFFFD,
	0x1E1C: 0xFFFD,
	0x1E1D: 0xFFFD,
	0x1E1E: 0xFFFD,
	0x1E1F: 0xFFFD,
	0x1E20: 0xFFFD,
	0x1E21: 0xFFFD,
	0x1E22: 0xFFFD,
	0x1E23: 0xFFFD,
	0x1E24: 0xFFFD,
	0x1E25: 0xFFFD,
	0x1E26: 0xFFFD,
	0x1E27: 0xFFFD,
	0x1E28: 0xFFFD,
	0x1E29: 0xFFFD,
	0x1E2A: 0xFFFD,
	0x1E2B: 0xFFFD,
	0x1E2C: 0xFFFD,
	0x1E2D: 0xFFFD,
	0x1E2E: 0xFFFD,
	0x1E2F: 0xFFFD,
	0x1E30: 0xFFFD,
	0x1E31: 0xFFFD,
	0x1E32: 0xFFFD,
	0x1E33: 0xFFFD,
	0x1E34: 0xFFFD,
	0x1E35: 0xFFFD,
	0x1E36: 0xFFFD,
	0x1E37: 0xFFFD,
	0x1E38: 0xFFFD,
	0x1E39: 0xFFFD,
	0x1E3A: 0xFFFD,
	0x1E3B: 0x9BD6,
	0x1E3C: 0xFFFD,
	0x1E3D: 0xFFFD,
	0x1E3E: 0xFFFD,
	0x1E3F: 0xFFFD,
	0x1E40: 0xFFFD,
	0x1E41: 0xFFFD,
	0x1E42: 0xFFFD,
	0x1E43: 0x9BD3,
	0x1E44: 0xFFFD,
	0x1E45: 0xFFFD,
	0x1E46: 0xFFFD,
	0x1E47: 0xFFFD,
	0x1E48: 0xFFFD,
	0x1E49: 0x9BD4,
	0x1E4A: 0xFFFD,
	0x1E4B: 0xFFFD,
	0x1E4C: 0xFFFD,
	0x1E4D: 0xFFFD,
	0x1E4E: 0xFFFD,
	0x1E4F: 0xFFFD,
	0x1E50: 0xFFFD,
	0x1E51: 0xFFFD,
	0x1E52: 0xFFFD,
	0x1E53: 0xFFFD,
	0x1E54: 0xFFFD,
	0x1E55: 0xFFFD,
	0x1E56: 0xFFFD,
	0x1E57: 0xFFFD,
	0x1E58: 0xFFFD,
	0x1E59: 0xFFFD,
	0x1E5A: 0xFFFD,
	0x1E5B: 0xFFFD,
	0x1E5C: 0xFFFD,
	0x1E5D: 0xFFFD,
	0x1E5E: 0xFFFD,
	0x1E5F: 0xFFFD,
	0x1E60: 0xFFFD,
	0x1E61: 0xFFFD,
	0x1E62: 0xFFFD,
	0x1E63: 0xFFFD,
	0x1E64: 0xFFFD,
	0x1E65: 0xFFFD,
	0x1E66: 0xFFFD,
	0x1E67: 0xFFFD,
	0x1E68: 0xFFFD,
	0x1E69: 0xFFFD,
	0x1E6A: 0xFFFD,
	0x1E6B: 0xFFFD,
	0x1E6C: 0xFFFD,
	0x1E6D: 0xFFFD,
	0x1E6E: 0xFFFD,
	0x1E6F: 0xFFFD,
	0x1E70: 0xFFFD,
	0x1E71: 0xFFFD,
	0x1E72: 0xFFFD,
	0x1E73: 0xFFFD,
	0x1E74: 0xFFFD,
	0x1E75: 0xFFFD,
	0x1E76: 0xFFFD,
	0x1E77: 0xFFFD,
	0x1E78: 0xFFFD,
	0x1E79: 0xFFFD,
	0x1E7A: 0xFFFD,
	0x1E7B: 0xFFFD,
	0x1E7C: 0xFFFD,
	0x1E7D: 0xFFFD,
	0x1E7E: 0xFFFD,
	0x1E7F: 0xFFFD,
	0x1E80: 0xFFFD,
	0x1E81: 0xFFFD,
	0x1E82: 0xFFFD,
	0x1E83: 0xFFFD,
	0x1E84: 0xFFFD,
	0x1E85: 0xFFFD,
	0x1E86: 0xFFFD,
	0x1E87: 0xFFFD,
	0x1E88: 0xFFFD,
	0x1E89: 0xFFFD,
	0x1E8A: 0xFFFD,
	0x1E8B: 0xFFFD,
	0x1E8C: 0xFFFD,
	0x1E8D: 0xFFFD,
	0x1E8E: 0xFFFD,
	0x1E8F: 0xFFFD,
	0x1E90: 0xFFFD,
	0x1E91: 0xFFFD,
	0x1E92: 0xFFFD,
	0x1E93: 0xFFFD,
	0x1E94: 0xFFFD,
	0x1E95: 0xFFFD,
	0x1E96: 0xFFFD,
	0x1E97: 0xFFFD,
	0x1E98: 0xFFFD,
	0x1E99: 0xFFFD,
	0x1E9A: 0xFFFD,
	0x1E9B: 0xFFFD,
	0x1E9C: 0xFFFD,
	0x1E9D: 0xFFFD,
	0x1E9E: 0xFFFD,
	0x1E9F: 0xFFFD,
	0x1EA0: 0xFFFD,
	0x1EA1: 0xFFFD,
	0x1EA2: 0xFFFD,
	0x1EA3: 0xFFFD,
	0x1EA4: 0xFFFD,
	0x1EA5: 0xFFFD,
	0x1EA6: 0xFFFD,
	0x1EA7: 0xFFFD,
	0x1EA8: 0xFFFD,
	0x1EA9: 0xFFFD,
	0x1EAA: 0xFFFD,
	0x1EAB: 0xFFFD,
	0x1EAC: 0xFFFD,
	0x1EAD: 0xFFFD,
	0x1EAE: 0xFFFD,
	0x1EAF: 0xFFFD,
	0x1EB0: 0xFFFD,
	0x1EB1: 0xFFFD,
	0x1EB2: 0xFFFD,
	0x1EB3: 0xFFFD,
	0x1EB4: 0xFFFD,
	0x1EB5: 0xFFFD,
	0x1EB6: 0xFFFD,
	0x1EB7: 0xFFFD,
	0x1EB8: 0xFFFD,
	0x1EB9: 0xFFFD,
	0x1EBA: 0xFFFD,
	0x1EBB: 0xFFFD,
	0x1EBC: 0xFFFD,
	0x1EBD: 0xFFFD,
	0x1EBE: 0xFFFD,
	0x1EBF: 0xFFFD,
	0x1EC0: 0xFFFD,
	0x1EC1: 0xFFFD,
	0x1EC2: 0xFFFD,
	0x1EC3: 0xFFFD,
	0x1EC4: 0xFFFD,
	0x1EC5: 0xFFFD,
	0x1EC6: 0xFFFD,
	0x1EC7: 0xFFFD,
	0x1EC8: 0xFFFD,
	0x1EC9: 0xFFFD,
	0x1ECA: 0xFFFD,
	0x1ECB: 0xFFFD,
	0x1ECC: 0xFFFD,
	0x1ECD: 0xFFFD,
	0x1ECE: 0xFFFD,
	0x1ECF: 0xFFFD,
	0x1ED0: 0xFFFD,
	0x1ED1: 0xFFFD,
	0x1ED2: 0xFFFD,
	0x1ED3: 0xFFFD,
	0x1ED4: 0xFFFD,
	0x1ED5: 0xFFFD,
	0x1ED6: 0xFFFD,
	0x1ED7: 0xFFFD,
	0x1ED8: 0xFFFD,
	0x1ED9: 0xFFFD,
	0x1EDA: 0xFFFD,
	0x1EDB: 0xFFFD,
	0x1EDC: 0xFFFD,
	0x1EDD: 0xFFFD,
	0x1EDE: 0xFFFD,
	0x1EDF: 0xFFFD,
	0x1EE0: 0xFFFD,
	0x1EE1: 0xFFFD,
	0x1EE2: 0xFFFD,
	0x1EE3: 0xFFFD,
	0x1EE4: 0xFFFD,
	0x1EE5: 0xFFFD,
	0x1EE6: 0xFFFD,
	0x1EE7: 0xFFFD,
	0x1EE8: 0xFFFD,
	0x1EE9: 0xFFFD,
	0x1EEA: 0xFFFD,
	0x1EEB: 0xFFFD,
	0x1EEC: 0xFFFD,
	0x1EED: 0xFFFD,
	0x1EEE: 0xFFFD,
	0x1EEF: 0xFFFD,
	0x1EF0: 0xFFFD,
	0x1EF1: 0xFFFD,
	0x1EF2: 0xA0DB,
	0x1EF3: 0xA0EB,
	0x1EF4: 0xFFFD,
	0x1EF5: 0xFFFD,
	0x1EF6: 0xFFFD,
	0x1EF7: 0xFFFD,
	0x1EF8: 0xFFFD,
	0x1EF9: 0xFFFD,
	0x1EFA: 0xFFFD,
	0x1EFB: 0xFFFD,
	0x1EFC: 0xFFFD,
	0x1EFD: 0xFFFD,
	0x1EFE: 0xFFFD,
	0x1EFF: 0xFFFD,
	0x1F00: 0xFFFD,
	0x1F01: 0xFFFD,
	0x1F02: 0xFFFD,
	0x1F03: 0xFFFD,
	0x1F04: 0xFFFD,
	0x1F05: 0xFFFD,
	0x1F06: 0xFFFD,
	0x1F07: 0xFFFD,
	0x1F08: 0xFFFD,
	0x1F09: 0xFFFD,
	0x1F0A: 0xFFFD,
	0x1F0B: 0xFFFD,
	0x1F0C: 0xFFFD,
	0x1F0D: 0xFFFD,
	0x1F0E: 0xFFFD,
	0x1F0F: 0xFFFD,
	0x1F10: 0xFFFD,
	0x1F11: 0xFFFD,
	0x1F12: 0xFFFD,
	0x1F13: 0xFFFD,
	0x1F14: 0xFFFD,
	0x1F15: 0xFFFD,
	0x1F16: 0xFFFD,
	0x1F17: 0xFFFD,
	0x1F18: 0xFFFD,
	0x1F19: 0xFFFD,
	0x1F1A: 0xFFFD,
	0x1F1B: 0xFFFD,
	0x1F1C: 0xFFFD,
	0x1F1D: 0xFFFD,
	0x1F1E: 0xFFFD,
	0x1F1F: 0xFFFD,
	0x1F20: 0xFFFD,
	0x1F21: 0xFFFD,
	0x1F22: 0xFFFD,
	0x1F23: 0xFFFD,
	0x1F24: 0xFFFD,
	0x1F25: 0xFFFD,
	0x1F26: 0xFFFD,
	0x1F27: 0xFFFD,
	0x1F28: 0xFFFD,
	0x1F29: 0xFFFD,
	0x1F2A: 0xFFFD,
	0x1F2B: 0xFFFD,
	0x1F2C: 0xFFFD,
	0x1F2D: 0xFFFD,
	0x1F2E: 0xFFFD,
	0x1F2F: 0xFFFD,
	0x1F30: 0xFFFD,
	0x1F31: 0xFFFD,
	0x1F32: 0xFFFD,
	0x1F33: 0xFFFD,
	0x1F34: 0xFFFD,
	0x1F35: 0xFFFD,
	0x1F36: 0xFFFD,
	0x1F37: 0xFFFD,
	0x1F38: 0xFFFD,
	0x1F39: 0xFFFD,
	0x1F3A: 0xFFFD,
	0x1F3B: 0xFFFD,
	0x1F3C: 0xFFFD,
	0x1F3D: 0xFFFD,
	0x1F3E: 0xFFFD,
	0x1F3F: 0xFFFD,
	0x1F40: 0xFFFD,
	0x1F41: 0xFFFD,
	0x1F42: 0xFFFD,
	0x1F43: 0xFFFD,
	0x1F44: 0xFFFD,
	0x1F45: 0xFFFD,
	0x1F46: 0xFFFD,
	0x1F47: 0xFFFD,
	0x1F48: 0xFFFD,
	0x1F49: 0xFFFD,
	0x1F4A: 0xFFFD,
	0x1F4B: 0xFFFD,
	0x1F4C: 0xFFFD,
	0x1F4D: 0xFFFD,
	0x1F4E: 0xFFFD,
	0x1F4F: 0xFFFD,
	0x1F50: 0xFFFD,
	0x1F51: 0xFFFD,
	0x1F52: 0xFFFD,
	0x1F53: 0xFFFD,
	0x1F54: 0xFFFD,
	0x1F55: 0xFFFD,
	0x1F56: 0xFFFD,
	0x1F57: 0xFFFD,
	0x1F58: 0xFFFD,
	0x1F59: 0xFFFD,
	0x1F5A: 0xFFFD,
	0x1F5B: 0xFFFD,
	0x1F5C: 0xFFFD,
	0x1F5D: 0xFFFD,
	0x1F5E: 0xFFFD,
	0x1F5F: 0xFFFD,
	0x1F60: 0xFFFD,
	0x1F61: 0xFFFD,
	0x1F62: 0xFFFD,
	0x1F63: 0xFFFD,
	0x1F64: 0xFFFD,
	0x1F65: 0xFFFD,
	0x1F66: 0xFFFD,
	0x1F67: 0xFFFD,
	0x1F68: 0xFFFD,
	0x1F69: 0xFFFD,
	0x1F6A: 0xFFFD,
	0x1F6B: 0xFFFD,
	0x1F6C: 0xFFFD,
	0x1F6D: 0xFFFD,
	0x1F6E: 0xFFFD,
	0x1F6F: 0xFFFD,
	0x1F70: 0xFFFD,
	0x1F71: 0xFFFD,
	0x1F72: 0xFFFD,
	0x1F73: 0xFFFD,
	0x1F74: 0xFFFD,
	0x1F75: 0xFFFD,
	0x1F76: 0xFFFD,
	0x1F77: 0xFFFD,
	0x1F78: 0xFFFD,
	0x1F79: 0xFFFD,
	0x1F7A: 0xFFFD,
	0x1F7B: 0xFFFD,
	0x1F7C: 0xFFFD,
	0x1F7D: 0xFFFD,
	0x1F7E: 0xFFFD,
	0x1F7F: 0xFFFD,
	0x1F80: 0xFFFD,
	0x1F81: 0xFFFD,
	0x1F82: 0xFFFD,
	0x1F83: 0xFFFD,
	0x1F84: 0xFFFD,
	0x1F85: 0xFFFD,
	0x1F86: 0xFFFD,
	0x1F87: 0xFFFD,
	0x1F88: 0xFFFD,
	0x1F89: 0xFFFD,
	0x1F8A: 0xFFFD,
	0x1F8B: 0xFFFD,
	0x1F8C: 0xFFFD,
	0x1F8D: 0xFFFD,
	0x1F8E: 0xFFFD,
	0x1F8F: 0xFFFD,
	0x1F90: 0xFFFD,
	0x1F91: 0xFFFD,
	0x1F92: 0xFFFD,
	0x1F93: 0xFFFD,
	0x1F94: 0xFFFD,
	0x1F95: 0xFFFD,
	0x1F96: 0xFFFD,
	0x1F97: 0xFFFD,
	0x1F98: 0xFFFD,
	0x1F99: 0xFFFD,
	0x1F9A: 0xFFFD,
	0x1F9B: 0xFFFD,
	0x1F9C: 0xFFFD,
	0x1F9D: 0xFFFD,
	0x1F9E: 0xFFFD,
	0x1F9F: 0xFFFD,
	0x1FA0: 0xFFFD,
	0x1FA1: 0xFFFD,
	0x1FA2: 0xFFFD,
	0x1FA3: 0xFFFD,
	0x1FA4: 0xFFFD,
	0x1FA5: 0xFFFD,
	0x1FA6: 0xFFFD,
	0x1FA7: 0xFFFD,
	0x1FA8: 0xFFFD,
	0x1FA9: 0xFFFD,
	0x1FAA: 0xFFFD,
	0x1FAB: 0xFFFD,
	0x1FAC: 0xFFFD,
	0x1FAD: 0xFFFD,
	0x1FAE: 0xFFFD,
	0x1FAF: 0xFFFD,
	0x1FB0: 0xFFFD,
	0x1FB1: 0xFFFD,
	0x1FB2: 0xFFFD,
	0x1FB3: 0xFFFD,
	0x1FB4: 0xFFFD,
	0x1FB5: 0xFFFD,
	0x1FB6: 0xFFFD,
	0x1FB7: 0xFFFD,
	0x1FB8: 0xFFFD,
	0x1FB9: 0xFFFD,
	0x1FBA: 0xFFFD,
	0x1FBB: 0xFFFD,
	0x1FBC: 0xFFFD,
	0x1FBD: 0xFFFD,
	0x1FBE: 0xFFFD,
	0x1FBF: 0xFFFD,
	0x1FC0: 0xFFFD,
	0x1FC1: 0xFFFD,
	0x1FC2: 0xFFFD,
	0x1FC3: 0xFFFD,
	0x1FC4: 0xFFFD,
	0x1FC5: 0xFFFD,
	0x1FC6: 0xFFFD,
	0x1FC7: 0xFFFD,
	0x1FC8: 0xFFFD,
	0x1FC9: 0xFFFD,
	0x1FCA: 0xFFFD,
	0x1FCB: 0xFFFD,
	0x1FCC: 0xFFFD,
	0x1FCD: 0xFFFD,
	0x1FCE: 0xFFFD,
	0x1FCF: 0xFFFD,
	0x1FD0: 0xFFFD,
	0x1FD1: 0xFFFD,
	0x1FD2: 0xFFFD,
	0x1FD3: 0xFFFD,
	0x1FD4: 0xFFFD,
	0x1FD5: 0xFFFD,
	0x1FD6: 0xFFFD,
	0x1FD7: 0xFFFD,
	0x1FD8: 0xFFFD,
	0x1FD9: 0xFFFD,
	0x1FDA: 0xFFFD,
	0x1FDB: 0xFFFD,
	0x1FDC: 0xFFFD,
	0x1FDD: 0xFFFD,
	0x1FDE: 0xFFFD,
	0x1FDF: 0xFFFD,
	0x1FE0: 0xFFFD,
	0x1FE1: 0xFFFD,
	0x1FE2: 0xFFFD,
	0x1FE3: 0xFFFD,
	0x1FE4: 0xFFFD,
	0x1FE5: 0xFFFD,
	0x1FE6: 0xFFFD,
	0x1FE7: 0xFFFD,
	0x1FE8: 0xFFFD,
	0x1FE9: 0xFFFD,
	0x1FEA: 0xFFFD,
	0x1FEB: 0xFFFD,
	0x1FEC: 0xFFFD,
	0x1FED: 0xFFFD,
	0x1FEE: 0xFFFD,
	0x1FEF: 0xFFFD,
	0x1FF0: 0xFFFD,
	0x1FF1: 0xFFFD,
	0x1FF2: 0xFFFD,
	0x1FF3: 0xFFFD,
	0x1FF4: 0xFFFD,
	0x1FF5: 0xFFFD,
	0x1FF6: 0xFFFD,
	0x1FF7: 0xFFFD,
	0x1FF8: 0xFFFD,
	0x1FF9: 0xFFFD,
	0x1FFA: 0xFFFD,
	0x1FFB: 0xFFFD,
	0x1FFC: 0xFFFD,
	0x1FFD: 0xFFFD,
	0x1FFE: 0xFFFD,
	0x1FFF: 0xFFFD,
	0x2000: 0xFFFD,
	0x2001: 0xFFFD,
	0x2002: 0xFFFD,
	0x2003: 0xFFFD,
	0x2004: 0xFFFD,
	0x2005: 0xFFFD,
	0x2006: 0xFFFD,
	0x2007: 0xFFFD,
	0x2008: 0xFFFD,
	0x2009: 0xFFFD,
	0x200A: 0xFFFD,
	0x200B: 0xFFFD,
	0x200C: 0xFFFD,
	0x200D: 0xFFFD,
	0x200E: 0xFFFD,
	0x200F: 0xFFFD,
	0x2010: 0x9FEC,
	0x2011: 0xFFFD,
	0x2012: 0xFFFD,
	0x2013: 0xA156,
	0x2014: 0xA158,
	0x2015: 0xA277,
	0x2016: 0xA1FC,
	0x2017: 0xFFFD,
	0x2018: 0xA1A5,
	0x2019: 0xA1A6,
	0x201A: 0xFFFD,
	0x201B: 0xFFFD,
	0x201C: 0xA1A7,
	0x201D: 0xA1A8,
	0x201E: 0xFFFD,
	0x201F: 0xFFFD,
	0x2020: 0xA1CF,
	0x2021: 0x91DE,
	0x2022: 0xA145,
	0x2023: 0xFFFD,
	0x2024: 0xA3BB,
	0x2025: 0xA14C,
	0x2026: 0xA14B,
	0x2027: 0xA145,
	0x2028: 0xFFFD,
	0x2029: 0xFFFD,
	0x202A: 0xFFFD,
	0x202B: 0xFFFD,
	0x202C: 0xFFFD,
	0x202D: 0xFFFD,
	0x202E: 0xFFFD,
	0x202F: 0xFFFD,
	0x2030: 0xFEE2,
	0x2031: 0xFFFD,
	0x2032: 0xA1AC,
	0x2033: 0xA1B2,
	0x2034: 0xFFFD,
	0x2035: 0xA1AB,
	0x2036: 0xFFFD,
	0x2037: 0xFFFD,
	0x2038: 0xFFFD,
	0x2039: 0xFFFD,
	0x203A: 0xFFFD,
	0x203B: 0xA1B0,
	0x203C: 0x91F7,
	0x203D: 0xFFFD,
	0x203E: 0xA1C3,
	0x203F: 0xFFFD,
	0x2040: 0xFFFD,
	0x2041: 0xFFFD,
	0x2042: 0xFFFD,
	0x2043: 0xFFFD,
	0x2044: 0xFFFD,
	0x2045: 0xFFFD,
	0x2046: 0xFFFD,
	0x2047: 0xFFFD,
	0x2048: 0xFFFD,
	0x2049: 0xFFFD,
	0x204A: 0xFFFD,
	0x204B: 0xFFFD,
	0x204C: 0xFFFD,
	0x204D: 0xFFFD,
	0x204E: 0xFFFD,
	0x204F: 0xFFFD,
	0x2050: 0xFFFD,
	0x2051: 0xFFFD,
	0x2052: 0xFFFD,
	0x2053: 0xFFFD,
	0x2054: 0xFFFD,
	0x2055: 0xFFFD,
	0x2056: 0xFFFD,
	0x2057: 0xFFFD,
	0x2058: 0xFFFD,
	0x2059: 0xFFFD,
	0x205A: 0xFFFD,
	0x205B: 0xFFFD,
	0x205C: 0xFFFD,
	0x205D: 0xFFFD,
	0x205E: 0xFFFD,
	0x205F: 0xFFFD,
	0x2060: 0xFFFD,
	0x2061: 0xFFFD,
	0x2062: 0xFFFD,
	0x2063: 0xFFFD,
	0x2064: 0xFFFD,
	0x2065: 0xFFFD,
	0x2066: 0xFFFD,
	0x2067: 0xFFFD,
	0x2068: 0xFFFD,
	0x2069: 0xFFFD,
	0x206A: 0xFFFD,
	0x206B: 0xFFFD,
	0x206C: 0xFFFD,
	0x206D: 0xFFFD,
	0x206E: 0xFFFD,
	0x206F: 0xFFFD,
	0x2070: 0xFFFD,
	0x2071: 0xFFFD,
	0x2072: 0xFFFD,
	0x2073: 0xFFFD,
	0x2074: 0xFFFD,
	0x2075: 0xFFFD,
	0x2076: 0xFFFD,
	0x2077: 0xFFFD,
	0x2078: 0xFFFD,
	0x2079: 0xFFFD,
	0x207A: 0xFFFD,
	0x207B: 0xFFFD,
	0x207C: 0xFFFD,
	0x207D: 0xFFFD,
	0x207E: 0xFFFD,
	0x207F: 0xFFFD,
	0x2080: 0xFFFD,
	0x2081: 0xFFFD,
	0x2082: 0xFFFD,
	0x2083: 0xFFFD,
	0x2084: 0xFFFD,
	0x2085: 0xFFFD,
	0x2086: 0xFFFD,
	0x2087: 0xFFFD,
	0x2088: 0xFFFD,
	0x2089: 0xFFFD,
	0x208A: 0xFFFD,
	0x208B: 0xFFFD,
	0x208C: 0xFFFD,
	0x208D: 0xFFFD,
	0x208E: 0xFFFD,
	0x208F: 0xFFFD,
	0x2090: 0xFFFD,
	0x2091: 0xFFFD,
	0x2092: 0xFFFD,
	0x2093: 0xFFFD,
	0x2094: 0xFFFD,
	0x2095: 0xFFFD,
	0x2096: 0xFFFD,
	0x2097: 0xFFFD,
	0x2098: 0xFFFD,
	0x2099: 0xFFFD,
	0x209A: 0xFFFD,
	0x209B: 0xFFFD,
	0x209C: 0xFFFD,
	0x209D: 0xFFFD,
	0x209E: 0xFFFD,
	0x209F: 0xFFFD,
	0x20A0: 0xFFFD,
	0x20A1: 0xFFFD,
	0x20A2: 0xFFFD,
	0x20A3: 0xFFFD,
	0x20A4: 0xFFFD,
	0x20A5: 0xFFFD,
	0x20A6: 0xFFFD,
	0x20A7: 0xFFFD,
	0x20A8: 0xFFFD,
	0x20A9: 0xFFFD,
	0x20AA: 0xFFFD,
	0x20AB: 0xFFFD,
	0x20AC: 0xA3E1,
	0x20AD: 0xFFFD,
	0x20AE: 0xFFFD,
	0x20AF: 0xFFFD,
	0x20B0: 0xFFFD,
	0x20B1: 0xFFFD,
	0x20B2: 0xFFFD,
	0x20B3: 0xFFFD,
	0x20B4: 0xFFFD,
	0x20B5: 0xFFFD,
	0x20B6: 0xFFFD,
	0x20B7: 0xFFFD,
	0x20B8: 0xFFFD,
	0x20B9: 0xFFFD,
	0x20BA: 0xFFFD,
	0x20BB: 0xFFFD,
	0x20BC: 0xFFFD,
	0x20BD: 0xFFFD,
	0x20BE: 0xFFFD,
	0x20BF: 0xFFFD,
	0x20C0: 0xFFFD,
	0x20C1: 0xFFFD,
	0x20C2: 0xFFFD,
	0x20C3: 0xFFFD,
	0x20C4: 0xFFFD,
	0x20C5: 0xFFFD,
	0x20C6: 0xFFFD,
	0x20C7: 0xFFFD,
	0x20C8: 0xFFFD,
	0x20C9: 0xFFFD,
	0x20CA: 0xFFFD,
	0x20CB: 0xFFFD,
	0x20CC: 0xFFFD,
	0x20CD: 0xFFFD,
	0x20CE: 0xFFFD,
	0x20CF: 0xFFFD,
	0x20D0: 0xFFFD,
	0x20D1: 0xFFFD,
	0x20D2: 0xFFFD,
	0x20D3: 0xFFFD,
	0x20D4: 0xFFFD,
	0x20D5: 0xFFFD,
	0x20D6: 0xFFFD,
	0x20D7: 0xFFFD,
	0x20D8: 0xFFFD,
	0x20D9: 0xFFFD,
	0x20DA: 0xFFFD,
	0x20DB: 0xFFFD,
	0x20DC: 0xFFFD,
	0x20DD: 0xFFFD,
	0x20DE: 0xFFFD,
	0x20DF: 0xFFFD,
	0x20E0: 0xFFFD,
	0x20E1: 0xFFFD,
	0x20E2: 0xFFFD,
	0x20E3: 0xFFFD,
	0x20E4: 0xFFFD,
	0x20E5: 0xFFFD,
	0x20E6: 0xFFFD,
	0x20E7: 0xFFFD,
	0x20E8: 0xFFFD,
	0x20E9: 0xFFFD,
	0x20EA: 0xFFFD,
	0x20EB: 0xFFFD,
	0x20EC: 0xFFFD,
	0x20ED: 0xFFFD,
	0x20EE: 0xFFFD,
	0x20EF: 0xFFFD,
	0x20F0: 0xFFFD,
	0x20F1: 0xFFFD,
	0x20F2: 0xFFFD,
	0x20F3: 0xFFFD,
	0x20F4: 0xFFFD,
	0x20F5: 0xFFFD,
	0x20F6: 0xFFFD,
	0x20F7: 0xFFFD,
	0x20F8: 0xFFFD,
	0x20F9: 0xFFFD,
	0x20FA: 0xFFFD,
	0x20FB: 0xFFFD,
	0x20FC: 0xFFFD,
	0x20FD: 0xFFFD,
	0x20FE: 0xFFFD,
	0x20FF: 0xFFFD,
	0x2100: 0xFFFD,
	0x2101: 0xFFFD,
	0x2102: 0xFFFD,
	0x2103: 0xA24A,
	0x2104: 0xFFFD,
	0x2105: 0xA1C1,
	0x2106: 0xFFFD,
	0x2107: 0xFFFD,
	0x2108: 0xFFFD,
	0x2109: 0xA24B,
	0x210A: 0xFFFD,
	0x210B: 0xFFFD,
	0x210C: 0xFFFD,
	0x210D: 0xFFFD,
	0x210E: 0xFFFD,
	0x210F: 0xFFFD,
	0x2110: 0xFFFD,
	0x2111: 0xFFFD,
	0x2112: 0xFFFD,
	0x2113: 0xFFFD,
	0x2114: 0xFFFD,
	0x2115: 0xFFFD,
	0x2116: 0x9DCF,
	0x2117: 0xFFFD,
	0x2118: 0xFFFD,
	0x2119: 0xFFFD,
	0x211A: 0xFFFD,
	0x211B: 0xFFFD,
	0x211C: 0xFFFD,
	0x211D: 0xFFFD,
	0x211E: 0x9DE2,
	0x211F: 0xFFFD,
	0x2120: 0xFFFD,
	0x2121: 0x9DC9,
	0x2122: 0x97FC,
	0x2123: 0xFFFD,
	0x2124: 0xFFFD,
	0x2125: 0xFFFD,
	0x2126: 0xFFFD,
	0x2127: 0xFFFD,
	0x2128: 0xFFFD,
	0x2129: 0xFFFD,
	0x212A: 0xFFFD,
	0x212B: 0x9652,
	0x212C: 0xFFFD,
	0x212D: 0xFFFD,
	0x212E: 0xFFFD,
	0x212F: 0xFFFD,
	0x2130: 0xFFFD,
	0x2131: 0xFFFD,
	0x2132: 0xFFFD,
	0x2133: 0xFFFD,
	0x2134: 0xFFFD,
	0x2135: 0xFFFD,
	0x2136: 0xFFFD,
	0x2137: 0xFFFD,
	0x2138: 0xFFFD,
	0x2139: 0xFFFD,
	0x213A: 0xFFFD,
	0x213B: 0x9DC8,
	0x213C: 0xFFFD,
	0x213D: 0xFFFD,
	0x213E: 0xFFFD,
	0x213F: 0xFFFD,
	0x2140: 0xFFFD,
	0x2141: 0xFFFD,
	0x2142: 0xFFFD,
	0x2143: 0xFFFD,
	0x2144: 0xFFFD,
	0x2145: 0xFFFD,
	0x2146: 0xFFFD,
	0x2147: 0xFFFD,
	0x2148: 0xFFFD,
	0x2149: 0xFFFD,
	0x214A: 0xFFFD,
	0x214B: 0xFFFD,
	0x214C: 0xFFFD,
	0x214D: 0xFFFD,
	0x214E: 0xFFFD,
	0x214F: 0xFFFD,
	0x2150: 0xFFFD,
	0x2151: 0xFFFD,
	0x2152: 0xFFFD,
	0x2153: 0xFEB1,
	0x2154: 0xFEB2,
	0x2155: 0xFEB5,
	0x2156: 0xFEB6,
	0x2157: 0xFEB7,
	0x2158: 0xFEB8,
	0x2159: 0xFEB9,
	0x215A: 0xFEBA,
	0x215B: 0xFEC1,
	0x215C: 0xFEC2,
	0x215D: 0xFEC3,
	0x215E: 0xFEC4,
	0x215F: 0xFFFD,
	0x2160: 0xA2B9,
	0x2161: 0xA2BA,
	0x2162: 0xA2BB,
	0x2163: 0xA2BC,
	0x2164: 0xA2BD,
	0x2165: 0xA2BE,
	0x2166: 0xA2BF,
	0x2167: 0xA2C0,
	0x2168: 0xA2C1,
	0x2169: 0xA2C2,
	0x216A: 0xFFFD,
	0x216B: 0xFFFD,
	0x216C: 0xFFFD,
	0x216D: 0xFFFD,
	0x216E: 0xFFFD,
	0x216F: 0xFFFD,
	0x2170: 0xC6B5,
	0x2171: 0xC6B6,
	0x2172: 0xC6B7,
	0x2173: 0xC6B8,
	0x2174: 0xC6B9,
	0x2175: 0xC6BA,
	0x2176: 0xC6BB,
	0x2177: 0xC6BC,
	0x2178: 0xC6BD,
	0x2179: 0xC6BE,
	0x217A: 0xFFFD,
	0x217B: 0xFFFD,
	0x217C: 0xFFFD,
	0x217D: 0xFFFD,
	0x217E: 0xFFFD,
	0x217F: 0xFFFD,
	0x2180: 0xFFFD,
	0x2181: 0xFFFD,
	0x2182: 0xFFFD,
	0x2183: 0xFFFD,
	0x2184: 0xFFFD,
	0x2185: 0xFFFD,
	0x2186: 0xFFFD,
	0x2187: 0xFFFD,
	0x2188: 0xFFFD,
	0x2189: 0xFFFD,
	0x218A: 0xFFFD,
	0x218B: 0xFFFD,
	0x218C: 0xFFFD,
	0x218D: 0xFFFD,
	0x218E: 0xFFFD,
	0x218F: 0xFFFD,
	0x2190: 0xA1F6,
	0x2191: 0xA1F4,
	0x2192: 0xA1F7,
	0x2193: 0xA1F5,
	0x2194: 0x91FB,
	0x2195: 0x91F6,
	0x2196: 0xA1F8,
	0x2197: 0xA1F9,
	0x2198: 0xA1FB,
	0x2199: 0xA1FA,
	0x219A: 0xFFFD,
	0x219B: 0xFFFD,
	0x219C: 0xFFFD,
	0x219D: 0xFFFD,
	0x219E: 0xFFFD,
	0x219F: 0xFFFD,
	0x21A0: 0xFFFD,
	0x21A1: 0xFFFD,
	0x21A2: 0xFFFD,
	0x21A3: 0xFFFD,
	0x21A4: 0xFFFD,
	0x21A5: 0xFFFD,
	0x21A6: 0xFFFD,
	0x21A7: 0xFFFD,
	0x21A8: 0x91FA,
	0x21A9: 0xFFFD,
	0x21AA: 0xFFFD,
	0x21AB: 0xFFFD,
	0x21AC: 0xFFFD,
	0x21AD: 0xFFFD,
	0x21AE: 0xFFFD,
	0x21AF: 0xFFFD,
	0x21B0: 0xFFFD,
	0x21B1: 0xFFFD,
	0x21B2: 0x9DFD,
	0x21B3: 0xFFFD,
	0x21B4: 0xFFFD,
	0x21B5: 0xFFFD,
	0x21B6: 0xFFFD,
	0x21B7: 0xFFFD,
	0x21B8: 0xC877,
	0x21B9: 0xC878,
	0x21BA: 0xFFFD,
	0x21BB: 0xFFFD,
	0x21BC: 0xFFFD,
	0x21BD: 0xFFFD,
	0x21BE: 0xFFFD,
	0x21BF: 0xFFFD,
	0x21C0: 0xFFFD,
	0x21C1: 0xFFFD,
	0x21C2: 0xFFFD,
	0x21C3: 0xFFFD,
	0x21C4: 0xFFFD,
	0x21C5: 0xFFFD,
	0x21C6: 0xFFFD,
	0x21C7: 0xFFFD,
	0x21C8: 0xFFFD,
	0x21C9: 0xFFFD,
	0x21CA: 0xFFFD,
	0x21CB: 0x9653,
	0x21CC: 0xFFFD,
	0x21CD: 0xFFFD,
	0x21CE: 0xFFFD,
	0x21CF: 0xFFFD,
	0x21D0: 0xFFFD,
	0x21D1: 0xFFFD,
	0x21D2: 0xFFFD,
	0x21D3: 0xFFFD,
	0x21D4: 0x9965,
	0x21D5: 0xFFFD,
	0x21D6: 0xFFFD,
	0x21D7: 0xFFFD,
	0x21D8: 0xFFFD,
	0x21D9: 0xFFFD,
	0x21DA: 0xFFFD,
	0x21DB: 0xFFFD,
	0x21DC: 0xFFFD,
	0x21DD: 0xFFFD,
	0x21DE: 0xFFFD,
	0x21DF: 0xFFFD,
	0x21E0: 0xFFFD,
	0x21E1: 0xFFFD,
	0x21E2: 0xFFFD,
	0x21E3: 0xFFFD,
	0x21E4: 0xFFFD,
	0x21E5: 0xFFFD,
	0x21E6: 0x9D4A,
	0x21E7: 0xC876,
	0x21E8: 0x9D49,
	0x21E9: 0x9D4C,
	0x21EA: 0xFFFD,
	0x21EB: 0xFFFD,
	0x21EC: 0xFFFD,
	0x21ED: 0xFFFD,
	0x21EE: 0xFFFD,
	0x21EF: 0xFFFD,
	0x21F0: 0xFFFD,
	0x21F1: 0xFFFD,
	0x21F2: 0xFFFD,
	0x21F3: 0xFFFD,
	0x21F4: 0xFFFD,
	0x21F5: 0xFFFD,
	0x21F6: 0xFFFD,
	0x21F7: 0xFFFD,
	0x21F8: 0xFFFD,
	0x21F9: 0xFFFD,
	0x21FA: 0xFFFD,
	0x21FB: 0xFFFD,
	0x21FC: 0xFFFD,
	0x21FD: 0xFFFD,
	0x21FE: 0xFFFD,
	0x21FF: 0xFFFD,
	0x2200: 0x91F9,
	0x2201: 0xFFFD,
	0x2202: 0xA079,
	0x2203: 0x98F9,
	0x2204: 0xFFFD,
	0x2205: 0xFFFD,
	0x2206: 0xFFFD,
	0x2207: 0xA1BE,
	0x2208: 0x916B,
	0x2209: 0xFFFD,
	0x220A: 0xFFFD,
	0x220B: 0x915F,
	0x220C: 0xFFFD,
	0x220D: 0xFFFD,
	0x220E: 0xFFFD,
	0x220F: 0xA353,
	0x2210: 0xFFFD,
	0x2211: 0xA355,
	0x2212: 0xFFFD,
	0x2213: 0xFFFD,
	0x2214: 0xFFFD,
	0x2215: 0xA241,
	0x2216: 0xA242,
	0x2217: 0xFFFD,
	0x2218: 0xA258,
	0x2219: 0xFFFD,
	0x221A: 0xA1D4,
	0x221B: 0xFFFD,
	0x221C: 0xFFFD,
	0x221D: 0xFFFD,
	0x221E: 0xA1DB,
	0x221F: 0xA1E8,
	0x2220: 0xA1E7,
	0x2221: 0xFFFD,
	0x2222: 0xFFFD,
	0x2223: 0xA1FD,
	0x2224: 0xFFFD,
	0x2225: 0xA1FC,
	0x2226: 0xFFFD,
	0x2227: 0xA34E,
	0x2228: 0xA2E4,
	0x2229: 0xA1E4,
	0x222A: 0xA1E5,
	0x222B: 0xA1EC,
	0x222C: 0x9F4C,
	0x222D: 0xFFFD,
	0x222E: 0xA1ED,
	0x222F: 0xFFFD,
	0x2230: 0xFFFD,
	0x2231: 0xFFFD,
	0x2232: 0xFFFD,
	0x2233: 0xFFFD,
	0x2234: 0xA1EF,
	0x2235: 0xA1EE,
	0x2236: 0xA147,
	0x2237: 0x9F46,
	0x2238: 0xFFFD,
	0x2239: 0xFFFD,
	0x223A: 0xFFFD,
	0x223B: 0xFFFD,
	0x223C: 0xFFFD,
	0x223D: 0xFFFD,
	0x223E: 0xFFFD,
	0x223F: 0xFFFD,
	0x2240: 0xFFFD,
	0x2241: 0xFFFD,
	0x2242: 0xFFFD,
	0x2243: 0xFFFD,
	0x2244: 0xFFFD,
	0x2245: 0xFFFD,
	0x2246: 0xFFFD,
	0x2247: 0xFFFD,
	0x2248: 0xFFFD,
	0x2249: 0xFFFD,
	0x224A: 0xFFFD,
	0x224B: 0xFFFD,
	0x224C: 0xFFFD,
	0x224D: 0xFFFD,
	0x224E: 0xFFFD,
	0x224F: 0xFFFD,
	0x2250: 0xFFFD,
	0x2251: 0xFFFD,
	0x2252: 0xA1DC,
	0x2253: 0xFFFD,
	0x2254: 0xFFFD,
	0x2255: 0xFFFD,
	0x2256: 0xFFFD,
	0x2257: 0xFFFD,
	0x2258: 0xFFFD,
	0x2259: 0xFFFD,
	0x225A: 0xFFFD,
	0x225B: 0xFFFD,
	0x225C: 0xFFFD,
	0x225D: 0xFFFD,
	0x225E: 0xFFFD,
	0x225F: 0xFFFD,
	0x2260: 0xA1DA,
	0x2261: 0xA1DD,
	0x2262: 0xFFFD,
	0x2263: 0xA1DD,
	0x2264: 0xFFFD,
	0x2265: 0xFFFD,
	0x2266: 0xA1D8,
	0x2267: 0xA1D9,
	0x2268: 0xFFFD,
	0x2269: 0xFFFD,
	0x226A: 0xFFFD,
	0x226B: 0xFFFD,
	0x226C: 0xFFFD,
	0x226D: 0xFFFD,
	0x226E: 0xFFFD,
	0x226F: 0xFFFD,
	0x2270: 0xFFFD,
	0x2271: 0xFFFD,
	0x2272: 0xFFFD,
	0x2273: 0xFFFD,
	0x2274: 0xFFFD,
	0x2275: 0xFFFD,
	0x2276: 0xFFFD,
	0x2277: 0xFFFD,
	0x2278: 0xFFFD,
	0x2279: 0xFFFD,
	0x227A: 0xFFFD,
	0x227B: 0xFFFD,
	0x227C: 0xFFFD,
	0x227D: 0xFFFD,
	0x227E: 0xFFFD,
	0x227F: 0xFFFD,
	0x2280: 0xFFFD,
	0x2281: 0xFFFD,
	0x2282: 0x9AE0,
	0x2283: 0x9AA6,
	0x2284: 0xFFFD,
	0x2285: 0xFFFD,
	0x2286: 0x9C72,
	0x2287: 0x9CAA,
	0x2288: 0xFFFD,
	0x2289: 0xFFFD,
	0x228A: 0xFFFD,
	0x228B: 0xFFFD,
	0x228C: 0xFFFD,
	0x228D: 0xFFFD,
	0x228E: 0xFFFD,
	0x228F: 0xFFFD,
	0x2290: 0xFFFD,
	0x2291: 0xFFFD,
	0x2292: 0xFFFD,
	0x2293: 0xFFFD,
	0x2294: 0xFFFD,
	0x2295: 0xA1F2,
	0x2296: 0xFFFD,
	0x2297: 0xFFFD,
	0x2298: 0xFFFD,
	0x2299: 0xA1F3,
	0x229A: 0xFFFD,
	0x229B: 0xFFFD,
	0x229C: 0xFFFD,
	0x229D: 0xFFFD,
	0x229E: 0xFFFD,
	0x229F: 0xFFFD,
	0x22A0: 0xFFFD,
	0x22A1: 0xFFFD,
	0x22A2: 0xFFFD,
	0x22A3: 0xFFFD,
	0x22A4: 0xFFFD,
	0x22A5: 0xA1E6,
	0x22A6: 0xFFFD,
	0x22A7: 0xFFFD,
	0x22A8: 0xFFFD,
	0x22A9: 0xFFFD,
	0x22AA: 0xFFFD,
	0x22AB: 0xFFFD,
	0x22AC: 0xFFFD,
	0x22AD: 0xFFFD,
	0x22AE: 0xFFFD,
	0x22AF: 0xFFFD,
	0x22B0: 0xFFFD,
	0x22B1: 0xFFFD,
	0x22B2: 0xFFFD,
	0x22B3: 0xFFFD,
	0x22B4: 0xFFFD,
	0x22B5: 0xFFFD,
	0x22B6: 0xFFFD,
	0x22B7: 0xFFFD,
	0x22B8: 0xFFFD,
	0x22B9: 0xFFFD,
	0x22BA: 0xFFFD,
	0x22BB: 0xFFFD,
	0x22BC: 0xFFFD,
	0x22BD: 0xFFFD,
	0x22BE: 0xFFFD,
	0x22BF: 0xA1E9,
	0x22C0: 0xFFFD,
	0x22C1: 0xFFFD,
	0x22C2: 0xFFFD,
	0x22C3: 0xFFFD,
	0x22C4: 0xFFFD,
	0x22C5: 0xFFFD,
	0x22C6: 0xFFFD,
	0x22C7: 0xFFFD,
	0x22C8: 0xFFFD,
	0x22C9: 0xFFFD,
	0x22CA: 0xFFFD,
	0x22CB: 0xFFFD,
	0x22CC: 0xFFFD,
	0x22CD: 0xFFFD,
	0x22CE: 0xFFFD,
	0x22CF: 0xFFFD,
	0x22D0: 0xFFFD,
	0x22D1: 0xFFFD,
	0x22D2: 0xFFFD,
	0x22D3: 0xFFFD,
	0x22D4: 0xFFFD,
	0x22D5: 0xFFFD,
	0x22D6: 0xFFFD,
	0x22D7: 0xFFFD,
	0x22D8: 0xFFFD,
	0x22D9: 0xFFFD,
	0x22DA: 0xFFFD,
	0x22DB: 0xFFFD,
	0x22DC: 0xFFFD,
	0x22DD: 0xFFFD,
	0x22DE: 0xFFFD,
	0x22DF: 0xFFFD,
	0x22E0: 0xFFFD,
	0x22E1: 0xFFFD,
	0x22E2: 0xFFFD,
	0x22E3: 0xFFFD,
	0x22E4: 0xFFFD,
	0x22E5: 0xFFFD,
	0x22E6: 0xFFFD,
	0x22E7: 0xFFFD,
	0x22E8: 0xFFFD,
	0x22E9: 0xFFFD,
	0x22EA: 0xFFFD,
	0x22EB: 0xFFFD,
	0x22EC: 0xFFFD,
	0x22ED: 0xFFFD,
	0x22EE: 0xFFFD,
	0x22EF: 0xFFFD,
	0x22F0: 0xFFFD,
	0x22F1: 0xFFFD,
	0x22F2: 0xFFFD,
	0x22F3: 0xFFFD,
	0x22F4: 0xFFFD,
	0x22F5: 0xFFFD,
	0x22F6: 0xFFFD,
	0x22F7: 0xFFFD,
	0x22F8: 0xFFFD,
	0x22F9: 0xFFFD,
	0x22FA: 0xFFFD,
	0x22FB: 0xFFFD,
	0x22FC: 0xFFFD,
	0x22FD: 0xFFFD,
	0x22FE: 0xFFFD,
	0x22FF: 0xFFFD,
	0x2300: 0xFFFD,
	0x2301: 0xFFFD,
	0x2302: 0x91FC,
	0x2303: 0xFFFD,
	0x2304: 0xFFFD,
	0x2305: 0xFFFD,
	0x2306: 0xFFFD,
	0x2307: 0xA15B,
	0x2308: 0xFFFD,
	0x2309: 0xFFFD,
	0x230A: 0xFFFD,
	0x230B: 0xFFFD,
	0x230C: 0xFFFD,
	0x230D: 0xFFFD,
	0x230E: 0xFFFD,
	0x230F: 0xFFFD,
	0x2310: 0xFFFD,
	0x2311: 0xFFFD,
	0x2312: 0xFED9,
	0x2313: 0xFFFD,
	0x2314: 0xFFFD,
	0x2315: 0xFFFD,
	0x2316: 0xFFFD,
	0x2317: 0xFFFD,
	0x2318: 0xFFFD,
	0x2319: 0xFFFD,
	0x231A: 0xFFFD,
	0x231B: 0xFFFD,
	0x231C: 0xFFFD,
	0x231D: 0xFFFD,
	0x231E: 0xFFFD,
	0x231F: 0xFFFD,
	0x2320: 0xFFFD,
	0x2321: 0xFFFD,
	0x2322: 0xFFFD,
	0x2323: 0xFFFD,
	0x2324: 0xFFFD,
	0x2325: 0xFFFD,
	0x2326: 0xFFFD,
	0x2327: 0xFFFD,
	0x2328: 0xFFFD,
	0x2329: 0xFFFD,
	0x232A: 0xFFFD,
	0x232B: 0xFFFD,
	0x232C: 0xFFFD,
	0x232D: 0xFFFD,
	0x232E: 0xFFFD,
	0x232F: 0xFFFD,
	0x2330: 0xFFFD,
	0x2331: 0xFFFD,
	0x2332: 0xFFFD,
	0x2333: 0xFFFD,
	0x2334: 0xFFFD,
	0x2335: 0xFFFD,
	0x2336: 0xFFFD,
	0x2337: 0xFFFD,
	0x2338: 0xFFFD,
	0x2339: 0xFFFD,
	0x233A: 0xFFFD,
	0x233B: 0xFFFD,
	0x233C: 0xFFFD,
	0x233D: 0xFFFD,
	0x233E: 0xFFFD,
	0x233F: 0xFFFD,
	0x2340: 0xFFFD,
	0x2341: 0xFFFD,
	0x2342: 0xFFFD,
	0x2343: 0xFFFD,
	0x2344: 0xFFFD,
	0x2345: 0xFFFD,
	0x2346: 0xFFFD,
	0x2347: 0xFFFD,
	0x2348: 0xFFFD,
	0x2349: 0xFFFD,
	0x234A: 0xFFFD,
	0x234B: 0xFFFD,
	0x234C: 0xFFFD,
	0x234D: 0xFFFD,
	0x234E: 0xFFFD,
	0x234F: 0xFFFD,
	0x2350: 0xFFFD,
	0x2351: 0xFFFD,
	0x2352: 0xFFFD,
	0x2353: 0xFFFD,
	0x2354: 0xFFFD,
	0x2355: 0xFFFD,
	0x2356: 0xFFFD,
	0x2357: 0xFFFD,
	0x2358: 0xFFFD,
	0x2359: 0xFFFD,
	0x235A: 0xFFFD,
	0x235B: 0xFFFD,
	0x235C: 0xFFFD,
	0x235D: 0xFFFD,
	0x235E: 0xFFFD,
	0x235F: 0xFFFD,
	0x2360: 0xFFFD,
	0x2361: 0xFFFD,
	0x2362: 0xFFFD,
	0x2363: 0xFFFD,
	0x2364: 0xFFFD,
	0x2365: 0xFFFD,
	0x2366: 0xFFFD,
	0x2367: 0xFFFD,
	0x2368: 0xFFFD,
	0x2369: 0xFFFD,
	0x236A: 0xFFFD,
	0x236B: 0xFFFD,
	0x236C: 0xFFFD,
	0x236D: 0xFFFD,
	0x236E: 0xFFFD,
	0x236F: 0xFFFD,
	0x2370: 0xFFFD,
	0x2371: 0xFFFD,
	0x2372: 0xFFFD,
	0x2373: 0xFFFD,
	0x2374: 0xFFFD,
	0x2375: 0xFFFD,
	0x2376: 0xFFFD,
	0x2377: 0xFFFD,
	0x2378: 0xFFFD,
	0x2379: 0xFFFD,
	0x237A: 0xFFFD,
	0x237B: 0xFFFD,
	0x237C: 0xFFFD,
	0x237D: 0xFFFD,
	0x237E: 0xFFFD,
	0x237F: 0xFFFD,
	0x2380: 0xFFFD,
	0x2381: 0xFFFD,
	0x2382: 0xFFFD,
	0x2383: 0xFFFD,
	0x2384: 0xFFFD,
	0x2385: 0xFFFD,
	0x2386: 0xFFFD,
	0x2387: 0xFFFD,
	0x2388: 0xFFFD,
	0x2389: 0xFFFD,
	0x238A: 0xFFFD,
	0x238B: 0xFFFD,
	0x238C: 0xFFFD,
	0x238D: 0xFFFD,
	0x238E: 0xFFFD,
	0x238F: 0xFFFD,
	0x2390: 0xFFFD,
	0x2391: 0xFFFD,
	0x2392: 0xFFFD,
	0x2393: 0xFFFD,
	0x2394: 0xFFFD,
	0x2395: 0xFFFD,
	0x2396: 0xFFFD,
	0x2397: 0xFFFD,
	0x2398: 0xFFFD,
	0x2399: 0xFFFD,
	0x239A: 0xFFFD,
	0x239B: 0xFFFD,
	0x239C: 0xFFFD,
	0x239D: 0xFFFD,
	0x239E: 0xFFFD,
	0x239F: 0xFFFD,
	0x23A0: 0xFFFD,
	0x23A1: 0xFFFD,
	0x23A2: 0xFFFD,
	0x23A3: 0xFFFD,
	0x23A4: 0xFFFD,
	0x23A5: 0xFFFD,
	0x23A6: 0xFFFD,
	0x23A7: 0xFFFD,
	0x23A8: 0xFFFD,
	0x23A9: 0xFFFD,
	0x23AA: 0xFFFD,
	0x23AB: 0xFFFD,
	0x23AC: 0xFFFD,
	0x23AD: 0xFFFD,
	0x23AE: 0xFFFD,
	0x23AF: 0xFFFD,
	0x23B0: 0xFFFD,
	0x23B1: 0xFFFD,
	0x23B2: 0xFFFD,
	0x23B3: 0xFFFD,
	0x23B4: 0xFFFD,
	0x23B5: 0xFFFD,
	0x23B6: 0xFFFD,
	0x23B7: 0xFFFD,
	0x23B8: 0xFFFD,
	0x23B9: 0xFFFD,
	0x23BA: 0xFFFD,
	0x23BB: 0xFFFD,
	0x23BC: 0xFFFD,
	0x23BD: 0xFFFD,
	0x23BE: 0xFFFD,
	0x23BF: 0xFFFD,
	0x23C0: 0xFFFD,
	0x23C1: 0xFFFD,
	0x23C2: 0xFFFD,
	0x23C3: 0xFFFD,
	0x23C4: 0xFFFD,
	0x23C5: 0xFFFD,
	0x23C6: 0xFFFD,
	0x23C7: 0xFFFD,
	0x23C8: 0xFFFD,
	0x23C9: 0xFFFD,
	0x23CA: 0xFFFD,
	0x23CB: 0xFFFD,
	0x23CC: 0xFFFD,
	0x23CD: 0xFFFD,
	0x23CE: 0xFFFD,
	0x23CF: 0xFFFD,
	0x23D0: 0xFFFD,
	0x23D1: 0xFFFD,
	0x23D2: 0xFFFD,
	0x23D3: 0xFFFD,
	0x23D4: 0xFFFD,
	0x23D5: 0xFFFD,
	0x23D6: 0xFFFD,
	0x23D7: 0xFFFD,
	0x23D8: 0xFFFD,
	0x23D9: 0xFFFD,
	0x23DA: 0xFFFD,
	0x23DB: 0xFFFD,
	0x23DC: 0xFFFD,
	0x23DD: 0xFFFD,
	0x23DE: 0xFFFD,
	0x23DF: 0xFFFD,
	0x23E0: 0xFFFD,
	0x23E1: 0xFFFD,
	0x23E2: 0xFFFD,
	0x23E3: 0xFFFD,
	0x23E4: 0xFFFD,
	0x23E5: 0xFFFD,
	0x23E6: 0xFFFD,
	0x23E7: 0xFFFD,
	0x23E8: 0xFFFD,
	0x23E9: 0xFFFD,
	0x23EA: 0xFFFD,
	0x23EB: 0xFFFD,
	0x23EC: 0xFFFD,
	0x23ED: 0xFFFD,
	0x23EE: 0xFFFD,
	0x23EF: 0xFFFD,
	0x23F0: 0xFFFD,
	0x23F1: 0xFFFD,
	0x23F2: 0xFFFD,
	0x23F3: 0xFFFD,
	0x23F4: 0xFFFD,
	0x23F5: 0xFFFD,
	0x23F6: 0xFFFD,
	0x23F7: 0xFFFD,
	0x23F8: 0xFFFD,
	0x23F9: 0xFFFD,
	0x23FA: 0xFFFD,
	0x23FB: 0xFFFD,
	0x23FC: 0xFFFD,
	0x23FD: 0xFFFD,
	0x23FE: 0xFFFD,
	0x23FF: 0xFFFD,
	0x2400: 0xA3C0,
	0x2401: 0xA3C1,
	0x2402: 0xA3C2,
	0x2403: 0xA3C3,
	0x2404: 0xA3C4,
	0x2405: 0xA3C5,
	0x2406: 0xA3C6,
	0x2407: 0xA3C7,
	0x2408: 0xA3C8,
	0x2409: 0xA3C9,
	0x240A: 0xA3CA,
	0x240B: 0xA3CB,
	0x240C: 0xA3CC,
	0x240D: 0xA3CD,
	0x240E: 0xA3CE,
	0x240F: 0xA3CF,
	0x2410: 0xA3D0,
	0x2411: 0xA3D1,
	0x2412: 0xA3D2,
	0x2413: 0xA3D3,
	0x2414: 0xA3D4,
	0x2415: 0xA3D5,
	0x2416: 0xA3D6,
	0x2417: 0xA3D7,
	0x2418: 0xA3D8,
	0x2419: 0xA3D9,
	0x241A: 0xA3DA,
	0x241B: 0xA3DB,
	0x241C: 0xA3DC,
	0x241D: 0xA3DD,
	0x241E: 0xA3DE,
	0x241F: 0xA3DF,
	0x2420: 0xFFFD,
	0x2421: 0xA3E0,
	0x2422: 0xFFFD,
	0x2423: 0xFFFD,
	0x2424: 0xFFFD,
	0x2425: 0xFFFD,
	0x2426: 0xFFFD,
	0x2427: 0xFFFD,
	0x2428: 0xFFFD,
	0x2429: 0xFFFD,
	0x242A: 0xFFFD,
	0x242B: 0xFFFD,
	0x242C: 0xFFFD,
	0x242D: 0xFFFD,
	0x242E: 0xFFFD,
	0x242F: 0xFFFD,
	0x2430: 0xFFFD,
	0x2431: 0xFFFD,
	0x2432: 0xFFFD,
	0x2433: 0xFFFD,
	0x2434: 0xFFFD,
	0x2435: 0xFFFD,
	0x2436: 0xFFFD,
	0x2437: 0xFFFD,
	0x2438: 0xFFFD,
	0x2439: 0xFFFD,
	0x243A: 0xFFFD,
	0x243B: 0xFFFD,
	0x243C: 0xFFFD,
	0x243D: 0xFFFD,
	0x243E: 0xFFFD,
	0x243F: 0xFFFD,
	0x2440: 0xFFFD,
	0x2441: 0xFFFD,
	0x2442: 0xFFFD,
	0x2443: 0xFFFD,
	0x2444: 0xFFFD,
	0x2445: 0xFFFD,
	0x2446: 0xFFFD,
	0x2447: 0xFFFD,
	0x2448: 0xFFFD,
	0x2449: 0xFFFD,
	0x244A: 0xFFFD,
	0x244B: 0xFFFD,
	0x244C: 0xFFFD,
	0x244D: 0xFFFD,
	0x244E: 0xFFFD,
	0x244F: 0xFFFD,
	0x2450: 0xFFFD,
	0x2451: 0xFFFD,
	0x2452: 0xFFFD,
	0x2453: 0xFFFD,
	0x2454: 0xFFFD,
	0x2455: 0xFFFD,
	0x2456: 0xFFFD,
	0x2457: 0xFFFD,
	0x2458: 0xFFFD,
	0x2459: 0xFFFD,
	0x245A: 0xFFFD,
	0x245B: 0xFFFD,
	0x245C: 0xFFFD,
	0x245D: 0xFFFD,
	0x245E: 0xFFFD,
	0x245F: 0xFFFD,
	0x2460: 0xC6A1,
	0x2461: 0xC6A2,
	0x2462: 0xC6A3,
	0x2463: 0xC6A4,
	0x2464: 0xC6A5,
	0x2465: 0xC6A6,
	0x2466: 0xC6A7,
	0x2467: 0xC6A8,
	0x2468: 0xC6A9,
	0x2469: 0xC6AA,
	0x246A: 0x974B,
	0x246B: 0x974C,
	0x246C: 0x974D,
	0x246D: 0x974E,
	0x246E: 0x974F,
	0x246F: 0x9750,
	0x2470: 0x9751,
	0x2471: 0x9752,
	0x2472: 0x9753,
	0x2473: 0x9754,
	0x2474: 0xC6AB,
	0x2475: 0xC6AC,
	0x2476: 0xC6AD,
	0x2477: 0xC6AE,
	0x2478: 0xC6AF,
	0x2479: 0xC6B0,
	0x247A: 0xC6B1,
	0x247B: 0xC6B2,
	0x247C: 0xC6B3,
	0x247D: 0xC6B4,
	0x247E: 0x994B,
	0x247F: 0x994C,
	0x2480: 0x994D,
	0x2481: 0x994E,
	0x2482: 0x994F,
	0x2483: 0x9950,
	0x2484: 0x9951,
	0x2485: 0x9952,
	0x2486: 0x9953,
	0x2487: 0x9954,
	0x2488: 0x9A41,
	0x2489: 0x9A42,
	0x248A: 0x9A43,
	0x248B: 0x9A44,
	0x248C: 0x9A45,
	0x248D: 0x9A46,
	0x248E: 0x9A47,
	0x248F: 0x9A48,
	0x2490: 0x9A49,
	0x2491: 0x9A4A,
	0x2492: 0x9A4B,
	0x2493: 0x9A4C,
	0x2494: 0x9A4D,
	0x2495: 0x9A4E,
	0x2496: 0x9A4F,
	0x2497: 0x9A50,
	0x2498: 0x9A51,
	0x2499: 0x9A52,
	0x249A: 0x9A53,
	0x249B: 0x9A54,
	0x249C: 0x99E1,
	0x249D: 0x99E2,
	0x249E: 0x99E3,
	0x249F: 0x99E4,
	0x24A0: 0x99E5,
	0x24A1: 0x99E6,
	0x24A2: 0x99E7,
	0x24A3: 0x99E8,
	0x24A4: 0x99E9,
	0x24A5: 0x99EA,
	0x24A6: 0x99EB,
	0x24A7: 0x99EC,
	0x24A8: 0x99ED,
	0x24A9: 0x99EE,
	0x24AA: 0x99EF,
	0x24AB: 0x99F0,
	0x24AC: 0x99F1,
	0x24AD: 0x99F2,
	0x24AE: 0x99F3,
	0x24AF: 0x99F4,
	0x24B0: 0x99F5,
	0x24B1: 0x99F6,
	0x24B2: 0x99F7,
	0x24B3: 0x99F8,
	0x24B4: 0x99F9,
	0x24B5: 0x99FA,
	0x24B6: 0x97C7,
	0x24B7: 0x97C8,
	0x24B8: 0x97C9,
	0x24B9: 0x97CA,
	0x24BA: 0x97CB,
	0x24BB: 0x97CC,
	0x24BC: 0x97CD,
	0x24BD: 0x97CE,
	0x24BE: 0x97CF,
	0x24BF: 0x97D0,
	0x24C0: 0x97D1,
	0x24C1: 0x97D2,
	0x24C2: 0x97D3,
	0x24C3: 0x97D4,
	0x24C4: 0x97D5,
	0x24C5: 0x97D6,
	0x24C6: 0x97D7,
	0x24C7: 0x97D8,
	0x24C8: 0x97D9,
	0x24C9: 0x97DA,
	0x24CA: 0x97DB,
	0x24CB: 0x97DC,
	0x24CC: 0x97DD,
	0x24CD: 0x97DE,
	0x24CE: 0x97DF,
	0x24CF: 0x97E0,
	0x24D0: 0x97E1,
	0x24D1: 0x97E2,
	0x24D2: 0x97E3,
	0x24D3: 0x97E4,
	0x24D4: 0x97E5,
	0x24D5: 0x97E6,
	0x24D6: 0x97E7,
	0x24D7: 0x97E8,
	0x24D8: 0x97E9,
	0x24D9: 0x97EA,
	0x24DA: 0x97EB,
	0x24DB: 0x97EC,
	0x24DC: 0x97ED,
	0x24DD: 0x97EE,
	0x24DE: 0x97EF,
	0x24DF: 0x97F0,
	0x24E0: 0x97F1,
	0x24E1: 0x97F2,
	0x24E2: 0x97F3,
	0x24E3: 0x97F4,
	0x24E4: 0x97F5,
	0x24E5: 0x97F6,
	0x24E6: 0x97F7,
	0x24E7: 0x97F8,
	0x24E8: 0x97F9,
	0x24E9: 0x97FA,
	0x24EA: 0x9740,
	0x24EB: 0xFFFD,
	0x24EC: 0xFFFD,
	0x24ED: 0xFFFD,
	0x24EE: 0xFFFD,
	0x24EF: 0xFFFD,
	0x24F0: 0xFFFD,
	0x24F1: 0xFFFD,
	0x24F2: 0xFFFD,
	0x24F3: 0xFFFD,
	0x24F4: 0xFFFD,
	0x24F5: 0xFFFD,
	0x24F6: 0xFFFD,
	0x24F7: 0xFFFD,
	0x24F8: 0xFFFD,
	0x24F9: 0xFFFD,
	0x24FA: 0xFFFD,
	0x24FB: 0xFFFD,
	0x24FC: 0xFFFD,
	0x24FD: 0xFFFD,
	0x24FE: 0xFFFD,
	0x24FF: 0xFFFD,
	0x2500: 0xA277,
	0x2501: 0x9D7D,
	0x2502: 0xA278,
	0x2503: 0x9D7E,
	0x2504: 0xA14C,
	0x2505: 0xA14C,
	0x2506: 0xA14A,
	0x2507: 0xA14A,
	0x2508: 0xA14B,
	0x2509: 0xA14B,
	0x250A: 0xA155,
	0x250B: 0xA155,
	0x250C: 0xA27A,
	0x250D: 0xA27A,
	0x250E: 0xA27A,
	0x250F: 0xA27A,
	0x2510: 0xA27B,
	0x2511: 0xA27B,
	0x2512: 0xA27B,
	0x2513: 0xA27B,
	0x2514: 0xA27C,
	0x2515: 0xA27C,
	0x2516: 0xA27C,
	0x2517: 0xA27C,
	0x2518: 0xA27D,
	0x2519: 0xA27D,
	0x251A: 0xA27D,
	0x251B: 0xA27D,
	0x251C: 0xA275,
	0x251D: 0xA275,
	0x251E: 0xA275,
	0x251F: 0xA275,
	0x2520: 0xA275,
	0x2521: 0xA275,
	0x2522: 0xA275,
	0x2523: 0xA275,
	0x2524: 0xA274,
	0x2525: 0xA274,
	0x2526: 0xA274,
	0x2527: 0xA274,
	0x2528: 0xA274,
	0x2529: 0xA274,
	0x252A: 0xA274,
	0x252B: 0xA274,
	0x252C: 0xA273,
	0x252D: 0xA273,
	0x252E: 0xA273,
	0x252F: 0xA273,
	0x2530: 0xA273,
	0x2531: 0xA273,
	0x2532: 0xA273,
	0x2533: 0xA273,
	0x2534: 0xA272,
	0x2535: 0xA272,
	0x2536: 0xA272,
	0x2537: 0xA272,
	0x2538: 0xA272,
	0x2539: 0xA272,
	0x253A: 0xA272,
	0x253B: 0xA272,
	0x253C: 0xA271,
	0x253D: 0xA271,
	0x253E: 0xA271,
	0x253F: 0xA271,
	0x2540: 0xA271,
	0x2541: 0xA271,
	0x2542: 0xA271,
	0x2543: 0xA271,
	0x2544: 0xA271,
	0x2545: 0xA271,
	0x2546: 0xA271,
	0x2547: 0xA271,
	0x2548: 0xA271,
	0x2549: 0xA271,
	0x254A: 0xA271,
	0x254B: 0xA271,
	0x254C: 0xFFFD,
	0x254D: 0xFFFD,
	0x254E: 0x91F0,
	0x254F: 0xFFFD,
	0x2550: 0xF9F9,
	0x2551: 0xF9F8,
	0x2552: 0xF9E6,
	0x2553: 0xF9EF,
	0x2554: 0xF9DD,
	0x2555: 0xF9E8,
	0x2556: 0xF9F1,
	0x2557: 0xF9DF,
	0x2558: 0xF9EC,
	0x2559: 0xF9F5,
	0x255A: 0xF9E3,
	0x255B: 0xF9EE,
	0x255C: 0xF9F7,
	0x255D: 0xF9E5,
	0x255E: 0xF9E9,
	0x255F: 0xF9F2,
	0x2560: 0xF9E0,
	0x2561: 0xF9EB,
	0x2562: 0xF9F4,
	0x2563: 0xF9E2,
	0x2564: 0xF9E7,
	0x2565: 0xF9F0,
	0x2566: 0xF9DE,
	0x2567: 0xF9ED,
	0x2568: 0xF9F6,
	0x2569: 0xF9E4,
	0x256A: 0xF9EA,
	0x256B: 0xF9F3,
	0x256C: 0xF9E1,
	0x256D: 0xA27E,
	0x256E: 0xA2A1,
	0x256F: 0xA2A3,
	0x2570: 0xA2A2,
	0x2571: 0xA2AC,
	0x2572: 0xA2AD,
	0x2573: 0xA2AE,
	0x2574: 0xA15A,
	0x2575: 0xFFFD,
	0x2576: 0xFFFD,
	0x2577: 0xFFFD,
	0x2578: 0xFFFD,
	0x2579: 0xFFFD,
	0x257A: 0xFFFD,
	0x257B: 0xFFFD,
	0x257C: 0xFFFD,
	0x257D: 0xFFFD,
	0x257E: 0xFFFD,
	0x257F: 0xFFFD,
	0x2580: 0xFFFD,
	0x2581: 0xA262,
	0x2582: 0xA263,
	0x2583: 0xA264,
	0x2584: 0xA265,
	0x2585: 0xA266,
	0x2586: 0xA267,
	0x2587: 0xA268,
	0x2588: 0xA269,
	0x2589: 0xA270,
	0x258A: 0xA26F,
	0x258B: 0xA26E,
	0x258C: 0xA26D,
	0x258D: 0xA26C,
	0x258E: 0xA26B,
	0x258F: 0xA26A,
	0x2590: 0xFFFD,
	0x2591: 0xFFFD,
	0x2592: 0xFFFD,
	0x2593: 0xF9FE,
	0x2594: 0xA276,
	0x2595: 0xA279,
	0x2596: 0xFFFD,
	0x2597: 0xFFFD,
	0x2598: 0xFFFD,
	0x2599: 0xFFFD,
	0x259A: 0xFFFD,
	0x259B: 0xFFFD,
	0x259C: 0xFFFD,
	0x259D: 0xFFFD,
	0x259E: 0xFFFD,
	0x259F: 0xFFFD,
	0x25A0: 0xA1BD,
	0x25A1: 0xA1BC,
	0x25A2: 0xFFFD,
	0x25A3: 0xFFFD,
	0x25A4: 0xFFFD,
	0x25A5: 0xFFFD,
	0x25A6: 0xFFFD,
	0x25A7: 0xFFFD,
	0x25A8: 0xFFFD,
	0x25A9: 0xFFFD,
	0x25AA: 0xFFFD,
	0x25AB: 0xFFFD,
	0x25AC: 0xFFFD,
	0x25AD: 0xFFFD,
	0x25AE: 0xFFFD,
	0x25AF: 0xFFFD,
	0x25B0: 0xFFFD,
	0x25B1: 0xFFFD,
	0x25B2: 0xA1B6,
	0x25B3: 0xA1B5,
	0x25B4: 0xFFFD,
	0x25B5: 0xFFFD,
	0x25B6: 0x91F4,
	0x25B7: 0xFFFD,
	0x25B8: 0xFFFD,
	0x25B9: 0xFFFD,
	0x25BA: 0xFFFD,
	0x25BB: 0xFFFD,
	0x25BC: 0xA1BF,
	0x25BD: 0xA1BE,
	0x25BE: 0xFFFD,
	0x25BF: 0xFFFD,
	0x25C0: 0xFFFD,
	0x25C1: 0xFFFD,
	0x25C2: 0xFFFD,
	0x25C3: 0xFFFD,
	0x25C4: 0x91F5,
	0x25C5: 0xFFFD,
	0x25C6: 0xA1BB,
	0x25C7: 0xA1BA,
	0x25C8: 0xFFFD,
	0x25C9: 0xFFFD,
	0x25CA: 0xFFFD,
	0x25CB: 0xA1B3,
	0x25CC: 0xFFFD,
	0x25CD: 0xFFFD,
	0x25CE: 0xA1B7,
	0x25CF: 0xA1B4,
	0x25D0: 0xFFFD,
	0x25D1: 0xFFFD,
	0x25D2: 0xFFFD,
	0x25D3: 0xFFFD,
	0x25D4: 0xFFFD,
	0x25D5: 0xFFFD,
	0x25D6: 0xFFFD,
	0x25D7: 0xFFFD,
	0x25D8: 0x91F1,
	0x25D9: 0x91F2,
	0x25DA: 0xFFFD,
	0x25DB: 0xFFFD,
	0x25DC: 0xFFFD,
	0x25DD: 0xFFFD,
	0x25DE: 0xFFFD,
	0x25DF: 0xFFFD,
	0x25E0: 0xFFFD,
	0x25E1: 0xFFFD,
	0x25E2: 0xA2A8,
	0x25E3: 0xA2A9,
	0x25E4: 0xA2AB,
	0x25E5: 0xA2AA,
	0x25E6: 0xFFFD,
	0x25E7: 0xFFFD,
	0x25E8: 0xFFFD,
	0x25E9: 0xFFFD,
	0x25EA: 0xFFFD,
	0x25EB: 0xFFFD,
	0x25EC: 0xFFFD,
	0x25ED: 0xFFFD,
	0x25EE: 0xFFFD,
	0x25EF: 0xA1B3,
	0x25F0: 0xFFFD,
	0x25F1: 0xFFFD,
	0x25F2: 0xFFFD,
	0x25F3: 0xFFFD,
	0x25F4: 0xFFFD,
	0x25F5: 0xFFFD,
	0x25F6: 0xFFFD,
	0x25F7: 0xFFFD,
	0x25F8: 0xFFFD,
	0x25F9: 0xFFFD,
	0x25FA: 0xFFFD,
	0x25FB: 0xFFFD,
	0x25FC: 0xFFFD,
	0x25FD: 0xFFFD,
	0x25FE: 0xFFFD,
	0x25FF: 0xFFFD,
	0x2600: 0xFFFD,
	0x2601: 0x9DBA,
	0x2602: 0x9DBC,
	0x2603: 0xFFFD,
	0x2604: 0xFFFD,
	0x2605: 0xA1B9,
	0x2606: 0xA1B8,
	0x2607: 0xFFFD,
	0x2608: 0xFFFD,
	0x2609: 0xA1F3,
	0x260A: 0xFFFD,
	0x260B: 0xFFFD,
	0x260C: 0xFFFD,
	0x260D: 0xFFFD,
	0x260E: 0x9D40,
	0x260F: 0xFFFD,
	0x2610: 0xFFFD,
	0x2611: 0x9DED,
	0x2612: 0x9CD1,
	0x2613: 0xFFFD,
	0x2614: 0xFFFD,
	0x2615: 0xFFFD,
	0x2616: 0xFFFD,
	0x2617: 0xFFFD,
	0x2618: 0xFFFD,
	0x2619: 0xFFFD,
	0x261A: 0xFFFD,
	0x261B: 0x9D4F,
	0x261C: 0x9D4E,
	0x261D: 0xFFFD,
	0x261E: 0x9D4D,
	0x261F: 0x9D50,
	0x2620: 0x9DD5,
	0x2621: 0xFFFD,
	0x2622: 0xFFFD,
	0x2623: 0xFFFD,
	0x2624: 0xFFFD,
	0x2625: 0xFFFD,
	0x2626: 0xFFFD,
	0x2627: 0xFFFD,
	0x2628: 0xFFFD,
	0x2629: 0xFFFD,
	0x262A: 0xFFFD,
	0x262B: 0xFFFD,
	0x262C: 0xFFFD,
	0x262D: 0xFFFD,
	0x262E: 0xFFFD,
	0x262F: 0x9F55,
	0x2630: 0x9F56,
	0x2631: 0x9F5D,
	0x2632: 0x9F5B,
	0x2633: 0x9F58,
	0x2634: 0x9F59,
	0x2635: 0x9F5A,
	0x2636: 0x9F5C,
	0x2637: 0x9F57,
	0x2638: 0xFFFD,
	0x2639: 0x9D5E,
	0x263A: 0x9D5D,
	0x263B: 0x98FC,
	0x263C: 0x9DB8,
	0x263D: 0x9D57,
	0x263E: 0xFFFD,
	0x263F: 0xFFFD,
	0x2640: 0xA1F0,
	0x2641: 0xA1F2,
	0x2642: 0xA1F1,
	0x2643: 0xFFFD,
	0x2644: 0xFFFD,
	0x2645: 0xFFFD,
	0x2646: 0xFFFD,
	0x2647: 0xFFFD,
	0x2648: 0xFFFD,
	0x2649: 0xFFFD,
	0x264A: 0xFFFD,
	0x264B: 0xFFFD,
	0x264C: 0xFFFD,
	0x264D: 0xFFFD,
	0x264E: 0xFFFD,
	0x264F: 0xFFFD,
	0x2650: 0xFFFD,
	0x2651: 0xFFFD,
	0x2652: 0xFFFD,
	0x2653: 0xFFFD,
	0x2654: 0xFFFD,
	0x2655: 0xFFFD,
	0x2656: 0xFFFD,
	0x2657: 0xFFFD,
	0x2658: 0xFFFD,
	0x2659: 0xFFFD,
	0x265A: 0xFFFD,
	0x265B: 0xFFFD,
	0x265C: 0xFFFD,
	0x265D: 0xFFFD,
	0x265E: 0xFFFD,
	0x265F: 0xFFFD,
	0x2660: 0x9DD8,
	0x2661: 0x9DDD,
	0x2662: 0x9DDB,
	0x2663: 0x9DDA,
	0x2664: 0x9DD7,
	0x2665: 0x9DDE,
	0x2666: 0x9DDC,
	0x2667: 0x9DD9,
	0x2668: 0xFFFD,
	0x2669: 0xFFFD,
	0x266A: 0x9D66,
	0x266B: 0xFFFD,
	0x266C: 0x9D65,
	0x266D: 0xA2EA,
	0x266E: 0xFFFD,
	0x266F: 0xA1AD,
	0x2670: 0xFFFD,
	0x2671: 0xFFFD,
	0x2672: 0xFFFD,
	0x2673: 0xFFFD,
	0x2674: 0xFFFD,
	0x2675: 0xFFFD,
	0x2676: 0xFFFD,
	0x2677: 0xFFFD,
	0x2678: 0xFFFD,
	0x2679: 0xFFFD,
	0x267A: 0xFFFD,
	0x267B: 0xFFFD,
	0x267C: 0xFFFD,
	0x267D: 0xFFFD,
	0x267E: 0xFFFD,
	0x267F: 0xFFFD,
	0x2680: 0xFFFD,
	0x2681: 0xFFFD,
	0x2682: 0xFFFD,
	0x2683: 0xFFFD,
	0x2684: 0xFFFD,
	0x2685: 0xFFFD,
	0x2686: 0xFFFD,
	0x2687: 0xFFFD,
	0x2688: 0xFFFD,
	0x2689: 0xFFFD,
	0x268A: 0xFFFD,
	0x268B: 0xFFFD,
	0x268C: 0xFFFD,
	0x268D: 0xFFFD,
	0x268E: 0xFFFD,
	0x268F: 0xFFFD,
	0x2690: 0xFFFD,
	0x2691: 0xFFFD,
	0x2692: 0xFFFD,
	0x2693: 0xFFFD,
	0x2694: 0xFFFD,
	0x2695: 0xFFFD,
	0x2696: 0xFFFD,
	0x2697: 0xFFFD,
	0x2698: 0xFFFD,
	0x2699: 0xFFFD,
	0x269A: 0xFFFD,
	0x269B: 0xFFFD,
	0x269C: 0xFFFD,
	0x269D: 0xFFFD,
	0x269E: 0xFFFD,
	0x269F: 0xFFFD,
	0x26A0: 0xFFFD,
	0x26A1: 0xFFFD,
	0x26A2: 0xFFFD,
	0x26A3: 0xFFFD,
	0x26A4: 0xFFFD,
	0x26A5: 0xFFFD,
	0x26A6: 0xFFFD,
	0x26A7: 0xFFFD,
	0x26A8: 0xFFFD,
	0x26A9: 0xFFFD,
	0x26AA: 0xFFFD,
	0x26AB: 0xFFFD,
	0x26AC: 0xFFFD,
	0x26AD: 0xFFFD,
	0x26AE: 0xFFFD,
	0x26AF: 0xFFFD,
	0x26B0: 0xFFFD,
	0x26B1: 0xFFFD,
	0x26B2: 0xFFFD,
	0x26B3: 0xFFFD,
	0x26B4: 0xFFFD,
	0x26B5: 0xFFFD,
	0x26B6: 0xFFFD,
	0x26B7: 0xFFFD,
	0x26B8: 0xFFFD,
	0x26B9: 0xFFFD,
	0x26BA: 0xFFFD,
	0x26BB: 0xFFFD,
	0x26BC: 0xFFFD,
	0x26BD: 0xFFFD,
	0x26BE: 0xFFFD,
	0x26BF: 0xFFFD,
	0x26C0: 0xFFFD,
	0x26C1: 0xFFFD,
	0x26C2: 0xFFFD,
	0x26C3: 0xFFFD,
	0x26C4: 0xFFFD,
	0x26C5: 0xFFFD,
	0x26C6: 0xFFFD,
	0x26C7: 0xFFFD,
	0x26C8: 0xFFFD,
	0x26C9: 0xFFFD,
	0x26CA: 0xFFFD,
	0x26CB: 0xFFFD,
	0x26CC: 0xFFFD,
	0x26CD: 0xFFFD,
	0x26CE: 0xFFFD,
	0x26CF: 0xFFFD,
	0x26D0: 0xFFFD,
	0x26D1: 0xFFFD,
	0x26D2: 0xFFFD,
	0x26D3: 0xFFFD,
	0x26D4: 0xFFFD,
	0x26D5: 0xFFFD,
	0x26D6: 0xFFFD,
	0x26D7: 0xFFFD,
	0x26D8: 0xFFFD,
	0x26D9: 0xFFFD,
	0x26DA: 0xFFFD,
	0x26DB: 0xFFFD,
	0x26DC: 0xFFFD,
	0x26DD: 0xFFFD,
	0x26DE: 0xFFFD,
	0x26DF: 0xFFFD,
	0x26E0: 0xFFFD,
	0x26E1: 0xFFFD,
	0x26E2: 0xFFFD,
	0x26E3: 0xFFFD,
	0x26E4: 0xFFFD,
	0x26E5: 0xFFFD,
	0x26E6: 0xFFFD,
	0x26E7: 0xFFFD,
	0x26E8: 0xFFFD,
	0x26E9: 0xFFFD,
	0x26EA: 0xFFFD,
	0x26EB: 0xFFFD,
	0x26EC: 0xFFFD,
	0x26ED: 0xFFFD,
	0x26EE: 0xFFFD,
	0x26EF: 0xFFFD,
	0x26F0: 0xFFFD,
	0x26F1: 0xFFFD,
	0x26F2: 0xFFFD,
	0x26F3: 0xFFFD,
	0x26F4: 0xFFFD,
	0x26F5: 0xFFFD,
	0x26F6: 0xFFFD,
	0x26F7: 0xFFFD,
	0x26F8: 0xFFFD,
	0x26F9: 0xFFFD,
	0x26FA: 0xFFFD,
	0x26FB: 0xFFFD,
	0x26FC: 0xFFFD,
	0x26FD: 0xFFFD,
	0x26FE: 0xFFFD,
	0x26FF: 0xFFFD,
	0x2700: 0xFFFD,
	0x2701: 0xFFFD,
	0x2702: 0x9D6C,
	0x2703: 0xFFFD,
	0x2704: 0xFFFD,
	0x2705: 0xFFFD,
	0x2706: 0xFFFD,
	0x2707: 0xFFFD,
	0x2708: 0x9DC0,
	0x2709: 0x9D6B,
	0x270A: 0xFFFD,
	0x270B: 0xFFFD,
	0x270C: 0xFFFD,
	0x270D: 0xFFFD,
	0x270E: 0xFFFD,
	0x270F: 0xFFFD,
	0x2710: 0xFFFD,
	0x2711: 0xFFFD,
	0x2712: 0xFFFD,
	0x2713: 0x9D55,
	0x2714: 0xFFFD,
	0x2715: 0x9D54,
	0x2716: 0xFFFD,
	0x2717: 0xFFFD,
	0x2718: 0xFFFD,
	0x2719: 0xFFFD,
	0x271A: 0xFFFD,
	0x271B: 0xFFFD,
	0x271C: 0xFFFD,
	0x271D: 0xFFFD,
	0x271E: 0xFFFD,
	0x271F: 0xFFFD,
	0x2720: 0xFFFD,
	0x2721: 0x9D5C,
	0x2722: 0xFFFD,
	0x2723: 0xFFFD,
	0x2724: 0xFFFD,
	0x2725: 0xFFFD,
	0x2726: 0xFFFD,
	0x2727: 0xFFFD,
	0x2728: 0xFFFD,
	0x2729: 0x9D5B,
	0x272A: 0xFFFD,
	0x272B: 0xFFFD,
	0x272C: 0xFFFD,
	0x272D: 0xFFFD,
	0x272E: 0xFFFD,
	0x272F: 0xFFFD,
	0x2730: 0xFFFD,
	0x2731: 0xFFFD,
	0x2732: 0xFFFD,
	0x2733: 0xFFFD,
	0x2734: 0xFFFD,
	0x2735: 0xFFFD,
	0x2736: 0xFFFD,
	0x2737: 0xFFFD,
	0x2738: 0xFFFD,
	0x2739: 0xFFFD,
	0x273A: 0xFFFD,
	0x273B: 0xFFFD,
	0x273C: 0xFFFD,
	0x273D: 0xC6E6,
	0x273E: 0xFFFD,
	0x273F: 0xFFFD,
	0x2740: 0xFFFD,
	0x2741: 0xFFFD,
	0x2742: 0xFFFD,
	0x2743: 0xFFFD,
	0x2744: 0xFFFD,
	0x2745: 0xFFFD,
	0x2746: 0xFFFD,
	0x2747: 0xFFFD,
	0x2748: 0xFFFD,
	0x2749: 0xFFFD,
	0x274A: 0xFFFD,
	0x274B: 0xFFFD,
	0x274C: 0xFFFD,
	0x274D: 0xFFFD,
	0x274E: 0xFFFD,
	0x274F: 0x9D77,
	0x2750: 0xFFFD,
	0x2751: 0xFFFD,
	0x2752: 0xFFFD,
	0x2753: 0xFFFD,
	0x2754: 0xFFFD,
	0x2755: 0xFFFD,
	0x2756: 0xFFFD,
	0x2757: 0xFFFD,
	0x2758: 0xFFFD,
	0x2759: 0xFFFD,
	0x275A: 0xFFFD,
	0x275B: 0xFFFD,
	0x275C: 0xFFFD,
	0x275D: 0xFFFD,
	0x275E: 0xFFFD,
	0x275F: 0xFFFD,
	0x2760: 0xFFFD,
	0x2761: 0xFFFD,
	0x2762: 0xFFFD,
	0x2763: 0xFFFD,
	0x2764: 0xFFFD,
	0x2765: 0xFFFD,
	0x2766: 0xFFFD,
	0x2767: 0xFFFD,
	0x2768: 0xFFFD,
	0x2769: 0xFFFD,
	0x276A: 0xFFFD,
	0x276B: 0xFFFD,
	0x276C: 0xFFFD,
	0x276D: 0xFFFD,
	0x276E: 0xFFFD,
	0x276F: 0xFFFD,
	0x2770: 0xFFFD,
	0x2771: 0xFFFD,
	0x2772: 0xFFFD,
	0x2773: 0xFFFD,
	0x2774: 0xFFFD,
	0x2775: 0xFFFD,
	0x2776: 0x9841,
	0x2777: 0x9842,
	0x2778: 0x9843,
	0x2779: 0x9844,
	0x277A: 0x9845,
	0x277B: 0x9846,
	0x277C: 0x9847,
	0x277D: 0x9848,
	0x277E: 0x9849,
	0x277F: 0x984A,
	0x2780: 0xC6A1,
	0x2781: 0xC6A2,
	0x2782: 0xC6A3,
	0x2783: 0xC6A4,
	0x2784: 0xC6A5,
	0x2785: 0xC6A6,
	0x2786: 0xC6A7,
	0x2787: 0xC6A8,
	0x2788: 0xC6A9,
	0x2789: 0xC6AA,
	0x278A: 0x9841,
	0x278B: 0x9842,
	0x278C: 0x9843,
	0x278D: 0x9844,
	0x278E: 0x9845,
	0x278F: 0x9846,
	0x2790: 0x9847,
	0x2791: 0x9848,
	0x2792: 0x9849,
	0x2793: 0x984A,
	0x2794: 0xFFFD,
	0x2795: 0xFFFD,
	0x2796: 0xFFFD,
	0x2797: 0xFFFD,
	0x2798: 0xFFFD,
	0x2799: 0xFFFD,
	0x279A: 0xFFFD,
	0x279B: 0xFFFD,
	0x279C: 0xFFFD,
	0x279D: 0xFFFD,
	0x279E: 0xFFFD,
	0x279F: 0xFFFD,
	0x27A0: 0xFFFD,
	0x27A1: 0xFFFD,
	0x27A2: 0xFFFD,
	0x27A3: 0xFFFD,
	0x27A4: 0xFFFD,
	0x27A5: 0xFFFD,
	0x27A6: 0xFFFD,
	0x27A7: 0xFFFD,
	0x27A8: 0xFFFD,
	0x27A9: 0xFFFD,
	0x27AA: 0xFFFD,
	0x27AB: 0xFFFD,
	0x27AC: 0xFFFD,
	0x27AD: 0xFFFD,
	0x27AE: 0xFFFD,
	0x27AF: 0xFFFD,
	0x27B0: 0xFFFD,
	0x27B1: 0xFFFD,
	0x27B2: 0xFFFD,
	0x27B3: 0xFFFD,
	0x27B4: 0xFFFD,
	0x27B5: 0xFFFD,
	0x27B6: 0xFFFD,
	0x27B7: 0xFFFD,
	0x27B8: 0xFFFD,
	0x27B9: 0xFFFD,
	0x27BA: 0xFFFD,
	0x27BB: 0xFFFD,
	0x27BC: 0xFFFD,
	0x27BD: 0xFFFD,
	0x27BE: 0xFFFD,
	0x27BF: 0xFFFD,
	0x27C0: 0xFFFD,
	0x27C1: 0xFFFD,
	0x27C2: 0xFFFD,
	0x27C3: 0xFFFD,
	0x27C4: 0xFFFD,
	0x27C5: 0xFFFD,
	0x27C6: 0xFFFD,
	0x27C7: 0xFFFD,
	0x27C8: 0xFFFD,
	0x27C9: 0xFFFD,
	0x27CA: 0xFFFD,
	0x27CB: 0xFFFD,
	0x27CC: 0xFFFD,
	0x27CD: 0xFFFD,
	0x27CE: 0xFFFD,
	0x27CF: 0xFFFD,
	0x27D0: 0xFFFD,
	0x27D1: 0xFFFD,
	0x27D2: 0xFFFD,
	0x27D3: 0xFFFD,
	0x27D4: 0xFFFD,
	0x27D5: 0xFFFD,
	0x27D6: 0xFFFD,
	0x27D7: 0xFFFD,
	0x27D8: 0xFFFD,
	0x27D9: 0xFFFD,
	0x27DA: 0xFFFD,
	0x27DB: 0xFFFD,
	0x27DC: 0xFFFD,
	0x27DD: 0xFFFD,
	0x27DE: 0xFFFD,
	0x27DF: 0xFFFD,
	0x27E0: 0xFFFD,
	0x27E1: 0xFFFD,
	0x27E2: 0xFFFD,
	0x27E3: 0xFFFD,
	0x27E4: 0xFFFD,
	0x27E5: 0xFFFD,
	0x27E6: 0xFFFD,
	0x27E7: 0xFFFD,
	0x27E8: 0xFFFD,
	0x27E9: 0xFFFD,
	0x27EA: 0xFFFD,
	0x27EB: 0xFFFD,
	0x27EC: 0xFFFD,
	0x27ED: 0xFFFD,
	0x27EE: 0xFFFD,
	0x27EF: 0xFFFD,
	0x27F0: 0xFFFD,
	0x27F1: 0xFFFD,
	0x27F2: 0xFFFD,
	0x27F3: 0xFFFD,
	0x27F4: 0xFFFD,
	0x27F5: 0xFFFD,
	0x27F6: 0xFFFD,
	0x27F7: 0xFFFD,
	0x27F8: 0xFFFD,
	0x27F9: 0xFFFD,
	0x27FA: 0xFFFD,
	0x27FB: 0xFFFD,
	0x27FC: 0xFFFD,
	0x27FD: 0xFFFD,
	0x27FE: 0xFFFD,
	0x27FF: 0xFFFD,
	0x2800: 0xFFFD,
	0x2801: 0xFFFD,
	0x2802: 0xFFFD,
	0x2803: 0xFFFD,
	0x2804: 0xFFFD,
	0x2805: 0xFFFD,
	0x2806: 0xFFFD,
	0x2807: 0xFFFD,
	0x2808: 0xFFFD,
	0x2809: 0xFFFD,
	0x280A: 0xFFFD,
	0x280B: 0xFFFD,
	0x280C: 0xFFFD,
	0x280D: 0xFFFD,
	0x280E: 0xFFFD,
	0x280F: 0xFFFD,
	0x2810: 0xFFFD,
	0x2811: 0xFFFD,
	0x2812: 0xFFFD,
	0x2813: 0xFFFD,
	0x2814: 0xFFFD,
	0x2815: 0xFFFD,
	0x2816: 0xFFFD,
	0x2817: 0xFFFD,
	0x2818: 0xFFFD,
	0x2819: 0xFFFD,
	0x281A: 0xFFFD,
	0x281B: 0xFFFD,
	0x281C: 0xFFFD,
	0x281D: 0xFFFD,
	0x281E: 0xFFFD,
	0x281F: 0xFFFD,
	0x2820: 0xFFFD,
	0x2821: 0xFFFD,
	0x2822: 0xFFFD,
	0x2823: 0xFFFD,
	0x2824: 0xFFFD,
	0x2825: 0xFFFD,
	0x2826: 0xFFFD,
	0x2827: 0xFFFD,
	0x2828: 0xFFFD,
	0x2829: 0xFFFD,
	0x282A: 0xFFFD,
	0x282B: 0xFFFD,
	0x282C: 0xFFFD,
	0x282D: 0xFFFD,
	0x282E: 0xFFFD,
	0x282F: 0xFFFD,
	0x2830: 0xFFFD,
	0x2831: 0xFFFD,
	0x2832: 0xFFFD,
	0x2833: 0xFFFD,
	0x2834: 0xFFFD,
	0x2835: 0xFFFD,
	0x2836: 0xFFFD,
	0x2837: 0xFFFD,
	0x2838: 0xFFFD,
	0x2839: 0xFFFD,
	0x283A: 0xFFFD,
	0x283B: 0xFFFD,
	0x283C: 0xFFFD,
	0x283D: 0xFFFD,
	0x283E: 0xFFFD,
	0x283F: 0xFFFD,
	0x2840: 0xFFFD,
	0x2841: 0xFFFD,
	0x2842: 0xFFFD,
	0x2843: 0xFFFD,
	0x2844: 0xFFFD,
	0x2845: 0xFFFD,
	0x2846: 0xFFFD,
	0x2847: 0xFFFD,
	0x2848: 0xFFFD,
	0x2849: 0xFFFD,
	0x284A: 0xFFFD,
	0x284B: 0xFFFD,
	0x284C: 0xFFFD,
	0x284D: 0xFFFD,
	0x284E: 0xFFFD,
	0x284F: 0xFFFD,
	0x2850: 0xFFFD,
	0x2851: 0xFFFD,
	0x2852: 0xFFFD,
	0x2853: 0xFFFD,
	0x2854: 0xFFFD,
	0x2855: 0xFFFD,
	0x2856: 0xFFFD,
	0x2857: 0xFFFD,
	0x2858: 0xFFFD,
	0x2859: 0xFFFD,
	0x285A: 0xFFFD,
	0x285B: 0xFFFD,
	0x285C: 0xFFFD,
	0x285D: 0xFFFD,
	0x285E: 0xFFFD,
	0x285F: 0xFFFD,
	0x2860: 0xFFFD,
	0x2861: 0xFFFD,
	0x2862: 0xFFFD,
	0x2863: 0xFFFD,
	0x2864: 0xFFFD,
	0x2865: 0xFFFD,
	0x2866: 0xFFFD,
	0x2867: 0xFFFD,
	0x2868: 0xFFFD,
	0x2869: 0xFFFD,
	0x286A: 0xFFFD,
	0x286B: 0xFFFD,
	0x286C: 0xFFFD,
	0x286D: 0xFFFD,
	0x286E: 0xFFFD,
	0x286F: 0xFFFD,
	0x2870: 0xFFFD,
	0x2871: 0xFFFD,
	0x2872: 0xFFFD,
	0x2873: 0xFFFD,
	0x2874: 0xFFFD,
	0x2875: 0xFFFD,
	0x2876: 0xFFFD,
	0x2877: 0xFFFD,
	0x2878: 0xFFFD,
	0x2879: 0xFFFD,
	0x287A: 0xFFFD,
	0x287B: 0xFFFD,
	0x287C: 0xFFFD,
	0x287D: 0xFFFD,
	0x287E: 0xFFFD,
	0x287F: 0xFFFD,
	0x2880: 0xFFFD,
	0x2881: 0xFFFD,
	0x2882: 0xFFFD,
	0x2883: 0xFFFD,
	0x2884: 0xFFFD,
	0x2885: 0xFFFD,
	0x2886: 0xFFFD,
	0x2887: 0xFFFD,
	0x2888: 0xFFFD,
	0x2889: 0xFFFD,
	0x288A: 0xFFFD,
	0x288B: 0xFFFD,
	0x288C: 0xFFFD,
	0x288D: 0xFFFD,
	0x288E: 0xFFFD,
	0x288F: 0xFFFD,
	0x2890: 0xFFFD,
	0x2891: 0xFFFD,
	0x2892: 0xFFFD,
	0x2893: 0xFFFD,
	0x2894: 0xFFFD,
	0x2895: 0xFFFD,
	0x2896: 0xFFFD,
	0x2897: 0xFFFD,
	0x2898: 0xFFFD,
	0x2899: 0xFFFD,
	0x289A: 0xFFFD,
	0x289B: 0xFFFD,
	0x289C: 0xFFFD,
	0x289D: 0xFFFD,
	0x289E: 0xFFFD,
	0x289F: 0xFFFD,
	0x28A0: 0xFFFD,
	0x28A1: 0xFFFD,
	0x28A2: 0xFFFD,
	0x28A3: 0xFFFD,
	0x28A4: 0xFFFD,
	0x28A5: 0xFFFD,
	0x28A6: 0xFFFD,
	0x28A7: 0xFFFD,
	0x28A8: 0xFFFD,
	0x28A9: 0xFFFD,
	0x28AA: 0xFFFD,
	0x28AB: 0xFFFD,
	0x28AC: 0xFFFD,
	0x28AD: 0xFFFD,
	0x28AE: 0xFFFD,
	0x28AF: 0xFFFD,
	0x28B0: 0xFFFD,
	0x28B1: 0xFFFD,
	0x28B2: 0xFFFD,
	0x28B3: 0xFFFD,
	0x28B4: 0xFFFD,
	0x28B5: 0xFFFD,
	0x28B6: 0xFFFD,
	0x28B7: 0xFFFD,
	0x28B8: 0xFFFD,
	0x28B9: 0xFFFD,
	0x28BA: 0xFFFD,
	0x28BB: 0xFFFD,
	0x28BC: 0xFFFD,
	0x28BD: 0xFFFD,
	0x28BE: 0xFFFD,
	0x28BF: 0xFFFD,
	0x28C0: 0xFFFD,
	0x28C1: 0xFFFD,
	0x28C2: 0xFFFD,
	0x28C3: 0xFFFD,
	0x28C4: 0xFFFD,
	0x28C5: 0xFFFD,
	0x28C6: 0xFFFD,
	0x28C7: 0xFFFD,
	0x28C8: 0xFFFD,
	0x28C9: 0xFFFD,
	0x28CA: 0xFFFD,
	0x28CB: 0xFFFD,
	0x28CC: 0xFFFD,
	0x28CD: 0xFFFD,
	0x28CE: 0xFFFD,
	0x28CF: 0xFFFD,
	0x28D0: 0xFFFD,
	0x28D1: 0xFFFD,
	0x28D2: 0xFFFD,
	0x28D3: 0xFFFD,
	0x28D4: 0xFFFD,
	0x28D5: 0xFFFD,
	0x28D6: 0xFFFD,
	0x28D7: 0xFFFD,
	0x28D8: 0xFFFD,
	0x28D9: 0xFFFD,
	0x28DA: 0xFFFD,
	0x28DB: 0xFFFD,
	0x28DC: 0xFFFD,
	0x28DD: 0xFFFD,
	0x28DE: 0xFFFD,
	0x28DF: 0xFFFD,
	0x28E0: 0xFFFD,
	0x28E1: 0xFFFD,
	0x28E2: 0xFFFD,
	0x28E3: 0xFFFD,
	0x28E4: 0xFFFD,
	0x28E5: 0xFFFD,
	0x28E6: 0xFFFD,
	0x28E7: 0xFFFD,
	0x28E8: 0xFFFD,
	0x28E9: 0xFFFD,
	0x28EA: 0xFFFD,
	0x28EB: 0xFFFD,
	0x28EC: 0xFFFD,
	0x28ED: 0xFFFD,
	0x28EE: 0xFFFD,
	0x28EF: 0xFFFD,
	0x28F0: 0xFFFD,
	0x28F1: 0xFFFD,
	0x28F2: 0xFFFD,
	0x28F3: 0xFFFD,
	0x28F4: 0xFFFD,
	0x28F5: 0xFFFD,
	0x28F6: 0xFFFD,
	0x28F7: 0xFFFD,
	0x28F8: 0xFFFD,
	0x28F9: 0xFFFD,
	0x28FA: 0xFFFD,
	0x28FB: 0xFFFD,
	0x28FC: 0xFFFD,
	0x28FD: 0xFFFD,
	0x28FE: 0xFFFD,
	0x28FF: 0xFFFD,
	0x2900: 0xFFFD,
	0x2901: 0xFFFD,
	0x2902: 0xFFFD,
	0x2903: 0xFFFD,
	0x2904: 0xFFFD,
	0x2905: 0xFFFD,
	0x2906: 0xFFFD,
	0x2907: 0xFFFD,
	0x2908: 0xFFFD,
	0x2909: 0xFFFD,
	0x290A: 0xFFFD,
	0x290B: 0xFFFD,
	0x290C: 0xFFFD,
	0x290D: 0xFFFD,
	0x290E: 0xFFFD,
	0x290F: 0xFFFD,
	0x2910: 0xFFFD,
	0x2911: 0xFFFD,
	0x2912: 0xFFFD,
	0x2913: 0xFFFD,
	0x2914: 0xFFFD,
	0x2915: 0xFFFD,
	0x2916: 0xFFFD,
	0x2917: 0xFFFD,
	0x2918: 0xFFFD,
	0x2919: 0xFFFD,
	0x291A: 0xFFFD,
	0x291B: 0xFFFD,
	0x291C: 0xFFFD,
	0x291D: 0xFFFD,
	0x291E: 0xFFFD,
	0x291F: 0xFFFD,
	0x2920: 0xFFFD,
	0x2921: 0xFFFD,
	0x2922: 0xFFFD,
	0x2923: 0xFFFD,
	0x2924: 0xFFFD,
	0x2925: 0xFFFD,
	0x2926: 0xFFFD,
	0x2927: 0xFFFD,
	0x2928: 0xFFFD,
	0x2929: 0xFFFD,
	0x292A: 0xFFFD,
	0x292B: 0xFFFD,
	0x292C: 0xFFFD,
	0x292D: 0xFFFD,
	0x292E: 0xFFFD,
	0x292F: 0xFFFD,
	0x2930: 0xFFFD,
	0x2931: 0xFFFD,
	0x2932: 0xFFFD,
	0x2933: 0xFFFD,
	0x2934: 0xFFFD,
	0x2935: 0xFFFD,
	0x2936: 0xFFFD,
	0x2937: 0xFFFD,
	0x2938: 0xFFFD,
	0x2939: 0xFFFD,
	0x293A: 0xFFFD,
	0x293B: 0xFFFD,
	0x293C: 0xFFFD,
	0x293D: 0xFFFD,
	0x293E: 0xFFFD,
	0x293F: 0xFFFD,
	0x2940: 0xFFFD,
	0x2941: 0xFFFD,
	0x2942: 0xFFFD,
	0x2943: 0xFFFD,
	0x2944: 0xFFFD,
	0x2945: 0xFFFD,
	0x2946: 0xFFFD,
	0x2947: 0xFFFD,
	0x2948: 0xFFFD,
	0x2949: 0xFFFD,
	0x294A: 0xFFFD,
	0x294B: 0xFFFD,
	0x294C: 0xFFFD,
	0x294D: 0xFFFD,
	0x294E: 0xFFFD,
	0x294F: 0xFFFD,
	0x2950: 0xFFFD,
	0x2951: 0xFFFD,
	0x2952: 0xFFFD,
	0x2953: 0xFFFD,
	0x2954: 0xFFFD,
	0x2955: 0xFFFD,
	0x2956: 0xFFFD,
	0x2957: 0xFFFD,
	0x2958: 0xFFFD,
	0x2959: 0xFFFD,
	0x295A: 0xFFFD,
	0x295B: 0xFFFD,
	0x295C: 0xFFFD,
	0x295D: 0xFFFD,
	0x295E: 0xFFFD,
	0x295F: 0xFFFD,
	0x2960: 0xFFFD,
	0x2961: 0xFFFD,
	0x2962: 0xFFFD,
	0x2963: 0xFFFD,
	0x2964: 0xFFFD,
	0x2965: 0xFFFD,
	0x2966: 0xFFFD,
	0x2967: 0xFFFD,
	0x2968: 0xFFFD,
	0x2969: 0xFFFD,
	0x296A: 0xFFFD,
	0x296B: 0xFFFD,
	0x296C: 0xFFFD,
	0x296D: 0xFFFD,
	0x296E: 0xFFFD,
	0x296F: 0xFFFD,
	0x2970: 0xFFFD,
	0x2971: 0xFFFD,
	0x2972: 0xFFFD,
	0x2973: 0xFFFD,
	0x2974: 0xFFFD,
	0x2975: 0xFFFD,
	0x2976: 0xFFFD,
	0x2977: 0xFFFD,
	0x2978: 0xFFFD,
	0x2979: 0xFFFD,
	0x297A: 0xFFFD,
	0x297B: 0xFFFD,
	0x297C: 0xFFFD,
	0x297D: 0xFFFD,
	0x297E: 0xFFFD,
	0x297F: 0xFFFD,
	0x2980: 0xFFFD,
	0x2981: 0xFFFD,
	0x2982: 0xFFFD,
	0x2983: 0xFFFD,
	0x2984: 0xFFFD,
	0x2985: 0xFFFD,
	0x2986: 0xFFFD,
	0x2987: 0xFFFD,
	0x2988: 0xFFFD,
	0x2989: 0xFFFD,
	0x298A: 0xFFFD,
	0x298B: 0xFFFD,
	0x298C: 0xFFFD,
	0x298D: 0xFFFD,
	0x298E: 0xFFFD,
	0x298F: 0xFFFD,
	0x2990: 0xFFFD,
	0x2991: 0xFFFD,
	0x2992: 0xFFFD,
	0x2993: 0xFFFD,
	0x2994: 0xFFFD,
	0x2995: 0xFFFD,
	0x2996: 0xFFFD,
	0x2997: 0xFFFD,
	0x2998: 0xFFFD,
	0x2999: 0xFFFD,
	0x299A: 0xFFFD,
	0x299B: 0xFFFD,
	0x299C: 0xFFFD,
	0x299D: 0xFFFD,
	0x299E: 0xFFFD,
	0x299F: 0xFFFD,
	0x29A0: 0xFFFD,
	0x29A1: 0xFFFD,
	0x29A2: 0xFFFD,
	0x29A3: 0xFFFD,
	0x29A4: 0xFFFD,
	0x29A5: 0xFFFD,
	0x29A6: 0xFFFD,
	0x29A7: 0xFFFD,
	0x29A8: 0xFFFD,
	0x29A9: 0xFFFD,
	0x29AA: 0xFFFD,
	0x29AB: 0xFFFD,
	0x29AC: 0xFFFD,
	0x29AD: 0xFFFD,
	0x29AE: 0xFFFD,
	0x29AF: 0xFFFD,
	0x29B0: 0xFFFD,
	0x29B1: 0xFFFD,
	0x29B2: 0xFFFD,
	0x29B3: 0xFFFD,
	0x29B4: 0xFFFD,
	0x29B5: 0xFFFD,
	0x29B6: 0xFFFD,
	0x29B7: 0xFFFD,
	0x29B8: 0xFFFD,
	0x29B9: 0xFFFD,
	0x29BA: 0xFFFD,
	0x29BB: 0xFFFD,
	0x29BC: 0xFFFD,
	0x29BD: 0xFFFD,
	0x29BE: 0xFFFD,
	0x29BF: 0xFFFD,
	0x29C0: 0xFFFD,
	0x29C1: 0xFFFD,
	0x29C2: 0xFFFD,
	0x29C3: 0xFFFD,
	0x29C4: 0xFFFD,
	0x29C5: 0xFFFD,
	0x29C6: 0xFFFD,
	0x29C7: 0xFFFD,
	0x29C8: 0xFFFD,
	0x29C9: 0xFFFD,
	0x29CA: 0xFFFD,
	0x29CB: 0xFFFD,
	0x29CC: 0xFFFD,
	0x29CD: 0xFFFD,
	0x29CE: 0xFFFD,
	0x29CF: 0xFFFD,
	0x29D0: 0xFFFD,
	0x29D1: 0xFFFD,
	0x29D2: 0xFFFD,
	0x29D3: 0xFFFD,
	0x29D4: 0xFFFD,
	0x29D5: 0xFFFD,
	0x29D6: 0xFFFD,
	0x29D7: 0xFFFD,
	0x29D8: 0xFFFD,
	0x29D9: 0xFFFD,
	0x29DA: 0xFFFD,
	0x29DB: 0xFFFD,
	0x29DC: 0xFFFD,
	0x29DD: 0xFFFD,
	0x29DE: 0xFFFD,
	0x29DF: 0xFFFD,
	0x29E0: 0xFFFD,
	0x29E1: 0xFFFD,
	0x29E2: 0xFFFD,
	0x29E3: 0xFFFD,
	0x29E4: 0xFFFD,
	0x29E5: 0xFFFD,
	0x29E6: 0xFFFD,
	0x29E7: 0xFFFD,
	0x29E8: 0xFFFD,
	0x29E9: 0xFFFD,
	0x29EA: 0xFFFD,
	0x29EB: 0xFFFD,
	0x29EC: 0xFFFD,
	0x29ED: 0xFFFD,
	0x29EE: 0xFFFD,
	0x29EF: 0xFFFD,
	0x29F0: 0xFFFD,
	0x29F1: 0xFFFD,
	0x29F2: 0xFFFD,
	0x29F3: 0xFFFD,
	0x29F4: 0xFFFD,
	0x29F5: 0xFFFD,
	0x29F6: 0xFFFD,
	0x29F7: 0xFFFD,
	0x29F8: 0xFFFD,
	0x29F9: 0xFFFD,
	0x29FA: 0xFFFD,
	0x29FB: 0xFFFD,
	0x29FC: 0xFFFD,
	0x29FD: 0xFFFD,
	0x29FE: 0xFFFD,
	0x29FF: 0xFFFD,
	0x2A00: 0xFFFD,
	0x2A01: 0xFFFD,
	0x2A02: 0xFFFD,
	0x2A03: 0xFFFD,
	0x2A04: 0xFFFD,
	0x2A05: 0xFFFD,
	0x2A06: 0xFFFD,
	0x2A07: 0xFFFD,
	0x2A08: 0xFFFD,
	0x2A09: 0xFFFD,
	0x2A0A: 0xFFFD,
	0x2A0B: 0xFFFD,
	0x2A0C: 0xFFFD,
	0x2A0D: 0xFFFD,
	0x2A0E: 0xFFFD,
	0x2A0F: 0xFFFD,
	0x2A10: 0xFFFD,
	0x2A11: 0xFFFD,
	0x2A12: 0xFFFD,
	0x2A13: 0xFFFD,
	0x2A14: 0xFFFD,
	0x2A15: 0xFFFD,
	0x2A16: 0xFFFD,
	0x2A17: 0xFFFD,
	0x2A18: 0xFFFD,
	0x2A19: 0xFFFD,
	0x2A1A: 0xFFFD,
	0x2A1B: 0xFFFD,
	0x2A1C: 0xFFFD,
	0x2A1D: 0xFFFD,
	0x2A1E: 0xFFFD,
	0x2A1F: 0xFFFD,
	0x2A20: 0xFFFD,
	0x2A21: 0xFFFD,
	0x2A22: 0xFFFD,
	0x2A23: 0xFFFD,
	0x2A24: 0xFFFD,
	0x2A25: 0xFFFD,
	0x2A26: 0xFFFD,
	0x2A27: 0xFFFD,
	0x2A28: 0xFFFD,
	0x2A29: 0xFFFD,
	0x2A2A: 0xFFFD,
	0x2A2B: 0xFFFD,
	0x2A2C: 0xFFFD,
	0x2A2D: 0xFFFD,
	0x2A2E: 0xFFFD,
	0x2A2F: 0xFFFD,
	0x2A30: 0xFFFD,
	0x2A31: 0xFFFD,
	0x2A32: 0xFFFD,
	0x2A33: 0xFFFD,
	0x2A34: 0xFFFD,
	0x2A35: 0xFFFD,
	0x2A36: 0xFFFD,
	0x2A37: 0xFFFD,
	0x2A38: 0xFFFD,
	0x2A39: 0xFFFD,
	0x2A3A: 0xFFFD,
	0x2A3B: 0xFFFD,
	0x2A3C: 0xFFFD,
	0x2A3D: 0xFFFD,
	0x2A3E: 0xFFFD,
	0x2A3F: 0xFFFD,
	0x2A40: 0xFFFD,
	0x2A41: 0xFFFD,
	0x2A42: 0xFFFD,
	0x2A43: 0xFFFD,
	0x2A44: 0xFFFD,
	0x2A45: 0xFFFD,
	0x2A46: 0xFFFD,
	0x2A47: 0xFFFD,
	0x2A48: 0xFFFD,
	0x2A49: 0xFFFD,
	0x2A4A: 0xFFFD,
	0x2A4B: 0xFFFD,
	0x2A4C: 0xFFFD,
	0x2A4D: 0xFFFD,
	0x2A4E: 0xFFFD,
	0x2A4F: 0xFFFD,
	0x2A50: 0xFFFD,
	0x2A51: 0xFFFD,
	0x2A52: 0xFFFD,
	0x2A53: 0xFFFD,
	0x2A54: 0xFFFD,
	0x2A55: 0xFFFD,
	0x2A56: 0xFFFD,
	0x2A57: 0xFFFD,
	0x2A58: 0xFFFD,
	0x2A59: 0xFFFD,
	0x2A5A: 0xFFFD,
	0x2A5B: 0xFFFD,
	0x2A5C: 0xFFFD,
	0x2A5D: 0xFFFD,
	0x2A5E: 0xFFFD,
	0x2A5F: 0xFFFD,
	0x2A60: 0xFFFD,
	0x2A61: 0xFFFD,
	0x2A62: 0xFFFD,
	0x2A63: 0xFFFD,
	0x2A64: 0xFFFD,
	0x2A65: 0xFFFD,
	0x2A66: 0xFFFD,
	0x2A67: 0xFFFD,
	0x2A68: 0xFFFD,
	0x2A69: 0xFFFD,
	0x2A6A: 0xFFFD,
	0x2A6B: 0xFFFD,
	0x2A6C: 0xFFFD,
	0x2A6D: 0xFFFD,
	0x2A6E: 0xFFFD,
	0x2A6F: 0xFFFD,
	0x2A70: 0xFFFD,
	0x2A71: 0xFFFD,
	0x2A72: 0xFFFD,
	0x2A73: 0xFFFD,
	0x2A74: 0xFFFD,
	0x2A75: 0xFFFD,
	0x2A76: 0xFFFD,
	0x2A77: 0xFFFD,
	0x2A78: 0xFFFD,
	0x2A79: 0xFFFD,
	0x2A7A: 0xFFFD,
	0x2A7B: 0xFFFD,
	0x2A7C: 0xFFFD,
	0x2A7D: 0xFFFD,
	0x2A7E: 0xFFFD,
	0x2A7F: 0xFFFD,
	0x2A80: 0xFFFD,
	0x2A81: 0xFFFD,
	0x2A82: 0xFFFD,
	0x2A83: 0xFFFD,
	0x2A84: 0xFFFD,
	0x2A85: 0xFFFD,
	0x2A86: 0xFFFD,
	0x2A87: 0xFFFD,
	0x2A88: 0xFFFD,
	0x2A89: 0xFFFD,
	0x2A8A: 0xFFFD,
	0x2A8B: 0xFFFD,
	0x2A8C: 0xFFFD,
	0x2A8D: 0xFFFD,
	0x2A8E: 0xFFFD,
	0x2A8F: 0xFFFD,
	0x2A90: 0xFFFD,
	0x2A91: 0xFFFD,
	0x2A92: 0xFFFD,
	0x2A93: 0xFFFD,
	0x2A94: 0xFFFD,
	0x2A95: 0xFFFD,
	0x2A96: 0xFFFD,
	0x2A97: 0xFFFD,
	0x2A98: 0xFFFD,
	0x2A99: 0xFFFD,
	0x2A9A: 0xFFFD,
	0x2A9B: 0xFFFD,
	0x2A9C: 0xFFFD,
	0x2A9D: 0xFFFD,
	0x2A9E: 0xFFFD,
	0x2A9F: 0xFFFD,
	0x2AA0: 0xFFFD,
	0x2AA1: 0xFFFD,
	0x2AA2: 0xFFFD,
	0x2AA3: 0xFFFD,
	0x2AA4: 0xFFFD,
	0x2AA5: 0xFFFD,
	0x2AA6: 0xFFFD,
	0x2AA7: 0xFFFD,
	0x2AA8: 0xFFFD,
	0x2AA9: 0xFFFD,
	0x2AAA: 0xFFFD,
	0x2AAB: 0xFFFD,
	0x2AAC: 0xFFFD,
	0x2AAD: 0xFFFD,
	0x2AAE: 0xFFFD,
	0x2AAF: 0xFFFD,
	0x2AB0: 0xFFFD,
	0x2AB1: 0xFFFD,
	0x2AB2: 0xFFFD,
	0x2AB3: 0xFFFD,
	0x2AB4: 0xFFFD,
	0x2AB5: 0xFFFD,
	0x2AB6: 0xFFFD,
	0x2AB7: 0xFFFD,
	0x2AB8: 0xFFFD,
	0x2AB9: 0xFFFD,
	0x2ABA: 0xFFFD,
	0x2ABB: 0xFFFD,
	0x2ABC: 0xFFFD,
	0x2ABD: 0xFFFD,
	0x2ABE: 0xFFFD,
	0x2ABF: 0xFFFD,
	0x2AC0: 0xFFFD,
	0x2AC1: 0xFFFD,
	0x2AC2: 0xFFFD,
	0x2AC3: 0xFFFD,
	0x2AC4: 0xFFFD,
	0x2AC5: 0xFFFD,
	0x2AC6: 0xFFFD,
	0x2AC7: 0xFFFD,
	0x2AC8: 0xFFFD,
	0x2AC9: 0xFFFD,
	0x2ACA: 0xFFFD,
	0x2ACB: 0xFFFD,
	0x2ACC: 0xFFFD,
	0x2ACD: 0xFFFD,
	0x2ACE: 0xFFFD,
	0x2ACF: 0xFFFD,
	0x2AD0: 0xFFFD,
	0x2AD1: 0xFFFD,
	0x2AD2: 0xFFFD,
	0x2AD3: 0xFFFD,
	0x2AD4: 0xFFFD,
	0x2AD5: 0xFFFD,
	0x2AD6: 0xFFFD,
	0x2AD7: 0xFFFD,
	0x2AD8: 0xFFFD,
	0x2AD9: 0xFFFD,
	0x2ADA: 0xFFFD,
	0x2ADB: 0xFFFD,
	0x2ADC: 0xFFFD,
	0x2ADD: 0xFFFD,
	0x2ADE: 0xFFFD,
	0x2ADF: 0xFFFD,
	0x2AE0: 0xFFFD,
	0x2AE1: 0xFFFD,
	0x2AE2: 0xFFFD,
	0x2AE3: 0xFFFD,
	0x2AE4: 0xFFFD,
	0x2AE5: 0xFFFD,
	0x2AE6: 0xFFFD,
	0x2AE7: 0xFFFD,
	0x2AE8: 0xFFFD,
	0x2AE9: 0xFFFD,
	0x2AEA: 0xFFFD,
	0x2AEB: 0xFFFD,
	0x2AEC: 0xFFFD,
	0x2AED: 0xFFFD,
	0x2AEE: 0xFFFD,
	0x2AEF: 0xFFFD,
	0x2AF0: 0xFFFD,
	0x2AF1: 0xFFFD,
	0x2AF2: 0xFFFD,
	0x2AF3: 0xFFFD,
	0x2AF4: 0xFFFD,
	0x2AF5: 0xFFFD,
	0x2AF6: 0xFFFD,
	0x2AF7: 0xFFFD,
	0x2AF8: 0xFFFD,
	0x2AF9: 0xFFFD,
	0x2AFA: 0xFFFD,
	0x2AFB: 0xFFFD,
	0x2AFC: 0xFFFD,
	0x2AFD: 0xFFFD,
	0x2AFE: 0xFFFD,
	0x2AFF: 0xFFFD,
	0x2B00: 0xFFFD,
	0x2B01: 0xFFFD,
	0x2B02: 0xFFFD,
	0x2B03: 0xFFFD,
	0x2B04: 0xFFFD,
	0x2B05: 0xFFFD,
	0x2B06: 0xFFFD,
	0x2B07: 0xFFFD,
	0x2B08: 0xFFFD,
	0x2B09: 0xFFFD,
	0x2B0A: 0xFFFD,
	0x2B0B: 0xFFFD,
	0x2B0C: 0xFFFD,
	0x2B0D: 0xFFFD,
	0x2B0E: 0xFFFD,
	0x2B0F: 0xFFFD,
	0x2B10: 0xFFFD,
	0x2B11: 0xFFFD,
	0x2B12: 0xFFFD,
	0x2B13: 0xFFFD,
	0x2B14: 0xFFFD,
	0x2B15: 0xFFFD,
	0x2B16: 0xFFFD,
	0x2B17: 0xFFFD,
	0x2B18: 0xFFFD,
	0x2B19: 0xFFFD,
	0x2B1A: 0xFFFD,
	0x2B1B: 0xFFFD,
	0x2B1C: 0xFFFD,
	0x2B1D: 0xFFFD,
	0x2B1E: 0xFFFD,
	0x2B1F: 0xFFFD,
	0x2B20: 0xFFFD,
	0x2B21: 0xFFFD,
	0x2B22: 0xFFFD,
	0x2B23: 0xFFFD,
	0x2B24: 0xFFFD,
	0x2B25: 0xFFFD,
	0x2B26: 0xFFFD,
	0x2B27: 0xFFFD,
	0x2B28: 0xFFFD,
	0x2B29: 0xFFFD,
	0x2B2A: 0xFFFD,
	0x2B2B: 0xFFFD,
	0x2B2C: 0xFFFD,
	0x2B2D: 0xFFFD,
	0x2B2E: 0xFFFD,
	0x2B2F: 0xFFFD,
	0x2B30: 0xFFFD,
	0x2B31: 0xFFFD,
	0x2B32: 0xFFFD,
	0x2B33: 0xFFFD,
	0x2B34: 0xFFFD,
	0x2B35: 0xFFFD,
	0x2B36: 0xFFFD,
	0x2B37: 0xFFFD,
	0x2B38: 0xFFFD,
	0x2B39: 0xFFFD,
	0x2B3A: 0xFFFD,
	0x2B3B: 0xFFFD,
	0x2B3C: 0xFFFD,
	0x2B3D: 0xFFFD,
	0x2B3E: 0xFFFD,
	0x2B3F: 0xFFFD,
	0x2B40: 0xFFFD,
	0x2B41: 0xFFFD,
	0x2B42: 0xFFFD,
	0x2B43: 0xFFFD,
	0x2B44: 0xFFFD,
	0x2B45: 0xFFFD,
	0x2B46: 0xFFFD,
	0x2B47: 0xFFFD,
	0x2B48: 0xFFFD,
	0x2B49: 0xFFFD,
	0x2B4A: 0xFFFD,
	0x2B4B: 0xFFFD,
	0x2B4C: 0xFFFD,
	0x2B4D: 0xFFFD,
	0x2B4E: 0xFFFD,
	0x2B4F: 0xFFFD,
	0x2B50: 0xFFFD,
	0x2B51: 0xFFFD,
	0x2B52: 0xFFFD,
	0x2B53: 0xFFFD,
	0x2B54: 0xFFFD,
	0x2B55: 0xFFFD,
	0x2B56: 0xFFFD,
	0x2B57: 0xFFFD,
	0x2B58: 0xFFFD,
	0x2B59: 0xFFFD,
	0x2B5A: 0xFFFD,
	0x2B5B: 0xFFFD,
	0x2B5C: 0xFFFD,
	0x2B5D: 0xFFFD,
	0x2B5E: 0xFFFD,
	0x2B5F: 0xFFFD,
	0x2B60: 0xFFFD,
	0x2B61: 0xFFFD,
	0x2B62: 0xFFFD,
	0x2B63: 0xFFFD,
	0x2B64: 0xFFFD,
	0x2B65: 0xFFFD,
	0x2B66: 0xFFFD,
	0x2B67: 0xFFFD,
	0x2B68: 0xFFFD,
	0x2B69: 0xFFFD,
	0x2B6A: 0xFFFD,
	0x2B6B: 0xFFFD,
	0x2B6C: 0xFFFD,
	0x2B6D: 0xFFFD,
	0x2B6E: 0xFFFD,
	0x2B6F: 0xFFFD,
	0x2B70: 0xFFFD,
	0x2B71: 0xFFFD,
	0x2B72: 0xFFFD,
	0x2B73: 0xFFFD,
	0x2B74: 0xFFFD,
	0x2B75: 0xFFFD,
	0x2B76: 0xFFFD,
	0x2B77: 0xFFFD,
	0x2B78: 0xFFFD,
	0x2B79: 0xFFFD,
	0x2B7A: 0xFFFD,
	0x2B7B: 0xFFFD,
	0x2B7C: 0xFFFD,
	0x2B7D: 0xFFFD,
	0x2B7E: 0xFFFD,
	0x2B7F: 0xFFFD,
	0x2B80: 0xFFFD,
	0x2B81: 0xFFFD,
	0x2B82: 0xFFFD,
	0x2B83: 0xFFFD,
	0x2B84: 0xFFFD,
	0x2B85: 0xFFFD,
	0x2B86: 0xFFFD,
	0x2B87: 0xFFFD,
	0x2B88: 0xFFFD,
	0x2B89: 0xFFFD,
	0x2B8A: 0xFFFD,
	0x2B8B: 0xFFFD,
	0x2B8C: 0xFFFD,
	0x2B8D: 0xFFFD,
	0x2B8E: 0xFFFD,
	0x2B8F: 0xFFFD,
	0x2B90: 0xFFFD,
	0x2B91: 0xFFFD,
	0x2B92: 0xFFFD,
	0x2B93: 0xFFFD,
	0x2B94: 0xFFFD,
	0x2B95: 0xFFFD,
	0x2B96: 0xFFFD,
	0x2B97: 0xFFFD,
	0x2B98: 0xFFFD,
	0x2B99: 0xFFFD,
	0x2B9A: 0xFFFD,
	0x2B9B: 0xFFFD,
	0x2B9C: 0xFFFD,
	0x2B9D: 0xFFFD,
	0x2B9E: 0xFFFD,
	0x2B9F: 0xFFFD,
	0x2BA0: 0xFFFD,
	0x2BA1: 0xFFFD,
	0x2BA2: 0xFFFD,
	0x2BA3: 0xFFFD,
	0x2BA4: 0xFFFD,
	0x2BA5: 0xFFFD,
	0x2BA6: 0xFFFD,
	0x2BA7: 0xFFFD,
	0x2BA8: 0xFFFD,
	0x2BA9: 0xFFFD,
	0x2BAA: 0xFFFD,
	0x2BAB: 0xFFFD,
	0x2BAC: 0xFFFD,
	0x2BAD: 0xFFFD,
	0x2BAE: 0xFFFD,
	0x2BAF: 0xFFFD,
	0x2BB0: 0xFFFD,
	0x2BB1: 0xFFFD,
	0x2BB2: 0xFFFD,
	0x2BB3: 0xFFFD,
	0x2BB4: 0xFFFD,
	0x2BB5: 0xFFFD,
	0x2BB6: 0xFFFD,
	0x2BB7: 0xFFFD,
	0x2BB8: 0xFFFD,
	0x2BB9: 0xFFFD,
	0x2BBA: 0xFFFD,
	0x2BBB: 0xFFFD,
	0x2BBC: 0xFFFD,
	0x2BBD: 0xFFFD,
	0x2BBE: 0xFFFD,
	0x2BBF: 0xFFFD,
	0x2BC0: 0xFFFD,
	0x2BC1: 0xFFFD,
	0x2BC2: 0xFFFD,
	0x2BC3: 0xFFFD,
	0x2BC4: 0xFFFD,
	0x2BC5: 0xFFFD,
	0x2BC6: 0xFFFD,
	0x2BC7: 0xFFFD,
	0x2BC8: 0xFFFD,
	0x2BC9: 0xFFFD,
	0x2BCA: 0xFFFD,
	0x2BCB: 0xFFFD,
	0x2BCC: 0xFFFD,
	0x2BCD: 0xFFFD,
	0x2BCE: 0xFFFD,
	0x2BCF: 0xFFFD,
	0x2BD0: 0xFFFD,
	0x2BD1: 0xFFFD,
	0x2BD2: 0xFFFD,
	0x2BD3: 0xFFFD,
	0x2BD4: 0xFFFD,
	0x2BD5: 0xFFFD,
	0x2BD6: 0xFFFD,
	0x2BD7: 0xFFFD,
	0x2BD8: 0xFFFD,
	0x2BD9: 0xFFFD,
	0x2BDA: 0xFFFD,
	0x2BDB: 0xFFFD,
	0x2BDC: 0xFFFD,
	0x2BDD: 0xFFFD,
	0x2BDE: 0xFFFD,
	0x2BDF: 0xFFFD,
	0x2BE0: 0xFFFD,
	0x2BE1: 0xFFFD,
	0x2BE2: 0xFFFD,
	0x2BE3: 0xFFFD,
	0x2BE4: 0xFFFD,
	0x2BE5: 0xFFFD,
	0x2BE6: 0xFFFD,
	0x2BE7: 0xFFFD,
	0x2BE8: 0xFFFD,
	0x2BE9: 0xFFFD,
	0x2BEA: 0xFFFD,
	0x2BEB: 0xFFFD,
	0x2BEC: 0xFFFD,
	0x2BED: 0xFFFD,
	0x2BEE: 0xFFFD,
	0x2BEF: 0xFFFD,
	0x2BF0: 0xFFFD,
	0x2BF1: 0xFFFD,
	0x2BF2: 0xFFFD,
	0x2BF3: 0xFFFD,
	0x2BF4: 0xFFFD,
	0x2BF5: 0xFFFD,
	0x2BF6: 0xFFFD,
	0x2BF7: 0xFFFD,
	0x2BF8: 0xFFFD,
	0x2BF9: 0xFFFD,
	0x2BFA: 0xFFFD,
	0x2BFB: 0xFFFD,
	0x2BFC: 0xFFFD,
	0x2BFD: 0xFFFD,
	0x2BFE: 0xFFFD,
	0x2BFF: 0xFFFD,
	0x2C00: 0xFFFD,
	0x2C01: 0xFFFD,
	0x2C02: 0xFFFD,
	0x2C03: 0xFFFD,
	0x2C04: 0xFFFD,
	0x2C05: 0xFFFD,
	0x2C06: 0xFFFD,
	0x2C07: 0xFFFD,
	0x2C08: 0xFFFD,
	0x2C09: 0xFFFD,
	0x2C0A: 0xFFFD,
	0x2C0B: 0xFFFD,
	0x2C0C: 0xFFFD,
	0x2C0D: 0xFFFD,
	0x2C0E: 0xFFFD,
	0x2C0F: 0xFFFD,
	0x2C10: 0xFFFD,
	0x2C11: 0xFFFD,
	0x2C12: 0xFFFD,
	0x2C13: 0xFFFD,
	0x2C14: 0xFFFD,
	0x2C15: 0xFFFD,
	0x2C16: 0xFFFD,
	0x2C17: 0xFFFD,
	0x2C18: 0xFFFD,
	0x2C19: 0xFFFD,
	0x2C1A: 0xFFFD,
	0x2C1B: 0xFFFD,
	0x2C1C: 0xFFFD,
	0x2C1D: 0xFFFD,
	0x2C1E: 0xFFFD,
	0x2C1F: 0xFFFD,
	0x2C20: 0xFFFD,
	0x2C21: 0xFFFD,
	0x2C22: 0xFFFD,
	0x2C23: 0xFFFD,
	0x2C24: 0xFFFD,
	0x2C25: 0xFFFD,
	0x2C26: 0xFFFD,
	0x2C27: 0xFFFD,
	0x2C28: 0xFFFD,
	0x2C29: 0xFFFD,
	0x2C2A: 0xFFFD,
	0x2C2B: 0xFFFD,
	0x2C2C: 0xFFFD,
	0x2C2D: 0xFFFD,
	0x2C2E: 0xFFFD,
	0x2C2F: 0xFFFD,
	0x2C30: 0xFFFD,
	0x2C31: 0xFFFD,
	0x2C32: 0xFFFD,
	0x2C33: 0xFFFD,
	0x2C34: 0xFFFD,
	0x2C35: 0xFFFD,
	0x2C36: 0xFFFD,
	0x2C37: 0xFFFD,
	0x2C38: 0xFFFD,
	0x2C39: 0xFFFD,
	0x2C3A: 0xFFFD,
	0x2C3B: 0xFFFD,
	0x2C3C: 0xFFFD,
	0x2C3D: 0xFFFD,
	0x2C3E: 0xFFFD,
	0x2C3F: 0xFFFD,
	0x2C40: 0xFFFD,
	0x2C41: 0xFFFD,
	0x2C42: 0xFFFD,
	0x2C43: 0xFFFD,
	0x2C44: 0xFFFD,
	0x2C45: 0xFFFD,
	0x2C46: 0xFFFD,
	0x2C47: 0xFFFD,
	0x2C48: 0xFFFD,
	0x2C49: 0xFFFD,
	0x2C4A: 0xFFFD,
	0x2C4B: 0xFFFD,
	0x2C4C: 0xFFFD,
	0x2C4D: 0xFFFD,
	0x2C4E: 0xFFFD,
	0x2C4F: 0xFFFD,
	0x2C50: 0xFFFD,
	0x2C51: 0xFFFD,
	0x2C52: 0xFFFD,
	0x2C53: 0xFFFD,
	0x2C54: 0xFFFD,
	0x2C55: 0xFFFD,
	0x2C56: 0xFFFD,
	0x2C57: 0xFFFD,
	0x2C58: 0xFFFD,
	0x2C59: 0xFFFD,
	0x2C5A: 0xFFFD,
	0x2C5B: 0xFFFD,
	0x2C5C: 0xFFFD,
	0x2C5D: 0xFFFD,
	0x2C5E: 0xFFFD,
	0x2C5F: 0xFFFD,
	0x2C60: 0xFFFD,
	0x2C61: 0xFFFD,
	0x2C62: 0xFFFD,
	0x2C63: 0xFFFD,
	0x2C64: 0xFFFD,
	0x2C65: 0xFFFD,
	0x2C66: 0xFFFD,
	0x2C67: 0xFFFD,
	0x2C68: 0xFFFD,
	0x2C69: 0xFFFD,
	0x2C6A: 0xFFFD,
	0x2C6B: 0xFFFD,
	0x2C6C: 0xFFFD,
	0x2C6D: 0xFFFD,
	0x2C6E: 0xFFFD,
	0x2C6F: 0xFFFD,
	0x2C70: 0xFFFD,
	0x2C71: 0xFFFD,
	0x2C72: 0xFFFD,
	0x2C73: 0xFFFD,
	0x2C74: 0xFFFD,
	0x2C75: 0xFFFD,
	0x2C76: 0xFFFD,
	0x2C77: 0xFFFD,
	0x2C78: 0xFFFD,
	0x2C79: 0xFFFD,
	0x2C7A: 0xFFFD,
	0x2C7B: 0xFFFD,
	0x2C7C: 0xFFFD,
	0x2C7D: 0xFFFD,
	0x2C7E: 0xFFFD,
	0x2C7F: 0xFFFD,
	0x2C80: 0xFFFD,
	0x2C81: 0xFFFD,
	0x2C82: 0xFFFD,
	0x2C83: 0xFFFD,
	0x2C84: 0xFFFD,
	0x2C85: 0xFFFD,
	0x2C86: 0xFFFD,
	0x2C87: 0xFFFD,
	0x2C88: 0xFFFD,
	0x2C89: 0xFFFD,
	0x2C8A: 0xFFFD,
	0x2C8B: 0xFFFD,
	0x2C8C: 0xFFFD,
	0x2C8D: 0xFFFD,
	0x2C8E: 0xFFFD,
	0x2C8F: 0xFFFD,
	0x2C90: 0xFFFD,
	0x2C91: 0xFFFD,
	0x2C92: 0xFFFD,
	0x2C93: 0xFFFD,
	0x2C94: 0xFFFD,
	0x2C95: 0xFFFD,
	0x2C96: 0xFFFD,
	0x2C97: 0xFFFD,
	0x2C98: 0xFFFD,
	0x2C99: 0xFFFD,
	0x2C9A: 0xFFFD,
	0x2C9B: 0xFFFD,
	0x2C9C: 0xFFFD,
	0x2C9D: 0xFFFD,
	0x2C9E: 0xFFFD,
	0x2C9F: 0xFFFD,
	0x2CA0: 0xFFFD,
	0x2CA1: 0xFFFD,
	0x2CA2: 0xFFFD,
	0x2CA3: 0xFFFD,
	0x2CA4: 0xFFFD,
	0x2CA5: 0xFFFD,
	0x2CA6: 0xFFFD,
	0x2CA7: 0xFFFD,
	0x2CA8: 0xFFFD,
	0x2CA9: 0xFFFD,
	0x2CAA: 0xFFFD,
	0x2CAB: 0xFFFD,
	0x2CAC: 0xFFFD,
	0x2CAD: 0xFFFD,
	0x2CAE: 0xFFFD,
	0x2CAF: 0xFFFD,
	0x2CB0: 0xFFFD,
	0x2CB1: 0xFFFD,
	0x2CB2: 0xFFFD,
	0x2CB3: 0xFFFD,
	0x2CB4: 0xFFFD,
	0x2CB5: 0xFFFD,
	0x2CB6: 0xFFFD,
	0x2CB7: 0xFFFD,
	0x2CB8: 0xFFFD,
	0x2CB9: 0xFFFD,
	0x2CBA: 0xFFFD,
	0x2CBB: 0xFFFD,
	0x2CBC: 0xFFFD,
	0x2CBD: 0xFFFD,
	0x2CBE: 0xFFFD,
	0x2CBF: 0xFFFD,
	0x2CC0: 0xFFFD,
	0x2CC1: 0xFFFD,
	0x2CC2: 0xFFFD,
	0x2CC3: 0xFFFD,
	0x2CC4: 0xFFFD,
	0x2CC5: 0xFFFD,
	0x2CC6: 0xFFFD,
	0x2CC7: 0xFFFD,
	0x2CC8: 0xFFFD,
	0x2CC9: 0xFFFD,
	0x2CCA: 0xFFFD,
	0x2CCB: 0xFFFD,
	0x2CCC: 0xFFFD,
	0x2CCD: 0xFFFD,
	0x2CCE: 0xFFFD,
	0x2CCF: 0xFFFD,
	0x2CD0: 0xFFFD,
	0x2CD1: 0xFFFD,
	0x2CD2: 0xFFFD,
	0x2CD3: 0xFFFD,
	0x2CD4: 0xFFFD,
	0x2CD5: 0xFFFD,
	0x2CD6: 0xFFFD,
	0x2CD7: 0xFFFD,
	0x2CD8: 0xFFFD,
	0x2CD9: 0xFFFD,
	0x2CDA: 0xFFFD,
	0x2CDB: 0xFFFD,
	0x2CDC: 0xFFFD,
	0x2CDD: 0xFFFD,
	0x2CDE: 0xFFFD,
	0x2CDF: 0xFFFD,
	0x2CE0: 0xFFFD,
	0x2CE1: 0xFFFD,
	0x2CE2: 0xFFFD,
	0x2CE3: 0xFFFD,
	0x2CE4: 0xFFFD,
	0x2CE5: 0xFFFD,
	0x2CE6: 0xFFFD,
	0x2CE7: 0xFFFD,
	0x2CE8: 0xFFFD,
	0x2CE9: 0xFFFD,
	0x2CEA: 0xFFFD,
	0x2CEB: 0xFFFD,
	0x2CEC: 0xFFFD,
	0x2CED: 0xFFFD,
	0x2CEE: 0xFFFD,
	0x2CEF: 0xFFFD,
	0x2CF0: 0xFFFD,
	0x2CF1: 0xFFFD,
	0x2CF2: 0xFFFD,
	0x2CF3: 0xFFFD,
	0x2CF4: 0xFFFD,
	0x2CF5: 0xFFFD,
	0x2CF6: 0xFFFD,
	0x2CF7: 0xFFFD,
	0x2CF8: 0xFFFD,
	0x2CF9: 0xFFFD,
	0x2CFA: 0xFFFD,
	0x2CFB: 0xFFFD,
	0x2CFC: 0xFFFD,
	0x2CFD: 0xFFFD,
	0x2CFE: 0xFFFD,
	0x2CFF: 0xFFFD,
	0x2D00: 0xFFFD,
	0x2D01: 0xFFFD,
	0x2D02: 0xFFFD,
	0x2D03: 0xFFFD,
	0x2D04: 0xFFFD,
	0x2D05: 0xFFFD,
	0x2D06: 0xFFFD,
	0x2D07: 0xFFFD,
	0x2D08: 0xFFFD,
	0x2D09: 0xFFFD,
	0x2D0A: 0xFFFD,
	0x2D0B: 0xFFFD,
	0x2D0C: 0xFFFD,
	0x2D0D: 0xFFFD,
	0x2D0E: 0xFFFD,
	0x2D0F: 0xFFFD,
	0x2D10: 0xFFFD,
	0x2D11: 0xFFFD,
	0x2D12: 0xFFFD,
	0x2D13: 0xFFFD,
	0x2D14: 0xFFFD,
	0x2D15: 0xFFFD,
	0x2D16: 0xFFFD,
	0x2D17: 0xFFFD,
	0x2D18: 0xFFFD,
	0x2D19: 0xFFFD,
	0x2D1A: 0xFFFD,
	0x2D1B: 0xFFFD,
	0x2D1C: 0xFFFD,
	0x2D1D: 0xFFFD,
	0x2D1E: 0xFFFD,
	0x2D1F: 0xFFFD,
	0x2D20: 0xFFFD,
	0x2D21: 0xFFFD,
	0x2D22: 0xFFFD,
	0x2D23: 0xFFFD,
	0x2D24: 0xFFFD,
	0x2D25: 0xFFFD,
	0x2D26: 0xFFFD,
	0x2D27: 0xFFFD,
	0x2D28: 0xFFFD,
	0x2D29: 0xFFFD,
	0x2D2A: 0xFFFD,
	0x2D2B: 0xFFFD,
	0x2D2C: 0xFFFD,
	0x2D2D: 0xFFFD,
	0x2D2E: 0xFFFD,
	0x2D2F: 0xFFFD,
	0x2D30: 0xFFFD,
	0x2D31: 0xFFFD,
	0x2D32: 0xFFFD,
	0x2D33: 0xFFFD,
	0x2D34: 0xFFFD,
	0x2D35: 0xFFFD,
	0x2D36: 0xFFFD,
	0x2D37: 0xFFFD,
	0x2D38: 0xFFFD,
	0x2D39: 0xFFFD,
	0x2D3A: 0xFFFD,
	0x2D3B: 0xFFFD,
	0x2D3C: 0xFFFD,
	0x2D3D: 0xFFFD,
	0x2D3E: 0xFFFD,
	0x2D3F: 0xFFFD,
	0x2D40: 0xFFFD,
	0x2D41: 0xFFFD,
	0x2D42: 0xFFFD,
	0x2D43: 0xFFFD,
	0x2D44: 0xFFFD,
	0x2D45: 0xFFFD,
	0x2D46: 0xFFFD,
	0x2D47: 0xFFFD,
	0x2D48: 0xFFFD,
	0x2D49: 0xFFFD,
	0x2D4A: 0xFFFD,
	0x2D4B: 0xFFFD,
	0x2D4C: 0xFFFD,
	0x2D4D: 0xFFFD,
	0x2D4E: 0xFFFD,
	0x2D4F: 0xFFFD,
	0x2D50: 0xFFFD,
	0x2D51: 0xFFFD,
	0x2D52: 0xFFFD,
	0x2D53: 0xFFFD,
	0x2D54: 0xFFFD,
	0x2D55: 0xFFFD,
	0x2D56: 0xFFFD,
	0x2D57: 0xFFFD,
	0x2D58: 0xFFFD,
	0x2D59: 0xFFFD,
	0x2D5A: 0xFFFD,
	0x2D5B: 0xFFFD,
	0x2D5C: 0xFFFD,
	0x2D5D: 0xFFFD,
	0x2D5E: 0xFFFD,
	0x2D5F: 0xFFFD,
	0x2D60: 0xFFFD,
	0x2D61: 0xFFFD,
	0x2D62: 0xFFFD,
	0x2D63: 0xFFFD,
	0x2D64: 0xFFFD,
	0x2D65: 0xFFFD,
	0x2D66: 0xFFFD,
	0x2D67: 0xFFFD,
	0x2D68: 0xFFFD,
	0x2D69: 0xFFFD,
	0x2D6A: 0xFFFD,
	0x2D6B: 0xFFFD,
	0x2D6C: 0xFFFD,
	0x2D6D: 0xFFFD,
	0x2D6E: 0xFFFD,
	0x2D6F: 0xFFFD,
	0x2D70: 0xFFFD,
	0x2D71: 0xFFFD,
	0x2D72: 0xFFFD,
	0x2D73: 0xFFFD,
	0x2D74: 0xFFFD,
	0x2D75: 0xFFFD,
	0x2D76: 0xFFFD,
	0x2D77: 0xFFFD,
	0x2D78: 0xFFFD,
	0x2D79: 0xFFFD,
	0x2D7A: 0xFFFD,
	0x2D7B: 0xFFFD,
	0x2D7C: 0xFFFD,
	0x2D7D: 0xFFFD,
	0x2D7E: 0xFFFD,
	0x2D7F: 0xFFFD,
	0x2D80: 0xFFFD,
	0x2D81: 0xFFFD,
	0x2D82: 0xFFFD,
	0x2D83: 0xFFFD,
	0x2D84: 0xFFFD,
	0x2D85: 0xFFFD,
	0x2D86: 0xFFFD,
	0x2D87: 0xFFFD,
	0x2D88: 0xFFFD,
	0x2D89: 0xFFFD,
	0x2D8A: 0xFFFD,
	0x2D8B: 0xFFFD,
	0x2D8C: 0xFFFD,
	0x2D8D: 0xFFFD,
	0x2D8E: 0xFFFD,
	0x2D8F: 0xFFFD,
	0x2D90: 0xFFFD,
	0x2D91: 0xFFFD,
	0x2D92: 0xFFFD,
	0x2D93: 0xFFFD,
	0x2D94: 0xFFFD,
	0x2D95: 0xFFFD,
	0x2D96: 0xFFFD,
	0x2D97: 0xFFFD,
	0x2D98: 0xFFFD,
	0x2D99: 0xFFFD,
	0x2D9A: 0xFFFD,
	0x2D9B: 0xFFFD,
	0x2D9C: 0xFFFD,
	0x2D9D: 0xFFFD,
	0x2D9E: 0xFFFD,
	0x2D9F: 0xFFFD,
	0x2DA0: 0xFFFD,
	0x2DA1: 0xFFFD,
	0x2DA2: 0xFFFD,
	0x2DA3: 0xFFFD,
	0x2DA4: 0xFFFD,
	0x2DA5: 0xFFFD,
	0x2DA6: 0xFFFD,
	0x2DA7: 0xFFFD,
	0x2DA8: 0xFFFD,
	0x2DA9: 0xFFFD,
	0x2DAA: 0xFFFD,
	0x2DAB: 0xFFFD,
	0x2DAC: 0xFFFD,
	0x2DAD: 0xFFFD,
	0x2DAE: 0xFFFD,
	0x2DAF: 0xFFFD,
	0x2DB0: 0xFFFD,
	0x2DB1: 0xFFFD,
	0x2DB2: 0xFFFD,
	0x2DB3: 0xFFFD,
	0x2DB4: 0xFFFD,
	0x2DB5: 0xFFFD,
	0x2DB6: 0xFFFD,
	0x2DB7: 0xFFFD,
	0x2DB8: 0xFFFD,
	0x2DB9: 0xFFFD,
	0x2DBA: 0xFFFD,
	0x2DBB: 0xFFFD,
	0x2DBC: 0xFFFD,
	0x2DBD: 0xFFFD,
	0x2DBE: 0xFFFD,
	0x2DBF: 0xFFFD,
	0x2DC0: 0xFFFD,
	0x2DC1: 0xFFFD,
	0x2DC2: 0xFFFD,
	0x2DC3: 0xFFFD,
	0x2DC4: 0xFFFD,
	0x2DC5: 0xFFFD,
	0x2DC6: 0xFFFD,
	0x2DC7: 0xFFFD,
	0x2DC8: 0xFFFD,
	0x2DC9: 0xFFFD,
	0x2DCA: 0xFFFD,
	0x2DCB: 0xFFFD,
	0x2DCC: 0xFFFD,
	0x2DCD: 0xFFFD,
	0x2DCE: 0xFFFD,
	0x2DCF: 0xFFFD,
	0x2DD0: 0xFFFD,
	0x2DD1: 0xFFFD,
	0x2DD2: 0xFFFD,
	0x2DD3: 0xFFFD,
	0x2DD4: 0xFFFD,
	0x2DD5: 0xFFFD,
	0x2DD6: 0xFFFD,
	0x2DD7: 0xFFFD,
	0x2DD8: 0xFFFD,
	0x2DD9: 0xFFFD,
	0x2DDA: 0xFFFD,
	0x2DDB: 0xFFFD,
	0x2DDC: 0xFFFD,
	0x2DDD: 0xFFFD,
	0x2DDE: 0xFFFD,
	0x2DDF: 0xFFFD,
	0x2DE0: 0xFFFD,
	0x2DE1: 0xFFFD,
	0x2DE2: 0xFFFD,
	0x2DE3: 0xFFFD,
	0x2DE4: 0xFFFD,
	0x2DE5: 0xFFFD,
	0x2DE6: 0xFFFD,
	0x2DE7: 0xFFFD,
	0x2DE8: 0xFFFD,
	0x2DE9: 0xFFFD,
	0x2DEA: 0xFFFD,
	0x2DEB: 0xFFFD,
	0x2DEC: 0xFFFD,
	0x2DED: 0xFFFD,
	0x2DEE: 0xFFFD,
	0x2DEF: 0xFFFD,
	0x2DF0: 0xFFFD,
	0x2DF1: 0xFFFD,
	0x2DF2: 0xFFFD,
	0x2DF3: 0xFFFD,
	0x2DF4: 0xFFFD,
	0x2DF5: 0xFFFD,
	0x2DF6: 0xFFFD,
	0x2DF7: 0xFFFD,
	0x2DF8: 0xFFFD,
	0x2DF9: 0xFFFD,
	0x2DFA: 0xFFFD,
	0x2DFB: 0xFFFD,
	0x2DFC: 0xFFFD,
	0x2DFD: 0xFFFD,
	0x2DFE: 0xFFFD,
	0x2DFF: 0xFFFD,
	0x2E00: 0xFFFD,
	0x2E01: 0xFFFD,
	0x2E02: 0xFFFD,
	0x2E03: 0xFFFD,
	0x2E04: 0xFFFD,
	0x2E05: 0xFFFD,
	0x2E06: 0xFFFD,
	0x2E07: 0xFFFD,
	0x2E08: 0xFFFD,
	0x2E09: 0xFFFD,
	0x2E0A: 0xFFFD,
	0x2E0B: 0xFFFD,
	0x2E0C: 0xFFFD,
	0x2E0D: 0xFFFD,
	0x2E0E: 0xFFFD,
	0x2E0F: 0xFFFD,
	0x2E10: 0xFFFD,
	0x2E11: 0xFFFD,
	0x2E12: 0xFFFD,
	0x2E13: 0xFFFD,
	0x2E14: 0xFFFD,
	0x2E15: 0xFFFD,
	0x2E16: 0xFFFD,
	0x2E17: 0xFFFD,
	0x2E18: 0xFFFD,
	0x2E19: 0xFFFD,
	0x2E1A: 0xFFFD,
	0x2E1B: 0xFFFD,
	0x2E1C: 0xFFFD,
	0x2E1D: 0xFFFD,
	0x2E1E: 0xFFFD,
	0x2E1F: 0xFFFD,
	0x2E20: 0xFFFD,
	0x2E21: 0xFFFD,
	0x2E22: 0xFFFD,
	0x2E23: 0xFFFD,
	0x2E24: 0xFFFD,
	0x2E25: 0xFFFD,
	0x2E26: 0xFFFD,
	0x2E27: 0xFFFD,
	0x2E28: 0xFFFD,
	0x2E29: 0xFFFD,
	0x2E2A: 0xFFFD,
	0x2E2B: 0xFFFD,
	0x2E2C: 0xFFFD,
	0x2E2D: 0xFFFD,
	0x2E2E: 0xFFFD,
	0x2E2F: 0xFFFD,
	0x2E30: 0xFFFD,
	0x2E31: 0xFFFD,
	0x2E32: 0xFFFD,
	0x2E33: 0xFFFD,
	0x2E34: 0xFFFD,
	0x2E35: 0xFFFD,
	0x2E36: 0xFFFD,
	0x2E37: 0xFFFD,
	0x2E38: 0xFFFD,
	0x2E39: 0xFFFD,
	0x2E3A: 0xFFFD,
	0x2E3B: 0xFFFD,
	0x2E3C: 0xFFFD,
	0x2E3D: 0xFFFD,
	0x2E3E: 0xFFFD,
	0x2E3F: 0xFFFD,
	0x2E40: 0xFFFD,
	0x2E41: 0xFFFD,
	0x2E42: 0xFFFD,
	0x2E43: 0xFFFD,
	0x2E44: 0xFFFD,
	0x2E45: 0xFFFD,
	0x2E46: 0xFFFD,
	0x2E47: 0xFFFD,
	0x2E48: 0xFFFD,
	0x2E49: 0xFFFD,
	0x2E4A: 0xFFFD,
	0x2E4B: 0xFFFD,
	0x2E4C: 0xFFFD,
	0x2E4D: 0xFFFD,
	0x2E4E: 0xFFFD,
	0x2E4F: 0xFFFD,
	0x2E50: 0xFFFD,
	0x2E51: 0xFFFD,
	0x2E52: 0xFFFD,
	0x2E53: 0xFFFD,
	0x2E54: 0xFFFD,
	0x2E55: 0xFFFD,
	0x2E56: 0xFFFD,
	0x2E57: 0xFFFD,
	0x2E58: 0xFFFD,
	0x2E59: 0xFFFD,
	0x2E5A: 0xFFFD,
	0x2E5B: 0xFFFD,
	0x2E5C: 0xFFFD,
	0x2E5D: 0xFFFD,
	0x2E5E: 0xFFFD,
	0x2E5F: 0xFFFD,
	0x2E60: 0xFFFD,
	0x2E61: 0xFFFD,
	0x2E62: 0xFFFD,
	0x2E63: 0xFFFD,
	0x2E64: 0xFFFD,
	0x2E65: 0xFFFD,
	0x2E66: 0xFFFD,
	0x2E67: 0xFFFD,
	0x2E68: 0xFFFD,
	0x2E69: 0xFFFD,
	0x2E6A: 0xFFFD,
	0x2E6B: 0xFFFD,
	0x2E6C: 0xFFFD,
	0x2E6D: 0xFFFD,
	0x2E6E: 0xFFFD,
	0x2E6F: 0xFFFD,
	0x2E70: 0xFFFD,
	0x2E71: 0xFFFD,
	0x2E72: 0xFFFD,
	0x2E73: 0xFFFD,
	0x2E74: 0xFFFD,
	0x2E75: 0xFFFD,
	0x2E76: 0xFFFD,
	0x2E77: 0xFFFD,
	0x2E78: 0xFFFD,
	0x2E79: 0xFFFD,
	0x2E7A: 0xFFFD,
	0x2E7B: 0xFFFD,
	0x2E7C: 0xFFFD,
	0x2E7D: 0xFFFD,
	0x2E7E: 0xFFFD,
	0x2E7F: 0xFFFD,
	0x2E80: 0x91ED,
	0x2E81: 0xFFFD,
	0x2E82: 0xFFFD,
	0x2E83: 0xFFFD,
	0x2E84: 0xFFFD,
	0x2E85: 0xFFFD,
	0x2E86: 0xFFFD,
	0x2E87: 0x9CCE,
	0x2E88: 0xFFFD,
	0x2E89: 0xFFFD,
	0x2E8A: 0x9CD5,
	0x2E8B: 0xFFFD,
	0x2E8C: 0x9CD4,
	0x2E8D: 0xFFFD,
	0x2E8E: 0xFFFD,
	0x2E8F: 0xFFFD,
	0x2E90: 0xFFFD,
	0x2E91: 0xFFFD,
	0x2E92: 0xFFFD,
	0x2E93: 0xFFFD,
	0x2E94: 0xFFFD,
	0x2E95: 0x9CDB,
	0x2E96: 0xFFFD,
	0x2E97: 0x91DB,
	0x2E98: 0xFFFD,
	0x2E99: 0xFFFD,
	0x2E9A: 0xFFFD,
	0x2E9B: 0xFFFD,
	0x2E9C: 0xFFFD,
	0x2E9D: 0xFFFD,
	0x2E9E: 0xFFFD,
	0x2E9F: 0xFFFD,
	0x2EA0: 0xFFFD,
	0x2EA1: 0xFFFD,
	0x2EA2: 0xFFFD,
	0x2EA3: 0xFFFD,
	0x2EA4: 0x91C9,
	0x2EA5: 0xFFFD,
	0x2EA6: 0xFFFD,
	0x2EA7: 0xFFFD,
	0x2EA8: 0xFFFD,
	0x2EA9: 0xFFFD,
	0x2EAA: 0xFFFD,
	0x2EAB: 0xFFFD,
	0x2EAC: 0xFFFD,
	0x2EAD: 0xFFFD,
	0x2EAE: 0x9CF7,
	0x2EAF: 0xFFFD,
	0x2EB0: 0xFFFD,
	0x2EB1: 0xFFFD,
	0x2EB2: 0xFFFD,
	0x2EB3: 0xFFFD,
	0x2EB4: 0xFFFD,
	0x2EB5: 0xFFFD,
	0x2EB6: 0xFFFD,
	0x2EB7: 0xFFFD,
	0x2EB8: 0xFFFD,
	0x2EB9: 0xFFFD,
	0x2EBA: 0xFFFD,
	0x2EBB: 0xFFFD,
	0x2EBC: 0xFFFD,
	0x2EBD: 0xFFFD,
	0x2EBE: 0xFFFD,
	0x2EBF: 0xFFFD,
	0x2EC0: 0xFFFD,
	0x2EC1: 0xFFFD,
	0x2EC2: 0xFFFD,
	0x2EC3: 0xFFFD,
	0x2EC4: 0xFFFD,
	0x2EC5: 0xFFFD,
	0x2EC6: 0xFFFD,
	0x2EC7: 0xFFFD,
	0x2EC8: 0xFFFD,
	0x2EC9: 0xFFFD,
	0x2ECA: 0xFFFD,
	0x2ECB: 0xFFFD,
	0x2ECC: 0xFFFD,
	0x2ECD: 0xFFFD,
	0x2ECE: 0xFFFD,
	0x2ECF: 0xFFFD,
	0x2ED0: 0xFFFD,
	0x2ED1: 0xFFFD,
	0x2ED2: 0xFFFD,
	0x2ED3: 0xFFFD,
	0x2ED4: 0xFFFD,
	0x2ED5: 0xFFFD,
	0x2ED6: 0xFFFD,
	0x2ED7: 0xFFFD,
	0x2ED8: 0xFFFD,
	0x2ED9: 0xFFFD,
	0x2EDA: 0xFFFD,
	0x2EDB: 0xFFFD,
	0x2EDC: 0xFFFD,
	0x2EDD: 0xFFFD,
	0x2EDE: 0xFFFD,
	0x2EDF: 0xFFFD,
	0x2EE0: 0xFFFD,
	0x2EE1: 0xFFFD,
	0x2EE2: 0xFFFD,
	0x2EE3: 0xFFFD,
	0x2EE4: 0xFFFD,
	0x2EE5: 0xFFFD,
	0x2EE6: 0xFFFD,
	0x2EE7: 0xFFFD,
	0x2EE8: 0xFFFD,
	0x2EE9: 0xFFFD,
	0x2EEA: 0xFFFD,
	0x2EEB: 0xFFFD,
	0x2EEC: 0xFFFD,
	0x2EED: 0xFFFD,
	0x2EEE: 0xFFFD,
	0x2EEF: 0xFFFD,
	0x2EF0: 0xFFFD,
	0x2EF1: 0xFFFD,
	0x2EF2: 0xFFFD,
	0x2EF3: 0xFFFD,
	0x2EF4: 0xFFFD,
	0x2EF5: 0xFFFD,
	0x2EF6: 0xFFFD,
	0x2EF7: 0xFFFD,
	0x2EF8: 0xFFFD,
	0x2EF9: 0xFFFD,
	0x2EFA: 0xFFFD,
	0x2EFB: 0xFFFD,
	0x2EFC: 0xFFFD,
	0x2EFD: 0xFFFD,
	0x2EFE: 0xFFFD,
	0x2EFF: 0xFFFD,
	0x2F00: 0xFFFD,
	0x2F01: 0xFFFD,
	0x2F02: 0xC6BF,
	0x2F03: 0xC6C0,
	0x2F04: 0xFFFD,
	0x2F05: 0xC6C1,
	0x2F06: 0xFFFD,
	0x2F07: 0xC6C2,
	0x2F08: 0xFFFD,
	0x2F09: 0xFFFD,
	0x2F0A: 0xFFFD,
	0x2F0B: 0xFFFD,
	0x2F0C: 0xC6C3,
	0x2F0D: 0xC6C4,
	0x2F0E: 0xC6C5,
	0x2F0F: 0xFFFD,
	0x2F10: 0xFFFD,
	0x2F11: 0xFFFD,
	0x2F12: 0xFFFD,
	0x2F13: 0xC6C6,
	0x2F14: 0xFFFD,
	0x2F15: 0xFFFD,
	0x2F16: 0xC6C7,
	0x2F17: 0xFFFD,
	0x2F18: 0xFFFD,
	0x2F19: 0xC6C8,
	0x2F1A: 0xFFFD,
	0x2F1B: 0xC6C9,
	0x2F1C: 0xFFFD,
	0x2F1D: 0xFFFD,
	0x2F1E: 0xFFFD,
	0x2F1F: 0xFFFD,
	0x2F20: 0xFFFD,
	0x2F21: 0xFFFD,
	0x2F22: 0xC6CA,
	0x2F23: 0xFFFD,
	0x2F24: 0xFFFD,
	0x2F25: 0xFFFD,
	0x2F26: 0xFFFD,
	0x2F27: 0xC6CB,
	0x2F28: 0xFFFD,
	0x2F29: 0xFFFD,
	0x2F2A: 0xFFFD,
	0x2F2B: 0xFFFD,
	0x2F2C: 0xFFFD,
	0x2F2D: 0xFFFD,
	0x2F2E: 0xC6CC,
	0x2F2F: 0xFFFD,
	0x2F30: 0xFFFD,
	0x2F31: 0xFFFD,
	0x2F32: 0xFFFD,
	0x2F33: 0xC6CD,
	0x2F34: 0xC6CE,
	0x2F35: 0xC6CF,
	0x2F36: 0xFFFD,
	0x2F37: 0xFFFD,
	0x2F38: 0xFFFD,
	0x2F39: 0xC6D0,
	0x2F3A: 0xC6D1,
	0x2F3B: 0xFFFD,
	0x2F3C: 0xFFFD,
	0x2F3D: 0xFFFD,
	0x2F3E: 0xFFFD,
	0x2F3F: 0xFFFD,
	0x2F40: 0xFFFD,
	0x2F41: 0xC6D2,
	0x2F42: 0xFFFD,
	0x2F43: 0xFFFD,
	0x2F44: 0xFFFD,
	0x2F45: 0xFFFD,
	0x2F46: 0xC6D3,
	0x2F47: 0xFFFD,
	0x2F48: 0xFFFD,
	0x2F49: 0xFFFD,
	0x2F4A: 0xFFFD,
	0x2F4B: 0xFFFD,
	0x2F4C: 0xFFFD,
	0x2F4D: 0xFFFD,
	0x2F4E: 0xFFFD,
	0x2F4F: 0xFFFD,
	0x2F50: 0xFFFD,
	0x2F51: 0xFFFD,
	0x2F52: 0xFFFD,
	0x2F53: 0xFFFD,
	0x2F54: 0xFFFD,
	0x2F55: 0xFFFD,
	0x2F56: 0xFFFD,
	0x2F57: 0xFFFD,
	0x2F58: 0xFFFD,
	0x2F59: 0xFFFD,
	0x2F5A: 0xFFFD,
	0x2F5B: 0xFFFD,
	0x2F5C: 0xFFFD,
	0x2F5D: 0xFFFD,
	0x2F5E: 0xFFFD,
	0x2F5F: 0xFFFD,
	0x2F60: 0xFFFD,
	0x2F61: 0xFFFD,
	0x2F62: 0xFFFD,
	0x2F63: 0xFFFD,
	0x2F64: 0xFFFD,
	0x2F65: 0xFFFD,
	0x2F66: 0xFFFD,
	0x2F67: 0xC6D4,
	0x2F68: 0xC6D5,
	0x2F69: 0xFFFD,
	0x2F6A: 0xFFFD,
	0x2F6B: 0xFFFD,
	0x2F6C: 0xFFFD,
	0x2F6D: 0xFFFD,
	0x2F6E: 0xFFFD,
	0x2F6F: 0xFFFD,
	0x2F70: 0xFFFD,
	0x2F71: 0xFFFD,
	0x2F72: 0xFFFD,
	0x2F73: 0xFFFD,
	0x2F74: 0xFFFD,
	0x2F75: 0xFFFD,
	0x2F76: 0xFFFD,
	0x2F77: 0xFFFD,
	0x2F78: 0xFFFD,
	0x2F79: 0xFFFD,
	0x2F7A: 0xFFFD,
	0x2F7B: 0xFFFD,
	0x2F7C: 0xFFFD,
	0x2F7D: 0xFFFD,
	0x2F7E: 0xFFFD,
	0x2F7F: 0xFFFD,
	0x2F80: 0xFFFD,
	0x2F81: 0xFFFD,
	0x2F82: 0xFFFD,
	0x2F83: 0xFFFD,
	0x2F84: 0xFFFD,
	0x2F85: 0xFFFD,
	0x2F86: 0xFFFD,
	0x2F87: 0xFFFD,
	0x2F88: 0xFFFD,
	0x2F89: 0xFFFD,
	0x2F8A: 0xFFFD,
	0x2F8B: 0xFFFD,
	0x2F8C: 0xFFFD,
	0x2F8D: 0xFFFD,
	0x2F8E: 0xFFFD,
	0x2F8F: 0xFFFD,
	0x2F90: 0xFFFD,
	0x2F91: 0xFFFD,
	0x2F92: 0xFFFD,
	0x2F93: 0xFFFD,
	0x2F94: 0xFFFD,
	0x2F95: 0xFFFD,
	0x2F96: 0xFFFD,
	0x2F97: 0xFFFD,
	0x2F98: 0xFFFD,
	0x2F99: 0xFFFD,
	0x2F9A: 0xFFFD,
	0x2F9B: 0xFFFD,
	0x2F9C: 0xFFFD,
	0x2F9D: 0xFFFD,
	0x2F9E: 0xFFFD,
	0x2F9F: 0xFFFD,
	0x2FA0: 0xFFFD,
	0x2FA1: 0xC6D6,
	0x2FA2: 0xFFFD,
	0x2FA3: 0xFFFD,
	0x2FA4: 0xFFFD,
	0x2FA5: 0xFFFD,
	0x2FA6: 0xFFFD,
	0x2FA7: 0xFFFD,
	0x2FA8: 0xFFFD,
	0x2FA9: 0xFFFD,
	0x2FAA: 0xC6D7,
	0x2FAB: 0xFFFD,
	0x2FAC: 0xFFFD,
	0x2FAD: 0xFFFD,
	0x2FAE: 0xFFFD,
	0x2FAF: 0xFFFD,
	0x2FB0: 0xFFFD,
	0x2FB1: 0xFFFD,
	0x2FB2: 0xFFFD,
	0x2FB3: 0xFFFD,
	0x2FB4: 0xFFFD,
	0x2FB5: 0xFFFD,
	0x2FB6: 0xFFFD,
	0x2FB7: 0xFFFD,
	0x2FB8: 0xFFFD,
	0x2FB9: 0xFFFD,
	0x2FBA: 0xFFFD,
	0x2FBB: 0xFFFD,
	0x2FBC: 0xFFFD,
	0x2FBD: 0xFFFD,
	0x2FBE: 0xFFFD,
	0x2FBF: 0xFFFD,
	0x2FC0: 0xFFFD,
	0x2FC1: 0xFFFD,
	0x2FC2: 0xFFFD,
	0x2FC3: 0xFFFD,
	0x2FC4: 0xFFFD,
	0x2FC5: 0xFFFD,
	0x2FC6: 0xFFFD,
	0x2FC7: 0xFFFD,
	0x2FC8: 0xFFFD,
	0x2FC9: 0xFFFD,
	0x2FCA: 0xFFFD,
	0x2FCB: 0xFFFD,
	0x2FCC: 0xFFFD,
	0x2FCD: 0xFFFD,
	0x2FCE: 0xFFFD,
	0x2FCF: 0xFFFD,
	0x2FD0: 0xFFFD,
	0x2FD1: 0xFFFD,
	0x2FD2: 0xFFFD,
	0x2FD3: 0xFFFD,
	0x2FD4: 0xFFFD,
	0x2FD5: 0xFFFD,
	0x2FD6: 0xFFFD,
	0x2FD7: 0xFFFD,
	0x2FD8: 0xFFFD,
	0x2FD9: 0xFFFD,
	0x2FDA: 0xFFFD,
	0x2FDB: 0xFFFD,
	0x2FDC: 0xFFFD,
	0x2FDD: 0xFFFD,
	0x2FDE: 0xFFFD,
	0x2FDF: 0xFFFD,
	0x2FE0: 0xFFFD,
	0x2FE1: 0xFFFD,
	0x2FE2: 0xFFFD,
	0x2FE3: 0xFFFD,
	0x2FE4: 0xFFFD,
	0x2FE5: 0xFFFD,
	0x2FE6: 0xFFFD,
	0x2FE7: 0xFFFD,
	0x2FE8: 0xFFFD,
	0x2FE9: 0xFFFD,
	0x2FEA: 0xFFFD,
	0x2FEB: 0xFFFD,
	0x2FEC: 0xFFFD,
	0x2FED: 0xFFFD,
	0x2FEE: 0xFFFD,
	0x2FEF: 0xFFFD,
	0x2FF0: 0xFFFD,
	0x2FF1: 0xFFFD,
	0x2FF2: 0xFFFD,
	0x2FF3: 0xFFFD,
	0x2FF4: 0xFFFD,
	0x2FF5: 0xFFFD,
	0x2FF6: 0xFFFD,
	0x2FF7: 0xFFFD,
	0x2FF8: 0xFFFD,
	0x2FF9: 0xFFFD,
	0x2FFA: 0xFFFD,
	0x2FFB: 0xFFFD,
	0x2FFC: 0xFFFD,
	0x2FFD: 0xFFFD,
	0x2FFE: 0xFFFD,
	0x2FFF: 0xFFFD,
	0x3000: 0xA140,
	0x3001: 0xA142,
	0x3002: 0xA143,
	0x3003: 0xA1B2,
	0x3004: 0xFFFD,
	0x3005: 0xC6E0,
	0x3006: 0xC6E1,
	0x3007: 0xC6E2,
	0x3008: 0xA171,
	0x3009: 0xA172,
	0x300A: 0xA16D,
	0x300B: 0xA16E,
	0x300C: 0xA175,
	0x300D: 0xA176,
	0x300E: 0xA179,
	0x300F: 0xA17A,
	0x3010: 0xA169,
	0x3011: 0xA16A,
	0x3012: 0xA245,
	0x3013: 0x965D,
	0x3014: 0xA165,
	0x3015: 0xA166,
	0x3016: 0x9D51,
	0x3017: 0x9D52,
	0x3018: 0xFFFD,
	0x3019: 0xFFFD,
	0x301A: 0xFFFD,
	0x301B: 0xFFFD,
	0x301C: 0xA1E3,
	0x301D: 0xA1A9,
	0x301E: 0xA1AA,
	0x301F: 0xFFFD,
	0x3020: 0xFFFD,
	0x3021: 0xA2C3,
	0x3022: 0xA2C4,
	0x3023: 0xA2C5,
	0x3024: 0xA2C6,
	0x3025: 0xA2C7,
	0x3026: 0xA2C8,
	0x3027: 0xA2C9,
	0x3028: 0xA2CA,
	0x3029: 0xA2CB,
	0x302A: 0xFFFD,
	0x302B: 0xFFFD,
	0x302C: 0xFFFD,
	0x302D: 0xFFFD,
	0x302E: 0xFFFD,
	0x302F: 0xFFFD,
	0x3030: 0xA1CA,
	0x3031: 0xFFFD,
	0x3032: 0xFFFD,
	0x3033: 0xFFFD,
	0x3034: 0xFFFD,
	0x3035: 0xFFFD,
	0x3036: 0xFFFD,
	0x3037: 0xFFFD,
	0x3038: 0xA2CC,
	0x3039: 0xA2CD,
	0x303A: 0xA2CE,
	0x303B: 0xFFFD,
	0x303C: 0xFFFD,
	0x303D: 0xFFFD,
	0x303E: 0xFFFD,
	0x303F: 0xFFFD,
	0x3040: 0xFFFD,
	0x3041: 0xC6E7,
	0x3042: 0xC6E8,
	0x3043: 0xC6E9,
	0x3044: 0xC6EA,
	0x3045: 0xC6EB,
	0x3046: 0xC6EC,
	0x3047: 0xC6ED,
	0x3048: 0xC6EE,
	0x3049: 0xC6EF,
	0x304A: 0xC6F0,
	0x304B: 0xC6F1,
	0x304C: 0xC6F2,
	0x304D: 0xC6F3,
	0x304E: 0xC6F4,
	0x304F: 0xC6F5,
	0x3050: 0xC6F6,
	0x3051: 0xC6F7,
	0x3052: 0xC6F8,
	0x3053: 0xC6F9,
	0x3054: 0xC6FA,
	0x3055: 0xC6FB,
	0x3056: 0xC6FC,
	0x3057: 0xC6FD,
	0x3058: 0xC6FE,
	0x3059: 0xC740,
	0x305A: 0xC741,
	0x305B: 0xC742,
	0x305C: 0xC743,
	0x305D: 0xC744,
	0x305E: 0xC745,
	0x305F: 0xC746,
	0x3060: 0xC747,
	0x3061: 0xC748,
	0x3062: 0xC749,
	0x3063: 0xC74A,
	0x3064: 0xC74B,
	0x3065: 0xC74C,
	0x3066: 0xC74D,
	0x3067: 0xC74E,
	0x3068: 0xC74F,
	0x3069: 0xC750,
	0x306A: 0xC751,
	0x306B: 0xC752,
	0x306C: 0xC753,
	0x306D: 0xC754,
	0x306E: 0xC755,
	0x306F: 0xC756,
	0x3070: 0xC757,
	0x3071: 0xC758,
	0x3072: 0xC759,
	0x3073: 0xC75A,
	0x3074: 0xC75B,
	0x3075: 0xC75C,
	0x3076: 0xC75D,
	0x3077: 0xC75E,
	0x3078: 0xC75F,
	0x3079: 0xC760,
	0x307A: 0xC761,
	0x307B: 0xC762,
	0x307C: 0xC763,
	0x307D: 0xC764,
	0x307E: 0xC765,
	0x307F: 0xC766,
	0x3080: 0xC767,
	0x3081: 0xC768,
	0x3082: 0xC769,
	0x3083: 0xC76A,
	0x3084: 0xC76B,
	0x3085: 0xC76C,
	0x3086: 0xC76D,
	0x3087: 0xC76E,
	0x3088: 0xC76F,
	0x3089: 0xC770,
	0x308A: 0xC771,
	0x308B: 0xC772,
	0x308C: 0xC773,
	0x308D: 0xC774,
	0x308E: 0xC775,
	0x308F: 0xC776,
	0x3090: 0xC777,
	0x3091: 0xC778,
	0x3092: 0xC779,
	0x3093: 0xC77A,
	0x3094: 0xC8B3,
	0x3095: 0xFFFD,
	0x3096: 0xFFFD,
	0x3097: 0xFFFD,
	0x3098: 0xFFFD,
	0x3099: 0xFFFD,
	0x309A: 0xFFFD,
	0x309B: 0xC8B1,
	0x309C: 0xC8B2,
	0x309D: 0xC6DC,
	0x309E: 0xC6DD,
	0x309F: 0xFFFD,
	0x30A0: 0xFFFD,
	0x30A1: 0xC77B,
	0x30A2: 0xC77C,
	0x30A3: 0xC77D,
	0x30A4: 0xC77E,
	0x30A5: 0xC7A1,
	0x30A6: 0xC7A2,
	0x30A7: 0xC7A3,
	0x30A8: 0xC7A4,
	0x30A9: 0xC7A5,
	0x30AA: 0xC7A6,
	0x30AB: 0xC7A7,
	0x30AC: 0xC7A8,
	0x30AD: 0xC7A9,
	0x30AE: 0xC7AA,
	0x30AF: 0xC7AB,
	0x30B0: 0xC7AC,
	0x30B1: 0xC7AD,
	0x30B2: 0xC7AE,
	0x30B3: 0xC7AF,
	0x30B4: 0xC7B0,
	0x30B5: 0xC7B1,
	0x30B6: 0xC7B2,
	0x30B7: 0xC7B3,
	0x30B8: 0xC7B4,
	0x30B9: 0xC7B5,
	0x30BA: 0xC7B6,
	0x30BB: 0xC7B7,
	0x30BC: 0xC7B8,
	0x30BD: 0xC7B9,
	0x30BE: 0xC7BA,
	0x30BF: 0xC7BB,
	0x30C0: 0xC7BC,
	0x30C1: 0xC7BD,
	0x30C2: 0xC7BE,
	0x30C3: 0xC7BF,
	0x30C4: 0xC7C0,
	0x30C5: 0xC7C1,
	0x30C6: 0xC7C2,
	0x30C7: 0xC7C3,
	0x30C8: 0xC7C4,
	0x30C9: 0xC7C5,
	0x30CA: 0xC7C6,
	0x30CB: 0xC7C7,
	0x30CC: 0xC7C8,
	0x30CD: 0xC7C9,
	0x30CE: 0xC7CA,
	0x30CF: 0xC7CB,
	0x30D0: 0xC7CC,
	0x30D1: 0xC7CD,
	0x30D2: 0xC7CE,
	0x30D3: 0xC7CF,
	0x30D4: 0xC7D0,
	0x30D5: 0xC7D1,
	0x30D6: 0xC7D2,
	0x30D7: 0xC7D3,
	0x30D8: 0xC7D4,
	0x30D9: 0xC7D5,
	0x30DA: 0xC7D6,
	0x30DB: 0xC7D7,
	0x30DC: 0xC7D8,
	0x30DD: 0xC7D9,
	0x30DE: 0xC7DA,
	0x30DF: 0xC7DB,
	0x30E0: 0xC7DC,
	0x30E1: 0xC7DD,
	0x30E2: 0xC7DE,
	0x30E3: 0xC7DF,
	0x30E4: 0xC7E0,
	0x30E5: 0xC7E1,
	0x30E6: 0xC7E2,
	0x30E7: 0xC7E3,
	0x30E8: 0xC7E4,
	0x30E9: 0xC7E5,
	0x30EA: 0xC7E6,
	0x30EB: 0xC7E7,
	0x30EC: 0xC7E8,
	0x30ED: 0xC7E9,
	0x30EE: 0xC7EA,
	0x30EF: 0xC7EB,
	0x30F0: 0xC7EC,
	0x30F1: 0xC7ED,
	0x30F2: 0xC7EE,
	0x30F3: 0xC7EF,
	0x30F4: 0xC7F0,
	0x30F5: 0xC7F1,
	0x30F6: 0xC7F2,
	0x30F7: 0xC8B4,
	0x30F8: 0xC8B5,
	0x30F9: 0xC8B6,
	0x30FA: 0xC8B7,
	0x30FB: 0xC8B8,
	0x30FC: 0xC6E3,
	0x30FD: 0xC6DA,
	0x30FE: 0xC6DB,
	0x30FF: 0xFFFD,
	0x3100: 0xFFFD,
	0x3101: 0xFFFD,
	0x3102: 0xFFFD,
	0x3103: 0xFFFD,
	0x3104: 0xFFFD,
	0x3105: 0xA374,
	0x3106: 0xA375,
	0x3107: 0xA376,
	0x3108: 0xA377,
	0x3109: 0xA378,
	0x310A: 0xA379,
	0x310B: 0xA37A,
	0x310C: 0xA37B,
	0x310D: 0xA37C,
	0x310E: 0xA37D,
	0x310F: 0xA37E,
	0x3110: 0xA3A1,
	0x3111: 0xA3A2,
	0x3112: 0xA3A3,
	0x3113: 0xA3A4,
	0x3114: 0xA3A5,
	0x3115: 0xA3A6,
	0x3116: 0xA3A7,
	0x3117: 0xA3A8,
	0x3118: 0xA3A9,
	0x3119: 0xA3AA,
	0x311A: 0xA3AB,
	0x311B: 0xA3AC,
	0x311C: 0xA3AD,
	0x311D: 0xA3AE,
	0x311E: 0xA3AF,
	0x311F: 0xA3B0,
	0x3120: 0xA3B1,
	0x3121: 0xA3B2,
	0x3122: 0xA3B3,
	0x3123: 0xA3B4,
	0x3124: 0xA3B5,
	0x3125: 0xA3B6,
	0x3126: 0xA3B7,
	0x3127: 0xA3B8,
	0x3128: 0xA3B9,
	0x3129: 0xA3BA,
	0x312A: 0xFFFD,
	0x312B: 0xFFFD,
	0x312C: 0xFFFD,
	0x312D: 0xFFFD,
	0x312E: 0xFFFD,
	0x312F: 0xFFFD,
	0x3130: 0xFFFD,
	0x3131: 0xFFFD,
	0x3132: 0xFFFD,
	0x3133: 0xFFFD,
	0x3134: 0xFFFD,
	0x3135: 0xFFFD,
	0x3136: 0xFFFD,
	0x3137: 0xFFFD,
	0x3138: 0xFFFD,
	0x3139: 0xFFFD,
	0x313A: 0xFFFD,
	0x313B: 0xFFFD,
	0x313C: 0xFFFD,
	0x313D: 0xFFFD,
	0x313E: 0xFFFD,
	0x313F: 0xFFFD,
	0x3140: 0xFFFD,
	0x3141: 0xFFFD,
	0x3142: 0xFFFD,
	0x3143: 0xFFFD,
	0x3144: 0xFFFD,
	0x3145: 0xFFFD,
	0x3146: 0xFFFD,
	0x3147: 0xFFFD,
	0x3148: 0xFFFD,
	0x3149: 0xFFFD,
	0x314A: 0xFFFD,
	0x314B: 0xFFFD,
	0x314C: 0xFFFD,
	0x314D: 0xFFFD,
	0x314E: 0xFFFD,
	0x314F: 0xFFFD,
	0x3150: 0xFFFD,
	0x3151: 0xFFFD,
	0x3152: 0xFFFD,
	0x3153: 0xFFFD,
	0x3154: 0xFFFD,
	0x3155: 0xFFFD,
	0x3156: 0xFFFD,
	0x3157: 0xFFFD,
	0x3158: 0xFFFD,
	0x3159: 0xFFFD,
	0x315A: 0xFFFD,
	0x315B: 0xFFFD,
	0x315C: 0xFFFD,
	0x315D: 0xFFFD,
	0x315E: 0xFFFD,
	0x315F: 0xFFFD,
	0x3160: 0xFFFD,
	0x3161: 0xFFFD,
	0x3162: 0xFFFD,
	0x3163: 0xFFFD,
	0x3164: 0xFFFD,
	0x3165: 0xFFFD,
	0x3166: 0xFFFD,
	0x3167: 0xFFFD,
	0x3168: 0xFFFD,
	0x3169: 0xFFFD,
	0x316A: 0xFFFD,
	0x316B: 0xFFFD,
	0x316C: 0xFFFD,
	0x316D: 0xFFFD,
	0x316E: 0xFFFD,
	0x316F: 0xFFFD,
	0x3170: 0xFFFD,
	0x3171: 0xFFFD,
	0x3172: 0xFFFD,
	0x3173: 0xFFFD,
	0x3174: 0xFFFD,
	0x3175: 0xFFFD,
	0x3176: 0xFFFD,
	0x3177: 0xFFFD,
	0x3178: 0xFFFD,
	0x3179: 0xFFFD,
	0x317A: 0xFFFD,
	0x317B: 0xFFFD,
	0x317C: 0xFFFD,
	0x317D: 0xFFFD,
	0x317E: 0xFFFD,
	0x317F: 0xFFFD,
	0x3180: 0xFFFD,
	0x3181: 0xFFFD,
	0x3182: 0xFFFD,
	0x3183: 0xFFFD,
	0x3184: 0xFFFD,
	0x3185: 0xFFFD,
	0x3186: 0xFFFD,
	0x3187: 0xFFFD,
	0x3188: 0xFFFD,
	0x3189: 0xFFFD,
	0x318A: 0xFFFD,
	0x318B: 0xFFFD,
	0x318C: 0xFFFD,
	0x318D: 0xFFFD,
	0x318E: 0xFFFD,
	0x318F: 0xFFFD,
	0x3190: 0xFFFD,
	0x3191: 0xFFFD,
	0x3192: 0xA440,
	0x3193: 0xA447,
	0x3194: 0xA454,
	0x3195: 0xA57C,
	0x3196: 0xA457,
	0x3197: 0xA4A4,
	0x3198: 0xA455,
	0x3199: 0xA5D2,
	0x319A: 0xA441,
	0x319B: 0xA4FE,
	0x319C: 0xA442,
	0x319D: 0xA4D1,
	0x319E: 0xA661,
	0x319F: 0xA448,
	0x31A0: 0xFFFD,
	0x31A1: 0xFFFD,
	0x31A2: 0xFFFD,
	0x31A3: 0xFFFD,
	0x31A4: 0xFFFD,
	0x31A5: 0xFFFD,
	0x31A6: 0xFFFD,
	0x31A7: 0xFFFD,
	0x31A8: 0xFFFD,
	0x31A9: 0xFFFD,
	0x31AA: 0xFFFD,
	0x31AB: 0xFFFD,
	0x31AC: 0xFFFD,
	0x31AD: 0xFFFD,
	0x31AE: 0xFFFD,
	0x31AF: 0xFFFD,
	0x31B0: 0xFFFD,
	0x31B1: 0xFFFD,
	0x31B2: 0xFFFD,
	0x31B3: 0xFFFD,
	0x31B4: 0xFFFD,
	0x31B5: 0xFFFD,
	0x31B6: 0xFFFD,
	0x31B7: 0xFFFD,
	0x31B8: 0xFFFD,
	0x31B9: 0xFFFD,
	0x31BA: 0xFFFD,
	0x31BB: 0xFFFD,
	0x31BC: 0xFFFD,
	0x31BD: 0xFFFD,
	0x31BE: 0xFFFD,
	0x31BF: 0xFFFD,
	0x31C0: 0xFFFD,
	0x31C1: 0xFFFD,
	0x31C2: 0xFFFD,
	0x31C3: 0xFFFD,
	0x31C4: 0xFFFD,
	0x31C5: 0xFFFD,
	0x31C6: 0xFFFD,
	0x31C7: 0xFFFD,
	0x31C8: 0xFFFD,
	0x31C9: 0xFFFD,
	0x31CA: 0xFFFD,
	0x31CB: 0xFFFD,
	0x31CC: 0xFFFD,
	0x31CD: 0xFFFD,
	0x31CE: 0xFFFD,
	0x31CF: 0xC879,
	0x31D0: 0xFFFD,
	0x31D1: 0xFFFD,
	0x31D2: 0xFFFD,
	0x31D3: 0xFFFD,
	0x31D4: 0xFFFD,
	0x31D5: 0xFFFD,
	0x31D6: 0xFFFD,
	0x31D7: 0xFFFD,
	0x31D8: 0xFFFD,
	0x31D9: 0xFFFD,
	0x31DA: 0xFFFD,
	0x31DB: 0xFFFD,
	0x31DC: 0xFFFD,
	0x31DD: 0xFFFD,
	0x31DE: 0xFFFD,
	0x31DF: 0xFFFD,
	0x31E0: 0xFFFD,
	0x31E1: 0xFFFD,
	0x31E2: 0xFFFD,
	0x31E3: 0xFFFD,
	0x31E4: 0xFFFD,
	0x31E5: 0xFFFD,
	0x31E6: 0xFFFD,
	0x31E7: 0xFFFD,
	0x31E8: 0xFFFD,
	0x31E9: 0xFFFD,
	0x31EA: 0xFFFD,
	0x31EB: 0xFFFD,
	0x31EC: 0xFFFD,
	0x31ED: 0xFFFD,
	0x31EE: 0xFFFD,
	0x31EF: 0xFFFD,
	0x31F0: 0xFFFD,
	0x31F1: 0xFFFD,
	0x31F2: 0xFFFD,
	0x31F3: 0xFFFD,
	0x31F4: 0xFFFD,
	0x31F5: 0xFFFD,
	0x31F6: 0xFFFD,
	0x31F7: 0xFFFD,
	0x31F8: 0xFFFD,
	0x31F9: 0xFFFD,
	0x31FA: 0xFFFD,
	0x31FB: 0xFFFD,
	0x31FC: 0xFFFD,
	0x31FD: 0xFFFD,
	0x31FE: 0xFFFD,
	0x31FF: 0xFFFD,
	0x3200: 0xFFFD,
	0x3201: 0xFFFD,
	0x3202: 0xFFFD,
	0x3203: 0xFFFD,
	0x3204: 0xFFFD,
	0x3205: 0xFFFD,
	0x3206: 0xFFFD,
	0x3207: 0xFFFD,
	0x3208: 0xFFFD,
	0x3209: 0xFFFD,
	0x320A: 0xFFFD,
	0x320B: 0xFFFD,
	0x320C: 0xFFFD,
	0x320D: 0xFFFD,
	0x320E: 0xFFFD,
	0x320F: 0xFFFD,
	0x3210: 0xFFFD,
	0x3211: 0xFFFD,
	0x3212: 0xFFFD,
	0x3213: 0xFFFD,
	0x3214: 0xFFFD,
	0x3215: 0xFFFD,
	0x3216: 0xFFFD,
	0x3217: 0xFFFD,
	0x3218: 0xFFFD,
	0x3219: 0xFFFD,
	0x321A: 0xFFFD,
	0x321B: 0xFFFD,
	0x321C: 0xFFFD,
	0x321D: 0xFFFD,
	0x321E: 0xFFFD,
	0x321F: 0xFFFD,
	0x3220: 0x9C41,
	0x3221: 0x9C42,
	0x3222: 0x9C43,
	0x3223: 0x9C44,
	0x3224: 0x9C45,
	0x3225: 0x9C46,
	0x3226: 0x9C47,
	0x3227: 0x9C48,
	0x3228: 0x9C49,
	0x3229: 0x9C4A,
	0x322A: 0xA4EB,
	0x322B: 0xA4F5,
	0x322C: 0xA4F4,
	0x322D: 0xA4EC,
	0x322E: 0xAAF7,
	0x322F: 0xA467,
	0x3230: 0xA4E9,
	0x3231: 0x99FD,
	0x3232: 0x99FC,
	0x3233: 0xAAC0,
	0x3234: 0xA657,
	0x3235: 0xAF53,
	0x3236: 0xB05D,
	0x3237: 0xAFAC,
	0x3238: 0xB3D2,
	0x3239: 0xA54E,
	0x323A: 0xA949,
	0x323B: 0xBEC7,
	0x323C: 0xBACA,
	0x323D: 0xA5F8,
	0x323E: 0xB8EA,
	0x323F: 0xA8F3,
	0x3240: 0xB2BD,
	0x3241: 0xA5F0,
	0x3242: 0xA6DB,
	0x3243: 0xA6DC,
	0x3244: 0xFFFD,
	0x3245: 0xFFFD,
	0x3246: 0xFFFD,
	0x3247: 0xFFFD,
	0x3248: 0xFFFD,
	0x3249: 0xFFFD,
	0x324A: 0xFFFD,
	0x324B: 0xFFFD,
	0x324C: 0xFFFD,
	0x324D: 0xFFFD,
	0x324E: 0xFFFD,
	0x324F: 0xFFFD,
	0x3250: 0xFFFD,
	0x3251: 0xFFFD,
	0x3252: 0xFFFD,
	0x3253: 0xFFFD,
	0x3254: 0xFFFD,
	0x3255: 0xFFFD,
	0x3256: 0xFFFD,
	0x3257: 0xFFFD,
	0x3258: 0xFFFD,
	0x3259: 0xFFFD,
	0x325A: 0xFFFD,
	0x325B: 0xFFFD,
	0x325C: 0xFFFD,
	0x325D: 0xFFFD,
	0x325E: 0xFFFD,
	0x325F: 0xFFFD,
	0x3260: 0xFFFD,
	0x3261: 0xFFFD,
	0x3262: 0xFFFD,
	0x3263: 0xFFFD,
	0x3264: 0xFFFD,
	0x3265: 0xFFFD,
	0x3266: 0xFFFD,
	0x3267: 0xFFFD,
	0x3268: 0xFFFD,
	0x3269: 0xFFFD,
	0x326A: 0xFFFD,
	0x326B: 0xFFFD,
	0x326C: 0xFFFD,
	0x326D: 0xFFFD,
	0x326E: 0xFFFD,
	0x326F: 0xFFFD,
	0x3270: 0xFFFD,
	0x3271: 0xFFFD,
	0x3272: 0xFFFD,
	0x3273: 0xFFFD,
	0x3274: 0xFFFD,
	0x3275: 0xFFFD,
	0x3276: 0xFFFD,
	0x3277: 0xFFFD,
	0x3278: 0xFFFD,
	0x3279: 0xFFFD,
	0x327A: 0xFFFD,
	0x327B: 0xFFFD,
	0x327C: 0xFFFD,
	0x327D: 0xFFFD,
	0x327E: 0xFFFD,
	0x327F: 0xFFFD,
	0x3280: 0xA440,
	0x3281: 0xA447,
	0x3282: 0xA454,
	0x3283: 0xA57C,
	0x3284: 0xA4AD,
	0x3285: 0xA4BB,
	0x3286: 0xA443,
	0x3287: 0xA44B,
	0x3288: 0xA445,
	0x3289: 0xA451,
	0x328A: 0xA4EB,
	0x328B: 0xA4F5,
	0x328C: 0xA4F4,
	0x328D: 0xA4EC,
	0x328E: 0xAAF7,
	0x328F: 0xA467,
	0x3290: 0xA4E9,
	0x3291: 0xAEE8,
	0x3292: 0xA6B3,
	0x3293: 0xAAC0,
	0x3294: 0xA657,
	0x3295: 0xAF53,
	0x3296: 0xB05D,
	0x3297: 0xAFAC,
	0x3298: 0xB3D2,
	0x3299: 0xAFB5,
	0x329A: 0xA86B,
	0x329B: 0xA46B,
	0x329C: 0xBE41,
	0x329D: 0xC075,
	0x329E: 0xA64C,
	0x329F: 0xAA60,
	0x32A0: 0xB6B5,
	0x32A1: 0xA5F0,
	0x32A2: 0xBC67,
	0x32A3: 0xA1C0,
	0x32A4: 0xA457,
	0x32A5: 0xA4A4,
	0x32A6: 0xA455,
	0x32A7: 0xA5AA,
	0x32A8: 0xA56B,
	0x32A9: 0xC2E5,
	0x32AA: 0xA976,
	0x32AB: 0xBEC7,
	0x32AC: 0xBACA,
	0x32AD: 0xA5F8,
	0x32AE: 0xB8EA,
	0x32AF: 0xA8F3,
	0x32B0: 0xA95D,
	0x32B1: 0xFFFD,
	0x32B2: 0xFFFD,
	0x32B3: 0xFFFD,
	0x32B4: 0xFFFD,
	0x32B5: 0xFFFD,
	0x32B6: 0xFFFD,
	0x32B7: 0xFFFD,
	0x32B8: 0xFFFD,
	0x32B9: 0xFFFD,
	0x32BA: 0xFFFD,
	0x32BB: 0xFFFD,
	0x32BC: 0xFFFD,
	0x32BD: 0xFFFD,
	0x32BE: 0xFFFD,
	0x32BF: 0xFFFD,
	0x32C0: 0xFFFD,
	0x32C1: 0xFFFD,
	0x32C2: 0xFFFD,
	0x32C3: 0xFFFD,
	0x32C4: 0xFFFD,
	0x32C5: 0xFFFD,
	0x32C6: 0xFFFD,
	0x32C7: 0xFFFD,
	0x32C8: 0xFFFD,
	0x32C9: 0xFFFD,
	0x32CA: 0xFFFD,
	0x32CB: 0xFFFD,
	0x32CC: 0x4867,
	0x32CD: 0xFFFD,
	0x32CE: 0x6556,
	0x32CF: 0xFFFD,
	0x32D0: 0xFFFD,
	0x32D1: 0xFFFD,
	0x32D2: 0xFFFD,
	0x32D3: 0xFFFD,
	0x32D4: 0xFFFD,
	0x32D5: 0xFFFD,
	0x32D6: 0xFFFD,
	0x32D7: 0xFFFD,
	0x32D8: 0xFFFD,
	0x32D9: 0xFFFD,
	0x32DA: 0xFFFD,
	0x32DB: 0xFFFD,
	0x32DC: 0xFFFD,
	0x32DD: 0xFFFD,
	0x32DE: 0xFFFD,
	0x32DF: 0xFFFD,
	0x32E0: 0xFFFD,
	0x32E1: 0xFFFD,
	0x32E2: 0xFFFD,
	0x32E3: 0xFFFD,
	0x32E4: 0xFFFD,
	0x32E5: 0xFFFD,
	0x32E6: 0xFFFD,
	0x32E7: 0xFFFD,
	0x32E8: 0xFFFD,
	0x32E9: 0xFFFD,
	0x32EA: 0xFFFD,
	0x32EB: 0xFFFD,
	0x32EC: 0xFFFD,
	0x32ED: 0xFFFD,
	0x32EE: 0xFFFD,
	0x32EF: 0xFFFD,
	0x32F0: 0xFFFD,
	0x32F1: 0xFFFD,
	0x32F2: 0xFFFD,
	0x32F3: 0xFFFD,
	0x32F4: 0xFFFD,
	0x32F5: 0xFFFD,
	0x32F6: 0xFFFD,
	0x32F7: 0xFFFD,
	0x32F8: 0xFFFD,
	0x32F9: 0xFFFD,
	0x32FA: 0xFFFD,
	0x32FB: 0xFFFD,
	0x32FC: 0xFFFD,
	0x32FD: 0xFFFD,
	0x32FE: 0xFFFD,
	0x32FF: 0xFFFD,
	0x3300: 0xFFFD,
	0x3301: 0xFFFD,
	0x3302: 0xFFFD,
	0x3303: 0xFFFD,
	0x3304: 0xFFFD,
	0x3305: 0xFFFD,
	0x3306: 0xFFFD,
	0x3307: 0xFFFD,
	0x3308: 0xFFFD,
	0x3309: 0xFFFD,
	0x330A: 0xFFFD,
	0x330B: 0xFFFD,
	0x330C: 0xFFFD,
	0x330D: 0xFFFD,
	0x330E: 0xFFFD,
	0x330F: 0xFFFD,
	0x3310: 0xFFFD,
	0x3311: 0xFFFD,
	0x3312: 0xFFFD,
	0x3313: 0xFFFD,
	0x3314: 0xFFFD,
	0x3315: 0xFFFD,
	0x3316: 0xFFFD,
	0x3317: 0xFFFD,
	0x3318: 0xFFFD,
	0x3319: 0xFFFD,
	0x331A: 0xFFFD,
	0x331B: 0xFFFD,
	0x331C: 0xFFFD,
	0x331D: 0xFFFD,
	0x331E: 0xFFFD,
	0x331F: 0xFFFD,
	0x3320: 0xFFFD,
	0x3321: 0xFFFD,
	0x3322: 0xFFFD,
	0x3323: 0xFFFD,
	0x3324: 0xFFFD,
	0x3325: 0xFFFD,
	0x3326: 0xFFFD,
	0x3327: 0xFFFD,
	0x3328: 0xFFFD,
	0x3329: 0xFFFD,
	0x332A: 0xFFFD,
	0x332B: 0xFFFD,
	0x332C: 0xFFFD,
	0x332D: 0xFFFD,
	0x332E: 0xFFFD,
	0x332F: 0xFFFD,
	0x3330: 0xFFFD,
	0x3331: 0xFFFD,
	0x3332: 0xFFFD,
	0x3333: 0xFFFD,
	0x3334: 0xFFFD,
	0x3335: 0xFFFD,
	0x3336: 0xFFFD,
	0x3337: 0xFFFD,
	0x3338: 0xFFFD,
	0x3339: 0xFFFD,
	0x333A: 0xFFFD,
	0x333B: 0xFFFD,
	0x333C: 0xFFFD,
	0x333D: 0xFFFD,
	0x333E: 0xFFFD,
	0x333F: 0xFFFD,
	0x3340: 0xFFFD,
	0x3341: 0xFFFD,
	0x3342: 0xFFFD,
	0x3343: 0xFFFD,
	0x3344: 0xFFFD,
	0x3345: 0xFFFD,
	0x3346: 0xFFFD,
	0x3347: 0xFFFD,
	0x3348: 0xFFFD,
	0x3349: 0xFFFD,
	0x334A: 0xFFFD,
	0x334B: 0xFFFD,
	0x334C: 0xFFFD,
	0x334D: 0xFFFD,
	0x334E: 0xFFFD,
	0x334F: 0xFFFD,
	0x3350: 0xFFFD,
	0x3351: 0xFFFD,
	0x3352: 0xFFFD,
	0x3353: 0xFFFD,
	0x3354: 0xFFFD,
	0x3355: 0xFFFD,
	0x3356: 0xFFFD,
	0x3357: 0xFFFD,
	0x3358: 0xFFFD,
	0x3359: 0xFFFD,
	0x335A: 0xFFFD,
	0x335B: 0xFFFD,
	0x335C: 0xFFFD,
	0x335D: 0xFFFD,
	0x335E: 0xFFFD,
	0x335F: 0xFFFD,
	0x3360: 0xFFFD,
	0x3361: 0xFFFD,
	0x3362: 0xFFFD,
	0x3363: 0xFFFD,
	0x3364: 0xFFFD,
	0x3365: 0xFFFD,
	0x3366: 0xFFFD,
	0x3367: 0xFFFD,
	0x3368: 0xFFFD,
	0x3369: 0xFFFD,
	0x336A: 0xFFFD,
	0x336B: 0xFFFD,
	0x336C: 0xFFFD,
	0x336D: 0xFFFD,
	0x336E: 0xFFFD,
	0x336F: 0xFFFD,
	0x3370: 0xFFFD,
	0x3371: 0xFFFD,
	0x3372: 0x6461,
	0x3373: 0x4155,
	0x3374: 0xFFFD,
	0x3375: 0x6F56,
	0x3376: 0x7063,
	0x3377: 0x646D,
	0x3378: 0xFFFD,
	0x3379: 0xFFFD,
	0x337A: 0x4955,
	0x337B: 0xFFFD,
	0x337C: 0xFFFD,
	0x337D: 0xFFFD,
	0x337E: 0xFFFD,
	0x337F: 0xFFFD,
	0x3380: 0x7041,
	0x3381: 0x6E41,
	0x3382: 0xFFFD,
	0x3383: 0x6D41,
	0x3384: 0x6B41,
	0x3385: 0x4B42,
	0x3386: 0x4D42,
	0x3387: 0x4742,
	0x3388: 0xFFFD,
	0x3389: 0xFFFD,
	0x338A: 0x7046,
	0x338B: 0x6E46,
	0x338C: 0xFFFD,
	0x338D: 0xFFFD,
	0x338E: 0xA255,
	0x338F: 0xA256,
	0x3390: 0x487A,
	0x3391: 0xFFFD,
	0x3392: 0xFFFD,
	0x3393: 0xFFFD,
	0x3394: 0xFFFD,
	0x3395: 0xFFFD,
	0x3396: 0xFFFD,
	0x3397: 0xFFFD,
	0x3398: 0xFFFD,
	0x3399: 0x666D,
	0x339A: 0x6E6D,
	0x339B: 0xFFFD,
	0x339C: 0xA250,
	0x339D: 0xA251,
	0x339E: 0xA252,
	0x339F: 0xFFFD,
	0x33A0: 0xFFFD,
	0x33A1: 0xA254,
	0x33A2: 0xFFFD,
	0x33A3: 0xFFFD,
	0x33A4: 0xFFFD,
	0x33A5: 0x9DE7,
	0x33A6: 0xFFFD,
	0x33A7: 0xFFFD,
	0x33A8: 0xFFFD,
	0x33A9: 0x5061,
	0x33AA: 0xFFFD,
	0x33AB: 0xFFFD,
	0x33AC: 0xFFFD,
	0x33AD: 0xFFFD,
	0x33AE: 0xFFFD,
	0x33AF: 0xFFFD,
	0x33B0: 0x7073,
	0x33B1: 0x6E73,
	0x33B2: 0xFFFD,
	0x33B3: 0x6D73,
	0x33B4: 0x7056,
	0x33B5: 0x6E56,
	0x33B6: 0xFFFD,
	0x33B7: 0x6D56,
	0x33B8: 0x6B56,
	0x33B9: 0x4D56,
	0x33BA: 0x7057,
	0x33BB: 0x6E57,
	0x33BC: 0xFFFD,
	0x33BD: 0x6D57,
	0x33BE: 0x6B57,
	0x33BF: 0x4D57,
	0x33C0: 0xFFFD,
	0x33C1: 0xFFFD,
	0x33C2: 0x9DE3,
	0x33C3: 0x4271,
	0x33C4: 0xA257,
	0x33C5: 0x6364,
	0x33C6: 0xFFFD,
	0x33C7: 0xFFFD,
	0x33C8: 0x6442,
	0x33C9: 0x4779,
	0x33CA: 0x6861,
	0x33CB: 0x4850,
	0x33CC: 0x696E,
	0x33CD: 0x4B4B,
	0x33CE: 0xA253,
	0x33CF: 0x6B74,
	0x33D0: 0x6C6D,
	0x33D1: 0xA1EB,
	0x33D2: 0xA1EA,
	0x33D3: 0x6C78,
	0x33D4: 0x6D62,
	0x33D5: 0xA24F,
	0x33D6: 0xFFFD,
	0x33D7: 0x5048,
	0x33D8: 0x9DE4,
	0x33D9: 0xFFFD,
	0x33DA: 0x5052,
	0x33DB: 0x7372,
	0x33DC: 0x5376,
	0x33DD: 0x5762,
	0x33DE: 0xFFFD,
	0x33DF: 0xFFFD,
	0x33E0: 0xFFFD,
	0x33E1: 0xFFFD,
	0x33E2: 0xFFFD,
	0x33E3: 0xFFFD,
	0x33E4: 0xFFFD,
	0x33E5: 0xFFFD,
	0x33E6: 0xFFFD,
	0x33E7: 0xFFFD,
	0x33E8: 0xFFFD,
	0x33E9: 0xFFFD,
	0x33EA: 0xFFFD,
	0x33EB: 0xFFFD,
	0x33EC: 0xFFFD,
	0x33ED: 0xFFFD,
	0x33EE: 0xFFFD,
	0x33EF: 0xFFFD,
	0x33F0: 0xFFFD,
	0x33F1: 0xFFFD,
	0x33F2: 0xFFFD,
	0x33F3: 0xFFFD,
	0x33F4: 0xFFFD,
	0x33F5: 0xFFFD,
	0x33F6: 0xFFFD,
	0x33F7: 0xFFFD,
	0x33F8: 0xFFFD,
	0x33F9: 0xFFFD,
	0x33FA: 0xFFFD,
	0x33FB: 0xFFFD,
	0x33FC: 0xFFFD,
	0x33FD: 0xFFFD,
	0x33FE: 0xFFFD,
	0x33FF: 0xFFFD,
	0x3400: 0xFFFD,
	0x3401: 0xFFFD,
	0x3402: 0xFFFD,
	0x3403: 0xFFFD,
	0x3404: 0x91E0,
	0x3405: 0xFFFD,
	0x3406: 0xFFFD,
	0x3407: 0xFFFD,
	0x3408: 0xFFFD,
	0x3409: 0xFFFD,
	0x340A: 0xFFFD,
	0x340B: 0xFFFD,
	0x340C: 0xFFFD,
	0x340D: 0xFFFD,
	0x340E: 0xFFFD,
	0x340F: 0xFFFD,
	0x3410: 0xFFFD,
	0x3411: 0xFFFD,
	0x3412: 0xFFFD,
	0x3413: 0xFFFD,
	0x3414: 0xFFFD,
	0x3415: 0xFFFD,
	0x3416: 0xFFFD,
	0x3417: 0xFFFD,
	0x3418: 0xFFFD,
	0x3419: 0xFFFD,
	0x341A: 0xFFFD,
	0x341B: 0xFFFD,
	0x341C: 0xFFFD,
	0x341D: 0xFFFD,
	0x341E: 0xFFFD,
	0x341F: 0xFFFD,
	0x3420: 0xFFFD,
	0x3421: 0xFFFD,
	0x3422: 0xFFFD,
	0x3423: 0xFFFD,
	0x3424: 0xFFFD,
	0x3425: 0xFFFD,
	0x3426: 0xFFFD,
	0x3427: 0xFFFD,
	0x3428: 0xFFFD,
	0x3429: 0xFFFD,
	0x342A: 0xFFFD,
	0x342B: 0xFFFD,
	0x342C: 0xFFFD,
	0x342D: 0xFFFD,
	0x342E: 0xFFFD,
	0x342F: 0xFFFD,
	0x3430: 0xFFFD,
	0x3431: 0xFFFD,
	0x3432: 0xFFFD,
	0x3433: 0xFFFD,
	0x3434: 0xFFFD,
	0x3435: 0xFFFD,
	0x3436: 0xFFFD,
	0x3437: 0xFFFD,
	0x3438: 0xFFFD,
	0x3439: 0xFFFD,
	0x343A: 0xFFFD,
	0x343B: 0xFFFD,
	0x343C: 0xFFFD,
	0x343D: 0xFFFD,
	0x343E: 0xFFFD,
	0x343F: 0xFFFD,
	0x3440: 0xFFFD,
	0x3441: 0xFFFD,
	0x3442: 0xFFFD,
	0x3443: 0xFFFD,
	0x3444: 0xFFFD,
	0x3445: 0xFFFD,
	0x3446: 0xFFFD,
	0x3447: 0xFFFD,
	0x3448: 0xFFFD,
	0x3449: 0xFFFD,
	0x344A: 0xFFFD,
	0x344B: 0xFFFD,
	0x344C: 0xFFFD,
	0x344D: 0xFFFD,
	0x344E: 0xFFFD,
	0x344F: 0xFFFD,
	0x3450: 0xFFFD,
	0x3451: 0xA0A2,
	0x3452: 0xFFFD,
	0x3453: 0xFFFD,
	0x3454: 0xFFFD,
	0x3455: 0xFFFD,
	0x3456: 0xFFFD,
	0x3457: 0xFFFD,
	0x3458: 0xFFFD,
	0x3459: 0xFFFD,
	0x345A: 0xFFFD,
	0x345B: 0xFFFD,
	0x345C: 0xFFFD,
	0x345D: 0xFFFD,
	0x345E: 0xFFFD,
	0x345F: 0xFFFD,
	0x3460: 0xFFFD,
	0x3461: 0xFFFD,
	0x3462: 0xFFFD,
	0x3463: 0xFFFD,
	0x3464: 0xFFFD,
	0x3465: 0xFFFD,
	0x3466: 0xFFFD,
	0x3467: 0xFFFD,
	0x3468: 0xFFFD,
	0x3469: 0xFFFD,
	0x346A: 0xFFFD,
	0x346B: 0xFFFD,
	0x346C: 0xFFFD,
	0x346D: 0xFFFD,
	0x346E: 0xFFFD,
	0x346F: 0xFFFD,
	0x3470: 0xFFFD,
	0x3471: 0xFFFD,
	0x3472: 0xFFFD,
	0x3473: 0xFFFD,
	0x3474: 0xFFFD,
	0x3475: 0xFFFD,
	0x3476: 0xFFFD,
	0x3477: 0xFFFD,
	0x3478: 0xFFFD,
	0x3479: 0xFFFD,
	0x347A: 0xFFFD,
	0x347B: 0xFFFD,
	0x347C: 0xFFFD,
	0x347D: 0xFFFD,
	0x347E: 0xFFFD,
	0x347F: 0xFFFD,
	0x3480: 0xFFFD,
	0x3481: 0xFFFD,
	0x3482: 0xFFFD,
	0x3483: 0xFFFD,
	0x3484: 0xFFFD,
	0x3485: 0xFFFD,
	0x3486: 0xFFFD,
	0x3487: 0xFFFD,
	0x3488: 0xFFFD,
	0x3489: 0xFFFD,
	0x348A: 0xFFFD,
	0x348B: 0xFFFD,
	0x348C: 0xFFFD,
	0x348D: 0xFFFD,
	0x348E: 0xFFFD,
	0x348F: 0xFFFD,
	0x3490: 0xFFFD,
	0x3491: 0xFFFD,
	0x3492: 0xFFFD,
	0x3493: 0xFFFD,
	0x3494: 0xFFFD,
	0x3495: 0xFFFD,
	0x3496: 0xFFFD,
	0x3497: 0xFFFD,
	0x3498: 0xFFFD,
	0x3499: 0xFFFD,
	0x349A: 0xFFFD,
	0x349B: 0xFFFD,
	0x349C: 0xFFFD,
	0x349D: 0xFFFD,
	0x349E: 0xFFFD,
	0x349F: 0xFFFD,
	0x34A0: 0xFFFD,
	0x34A1: 0xFFFD,
	0x34A2: 0xFFFD,
	0x34A3: 0xFFFD,
	0x34A4: 0xFFFD,
	0x34A5: 0xFFFD,
	0x34A6: 0xFFFD,
	0x34A7: 0xFFFD,
	0x34A8: 0xFFFD,
	0x34A9: 0xFFFD,
	0x34AA: 0xFFFD,
	0x34AB: 0xFFFD,
	0x34AC: 0xFFFD,
	0x34AD: 0xFFFD,
	0x34AE: 0xFFFD,
	0x34AF: 0xFFFD,
	0x34B0: 0xFFFD,
	0x34B1: 0xFFFD,
	0x34B2: 0xFFFD,
	0x34B3: 0xFFFD,
	0x34B4: 0xFFFD,
	0x34B5: 0xFFFD,
	0x34B6: 0xFFFD,
	0x34B7: 0xFFFD,
	0x34B8: 0xFFFD,
	0x34B9: 0xFFFD,
	0x34BA: 0xFFFD,
	0x34BB: 0xFFFD,
	0x34BC: 0xFFFD,
	0x34BD: 0xFFFD,
	0x34BE: 0xFFFD,
	0x34BF: 0xFFFD,
	0x34C0: 0xFFFD,
	0x34C1: 0xFFFD,
	0x34C2: 0xFFFD,
	0x34C3: 0xFFFD,
	0x34C4: 0xFFFD,
	0x34C5: 0xFFFD,
	0x34C6: 0xFFFD,
	0x34C7: 0xFFFD,
	0x34C8: 0xFFFD,
	0x34C9: 0xFFFD,
	0x34CA: 0xFFFD,
	0x34CB: 0xFFFD,
	0x34CC: 0xFFFD,
	0x34CD: 0xFFFD,
	0x34CE: 0xFFFD,
	0x34CF: 0xFFFD,
	0x34D0: 0xFFFD,
	0x34D1: 0xFFFD,
	0x34D2: 0xFFFD,
	0x34D3: 0xFFFD,
	0x34D4: 0xFFFD,
	0x34D5: 0xFFFD,
	0x34D6: 0xFFFD,
	0x34D7: 0xFFFD,
	0x34D8: 0xFFFD,
	0x34D9: 0xFFFD,
	0x34DA: 0xFFFD,
	0x34DB: 0xFFFD,
	0x34DC: 0xFFFD,
	0x34DD: 0xFFFD,
	0x34DE: 0xFFFD,
	0x34DF: 0xFB44,
	0x34E0: 0xFFFD,
	0x34E1: 0xFFFD,
	0x34E2: 0xFFFD,
	0x34E3: 0xFFFD,
	0x34E4: 0xFFFD,
	0x34E5: 0xFFFD,
	0x34E6: 0xFFFD,
	0x34E7: 0xFFFD,
	0x34E8: 0xFFFD,
	0x34E9: 0xFFFD,
	0x34EA: 0xFFFD,
	0x34EB: 0xFFFD,
	0x34EC: 0xFFFD,
	0x34ED: 0xFFFD,
	0x34EE: 0xFFFD,
	0x34EF: 0xFFFD,
	0x34F0: 0xFFFD,
	0x34F1: 0xFFFD,
	0x34F2: 0xFFFD,
	0x34F3: 0xFFFD,
	0x34F4: 0xFFFD,
	0x34F5: 0xFFFD,
	0x34F6: 0xFFFD,
	0x34F7: 0xFFFD,
	0x34F8: 0xFFFD,
	0x34F9: 0xFFFD,
	0x34FA: 0xFFFD,
	0x34FB: 0xFFFD,
	0x34FC: 0xFFFD,
	0x34FD: 0xFFFD,
	0x34FE: 0xFFFD,
	0x34FF: 0xFFFD,
	0x3500: 0xFFFD,
	0x3501: 0xFFFD,
	0x3502: 0xFFFD,
	0x3503: 0xFFFD,
	0x3504: 0xFFFD,
	0x3505: 0xFFFD,
	0x3506: 0xFFFD,
	0x3507: 0xFFFD,
	0x3508: 0xFFFD,
	0x3509: 0xFFFD,
	0x350A: 0xFFFD,
	0x350B: 0xFFFD,
	0x350C: 0xFFFD,
	0x350D: 0xFFFD,
	0x350E: 0xFFFD,
	0x350F: 0xFFFD,
	0x3510: 0xFFFD,
	0x3511: 0xFFFD,
	0x3512: 0xFFFD,
	0x3513: 0xFFFD,
	0x3514: 0xFFFD,
	0x3515: 0xFFFD,
	0x3516: 0xFFFD,
	0x3517: 0xFFFD,
	0x3518: 0xFFFD,
	0x3519: 0xFFFD,
	0x351A: 0xFFFD,
	0x351B: 0xFFFD,
	0x351C: 0xFFFD,
	0x351D: 0xFFFD,
	0x351E: 0xFFFD,
	0x351F: 0xFFFD,
	0x3520: 0xFFFD,
	0x3521: 0xFFFD,
	0x3522: 0xFFFD,
	0x3523: 0xFFFD,
	0x3524: 0xFFFD,
	0x3525: 0xFFFD,
	0x3526: 0xFFFD,
	0x3527: 0xFFFD,
	0x3528: 0xFFFD,
	0x3529: 0xFFFD,
	0x352A: 0xFFFD,
	0x352B: 0xFFFD,
	0x352C: 0xFFFD,
	0x352D: 0xFFFD,
	0x352E: 0xFFFD,
	0x352F: 0xFFFD,
	0x3530: 0xFFFD,
	0x3531: 0xFFFD,
	0x3532: 0xFFFD,
	0x3533: 0xFFFD,
	0x3534: 0xFFFD,
	0x3535: 0xFFFD,
	0x3536: 0xFFFD,
	0x3537: 0xFFFD,
	0x3538: 0xFFFD,
	0x3539: 0xFFFD,
	0x353A: 0xFFFD,
	0x353B: 0xFFFD,
	0x353C: 0xFFFD,
	0x353D: 0xFFFD,
	0x353E: 0xFFFD,
	0x353F: 0xFFFD,
	0x3540: 0xFFFD,
	0x3541: 0xFFFD,
	0x3542: 0xFFFD,
	0x3543: 0xFFFD,
	0x3544: 0xFFFD,
	0x3545: 0xFFFD,
	0x3546: 0xFFFD,
	0x3547: 0xFFFD,
	0x3548: 0xFFFD,
	0x3549: 0xFFFD,
	0x354A: 0xFFFD,
	0x354B: 0xFFFD,
	0x354C: 0xFFFD,
	0x354D: 0xFFFD,
	0x354E: 0xFFFD,
	0x354F: 0xFFFD,
	0x3550: 0xFFFD,
	0x3551: 0x95B8,
	0x3552: 0xFFFD,
	0x3553: 0xFFFD,
	0x3554: 0xFFFD,
	0x3555: 0xFFFD,
	0x3556: 0xFFFD,
	0x3557: 0xFFFD,
	0x3558: 0xFFFD,
	0x3559: 0xFFFD,
	0x355A: 0xFFFD,
	0x355B: 0xFFFD,
	0x355C: 0xFFFD,
	0x355D: 0xFFFD,
	0x355E: 0xFFFD,
	0x355F: 0xFFFD,
	0x3560: 0xFFFD,
	0x3561: 0xFFFD,
	0x3562: 0xFFFD,
	0x3563: 0xFFFD,
	0x3564: 0xFFFD,
	0x3565: 0xFFFD,
	0x3566: 0xFFFD,
	0x3567: 0xFFFD,
	0x3568: 0xFFFD,
	0x3569: 0xFFFD,
	0x356A: 0xFFFD,
	0x356B: 0xFFFD,
	0x356C: 0xFFFD,
	0x356D: 0xFFFD,
	0x356E: 0xFFFD,
	0x356F: 0xFFFD,
	0x3570: 0xFFFD,
	0x3571: 0xFFFD,
	0x3572: 0xFFFD,
	0x3573: 0xFFFD,
	0x3574: 0xFFFD,
	0x3575: 0xFFFD,
	0x3576: 0xFFFD,
	0x3577: 0xFFFD,
	0x3578: 0xFFFD,
	0x3579: 0xFFFD,
	0x357A: 0xFFFD,
	0x357B: 0xFFFD,
	0x357C: 0xFFFD,
	0x357D: 0xFFFD,
	0x357E: 0xFFFD,
	0x357F: 0xFFFD,
	0x3580: 0xFFFD,
	0x3581: 0xFFFD,
	0x3582: 0xFFFD,
	0x3583: 0xFFFD,
	0x3584: 0xFFFD,
	0x3585: 0xFFFD,
	0x3586: 0xFFFD,
	0x3587: 0xFFFD,
	0x3588: 0xFFFD,
	0x3589: 0xFFFD,
	0x358A: 0xFFFD,
	0x358B: 0xFFFD,
	0x358C: 0xFFFD,
	0x358D: 0xFFFD,
	0x358E: 0xFFFD,
	0x358F: 0xFFFD,
	0x3590: 0xFFFD,
	0x3591: 0xFFFD,
	0x3592: 0xFFFD,
	0x3593: 0xFFFD,
	0x3594: 0xFFFD,
	0x3595: 0xFFFD,
	0x3596: 0xFFFD,
	0x3597: 0xFFFD,
	0x3598: 0xFFFD,
	0x3599: 0xFFFD,
	0x359A: 0xFFFD,
	0x359B: 0xFFFD,
	0x359C: 0xFFFD,
	0x359D: 0xFFFD,
	0x359E: 0xFFFD,
	0x359F: 0xFFFD,
	0x35A0: 0xFFFD,
	0x35A1: 0xFFFD,
	0x35A2: 0xFFFD,
	0x35A3: 0xFFFD,
	0x35A4: 0xFFFD,
	0x35A5: 0xFFFD,
	0x35A6: 0xFFFD,
	0x35A7: 0xFFFD,
	0x35A8: 0xFFFD,
	0x35A9: 0xFFFD,
	0x35AA: 0xFFFD,
	0x35AB: 0xFFFD,
	0x35AC: 0xFFFD,
	0x35AD: 0xFFFD,
	0x35AE: 0xFFFD,
	0x35AF: 0xFFFD,
	0x35B0: 0xFFFD,
	0x35B1: 0xFFFD,
	0x35B2: 0xFFFD,
	0x35B3: 0xFFFD,
	0x35B4: 0xFFFD,
	0x35B5: 0xFFFD,
	0x35B6: 0xFFFD,
	0x35B7: 0xFFFD,
	0x35B8: 0xFFFD,
	0x35B9: 0xFFFD,
	0x35BA: 0xFFFD,
	0x35BB: 0xFFFD,
	0x35BC: 0xFFFD,
	0x35BD: 0xFFFD,
	0x35BE: 0xFFFD,
	0x35BF: 0xFFFD,
	0x35C0: 0xFFFD,
	0x35C1: 0xFFFD,
	0x35C2: 0xFFFD,
	0x35C3: 0xFFFD,
	0x35C4: 0xFFFD,
	0x35C5: 0xFFFD,
	0x35C6: 0xFFFD,
	0x35C7: 0xFFFD,
	0x35C8: 0xFFFD,
	0x35C9: 0xFFFD,
	0x35CA: 0xFFFD,
	0x35CB: 0xFFFD,
	0x35CC: 0xFFFD,
	0x35CD: 0xFFFD,
	0x35CE: 0xA048,
	0x35CF: 0xFFFD,
	0x35D0: 0xFFFD,
	0x35D1: 0xFFFD,
	0x35D2: 0xA04C,
	0x35D3: 0xFFFD,
	0x35D4: 0xFFFD,
	0x35D5: 0xFFFD,
	0x35D6: 0xFBDF,
	0x35D7: 0xFFFD,
	0x35D8: 0xFFFD,
	0x35D9: 0xFFFD,
	0x35DA: 0xFFFD,
	0x35DB: 0xFFFD,
	0x35DC: 0xFFFD,
	0x35DD: 0xFFFD,
	0x35DE: 0xFFFD,
	0x35DF: 0xFFFD,
	0x35E0: 0xFFFD,
	0x35E1: 0xFFFD,
	0x35E2: 0xFFFD,
	0x35E3: 0xFFFD,
	0x35E4: 0xFFFD,
	0x35E5: 0xFFFD,
	0x35E6: 0xFFFD,
	0x35E7: 0xFFFD,
	0x35E8: 0xFFFD,
	0x35E9: 0xFFFD,
	0x35EA: 0xFFFD,
	0x35EB: 0xFFFD,
	0x35EC: 0xFFFD,
	0x35ED: 0xFFFD,
	0x35EE: 0xFFFD,
	0x35EF: 0xFFFD,
	0x35F0: 0xFFFD,
	0x35F1: 0xFFFD,
	0x35F2: 0xFFFD,
	0x35F3: 0xFBE5,
	0x35F4: 0xFFFD,
	0x35F5: 0xFFFD,
	0x35F6: 0xFFFD,
	0x35F7: 0xFFFD,
	0x35F8: 0xFFFD,
	0x35F9: 0xFFFD,
	0x35FA: 0xFFFD,
	0x35FB: 0xFFFD,
	0x35FC: 0xFFFD,
	0x35FD: 0xFFFD,
	0x35FE: 0xFB6F,
	0x35FF: 0xFFFD,
	0x3600: 0xFFFD,
	0x3601: 0xFFFD,
	0x3602: 0xFFFD,
	0x3603: 0xFFFD,
	0x3604: 0xFFFD,
	0x3605: 0xFFFD,
	0x3606: 0xFFFD,
	0x3607: 0xFFFD,
	0x3608: 0xFFFD,
	0x3609: 0xFFFD,
	0x360A: 0xFFFD,
	0x360B: 0xFFFD,
	0x360C: 0xFFFD,
	0x360D: 0xFFFD,
	0x360E: 0xFFFD,
	0x360F: 0xFFFD,
	0x3610: 0xFFFD,
	0x3611: 0xFFFD,
	0x3612: 0xFFFD,
	0x3613: 0xFFFD,
	0x3614: 0xFFFD,
	0x3615: 0xFFFD,
	0x3616: 0xFFFD,
	0x3617: 0xFFFD,
	0x3618: 0xFFFD,
	0x3619: 0xFFFD,
	0x361A: 0xFFFD,
	0x361B: 0xFFFD,
	0x361C: 0xFFFD,
	0x361D: 0xFFFD,
	0x361E: 0xFFFD,
	0x361F: 0xFFFD,
	0x3620: 0xFFFD,
	0x3621: 0xFFFD,
	0x3622: 0xFFFD,
	0x3623: 0xFFFD,
	0x3624: 0xFFFD,
	0x3625: 0xFFFD,
	0x3626: 0xFFFD,
	0x3627: 0xFFFD,
	0x3628: 0xFFFD,
	0x3629: 0xFFFD,
	0x362A: 0xFFFD,
	0x362B: 0xFFFD,
	0x362C: 0xFFFD,
	0x362D: 0x9542,
	0x362E: 0xFFFD,
	0x362F: 0xFFFD,
	0x3630: 0xFFFD,
	0x3631: 0xFFFD,
	0x3632: 0xFFFD,
	0x3633: 0xFFFD,
	0x3634: 0xFFFD,
	0x3635: 0xFFFD,
	0x3636: 0xFFFD,
	0x3637: 0xFFFD,
	0x3638: 0xFFFD,
	0x3639: 0xFFFD,
	0x363A: 0xFFFD,
	0x363B: 0xFFFD,
	0x363C: 0xFFFD,
	0x363D: 0xFFFD,
	0x363E: 0xFFFD,
	0x363F: 0xFFFD,
	0x3640: 0xFFFD,
	0x3641: 0xFFFD,
	0x3642: 0xFFFD,
	0x3643: 0xFFFD,
	0x3644: 0xFFFD,
	0x3645: 0xFFFD,
	0x3646: 0xFFFD,
	0x3647: 0xFFFD,
	0x3648: 0xFFFD,
	0x3649: 0xFFFD,
	0x364A: 0xFFFD,
	0x364B: 0xFFFD,
	0x364C: 0xFFFD,
	0x364D: 0xFFFD,
	0x364E: 0xFFFD,
	0x364F: 0xFFFD,
	0x3650: 0xFFFD,
	0x3651: 0xFFFD,
	0x3652: 0xFFFD,
	0x3653: 0xFFFD,
	0x3654: 0xFE7D,
	0x3655: 0xFFFD,
	0x3656: 0xFFFD,
	0x3657: 0xFFFD,
	0x3658: 0xFFFD,
	0x3659: 0xFFFD,
	0x365A: 0xFFFD,
	0x365B: 0xFFFD,
	0x365C: 0xFFFD,
	0x365D: 0xFFFD,
	0x365E: 0xFFFD,
	0x365F: 0xFFFD,
	0x3660: 0xFFFD,
	0x3661: 0xFFFD,
	0x3662: 0xFFFD,
	0x3663: 0xFFFD,
	0x3664: 0xFFFD,
	0x3665: 0xFFFD,
	0x3666: 0xFFFD,
	0x3667: 0xFFFD,
	0x3668: 0xFFFD,
	0x3669: 0xFFFD,
	0x366A: 0xFFFD,
	0x366B: 0xFFFD,
	0x366C: 0xFFFD,
	0x366D: 0xFFFD,
	0x366E: 0xFFFD,
	0x366F: 0xFFFD,
	0x3670: 0xFFFD,
	0x3671: 0xFFFD,
	0x3672: 0xFFFD,
	0x3673: 0xFFFD,
	0x3674: 0xFFFD,
	0x3675: 0xFFFD,
	0x3676: 0xFFFD,
	0x3677: 0xFFFD,
	0x3678: 0xFFFD,
	0x3679: 0xFFFD,
	0x367A: 0xFFFD,
	0x367B: 0xFFFD,
	0x367C: 0xFFFD,
	0x367D: 0xFFFD,
	0x367E: 0xFFFD,
	0x367F: 0xFFFD,
	0x3680: 0xFFFD,
	0x3681: 0xFFFD,
	0x3682: 0xFFFD,
	0x3683: 0xFFFD,
	0x3684: 0xFFFD,
	0x3685: 0xFFFD,
	0x3686: 0xFFFD,
	0x3687: 0xFFFD,
	0x3688: 0xFFFD,
	0x3689: 0xFFFD,
	0x368A: 0xFFFD,
	0x368B: 0xFFFD,
	0x368C: 0xFFFD,
	0x368D: 0xFFFD,
	0x368E: 0xFFFD,
	0x368F: 0xFFFD,
	0x3690: 0xFFFD,
	0x3691: 0xFFFD,
	0x3692: 0xFFFD,
	0x3693: 0xFFFD,
	0x3694: 0xFFFD,
	0x3695: 0xFFFD,
	0x3696: 0xFFFD,
	0x3697: 0xFFFD,
	0x3698: 0xFFFD,
	0x3699: 0xFFFD,
	0x369A: 0xFFFD,
	0x369B: 0xFFFD,
	0x369C: 0xFFFD,
	0x369D: 0xFFFD,
	0x369E: 0xFFFD,
	0x369F: 0xFFFD,
	0x36A0: 0xFFFD,
	0x36A1: 0xFFFD,
	0x36A2: 0xFFFD,
	0x36A3: 0xFFFD,
	0x36A4: 0xFFFD,
	0x36A5: 0xFFFD,
	0x36A6: 0xFFFD,
	0x36A7: 0xFFFD,
	0x36A8: 0xFFFD,
	0x36A9: 0xFFFD,
	0x36AA: 0xFFFD,
	0x36AB: 0xFFFD,
	0x36AC: 0xFFFD,
	0x36AD: 0xFFFD,
	0x36AE: 0xFFFD,
	0x36AF: 0xFFFD,
	0x36B0: 0xFFFD,
	0x36B1: 0xFFFD,
	0x36B2: 0xFFFD,
	0x36B3: 0xFFFD,
	0x36B4: 0xFFFD,
	0x36B5: 0xFFFD,
	0x36B6: 0xFFFD,
	0x36B7: 0xFFFD,
	0x36B8: 0xFFFD,
	0x36B9: 0xFFFD,
	0x36BA: 0xFFFD,
	0x36BB: 0xFFFD,
	0x36BC: 0xFFFD,
	0x36BD: 0xFFFD,
	0x36BE: 0xFFFD,
	0x36BF: 0xFFFD,
	0x36C0: 0xFFFD,
	0x36C1: 0xFFFD,
	0x36C2: 0xFFFD,
	0x36C3: 0xFFFD,
	0x36C4: 0xFFFD,
	0x36C5: 0xFFFD,
	0x36C6: 0xFFFD,
	0x36C7: 0xFE67,
	0x36C8: 0xFFFD,
	0x36C9: 0xFFFD,
	0x36CA: 0xFFFD,
	0x36CB: 0xFFFD,
	0x36CC: 0xFFFD,
	0x36CD: 0xFFFD,
	0x36CE: 0xFFFD,
	0x36CF: 0xFFFD,
	0x36D0: 0xFFFD,
	0x36D1: 0xFFFD,
	0x36D2: 0xFFFD,
	0x36D3: 0xFFFD,
	0x36D4: 0xFFFD,
	0x36D5: 0xFFFD,
	0x36D6: 0xFFFD,
	0x36D7: 0xFFFD,
	0x36D8: 0xFFFD,
	0x36D9: 0xFFFD,
	0x36DA: 0xFFFD,
	0x36DB: 0xFFFD,
	0x36DC: 0xFFFD,
	0x36DD: 0xFFFD,
	0x36DE: 0xFFFD,
	0x36DF: 0xFFFD,
	0x36E0: 0xFFFD,
	0x36E1: 0xFFFD,
	0x36E2: 0xFFFD,
	0x36E3: 0xFFFD,
	0x36E4: 0xFFFD,
	0x36E5: 0xFFFD,
	0x36E6: 0xFFFD,
	0x36E7: 0xFFFD,
	0x36E8: 0xFFFD,
	0x36E9: 0xFFFD,
	0x36EA: 0xFFFD,
	0x36EB: 0xFFFD,
	0x36EC: 0xFFFD,
	0x36ED: 0xFFFD,
	0x36EE: 0xFFFD,
	0x36EF: 0xFFFD,
	0x36F0: 0xFFFD,
	0x36F1: 0xFFFD,
	0x36F2: 0xFFFD,
	0x36F3: 0xFFFD,
	0x36F4: 0xFFFD,
	0x36F5: 0xFFFD,
	0x36F6: 0xFFFD,
	0x36F7: 0xFFFD,
	0x36F8: 0xFFFD,
	0x36F9: 0xFFFD,
	0x36FA: 0xFFFD,
	0x36FB: 0xFFFD,
	0x36FC: 0xFFFD,
	0x36FD: 0xFFFD,
	0x36FE: 0xFFFD,
	0x36FF: 0xFFFD,
	0x3700: 0xFFFD,
	0x3701: 0xFFFD,
	0x3702: 0xFFFD,
	0x3703: 0xFFFD,
	0x3704: 0xFFFD,
	0x3705: 0xFFFD,
	0x3706: 0xFFFD,
	0x3707: 0xFFFD,
	0x3708: 0xFFFD,
	0x3709: 0xFFFD,
	0x370A: 0xFFFD,
	0x370B: 0xFFFD,
	0x370C: 0xFFFD,
	0x370D: 0xFFFD,
	0x370E: 0xFFFD,
	0x370F: 0xFFFD,
	0x3710: 0xFFFD,
	0x3711: 0xFFFD,
	0x3712: 0xFFFD,
	0x3713: 0xFFFD,
	0x3714: 0xFFFD,
	0x3715: 0xFFFD,
	0x3716: 0xFFFD,
	0x3717: 0xFFFD,
	0x3718: 0xFFFD,
	0x3719: 0xFFFD,
	0x371A: 0xFFFD,
	0x371B: 0xFFFD,
	0x371C: 0xFFFD,
	0x371D: 0xFFFD,
	0x371E: 0xFFFD,
	0x371F: 0xFFFD,
	0x3720: 0xFFFD,
	0x3721: 0xFFFD,
	0x3722: 0xFFFD,
	0x3723: 0xFFFD,
	0x3724: 0xFFFD,
	0x3725: 0xFFFD,
	0x3726: 0xFFFD,
	0x3727: 0xFFFD,
	0x3728: 0xFFFD,
	0x3729: 0xFFFD,
	0x372A: 0xFFFD,
	0x372B: 0xFFFD,
	0x372C: 0xFFFD,
	0x372D: 0xFFFD,
	0x372E: 0xFFFD,
	0x372F: 0xFFFD,
	0x3730: 0xFFFD,
	0x3731: 0xFFFD,
	0x3732: 0xFFFD,
	0x3733: 0xFFFD,
	0x3734: 0xFFFD,
	0x3735: 0xFFFD,
	0x3736: 0xFFFD,
	0x3737: 0xFFFD,
	0x3738: 0xFFFD,
	0x3739: 0xFFFD,
	0x373A: 0xFFFD,
	0x373B: 0xFFFD,
	0x373C: 0xFFFD,
	0x373D: 0xFFFD,
	0x373E: 0xFFFD,
	0x373F: 0xFFFD,
	0x3740: 0xFFFD,
	0x3741: 0xFFFD,
	0x3742: 0xFFFD,
	0x3743: 0xFFFD,
	0x3744: 0xFFFD,
	0x3745: 0xFFFD,
	0x3746: 0xFFFD,
	0x3747: 0xFFFD,
	0x3748: 0xFFFD,
	0x3749: 0xFFFD,
	0x374A: 0xFFFD,
	0x374B: 0xFFFD,
	0x374C: 0xFFFD,
	0x374D: 0xFFFD,
	0x374E: 0xFFFD,
	0x374F: 0xFFFD,
	0x3750: 0xFFFD,
	0x3751: 0xFFFD,
	0x3752: 0xFFFD,
	0x3753: 0xFFFD,
	0x3754: 0xFFFD,
	0x3755: 0xFFFD,
	0x3756: 0xFFFD,
	0x3757: 0xFFFD,
	0x3758: 0xFFFD,
	0x3759: 0xFFFD,
	0x375A: 0xFFFD,
	0x375B: 0xFFFD,
	0x375C: 0xFFFD,
	0x375D: 0xFFFD,
	0x375E: 0xFFFD,
	0x375F: 0xFFFD,
	0x3760: 0xFFFD,
	0x3761: 0xFFFD,
	0x3762: 0xFFFD,
	0x3763: 0xFFFD,
	0x3764: 0xFFFD,
	0x3765: 0xFFFD,
	0x3766: 0xFFFD,
	0x3767: 0xFFFD,
	0x3768: 0xFFFD,
	0x3769: 0xFFFD,
	0x376A: 0xFFFD,
	0x376B: 0xFFFD,
	0x376C: 0xFFFD,
	0x376D: 0xFFFD,
	0x376E: 0xFFFD,
	0x376F: 0xFFFD,
	0x3770: 0xFFFD,
	0x3771: 0xFFFD,
	0x3772: 0xFFFD,
	0x3773: 0xFFFD,
	0x3774: 0xFFFD,
	0x3775: 0xFFFD,
	0x3776: 0xFFFD,
	0x3777: 0xFFFD,
	0x3778: 0xFFFD,
	0x3779: 0xFFFD,
	0x377A: 0xFFFD,
	0x377B: 0xFFFD,
	0x377C: 0xFFFD,
	0x377D: 0xFFFD,
	0x377E: 0xFFFD,
	0x377F: 0xFFFD,
	0x3780: 0xFFFD,
	0x3781: 0xFFFD,
	0x3782: 0xFFFD,
	0x3783: 0xFFFD,
	0x3784: 0xFFFD,
	0x3785: 0xFFFD,
	0x3786: 0xFFFD,
	0x3787: 0xFFFD,
	0x3788: 0xFFFD,
	0x3789: 0xFFFD,
	0x378A: 0xFFFD,
	0x378B: 0xFFFD,
	0x378C: 0xFFFD,
	0x378D: 0xFFFD,
	0x378E: 0xFFFD,
	0x378F: 0xFFFD,
	0x3790: 0xFFFD,
	0x3791: 0xFFFD,
	0x3792: 0xFFFD,
	0x3793: 0xFFFD,
	0x3794: 0xFFFD,
	0x3795: 0xFFFD,
	0x3796: 0xFFFD,
	0x3797: 0xFFFD,
	0x3798: 0xFFFD,
	0x3799: 0xFFFD,
	0x379A: 0xFFFD,
	0x379B: 0xFFFD,
	0x379C: 0xFFFD,
	0x379D: 0xFFFD,
	0x379E: 0xFFFD,
	0x379F: 0xFFFD,
	0x37A0: 0xFFFD,
	0x37A1: 0xFFFD,
	0x37A2: 0xFFFD,
	0x37A3: 0xFFFD,
	0x37A4: 0xFFFD,
	0x37A5: 0xFFFD,
	0x37A6: 0xFFFD,
	0x37A7: 0xFFFD,
	0x37A8: 0xFFFD,
	0x37A9: 0xFFFD,
	0x37AA: 0xFFFD,
	0x37AB: 0xFFFD,
	0x37AC: 0xFFFD,
	0x37AD: 0xFFFD,
	0x37AE: 0xFFFD,
	0x37AF: 0xFFFD,
	0x37B0: 0xFFFD,
	0x37B1: 0xFFFD,
	0x37B2: 0xFFFD,
	0x37B3: 0xFFFD,
	0x37B4: 0xFFFD,
	0x37B5: 0xFFFD,
	0x37B6: 0xFFFD,
	0x37B7: 0xFFFD,
	0x37B8: 0xFFFD,
	0x37B9: 0xFFFD,
	0x37BA: 0xFFFD,
	0x37BB: 0xFFFD,
	0x37BC: 0xFFFD,
	0x37BD: 0xFFFD,
	0x37BE: 0xFFFD,
	0x37BF: 0xFFFD,
	0x37C0: 0xFFFD,
	0x37C1: 0xFFFD,
	0x37C2: 0xFFFD,
	0x37C3: 0xFFFD,
	0x37C4: 0xFFFD,
	0x37C5: 0xFFFD,
	0x37C6: 0xFFFD,
	0x37C7: 0xFFFD,
	0x37C8: 0xFFFD,
	0x37C9: 0xFFFD,
	0x37CA: 0xFFFD,
	0x37CB: 0xFFFD,
	0x37CC: 0xFFFD,
	0x37CD: 0xFFFD,
	0x37CE: 0xFFFD,
	0x37CF: 0xFFFD,
	0x37D0: 0xFFFD,
	0x37D1: 0xFFFD,
	0x37D2: 0xFFFD,
	0x37D3: 0xFFFD,
	0x37D4: 0xFFFD,
	0x37D5: 0xFFFD,
	0x37D6: 0xFFFD,
	0x37D7: 0xFFFD,
	0x37D8: 0xFFFD,
	0x37D9: 0xFFFD,
	0x37DA: 0xFFFD,
	0x37DB: 0xFFFD,
	0x37DC: 0xFFFD,
	0x37DD: 0xFFFD,
	0x37DE: 0xFFFD,
	0x37DF: 0xFFFD,
	0x37E0: 0xFFFD,
	0x37E1: 0xFFFD,
	0x37E2: 0xFFFD,
	0x37E3: 0xFFFD,
	0x37E4: 0xFFFD,
	0x37E5: 0xFFFD,
	0x37E6: 0xFFFD,
	0x37E7: 0xFFFD,
	0x37E8: 0xFFFD,
	0x37E9: 0xFFFD,
	0x37EA: 0xFFFD,
	0x37EB: 0xFFFD,
	0x37EC: 0xFFFD,
	0x37ED: 0xFFFD,
	0x37EE: 0xFFFD,
	0x37EF: 0xFFFD,
	0x37F0: 0xFFFD,
	0x37F1: 0xFFFD,
	0x37F2: 0xFFFD,
	0x37F3: 0xFFFD,
	0x37F4: 0xFFFD,
	0x37F5: 0xFFFD,
	0x37F6: 0xFFFD,
	0x37F7: 0xFFFD,
	0x37F8: 0xFFFD,
	0x37F9: 0xFFFD,
	0x37FA: 0xFFFD,
	0x37FB: 0xFFFD,
	0x37FC: 0xFFFD,
	0x37FD: 0xFFFD,
	0x37FE: 0xFFFD,
	0x37FF: 0xFFFD,
	0x3800: 0xFFFD,
	0x3801: 0xFFFD,
	0x3802: 0xFFFD,
	0x3803: 0xFFFD,
	0x3804: 0xFFFD,
	0x3805: 0xFFFD,
	0x3806: 0xFFFD,
	0x3807: 0xFFFD,
	0x3808: 0xFFFD,
	0x3809: 0xFFFD,
	0x380A: 0xFFFD,
	0x380B: 0xFFFD,
	0x380C: 0xFFFD,
	0x380D: 0xFFFD,
	0x380E: 0xFFFD,
	0x380F: 0xFFFD,
	0x3810: 0xFFFD,
	0x3811: 0xFFFD,
	0x3812: 0xFFFD,
	0x3813: 0xFFFD,
	0x3814: 0xFFFD,
	0x3815: 0xFFFD,
	0x3816: 0xFFFD,
	0x3817: 0xFFFD,
	0x3818: 0xFFFD,
	0x3819: 0xFFFD,
	0x381A: 0xFFFD,
	0x381B: 0xFFFD,
	0x381C: 0xFFFD,
	0x381D: 0xFFFD,
	0x381E: 0xFFFD,
	0x381F: 0xFFFD,
	0x3820: 0xFFFD,
	0x3821: 0xFFFD,
	0x3822: 0xFFFD,
	0x3823: 0xFFFD,
	0x3824: 0xFFFD,
	0x3825: 0xFFFD,
	0x3826: 0xFFFD,
	0x3827: 0xFFFD,
	0x3828: 0xFFFD,
	0x3829: 0xFFFD,
	0x382A: 0xFFFD,
	0x382B: 0xFFFD,
	0x382C: 0xFFFD,
	0x382D: 0xFFFD,
	0x382E: 0xFFFD,
	0x382F: 0xFFFD,
	0x3830: 0xFFFD,
	0x3831: 0xFFFD,
	0x3832: 0xFFFD,
	0x3833: 0xFFFD,
	0x3834: 0xFFFD,
	0x3835: 0xFFFD,
	0x3836: 0xFFFD,
	0x3837: 0xFFFD,
	0x3838: 0xFFFD,
	0x3839: 0xFFFD,
	0x383A: 0xFFFD,
	0x383B: 0xFFFD,
	0x383C: 0xFFFD,
	0x383D: 0xFFFD,
	0x383E: 0xFFFD,
	0x383F: 0xFFFD,
	0x3840: 0xFFFD,
	0x3841: 0xFFFD,
	0x3842: 0xFFFD,
	0x3843: 0xFFFD,
	0x3844: 0xFFFD,
	0x3845: 0xFFFD,
	0x3846: 0xFFFD,
	0x3847: 0xFFFD,
	0x3848: 0xFFFD,
	0x3849: 0xFFFD,
	0x384A: 0xFFFD,
	0x384B: 0xFFFD,
	0x384C: 0xFFFD,
	0x384D: 0xFFFD,
	0x384E: 0xFFFD,
	0x384F: 0xFFFD,
	0x3850: 0xFFFD,
	0x3851: 0xFFFD,
	0x3852: 0xFFFD,
	0x3853: 0xFFFD,
	0x3854: 0xFFFD,
	0x3855: 0xFFFD,
	0x3856: 0xFFFD,
	0x3857: 0xFFFD,
	0x3858: 0xFFFD,
	0x3859: 0xFFFD,
	0x385A: 0xFFFD,
	0x385B: 0xFFFD,
	0x385C: 0xFFFD,
	0x385D: 0xFFFD,
	0x385E: 0xFFFD,
	0x385F: 0xFFFD,
	0x3860: 0xFFFD,
	0x3861: 0xFFFD,
	0x3862: 0xFFFD,
	0x3863: 0xFFFD,
	0x3864: 0xFFFD,
	0x3865: 0xFFFD,
	0x3866: 0xFFFD,
	0x3867: 0xFFFD,
	0x3868: 0xFFFD,
	0x3869: 0xFFFD,
	0x386A: 0xFFFD,
	0x386B: 0xFFFD,
	0x386C: 0xFFFD,
	0x386D: 0xFFFD,
	0x386E: 0xFFFD,
	0x386F: 0xFFFD,
	0x3870: 0xFFFD,
	0x3871: 0xFFFD,
	0x3872: 0xFFFD,
	0x3873: 0xFFFD,
	0x3874: 0xFFFD,
	0x3875: 0xFFFD,
	0x3876: 0xFFFD,
	0x3877: 0xFFFD,
	0x3878: 0xFFFD,
	0x3879: 0xFFFD,
	0x387A: 0xFFFD,
	0x387B: 0xFFFD,
	0x387C: 0xFFFD,
	0x387D: 0xFFFD,
	0x387E: 0xFFFD,
	0x387F: 0xFFFD,
	0x3880: 0xFFFD,
	0x3881: 0xFFFD,
	0x3882: 0xFFFD,
	0x3883: 0xFFFD,
	0x3884: 0xFFFD,
	0x3885: 0xFFFD,
	0x3886: 0xFFFD,
	0x3887: 0xFFFD,
	0x3888: 0xFFFD,
	0x3889: 0xFFFD,
	0x388A: 0xFFFD,
	0x388B: 0xFFFD,
	0x388C: 0xFFFD,
	0x388D: 0xFFFD,
	0x388E: 0xFFFD,
	0x388F: 0xFFFD,
	0x3890: 0xFFFD,
	0x3891: 0xFFFD,
	0x3892: 0xFFFD,
	0x3893: 0xFFFD,
	0x3894: 0xFFFD,
	0x3895: 0xFFFD,
	0x3896: 0xFFFD,
	0x3897: 0xFFFD,
	0x3898: 0xFFFD,
	0x3899: 0xFFFD,
	0x389A: 0xFFFD,
	0x389B: 0xFFFD,
	0x389C: 0xFFFD,
	0x389D: 0xFFFD,
	0x389E: 0xFFFD,
	0x389F: 0xFFFD,
	0x38A0: 0xFFFD,
	0x38A1: 0xFFFD,
	0x38A2: 0xFFFD,
	0x38A3: 0xFFFD,
	0x38A4: 0xFFFD,
	0x38A5: 0xFFFD,
	0x38A6: 0xFFFD,
	0x38A7: 0xFFFD,
	0x38A8: 0xFFFD,
	0x38A9: 0xFFFD,
	0x38AA: 0xFFFD,
	0x38AB: 0xFFFD,
	0x38AC: 0xFFFD,
	0x38AD: 0xFFFD,
	0x38AE: 0xFFFD,
	0x38AF: 0xFFFD,
	0x38B0: 0xFFFD,
	0x38B1: 0xFFFD,
	0x38B2: 0xFFFD,
	0x38B3: 0xFFFD,
	0x38B4: 0xFFFD,
	0x38B5: 0xFFFD,
	0x38B6: 0xFFFD,
	0x38B7: 0xFFFD,
	0x38B8: 0xFFFD,
	0x38B9: 0xFFFD,
	0x38BA: 0xFFFD,
	0x38BB: 0xFFFD,
	0x38BC: 0xFFFD,
	0x38BD: 0xFFFD,
	0x38BE: 0xFFFD,
	0x38BF: 0xFFFD,
	0x38C0: 0xFFFD,
	0x38C1: 0xFFFD,
	0x38C2: 0xFFFD,
	0x38C3: 0xFFFD,
	0x38C4: 0xFFFD,
	0x38C5: 0xFFFD,
	0x38C6: 0xFFFD,
	0x38C7: 0xFFFD,
	0x38C8: 0xFFFD,
	0x38C9: 0xFFFD,
	0x38CA: 0xFFFD,
	0x38CB: 0xFFFD,
	0x38CC: 0xFFFD,
	0x38CD: 0xFFFD,
	0x38CE: 0xFFFD,
	0x38CF: 0xFFFD,
	0x38D0: 0xFFFD,
	0x38D1: 0xFFFD,
	0x38D2: 0xFFFD,
	0x38D3: 0xFFFD,
	0x38D4: 0xFFFD,
	0x38D5: 0xFFFD,
	0x38D6: 0xFFFD,
	0x38D7: 0xFFFD,
	0x38D8: 0xFFFD,
	0x38D9: 0xFFFD,
	0x38DA: 0xFFFD,
	0x38DB: 0xFFFD,
	0x38DC: 0xFFFD,
	0x38DD: 0xFFFD,
	0x38DE: 0xFFFD,
	0x38DF: 0xFFFD,
	0x38E0: 0xFFFD,
	0x38E1: 0xFFFD,
	0x38E2: 0xFFFD,
	0x38E3: 0xFFFD,
	0x38E4: 0xFFFD,
	0x38E5: 0xFFFD,
	0x38E6: 0xFFFD,
	0x38E7: 0xFFFD,
	0x38E8: 0xFFFD,
	0x38E9: 0xFFFD,
	0x38EA: 0xFFFD,
	0x38EB: 0xFFFD,
	0x38EC: 0xFFFD,
	0x38ED: 0xFFFD,
	0x38EE: 0xFFFD,
	0x38EF: 0xFFFD,
	0x38F0: 0xFFFD,
	0x38F1: 0xFFFD,
	0x38F2: 0xFFFD,
	0x38F3: 0xFFFD,
	0x38F4: 0xFFFD,
	0x38F5: 0xFFFD,
	0x38F6: 0xFFFD,
	0x38F7: 0xFFFD,
	0x38F8: 0xFFFD,
	0x38F9: 0xFFFD,
	0x38FA: 0xFFFD,
	0x38FB: 0xFFFD,
	0x38FC: 0xFFFD,
	0x38FD: 0xFFFD,
	0x38FE: 0xFFFD,
	0x38FF: 0xFFFD,
	0x3900: 0xFFFD,
	0x3901: 0xFFFD,
	0x3902: 0xFFFD,
	0x3903: 0xFFFD,
	0x3904: 0xFFFD,
	0x3905: 0xFFFD,
	0x3906: 0xFFFD,
	0x3907: 0xFFFD,
	0x3908: 0xFFFD,
	0x3909: 0xFFFD,
	0x390A: 0xFFFD,
	0x390B: 0xFFFD,
	0x390C: 0xFFFD,
	0x390D: 0xFFFD,
	0x390E: 0xFFFD,
	0x390F: 0xFFFD,
	0x3910: 0xFFFD,
	0x3911: 0xFFFD,
	0x3912: 0xFFFD,
	0x3913: 0xFFFD,
	0x3914: 0xFFFD,
	0x3915: 0xFFFD,
	0x3916: 0xFFFD,
	0x3917: 0xFFFD,
	0x3918: 0xFFFD,
	0x3919: 0xFFFD,
	0x391A: 0xFFFD,
	0x391B: 0xFFFD,
	0x391C: 0xFFFD,
	0x391D: 0xFFFD,
	0x391E: 0xFFFD,
	0x391F: 0xFFFD,
	0x3920: 0xFFFD,
	0x3921: 0xFFFD,
	0x3922: 0xFFFD,
	0x3923: 0xFFFD,
	0x3924: 0xFFFD,
	0x3925: 0xFFFD,
	0x3926: 0xFFFD,
	0x3927: 0xFFFD,
	0x3928: 0xFFFD,
	0x3929: 0xFFFD,
	0x392A: 0xFFFD,
	0x392B: 0xFFFD,
	0x392C: 0xFFFD,
	0x392D: 0xFFFD,
	0x392E: 0xFFFD,
	0x392F: 0xFFFD,
	0x3930: 0xFFFD,
	0x3931: 0xFFFD,
	0x3932: 0xFFFD,
	0x3933: 0xFFFD,
	0x3934: 0xFFFD,
	0x3935: 0xFFFD,
	0x3936: 0xFFFD,
	0x3937: 0xFFFD,
	0x3938: 0xFFFD,
	0x3939: 0xFFFD,
	0x393A: 0xFFFD,
	0x393B: 0xFFFD,
	0x393C: 0xFFFD,
	0x393D: 0xFFFD,
	0x393E: 0xFFFD,
	0x393F: 0xFFFD,
	0x3940: 0xFFFD,
	0x3941: 0xFFFD,
	0x3942: 0xFFFD,
	0x3943: 0xFFFD,
	0x3944: 0xFFFD,
	0x3945: 0xFFFD,
	0x3946: 0xFFFD,
	0x3947: 0xFFFD,
	0x3948: 0xFFFD,
	0x3949: 0xFFFD,
	0x394A: 0xFFFD,
	0x394B: 0xFFFD,
	0x394C: 0xFFFD,
	0x394D: 0xFFFD,
	0x394E: 0xFFFD,
	0x394F: 0xFFFD,
	0x3950: 0xFFFD,
	0x3951: 0xFFFD,
	0x3952: 0xFFFD,
	0x3953: 0xFFFD,
	0x3954: 0xFFFD,
	0x3955: 0xFFFD,
	0x3956: 0xFFFD,
	0x3957: 0xFFFD,
	0x3958: 0xFFFD,
	0x3959: 0xFFFD,
	0x395A: 0xFFFD,
	0x395B: 0xFFFD,
	0x395C: 0xFFFD,
	0x395D: 0xFFFD,
	0x395E: 0xFFFD,
	0x395F: 0xFFFD,
	0x3960: 0xFFFD,
	0x3961: 0xFFFD,
	0x3962: 0xFFFD,
	0x3963: 0xFFFD,
	0x3964: 0xFFFD,
	0x3965: 0xFFFD,
	0x3966: 0xFFFD,
	0x3967: 0xFFFD,
	0x3968: 0xFFFD,
	0x3969: 0xFFFD,
	0x396A: 0xFFFD,
	0x396B: 0xFFFD,
	0x396C: 0xFFFD,
	0x396D: 0xFFFD,
	0x396E: 0xFFFD,
	0x396F: 0xFFFD,
	0x3970: 0xFFFD,
	0x3971: 0xFFFD,
	0x3972: 0xFFFD,
	0x3973: 0xFFFD,
	0x3974: 0xFFFD,
	0x3975: 0xFFFD,
	0x3976: 0xFFFD,
	0x3977: 0xFFFD,
	0x3978: 0xFFFD,
	0x3979: 0xFFFD,
	0x397A: 0xFFFD,
	0x397B: 0xFFFD,
	0x397C: 0xFFFD,
	0x397D: 0xFFFD,
	0x397E: 0xFFFD,
	0x397F: 0xFFFD,
	0x3980: 0xFFFD,
	0x3981: 0xFFFD,
	0x3982: 0xFFFD,
	0x3983: 0xFFFD,
	0x3984: 0xFFFD,
	0x3985: 0xFFFD,
	0x3986: 0xFFFD,
	0x3987: 0xFFFD,
	0x3988: 0xFFFD,
	0x3989: 0xFFFD,
	0x398A: 0xFFFD,
	0x398B: 0xFFFD,
	0x398C: 0xFFFD,
	0x398D: 0xFFFD,
	0x398E: 0xFFFD,
	0x398F: 0xFFFD,
	0x3990: 0xFFFD,
	0x3991: 0xFFFD,
	0x3992: 0xFFFD,
	0x3993: 0xFFFD,
	0x3994: 0xFFFD,
	0x3995: 0xFFFD,
	0x3996: 0xFFFD,
	0x3997: 0xFFFD,
	0x3998: 0xFFFD,
	0x3999: 0xFFFD,
	0x399A: 0xFFFD,
	0x399B: 0xFFFD,
	0x399C: 0xFFFD,
	0x399D: 0xFFFD,
	0x399E: 0xFFFD,
	0x399F: 0xFFFD,
	0x39A0: 0xFFFD,
	0x39A1: 0xFFFD,
	0x39A2: 0xFFFD,
	0x39A3: 0xFFFD,
	0x39A4: 0xFFFD,
	0x39A5: 0xFFFD,
	0x39A6: 0xFFFD,
	0x39A7: 0xFFFD,
	0x39A8: 0xFFFD,
	0x39A9: 0xFFFD,
	0x39AA: 0xFFFD,
	0x39AB: 0xFFFD,
	0x39AC: 0xFFFD,
	0x39AD: 0xFFFD,
	0x39AE: 0xFFFD,
	0x39AF: 0xFFFD,
	0x39B0: 0xFFFD,
	0x39B1: 0xFFFD,
	0x39B2: 0xFFFD,
	0x39B3: 0xFFFD,
	0x39B4: 0xFFFD,
	0x39B5: 0xFFFD,
	0x39B6: 0xFFFD,
	0x39B7: 0xFFFD,
	0x39B8: 0x955E,
	0x39B9: 0xFFFD,
	0x39BA: 0xFFFD,
	0x39BB: 0xFFFD,
	0x39BC: 0xFFFD,
	0x39BD: 0xFFFD,
	0x39BE: 0xFFFD,
	0x39BF: 0xFFFD,
	0x39C0: 0xFFFD,
	0x39C1: 0xFFFD,
	0x39C2: 0xFFFD,
	0x39C3: 0xFFFD,
	0x39C4: 0xFFFD,
	0x39C5: 0xFFFD,
	0x39C6: 0xFFFD,
	0x39C7: 0xFFFD,
	0x39C8: 0xFFFD,
	0x39C9: 0xFFFD,
	0x39CA: 0xFFFD,
	0x39CB: 0xFFFD,
	0x39CC: 0xFFFD,
	0x39CD: 0xFFFD,
	0x39CE: 0xFFFD,
	0x39CF: 0xFFFD,
	0x39D0: 0xFFFD,
	0x39D1: 0xFFFD,
	0x39D2: 0xFFFD,
	0x39D3: 0xFFFD,
	0x39D4: 0xFFFD,
	0x39D5: 0xFFFD,
	0x39D6: 0xFFFD,
	0x39D7: 0xFFFD,
	0x39D8: 0xFFFD,
	0x39D9: 0xFFFD,
	0x39DA: 0xFFFD,
	0x39DB: 0xFFFD,
	0x39DC: 0xFFFD,
	0x39DD: 0xFFFD,
	0x39DE: 0xFFFD,
	0x39DF: 0xFFFD,
	0x39E0: 0xFFFD,
	0x39E1: 0xFFFD,
	0x39E2: 0xFFFD,
	0x39E3: 0xFFFD,
	0x39E4: 0xFFFD,
	0x39E5: 0xFFFD,
	0x39E6: 0xFFFD,
	0x39E7: 0xFFFD,
	0x39E8: 0xFFFD,
	0x39E9: 0xFFFD,
	0x39EA: 0xFFFD,
	0x39EB: 0xFFFD,
	0x39EC: 0xFFFD,
	0x39ED: 0xFFFD,
	0x39EE: 0xFFFD,
	0x39EF: 0xFFFD,
	0x39F0: 0xFFFD,
	0x39F1: 0xFFFD,
	0x39F2: 0xFFFD,
	0x39F3: 0xFFFD,
	0x39F4: 0xFFFD,
	0x39F5: 0xFFFD,
	0x39F6: 0xFFFD,
	0x39F7: 0xFFFD,
	0x39F8: 0xFFFD,
	0x39F9: 0xFFFD,
	0x39FA: 0xFFFD,
	0x39FB: 0xFFFD,
	0x39FC: 0xFFFD,
	0x39FD: 0xFFFD,
	0x39FE: 0xFFFD,
	0x39FF: 0xFFFD,
	0x3A00: 0xFFFD,
	0x3A01: 0xFFFD,
	0x3A02: 0xFFFD,
	0x3A03: 0xFFFD,
	0x3A04: 0xFFFD,
	0x3A05: 0xFFFD,
	0x3A06: 0xFFFD,
	0x3A07: 0xFFFD,
	0x3A08: 0xFFFD,
	0x3A09: 0xFFFD,
	0x3A0A: 0xFFFD,
	0x3A0B: 0xFFFD,
	0x3A0C: 0xFFFD,
	0x3A0D: 0xFFFD,
	0x3A0E: 0xFFFD,
	0x3A0F: 0xFFFD,
	0x3A10: 0xFFFD,
	0x3A11: 0xFFFD,
	0x3A12: 0xFFFD,
	0x3A13: 0xFFFD,
	0x3A14: 0xFFFD,
	0x3A15: 0xFFFD,
	0x3A16: 0xFFFD,
	0x3A17: 0xFFFD,
	0x3A18: 0xFFFD,
	0x3A19: 0xFFFD,
	0x3A1A: 0xFFFD,
	0x3A1B: 0xFFFD,
	0x3A1C: 0xFFFD,
	0x3A1D: 0xFFFD,
	0x3A1E: 0xFFFD,
	0x3A1F: 0xFFFD,
	0x3A20: 0xFFFD,
	0x3A21: 0xFFFD,
	0x3A22: 0xFFFD,
	0x3A23: 0xFFFD,
	0x3A24: 0xFFFD,
	0x3A25: 0xFFFD,
	0x3A26: 0xFFFD,
	0x3A27: 0xFFFD,
	0x3A28: 0xFFFD,
	0x3A29: 0xFFFD,
	0x3A2A: 0x95DE,
	0x3A2B: 0xFFFD,
	0x3A2C: 0xFFFD,
	0x3A2D: 0xFFFD,
	0x3A2E: 0xFFFD,
	0x3A2F: 0xFFFD,
	0x3A30: 0xFFFD,
	0x3A31: 0xFFFD,
	0x3A32: 0xFFFD,
	0x3A33: 0xFFFD,
	0x3A34: 0xFFFD,
	0x3A35: 0xFFFD,
	0x3A36: 0xFFFD,
	0x3A37: 0xFFFD,
	0x3A38: 0xFFFD,
	0x3A39: 0xFFFD,
	0x3A3A: 0xFFFD,
	0x3A3B: 0xFFFD,
	0x3A3C: 0xFFFD,
	0x3A3D: 0xFFFD,
	0x3A3E: 0xFFFD,
	0x3A3F: 0xFFFD,
	0x3A40: 0xFFFD,
	0x3A41: 0xFFFD,
	0x3A42: 0xFFFD,
	0x3A43: 0xFFFD,
	0x3A44: 0xFFFD,
	0x3A45: 0xFFFD,
	0x3A46: 0xFFFD,
	0x3A47: 0xFFFD,
	0x3A48: 0xFFFD,
	0x3A49: 0xFFFD,
	0x3A4A: 0xFFFD,
	0x3A4B: 0xFFFD,
	0x3A4C: 0xFFFD,
	0x3A4D: 0xFFFD,
	0x3A4E: 0xFFFD,
	0x3A4F: 0xFFFD,
	0x3A50: 0xFFFD,
	0x3A51: 0xFFFD,
	0x3A52: 0xFFFD,
	0x3A53: 0xFFFD,
	0x3A54: 0xFFFD,
	0x3A55: 0xFFFD,
	0x3A56: 0xFFFD,
	0x3A57: 0x95C7,
	0x3A58: 0xFFFD,
	0x3A59: 0xFFFD,
	0x3A5A: 0xFFFD,
	0x3A5B: 0xFFFD,
	0x3A5C: 0xFC61,
	0x3A5D: 0xFFFD,
	0x3A5E: 0xFFFD,
	0x3A5F: 0xFFFD,
	0x3A60: 0xFFFD,
	0x3A61: 0xFFFD,
	0x3A62: 0xFFFD,
	0x3A63: 0xFFFD,
	0x3A64: 0xFFFD,
	0x3A65: 0xFFFD,
	0x3A66: 0xFFFD,
	0x3A67: 0xFFFD,
	0x3A68: 0xFFFD,
	0x3A69: 0xFFFD,
	0x3A6A: 0xFFFD,
	0x3A6B: 0xFFFD,
	0x3A6C: 0xFFFD,
	0x3A6D: 0xFFFD,
	0x3A6E: 0xFFFD,
	0x3A6F: 0xFFFD,
	0x3A70: 0xFFFD,
	0x3A71: 0xFFFD,
	0x3A72: 0xFFFD,
	0x3A73: 0xFFFD,
	0x3A74: 0xFFFD,
	0x3A75: 0xFFFD,
	0x3A76: 0xFFFD,
	0x3A77: 0xFFFD,
	0x3A78: 0xFFFD,
	0x3A79: 0xFFFD,
	0x3A7A: 0xFFFD,
	0x3A7B: 0xFFFD,
	0x3A7C: 0xFFFD,
	0x3A7D: 0xFFFD,
	0x3A7E: 0xFFFD,
	0x3A7F: 0xFFFD,
	0x3A80: 0xFFFD,
	0x3A81: 0xFFFD,
	0x3A82: 0xFFFD,
	0x3A83: 0xFFFD,
	0x3A84: 0xFFFD,
	0x3A85: 0xFFFD,
	0x3A86: 0xFFFD,
	0x3A87: 0xFFFD,
	0x3A88: 0xFFFD,
	0x3A89: 0xFFFD,
	0x3A8A: 0xFFFD,
	0x3A8B: 0xFFFD,
	0x3A8C: 0xFFFD,
	0x3A8D: 0xFFFD,
	0x3A8E: 0xFFFD,
	0x3A8F: 0xFFFD,
	0x3A90: 0xFFFD,
	0x3A91: 0xFFFD,
	0x3A92: 0xFFFD,
	0x3A93: 0xFFFD,
	0x3A94: 0xFFFD,
	0x3A95: 0xFFFD,
	0x3A96: 0xFFFD,
	0x3A97: 0xFFFD,
	0x3A98: 0xFFFD,
	0x3A99: 0xFFFD,
	0x3A9A: 0xFFFD,
	0x3A9B: 0xFFFD,
	0x3A9C: 0xFFFD,
	0x3A9D: 0xFFFD,
	0x3A9E: 0xFFFD,
	0x3A9F: 0xFFFD,
	0x3AA0: 0xFFFD,
	0x3AA1: 0xFFFD,
	0x3AA2: 0xFFFD,
	0x3AA3: 0xFFFD,
	0x3AA4: 0xFFFD,
	0x3AA5: 0xFFFD,
	0x3AA6: 0xFFFD,
	0x3AA7: 0xFFFD,
	0x3AA8: 0xFFFD,
	0x3AA9: 0xFFFD,
	0x3AAA: 0xFFFD,
	0x3AAB: 0xFFFD,
	0x3AAC: 0xFFFD,
	0x3AAD: 0xFFFD,
	0x3AAE: 0xFFFD,
	0x3AAF: 0xFFFD,
	0x3AB0: 0xFFFD,
	0x3AB1: 0xFFFD,
	0x3AB2: 0xFFFD,
	0x3AB3: 0xFFFD,
	0x3AB4: 0xFFFD,
	0x3AB5: 0xFFFD,
	0x3AB6: 0xFFFD,
	0x3AB7: 0xFFFD,
	0x3AB8: 0xFFFD,
	0x3AB9: 0xFFFD,
	0x3ABA: 0xFFFD,
	0x3ABB: 0xFFFD,
	0x3ABC: 0xFFFD,
	0x3ABD: 0xFFFD,
	0x3ABE: 0xFFFD,
	0x3ABF: 0xFFFD,
	0x3AC0: 0xFFFD,
	0x3AC1: 0xFFFD,
	0x3AC2: 0xFFFD,
	0x3AC3: 0xFFFD,
	0x3AC4: 0xFFFD,
	0x3AC5: 0xFFFD,
	0x3AC6: 0xFFFD,
	0x3AC7: 0xFFFD,
	0x3AC8: 0xFFFD,
	0x3AC9: 0xFFFD,
	0x3ACA: 0xFFFD,
	0x3ACB: 0xFFFD,
	0x3ACC: 0xFFFD,
	0x3ACD: 0xFFFD,
	0x3ACE: 0xFFFD,
	0x3ACF: 0xFFFD,
	0x3AD0: 0xFFFD,
	0x3AD1: 0xFFFD,
	0x3AD2: 0xFFFD,
	0x3AD3: 0xFFFD,
	0x3AD4: 0xFFFD,
	0x3AD5: 0xFFFD,
	0x3AD6: 0xFFFD,
	0x3AD7: 0xFFFD,
	0x3AD8: 0xFFFD,
	0x3AD9: 0xFFFD,
	0x3ADA: 0xFFFD,
	0x3ADB: 0xFFFD,
	0x3ADC: 0xFFFD,
	0x3ADD: 0xFFFD,
	0x3ADE: 0xFFFD,
	0x3ADF: 0xFFFD,
	0x3AE0: 0xFFFD,
	0x3AE1: 0xFFFD,
	0x3AE2: 0xFFFD,
	0x3AE3: 0xFFFD,
	0x3AE4: 0xFFFD,
	0x3AE5: 0xFFFD,
	0x3AE6: 0xFFFD,
	0x3AE7: 0xFFFD,
	0x3AE8: 0xFFFD,
	0x3AE9: 0xFFFD,
	0x3AEA: 0xFFFD,
	0x3AEB: 0xFFFD,
	0x3AEC: 0xFFFD,
	0x3AED: 0xFFFD,
	0x3AEE: 0xFFFD,
	0x3AEF: 0xFFFD,
	0x3AF0: 0xFFFD,
	0x3AF1: 0xFFFD,
	0x3AF2: 0xFFFD,
	0x3AF3: 0xFFFD,
	0x3AF4: 0xFFFD,
	0x3AF5: 0xFFFD,
	0x3AF6: 0xFFFD,
	0x3AF7: 0xFFFD,
	0x3AF8: 0xFFFD,
	0x3AF9: 0xFFFD,
	0x3AFA: 0xFFFD,
	0x3AFB: 0xFFFD,
	0x3AFC: 0xFFFD,
	0x3AFD: 0xFFFD,
	0x3AFE: 0xFFFD,
	0x3AFF: 0xFFFD,
	0x3B00: 0xFFFD,
	0x3B01: 0xFFFD,
	0x3B02: 0xFFFD,
	0x3B03: 0xFFFD,
	0x3B04: 0xFFFD,
	0x3B05: 0xFFFD,
	0x3B06: 0xFFFD,
	0x3B07: 0xFFFD,
	0x3B08: 0xFFFD,
	0x3B09: 0xFFFD,
	0x3B0A: 0xFFFD,
	0x3B0B: 0xFFFD,
	0x3B0C: 0xFFFD,
	0x3B0D: 0xFFFD,
	0x3B0E: 0xFFFD,
	0x3B0F: 0xFFFD,
	0x3B10: 0xFFFD,
	0x3B11: 0xFFFD,
	0x3B12: 0xFFFD,
	0x3B13: 0xFFFD,
	0x3B14: 0xFFFD,
	0x3B15: 0xFFFD,
	0x3B16: 0xFFFD,
	0x3B17: 0xFFFD,
	0x3B18: 0xFFFD,
	0x3B19: 0xFFFD,
	0x3B1A: 0xFFFD,
	0x3B1B: 0xFFFD,
	0x3B1C: 0xFFFD,
	0x3B1D: 0xFFFD,
	0x3B1E: 0xFFFD,
	0x3B1F: 0xFFFD,
	0x3B20: 0xFFFD,
	0x3B21: 0xFFFD,
	0x3B22: 0xFFFD,
	0x3B23: 0xFFFD,
	0x3B24: 0xFFFD,
	0x3B25: 0xFFFD,
	0x3B26: 0xFFFD,
	0x3B27: 0xFFFD,
	0x3B28: 0xFFFD,
	0x3B29: 0xFFFD,
	0x3B2A: 0xFFFD,
	0x3B2B: 0xFFFD,
	0x3B2C: 0xFFFD,
	0x3B2D: 0xFFFD,
	0x3B2E: 0xFFFD,
	0x3B2F: 0xFFFD,
	0x3B30: 0xFFFD,
	0x3B31: 0xFFFD,
	0x3B32: 0xFFFD,
	0x3B33: 0xFFFD,
	0x3B34: 0xFFFD,
	0x3B35: 0xFFFD,
	0x3B36: 0xFFFD,
	0x3B37: 0xFFFD,
	0x3B38: 0xFFFD,
	0x3B39: 0xFFFD,
	0x3B3A: 0xFFFD,
	0x3B3B: 0xFFFD,
	0x3B3C: 0xFFFD,
	0x3B3D: 0xFFFD,
	0x3B3E: 0xFFFD,
	0x3B3F: 0xFFFD,
	0x3B40: 0xFFFD,
	0x3B41: 0xFFFD,
	0x3B42: 0xFFFD,
	0x3B43: 0xFFFD,
	0x3B44: 0xFFFD,
	0x3B45: 0xFFFD,
	0x3B46: 0xFFFD,
	0x3B47: 0xFFFD,
	0x3B48: 0xFFFD,
	0x3B49: 0xFFFD,
	0x3B4A: 0xFFFD,
	0x3B4B: 0xFFFD,
	0x3B4C: 0xFFFD,
	0x3B4D: 0xFFFD,
	0x3B4E: 0xFFFD,
	0x3B4F: 0xFFFD,
	0x3B50: 0xFFFD,
	0x3B51: 0xFFFD,
	0x3B52: 0xFFFD,
	0x3B53: 0xFFFD,
	0x3B54: 0xFFFD,
	0x3B55: 0xFFFD,
	0x3B56: 0xFFFD,
	0x3B57: 0xFFFD,
	0x3B58: 0xFFFD,
	0x3B59: 0xFFFD,
	0x3B5A: 0xFFFD,
	0x3B5B: 0xFFFD,
	0x3B5C: 0xFFFD,
	0x3B5D: 0xFFFD,
	0x3B5E: 0xFFFD,
	0x3B5F: 0xFFFD,
	0x3B60: 0xFFFD,
	0x3B61: 0xFFFD,
	0x3B62: 0xFFFD,
	0x3B63: 0xFFFD,
	0x3B64: 0xFFFD,
	0x3B65: 0xFFFD,
	0x3B66: 0xFFFD,
	0x3B67: 0xFFFD,
	0x3B68: 0xFFFD,
	0x3B69: 0xFFFD,
	0x3B6A: 0xFFFD,
	0x3B6B: 0xFFFD,
	0x3B6C: 0xFFFD,
	0x3B6D: 0xFFFD,
	0x3B6E: 0xFFFD,
	0x3B6F: 0xFFFD,
	0x3B70: 0xFFFD,
	0x3B71: 0xFFFD,
	0x3B72: 0xFFFD,
	0x3B73: 0xFFFD,
	0x3B74: 0xFFFD,
	0x3B75: 0xFFFD,
	0x3B76: 0xFFFD,
	0x3B77: 0xFFFD,
	0x3B78: 0xFFFD,
	0x3B79: 0xFFFD,
	0x3B7A: 0xFFFD,
	0x3B7B: 0xFFFD,
	0x3B7C: 0xFFFD,
	0x3B7D: 0xFFFD,
	0x3B7E: 0xFFFD,
	0x3B7F: 0xFFFD,
	0x3B80: 0xFFFD,
	0x3B81: 0xFFFD,
	0x3B82: 0xFFFD,
	0x3B83: 0xFFFD,
	0x3B84: 0xFFFD,
	0x3B85: 0xFFFD,
	0x3B86: 0xFFFD,
	0x3B87: 0xFFFD,
	0x3B88: 0xFFFD,
	0x3B89: 0xFFFD,
	0x3B8A: 0xFFFD,
	0x3B8B: 0xFFFD,
	0x3B8C: 0xFFFD,
	0x3B8D: 0xFFFD,
	0x3B8E: 0xFFFD,
	0x3B8F: 0xFFFD,
	0x3B90: 0xFFFD,
	0x3B91: 0xFFFD,
	0x3B92: 0xFFFD,
	0x3B93: 0xFFFD,
	0x3B94: 0xFFFD,
	0x3B95: 0xFFFD,
	0x3B96: 0xFFFD,
	0x3B97: 0xFFFD,
	0x3B98: 0xFFFD,
	0x3B99: 0xFFFD,
	0x3B9A: 0xFFFD,
	0x3B9B: 0xFFFD,
	0x3B9C: 0xFFFD,
	0x3B9D: 0xFFFD,
	0x3B9E: 0xFFFD,
	0x3B9F: 0xFFFD,
	0x3BA0: 0xFFFD,
	0x3BA1: 0xFFFD,
	0x3BA2: 0xFFFD,
	0x3BA3: 0xFFFD,
	0x3BA4: 0xFFFD,
	0x3BA5: 0xFFFD,
	0x3BA6: 0xFFFD,
	0x3BA7: 0xFFFD,
	0x3BA8: 0xFFFD,
	0x3BA9: 0xFFFD,
	0x3BAA: 0xFFFD,
	0x3BAB: 0xFFFD,
	0x3BAC: 0xFFFD,
	0x3BAD: 0xFFFD,
	0x3BAE: 0xFFFD,
	0x3BAF: 0xFFFD,
	0x3BB0: 0xFFFD,
	0x3BB1: 0xFFFD,
	0x3BB2: 0xFFFD,
	0x3BB3: 0xFFFD,
	0x3BB4: 0xFFFD,
	0x3BB5: 0xFFFD,
	0x3BB6: 0xFFFD,
	0x3BB7: 0xFFFD,
	0x3BB8: 0xFFFD,
	0x3BB9: 0xFFFD,
	0x3BBA: 0xFFFD,
	0x3BBB: 0xFFFD,
	0x3BBC: 0xFFFD,
	0x3BBD: 0xFFFD,
	0x3BBE: 0xFFFD,
	0x3BBF: 0xFFFD,
	0x3BC0: 0xFFFD,
	0x3BC1: 0xFFFD,
	0x3BC2: 0xFFFD,
	0x3BC3: 0xFFFD,
	0x3BC4: 0xFFFD,
	0x3BC5: 0xFFFD,
	0x3BC6: 0xFFFD,
	0x3BC7: 0xFFFD,
	0x3BC8: 0xFFFD,
	0x3BC9: 0xFFFD,
	0x3BCA: 0xFFFD,
	0x3BCB: 0xFFFD,
	0x3BCC: 0xFFFD,
	0x3BCD: 0xFFFD,
	0x3BCE: 0xFFFD,
	0x3BCF: 0xFFFD,
	0x3BD0: 0xFFFD,
	0x3BD1: 0xFFFD,
	0x3BD2: 0xFFFD,
	0x3BD3: 0xFFFD,
	0x3BD4: 0xFFFD,
	0x3BD5: 0xFFFD,
	0x3BD6: 0xFFFD,
	0x3BD7: 0xFFFD,
	0x3BD8: 0xFFFD,
	0x3BD9: 0xFFFD,
	0x3BDA: 0xFFFD,
	0x3BDB: 0xFFFD,
	0x3BDC: 0xFFFD,
	0x3BDD: 0xFFFD,
	0x3BDE: 0xFFFD,
	0x3BDF: 0xFFFD,
	0x3BE0: 0xFFFD,
	0x3BE1: 0xFFFD,
	0x3BE2: 0xFFFD,
	0x3BE3: 0xFFFD,
	0x3BE4: 0xFFFD,
	0x3BE5: 0xFFFD,
	0x3BE6: 0xFFFD,
	0x3BE7: 0xFFFD,
	0x3BE8: 0xFFFD,
	0x3BE9: 0xFFFD,
	0x3BEA: 0xFFFD,
	0x3BEB: 0xFFFD,
	0x3BEC: 0xFFFD,
	0x3BED: 0x95C9,
	0x3BEE: 0xFFFD,
	0x3BEF: 0xFFFD,
	0x3BF0: 0xFFFD,
	0x3BF1: 0xFFFD,
	0x3BF2: 0xFFFD,
	0x3BF3: 0xFFFD,
	0x3BF4: 0xFFFD,
	0x3BF5: 0xFFFD,
	0x3BF6: 0xFFFD,
	0x3BF7: 0xFFFD,
	0x3BF8: 0xFFFD,
	0x3BF9: 0xFFFD,
	0x3BFA: 0xFFFD,
	0x3BFB: 0xFFFD,
	0x3BFC: 0xFFFD,
	0x3BFD: 0xFFFD,
	0x3BFE: 0xFFFD,
	0x3BFF: 0xFFFD,
	0x3C00: 0xFFFD,
	0x3C01: 0xFFFD,
	0x3C02: 0xFFFD,
	0x3C03: 0xFFFD,
	0x3C04: 0xFFFD,
	0x3C05: 0xFFFD,
	0x3C06: 0xFFFD,
	0x3C07: 0xFFFD,
	0x3C08: 0xFFFD,
	0x3C09: 0xFFFD,
	0x3C0A: 0xFFFD,
	0x3C0B: 0xFFFD,
	0x3C0C: 0xFFFD,
	0x3C0D: 0xFFFD,
	0x3C0E: 0xFFFD,
	0x3C0F: 0xFFFD,
	0x3C10: 0xFFFD,
	0x3C11: 0xFFFD,
	0x3C12: 0xFFFD,
	0x3C13: 0xFFFD,
	0x3C14: 0xFFFD,
	0x3C15: 0xFFFD,
	0x3C16: 0xFFFD,
	0x3C17: 0xFFFD,
	0x3C18: 0xFFFD,
	0x3C19: 0xFFFD,
	0x3C1A: 0xFFFD,
	0x3C1B: 0xFFFD,
	0x3C1C: 0xFFFD,
	0x3C1D: 0xFFFD,
	0x3C1E: 0xFFFD,
	0x3C1F: 0xFFFD,
	0x3C20: 0xFFFD,
	0x3C21: 0xFFFD,
	0x3C22: 0xFFFD,
	0x3C23: 0xFFFD,
	0x3C24: 0xFFFD,
	0x3C25: 0xFFFD,
	0x3C26: 0xFFFD,
	0x3C27: 0xFFFD,
	0x3C28: 0xFFFD,
	0x3C29: 0xFFFD,
	0x3C2A: 0xFFFD,
	0x3C2B: 0xFFFD,
	0x3C2C: 0xFFFD,
	0x3C2D: 0xFFFD,
	0x3C2E: 0xFFFD,
	0x3C2F: 0xFFFD,
	0x3C30: 0xFFFD,
	0x3C31: 0xFFFD,
	0x3C32: 0xFFFD,
	0x3C33: 0xFFFD,
	0x3C34: 0xFFFD,
	0x3C35: 0xFFFD,
	0x3C36: 0xFFFD,
	0x3C37: 0xFFFD,
	0x3C38: 0xFFFD,
	0x3C39: 0xFFFD,
	0x3C3A: 0xFFFD,
	0x3C3B: 0xFFFD,
	0x3C3C: 0xFFFD,
	0x3C3D: 0xFFFD,
	0x3C3E: 0xFFFD,
	0x3C3F: 0xFFFD,
	0x3C40: 0xFFFD,
	0x3C41: 0xFFFD,
	0x3C42: 0xFFFD,
	0x3C43: 0xFFFD,
	0x3C44: 0xFFFD,
	0x3C45: 0xFFFD,
	0x3C46: 0xFFFD,
	0x3C47: 0xFFFD,
	0x3C48: 0xFFFD,
	0x3C49: 0xFFFD,
	0x3C4A: 0xFFFD,
	0x3C4B: 0xFFFD,
	0x3C4C: 0xFFFD,
	0x3C4D: 0xFFFD,
	0x3C4E: 0xFFFD,
	0x3C4F: 0xFFFD,
	0x3C50: 0xFFFD,
	0x3C51: 0xFFFD,
	0x3C52: 0xFFFD,
	0x3C53: 0xFFFD,
	0x3C54: 0xFFFD,
	0x3C55: 0xFFFD,
	0x3C56: 0xFFFD,
	0x3C57: 0xFFFD,
	0x3C58: 0xFFFD,
	0x3C59: 0xFFFD,
	0x3C5A: 0xFFFD,
	0x3C5B: 0xFFFD,
	0x3C5C: 0xFFFD,
	0x3C5D: 0xFFFD,
	0x3C5E: 0xFFFD,
	0x3C5F: 0xFFFD,
	0x3C60: 0xFFFD,
	0x3C61: 0xFFFD,
	0x3C62: 0xFFFD,
	0x3C63: 0xFFFD,
	0x3C64: 0xFFFD,
	0x3C65: 0xFFFD,
	0x3C66: 0xFFFD,
	0x3C67: 0xFFFD,
	0x3C68: 0xFFFD,
	0x3C69: 0xFFFD,
	0x3C6A: 0xFFFD,
	0x3C6B: 0xFFFD,
	0x3C6C: 0xFFFD,
	0x3C6D: 0xFFFD,
	0x3C6E: 0xFFFD,
	0x3C6F: 0xFFFD,
	0x3C70: 0xFFFD,
	0x3C71: 0xFFFD,
	0x3C72: 0xFFFD,
	0x3C73: 0xFFFD,
	0x3C74: 0xFFFD,
	0x3C75: 0xFFFD,
	0x3C76: 0xFFFD,
	0x3C77: 0xFFFD,
	0x3C78: 0xFFFD,
	0x3C79: 0xFFFD,
	0x3C7A: 0xFFFD,
	0x3C7B: 0xFFFD,
	0x3C7C: 0xFFFD,
	0x3C7D: 0xFFFD,
	0x3C7E: 0xFFFD,
	0x3C7F: 0xFFFD,
	0x3C80: 0xFFFD,
	0x3C81: 0xFFFD,
	0x3C82: 0xFFFD,
	0x3C83: 0xFFFD,
	0x3C84: 0xFFFD,
	0x3C85: 0xFFFD,
	0x3C86: 0xFFFD,
	0x3C87: 0xFFFD,
	0x3C88: 0xFFFD,
	0x3C89: 0xFFFD,
	0x3C8A: 0xFFFD,
	0x3C8B: 0xFFFD,
	0x3C8C: 0xFFFD,
	0x3C8D: 0xFFFD,
	0x3C8E: 0xFFFD,
	0x3C8F: 0xFFFD,
	0x3C90: 0xFFFD,
	0x3C91: 0xFFFD,
	0x3C92: 0xFFFD,
	0x3C93: 0xFFFD,
	0x3C94: 0xFFFD,
	0x3C95: 0xFFFD,
	0x3C96: 0xFFFD,
	0x3C97: 0xFFFD,
	0x3C98: 0xFFFD,
	0x3C99: 0xFFFD,
	0x3C9A: 0xFFFD,
	0x3C9B: 0xFFFD,
	0x3C9C: 0xFFFD,
	0x3C9D: 0xFFFD,
	0x3C9E: 0xFFFD,
	0x3C9F: 0xFFFD,
	0x3CA0: 0xFFFD,
	0x3CA1: 0xFFFD,
	0x3CA2: 0xFFFD,
	0x3CA3: 0xFFFD,
	0x3CA4: 0xFFFD,
	0x3CA5: 0xFFFD,
	0x3CA6: 0xFFFD,
	0x3CA7: 0xFFFD,
	0x3CA8: 0xFFFD,
	0x3CA9: 0xFFFD,
	0x3CAA: 0xFFFD,
	0x3CAB: 0xFFFD,
	0x3CAC: 0xFFFD,
	0x3CAD: 0xFFFD,
	0x3CAE: 0xFFFD,
	0x3CAF: 0xFFFD,
	0x3CB0: 0xFFFD,
	0x3CB1: 0xFFFD,
	0x3CB2: 0xFFFD,
	0x3CB3: 0xFFFD,
	0x3CB4: 0xFFFD,
	0x3CB5: 0xFFFD,
	0x3CB6: 0xFFFD,
	0x3CB7: 0xFFFD,
	0x3CB8: 0xFFFD,
	0x3CB9: 0xFFFD,
	0x3CBA: 0xFFFD,
	0x3CBB: 0xFFFD,
	0x3CBC: 0xFFFD,
	0x3CBD: 0xFFFD,
	0x3CBE: 0xFFFD,
	0x3CBF: 0xFFFD,
	0x3CC0: 0xFFFD,
	0x3CC1: 0xFFFD,
	0x3CC2: 0xFFFD,
	0x3CC3: 0xFFFD,
	0x3CC4: 0xFFFD,
	0x3CC5: 0xFFFD,
	0x3CC6: 0xFFFD,
	0x3CC7: 0xFFFD,
	0x3CC8: 0xFFFD,
	0x3CC9: 0xFFFD,
	0x3CCA: 0xFFFD,
	0x3CCB: 0xFFFD,
	0x3CCC: 0xFFFD,
	0x3CCD: 0xFFFD,
	0x3CCE: 0xFFFD,
	0x3CCF: 0xFFFD,
	0x3CD0: 0xFFFD,
	0x3CD1: 0xFC7C,
	0x3CD2: 0xFFFD,
	0x3CD3: 0xFFFD,
	0x3CD4: 0xFFFD,
	0x3CD5: 0xFFFD,
	0x3CD6: 0xFFFD,
	0x3CD7: 0xFFFD,
	0x3CD8: 0xFFFD,
	0x3CD9: 0xFFFD,
	0x3CDA: 0xFFFD,
	0x3CDB: 0xFFFD,
	0x3CDC: 0xFFFD,
	0x3CDD: 0xFFFD,
	0x3CDE: 0xFFFD,
	0x3CDF: 0xFFFD,
	0x3CE0: 0xFFFD,
	0x3CE1: 0xFFFD,
	0x3CE2: 0xFFFD,
	0x3CE3: 0xFFFD,
	0x3CE4: 0xFFFD,
	0x3CE5: 0xFFFD,
	0x3CE6: 0xFFFD,
	0x3CE7: 0xFFFD,
	0x3CE8: 0xFFFD,
	0x3CE9: 0xFFFD,
	0x3CEA: 0xFFFD,
	0x3CEB: 0xFFFD,
	0x3CEC: 0xFFFD,
	0x3CED: 0xFFFD,
	0x3CEE: 0xFFFD,
	0x3CEF: 0xFFFD,
	0x3CF0: 0xFFFD,
	0x3CF1: 0xFFFD,
	0x3CF2: 0xFFFD,
	0x3CF3: 0xFFFD,
	0x3CF4: 0xFFFD,
	0x3CF5: 0xFFFD,
	0x3CF6: 0xFFFD,
	0x3CF7: 0xFFFD,
	0x3CF8: 0xFFFD,
	0x3CF9: 0xFFFD,
	0x3CFA: 0xFFFD,
	0x3CFB: 0xFFFD,
	0x3CFC: 0xFFFD,
	0x3CFD: 0xFFFD,
	0x3CFE: 0xFFFD,
	0x3CFF: 0xFFFD,
	0x3D00: 0xFFFD,
	0x3D01: 0xFFFD,
	0x3D02: 0xFFFD,
	0x3D03: 0xFFFD,
	0x3D04: 0xFFFD,
	0x3D05: 0xFFFD,
	0x3D06: 0xFFFD,
	0x3D07: 0xFFFD,
	0x3D08: 0xFFFD,
	0x3D09: 0xFFFD,
	0x3D0A: 0xFFFD,
	0x3D0B: 0xFFFD,
	0x3D0C: 0xFFFD,
	0x3D0D: 0xFFFD,
	0x3D0E: 0xFFFD,
	0x3D0F: 0xFFFD,
	0x3D10: 0xFFFD,
	0x3D11: 0xFFFD,
	0x3D12: 0xFFFD,
	0x3D13: 0xFFFD,
	0x3D14: 0xFFFD,
	0x3D15: 0xFFFD,
	0x3D16: 0xFFFD,
	0x3D17: 0xFFFD,
	0x3D18: 0xFFFD,
	0x3D19: 0xFFFD,
	0x3D1A: 0xFFFD,
	0x3D1B: 0xFFFD,
	0x3D1C: 0xFFFD,
	0x3D1D: 0xFFFD,
	0x3D1E: 0xFFFD,
	0x3D1F: 0xFFFD,
	0x3D20: 0xFFFD,
	0x3D21: 0xFFFD,
	0x3D22: 0xFFFD,
	0x3D23: 0xFFFD,
	0x3D24: 0xFFFD,
	0x3D25: 0xFFFD,
	0x3D26: 0xFFFD,
	0x3D27: 0xFFFD,
	0x3D28: 0xFFFD,
	0x3D29: 0xFFFD,
	0x3D2A: 0xFFFD,
	0x3D2B: 0xFFFD,
	0x3D2C: 0xFFFD,
	0x3D2D: 0xFFFD,
	0x3D2E: 0xFFFD,
	0x3D2F: 0xFFFD,
	0x3D30: 0xFFFD,
	0x3D31: 0xFFFD,
	0x3D32: 0xFFFD,
	0x3D33: 0xFFFD,
	0x3D34: 0xFFFD,
	0x3D35: 0xFFFD,
	0x3D36: 0xFFFD,
	0x3D37: 0xFFFD,
	0x3D38: 0xFFFD,
	0x3D39: 0xFFFD,
	0x3D3A: 0xFFFD,
	0x3D3B: 0xFFFD,
	0x3D3C: 0xFFFD,
	0x3D3D: 0xFFFD,
	0x3D3E: 0xFFFD,
	0x3D3F: 0xFFFD,
	0x3D40: 0xFFFD,
	0x3D41: 0xFFFD,
	0x3D42: 0xFFFD,
	0x3D43: 0xFFFD,
	0x3D44: 0xFFFD,
	0x3D45: 0xFFFD,
	0x3D46: 0xFFFD,
	0x3D47: 0xFFFD,
	0x3D48: 0xFFFD,
	0x3D49: 0xFFFD,
	0x3D4A: 0xFFFD,
	0x3D4B: 0xFFFD,
	0x3D4C: 0xFFFD,
	0x3D4D: 0xFFFD,
	0x3D4E: 0xFFFD,
	0x3D4F: 0xFFFD,
	0x3D50: 0xFFFD,
	0x3D51: 0xFFFD,
	0x3D52: 0xFFFD,
	0x3D53: 0xFFFD,
	0x3D54: 0xFFFD,
	0x3D55: 0xFFFD,
	0x3D56: 0xFFFD,
	0x3D57: 0xFFFD,
	0x3D58: 0xFFFD,
	0x3D59: 0xFFFD,
	0x3D5A: 0xFFFD,
	0x3D5B: 0xFFFD,
	0x3D5C: 0xFFFD,
	0x3D5D: 0xFFFD,
	0x3D5E: 0xFFFD,
	0x3D5F: 0xFFFD,
	0x3D60: 0xFFFD,
	0x3D61: 0xFFFD,
	0x3D62: 0xFFFD,
	0x3D63: 0xFFFD,
	0x3D64: 0xFFFD,
	0x3D65: 0xFFFD,
	0x3D66: 0xFFFD,
	0x3D67: 0xFFFD,
	0x3D68: 0xFFFD,
	0x3D69: 0xFFFD,
	0x3D6A: 0xFFFD,
	0x3D6B: 0xFFFD,
	0x3D6C: 0xFFFD,
	0x3D6D: 0xFFFD,
	0x3D6E: 0xFFFD,
	0x3D6F: 0xFFFD,
	0x3D70: 0xFFFD,
	0x3D71: 0xFFFD,
	0x3D72: 0xFFFD,
	0x3D73: 0xFFFD,
	0x3D74: 0xFFFD,
	0x3D75: 0xFFFD,
	0x3D76: 0xFFFD,
	0x3D77: 0xFFFD,
	0x3D78: 0xFFFD,
	0x3D79: 0xFFFD,
	0x3D7A: 0xFFFD,
	0x3D7B: 0xFFFD,
	0x3D7C: 0xFFFD,
	0x3D7D: 0xFFFD,
	0x3D7E: 0xFFFD,
	0x3D7F: 0xFFFD,
	0x3D80: 0xFFFD,
	0x3D81: 0xFFFD,
	0x3D82: 0xFFFD,
	0x3D83: 0xFFFD,
	0x3D84: 0xFFFD,
	0x3D85: 0xFFFD,
	0x3D86: 0xFFFD,
	0x3D87: 0xFFFD,
	0x3D88: 0xFFFD,
	0x3D89: 0xFFFD,
	0x3D8A: 0xFFFD,
	0x3D8B: 0xFFFD,
	0x3D8C: 0xFFFD,
	0x3D8D: 0xFFFD,
	0x3D8E: 0xFFFD,
	0x3D8F: 0xFFFD,
	0x3D90: 0xFFFD,
	0x3D91: 0xFFFD,
	0x3D92: 0xFFFD,
	0x3D93: 0xFFFD,
	0x3D94: 0xFFFD,
	0x3D95: 0xFFFD,
	0x3D96: 0xFFFD,
	0x3D97: 0xFFFD,
	0x3D98: 0xFFFD,
	0x3D99: 0xFFFD,
	0x3D9A: 0xFFFD,
	0x3D9B: 0xFFFD,
	0x3D9C: 0xFFFD,
	0x3D9D: 0xFFFD,
	0x3D9E: 0xFFFD,
	0x3D9F: 0xFFFD,
	0x3DA0: 0xFFFD,
	0x3DA1: 0xFFFD,
	0x3DA2: 0xFFFD,
	0x3DA3: 0xFFFD,
	0x3DA4: 0xFFFD,
	0x3DA5: 0xFFFD,
	0x3DA6: 0xFFFD,
	0x3DA7: 0xFFFD,
	0x3DA8: 0xFFFD,
	0x3DA9: 0xFFFD,
	0x3DAA: 0xFFFD,
	0x3DAB: 0xFFFD,
	0x3DAC: 0xFFFD,
	0x3DAD: 0xFFFD,
	0x3DAE: 0xFFFD,
	0x3DAF: 0xFFFD,
	0x3DB0: 0xFFFD,
	0x3DB1: 0xFFFD,
	0x3DB2: 0xFFFD,
	0x3DB3: 0xFFFD,
	0x3DB4: 0xFFFD,
	0x3DB5: 0xFFFD,
	0x3DB6: 0xFFFD,
	0x3DB7: 0xFFFD,
	0x3DB8: 0xFFFD,
	0x3DB9: 0xFFFD,
	0x3DBA: 0xFFFD,
	0x3DBB: 0xFFFD,
	0x3DBC: 0xFFFD,
	0x3DBD: 0xFFFD,
	0x3DBE: 0xFFFD,
	0x3DBF: 0xFFFD,
	0x3DC0: 0xFFFD,
	0x3DC1: 0xFFFD,
	0x3DC2: 0xFFFD,
	0x3DC3: 0xFFFD,
	0x3DC4: 0xFFFD,
	0x3DC5: 0xFFFD,
	0x3DC6: 0xFFFD,
	0x3DC7: 0xFFFD,
	0x3DC8: 0xFFFD,
	0x3DC9: 0xFFFD,
	0x3DCA: 0xFFFD,
	0x3DCB: 0xFFFD,
	0x3DCC: 0xFCA8,
	0x3DCD: 0xFFFD,
	0x3DCE: 0xFFFD,
	0x3DCF: 0xFFFD,
	0x3DD0: 0xFFFD,
	0x3DD1: 0xFFFD,
	0x3DD2: 0xFFFD,
	0x3DD3: 0xFFFD,
	0x3DD4: 0xFFFD,
	0x3DD5: 0xFFFD,
	0x3DD6: 0xFFFD,
	0x3DD7: 0xFFFD,
	0x3DD8: 0xFFFD,
	0x3DD9: 0xFFFD,
	0x3DDA: 0xFFFD,
	0x3DDB: 0xFFFD,
	0x3DDC: 0xFFFD,
	0x3DDD: 0xFFFD,
	0x3DDE: 0xFFFD,
	0x3DDF: 0xFFFD,
	0x3DE0: 0xFFFD,
	0x3DE1: 0xFFFD,
	0x3DE2: 0xFFFD,
	0x3DE3: 0xFFFD,
	0x3DE4: 0xFFFD,
	0x3DE5: 0xFFFD,
	0x3DE6: 0xFFFD,
	0x3DE7: 0xFFFD,
	0x3DE8: 0xFFFD,
	0x3DE9: 0xFFFD,
	0x3DEA: 0xFFFD,
	0x3DEB: 0xFFFD,
	0x3DEC: 0xFFFD,
	0x3DED: 0xFFFD,
	0x3DEE: 0xFFFD,
	0x3DEF: 0xFFFD,
	0x3DF0: 0xFFFD,
	0x3DF1: 0xFFFD,
	0x3DF2: 0xFFFD,
	0x3DF3: 0xFFFD,
	0x3DF4: 0xFFFD,
	0x3DF5: 0xFFFD,
	0x3DF6: 0xFFFD,
	0x3DF7: 0xFFFD,
	0x3DF8: 0xFFFD,
	0x3DF9: 0xFFFD,
	0x3DFA: 0xFFFD,
	0x3DFB: 0xFFFD,
	0x3DFC: 0xFFFD,
	0x3DFD: 0xFFFD,
	0x3DFE: 0xFFFD,
	0x3DFF: 0xFFFD,
	0x3E00: 0xFFFD,
	0x3E01: 0xFFFD,
	0x3E02: 0xFFFD,
	0x3E03: 0xFFFD,
	0x3E04: 0xFFFD,
	0x3E05: 0xFFFD,
	0x3E06: 0xFFFD,
	0x3E07: 0xFFFD,
	0x3E08: 0xFFFD,
	0x3E09: 0xFFFD,
	0x3E0A: 0xFFFD,
	0x3E0B: 0xFFFD,
	0x3E0C: 0xFFFD,
	0x3E0D: 0xFFFD,
	0x3E0E: 0xFFFD,
	0x3E0F: 0xFFFD,
	0x3E10: 0xFFFD,
	0x3E11: 0xFFFD,
	0x3E12: 0xFFFD,
	0x3E13: 0xFFFD,
	0x3E14: 0xFFFD,
	0x3E15: 0xFFFD,
	0x3E16: 0xFFFD,
	0x3E17: 0xFFFD,
	0x3E18: 0xFFFD,
	0x3E19: 0xFFFD,
	0x3E1A: 0xFFFD,
	0x3E1B: 0xFFFD,
	0x3E1C: 0xFFFD,
	0x3E1D: 0xFFFD,
	0x3E1E: 0xFFFD,
	0x3E1F: 0xFFFD,
	0x3E20: 0xFFFD,
	0x3E21: 0xFFFD,
	0x3E22: 0xFFFD,
	0x3E23: 0xFFFD,
	0x3E24: 0xFFFD,
	0x3E25: 0xFFFD,
	0x3E26: 0xFFFD,
	0x3E27: 0xFFFD,
	0x3E28: 0xFFFD,
	0x3E29: 0xFFFD,
	0x3E2A: 0xFFFD,
	0x3E2B: 0xFFFD,
	0x3E2C: 0xFFFD,
	0x3E2D: 0xFFFD,
	0x3E2E: 0xFFFD,
	0x3E2F: 0xFFFD,
	0x3E30: 0xFFFD,
	0x3E31: 0xFFFD,
	0x3E32: 0xFFFD,
	0x3E33: 0xFFFD,
	0x3E34: 0xFFFD,
	0x3E35: 0xFFFD,
	0x3E36: 0xFFFD,
	0x3E37: 0xFFFD,
	0x3E38: 0xFFFD,
	0x3E39: 0xFFFD,
	0x3E3A: 0xFFFD,
	0x3E3B: 0xFFFD,
	0x3E3C: 0xFFFD,
	0x3E3D: 0xFFFD,
	0x3E3E: 0xFFFD,
	0x3E3F: 0xFFFD,
	0x3E40: 0xFFFD,
	0x3E41: 0xFFFD,
	0x3E42: 0xFFFD,
	0x3E43: 0xFFFD,
	0x3E44: 0xFFFD,
	0x3E45: 0xFFFD,
	0x3E46: 0xFFFD,
	0x3E47: 0xFFFD,
	0x3E48: 0xFFFD,
	0x3E49: 0xFFFD,
	0x3E4A: 0xFFFD,
	0x3E4B: 0xFFFD,
	0x3E4C: 0xFFFD,
	0x3E4D: 0xFFFD,
	0x3E4E: 0xFFFD,
	0x3E4F: 0xFFFD,
	0x3E50: 0xFFFD,
	0x3E51: 0xFFFD,
	0x3E52: 0xFFFD,
	0x3E53: 0xFFFD,
	0x3E54: 0xFFFD,
	0x3E55: 0xFFFD,
	0x3E56: 0xFFFD,
	0x3E57: 0xFFFD,
	0x3E58: 0xFFFD,
	0x3E59: 0xFFFD,
	0x3E5A: 0xFFFD,
	0x3E5B: 0xFFFD,
	0x3E5C: 0xFFFD,
	0x3E5D: 0xFFFD,
	0x3E5E: 0xFFFD,
	0x3E5F: 0xFFFD,
	0x3E60: 0xFFFD,
	0x3E61: 0xFFFD,
	0x3E62: 0xFFFD,
	0x3E63: 0xFFFD,
	0x3E64: 0xFFFD,
	0x3E65: 0xFFFD,
	0x3E66: 0xFFFD,
	0x3E67: 0xFFFD,
	0x3E68: 0xFFFD,
	0x3E69: 0xFFFD,
	0x3E6A: 0xFFFD,
	0x3E6B: 0xFFFD,
	0x3E6C: 0xFFFD,
	0x3E6D: 0xFFFD,
	0x3E6E: 0xFFFD,
	0x3E6F: 0xFFFD,
	0x3E70: 0xFFFD,
	0x3E71: 0xFFFD,
	0x3E72: 0xFFFD,
	0x3E73: 0xFFFD,
	0x3E74: 0xFFFD,
	0x3E75: 0xFFFD,
	0x3E76: 0xFFFD,
	0x3E77: 0xFFFD,
	0x3E78: 0xFFFD,
	0x3E79: 0xFFFD,
	0x3E7A: 0xFFFD,
	0x3E7B: 0xFFFD,
	0x3E7C: 0xFFFD,
	0x3E7D: 0xFFFD,
	0x3E7E: 0xFFFD,
	0x3E7F: 0xFFFD,
	0x3E80: 0xFFFD,
	0x3E81: 0xFFFD,
	0x3E82: 0xFFFD,
	0x3E83: 0xFFFD,
	0x3E84: 0xFFFD,
	0x3E85: 0xFFFD,
	0x3E86: 0xFFFD,
	0x3E87: 0xFFFD,
	0x3E88: 0xFFFD,
	0x3E89: 0xFFFD,
	0x3E8A: 0xFFFD,
	0x3E8B: 0xFFFD,
	0x3E8C: 0xFFFD,
	0x3E8D: 0xFFFD,
	0x3E8E: 0xFFFD,
	0x3E8F: 0xFFFD,
	0x3E90: 0xFFFD,
	0x3E91: 0xFFFD,
	0x3E92: 0xFFFD,
	0x3E93: 0xFFFD,
	0x3E94: 0xFFFD,
	0x3E95: 0xFFFD,
	0x3E96: 0xFFFD,
	0x3E97: 0xFFFD,
	0x3E98: 0xFFFD,
	0x3E99: 0xFFFD,
	0x3E9A: 0xFFFD,
	0x3E9B: 0xFFFD,
	0x3E9C: 0xFFFD,
	0x3E9D: 0xFFFD,
	0x3E9E: 0xFFFD,
	0x3E9F: 0xFFFD,
	0x3EA0: 0xFFFD,
	0x3EA1: 0xFFFD,
	0x3EA2: 0xFFFD,
	0x3EA3: 0xFFFD,
	0x3EA4: 0xFFFD,
	0x3EA5: 0xFFFD,
	0x3EA6: 0xFFFD,
	0x3EA7: 0xFFFD,
	0x3EA8: 0xFFFD,
	0x3EA9: 0xFFFD,
	0x3EAA: 0xFFFD,
	0x3EAB: 0xFFFD,
	0x3EAC: 0xFFFD,
	0x3EAD: 0xFFFD,
	0x3EAE: 0xFFFD,
	0x3EAF: 0xFFFD,
	0x3EB0: 0xFFFD,
	0x3EB1: 0xFFFD,
	0x3EB2: 0xFFFD,
	0x3EB3: 0xFFFD,
	0x3EB4: 0xFFFD,
	0x3EB5: 0xFFFD,
	0x3EB6: 0xFFFD,
	0x3EB7: 0xFFFD,
	0x3EB8: 0xFFFD,
	0x3EB9: 0xFFFD,
	0x3EBA: 0xFFFD,
	0x3EBB: 0xFFFD,
	0x3EBC: 0xFFFD,
	0x3EBD: 0xFFFD,
	0x3EBE: 0xFFFD,
	0x3EBF: 0xFFFD,
	0x3EC0: 0xFFFD,
	0x3EC1: 0xFFFD,
	0x3EC2: 0xFFFD,
	0x3EC3: 0xFFFD,
	0x3EC4: 0xFFFD,
	0x3EC5: 0xFFFD,
	0x3EC6: 0xFFFD,
	0x3EC7: 0xFFFD,
	0x3EC8: 0xFFFD,
	0x3EC9: 0xFFFD,
	0x3ECA: 0xFFFD,
	0x3ECB: 0xFFFD,
	0x3ECC: 0xFFFD,
	0x3ECD: 0xFFFD,
	0x3ECE: 0xFFFD,
	0x3ECF: 0xFFFD,
	0x3ED0: 0xFFFD,
	0x3ED1: 0xFFFD,
	0x3ED2: 0xFFFD,
	0x3ED3: 0xFFFD,
	0x3ED4: 0xFFFD,
	0x3ED5: 0xFFFD,
	0x3ED6: 0xFFFD,
	0x3ED7: 0xFFFD,
	0x3ED8: 0xFFFD,
	0x3ED9: 0xFE71,
	0x3EDA: 0xFFFD,
	0x3EDB: 0xFFFD,
	0x3EDC: 0xFFFD,
	0x3EDD: 0xFFFD,
	0x3EDE: 0xFFFD,
	0x3EDF: 0xFFFD,
	0x3EE0: 0xFFFD,
	0x3EE1: 0xFFFD,
	0x3EE2: 0xFFFD,
	0x3EE3: 0xFFFD,
	0x3EE4: 0xFFFD,
	0x3EE5: 0xFFFD,
	0x3EE6: 0xFFFD,
	0x3EE7: 0xFFFD,
	0x3EE8: 0xFFFD,
	0x3EE9: 0xFFFD,
	0x3EEA: 0xFFFD,
	0x3EEB: 0xFFFD,
	0x3EEC: 0xFFFD,
	0x3EED: 0xFFFD,
	0x3EEE: 0xFFFD,
	0x3EEF: 0xFFFD,
	0x3EF0: 0xFFFD,
	0x3EF1: 0xFFFD,
	0x3EF2: 0xFFFD,
	0x3EF3: 0xFFFD,
	0x3EF4: 0xFFFD,
	0x3EF5: 0xFFFD,
	0x3EF6: 0xFFFD,
	0x3EF7: 0xFFFD,
	0x3EF8: 0xFFFD,
	0x3EF9: 0xFFFD,
	0x3EFA: 0xFFFD,
	0x3EFB: 0xFFFD,
	0x3EFC: 0xFFFD,
	0x3EFD: 0xFFFD,
	0x3EFE: 0xFFFD,
	0x3EFF: 0xFFFD,
	0x3F00: 0xFFFD,
	0x3F01: 0xFFFD,
	0x3F02: 0xFFFD,
	0x3F03: 0xFFFD,
	0x3F04: 0xFFFD,
	0x3F05: 0xFFFD,
	0x3F06: 0xFFFD,
	0x3F07: 0xFFFD,
	0x3F08: 0xFFFD,
	0x3F09: 0xFFFD,
	0x3F0A: 0xFFFD,
	0x3F0B: 0xFFFD,
	0x3F0C: 0xFFFD,
	0x3F0D: 0xFFFD,
	0x3F0E: 0xFFFD,
	0x3F0F: 0xFFFD,
	0x3F10: 0xFFFD,
	0x3F11: 0xFFFD,
	0x3F12: 0xFFFD,
	0x3F13: 0xFFFD,
	0x3F14: 0xFFFD,
	0x3F15: 0xFFFD,
	0x3F16: 0xFFFD,
	0x3F17: 0xFFFD,
	0x3F18: 0xFFFD,
	0x3F19: 0xFFFD,
	0x3F1A: 0xFFFD,
	0x3F1B: 0xFFFD,
	0x3F1C: 0xFFFD,
	0x3F1D: 0xFFFD,
	0x3F1E: 0xFFFD,
	0x3F1F: 0xFFFD,
	0x3F20: 0xFFFD,
	0x3F21: 0xFFFD,
	0x3F22: 0xFFFD,
	0x3F23: 0xFFFD,
	0x3F24: 0xFFFD,
	0x3F25: 0xFFFD,
	0x3F26: 0xFFFD,
	0x3F27: 0xFFFD,
	0x3F28: 0xFFFD,
	0x3F29: 0xFFFD,
	0x3F2A: 0xFFFD,
	0x3F2B: 0xFFFD,
	0x3F2C: 0xFFFD,
	0x3F2D: 0xFFFD,
	0x3F2E: 0xFFFD,
	0x3F2F: 0xFFFD,
	0x3F30: 0xFFFD,
	0x3F31: 0xFFFD,
	0x3F32: 0xFFFD,
	0x3F33: 0xFFFD,
	0x3F34: 0xFFFD,
	0x3F35: 0xFFFD,
	0x3F36: 0xFFFD,
	0x3F37: 0xFFFD,
	0x3F38: 0xFFFD,
	0x3F39: 0xFFFD,
	0x3F3A: 0xFFFD,
	0x3F3B: 0xFFFD,
	0x3F3C: 0xFFFD,
	0x3F3D: 0xFFFD,
	0x3F3E: 0xFFFD,
	0x3F3F: 0xFFFD,
	0x3F40: 0xFFFD,
	0x3F41: 0xFFFD,
	0x3F42: 0xFFFD,
	0x3F43: 0xFFFD,
	0x3F44: 0xFFFD,
	0x3F45: 0xFFFD,
	0x3F46: 0xFFFD,
	0x3F47: 0xFFFD,
	0x3F48: 0xFFFD,
	0x3F49: 0xFFFD,
	0x3F4A: 0xFFFD,
	0x3F4B: 0xFFFD,
	0x3F4C: 0xFFFD,
	0x3F4D: 0xFFFD,
	0x3F4E: 0xFFFD,
	0x3F4F: 0xFFFD,
	0x3F50: 0xFFFD,
	0x3F51: 0xFFFD,
	0x3F52: 0xFFFD,
	0x3F53: 0xFFFD,
	0x3F54: 0xFFFD,
	0x3F55: 0xFFFD,
	0x3F56: 0xFFFD,
	0x3F57: 0xFFFD,
	0x3F58: 0xFFFD,
	0x3F59: 0xFFFD,
	0x3F5A: 0xFFFD,
	0x3F5B: 0xFFFD,
	0x3F5C: 0xFFFD,
	0x3F5D: 0xFFFD,
	0x3F5E: 0xFFFD,
	0x3F5F: 0xFFFD,
	0x3F60: 0xFFFD,
	0x3F61: 0xFFFD,
	0x3F62: 0xFFFD,
	0x3F63: 0xFFFD,
	0x3F64: 0xFFFD,
	0x3F65: 0xFFFD,
	0x3F66: 0xFFFD,
	0x3F67: 0xFFFD,
	0x3F68: 0xFFFD,
	0x3F69: 0xFFFD,
	0x3F6A: 0xFFFD,
	0x3F6B: 0xFFFD,
	0x3F6C: 0xFFFD,
	0x3F6D: 0xFFFD,
	0x3F6E: 0xFFFD,
	0x3F6F: 0xFFFD,
	0x3F70: 0xFFFD,
	0x3F71: 0xFFFD,
	0x3F72: 0xFFFD,
	0x3F73: 0xFFFD,
	0x3F74: 0xFFFD,
	0x3F75: 0xFFFD,
	0x3F76: 0xFFFD,
	0x3F77: 0xFFFD,
	0x3F78: 0xFFFD,
	0x3F79: 0xFFFD,
	0x3F7A: 0xFFFD,
	0x3F7B: 0xFFFD,
	0x3F7C: 0xFFFD,
	0x3F7D: 0xFFFD,
	0x3F7E: 0xFFFD,
	0x3F7F: 0xFFFD,
	0x3F80: 0xFFFD,
	0x3F81: 0xFFFD,
	0x3F82: 0xFFFD,
	0x3F83: 0xFFFD,
	0x3F84: 0xFFFD,
	0x3F85: 0xFFFD,
	0x3F86: 0xFFFD,
	0x3F87: 0xFFFD,
	0x3F88: 0xFFFD,
	0x3F89: 0xFFFD,
	0x3F8A: 0xFFFD,
	0x3F8B: 0xFFFD,
	0x3F8C: 0xFFFD,
	0x3F8D: 0xFFFD,
	0x3F8E: 0xFFFD,
	0x3F8F: 0xFFFD,
	0x3F90: 0xFFFD,
	0x3F91: 0xFFFD,
	0x3F92: 0xFFFD,
	0x3F93: 0xFFFD,
	0x3F94: 0xFFFD,
	0x3F95: 0xFFFD,
	0x3F96: 0xFFFD,
	0x3F97: 0xFFFD,
	0x3F98: 0xFFFD,
	0x3F99: 0xFFFD,
	0x3F9A: 0xFFFD,
	0x3F9B: 0xFFFD,
	0x3F9C: 0xFFFD,
	0x3F9D: 0xFFFD,
	0x3F9E: 0xFFFD,
	0x3F9F: 0xFFFD,
	0x3FA0: 0xFFFD,
	0x3FA1: 0xFFFD,
	0x3FA2: 0xFFFD,
	0x3FA3: 0xFFFD,
	0x3FA4: 0xFFFD,
	0x3FA5: 0xFFFD,
	0x3FA6: 0xFFFD,
	0x3FA7: 0xFFFD,
	0x3FA8: 0xFFFD,
	0x3FA9: 0xFFFD,
	0x3FAA: 0xFFFD,
	0x3FAB: 0xFFFD,
	0x3FAC: 0xFFFD,
	0x3FAD: 0xFFFD,
	0x3FAE: 0xFFFD,
	0x3FAF: 0xFFFD,
	0x3FB0: 0xFFFD,
	0x3FB1: 0xFFFD,
	0x3FB2: 0xFFFD,
	0x3FB3: 0xFFFD,
	0x3FB4: 0xFFFD,
	0x3FB5: 0xFFFD,
	0x3FB6: 0xFFFD,
	0x3FB7: 0xFFFD,
	0x3FB8: 0xFFFD,
	0x3FB9: 0xFFFD,
	0x3FBA: 0xFFFD,
	0x3FBB: 0xFFFD,
	0x3FBC: 0xFFFD,
	0x3FBD: 0xFFFD,
	0x3FBE: 0xFFFD,
	0x3FBF: 0xFFFD,
	0x3FC0: 0xFFFD,
	0x3FC1: 0xFFFD,
	0x3FC2: 0xFFFD,
	0x3FC3: 0xFFFD,
	0x3FC4: 0xFFFD,
	0x3FC5: 0xFFFD,
	0x3FC6: 0xFFFD,
	0x3FC7: 0xFFFD,
	0x3FC8: 0xFFFD,
	0x3FC9: 0xFFFD,
	0x3FCA: 0xFFFD,
	0x3FCB: 0xFFFD,
	0x3FCC: 0xFFFD,
	0x3FCD: 0xFFFD,
	0x3FCE: 0xFFFD,
	0x3FCF: 0xFFFD,
	0x3FD0: 0xFFFD,
	0x3FD1: 0xFFFD,
	0x3FD2: 0xFFFD,
	0x3FD3: 0xFFFD,
	0x3FD4: 0xFFFD,
	0x3FD5: 0xFFFD,
	0x3FD6: 0xFFFD,
	0x3FD7: 0xFFFD,
	0x3FD8: 0xFFFD,
	0x3FD9: 0xFFFD,
	0x3FDA: 0xFFFD,
	0x3FDB: 0xFFFD,
	0x3FDC: 0xFFFD,
	0x3FDD: 0xFFFD,
	0x3FDE: 0xFFFD,
	0x3FDF: 0xFFFD,
	0x3FE0: 0xFFFD,
	0x3FE1: 0xFFFD,
	0x3FE2: 0xFFFD,
	0x3FE3: 0xFFFD,
	0x3FE4: 0xFFFD,
	0x3FE5: 0xFFFD,
	0x3FE6: 0xFFFD,
	0x3FE7: 0xFFFD,
	0x3FE8: 0xFFFD,
	0x3FE9: 0xFFFD,
	0x3FEA: 0xFFFD,
	0x3FEB: 0xFFFD,
	0x3FEC: 0xFFFD,
	0x3FED: 0xFFFD,
	0x3FEE: 0xFFFD,
	0x3FEF: 0xFFFD,
	0x3FF0: 0xFFFD,
	0x3FF1: 0xFFFD,
	0x3FF2: 0xFFFD,
	0x3FF3: 0xFFFD,
	0x3FF4: 0xFFFD,
	0x3FF5: 0xFFFD,
	0x3FF6: 0xFFFD,
	0x3FF7: 0xFFFD,
	0x3FF8: 0xFFFD,
	0x3FF9: 0xFFFD,
	0x3FFA: 0xFFFD,
	0x3FFB: 0xFFFD,
	0x3FFC: 0xFFFD,
	0x3FFD: 0xFFFD,
	0x3FFE: 0xFFFD,
	0x3FFF: 0xFFFD,
	0x4000: 0xFFFD,
	0x4001: 0xFFFD,
	0x4002: 0xFFFD,
	0x4003: 0xFFFD,
	0x4004: 0xFFFD,
	0x4005: 0xFFFD,
	0x4006: 0xFFFD,
	0x4007: 0xFFFD,
	0x4008: 0xFFFD,
	0x4009: 0xFFFD,
	0x400A: 0xFFFD,
	0x400B: 0xFFFD,
	0x400C: 0xFFFD,
	0x400D: 0xFFFD,
	0x400E: 0xFFFD,
	0x400F: 0xFFFD,
	0x4010: 0xFFFD,
	0x4011: 0xFFFD,
	0x4012: 0xFFFD,
	0x4013: 0xFFFD,
	0x4014: 0xFFFD,
	0x4015: 0xFFFD,
	0x4016: 0xFFFD,
	0x4017: 0xFFFD,
	0x4018: 0xFFFD,
	0x4019: 0xFFFD,
	0x401A: 0xFFFD,
	0x401B: 0xFFFD,
	0x401C: 0xFFFD,
	0x401D: 0xFFFD,
	0x401E: 0xFFFD,
	0x401F: 0xFFFD,
	0x4020: 0xFFFD,
	0x4021: 0xFFFD,
	0x4022: 0xFFFD,
	0x4023: 0xFFFD,
	0x4024: 0xFFFD,
	0x4025: 0xFFFD,
	0x4026: 0xFFFD,
	0x4027: 0xFFFD,
	0x4028: 0xFFFD,
	0x4029: 0xFFFD,
	0x402A: 0xFFFD,
	0x402B: 0xFFFD,
	0x402C: 0xFFFD,
	0x402D: 0xFFFD,
	0x402E: 0xFFFD,
	0x402F: 0xFFFD,
	0x4030: 0xFFFD,
	0x4031: 0xFFFD,
	0x4032: 0xFFFD,
	0x4033: 0xFFFD,
	0x4034: 0xFFFD,
	0x4035: 0xFFFD,
	0x4036: 0xFFFD,
	0x4037: 0xFFFD,
	0x4038: 0xFFFD,
	0x4039: 0xFFFD,
	0x403A: 0xFFFD,
	0x403B: 0xFFFD,
	0x403C: 0xFFFD,
	0x403D: 0xFFFD,
	0x403E: 0xFFFD,
	0x403F: 0xFFFD,
	0x4040: 0xFFFD,
	0x4041: 0xFFFD,
	0x4042: 0xFFFD,
	0x4043: 0xFFFD,
	0x4044: 0xFFFD,
	0x4045: 0xFFFD,
	0x4046: 0xFFFD,
	0x4047: 0xFFFD,
	0x4048: 0xFFFD,
	0x4049: 0xFFFD,
	0x404A: 0xFFFD,
	0x404B: 0xFFFD,
	0x404C: 0xFFFD,
	0x404D: 0xFFFD,
	0x404E: 0xFFFD,
	0x404F: 0xFFFD,
	0x4050: 0xFFFD,
	0x4051: 0xFFFD,
	0x4052: 0xFFFD,
	0x4053: 0xFFFD,
	0x4054: 0xFFFD,
	0x4055: 0xFFFD,
	0x4056: 0xFFFD,
	0x4057: 0xFFFD,
	0x4058: 0xFFFD,
	0x4059: 0xFFFD,
	0x405A: 0xFFFD,
	0x405B: 0xFFFD,
	0x405C: 0xFFFD,
	0x405D: 0xFFFD,
	0x405E: 0xFFFD,
	0x405F: 0xFFFD,
	0x4060: 0xFFFD,
	0x4061: 0xFFFD,
	0x4062: 0xFFFD,
	0x4063: 0xFFFD,
	0x4064: 0xFFFD,
	0x4065: 0xFCC2,
	0x4066: 0xFFFD,
	0x4067: 0xFFFD,
	0x4068: 0xFFFD,
	0x4069: 0xFFFD,
	0x406A: 0xFFFD,
	0x406B: 0xFFFD,
	0x406C: 0xFFFD,
	0x406D: 0xFFFD,
	0x406E: 0xFFFD,
	0x406F: 0xFFFD,
	0x4070: 0xFFFD,
	0x4071: 0xFFFD,
	0x4072: 0xFFFD,
	0x4073: 0xFFFD,
	0x4074: 0xFFFD,
	0x4075: 0xFFFD,
	0x4076: 0xFFFD,
	0x4077: 0xFFFD,
	0x4078: 0xFFFD,
	0x4079: 0xFFFD,
	0x407A: 0xFFFD,
	0x407B: 0xFFFD,
	0x407C: 0xFFFD,
	0x407D: 0xFFFD,
	0x407E: 0xFFFD,
	0x407F: 0xFFFD,
	0x4080: 0xFFFD,
	0x4081: 0xFFFD,
	0x4082: 0xFFFD,
	0x4083: 0xFFFD,
	0x4084: 0xFFFD,
	0x4085: 0xFFFD,
	0x4086: 0xFFFD,
	0x4087: 0xFFFD,
	0x4088: 0xFFFD,
	0x4089: 0xFFFD,
	0x408A: 0xFFFD,
	0x408B: 0xFFFD,
	0x408C: 0xFFFD,
	0x408D: 0xFFFD,
	0x408E: 0xFFFD,
	0x408F: 0xFFFD,
	0x4090: 0xFFFD,
	0x4091: 0xFFFD,
	0x4092: 0xFFFD,
	0x4093: 0xFFFD,
	0x4094: 0xFFFD,
	0x4095: 0xFFFD,
	0x4096: 0xFFFD,
	0x4097: 0xFFFD,
	0x4098: 0xFFFD,
	0x4099: 0xFFFD,
	0x409A: 0xFFFD,
	0x409B: 0xFFFD,
	0x409C: 0xFFFD,
	0x409D: 0xFFFD,
	0x409E: 0xFFFD,
	0x409F: 0xFFFD,
	0x40A0: 0xFFFD,
	0x40A1: 0xFFFD,
	0x40A2: 0xFFFD,
	0x40A3: 0xFFFD,
	0x40A4: 0xFFFD,
	0x40A5: 0xFFFD,
	0x40A6: 0xFFFD,
	0x40A7: 0xFFFD,
	0x40A8: 0xFFFD,
	0x40A9: 0xFFFD,
	0x40AA: 0xFFFD,
	0x40AB: 0xFFFD,
	0x40AC: 0xFFFD,
	0x40AD: 0xFFFD,
	0x40AE: 0xFFFD,
	0x40AF: 0xFFFD,
	0x40B0: 0xFFFD,
	0x40B1: 0xFFFD,
	0x40B2: 0xFFFD,
	0x40B3: 0xFFFD,
	0x40B4: 0xFFFD,
	0x40B5: 0xFFFD,
	0x40B6: 0xFFFD,
	0x40B7: 0xFFFD,
	0x40B8: 0xFFFD,
	0x40B9: 0xFFFD,
	0x40BA: 0xFFFD,
	0x40BB: 0xFFFD,
	0x40BC: 0xFFFD,
	0x40BD: 0xFFFD,
	0x40BE: 0xFFFD,
	0x40BF: 0xFFFD,
	0x40C0: 0xFFFD,
	0x40C1: 0xFFFD,
	0x40C2: 0xFFFD,
	0x40C3: 0xFFFD,
	0x40C4: 0xFFFD,
	0x40C5: 0xFFFD,
	0x40C6: 0xFFFD,
	0x40C7: 0xFFFD,
	0x40C8: 0xFFFD,
	0x40C9: 0xFFFD,
	0x40CA: 0xFFFD,
	0x40CB: 0xFFFD,
	0x40CC: 0xFFFD,
	0x40CD: 0xFFFD,
	0x40CE: 0xFFFD,
	0x40CF: 0xFFFD,
	0x40D0: 0xFFFD,
	0x40D1: 0xFFFD,
	0x40D2: 0xFFFD,
	0x40D3: 0xFFFD,
	0x40D4: 0xFFFD,
	0x40D5: 0xFFFD,
	0x40D6: 0xFFFD,
	0x40D7: 0xFFFD,
	0x40D8: 0xFFFD,
	0x40D9: 0xFFFD,
	0x40DA: 0xFFFD,
	0x40DB: 0xFFFD,
	0x40DC: 0xFFFD,
	0x40DD: 0xFFFD,
	0x40DE: 0xFFFD,
	0x40DF: 0xFE4D,
	0x40E0: 0xFFFD,
	0x40E1: 0xFFFD,
	0x40E2: 0xFFFD,
	0x40E3: 0xFFFD,
	0x40E4: 0xFFFD,
	0x40E5: 0xFFFD,
	0x40E6: 0xFFFD,
	0x40E7: 0xFFFD,
	0x40E8: 0xFFFD,
	0x40E9: 0xFFFD,
	0x40EA: 0xFFFD,
	0x40EB: 0xFFFD,
	0x40EC: 0xFFFD,
	0x40ED: 0xFFFD,
	0x40EE: 0xFFFD,
	0x40EF: 0xFFFD,
	0x40F0: 0xFFFD,
	0x40F1: 0xFFFD,
	0x40F2: 0xFFFD,
	0x40F3: 0xFFFD,
	0x40F4: 0xFFFD,
	0x40F5: 0xFFFD,
	0x40F6: 0xFFFD,
	0x40F7: 0xFFFD,
	0x40F8: 0xFFFD,
	0x40F9: 0xFFFD,
	0x40FA: 0xFFFD,
	0x40FB: 0xFFFD,
	0x40FC: 0xFFFD,
	0x40FD: 0xFFFD,
	0x40FE: 0xFFFD,
	0x40FF: 0xFFFD,
	0x4100: 0xFFFD,
	0x4101: 0xFFFD,
	0x4102: 0xFFFD,
	0x4103: 0xFFFD,
	0x4104: 0xFFFD,
	0x4105: 0xFFFD,
	0x4106: 0xFFFD,
	0x4107: 0xFFFD,
	0x4108: 0xFFFD,
	0x4109: 0xFFFD,
	0x410A: 0xFFFD,
	0x410B: 0xFFFD,
	0x410C: 0xFFFD,
	0x410D: 0xFFFD,
	0x410E: 0xFFFD,
	0x410F: 0xFFFD,
	0x4110: 0xFFFD,
	0x4111: 0xFFFD,
	0x4112: 0xFFFD,
	0x4113: 0xFFFD,
	0x4114: 0xFFFD,
	0x4115: 0xFFFD,
	0x4116: 0xFFFD,
	0x4117: 0xFFFD,
	0x4118: 0xFFFD,
	0x4119: 0xFFFD,
	0x411A: 0xFFFD,
	0x411B: 0xFFFD,
	0x411C: 0xFFFD,
	0x411D: 0xFFFD,
	0x411E: 0xFFFD,
	0x411F: 0xFFFD,
	0x4120: 0xFFFD,
	0x4121: 0xFFFD,
	0x4122: 0xFFFD,
	0x4123: 0xFFFD,
	0x4124: 0xFFFD,
	0x4125: 0xFFFD,
	0x4126: 0xFFFD,
	0x4127: 0xFFFD,
	0x4128: 0xFFFD,
	0x4129: 0xFFFD,
	0x412A: 0xFFFD,
	0x412B: 0xFFFD,
	0x412C: 0xFFFD,
	0x412D: 0xFFFD,
	0x412E: 0xFFFD,
	0x412F: 0xFFFD,
	0x4130: 0xFFFD,
	0x4131: 0xFFFD,
	0x4132: 0xFFFD,
	0x4133: 0xFFFD,
	0x4134: 0xFFFD,
	0x4135: 0xFFFD,
	0x4136: 0xFFFD,
	0x4137: 0xFFFD,
	0x4138: 0xFFFD,
	0x4139: 0xFFFD,
	0x413A: 0xFFFD,
	0x413B: 0xFFFD,
	0x413C: 0xFFFD,
	0x413D: 0xFFFD,
	0x413E: 0xFFFD,
	0x413F: 0xFFFD,
	0x4140: 0xFFFD,
	0x4141: 0xFFFD,
	0x4142: 0xFFFD,
	0x4143: 0xFFFD,
	0x4144: 0xFFFD,
	0x4145: 0xFFFD,
	0x4146: 0xFFFD,
	0x4147: 0xFFFD,
	0x4148: 0xFFFD,
	0x4149: 0xFFFD,
	0x414A: 0xFFFD,
	0x414B: 0xFFFD,
	0x414C: 0xFFFD,
	0x414D: 0xFFFD,
	0x414E: 0xFFFD,
	0x414F: 0xFFFD,
	0x4150: 0xFFFD,
	0x4151: 0xFFFD,
	0x4152: 0xFFFD,
	0x4153: 0xFFFD,
	0x4154: 0xFFFD,
	0x4155: 0xFFFD,
	0x4156: 0xFFFD,
	0x4157: 0xFFFD,
	0x4158: 0xFFFD,
	0x4159: 0xFFFD,
	0x415A: 0xFFFD,
	0x415B: 0xFFFD,
	0x415C: 0xFFFD,
	0x415D: 0xFFFD,
	0x415E: 0xFFFD,
	0x415F: 0xFFFD,
	0x4160: 0xFFFD,
	0x4161: 0xFFFD,
	0x4162: 0xFFFD,
	0x4163: 0xFFFD,
	0x4164: 0xFFFD,
	0x4165: 0xFFFD,
	0x4166: 0xFFFD,
	0x4167: 0xFFFD,
	0x4168: 0xFFFD,
	0x4169: 0xFFFD,
	0x416A: 0xFFFD,
	0x416B: 0xFFFD,
	0x416C: 0xFFFD,
	0x416D: 0xFFFD,
	0x416E: 0xFFFD,
	0x416F: 0xFFFD,
	0x4170: 0xFFFD,
	0x4171: 0xFFFD,
	0x4172: 0xFFFD,
	0x4173: 0xFFFD,
	0x4174: 0xFFFD,
	0x4175: 0xFFFD,
	0x4176: 0xFFFD,
	0x4177: 0xFFFD,
	0x4178: 0xFFFD,
	0x4179: 0xFFFD,
	0x417A: 0xFFFD,
	0x417B: 0xFFFD,
	0x417C: 0xFFFD,
	0x417D: 0xFFFD,
	0x417E: 0xFFFD,
	0x417F: 0xFFFD,
	0x4180: 0xFFFD,
	0x4181: 0xFFFD,
	0x4182: 0xFFFD,
	0x4183: 0xFFFD,
	0x4184: 0xFFFD,
	0x4185: 0xFFFD,
	0x4186: 0xFFFD,
	0x4187: 0xFFFD,
	0x4188: 0xFFFD,
	0x4189: 0xFFFD,
	0x418A: 0xFFFD,
	0x418B: 0xFFFD,
	0x418C: 0xFFFD,
	0x418D: 0xFFFD,
	0x418E: 0xFFFD,
	0x418F: 0xFFFD,
	0x4190: 0xFFFD,
	0x4191: 0xFFFD,
	0x4192: 0xFFFD,
	0x4193: 0xFFFD,
	0x4194: 0xFFFD,
	0x4195: 0xFFFD,
	0x4196: 0xFFFD,
	0x4197: 0xFFFD,
	0x4198: 0xFFFD,
	0x4199: 0xFFFD,
	0x419A: 0xFFFD,
	0x419B: 0xFFFD,
	0x419C: 0xFFFD,
	0x419D: 0xFFFD,
	0x419E: 0xFFFD,
	0x419F: 0xFFFD,
	0x41A0: 0xFFFD,
	0x41A1: 0xFFFD,
	0x41A2: 0xFFFD,
	0x41A3: 0xFFFD,
	0x41A4: 0xFFFD,
	0x41A5: 0xFFFD,
	0x41A6: 0xFFFD,
	0x41A7: 0xFFFD,
	0x41A8: 0xFFFD,
	0x41A9: 0xFFFD,
	0x41AA: 0xFFFD,
	0x41AB: 0xFFFD,
	0x41AC: 0xFFFD,
	0x41AD: 0xFFFD,
	0x41AE: 0xFFFD,
	0x41AF: 0xFFFD,
	0x41B0: 0xFFFD,
	0x41B1: 0xFFFD,
	0x41B2: 0xFFFD,
	0x41B3: 0xFFFD,
	0x41B4: 0xFFFD,
	0x41B5: 0xFFFD,
	0x41B6: 0xFFFD,
	0x41B7: 0xFFFD,
	0x41B8: 0xFFFD,
	0x41B9: 0xFFFD,
	0x41BA: 0xFFFD,
	0x41BB: 0xFFFD,
	0x41BC: 0xFFFD,
	0x41BD: 0xFFFD,
	0x41BE: 0xFFFD,
	0x41BF: 0xFFFD,
	0x41C0: 0xFFFD,
	0x41C1: 0xFFFD,
	0x41C2: 0xFFFD,
	0x41C3: 0xFFFD,
	0x41C4: 0xFFFD,
	0x41C5: 0xFFFD,
	0x41C6: 0xFFFD,
	0x41C7: 0xFFFD,
	0x41C8: 0xFFFD,
	0x41C9: 0xFFFD,
	0x41CA: 0xFFFD,
	0x41CB: 0xFFFD,
	0x41CC: 0xFFFD,
	0x41CD: 0xFFFD,
	0x41CE: 0xFFFD,
	0x41CF: 0xFFFD,
	0x41D0: 0xFFFD,
	0x41D1: 0xFFFD,
	0x41D2: 0xFFFD,
	0x41D3: 0xFFFD,
	0x41D4: 0xFFFD,
	0x41D5: 0xFFFD,
	0x41D6: 0xFFFD,
	0x41D7: 0xFFFD,
	0x41D8: 0xFFFD,
	0x41D9: 0xFFFD,
	0x41DA: 0xFFFD,
	0x41DB: 0xFFFD,
	0x41DC: 0xFFFD,
	0x41DD: 0xFFFD,
	0x41DE: 0xFFFD,
	0x41DF: 0xFFFD,
	0x41E0: 0xFFFD,
	0x41E1: 0xFFFD,
	0x41E2: 0xFFFD,
	0x41E3: 0xFFFD,
	0x41E4: 0xFFFD,
	0x41E5: 0xFFFD,
	0x41E6: 0xFFFD,
	0x41E7: 0xFFFD,
	0x41E8: 0xFFFD,
	0x41E9: 0xFFFD,
	0x41EA: 0xFFFD,
	0x41EB: 0xFFFD,
	0x41EC: 0xFFFD,
	0x41ED: 0xFFFD,
	0x41EE: 0xFFFD,
	0x41EF: 0xFFFD,
	0x41F0: 0xFFFD,
	0x41F1: 0xFFFD,
	0x41F2: 0xFFFD,
	0x41F3: 0xFFFD,
	0x41F4: 0xFFFD,
	0x41F5: 0xFFFD,
	0x41F6: 0xFFFD,
	0x41F7: 0xFFFD,
	0x41F8: 0xFFFD,
	0x41F9: 0xFFFD,
	0x41FA: 0xFFFD,
	0x41FB: 0xFFFD,
	0x41FC: 0xFFFD,
	0x41FD: 0xFFFD,
	0x41FE: 0xFFFD,
	0x41FF: 0xFFFD,
	0x4200: 0xFFFD,
	0x4201: 0xFFFD,
	0x4202: 0xFFFD,
	0x4203: 0xFFFD,
	0x4204: 0xFFFD,
	0x4205: 0xFFFD,
	0x4206: 0xFFFD,
	0x4207: 0xFFFD,
	0x4208: 0xFFFD,
	0x4209: 0xFFFD,
	0x420A: 0xFFFD,
	0x420B: 0xFFFD,
	0x420C: 0xFFFD,
	0x420D: 0xFFFD,
	0x420E: 0xFFFD,
	0x420F: 0xFFFD,
	0x4210: 0xFFFD,
	0x4211: 0xFFFD,
	0x4212: 0xFFFD,
	0x4213: 0xFFFD,
	0x4214: 0xFFFD,
	0x4215: 0xFFFD,
	0x4216: 0xFFFD,
	0x4217: 0xFFFD,
	0x4218: 0xFFFD,
	0x4219: 0xFFFD,
	0x421A: 0xFFFD,
	0x421B: 0xFFFD,
	0x421C: 0xFFFD,
	0x421D: 0xFFFD,
	0x421E: 0xFFFD,
	0x421F: 0xFFFD,
	0x4220: 0xFFFD,
	0x4221: 0xFFFD,
	0x4222: 0xFFFD,
	0x4223: 0xFFFD,
	0x4224: 0xFFFD,
	0x4225: 0xFFFD,
	0x4226: 0xFFFD,
	0x4227: 0xFFFD,
	0x4228: 0xFFFD,
	0x4229: 0xFFFD,
	0x422A: 0xFFFD,
	0x422B: 0xFFFD,
	0x422C: 0xFFFD,
	0x422D: 0xFFFD,
	0x422E: 0xFFFD,
	0x422F: 0xFFFD,
	0x4230: 0xFFFD,
	0x4231: 0xFFFD,
	0x4232: 0xFFFD,
	0x4233: 0xFFFD,
	0x4234: 0xFFFD,
	0x4235: 0xFFFD,
	0x4236: 0xFFFD,
	0x4237: 0xFFFD,
	0x4238: 0xFFFD,
	0x4239: 0xFFFD,
	0x423A: 0xFFFD,
	0x423B: 0xFFFD,
	0x423C: 0xFFFD,
	0x423D: 0xFFFD,
	0x423E: 0xFFFD,
	0x423F: 0xFFFD,
	0x4240: 0xFFFD,
	0x4241: 0xFFFD,
	0x4242: 0xFFFD,
	0x4243: 0xFFFD,
	0x4244: 0xFFFD,
	0x4245: 0xFFFD,
	0x4246: 0xFFFD,
	0x4247: 0xFFFD,
	0x4248: 0xFFFD,
	0x4249: 0xFFFD,
	0x424A: 0xFFFD,
	0x424B: 0xFFFD,
	0x424C: 0xFFFD,
	0x424D: 0xFFFD,
	0x424E: 0xFFFD,
	0x424F: 0xFFFD,
	0x4250: 0xFFFD,
	0x4251: 0xFFFD,
	0x4252: 0xFFFD,
	0x4253: 0xFFFD,
	0x4254: 0xFFFD,
	0x4255: 0xFFFD,
	0x4256: 0xFFFD,
	0x4257: 0xFFFD,
	0x4258: 0xFFFD,
	0x4259: 0xFFFD,
	0x425A: 0xFFFD,
	0x425B: 0xFFFD,
	0x425C: 0xFFFD,
	0x425D: 0xFFFD,
	0x425E: 0xFFFD,
	0x425F: 0xFFFD,
	0x4260: 0xFFFD,
	0x4261: 0xFFFD,
	0x4262: 0xFFFD,
	0x4263: 0xFFFD,
	0x4264: 0xFFFD,
	0x4265: 0xFFFD,
	0x4266: 0xFFFD,
	0x4267: 0xFFFD,
	0x4268: 0xFFFD,
	0x4269: 0xFFFD,
	0x426A: 0xFFFD,
	0x426B: 0xFFFD,
	0x426C: 0xFFFD,
	0x426D: 0xFFFD,
	0x426E: 0xFFFD,
	0x426F: 0xFFFD,
	0x4270: 0xFFFD,
	0x4271: 0xFFFD,
	0x4272: 0xFFFD,
	0x4273: 0xFFFD,
	0x4274: 0xFFFD,
	0x4275: 0xFFFD,
	0x4276: 0xFFFD,
	0x4277: 0xFFFD,
	0x4278: 0xFFFD,
	0x4279: 0xFFFD,
	0x427A: 0xFFFD,
	0x427B: 0xFFFD,
	0x427C: 0xFFFD,
	0x427D: 0xFFFD,
	0x427E: 0xFFFD,
	0x427F: 0xFFFD,
	0x4280: 0xFFFD,
	0x4281: 0xFFFD,
	0x4282: 0xFFFD,
	0x4283: 0xFFFD,
	0x4284: 0xFFFD,
	0x4285: 0xFFFD,
	0x4286: 0xFFFD,
	0x4287: 0xFFFD,
	0x4288: 0xFFFD,
	0x4289: 0xFFFD,
	0x428A: 0xFFFD,
	0x428B: 0xFFFD,
	0x428C: 0xFFFD,
	0x428D: 0xFFFD,
	0x428E: 0xFFFD,
	0x428F: 0xFFFD,
	0x4290: 0xFFFD,
	0x4291: 0xFFFD,
	0x4292: 0xFFFD,
	0x4293: 0xFFFD,
	0x4294: 0xFFFD,
	0x4295: 0xFFFD,
	0x4296: 0xFFFD,
	0x4297: 0xFFFD,
	0x4298: 0xFFFD,
	0x4299: 0xFFFD,
	0x429A: 0xFFFD,
	0x429B: 0xFFFD,
	0x429C: 0xFFFD,
	0x429D: 0xFFFD,
	0x429E: 0xFFFD,
	0x429F: 0xFFFD,
	0x42A0: 0xFFFD,
	0x42A1: 0xFFFD,
	0x42A2: 0xFFFD,
	0x42A3: 0xFFFD,
	0x42A4: 0xFFFD,
	0x42A5: 0xFFFD,
	0x42A6: 0xFFFD,
	0x42A7: 0xFFFD,
	0x42A8: 0xFFFD,
	0x42A9: 0xFFFD,
	0x42AA: 0xFFFD,
	0x42AB: 0xFFFD,
	0x42AC: 0xFFFD,
	0x42AD: 0xFFFD,
	0x42AE: 0xFFFD,
	0x42AF: 0xFFFD,
	0x42B0: 0xFFFD,
	0x42B1: 0xFFFD,
	0x42B2: 0xFFFD,
	0x42B3: 0xFFFD,
	0x42B4: 0xFFFD,
	0x42B5: 0xFFFD,
	0x42B6: 0xFFFD,
	0x42B7: 0xFFFD,
	0x42B8: 0xFFFD,
	0x42B9: 0xFFFD,
	0x42BA: 0xFFFD,
	0x42BB: 0xFFFD,
	0x42BC: 0xFFFD,
	0x42BD: 0xFFFD,
	0x42BE: 0xFFFD,
	0x42BF: 0xFFFD,
	0x42C0: 0xFFFD,
	0x42C1: 0xFFFD,
	0x42C2: 0xFFFD,
	0x42C3: 0xFFFD,
	0x42C4: 0xFFFD,
	0x42C5: 0xFFFD,
	0x42C6: 0xFFFD,
	0x42C7: 0xFFFD,
	0x42C8: 0xFFFD,
	0x42C9: 0xFFFD,
	0x42CA: 0xFFFD,
	0x42CB: 0xFFFD,
	0x42CC: 0xFFFD,
	0x42CD: 0xFFFD,
	0x42CE: 0xFFFD,
	0x42CF: 0xFFFD,
	0x42D0: 0xFFFD,
	0x42D1: 0xFFFD,
	0x42D2: 0xFFFD,
	0x42D3: 0xFFFD,
	0x42D4: 0xFFFD,
	0x42D5: 0xFFFD,
	0x42D6: 0xFFFD,
	0x42D7: 0xFFFD,
	0x42D8: 0xFFFD,
	0x42D9: 0xFFFD,
	0x42DA: 0xFFFD,
	0x42DB: 0xFFFD,
	0x42DC: 0xFFFD,
	0x42DD: 0xFFFD,
	0x42DE: 0xFFFD,
	0x42DF: 0xFFFD,
	0x42E0: 0xFFFD,
	0x42E1: 0xFFFD,
	0x42E2: 0xFFFD,
	0x42E3: 0xFFFD,
	0x42E4: 0xFFFD,
	0x42E5: 0xFFFD,
	0x42E6: 0xFFFD,
	0x42E7: 0xFFFD,
	0x42E8: 0xFFFD,
	0x42E9: 0xFFFD,
	0x42EA: 0xFFFD,
	0x42EB: 0xFFFD,
	0x42EC: 0xFFFD,
	0x42ED: 0xFFFD,
	0x42EE: 0xFFFD,
	0x42EF: 0xFFFD,
	0x42F0: 0xFFFD,
	0x42F1: 0xFFFD,
	0x42F2: 0xFFFD,
	0x42F3: 0xFFFD,
	0x42F4: 0xFFFD,
	0x42F5: 0xFFFD,
	0x42F6: 0xFFFD,
	0x42F7: 0xFFFD,
	0x42F8: 0xFFFD,
	0x42F9: 0xFFFD,
	0x42FA: 0xFFFD,
	0x42FB: 0xFFFD,
	0x42FC: 0xFFFD,
	0x42FD: 0xFFFD,
	0x42FE: 0xFFFD,
	0x42FF: 0xFFFD,
	0x4300: 0xFFFD,
	0x4301: 0xFFFD,
	0x4302: 0xFFFD,
	0x4303: 0xFFFD,
	0x4304: 0xFFFD,
	0x4305: 0xFFFD,
	0x4306: 0xFFFD,
	0x4307: 0xFFFD,
	0x4308: 0xFFFD,
	0x4309: 0xFFFD,
	0x430A: 0xFFFD,
	0x430B: 0xFFFD,
	0x430C: 0xFFFD,
	0x430D: 0xFFFD,
	0x430E: 0xFFFD,
	0x430F: 0xFFFD,
	0x4310: 0xFFFD,
	0x4311: 0xFFFD,
	0x4312: 0xFFFD,
	0x4313: 0xFFFD,
	0x4314: 0xFFFD,
	0x4315: 0xFFFD,
	0x4316: 0xFFFD,
	0x4317: 0xFFFD,
	0x4318: 0xFFFD,
	0x4319: 0xFFFD,
	0x431A: 0xFFFD,
	0x431B: 0xFFFD,
	0x431C: 0xFFFD,
	0x431D: 0xFFFD,
	0x431E: 0xFFFD,
	0x431F: 0xFFFD,
	0x4320: 0xFFFD,
	0x4321: 0xFFFD,
	0x4322: 0xFFFD,
	0x4323: 0xFFFD,
	0x4324: 0xFFFD,
	0x4325: 0xFFFD,
	0x4326: 0xFFFD,
	0x4327: 0xFFFD,
	0x4328: 0xFFFD,
	0x4329: 0xFFFD,
	0x432A: 0xFFFD,
	0x432B: 0xFFFD,
	0x432C: 0xFFFD,
	0x432D: 0xFFFD,
	0x432E: 0xFFFD,
	0x432F: 0xFFFD,
	0x4330: 0xFFFD,
	0x4331: 0xFFFD,
	0x4332: 0xFFFD,
	0x4333: 0xFFFD,
	0x4334: 0xFFFD,
	0x4335: 0xFFFD,
	0x4336: 0xFFFD,
	0x4337: 0xFFFD,
	0x4338: 0xFFFD,
	0x4339: 0xFFFD,
	0x433A: 0xFFFD,
	0x433B: 0xFFFD,
	0x433C: 0xFFFD,
	0x433D: 0xFFFD,
	0x433E: 0xFFFD,
	0x433F: 0xFFFD,
	0x4340: 0xFFFD,
	0x4341: 0xFFFD,
	0x4342: 0xFFFD,
	0x4343: 0xFFFD,
	0x4344: 0xFFFD,
	0x4345: 0xFFFD,
	0x4346: 0xFFFD,
	0x4347: 0xFFFD,
	0x4348: 0xFFFD,
	0x4349: 0xFFFD,
	0x434A: 0xFFFD,
	0x434B: 0xFFFD,
	0x434C: 0xFFFD,
	0x434D: 0xFFFD,
	0x434E: 0xFFFD,
	0x434F: 0xFFFD,
	0x4350: 0xFFFD,
	0x4351: 0xFFFD,
	0x4352: 0xFFFD,
	0x4353: 0xFFFD,
	0x4354: 0xFFFD,
	0x4355: 0xFFFD,
	0x4356: 0xFFFD,
	0x4357: 0xFFFD,
	0x4358: 0xFFFD,
	0x4359: 0xFFFD,
	0x435A: 0xFFFD,
	0x435B: 0xFFFD,
	0x435C: 0xFFFD,
	0x435D: 0xFFFD,
	0x435E: 0xFFFD,
	0x435F: 0xFFFD,
	0x4360: 0xFFFD,
	0x4361: 0xFFFD,
	0x4362: 0xFFFD,
	0x4363: 0xFFFD,
	0x4364: 0xFFFD,
	0x4365: 0xFFFD,
	0x4366: 0xFFFD,
	0x4367: 0xFFFD,
	0x4368: 0xFFFD,
	0x4369: 0xFFFD,
	0x436A: 0xFFFD,
	0x436B: 0xFFFD,
	0x436C: 0xFFFD,
	0x436D: 0xFFFD,
	0x436E: 0xFFFD,
	0x436F: 0xFFFD,
	0x4370: 0xFFFD,
	0x4371: 0xFFFD,
	0x4372: 0xFFFD,
	0x4373: 0xFFFD,
	0x4374: 0xFFFD,
	0x4375: 0xFFFD,
	0x4376: 0xFFFD,
	0x4377: 0xFFFD,
	0x4378: 0xFFFD,
	0x4379: 0xFFFD,
	0x437A: 0xFFFD,
	0x437B: 0xFFFD,
	0x437C: 0xFFFD,
	0x437D: 0xFFFD,
	0x437E: 0xFFFD,
	0x437F: 0xFFFD,
	0x4380: 0xFFFD,
	0x4381: 0xFFFD,
	0x4382: 0xFFFD,
	0x4383: 0xFFFD,
	0x4384: 0xFFFD,
	0x4385: 0xFFFD,
	0x4386: 0xFFFD,
	0x4387: 0xFFFD,
	0x4388: 0xFFFD,
	0x4389: 0xFFFD,
	0x438A: 0xFFFD,
	0x438B: 0xFFFD,
	0x438C: 0xFFFD,
	0x438D: 0xFFFD,
	0x438E: 0xFFFD,
	0x438F: 0xFFFD,
	0x4390: 0xFFFD,
	0x4391: 0xFFFD,
	0x4392: 0xFFFD,
	0x4393: 0xFFFD,
	0x4394: 0xFFFD,
	0x4395: 0xFFFD,
	0x4396: 0xFFFD,
	0x4397: 0xFFFD,
	0x4398: 0xFFFD,
	0x4399: 0xFFFD,
	0x439A: 0xFFFD,
	0x439B: 0xFFFD,
	0x439C: 0xFFFD,
	0x439D: 0xFFFD,
	0x439E: 0xFFFD,
	0x439F: 0xFFFD,
	0x43A0: 0xFFFD,
	0x43A1: 0xFFFD,
	0x43A2: 0xFFFD,
	0x43A3: 0xFFFD,
	0x43A4: 0xFFFD,
	0x43A5: 0xFFFD,
	0x43A6: 0xFFFD,
	0x43A7: 0xFFFD,
	0x43A8: 0xFFFD,
	0x43A9: 0xFFFD,
	0x43AA: 0xFFFD,
	0x43AB: 0xFFFD,
	0x43AC: 0xFFFD,
	0x43AD: 0xFFFD,
	0x43AE: 0xFFFD,
	0x43AF: 0xFFFD,
	0x43B0: 0xFFFD,
	0x43B1: 0xFFFD,
	0x43B2: 0xFFFD,
	0x43B3: 0xFFFD,
	0x43B4: 0xFFFD,
	0x43B5: 0xFFFD,
	0x43B6: 0xFFFD,
	0x43B7: 0xFFFD,
	0x43B8: 0xFFFD,
	0x43B9: 0xFFFD,
	0x43BA: 0xFFFD,
	0x43BB: 0xFFFD,
	0x43BC: 0xFFFD,
	0x43BD: 0xFFFD,
	0x43BE: 0xFFFD,
	0x43BF: 0xFFFD,
	0x43C0: 0xFFFD,
	0x43C1: 0xFFFD,
	0x43C2: 0xFFFD,
	0x43C3: 0xFFFD,
	0x43C4: 0xFFFD,
	0x43C5: 0xFFFD,
	0x43C6: 0xFFFD,
	0x43C7: 0xFFFD,
	0x43C8: 0xFFFD,
	0x43C9: 0xFFFD,
	0x43CA: 0xFFFD,
	0x43CB: 0xFFFD,
	0x43CC: 0xFFFD,
	0x43CD: 0xFFFD,
	0x43CE: 0xFFFD,
	0x43CF: 0xFFFD,
	0x43D0: 0xFFFD,
	0x43D1: 0xFFFD,
	0x43D2: 0xFFFD,
	0x43D3: 0xFFFD,
	0x43D4: 0xFFFD,
	0x43D5: 0xFFFD,
	0x43D6: 0xFFFD,
	0x43D7: 0xFFFD,
	0x43D8: 0xFFFD,
	0x43D9: 0xFFFD,
	0x43DA: 0xFFFD,
	0x43DB: 0xFFFD,
	0x43DC: 0xFFFD,
	0x43DD: 0xFFFD,
	0x43DE: 0xFFFD,
	0x43DF: 0xFFFD,
	0x43E0: 0xFFFD,
	0x43E1: 0xFFFD,
	0x43E2: 0xFFFD,
	0x43E3: 0xFFFD,
	0x43E4: 0xFFFD,
	0x43E5: 0xFFFD,
	0x43E6: 0xFFFD,
	0x43E7: 0xFFFD,
	0x43E8: 0xFFFD,
	0x43E9: 0xFFFD,
	0x43EA: 0xFFFD,
	0x43EB: 0xFFFD,
	0x43EC: 0xFFFD,
	0x43ED: 0xFFFD,
	0x43EE: 0xFFFD,
	0x43EF: 0xFFFD,
	0x43F0: 0xFFFD,
	0x43F1: 0xFFFD,
	0x43F2: 0xFFFD,
	0x43F3: 0xFFFD,
	0x43F4: 0xFFFD,
	0x43F5: 0xFFFD,
	0x43F6: 0xFFFD,
	0x43F7: 0xFFFD,
	0x43F8: 0xFFFD,
	0x43F9: 0xFFFD,
	0x43FA: 0xFFFD,
	0x43FB: 0xFFFD,
	0x43FC: 0xFFFD,
	0x43FD: 0xFFFD,
	0x43FE: 0xFFFD,
	0x43FF: 0xFFFD,
	0x4400: 0xFFFD,
	0x4401: 0xFFFD,
	0x4402: 0xFFFD,
	0x4403: 0xFFFD,
	0x4404: 0xFFFD,
	0x4405: 0xFFFD,
	0x4406: 0xFFFD,
	0x4407: 0xFFFD,
	0x4408: 0xFFFD,
	0x4409: 0xFFFD,
	0x440A: 0xFFFD,
	0x440B: 0xFFFD,
	0x440C: 0xFFFD,
	0x440D: 0xFFFD,
	0x440E: 0xFFFD,
	0x440F: 0xFFFD,
	0x4410: 0xFFFD,
	0x4411: 0xFFFD,
	0x4412: 0xFFFD,
	0x4413: 0xFFFD,
	0x4414: 0xFFFD,
	0x4415: 0xFFFD,
	0x4416: 0xFFFD,
	0x4417: 0xFFFD,
	0x4418: 0xFFFD,
	0x4419: 0xFFFD,
	0x441A: 0xFFFD,
	0x441B: 0xFFFD,
	0x441C: 0xFFFD,
	0x441D: 0xFFFD,
	0x441E: 0xFFFD,
	0x441F: 0xFFFD,
	0x4420: 0xFFFD,
	0x4421: 0xFFFD,
	0x4422: 0xFFFD,
	0x4423: 0xFFFD,
	0x4424: 0xFFFD,
	0x4425: 0xFFFD,
	0x4426: 0xFFFD,
	0x4427: 0xFFFD,
	0x4428: 0xFFFD,
	0x4429: 0xFFFD,
	0x442A: 0xFFFD,
	0x442B: 0xFFFD,
	0x442C: 0xFFFD,
	0x442D: 0xFFFD,
	0x442E: 0xFFFD,
	0x442F: 0xFFFD,
	0x4430: 0xFFFD,
	0x4431: 0xFFFD,
	0x4432: 0xFFFD,
	0x4433: 0xFFFD,
	0x4434: 0xFFFD,
	0x4435: 0xFFFD,
	0x4436: 0x96AD,
	0x4437: 0xFFFD,
	0x4438: 0xFFFD,
	0x4439: 0xFFFD,
	0x443A: 0xFFFD,
	0x443B: 0xFFFD,
	0x443C: 0xFFFD,
	0x443D: 0xFFFD,
	0x443E: 0xFFFD,
	0x443F: 0xFFFD,
	0x4440: 0xFFFD,
	0x4441: 0xFFFD,
	0x4442: 0xFFFD,
	0x4443: 0xFFFD,
	0x4444: 0xFFFD,
	0x4445: 0xFFFD,
	0x4446: 0xFFFD,
	0x4447: 0xFFFD,
	0x4448: 0xFFFD,
	0x4449: 0xFFFD,
	0x444A: 0xFFFD,
	0x444B: 0xFFFD,
	0x444C: 0xFFFD,
	0x444D: 0xFFFD,
	0x444E: 0xFFFD,
	0x444F: 0xFFFD,
	0x4450: 0xFFFD,
	0x4451: 0xFFFD,
	0x4452: 0xFFFD,
	0x4453: 0xFFFD,
	0x4454: 0xFFFD,
	0x4455: 0xFFFD,
	0x4456: 0xFFFD,
	0x4457: 0xFFFD,
	0x4458: 0xFFFD,
	0x4459: 0xFFFD,
	0x445A: 0xFFFD,
	0x445B: 0xFFFD,
	0x445C: 0xFFFD,
	0x445D: 0xFFFD,
	0x445E: 0xFFFD,
	0x445F: 0xFFFD,
	0x4460: 0xFFFD,
	0x4461: 0xFFFD,
	0x4462: 0xFFFD,
	0x4463: 0xFFFD,
	0x4464: 0xFFFD,
	0x4465: 0xFFFD,
	0x4466: 0xFFFD,
	0x4467: 0xFFFD,
	0x4468: 0xFFFD,
	0x4469: 0xFFFD,
	0x446A: 0xFFFD,
	0x446B: 0xFFFD,
	0x446C: 0xFFFD,
	0x446D: 0xFFFD,
	0x446E: 0xFFFD,
	0x446F: 0xFFFD,
	0x4470: 0xFFFD,
	0x4471: 0xFFFD,
	0x4472: 0xFFFD,
	0x4473: 0xFFFD,
	0x4474: 0xFFFD,
	0x4475: 0xFFFD,
	0x4476: 0xFFFD,
	0x4477: 0xFFFD,
	0x4478: 0xFFFD,
	0x4479: 0xFFFD,
	0x447A: 0xFFFD,
	0x447B: 0xFFFD,
	0x447C: 0xFFFD,
	0x447D: 0xFFFD,
	0x447E: 0xFFFD,
	0x447F: 0xFFFD,
	0x4480: 0xFFFD,
	0x4481: 0xFFFD,
	0x4482: 0xFFFD,
	0x4483: 0xFFFD,
	0x4484: 0xFFFD,
	0x4485: 0xFFFD,
	0x4486: 0xFFFD,
	0x4487: 0xFFFD,
	0x4488: 0xFFFD,
	0x4489: 0xFFFD,
	0x448A: 0xFFFD,
	0x448B: 0xFFFD,
	0x448C: 0xFFFD,
	0x448D: 0xFFFD,
	0x448E: 0xFFFD,
	0x448F: 0xFFFD,
	0x4490: 0xFFFD,
	0x4491: 0x9CD3,
	0x4492: 0xFFFD,
	0x4493: 0xFFFD,
	0x4494: 0xFFFD,
	0x4495: 0xFFFD,
	0x4496: 0xFFFD,
	0x4497: 0xFFFD,
	0x4498: 0xFFFD,
	0x4499: 0xFFFD,
	0x449A: 0xFFFD,
	0x449B: 0xFFFD,
	0x449C: 0xFFFD,
	0x449D: 0xFFFD,
	0x449E: 0xFFFD,
	0x449F: 0xFFFD,
	0x44A0: 0xFFFD,
	0x44A1: 0xFFFD,
	0x44A2: 0xFFFD,
	0x44A3: 0xFFFD,
	0x44A4: 0xFFFD,
	0x44A5: 0xFFFD,
	0x44A6: 0xFFFD,
	0x44A7: 0xFFFD,
	0x44A8: 0xFFFD,
	0x44A9: 0xFFFD,
	0x44AA: 0xFFFD,
	0x44AB: 0xFFFD,
	0x44AC: 0xFFFD,
	0x44AD: 0xFFFD,
	0x44AE: 0xFFFD,
	0x44AF: 0xFFFD,
	0x44B0: 0xFFFD,
	0x44B1: 0xFFFD,
	0x44B2: 0xFFFD,
	0x44B3: 0xFFFD,
	0x44B4: 0xFFFD,
	0x44B5: 0xFFFD,
	0x44B6: 0xFFFD,
	0x44B7: 0xFD5E,
	0x44B8: 0xFFFD,
	0x44B9: 0xFFFD,
	0x44BA: 0xFFFD,
	0x44BB: 0xFFFD,
	0x44BC: 0xFFFD,
	0x44BD: 0xFFFD,
	0x44BE: 0xFFFD,
	0x44BF: 0xFFFD,
	0x44C0: 0xFFFD,
	0x44C1: 0xFFFD,
	0x44C2: 0xFFFD,
	0x44C3: 0xFFFD,
	0x44C4: 0xFFFD,
	0x44C5: 0xFFFD,
	0x44C6: 0xFFFD,
	0x44C7: 0xFFFD,
	0x44C8: 0xFFFD,
	0x44C9: 0xFFFD,
	0x44CA: 0xFFFD,
	0x44CB: 0xFFFD,
	0x44CC: 0xFFFD,
	0x44CD: 0xFFFD,
	0x44CE: 0xFFFD,
	0x44CF: 0xFFFD,
	0x44D0: 0xFFFD,
	0x44D1: 0xFFFD,
	0x44D2: 0xFFFD,
	0x44D3: 0xFFFD,
	0x44D4: 0xFFFD,
	0x44D5: 0xFFFD,
	0x44D6: 0xFFFD,
	0x44D7: 0xFFFD,
	0x44D8: 0xFFFD,
	0x44D9: 0xFFFD,
	0x44DA: 0xFFFD,
	0x44DB: 0xFFFD,
	0x44DC: 0xFFFD,
	0x44DD: 0xFFFD,
	0x44DE: 0xFFFD,
	0x44DF: 0xFFFD,
	0x44E0: 0xFFFD,
	0x44E1: 0xFFFD,
	0x44E2: 0xFFFD,
	0x44E3: 0xFFFD,
	0x44E4: 0xFFFD,
	0x44E5: 0xFFFD,
	0x44E6: 0xFFFD,
	0x44E7: 0xFFFD,
	0x44E8: 0xFFFD,
	0x44E9: 0xFFFD,
	0x44EA: 0xFE4A,
	0x44EB: 0xFFFD,
	0x44EC: 0xFFFD,
	0x44ED: 0xFFFD,
	0x44EE: 0xFFFD,
	0x44EF: 0xFFFD,
	0x44F0: 0xFFFD,
	0x44F1: 0xFFFD,
	0x44F2: 0xFFFD,
	0x44F3: 0xFFFD,
	0x44F4: 0xFFFD,
	0x44F5: 0xFFFD,
	0x44F6: 0xFFFD,
	0x44F7: 0xFFFD,
	0x44F8: 0xFFFD,
	0x44F9: 0xFFFD,
	0x44FA: 0xFFFD,
	0x44FB: 0xFD67,
	0x44FC: 0xFFFD,
	0x44FD: 0xFFFD,
	0x44FE: 0xFFFD,
	0x44FF: 0xFFFD,
	0x4500: 0xFFFD,
	0x4501: 0xFFFD,
	0x4502: 0xFFFD,
	0x4503: 0xFFFD,
	0x4504: 0xFFFD,
	0x4505: 0xFFFD,
	0x4506: 0xFFFD,
	0x4507: 0xFFFD,
	0x4508: 0xFFFD,
	0x4509: 0xFFFD,
	0x450A: 0xFFFD,
	0x450B: 0xFFFD,
	0x450C: 0xFFFD,
	0x450D: 0xFFFD,
	0x450E: 0xFFFD,
	0x450F: 0xFFFD,
	0x4510: 0xFFFD,
	0x4511: 0xFFFD,
	0x4512: 0xFFFD,
	0x4513: 0xFFFD,
	0x4514: 0xFFFD,
	0x4515: 0xFFFD,
	0x4516: 0xFFFD,
	0x4517: 0xFFFD,
	0x4518: 0xFFFD,
	0x4519: 0xFFFD,
	0x451A: 0xFFFD,
	0x451B: 0xFFFD,
	0x451C: 0xFFFD,
	0x451D: 0xFFFD,
	0x451E: 0xFFFD,
	0x451F: 0xFFFD,
	0x4520: 0xFFFD,
	0x4521: 0xFFFD,
	0x4522: 0xFFFD,
	0x4523: 0xFFFD,
	0x4524: 0xFFFD,
	0x4525: 0xFFFD,
	0x4526: 0xFFFD,
	0x4527: 0xFFFD,
	0x4528: 0xFFFD,
	0x4529: 0xFFFD,
	0x452A: 0xFFFD,
	0x452B: 0xFFFD,
	0x452C: 0xFFFD,
	0x452D: 0xFFFD,
	0x452E: 0xFFFD,
	0x452F: 0xFFFD,
	0x4530: 0xFFFD,
	0x4531: 0xFFFD,
	0x4532: 0xFFFD,
	0x4533: 0xFFFD,
	0x4534: 0xFFFD,
	0x4535: 0xFFFD,
	0x4536: 0xFFFD,
	0x4537: 0xFFFD,
	0x4538: 0xFFFD,
	0x4539: 0xFFFD,
	0x453A: 0xFFFD,
	0x453B: 0xFFFD,
	0x453C: 0xFFFD,
	0x453D: 0xFFFD,
	0x453E: 0xFFFD,
	0x453F: 0xFFFD,
	0x4540: 0xFFFD,
	0x4541: 0xFFFD,
	0x4542: 0xFFFD,
	0x4543: 0xFFFD,
	0x4544: 0xFFFD,
	0x4545: 0xFFFD,
	0x4546: 0xFFFD,
	0x4547: 0xFFFD,
	0x4548: 0xFFFD,
	0x4549: 0xFFFD,
	0x454A: 0xFFFD,
	0x454B: 0xFFFD,
	0x454C: 0xFFFD,
	0x454D: 0xFFFD,
	0x454E: 0xFFFD,
	0x454F: 0xFFFD,
	0x4550: 0xFFFD,
	0x4551: 0xFFFD,
	0x4552: 0xFFFD,
	0x4553: 0xFFFD,
	0x4554: 0xFFFD,
	0x4555: 0xFFFD,
	0x4556: 0xFFFD,
	0x4557: 0xFFFD,
	0x4558: 0xFFFD,
	0x4559: 0xFFFD,
	0x455A: 0xFFFD,
	0x455B: 0xFFFD,
	0x455C: 0xFFFD,
	0x455D: 0xFFFD,
	0x455E: 0xFFFD,
	0x455F: 0xFFFD,
	0x4560: 0xFFFD,
	0x4561: 0xFFFD,
	0x4562: 0xFFFD,
	0x4563: 0xFFFD,
	0x4564: 0xFFFD,
	0x4565: 0xFFFD,
	0x4566: 0xFFFD,
	0x4567: 0xFFFD,
	0x4568: 0xFFFD,
	0x4569: 0xFFFD,
	0x456A: 0xFFFD,
	0x456B: 0xFFFD,
	0x456C: 0xFFFD,
	0x456D: 0xFFFD,
	0x456E: 0xFFFD,
	0x456F: 0xFFFD,
	0x4570: 0xFFFD,
	0x4571: 0xFFFD,
	0x4572: 0xFFFD,
	0x4573: 0xFFFD,
	0x4574: 0xFFFD,
	0x4575: 0xFFFD,
	0x4576: 0xFFFD,
	0x4577: 0xFFFD,
	0x4578: 0xFFFD,
	0x4579: 0xFFFD,
	0x457A: 0xFFFD,
	0x457B: 0xFFFD,
	0x457C: 0xFFFD,
	0x457D: 0xFFFD,
	0x457E: 0xFFFD,
	0x457F: 0xFFFD,
	0x4580: 0xFFFD,
	0x4581: 0xFFFD,
	0x4582: 0xFFFD,
	0x4583: 0xFFFD,
	0x4584: 0xFFFD,
	0x4585: 0xFFFD,
	0x4586: 0xFFFD,
	0x4587: 0xFFFD,
	0x4588: 0xFFFD,
	0x4589: 0xFFFD,
	0x458A: 0xFFFD,
	0x458B: 0xFFFD,
	0x458C: 0xFFFD,
	0x458D: 0xFFFD,
	0x458E: 0xFFFD,
	0x458F: 0xFFFD,
	0x4590: 0xFFFD,
	0x4591: 0xFFFD,
	0x4592: 0xFFFD,
	0x4593: 0xFFFD,
	0x4594: 0xFFFD,
	0x4595: 0xFFFD,
	0x4596: 0xFFFD,
	0x4597: 0xFFFD,
	0x4598: 0xFFFD,
	0x4599: 0xFFFD,
	0x459A: 0xFFFD,
	0x459B: 0xFFFD,
	0x459C: 0xFFFD,
	0x459D: 0xFFFD,
	0x459E: 0xFFFD,
	0x459F: 0xFFFD,
	0x45A0: 0xFFFD,
	0x45A1: 0xFFFD,
	0x45A2: 0xFFFD,
	0x45A3: 0xFFFD,
	0x45A4: 0xFFFD,
	0x45A5: 0xFFFD,
	0x45A6: 0xFFFD,
	0x45A7: 0xFFFD,
	0x45A8: 0xFFFD,
	0x45A9: 0xFFFD,
	0x45AA: 0xFFFD,
	0x45AB: 0xFFFD,
	0x45AC: 0xFFFD,
	0x45AD: 0xFFFD,
	0x45AE: 0xFFFD,
	0x45AF: 0xFFFD,
	0x45B0: 0xFFFD,
	0x45B1: 0xFFFD,
	0x45B2: 0xFFFD,
	0x45B3: 0xFFFD,
	0x45B4: 0xFFFD,
	0x45B5: 0xFFFD,
	0x45B6: 0xFFFD,
	0x45B7: 0xFFFD,
	0x45B8: 0xFFFD,
	0x45B9: 0xFFFD,
	0x45BA: 0xFFFD,
	0x45BB: 0xFFFD,
	0x45BC: 0xFFFD,
	0x45BD: 0xFFFD,
	0x45BE: 0xFFFD,
	0x45BF: 0xFFFD,
	0x45C0: 0xFFFD,
	0x45C1: 0xFFFD,
	0x45C2: 0xFFFD,
	0x45C3: 0xFFFD,
	0x45C4: 0xFFFD,
	0x45C5: 0xFFFD,
	0x45C6: 0xFFFD,
	0x45C7: 0xFFFD,
	0x45C8: 0xFFFD,
	0x45C9: 0xFFFD,
	0x45CA: 0xFFFD,
	0x45CB: 0xFFFD,
	0x45CC: 0xFFFD,
	0x45CD: 0xFFFD,
	0x45CE: 0xFFFD,
	0x45CF: 0xFFFD,
	0x45D0: 0xFFFD,
	0x45D1: 0xFFFD,
	0x45D2: 0xFFFD,
	0x45D3: 0xFFFD,
	0x45D4: 0xFFFD,
	0x45D5: 0xFFFD,
	0x45D6: 0xFFFD,
	0x45D7: 0xFFFD,
	0x45D8: 0xFFFD,
	0x45D9: 0xFFFD,
	0x45DA: 0xFFFD,
	0x45DB: 0xFFFD,
	0x45DC: 0xFFFD,
	0x45DD: 0xFFFD,
	0x45DE: 0xFFFD,
	0x45DF: 0xFFFD,
	0x45E0: 0xFFFD,
	0x45E1: 0xFFFD,
	0x45E2: 0xFFFD,
	0x45E3: 0xFFFD,
	0x45E4: 0xFFFD,
	0x45E5: 0xFFFD,
	0x45E6: 0xFFFD,
	0x45E7: 0xFFFD,
	0x45E8: 0xFFFD,
	0x45E9: 0xFFFD,
	0x45EA: 0xFFFD,
	0x45EB: 0xFFFD,
	0x45EC: 0xFFFD,
	0x45ED: 0xFFFD,
	0x45EE: 0xFFFD,
	0x45EF: 0xFFFD,
	0x45F0: 0xFFFD,
	0x45F1: 0xFFFD,
	0x45F2: 0xFFFD,
	0x45F3: 0xFFFD,
	0x45F4: 0xFFFD,
	0x45F5: 0xFFFD,
	0x45F6: 0xFFFD,
	0x45F7: 0xFFFD,
	0x45F8: 0xFFFD,
	0x45F9: 0xFFFD,
	0x45FA: 0xFFFD,
	0x45FB: 0xFFFD,
	0x45FC: 0xFFFD,
	0x45FD: 0xFFFD,
	0x45FE: 0xFFFD,
	0x45FF: 0xFFFD,
	0x4600: 0xFFFD,
	0x4601: 0xFFFD,
	0x4602: 0xFFFD,
	0x4603: 0xFFFD,
	0x4604: 0xFFFD,
	0x4605: 0xFFFD,
	0x4606: 0xFFFD,
	0x4607: 0xFFFD,
	0x4608: 0xFFFD,
	0x4609: 0xFFFD,
	0x460A: 0xFFFD,
	0x460B: 0xFFFD,
	0x460C: 0xFFFD,
	0x460D: 0xFFFD,
	0x460E: 0xFFFD,
	0x460F: 0xFBB0,
	0x4610: 0xFFFD,
	0x4611: 0xFFFD,
	0x4612: 0xFFFD,
	0x4613: 0xFFFD,
	0x4614: 0xFFFD,
	0x4615: 0xFFFD,
	0x4616: 0xFFFD,
	0x4617: 0xFFFD,
	0x4618: 0xFFFD,
	0x4619: 0xFFFD,
	0x461A: 0xFFFD,
	0x461B: 0xFFFD,
	0x461C: 0xFFFD,
	0x461D: 0xFFFD,
	0x461E: 0xFFFD,
	0x461F: 0xFFFD,
	0x4620: 0xFFFD,
	0x4621: 0xFFFD,
	0x4622: 0xFFFD,
	0x4623: 0xFFFD,
	0x4624: 0xFFFD,
	0x4625: 0xFFFD,
	0x4626: 0xFFFD,
	0x4627: 0xFFFD,
	0x4628: 0xFFFD,
	0x4629: 0xFFFD,
	0x462A: 0xFFFD,
	0x462B: 0xFFFD,
	0x462C: 0xFFFD,
	0x462D: 0xFFFD,
	0x462E: 0xFFFD,
	0x462F: 0xFFFD,
	0x4630: 0xFFFD,
	0x4631: 0xFFFD,
	0x4632: 0xFFFD,
	0x4633: 0xFFFD,
	0x4634: 0xFFFD,
	0x4635: 0xFFFD,
	0x4636: 0xFFFD,
	0x4637: 0xFFFD,
	0x4638: 0xFFFD,
	0x4639: 0xFFFD,
	0x463A: 0xFFFD,
	0x463B: 0xFFFD,
	0x463C: 0xFFFD,
	0x463D: 0xFFFD,
	0x463E: 0xFFFD,
	0x463F: 0xFFFD,
	0x4640: 0xFFFD,
	0x4641: 0xFFFD,
	0x4642: 0xFFFD,
	0x4643: 0xFFFD,
	0x4644: 0xFFFD,
	0x4645: 0xFFFD,
	0x4646: 0xFFFD,
	0x4647: 0xFFFD,
	0x4648: 0xFFFD,
	0x4649: 0xFFFD,
	0x464A: 0xFFFD,
	0x464B: 0xFFFD,
	0x464C: 0xFFFD,
	0x464D: 0xFFFD,
	0x464E: 0xFFFD,
	0x464F: 0xFFFD,
	0x4650: 0xFFFD,
	0x4651: 0xFFFD,
	0x4652: 0xFFFD,
	0x4653: 0xFFFD,
	0x4654: 0xFFFD,
	0x4655: 0xFFFD,
	0x4656: 0xFFFD,
	0x4657: 0xFFFD,
	0x4658: 0xFFFD,
	0x4659: 0xFFFD,
	0x465A: 0xFFFD,
	0x465B: 0xFFFD,
	0x465C: 0xFFFD,
	0x465D: 0xFFFD,
	0x465E: 0xFFFD,
	0x465F: 0xFFFD,
	0x4660: 0xFFFD,
	0x4661: 0xFFFD,
	0x4662: 0xFFFD,
	0x4663: 0xFFFD,
	0x4664: 0xFFFD,
	0x4665: 0xFFFD,
	0x4666: 0xFFFD,
	0x4667: 0xFFFD,
	0x4668: 0xFFFD,
	0x4669: 0xFFFD,
	0x466A: 0xFFFD,
	0x466B: 0xFFFD,
	0x466C: 0xFFFD,
	0x466D: 0xFFFD,
	0x466E: 0xFFFD,
	0x466F: 0xFFFD,
	0x4670: 0xFFFD,
	0x4671: 0xFFFD,
	0x4672: 0xFFFD,
	0x4673: 0xFFFD,
	0x4674: 0xFFFD,
	0x4675: 0xFFFD,
	0x4676: 0xFFFD,
	0x4677: 0xFFFD,
	0x4678: 0xFFFD,
	0x4679: 0xFFFD,
	0x467A: 0xFFFD,
	0x467B: 0xFFFD,
	0x467C: 0xFFFD,
	0x467D: 0xFFFD,
	0x467E: 0xFFFD,
	0x467F: 0xFFFD,
	0x4680: 0xFFFD,
	0x4681: 0xFFFD,
	0x4682: 0xFFFD,
	0x4683: 0xFFFD,
	0x4684: 0xFFFD,
	0x4685: 0xFFFD,
	0x4686: 0xFFFD,
	0x4687: 0xFFFD,
	0x4688: 0xFFFD,
	0x4689: 0xFFFD,
	0x468A: 0xFFFD,
	0x468B: 0xFFFD,
	0x468C: 0xFFFD,
	0x468D: 0xFFFD,
	0x468E: 0xFFFD,
	0x468F: 0xFFFD,
	0x4690: 0xFFFD,
	0x4691: 0xFFFD,
	0x4692: 0xFFFD,
	0x4693: 0xFFFD,
	0x4694: 0xFFFD,
	0x4695: 0xFFFD,
	0x4696: 0xFFFD,
	0x4697: 0xFFFD,
	0x4698: 0xFFFD,
	0x4699: 0xFFFD,
	0x469A: 0xFFFD,
	0x469B: 0xFFFD,
	0x469C: 0xFFFD,
	0x469D: 0xFFFD,
	0x469E: 0xFFFD,
	0x469F: 0xFFFD,
	0x46A0: 0xFFFD,
	0x46A1: 0xFFFD,
	0x46A2: 0xFFFD,
	0x46A3: 0xFFFD,
	0x46A4: 0xFFFD,
	0x46A5: 0xFFFD,
	0x46A6: 0xFFFD,
	0x46A7: 0xFFFD,
	0x46A8: 0xFFFD,
	0x46A9: 0xFFFD,
	0x46AA: 0xFFFD,
	0x46AB: 0xFFFD,
	0x46AC: 0xFFFD,
	0x46AD: 0xFFFD,
	0x46AE: 0xFFFD,
	0x46AF: 0xFFFD,
	0x46B0: 0xFFFD,
	0x46B1: 0xFFFD,
	0x46B2: 0xFFFD,
	0x46B3: 0xFFFD,
	0x46B4: 0xFFFD,
	0x46B5: 0xFFFD,
	0x46B6: 0xFFFD,
	0x46B7: 0xFFFD,
	0x46B8: 0xFFFD,
	0x46B9: 0xFFFD,
	0x46BA: 0xFFFD,
	0x46BB: 0xFFFD,
	0x46BC: 0xFFFD,
	0x46BD: 0xFFFD,
	0x46BE: 0xFFFD,
	0x46BF: 0xFFFD,
	0x46C0: 0xFFFD,
	0x46C1: 0xFFFD,
	0x46C2: 0xFFFD,
	0x46C3: 0xFFFD,
	0x46C4: 0xFFFD,
	0x46C5: 0xFFFD,
	0x46C6: 0xFFFD,
	0x46C7: 0xFFFD,
	0x46C8: 0xFFFD,
	0x46C9: 0xFFFD,
	0x46CA: 0xFFFD,
	0x46CB: 0xFFFD,
	0x46CC: 0xFFFD,
	0x46CD: 0xFFFD,
	0x46CE: 0xFFFD,
	0x46CF: 0xFFFD,
	0x46D0: 0xFFFD,
	0x46D1: 0xFFFD,
	0x46D2: 0xFFFD,
	0x46D3: 0xFFFD,
	0x46D4: 0xFFFD,
	0x46D5: 0xFFFD,
	0x46D6: 0xFFFD,
	0x46D7: 0xFFFD,
	0x46D8: 0xFFFD,
	0x46D9: 0xFFFD,
	0x46DA: 0xFFFD,
	0x46DB: 0xFFFD,
	0x46DC: 0xFFFD,
	0x46DD: 0xFFFD,
	0x46DE: 0xFFFD,
	0x46DF: 0xFFFD,
	0x46E0: 0xFFFD,
	0x46E1: 0xFFFD,
	0x46E2: 0xFFFD,
	0x46E3: 0xFFFD,
	0x46E4: 0xFFFD,
	0x46E5: 0xFFFD,
	0x46E6: 0xFFFD,
	0x46E7: 0xFFFD,
	0x46E8: 0xFFFD,
	0x46E9: 0xFFFD,
	0x46EA: 0xFFFD,
	0x46EB: 0xFFFD,
	0x46EC: 0xFFFD,
	0x46ED: 0xFFFD,
	0x46EE: 0xFFFD,
	0x46EF: 0xFFFD,
	0x46F0: 0xFFFD,
	0x46F1: 0xFFFD,
	0x46F2: 0xFFFD,
	0x46F3: 0xFFFD,
	0x46F4: 0xFFFD,
	0x46F5: 0xFFFD,
	0x46F6: 0xFFFD,
	0x46F7: 0xFFFD,
	0x46F8: 0xFFFD,
	0x46F9: 0xFFFD,
	0x46FA: 0xFFFD,
	0x46FB: 0xFFFD,
	0x46FC: 0xFFFD,
	0x46FD: 0xFFFD,
	0x46FE: 0xFFFD,
	0x46FF: 0xFFFD,
	0x4700: 0xFFFD,
	0x4701: 0xFFFD,
	0x4702: 0xFFFD,
	0x4703: 0xFFFD,
	0x4704: 0xFFFD,
	0x4705: 0xFFFD,
	0x4706: 0xFFFD,
	0x4707: 0xFFFD,
	0x4708: 0xFFFD,
	0x4709: 0xFFFD,
	0x470A: 0xFFFD,
	0x470B: 0xFFFD,
	0x470C: 0xFFFD,
	0x470D: 0xFFFD,
	0x470E: 0xFFFD,
	0x470F: 0xFFFD,
	0x4710: 0xFFFD,
	0x4711: 0xFFFD,
	0x4712: 0xFFFD,
	0x4713: 0xFFFD,
	0x4714: 0xFFFD,
	0x4715: 0xFFFD,
	0x4716: 0xFFFD,
	0x4717: 0xFFFD,
	0x4718: 0xFFFD,
	0x4719: 0xFFFD,
	0x471A: 0xFFFD,
	0x471B: 0xFFFD,
	0x471C: 0xFFFD,
	0x471D: 0xFFFD,
	0x471E: 0xFFFD,
	0x471F: 0xFFFD,
	0x4720: 0xFFFD,
	0x4721: 0xFFFD,
	0x4722: 0xFFFD,
	0x4723: 0xFFFD,
	0x4724: 0xFFFD,
	0x4725: 0xFFFD,
	0x4726: 0xFFFD,
	0x4727: 0xFFFD,
	0x4728: 0xFFFD,
	0x4729: 0xFFFD,
	0x472A: 0xFFFD,
	0x472B: 0xFFFD,
	0x472C: 0xFFFD,
	0x472D: 0xFFFD,
	0x472E: 0xFFFD,
	0x472F: 0xFFFD,
	0x4730: 0xFFFD,
	0x4731: 0xFFFD,
	0x4732: 0xFFFD,
	0x4733: 0xFFFD,
	0x4734: 0xFFFD,
	0x4735: 0xFFFD,
	0x4736: 0xFFFD,
	0x4737: 0xFFFD,
	0x4738: 0xFFFD,
	0x4739: 0xFFFD,
	0x473A: 0xFFFD,
	0x473B: 0xFFFD,
	0x473C: 0xFFFD,
	0x473D: 0xFFFD,
	0x473E: 0xFFFD,
	0x473F: 0xFFFD,
	0x4740: 0xFFFD,
	0x4741: 0xFFFD,
	0x4742: 0xFFFD,
	0x4743: 0xFFFD,
	0x4744: 0xFFFD,
	0x4745: 0xFFFD,
	0x4746: 0xFFFD,
	0x4747: 0xFFFD,
	0x4748: 0xFFFD,
	0x4749: 0xFFFD,
	0x474A: 0xFFFD,
	0x474B: 0xFFFD,
	0x474C: 0xFFFD,
	0x474D: 0xFFFD,
	0x474E: 0xFFFD,
	0x474F: 0xFFFD,
	0x4750: 0xFFFD,
	0x4751: 0xFFFD,
	0x4752: 0xFFFD,
	0x4753: 0xFFFD,
	0x4754: 0xFFFD,
	0x4755: 0xFFFD,
	0x4756: 0xFFFD,
	0x4757: 0xFFFD,
	0x4758: 0xFFFD,
	0x4759: 0xFFFD,
	0x475A: 0xFFFD,
	0x475B: 0xFFFD,
	0x475C: 0xFFFD,
	0x475D: 0xFFFD,
	0x475E: 0xFFFD,
	0x475F: 0xFFFD,
	0x4760: 0xFFFD,
	0x4761: 0xFFFD,
	0x4762: 0xFFFD,
	0x4763: 0xFFFD,
	0x4764: 0xFFFD,
	0x4765: 0xFFFD,
	0x4766: 0xFFFD,
	0x4767: 0xFFFD,
	0x4768: 0xFFFD,
	0x4769: 0xFFFD,
	0x476A: 0xFFFD,
	0x476B: 0xFFFD,
	0x476C: 0xFFFD,
	0x476D: 0xFFFD,
	0x476E: 0xFFFD,
	0x476F: 0xFFFD,
	0x4770: 0xFFFD,
	0x4771: 0xFFFD,
	0x4772: 0xFFFD,
	0x4773: 0xFFFD,
	0x4774: 0xFFFD,
	0x4775: 0xFFFD,
	0x4776: 0xFFFD,
	0x4777: 0xFFFD,
	0x4778: 0xFFFD,
	0x4779: 0xFFFD,
	0x477A: 0xFFFD,
	0x477B: 0xFFFD,
	0x477C: 0xFFFD,
	0x477D: 0xFFFD,
	0x477E: 0xFFFD,
	0x477F: 0xFFFD,
	0x4780: 0xFFFD,
	0x4781: 0xFFFD,
	0x4782: 0xFFFD,
	0x4783: 0xFFFD,
	0x4784: 0xFFFD,
	0x4785: 0xFFFD,
	0x4786: 0xFFFD,
	0x4787: 0xFFFD,
	0x4788: 0xFFFD,
	0x4789: 0xFFFD,
	0x478A: 0xFFFD,
	0x478B: 0xFFFD,
	0x478C: 0xFFFD,
	0x478D: 0xFFFD,
	0x478E: 0xFFFD,
	0x478F: 0xFFFD,
	0x4790: 0xFFFD,
	0x4791: 0xFFFD,
	0x4792: 0xFFFD,
	0x4793: 0xFFFD,
	0x4794: 0xFFFD,
	0x4795: 0xFFFD,
	0x4796: 0xFFFD,
	0x4797: 0xFFFD,
	0x4798: 0xFFFD,
	0x4799: 0xFFFD,
	0x479A: 0xFFFD,
	0x479B: 0xFFFD,
	0x479C: 0xFFFD,
	0x479D: 0xFFFD,
	0x479E: 0xFFFD,
	0x479F: 0xFFFD,
	0x47A0: 0xFFFD,
	0x47A1: 0xFFFD,
	0x47A2: 0xFFFD,
	0x47A3: 0xFFFD,
	0x47A4: 0xFFFD,
	0x47A5: 0xFFFD,
	0x47A6: 0xFFFD,
	0x47A7: 0xFFFD,
	0x47A8: 0xFFFD,
	0x47A9: 0xFFFD,
	0x47AA: 0xFFFD,
	0x47AB: 0xFFFD,
	0x47AC: 0xFFFD,
	0x47AD: 0xFFFD,
	0x47AE: 0xFFFD,
	0x47AF: 0xFFFD,
	0x47B0: 0xFFFD,
	0x47B1: 0xFFFD,
	0x47B2: 0xFFFD,
	0x47B3: 0xFFFD,
	0x47B4: 0xFFFD,
	0x47B5: 0xFFFD,
	0x47B6: 0xFFFD,
	0x47B7: 0xFFFD,
	0x47B8: 0xFFFD,
	0x47B9: 0xFFFD,
	0x47BA: 0xFFFD,
	0x47BB: 0xFFFD,
	0x47BC: 0xFFFD,
	0x47BD: 0xFFFD,
	0x47BE: 0xFFFD,
	0x47BF: 0xFFFD,
	0x47C0: 0xFFFD,
	0x47C1: 0xFFFD,
	0x47C2: 0xFFFD,
	0x47C3: 0xFFFD,
	0x47C4: 0xFFFD,
	0x47C5: 0xFFFD,
	0x47C6: 0xFFFD,
	0x47C7: 0xFFFD,
	0x47C8: 0xFFFD,
	0x47C9: 0xFFFD,
	0x47CA: 0xFFFD,
	0x47CB: 0xFFFD,
	0x47CC: 0xFFFD,
	0x47CD: 0xFFFD,
	0x47CE: 0xFFFD,
	0x47CF: 0xFFFD,
	0x47D0: 0xFFFD,
	0x47D1: 0xFFFD,
	0x47D2: 0xFFFD,
	0x47D3: 0xFFFD,
	0x47D4: 0xFFFD,
	0x47D5: 0xFFFD,
	0x47D6: 0xFFFD,
	0x47D7: 0xFFFD,
	0x47D8: 0xFFFD,
	0x47D9: 0xFFFD,
	0x47DA: 0xFFFD,
	0x47DB: 0xFFFD,
	0x47DC: 0xFFFD,
	0x47DD: 0xFFFD,
	0x47DE: 0xFFFD,
	0x47DF: 0xFFFD,
	0x47E0: 0xFFFD,
	0x47E1: 0xFFFD,
	0x47E2: 0xFFFD,
	0x47E3: 0xFFFD,
	0x47E4: 0xFFFD,
	0x47E5: 0xFFFD,
	0x47E6: 0xFFFD,
	0x47E7: 0xFFFD,
	0x47E8: 0xFFFD,
	0x47E9: 0xFFFD,
	0x47EA: 0xFFFD,
	0x47EB: 0xFFFD,
	0x47EC: 0xFFFD,
	0x47ED: 0xFFFD,
	0x47EE: 0xFFFD,
	0x47EF: 0xFFFD,
	0x47F0: 0xFFFD,
	0x47F1: 0xFFFD,
	0x47F2: 0xFFFD,
	0x47F3: 0xFFFD,
	0x47F4: 0xFFFD,
	0x47F5: 0xFFFD,
	0x47F6: 0xFFFD,
	0x47F7: 0xFFFD,
	0x47F8: 0xFFFD,
	0x47F9: 0xFFFD,
	0x47FA: 0xFFFD,
	0x47FB: 0xFFFD,
	0x47FC: 0xFFFD,
	0x47FD: 0xFFFD,
	0x47FE: 0xFFFD,
	0x47FF: 0xFFFD,
	0x4800: 0xFFFD,
	0x4801: 0xFFFD,
	0x4802: 0xFFFD,
	0x4803: 0xFFFD,
	0x4804: 0xFFFD,
	0x4805: 0xFFFD,
	0x4806: 0xFFFD,
	0x4807: 0xFFFD,
	0x4808: 0xFFFD,
	0x4809: 0xFFFD,
	0x480A: 0xFFFD,
	0x480B: 0xFFFD,
	0x480C: 0xFFFD,
	0x480D: 0xFFFD,
	0x480E: 0xFFFD,
	0x480F: 0xFFFD,
	0x4810: 0xFFFD,
	0x4811: 0xFFFD,
	0x4812: 0xFFFD,
	0x4813: 0xFFFD,
	0x4814: 0xFFFD,
	0x4815: 0xFFFD,
	0x4816: 0xFFFD,
	0x4817: 0xFFFD,
	0x4818: 0xFFFD,
	0x4819: 0xFFFD,
	0x481A: 0xFFFD,
	0x481B: 0xFFFD,
	0x481C: 0xFFFD,
	0x481D: 0xFFFD,
	0x481E: 0xFFFD,
	0x481F: 0xFFFD,
	0x4820: 0xFFFD,
	0x4821: 0xFFFD,
	0x4822: 0xFFFD,
	0x4823: 0xFFFD,
	0x4824: 0xFFFD,
	0x4825: 0xFFFD,
	0x4826: 0xFFFD,
	0x4827: 0xFFFD,
	0x4828: 0xFFFD,
	0x4829: 0xFFFD,
	0x482A: 0xFFFD,
	0x482B: 0xFFFD,
	0x482C: 0xFFFD,
	0x482D: 0xFFFD,
	0x482E: 0xFFFD,
	0x482F: 0xFFFD,
	0x4830: 0xFFFD,
	0x4831: 0xFFFD,
	0x4832: 0xFFFD,
	0x4833: 0xFFFD,
	0x4834: 0xFFFD,
	0x4835: 0xFFFD,
	0x4836: 0xFFFD,
	0x4837: 0xFFFD,
	0x4838: 0xFFFD,
	0x4839: 0xFFFD,
	0x483A: 0xFFFD,
	0x483B: 0xFFFD,
	0x483C: 0xFFFD,
	0x483D: 0xFFFD,
	0x483E: 0xFFFD,
	0x483F: 0xFFFD,
	0x4840: 0xFFFD,
	0x4841: 0xFFFD,
	0x4842: 0xFFFD,
	0x4843: 0xFFFD,
	0x4844: 0xFFFD,
	0x4845: 0xFFFD,
	0x4846: 0xFFFD,
	0x4847: 0xFFFD,
	0x4848: 0xFFFD,
	0x4849: 0xFFFD,
	0x484A: 0xFFFD,
	0x484B: 0xFFFD,
	0x484C: 0xFFFD,
	0x484D: 0xFFFD,
	0x484E: 0xFFFD,
	0x484F: 0xFFFD,
	0x4850: 0xFFFD,
	0x4851: 0xFFFD,
	0x4852: 0xFFFD,
	0x4853: 0xFFFD,
	0x4854: 0xFFFD,
	0x4855: 0xFFFD,
	0x4856: 0xFFFD,
	0x4857: 0xFFFD,
	0x4858: 0xFFFD,
	0x4859: 0xFFFD,
	0x485A: 0xFFFD,
	0x485B: 0xFFFD,
	0x485C: 0xFFFD,
	0x485D: 0xFFFD,
	0x485E: 0xFFFD,
	0x485F: 0xFFFD,
	0x4860: 0xFFFD,
	0x4861: 0xFFFD,
	0x4862: 0xFFFD,
	0x4863: 0xFFFD,
	0x4864: 0xFFFD,
	0x4865: 0xFFFD,
	0x4866: 0xFFFD,
	0x4867: 0xFFFD,
	0x4868: 0xFFFD,
	0x4869: 0xFFFD,
	0x486A: 0xFFFD,
	0x486B: 0xFFFD,
	0x486C: 0xFFFD,
	0x486D: 0xFFFD,
	0x486E: 0xFFFD,
	0x486F: 0xFFFD,
	0x4870: 0xFFFD,
	0x4871: 0xFFFD,
	0x4872: 0xFFFD,
	0x4873: 0xFFFD,
	0x4874: 0xFFFD,
	0x4875: 0xFFFD,
	0x4876: 0xFFFD,
	0x4877: 0xFFFD,
	0x4878: 0xFFFD,
	0x4879: 0xFFFD,
	0x487A: 0xFFFD,
	0x487B: 0xFFFD,
	0x487C: 0xFFFD,
	0x487D: 0xFFFD,
	0x487E: 0xFFFD,
	0x487F: 0xFFFD,
	0x4880: 0xFFFD,
	0x4881: 0xFFFD,
	0x4882: 0xFFFD,
	0x4883: 0xFFFD,
	0x4884: 0xFFFD,
	0x4885: 0xFFFD,
	0x4886: 0xFFFD,
	0x4887: 0xFFFD,
	0x4888: 0xFFFD,
	0x4889: 0xFFFD,
	0x488A: 0xFFFD,
	0x488B: 0xFFFD,
	0x488C: 0xFFFD,
	0x488D: 0xFFFD,
	0x488E: 0xFFFD,
	0x488F: 0xFFFD,
	0x4890: 0xFFFD,
	0x4891: 0xFFFD,
	0x4892: 0xFFFD,
	0x4893: 0xFFFD,
	0x4894: 0xFFFD,
	0x4895: 0xFFFD,
	0x4896: 0xFFFD,
	0x4897: 0xFFFD,
	0x4898: 0xFFFD,
	0x4899: 0xFFFD,
	0x489A: 0xFFFD,
	0x489B: 0xFFFD,
	0x489C: 0xFFFD,
	0x489D: 0xFFFD,
	0x489E: 0xFFFD,
	0x489F: 0xFFFD,
	0x48A0: 0xFFFD,
	0x48A1: 0xFFFD,
	0x48A2: 0xFFFD,
	0x48A3: 0xFFFD,
	0x48A4: 0xFFFD,
	0x48A5: 0xFFFD,
	0x48A6: 0xFFFD,
	0x48A7: 0xFFFD,
	0x48A8: 0xFFFD,
	0x48A9: 0xFFFD,
	0x48AA: 0xFFFD,
	0x48AB: 0xFFFD,
	0x48AC: 0xFFFD,
	0x48AD: 0xFFFD,
	0x48AE: 0xFFFD,
	0x48AF: 0xFFFD,
	0x48B0: 0xFFFD,
	0x48B1: 0xFFFD,
	0x48B2: 0xFFFD,
	0x48B3: 0xFFFD,
	0x48B4: 0xFFFD,
	0x48B5: 0xFFFD,
	0x48B6: 0xFFFD,
	0x48B7: 0xFFFD,
	0x48B8: 0xFFFD,
	0x48B9: 0xFFFD,
	0x48BA: 0xFFFD,
	0x48BB: 0xFFFD,
	0x48BC: 0xFFFD,
	0x48BD: 0xFFFD,
	0x48BE: 0xFFFD,
	0x48BF: 0xFFFD,
	0x48C0: 0xFFFD,
	0x48C1: 0xFFFD,
	0x48C2: 0xFFFD,
	0x48C3: 0xFFFD,
	0x48C4: 0xFFFD,
	0x48C5: 0xFFFD,
	0x48C6: 0xFFFD,
	0x48C7: 0xFFFD,
	0x48C8: 0xFFFD,
	0x48C9: 0xFFFD,
	0x48CA: 0xFFFD,
	0x48CB: 0xFFFD,
	0x48CC: 0xFFFD,
	0x48CD: 0xFFFD,
	0x48CE: 0xFFFD,
	0x48CF: 0xFFFD,
	0x48D0: 0xFFFD,
	0x48D1: 0xFFFD,
	0x48D2: 0xFFFD,
	0x48D3: 0xFFFD,
	0x48D4: 0xFFFD,
	0x48D5: 0xFFFD,
	0x48D6: 0xFFFD,
	0x48D7: 0xFFFD,
	0x48D8: 0xFFFD,
	0x48D9: 0xFFFD,
	0x48DA: 0xFFFD,
	0x48DB: 0xFFFD,
	0x48DC: 0xFFFD,
	0x48DD: 0xFFFD,
	0x48DE: 0xFFFD,
	0x48DF: 0xFFFD,
	0x48E0: 0xFFFD,
	0x48E1: 0xFFFD,
	0x48E2: 0xFFFD,
	0x48E3: 0xFFFD,
	0x48E4: 0xFFFD,
	0x48E5: 0xFFFD,
	0x48E6: 0xFFFD,
	0x48E7: 0xFFFD,
	0x48E8: 0xFFFD,
	0x48E9: 0xFFFD,
	0x48EA: 0xFFFD,
	0x48EB: 0xFFFD,
	0x48EC: 0xFFFD,
	0x48ED: 0xFFFD,
	0x48EE: 0xFFFD,
	0x48EF: 0xFFFD,
	0x48F0: 0xFFFD,
	0x48F1: 0xFFFD,
	0x48F2: 0xFFFD,
	0x48F3: 0xFFFD,
	0x48F4: 0xFFFD,
	0x48F5: 0xFFFD,
	0x48F6: 0xFFFD,
	0x48F7: 0xFFFD,
	0x48F8: 0xFFFD,
	0x48F9: 0xFFFD,
	0x48FA: 0xFFFD,
	0x48FB: 0xFFFD,
	0x48FC: 0xFFFD,
	0x48FD: 0xFFFD,
	0x48FE: 0xFFFD,
	0x48FF: 0xFFFD,
	0x4900: 0xFFFD,
	0x4901: 0xFFFD,
	0x4902: 0xFFFD,
	0x4903: 0xFFFD,
	0x4904: 0xFFFD,
	0x4905: 0xFFFD,
	0x4906: 0xFFFD,
	0x4907: 0xFFFD,
	0x4908: 0xFFFD,
	0x4909: 0xFFFD,
	0x490A: 0xFFFD,
	0x490B: 0xFFFD,
	0x490C: 0xFFFD,
	0x490D: 0xFFFD,
	0x490E: 0xFFFD,
	0x490F: 0xFFFD,
	0x4910: 0xFFFD,
	0x4911: 0xFFFD,
	0x4912: 0xFFFD,
	0x4913: 0xFFFD,
	0x4914: 0xFFFD,
	0x4915: 0xFFFD,
	0x4916: 0xFFFD,
	0x4917: 0xFFFD,
	0x4918: 0xFFFD,
	0x4919: 0xFFFD,
	0x491A: 0xFFFD,
	0x491B: 0xFFFD,
	0x491C: 0xFFFD,
	0x491D: 0xFFFD,
	0x491E: 0xFFFD,
	0x491F: 0xFFFD,
	0x4920: 0xFFFD,
	0x4921: 0xFFFD,
	0x4922: 0xFFFD,
	0x4923: 0xFFFD,
	0x4924: 0xFFFD,
	0x4925: 0xFFFD,
	0x4926: 0xFFFD,
	0x4927: 0xFFFD,
	0x4928: 0xFFFD,
	0x4929: 0xFFFD,
	0x492A: 0xFFFD,
	0x492B: 0xFFFD,
	0x492C: 0xFFFD,
	0x492D: 0xFFFD,
	0x492E: 0xFFFD,
	0x492F: 0xFFFD,
	0x4930: 0xFFFD,
	0x4931: 0xFFFD,
	0x4932: 0xFFFD,
	0x4933: 0xFFFD,
	0x4934: 0xFFFD,
	0x4935: 0xFFFD,
	0x4936: 0xFFFD,
	0x4937: 0xFFFD,
	0x4938: 0xFFFD,
	0x4939: 0xFFFD,
	0x493A: 0xFFFD,
	0x493B: 0xFFFD,
	0x493C: 0xFFFD,
	0x493D: 0xFFFD,
	0x493E: 0xFFFD,
	0x493F: 0xFFFD,
	0x4940: 0xFFFD,
	0x4941: 0xFFFD,
	0x4942: 0xFFFD,
	0x4943: 0xFFFD,
	0x4944: 0xFFFD,
	0x4945: 0xFFFD,
	0x4946: 0xFFFD,
	0x4947: 0xFFFD,
	0x4948: 0xFFFD,
	0x4949: 0xFFFD,
	0x494A: 0xFFFD,
	0x494B: 0xFFFD,
	0x494C: 0xFFFD,
	0x494D: 0xFFFD,
	0x494E: 0xFFFD,
	0x494F: 0xFFFD,
	0x4950: 0xFFFD,
	0x4951: 0xFFFD,
	0x4952: 0xFFFD,
	0x4953: 0xFFFD,
	0x4954: 0xFFFD,
	0x4955: 0xFFFD,
	0x4956: 0xFFFD,
	0x4957: 0xFFFD,
	0x4958: 0xFFFD,
	0x4959: 0xFFFD,
	0x495A: 0xFFFD,
	0x495B: 0xFFFD,
	0x495C: 0xFFFD,
	0x495D: 0xFFFD,
	0x495E: 0xFFFD,
	0x495F: 0xFFFD,
	0x4960: 0xFFFD,
	0x4961: 0xFFFD,
	0x4962: 0xFFFD,
	0x4963: 0xFFFD,
	0x4964: 0xFFFD,
	0x4965: 0xFFFD,
	0x4966: 0xFFFD,
	0x4967: 0xFFFD,
	0x4968: 0xFFFD,
	0x4969: 0xFFFD,
	0x496A: 0xFFFD,
	0x496B: 0xFFFD,
	0x496C: 0xFFFD,
	0x496D: 0xFFFD,
	0x496E: 0xFFFD,
	0x496F: 0xFFFD,
	0x4970: 0xFFFD,
	0x4971: 0xFFFD,
	0x4972: 0xFFFD,
	0x4973: 0xFFFD,
	0x4974: 0xFFFD,
	0x4975: 0xFFFD,
	0x4976: 0xFFFD,
	0x4977: 0xFFFD,
	0x4978: 0xFFFD,
	0x4979: 0xFFFD,
	0x497A: 0xFFFD,
	0x497B: 0xFFFD,
	0x497C: 0xFFFD,
	0x497D: 0xFFFD,
	0x497E: 0xFFFD,
	0x497F: 0xFFFD,
	0x4980: 0xFFFD,
	0x4981: 0xFFFD,
	0x4982: 0xFFFD,
	0x4983: 0xFFFD,
	0x4984: 0xFFFD,
	0x4985: 0xFFFD,
	0x4986: 0xFFFD,
	0x4987: 0xFFFD,
	0x4988: 0xFFFD,
	0x4989: 0xFB7D,
	0x498A: 0xFFFD,
	0x498B: 0xFFFD,
	0x498C: 0xFFFD,
	0x498D: 0xFFFD,
	0x498E: 0xFFFD,
	0x498F: 0xFFFD,
	0x4990: 0xFFFD,
	0x4991: 0xFFFD,
	0x4992: 0xFFFD,
	0x4993: 0xFFFD,
	0x4994: 0xFFFD,
	0x4995: 0xFFFD,
	0x4996: 0xFFFD,
	0x4997: 0xFFFD,
	0x4998: 0xFFFD,
	0x4999: 0xFFFD,
	0x499A: 0xFFFD,
	0x499B: 0xFFFD,
	0x499C: 0xFFFD,
	0x499D: 0xFFFD,
	0x499E: 0xFFFD,
	0x499F: 0xFFFD,
	0x49A0: 0xFFFD,
	0x49A1: 0xFFFD,
	0x49A2: 0xFFFD,
	0x49A3: 0xFFFD,
	0x49A4: 0xFFFD,
	0x49A5: 0xFFFD,
	0x49A6: 0xFFFD,
	0x49A7: 0xFFFD,
	0x49A8: 0xFFFD,
	0x49A9: 0xFFFD,
	0x49AA: 0xFFFD,
	0x49AB: 0xFFFD,
	0x49AC: 0xFFFD,
	0x49AD: 0xFFFD,
	0x49AE: 0xFFFD,
	0x49AF: 0xFFFD,
	0x49B0: 0xFFFD,
	0x49B1: 0xFFFD,
	0x49B2: 0xFFFD,
	0x49B3: 0xFFFD,
	0x49B4: 0xFFFD,
	0x49B5: 0xFFFD,
	0x49B6: 0xFFFD,
	0x49B7: 0xFFFD,
	0x49B8: 0xFFFD,
	0x49B9: 0xFFFD,
	0x49BA: 0xFFFD,
	0x49BB: 0xFFFD,
	0x49BC: 0xFFFD,
	0x49BD: 0xFFFD,
	0x49BE: 0xFFFD,
	0x49BF: 0xFFFD,
	0x49C0: 0xFFFD,
	0x49C1: 0xFFFD,
	0x49C2: 0xFFFD,
	0x49C3: 0xFFFD,
	0x49C4: 0xFFFD,
	0x49C5: 0xFFFD,
	0x49C6: 0xFFFD,
	0x49C7: 0xFFFD,
	0x49C8: 0xFFFD,
	0x49C9: 0xFFFD,
	0x49CA: 0xFFFD,
	0x49CB: 0xFFFD,
	0x49CC: 0xFFFD,
	0x49CD: 0xFFFD,
	0x49CE: 0xFFFD,
	0x49CF: 0xFFFD,
	0x49D0: 0xFFFD,
	0x49D1: 0xFFFD,
	0x49D2: 0xFFFD,
	0x49D3: 0xFFFD,
	0x49D4: 0xFFFD,
	0x49D5: 0xFFFD,
	0x49D6: 0xFFFD,
	0x49D7: 0xFFFD,
	0x49D8: 0xFFFD,
	0x49D9: 0xFFFD,
	0x49DA: 0xFFFD,
	0x49DB: 0xFFFD,
	0x49DC: 0xFFFD,
	0x49DD: 0xFFFD,
	0x49DE: 0xFFFD,
	0x49DF: 0xFFFD,
	0x49E0: 0xFFFD,
	0x49E1: 0xFFFD,
	0x49E2: 0xFFFD,
	0x49E3: 0xFFFD,
	0x49E4: 0xFFFD,
	0x49E5: 0xFFFD,
	0x49E6: 0xFFFD,
	0x49E7: 0xFFFD,
	0x49E8: 0xFFFD,
	0x49E9: 0xFFFD,
	0x49EA: 0xFFFD,
	0x49EB: 0xFFFD,
	0x49EC: 0xFFFD,
	0x49ED: 0xFFFD,
	0x49EE: 0xFFFD,
	0x49EF: 0xFFFD,
	0x49F0: 0xFFFD,
	0x49F1: 0xFFFD,
	0x49F2: 0xFFFD,
	0x49F3: 0xFFFD,
	0x49F4: 0xFFFD,
	0x49F5: 0xFFFD,
	0x49F6: 0xFFFD,
	0x49F7: 0xFFFD,
	0x49F8: 0xFFFD,
	0x49F9: 0xFFFD,
	0x49FA: 0xFFFD,
	0x49FB: 0xFFFD,
	0x49FC: 0xFFFD,
	0x49FD: 0xFFFD,
	0x49FE: 0xFFFD,
	0x49FF: 0xFFFD,
	0x4A00: 0xFFFD,
	0x4A01: 0xFFFD,
	0x4A02: 0xFFFD,
	0x4A03: 0xFFFD,
	0x4A04: 0xFFFD,
	0x4A05: 0xFFFD,
	0x4A06: 0xFFFD,
	0x4A07: 0xFFFD,
	0x4A08: 0xFFFD,
	0x4A09: 0xFFFD,
	0x4A0A: 0xFFFD,
	0x4A0B: 0xFFFD,
	0x4A0C: 0xFFFD,
	0x4A0D: 0xFFFD,
	0x4A0E: 0xFFFD,
	0x4A0F: 0xFFFD,
	0x4A10: 0xFFFD,
	0x4A11: 0xFFFD,
	0x4A12: 0xFFFD,
	0x4A13: 0xFFFD,
	0x4A14: 0xFFFD,
	0x4A15: 0xFFFD,
	0x4A16: 0xFFFD,
	0x4A17: 0xFFFD,
	0x4A18: 0xFFFD,
	0x4A19: 0xFFFD,
	0x4A1A: 0xFFFD,
	0x4A1B: 0xFFFD,
	0x4A1C: 0xFFFD,
	0x4A1D: 0xFFFD,
	0x4A1E: 0xFFFD,
	0x4A1F: 0xFFFD,
	0x4A20: 0xFFFD,
	0x4A21: 0xFFFD,
	0x4A22: 0xFFFD,
	0x4A23: 0xFFFD,
	0x4A24: 0xFFFD,
	0x4A25: 0xFFFD,
	0x4A26: 0xFFFD,
	0x4A27: 0xFFFD,
	0x4A28: 0xFFFD,
	0x4A29: 0xFFFD,
	0x4A2A: 0xFFFD,
	0x4A2B: 0xFFFD,
	0x4A2C: 0xFFFD,
	0x4A2D: 0xFFFD,
	0x4A2E: 0xFFFD,
	0x4A2F: 0xFFFD,
	0x4A30: 0xFFFD,
	0x4A31: 0xFFFD,
	0x4A32: 0xFFFD,
	0x4A33: 0xFFFD,
	0x4A34: 0xFFFD,
	0x4A35: 0xFFFD,
	0x4A36: 0xFFFD,
	0x4A37: 0xFFFD,
	0x4A38: 0xFFFD,
	0x4A39: 0xFFFD,
	0x4A3A: 0xFFFD,
	0x4A3B: 0xFFFD,
	0x4A3C: 0xFFFD,
	0x4A3D: 0xFFFD,
	0x4A3E: 0xFFFD,
	0x4A3F: 0xFFFD,
	0x4A40: 0xFFFD,
	0x4A41: 0xFFFD,
	0x4A42: 0xFFFD,
	0x4A43: 0xFFFD,
	0x4A44: 0xFFFD,
	0x4A45: 0xFFFD,
	0x4A46: 0xFFFD,
	0x4A47: 0xFFFD,
	0x4A48: 0xFFFD,
	0x4A49: 0xFFFD,
	0x4A4A: 0xFFFD,
	0x4A4B: 0xFFFD,
	0x4A4C: 0xFFFD,
	0x4A4D: 0xFFFD,
	0x4A4E: 0xFFFD,
	0x4A4F: 0xFFFD,
	0x4A50: 0xFFFD,
	0x4A51: 0xFFFD,
	0x4A52: 0xFFFD,
	0x4A53: 0xFFFD,
	0x4A54: 0xFFFD,
	0x4A55: 0xFFFD,
	0x4A56: 0xFFFD,
	0x4A57: 0xFFFD,
	0x4A58: 0xFFFD,
	0x4A59: 0xFFFD,
	0x4A5A: 0xFFFD,
	0x4A5B: 0xFFFD,
	0x4A5C: 0xFFFD,
	0x4A5D: 0xFFFD,
	0x4A5E: 0xFFFD,
	0x4A5F: 0xFFFD,
	0x4A60: 0xFFFD,
	0x4A61: 0xFFFD,
	0x4A62: 0xFFFD,
	0x4A63: 0xFFFD,
	0x4A64: 0xFFFD,
	0x4A65: 0xFFFD,
	0x4A66: 0xFFFD,
	0x4A67: 0xFFFD,
	0x4A68: 0xFFFD,
	0x4A69: 0xFFFD,
	0x4A6A: 0xFFFD,
	0x4A6B: 0xFFFD,
	0x4A6C: 0xFFFD,
	0x4A6D: 0xFFFD,
	0x4A6E: 0xFFFD,
	0x4A6F: 0xFFFD,
	0x4A70: 0xFFFD,
	0x4A71: 0xFFFD,
	0x4A72: 0xFFFD,
	0x4A73: 0xFFFD,
	0x4A74: 0xFFFD,
	0x4A75: 0xFFFD,
	0x4A76: 0xFFFD,
	0x4A77: 0xFFFD,
	0x4A78: 0xFFFD,
	0x4A79: 0xFFFD,
	0x4A7A: 0xFFFD,
	0x4A7B: 0xFFFD,
	0x4A7C: 0xFFFD,
	0x4A7D: 0xFFFD,
	0x4A7E: 0xFFFD,
	0x4A7F: 0xFFFD,
	0x4A80: 0xFFFD,
	0x4A81: 0xFFFD,
	0x4A82: 0xFFFD,
	0x4A83: 0xFFFD,
	0x4A84: 0xFFFD,
	0x4A85: 0xFFFD,
	0x4A86: 0xFFFD,
	0x4A87: 0xFFFD,
	0x4A88: 0xFFFD,
	0x4A89: 0xFFFD,
	0x4A8A: 0xFFFD,
	0x4A8B: 0xFFFD,
	0x4A8C: 0xFFFD,
	0x4A8D: 0xFFFD,
	0x4A8E: 0xFFFD,
	0x4A8F: 0xFFFD,
	0x4A90: 0xFFFD,
	0x4A91: 0xFFFD,
	0x4A92: 0xFFFD,
	0x4A93: 0xFFFD,
	0x4A94: 0xFFFD,
	0x4A95: 0xFFFD,
	0x4A96: 0xFFFD,
	0x4A97: 0xFFFD,
	0x4A98: 0xFFFD,
	0x4A99: 0xFFFD,
	0x4A9A: 0xFFFD,
	0x4A9B: 0xFFFD,
	0x4A9C: 0xFFFD,
	0x4A9D: 0xFFFD,
	0x4A9E: 0xFFFD,
	0x4A9F: 0xFFFD,
	0x4AA0: 0xFFFD,
	0x4AA1: 0xFFFD,
	0x4AA2: 0xFFFD,
	0x4AA3: 0xFFFD,
	0x4AA4: 0xFFFD,
	0x4AA5: 0xFFFD,
	0x4AA6: 0xFFFD,
	0x4AA7: 0xFFFD,
	0x4AA8: 0xFFFD,
	0x4AA9: 0xFFFD,
	0x4AAA: 0xFFFD,
	0x4AAB: 0xFFFD,
	0x4AAC: 0xFFFD,
	0x4AAD: 0xFFFD,
	0x4AAE: 0xFFFD,
	0x4AAF: 0xFFFD,
	0x4AB0: 0xFFFD,
	0x4AB1: 0xFFFD,
	0x4AB2: 0xFFFD,
	0x4AB3: 0xFFFD,
	0x4AB4: 0xFFFD,
	0x4AB5: 0xFFFD,
	0x4AB6: 0xFFFD,
	0x4AB7: 0xFFFD,
	0x4AB8: 0xFFFD,
	0x4AB9: 0xFFFD,
	0x4ABA: 0xFFFD,
	0x4ABB: 0xFFFD,
	0x4ABC: 0xFFFD,
	0x4ABD: 0xFFFD,
	0x4ABE: 0xFFFD,
	0x4ABF: 0xFFFD,
	0x4AC0: 0xFFFD,
	0x4AC1: 0xFFFD,
	0x4AC2: 0xFFFD,
	0x4AC3: 0xFFFD,
	0x4AC4: 0xFFFD,
	0x4AC5: 0xFFFD,
	0x4AC6: 0xFFFD,
	0x4AC7: 0xFFFD,
	0x4AC8: 0xFFFD,
	0x4AC9: 0xFFFD,
	0x4ACA: 0xFFFD,
	0x4ACB: 0xFFFD,
	0x4ACC: 0xFFFD,
	0x4ACD: 0xFFFD,
	0x4ACE: 0xFFFD,
	0x4ACF: 0xFFFD,
	0x4AD0: 0xFFFD,
	0x4AD1: 0xFFFD,
	0x4AD2: 0xFFFD,
	0x4AD3: 0xFFFD,
	0x4AD4: 0xFFFD,
	0x4AD5: 0xFFFD,
	0x4AD6: 0xFFFD,
	0x4AD7: 0xFFFD,
	0x4AD8: 0xFFFD,
	0x4AD9: 0xFFFD,
	0x4ADA: 0xFFFD,
	0x4ADB: 0xFFFD,
	0x4ADC: 0xFFFD,
	0x4ADD: 0xFFFD,
	0x4ADE: 0xFFFD,
	0x4ADF: 0xFFFD,
	0x4AE0: 0xFFFD,
	0x4AE1: 0xFFFD,
	0x4AE2: 0xFFFD,
	0x4AE3: 0xFFFD,
	0x4AE4: 0xFFFD,
	0x4AE5: 0xFFFD,
	0x4AE6: 0xFFFD,
	0x4AE7: 0xFFFD,
	0x4AE8: 0xFFFD,
	0x4AE9: 0xFFFD,
	0x4AEA: 0xFFFD,
	0x4AEB: 0xFFFD,
	0x4AEC: 0xFFFD,
	0x4AED: 0xFFFD,
	0x4AEE: 0xFFFD,
	0x4AEF: 0xFFFD,
	0x4AF0: 0xFFFD,
	0x4AF1: 0xFFFD,
	0x4AF2: 0xFFFD,
	0x4AF3: 0xFFFD,
	0x4AF4: 0xFFFD,
	0x4AF5: 0xFFFD,
	0x4AF6: 0xFFFD,
	0x4AF7: 0xFFFD,
	0x4AF8: 0xFFFD,
	0x4AF9: 0xFFFD,
	0x4AFA: 0xFFFD,
	0x4AFB: 0xFFFD,
	0x4AFC: 0xFFFD,
	0x4AFD: 0xFFFD,
	0x4AFE: 0xFFFD,
	0x4AFF: 0xFFFD,
	0x4B00: 0xFFFD,
	0x4B01: 0xFFFD,
	0x4B02: 0xFFFD,
	0x4B03: 0xFFFD,
	0x4B04: 0xFFFD,
	0x4B05: 0xFFFD,
	0x4B06: 0xFFFD,
	0x4B07: 0xFFFD,
	0x4B08: 0xFFFD,
	0x4B09: 0xFFFD,
	0x4B0A: 0xFFFD,
	0x4B0B: 0xFFFD,
	0x4B0C: 0xFFFD,
	0x4B0D: 0xFFFD,
	0x4B0E: 0xFFFD,
	0x4B0F: 0xFFFD,
	0x4B10: 0xFFFD,
	0x4B11: 0xFFFD,
	0x4B12: 0xFFFD,
	0x4B13: 0xFFFD,
	0x4B14: 0xFFFD,
	0x4B15: 0xFFFD,
	0x4B16: 0xFFFD,
	0x4B17: 0xFFFD,
	0x4B18: 0xFFFD,
	0x4B19: 0xFFFD,
	0x4B1A: 0xFFFD,
	0x4B1B: 0xFFFD,
	0x4B1C: 0xFFFD,
	0x4B1D: 0xFFFD,
	0x4B1E: 0xFFFD,
	0x4B1F: 0xFFFD,
	0x4B20: 0xFFFD,
	0x4B21: 0xFFFD,
	0x4B22: 0xFFFD,
	0x4B23: 0xFFFD,
	0x4B24: 0xFFFD,
	0x4B25: 0xFFFD,
	0x4B26: 0xFFFD,
	0x4B27: 0xFFFD,
	0x4B28: 0xFFFD,
	0x4B29: 0xFFFD,
	0x4B2A: 0xFFFD,
	0x4B2B: 0xFFFD,
	0x4B2C: 0xFFFD,
	0x4B2D: 0xFFFD,
	0x4B2E: 0xFFFD,
	0x4B2F: 0xFFFD,
	0x4B30: 0xFFFD,
	0x4B31: 0xFFFD,
	0x4B32: 0xFFFD,
	0x4B33: 0xFFFD,
	0x4B34: 0xFFFD,
	0x4B35: 0xFFFD,
	0x4B36: 0xFFFD,
	0x4B37: 0xFFFD,
	0x4B38: 0xFFFD,
	0x4B39: 0xFFFD,
	0x4B3A: 0xFFFD,
	0x4B3B: 0xFFFD,
	0x4B3C: 0xFFFD,
	0x4B3D: 0xFFFD,
	0x4B3E: 0xFFFD,
	0x4B3F: 0xFFFD,
	0x4B40: 0xFFFD,
	0x4B41: 0xFFFD,
	0x4B42: 0xFFFD,
	0x4B43: 0xFFFD,
	0x4B44: 0xFFFD,
	0x4B45: 0xFFFD,
	0x4B46: 0xFFFD,
	0x4B47: 0xFFFD,
	0x4B48: 0xFFFD,
	0x4B49: 0xFFFD,
	0x4B4A: 0xFFFD,
	0x4B4B: 0xFFFD,
	0x4B4C: 0xFFFD,
	0x4B4D: 0xFFFD,
	0x4B4E: 0xFFFD,
	0x4B4F: 0xFFFD,
	0x4B50: 0xFFFD,
	0x4B51: 0xFFFD,
	0x4B52: 0xFFFD,
	0x4B53: 0xFFFD,
	0x4B54: 0xFFFD,
	0x4B55: 0xFFFD,
	0x4B56: 0xFFFD,
	0x4B57: 0xFFFD,
	0x4B58: 0xFFFD,
	0x4B59: 0xFFFD,
	0x4B5A: 0xFFFD,
	0x4B5B: 0xFFFD,
	0x4B5C: 0xFFFD,
	0x4B5D: 0xFFFD,
	0x4B5E: 0xFFFD,
	0x4B5F: 0xFFFD,
	0x4B60: 0xFFFD,
	0x4B61: 0xFFFD,
	0x4B62: 0xFFFD,
	0x4B63: 0xFFFD,
	0x4B64: 0xFFFD,
	0x4B65: 0xFFFD,
	0x4B66: 0xFFFD,
	0x4B67: 0xFFFD,
	0x4B68: 0xFFFD,
	0x4B69: 0xFFFD,
	0x4B6A: 0xFFFD,
	0x4B6B: 0xFFFD,
	0x4B6C: 0xFFFD,
	0x4B6D: 0xFFFD,
	0x4B6E: 0xFFFD,
	0x4B6F: 0xFFFD,
	0x4B70: 0xFFFD,
	0x4B71: 0xFFFD,
	0x4B72: 0xFFFD,
	0x4B73: 0xFFFD,
	0x4B74: 0xFFFD,
	0x4B75: 0xFFFD,
	0x4B76: 0xFFFD,
	0x4B77: 0xFFFD,
	0x4B78: 0xFFFD,
	0x4B79: 0xFFFD,
	0x4B7A: 0xFFFD,
	0x4B7B: 0xFFFD,
	0x4B7C: 0xFFFD,
	0x4B7D: 0xFFFD,
	0x4B7E: 0xFDE3,
	0x4B7F: 0xFFFD,
	0x4B80: 0xFFFD,
	0x4B81: 0xFFFD,
	0x4B82: 0xFFFD,
	0x4B83: 0xFFFD,
	0x4B84: 0xFFFD,
	0x4B85: 0xFFFD,
	0x4B86: 0xFFFD,
	0x4B87: 0xFFFD,
	0x4B88: 0xFFFD,
	0x4B89: 0xFFFD,
	0x4B8A: 0xFFFD,
	0x4B8B: 0xFFFD,
	0x4B8C: 0xFFFD,
	0x4B8D: 0xFFFD,
	0x4B8E: 0xFFFD,
	0x4B8F: 0xFFFD,
	0x4B90: 0xFFFD,
	0x4B91: 0xFFFD,
	0x4B92: 0xFFFD,
	0x4B93: 0xFFFD,
	0x4B94: 0xFFFD,
	0x4B95: 0xFFFD,
	0x4B96: 0xFFFD,
	0x4B97: 0xFFFD,
	0x4B98: 0xFFFD,
	0x4B99: 0xFFFD,
	0x4B9A: 0xFFFD,
	0x4B9B: 0xFFFD,
	0x4B9C: 0xFFFD,
	0x4B9D: 0xFFFD,
	0x4B9E: 0xFFFD,
	0x4B9F: 0xFFFD,
	0x4BA0: 0xFFFD,
	0x4BA1: 0xFFFD,
	0x4BA2: 0xFFFD,
	0x4BA3: 0xFFFD,
	0x4BA4: 0xFFFD,
	0x4BA5: 0xFFFD,
	0x4BA6: 0xFFFD,
	0x4BA7: 0xFFFD,
	0x4BA8: 0xFFFD,
	0x4BA9: 0xFFFD,
	0x4BAA: 0xFFFD,
	0x4BAB: 0xFFFD,
	0x4BAC: 0xFFFD,
	0x4BAD: 0xFFFD,
	0x4BAE: 0xFFFD,
	0x4BAF: 0xFFFD,
	0x4BB0: 0xFFFD,
	0x4BB1: 0xFFFD,
	0x4BB2: 0xFFFD,
	0x4BB3: 0xFFFD,
	0x4BB4: 0xFFFD,
	0x4BB5: 0xFFFD,
	0x4BB6: 0xFFFD,
	0x4BB7: 0xFFFD,
	0x4BB8: 0xFFFD,
	0x4BB9: 0xFFFD,
	0x4BBA: 0xFFFD,
	0x4BBB: 0xFFFD,
	0x4BBC: 0xFFFD,
	0x4BBD: 0xFFFD,
	0x4BBE: 0xFFFD,
	0x4BBF: 0xFFFD,
	0x4BC0: 0xFFFD,
	0x4BC1: 0xFFFD,
	0x4BC2: 0xFFFD,
	0x4BC3: 0xFFFD,
	0x4BC4: 0xFFFD,
	0x4BC5: 0xFFFD,
	0x4BC6: 0xFFFD,
	0x4BC7: 0xFFFD,
	0x4BC8: 0xFFFD,
	0x4BC9: 0xFFFD,
	0x4BCA: 0xFFFD,
	0x4BCB: 0xFFFD,
	0x4BCC: 0xFFFD,
	0x4BCD: 0xFFFD,
	0x4BCE: 0xFFFD,
	0x4BCF: 0xFFFD,
	0x4BD0: 0xFFFD,
	0x4BD1: 0xFFFD,
	0x4BD2: 0xFFFD,
	0x4BD3: 0xFFFD,
	0x4BD4: 0xFFFD,
	0x4BD5: 0xFFFD,
	0x4BD6: 0xFFFD,
	0x4BD7: 0xFFFD,
	0x4BD8: 0xFFFD,
	0x4BD9: 0xFFFD,
	0x4BDA: 0xFFFD,
	0x4BDB: 0xFFFD,
	0x4BDC: 0xFFFD,
	0x4BDD: 0xFFFD,
	0x4BDE: 0xFFFD,
	0x4BDF: 0xFFFD,
	0x4BE0: 0xFFFD,
	0x4BE1: 0xFFFD,
	0x4BE2: 0xFFFD,
	0x4BE3: 0xFFFD,
	0x4BE4: 0xFFFD,
	0x4BE5: 0xFFFD,
	0x4BE6: 0xFFFD,
	0x4BE7: 0xFFFD,
	0x4BE8: 0xFFFD,
	0x4BE9: 0xFFFD,
	0x4BEA: 0xFFFD,
	0x4BEB: 0xFFFD,
	0x4BEC: 0xFFFD,
	0x4BED: 0xFFFD,
	0x4BEE: 0xFFFD,
	0x4BEF: 0xFFFD,
	0x4BF0: 0xFFFD,
	0x4BF1: 0xFFFD,
	0x4BF2: 0xFFFD,
	0x4BF3: 0xFFFD,
	0x4BF4: 0xFFFD,
	0x4BF5: 0xFFFD,
	0x4BF6: 0xFFFD,
	0x4BF7: 0xFFFD,
	0x4BF8: 0xFFFD,
	0x4BF9: 0xFFFD,
	0x4BFA: 0xFFFD,
	0x4BFB: 0xFFFD,
	0x4BFC: 0xFFFD,
	0x4BFD: 0xFFFD,
	0x4BFE: 0xFFFD,
	0x4BFF: 0xFFFD,
	0x4C00: 0xFFFD,
	0x4C01: 0xFFFD,
	0x4C02: 0xFFFD,
	0x4C03: 0xFFFD,
	0x4C04: 0xFDF1,
	0x4C05: 0xFFFD,
	0x4C06: 0xFFFD,
	0x4C07: 0xFDEF,
	0x4C08: 0xFFFD,
	0x4C09: 0xFFFD,
	0x4C0A: 0xFFFD,
	0x4C0B: 0xFFFD,
	0x4C0C: 0xFFFD,
	0x4C0D: 0xFFFD,
	0x4C0E: 0xFFFD,
	0x4C0F: 0xFFFD,
	0x4C10: 0xFFFD,
	0x4C11: 0xFFFD,
	0x4C12: 0xFFFD,
	0x4C13: 0xFFFD,
	0x4C14: 0xFFFD,
	0x4C15: 0xFFFD,
	0x4C16: 0xFFFD,
	0x4C17: 0xFFFD,
	0x4C18: 0xFFFD,
	0x4C19: 0xFFFD,
	0x4C1A: 0xFFFD,
	0x4C1B: 0xFFFD,
	0x4C1C: 0xFFFD,
	0x4C1D: 0xFFFD,
	0x4C1E: 0xFFFD,
	0x4C1F: 0xFFFD,
	0x4C20: 0xFFFD,
	0x4C21: 0xFFFD,
	0x4C22: 0xFFFD,
	0x4C23: 0xFFFD,
	0x4C24: 0xFFFD,
	0x4C25: 0xFFFD,
	0x4C26: 0xFFFD,
	0x4C27: 0xFFFD,
	0x4C28: 0xFFFD,
	0x4C29: 0xFFFD,
	0x4C2A: 0xFFFD,
	0x4C2B: 0xFFFD,
	0x4C2C: 0xFFFD,
	0x4C2D: 0xFFFD,
	0x4C2E: 0xFFFD,
	0x4C2F: 0xFFFD,
	0x4C30: 0xFFFD,
	0x4C31: 0xFFFD,
	0x4C32: 0xFFFD,
	0x4C33: 0xFFFD,
	0x4C34: 0xFFFD,
	0x4C35: 0xFFFD,
	0x4C36: 0xFFFD,
	0x4C37: 0xFFFD,
	0x4C38: 0xFFFD,
	0x4C39: 0xFFFD,
	0x4C3A: 0xFFFD,
	0x4C3B: 0xFDF2,
	0x4C3C: 0xFFFD,
	0x4C3D: 0xFFFD,
	0x4C3E: 0xFFFD,
	0x4C3F: 0xFFFD,
	0x4C40: 0xFFFD,
	0x4C41: 0xFFFD,
	0x4C42: 0xFFFD,
	0x4C43: 0xFFFD,
	0x4C44: 0xFFFD,
	0x4C45: 0xFFFD,
	0x4C46: 0xFFFD,
	0x4C47: 0xFFFD,
	0x4C48: 0xFFFD,
	0x4C49: 0xFFFD,
	0x4C4A: 0xFFFD,
	0x4C4B: 0xFFFD,
	0x4C4C: 0xFFFD,
	0x4C4D: 0xFFFD,
	0x4C4E: 0xFFFD,
	0x4C4F: 0xFFFD,
	0x4C50: 0xFFFD,
	0x4C51: 0xFFFD,
	0x4C52: 0xFFFD,
	0x4C53: 0xFFFD,
	0x4C54: 0xFFFD,
	0x4C55: 0xFFFD,
	0x4C56: 0xFFFD,
	0x4C57: 0xFFFD,
	0x4C58: 0xFFFD,
	0x4C59: 0xFFFD,
	0x4C5A: 0xFFFD,
	0x4C5B: 0xFFFD,
	0x4C5C: 0xFFFD,
	0x4C5D: 0xFFFD,
	0x4C5E: 0xFFFD,
	0x4C5F: 0xFFFD,
	0x4C60: 0xFFFD,
	0x4C61: 0xFFFD,
	0x4C62: 0xFFFD,
	0x4C63: 0xFFFD,
	0x4C64: 0xFFFD,
	0x4C65: 0xFFFD,
	0x4C66: 0xFFFD,
	0x4C67: 0xFFFD,
	0x4C68: 0xFFFD,
	0x4C69: 0xFFFD,
	0x4C6A: 0xFFFD,
	0x4C6B: 0xFFFD,
	0x4C6C: 0xFFFD,
	0x4C6D: 0xFFFD,
	0x4C6E: 0xFFFD,
	0x4C6F: 0xFFFD,
	0x4C70: 0xFFFD,
	0x4C71: 0xFFFD,
	0x4C72: 0xFFFD,
	0x4C73: 0xFFFD,
	0x4C74: 0xFFFD,
	0x4C75: 0xFFFD,
	0x4C76: 0xFFFD,
	0x4C77: 0xFFFD,
	0x4C78: 0xFFFD,
	0x4C79: 0xFFFD,
	0x4C7A: 0xFFFD,
	0x4C7B: 0xFFFD,
	0x4C7C: 0xFFFD,
	0x4C7D: 0xFB45,
	0x4C7E: 0xFFFD,
	0x4C7F: 0xFFFD,
	0x4C80: 0xFFFD,
	0x4C81: 0xFFFD,
	0x4C82: 0xFFFD,
	0x4C83: 0xFFFD,
	0x4C84: 0xFFFD,
	0x4C85: 0xFFFD,
	0x4C86: 0xFFFD,
	0x4C87: 0xFFFD,
	0x4C88: 0xFFFD,
	0x4C89: 0xFFFD,
	0x4C8A: 0xFFFD,
	0x4C8B: 0xFFFD,
	0x4C8C: 0xFFFD,
	0x4C8D: 0xFFFD,
	0x4C8E: 0xFFFD,
	0x4C8F: 0xFFFD,
	0x4C90: 0xFFFD,
	0x4C91: 0xFFFD,
	0x4C92: 0xFFFD,
	0x4C93: 0xFFFD,
	0x4C94: 0xFFFD,
	0x4C95: 0xFFFD,
	0x4C96: 0xFFFD,
	0x4C97: 0xFFFD,
	0x4C98: 0xFFFD,
	0x4C99: 0xFFFD,
	0x4C9A: 0xFFFD,
	0x4C9B: 0xFFFD,
	0x4C9C: 0xFFFD,
	0x4C9D: 0xFFFD,
	0x4C9E: 0xFFFD,
	0x4C9F: 0xFFFD,
	0x4CA0: 0xFFFD,
	0x4CA1: 0xFFFD,
	0x4CA2: 0xFFFD,
	0x4CA3: 0xFFFD,
	0x4CA4: 0xFFFD,
	0x4CA5: 0xFFFD,
	0x4CA6: 0xFFFD,
	0x4CA7: 0xFFFD,
	0x4CA8: 0xFFFD,
	0x4CA9: 0xFFFD,
	0x4CAA: 0xFFFD,
	0x4CAB: 0xFFFD,
	0x4CAC: 0xFFFD,
	0x4CAD: 0xFFFD,
	0x4CAE: 0xFFFD,
	0x4CAF: 0xFFFD,
	0x4CB0: 0xFFFD,
	0x4CB1: 0xFFFD,
	0x4CB2: 0xFFFD,
	0x4CB3: 0xFFFD,
	0x4CB4: 0xFFFD,
	0x4CB5: 0xFFFD,
	0x4CB6: 0xFFFD,
	0x4CB7: 0xFFFD,
	0x4CB8: 0xFFFD,
	0x4CB9: 0xFFFD,
	0x4CBA: 0xFFFD,
	0x4CBB: 0xFFFD,
	0x4CBC: 0xFFFD,
	0x4CBD: 0xFFFD,
	0x4CBE: 0xFFFD,
	0x4CBF: 0xFFFD,
	0x4CC0: 0xFFFD,
	0x4CC1: 0xFFFD,
	0x4CC2: 0xFFFD,
	0x4CC3: 0xFFFD,
	0x4CC4: 0xFFFD,
	0x4CC5: 0xFFFD,
	0x4CC6: 0xFFFD,
	0x4CC7: 0xFFFD,
	0x4CC8: 0xFFFD,
	0x4CC9: 0xFFFD,
	0x4CCA: 0xFFFD,
	0x4CCB: 0xFFFD,
	0x4CCC: 0xFFFD,
	0x4CCD: 0xFFFD,
	0x4CCE: 0xFFFD,
	0x4CCF: 0xFFFD,
	0x4CD0: 0xFFFD,
	0x4CD1: 0xFFFD,
	0x4CD2: 0xFFFD,
	0x4CD3: 0xFFFD,
	0x4CD4: 0xFFFD,
	0x4CD5: 0xFFFD,
	0x4CD6: 0xFFFD,
	0x4CD7: 0xFFFD,
	0x4CD8: 0xFFFD,
	0x4CD9: 0xFFFD,
	0x4CDA: 0xFFFD,
	0x4CDB: 0xFFFD,
	0x4CDC: 0xFFFD,
	0x4CDD: 0xFFFD,
	0x4CDE: 0xFFFD,
	0x4CDF: 0xFFFD,
	0x4CE0: 0xFFFD,
	0x4CE1: 0xFFFD,
	0x4CE2: 0xFFFD,
	0x4CE3: 0xFFFD,
	0x4CE4: 0xFFFD,
	0x4CE5: 0xFFFD,
	0x4CE6: 0xFFFD,
	0x4CE7: 0xFFFD,
	0x4CE8: 0xFFFD,
	0x4CE9: 0xFFFD,
	0x4CEA: 0xFFFD,
	0x4CEB: 0xFFFD,
	0x4CEC: 0xFFFD,
	0x4CED: 0xFFFD,
	0x4CEE: 0xFFFD,
	0x4CEF: 0xFFFD,
	0x4CF0: 0xFFFD,
	0x4CF1: 0xFFFD,
	0x4CF2: 0xFFFD,
	0x4CF3: 0xFFFD,
	0x4CF4: 0xFFFD,
	0x4CF5: 0xFFFD,
	0x4CF6: 0xFFFD,
	0x4CF7: 0xFFFD,
	0x4CF8: 0xFFFD,
	0x4CF9: 0xFFFD,
	0x4CFA: 0xFFFD,
	0x4CFB: 0xFFFD,
	0x4CFC: 0xFFFD,
	0x4CFD: 0xFFFD,
	0x4CFE: 0xFFFD,
	0x4CFF: 0xFFFD,
	0x4D00: 0xFFFD,
	0x4D01: 0xFFFD,
	0x4D02: 0xFFFD,
	0x4D03: 0xFFFD,
	0x4D04: 0xFFFD,
	0x4D05: 0xFFFD,
	0x4D06: 0xFFFD,
	0x4D07: 0xFFFD,
	0x4D08: 0xFFFD,
	0x4D09: 0xFFFD,
	0x4D0A: 0xFFFD,
	0x4D0B: 0xFFFD,
	0x4D0C: 0xFFFD,
	0x4D0D: 0xFFFD,
	0x4D0E: 0xFFFD,
	0x4D0F: 0xFFFD,
	0x4D10: 0xFFFD,
	0x4D11: 0xFFFD,
	0x4D12: 0xFFFD,
	0x4D13: 0xFFFD,
	0x4D14: 0xFFFD,
	0x4D15: 0xFFFD,
	0x4D16: 0xFFFD,
	0x4D17: 0xFFFD,
	0x4D18: 0xFFFD,
	0x4D19: 0xFFFD,
	0x4D1A: 0xFFFD,
	0x4D1B: 0xFFFD,
	0x4D1C: 0xFFFD,
	0x4D1D: 0xFFFD,
	0x4D1E: 0xFFFD,
	0x4D1F: 0xFFFD,
	0x4D20: 0xFFFD,
	0x4D21: 0xFFFD,
	0x4D22: 0xFFFD,
	0x4D23: 0xFFFD,
	0x4D24: 0xFFFD,
	0x4D25: 0xFFFD,
	0x4D26: 0xFFFD,
	0x4D27: 0xFFFD,
	0x4D28: 0xFFFD,
	0x4D29: 0xFFFD,
	0x4D2A: 0xFFFD,
	0x4D2B: 0xFFFD,
	0x4D2C: 0xFFFD,
	0x4D2D: 0xFFFD,
	0x4D2E: 0xFFFD,
	0x4D2F: 0xFFFD,
	0x4D30: 0xFFFD,
	0x4D31: 0xFFFD,
	0x4D32: 0xFFFD,
	0x4D33: 0xFFFD,
	0x4D34: 0xFFFD,
	0x4D35: 0xFFFD,
	0x4D36: 0xFFFD,
	0x4D37: 0xFFFD,
	0x4D38: 0xFFFD,
	0x4D39: 0xFFFD,
	0x4D3A: 0xFFFD,
	0x4D3B: 0xFFFD,
	0x4D3C: 0xFFFD,
	0x4D3D: 0xFFFD,
	0x4D3E: 0xFFFD,
	0x4D3F: 0xFFFD,
	0x4D40: 0xFFFD,
	0x4D41: 0xFFFD,
	0x4D42: 0xFFFD,
	0x4D43: 0xFFFD,
	0x4D44: 0xFFFD,
	0x4D45: 0xFFFD,
	0x4D46: 0xFFFD,
	0x4D47: 0xFFFD,
	0x4D48: 0xFFFD,
	0x4D49: 0xFFFD,
	0x4D4A: 0xFFFD,
	0x4D4B: 0xFFFD,
	0x4D4C: 0xFFFD,
	0x4D4D: 0xFFFD,
	0x4D4E: 0xFFFD,
	0x4D4F: 0xFFFD,
	0x4D50: 0xFFFD,
	0x4D51: 0xFFFD,
	0x4D52: 0xFFFD,
	0x4D53: 0xFFFD,
	0x4D54: 0xFFFD,
	0x4D55: 0xFFFD,
	0x4D56: 0xFFFD,
	0x4D57: 0xFFFD,
	0x4D58: 0xFFFD,
	0x4D59: 0xFFFD,
	0x4D5A: 0xFFFD,
	0x4D5B: 0xFFFD,
	0x4D5C: 0xFFFD,
	0x4D5D: 0xFFFD,
	0x4D5E: 0xFFFD,
	0x4D5F: 0xFFFD,
	0x4D60: 0xFFFD,
	0x4D61: 0xFFFD,
	0x4D62: 0xFFFD,
	0x4D63: 0xFFFD,
	0x4D64: 0xFFFD,
	0x4D65: 0xFFFD,
	0x4D66: 0xFFFD,
	0x4D67: 0xFFFD,
	0x4D68: 0xFFFD,
	0x4D69: 0xFFFD,
	0x4D6A: 0xFFFD,
	0x4D6B: 0xFFFD,
	0x4D6C: 0xFFFD,
	0x4D6D: 0xFFFD,
	0x4D6E: 0xFFFD,
	0x4D6F: 0xFFFD,
	0x4D70: 0xFFFD,
	0x4D71: 0xFFFD,
	0x4D72: 0xFFFD,
	0x4D73: 0xFFFD,
	0x4D74: 0xFFFD,
	0x4D75: 0xFFFD,
	0x4D76: 0xFFFD,
	0x4D77: 0xFFFD,
	0x4D78: 0xFFFD,
	0x4D79: 0xFFFD,
	0x4D7A: 0xFFFD,
	0x4D7B: 0xFFFD,
	0x4D7C: 0xFFFD,
	0x4D7D: 0xFFFD,
	0x4D7E: 0xFFFD,
	0x4D7F: 0xFFFD,
	0x4D80: 0xFFFD,
	0x4D81: 0xFFFD,
	0x4D82: 0xFFFD,
	0x4D83: 0xFFFD,
	0x4D84: 0xFFFD,
	0x4D85: 0xFFFD,
	0x4D86: 0xFFFD,
	0x4D87: 0xFFFD,
	0x4D88: 0xFFFD,
	0x4D89: 0xFFFD,
	0x4D8A: 0xFFFD,
	0x4D8B: 0xFFFD,
	0x4D8C: 0xFFFD,
	0x4D8D: 0xFFFD,
	0x4D8E: 0xFFFD,
	0x4D8F: 0xFFFD,
	0x4D90: 0xFFFD,
	0x4D91: 0xFFFD,
	0x4D92: 0xFFFD,
	0x4D93: 0xFFFD,
	0x4D94: 0xFFFD,
	0x4D95: 0xFFFD,
	0x4D96: 0xFFFD,
	0x4D97: 0xFFFD,
	0x4D98: 0xFFFD,
	0x4D99: 0xFFFD,
	0x4D9A: 0xFFFD,
	0x4D9B: 0xFFFD,
	0x4D9C: 0xFFFD,
	0x4D9D: 0xFFFD,
	0x4D9E: 0xFFFD,
	0x4D9F: 0xFFFD,
	0x4DA0: 0xFFFD,
	0x4DA1: 0xFFFD,
	0x4DA2: 0xFFFD,
	0x4DA3: 0xFFFD,
	0x4DA4: 0xFFFD,
	0x4DA5: 0xFFFD,
	0x4DA6: 0xFFFD,
	0x4DA7: 0xFFFD,
	0x4DA8: 0xFFFD,
	0x4DA9: 0xFFFD,
	0x4DAA: 0xFFFD,
	0x4DAB: 0xFFFD,
	0x4DAC: 0xFFFD,
	0x4DAD: 0xFFFD,
	0x4DAE: 0xFFFD,
	0x4DAF: 0xFFFD,
	0x4DB0: 0xFFFD,
	0x4DB1: 0xFFFD,
	0x4DB2: 0xFFFD,
	0x4DB3: 0xFFFD,
	0x4DB4: 0xFFFD,
	0x4DB5: 0xFFFD,
	0x4DB6: 0xFFFD,
	0x4DB7: 0xFFFD,
	0x4DB8: 0xFFFD,
	0x4DB9: 0xFFFD,
	0x4DBA: 0xFFFD,
	0x4DBB: 0xFFFD,
	0x4DBC: 0xFFFD,
	0x4DBD: 0xFFFD,
	0x4DBE: 0xFFFD,
	0x4DBF: 0xFFFD,
	0x4DC0: 0xFFFD,
	0x4DC1: 0xFFFD,
	0x4DC2: 0xFFFD,
	0x4DC3: 0xFFFD,
	0x4DC4: 0xFFFD,
	0x4DC5: 0xFFFD,
	0x4DC6: 0xFFFD,
	0x4DC7: 0xFFFD,
	0x4DC8: 0xFFFD,
	0x4DC9: 0xFFFD,
	0x4DCA: 0xFFFD,
	0x4DCB: 0xFFFD,
	0x4DCC: 0xFFFD,
	0x4DCD: 0xFFFD,
	0x4DCE: 0xFFFD,
	0x4DCF: 0xFFFD,
	0x4DD0: 0xFFFD,
	0x4DD1: 0xFFFD,
	0x4DD2: 0xFFFD,
	0x4DD3: 0xFFFD,
	0x4DD4: 0xFFFD,
	0x4DD5: 0xFFFD,
	0x4DD6: 0xFFFD,
	0x4DD7: 0xFFFD,
	0x4DD8: 0xFFFD,
	0x4DD9: 0xFFFD,
	0x4DDA: 0xFFFD,
	0x4DDB: 0xFFFD,
	0x4DDC: 0xFFFD,
	0x4DDD: 0xFFFD,
	0x4DDE: 0xFFFD,
	0x4DDF: 0xFFFD,
	0x4DE0: 0xFFFD,
	0x4DE1: 0xFFFD,
	0x4DE2: 0xFFFD,
	0x4DE3: 0xFFFD,
	0x4DE4: 0xFFFD,
	0x4DE5: 0xFFFD,
	0x4DE6: 0xFFFD,
	0x4DE7: 0xFFFD,
	0x4DE8: 0xFFFD,
	0x4DE9: 0xFFFD,
	0x4DEA: 0xFFFD,
	0x4DEB: 0xFFFD,
	0x4DEC: 0xFFFD,
	0x4DED: 0xFFFD,
	0x4DEE: 0xFFFD,
	0x4DEF: 0xFFFD,
	0x4DF0: 0xFFFD,
	0x4DF1: 0xFFFD,
	0x4DF2: 0xFFFD,
	0x4DF3: 0xFFFD,
	0x4DF4: 0xFFFD,
	0x4DF5: 0xFFFD,
	0x4DF6: 0xFFFD,
	0x4DF7: 0xFFFD,
	0x4DF8: 0xFFFD,
	0x4DF9: 0xFFFD,
	0x4DFA: 0xFFFD,
	0x4DFB: 0xFFFD,
	0x4DFC: 0xFFFD,
	0x4DFD: 0xFFFD,
	0x4DFE: 0xFFFD,
	0x4DFF: 0xFFFD,
	0x4E00: 0xA440,
	0x4E01: 0xA442,
	0x4E02: 0xFFFD,
	0x4E03: 0xA443,
	0x4E04: 0x98A7,
	0x4E05: 0xFFFD,
	0x4E06: 0x91D7,
	0x4E07: 0xC945,
	0x4E08: 0xA456,
	0x4E09: 0xA454,
	0x4E0A: 0xA457,
	0x4E0B: 0xA455,
	0x4E0C: 0xC946,
	0x4E0D: 0xA4A3,
	0x4E0E: 0xC94F,
	0x4E0F: 0xC94D,
	0x4E10: 0xA4A2,
	0x4E11: 0xA4A1,
	0x4E12: 0xFFFD,
	0x4E13: 0x83FD,
	0x4E14: 0xA542,
	0x4E15: 0xA541,
	0x4E16: 0xA540,
	0x4E17: 0x8140,
	0x4E18: 0xA543,
	0x4E19: 0xA4FE,
	0x4E1A: 0x85D2,
	0x4E1B: 0x8ABD,
	0x4E1C: 0x835B,
	0x4E1D: 0x8546,
	0x4E1E: 0xA5E0,
	0x4E1F: 0xA5E1,
	0x4E20: 0xFFFD,
	0x4E21: 0x93E5,
	0x4E22: 0x8141,
	0x4E23: 0xFFFD,
	0x4E24: 0x8355,
	0x4E25: 0x8BF2,
	0x4E26: 0xA8C3,
	0x4E27: 0x84CA,
	0x4E28: 0x9CC9,
	0x4E29: 0xFFFD,
	0x4E2A: 0x83AA,
	0x4E2B: 0xA458,
	0x4E2C: 0x8142,
	0x4E2D: 0xA4A4,
	0x4E2E: 0xC950,
	0x4E2F: 0x98A8,
	0x4E30: 0xA4A5,
	0x4E31: 0xC963,
	0x4E32: 0xA6EA,
	0x4E33: 0xCBB1,
	0x4E34: 0x8A5A,
	0x4E35: 0xFFFD,
	0x4E36: 0xC6BF,
	0x4E37: 0x91CC,
	0x4E38: 0xA459,
	0x4E39: 0xA4A6,
	0x4E3A: 0x836F,
	0x4E3B: 0xA544,
	0x4E3C: 0xC964,
	0x4E3D: 0x8BED,
	0x4E3E: 0x8A5B,
	0x4E3F: 0xC6C0,
	0x4E40: 0xFFFD,
	0x4E41: 0xFFFD,
	0x4E42: 0xC940,
	0x4E43: 0xA444,
	0x4E44: 0x94F2,
	0x4E45: 0xA45B,
	0x4E46: 0xFFFD,
	0x4E47: 0xC947,
	0x4E48: 0xA45C,
	0x4E49: 0x85F3,
	0x4E4A: 0xFFFD,
	0x4E4B: 0xA4A7,
	0x4E4C: 0x83BF,
	0x4E4D: 0xA545,
	0x4E4E: 0xA547,
	0x4E4F: 0xA546,
	0x4E50: 0x87E4,
	0x4E51: 0xFFFD,
	0x4E52: 0xA5E2,
	0x4E53: 0xA5E3,
	0x4E54: 0x84CE,
	0x4E55: 0x8143,
	0x4E56: 0xA8C4,
	0x4E57: 0x92E9,
	0x4E58: 0xADBC,
	0x4E59: 0xA441,
	0x4E5A: 0x9CDF,
	0x4E5B: 0x9CE8,
	0x4E5C: 0xC941,
	0x4E5D: 0xA445,
	0x4E5E: 0xA45E,
	0x4E5F: 0xA45D,
	0x4E60: 0x8474,
	0x4E61: 0x8570,
	0x4E62: 0x8144,
	0x4E63: 0xFFFD,
	0x4E64: 0xFFFD,
	0x4E65: 0xFFFD,
	0x4E66: 0x83BC,
	0x4E67: 0xFFFD,
	0x4E68: 0xFFFD,
	0x4E69: 0xA5E4,
	0x4E6A: 0xFE41,
	0x4E6B: 0xFFFD,
	0x4E6C: 0xFFFD,
	0x4E6D: 0xFFFD,
	0x4E6E: 0xFFFD,
	0x4E6F: 0xFFFD,
	0x4E70: 0x8567,
	0x4E71: 0x85AF,
	0x4E72: 0xFFFD,
	0x4E73: 0xA8C5,
	0x4E74: 0xFFFD,
	0x4E75: 0xFFFD,
	0x4E76: 0xFFFD,
	0x4E77: 0xFFFD,
	0x4E78: 0xA061,
	0x4E79: 0xFFFD,
	0x4E7A: 0xFFFD,
	0x4E7B: 0xFFFD,
	0x4E7C: 0xFFFD,
	0x4E7D: 0xFFFD,
	0x4E7E: 0xB0AE,
	0x4E7F: 0xD44B,
	0x4E80: 0x93FA,
	0x4E81: 0x98A9,
	0x4E82: 0xB6C3,
	0x4E83: 0xDCB1,
	0x4E84: 0xDCB2,
	0x4E85: 0xC6C1,
	0x4E86: 0xA446,
	0x4E87: 0x98AA,
	0x4E88: 0xA4A9,
	0x4E89: 0x835C,
	0x4E8A: 0x8145,
	0x4E8B: 0xA8C6,
	0x4E8C: 0xA447,
	0x4E8D: 0xC948,
	0x4E8E: 0xA45F,
	0x4E8F: 0x8A5F,
	0x4E90: 0xFFFD,
	0x4E91: 0xA4AA,
	0x4E92: 0xA4AC,
	0x4E93: 0xC951,
	0x4E94: 0xA4AD,
	0x4E95: 0xA4AB,
	0x4E96: 0xFFFD,
	0x4E97: 0xFFFD,
	0x4E98: 0xFE62,
	0x4E99: 0xA5E5,
	0x4E9A: 0x8352,
	0x4E9B: 0xA8C7,
	0x4E9C: 0x9240,
	0x4E9D: 0xFFFD,
	0x4E9E: 0xA8C8,
	0x4E9F: 0xAB45,
	0x4EA0: 0xC6C2,
	0x4EA1: 0xA460,
	0x4EA2: 0xA4AE,
	0x4EA3: 0x98AB,
	0x4EA4: 0xA5E6,
	0x4EA5: 0xA5E8,
	0x4EA6: 0xA5E7,
	0x4EA7: 0x8464,
	0x4EA8: 0xA6EB,
	0x4EA9: 0x83C2,
	0x4EAA: 0xFFFD,
	0x4EAB: 0xA8C9,
	0x4EAC: 0xA8CA,
	0x4EAD: 0xAB46,
	0x4EAE: 0xAB47,
	0x4EAF: 0xFFFD,
	0x4EB0: 0x8146,
	0x4EB1: 0xFFFD,
	0x4EB2: 0x895D,
	0x4EB3: 0xADBD,
	0x4EB4: 0xFFFD,
	0x4EB5: 0x8A62,
	0x4EB6: 0xDCB3,
	0x4EB7: 0x98AC,
	0x4EB8: 0xFFFD,
	0x4EB9: 0xF6D6,
	0x4EBA: 0xA448,
	0x4EBB: 0x9CF4,
	0x4EBC: 0x98AD,
	0x4EBD: 0xFFFD,
	0x4EBE: 0xFFFD,
	0x4EBF: 0x87A3,
	0x4EC0: 0xA4B0,
	0x4EC1: 0xA4AF,
	0x4EC2: 0xC952,
	0x4EC3: 0xA4B1,
	0x4EC4: 0xA4B7,
	0x4EC5: 0x85B2,
	0x4EC6: 0xA4B2,
	0x4EC7: 0xA4B3,
	0x4EC8: 0xC954,
	0x4EC9: 0xC953,
	0x4ECA: 0xA4B5,
	0x4ECB: 0xA4B6,
	0x4ECC: 0xFFFD,
	0x4ECD: 0xA4B4,
	0x4ECE: 0x8447,
	0x4ECF: 0x93C2,
	0x4ED0: 0xFFFD,
	0x4ED1: 0x8354,
	0x4ED2: 0xFFFD,
	0x4ED3: 0x83AC,
	0x4ED4: 0xA54A,
	0x4ED5: 0xA54B,
	0x4ED6: 0xA54C,
	0x4ED7: 0xA54D,
	0x4ED8: 0xA549,
	0x4ED9: 0xA550,
	0x4EDA: 0xC96A,
	0x4EDB: 0xFFFD,
	0x4EDC: 0xC966,
	0x4EDD: 0xC969,
	0x4EDE: 0xA551,
	0x4EDF: 0xA561,
	0x4EE0: 0xFFFD,
	0x4EE1: 0xC968,
	0x4EE2: 0xFFFD,
	0x4EE3: 0xA54E,
	0x4EE4: 0xA54F,
	0x4EE5: 0xA548,
	0x4EE6: 0xFFFD,
	0x4EE7: 0xFFFD,
	0x4EE8: 0xC965,
	0x4EE9: 0xC967,
	0x4EEA: 0x87A4,
	0x4EEB: 0x8147,
	0x4EEC: 0x83A8,
	0x4EED: 0x8148,
	0x4EEE: 0x9254,
	0x4EEF: 0xFFFD,
	0x4EF0: 0xA5F5,
	0x4EF1: 0xC9B0,
	0x4EF2: 0xA5F2,
	0x4EF3: 0xA5F6,
	0x4EF4: 0xC9BA,
	0x4EF5: 0xC9AE,
	0x4EF6: 0xA5F3,
	0x4EF7: 0xC9B2,
	0x4EF8: 0x98AE,
	0x4EF9: 0xFFFD,
	0x4EFA: 0xFFFD,
	0x4EFB: 0xA5F4,
	0x4EFC: 0x8149,
	0x4EFD: 0xA5F7,
	0x4EFE: 0xFFFD,
	0x4EFF: 0xA5E9,
	0x4F00: 0xC9B1,
	0x4F01: 0xA5F8,
	0x4F02: 0xC9B5,
	0x4F03: 0xFBBA,
	0x4F04: 0xC9B9,
	0x4F05: 0xC9B6,
	0x4F06: 0xFFFD,
	0x4F07: 0xFFFD,
	0x4F08: 0xC9B3,
	0x4F09: 0xA5EA,
	0x4F0A: 0xA5EC,
	0x4F0B: 0xA5F9,
	0x4F0C: 0xFFFD,
	0x4F0D: 0xA5EE,
	0x4F0E: 0xC9AB,
	0x4F0F: 0xA5F1,
	0x4F10: 0xA5EF,
	0x4F11: 0xA5F0,
	0x4F12: 0xC9BB,
	0x4F13: 0xC9B8,
	0x4F14: 0xC9AF,
	0x4F15: 0xA5ED,
	0x4F16: 0xFFFD,
	0x4F17: 0x8467,
	0x4F18: 0xC9AC,
	0x4F19: 0xA5EB,
	0x4F1A: 0x85D1,
	0x4F1B: 0x8DFD,
	0x4F1C: 0x814A,
	0x4F1D: 0xC9B4,
	0x4F1E: 0x84C4,
	0x4F1F: 0x83EC,
	0x4F20: 0x85B1,
	0x4F21: 0xFFFD,
	0x4F22: 0xC9B7,
	0x4F23: 0xFFFD,
	0x4F24: 0x85B4,
	0x4F25: 0x83A9,
	0x4F26: 0x83AB,
	0x4F27: 0x84C3,
	0x4F28: 0x98AF,
	0x4F29: 0x98B0,
	0x4F2A: 0x83EB,
	0x4F2B: 0x8343,
	0x4F2C: 0xC9AD,
	0x4F2D: 0xCA66,
	0x4F2E: 0xFFFD,
	0x4F2F: 0xA742,
	0x4F30: 0xA6F4,
	0x4F31: 0xFFFD,
	0x4F32: 0xFBBD,
	0x4F33: 0xCA67,
	0x4F34: 0xA6F1,
	0x4F35: 0xFFFD,
	0x4F36: 0xA744,
	0x4F37: 0x98B1,
	0x4F38: 0xA6F9,
	0x4F39: 0xFBBC,
	0x4F3A: 0xA6F8,
	0x4F3B: 0xCA5B,
	0x4F3C: 0xA6FC,
	0x4F3D: 0xA6F7,
	0x4F3E: 0xCA60,
	0x4F3F: 0xCA68,
	0x4F40: 0xFFFD,
	0x4F41: 0xCA64,
	0x4F42: 0x98B2,
	0x4F43: 0xA6FA,
	0x4F44: 0xFFFD,
	0x4F45: 0x98B3,
	0x4F46: 0xA6FD,
	0x4F47: 0xA6EE,
	0x4F48: 0xA747,
	0x4F49: 0xCA5D,
	0x4F4A: 0xFFFD,
	0x4F4B: 0x98B4,
	0x4F4C: 0xCBBD,
	0x4F4D: 0xA6EC,
	0x4F4E: 0xA743,
	0x4F4F: 0xA6ED,
	0x4F50: 0xA6F5,
	0x4F51: 0xA6F6,
	0x4F52: 0xCA62,
	0x4F53: 0xCA5E,
	0x4F54: 0xA6FB,
	0x4F55: 0xA6F3,
	0x4F56: 0xCA5A,
	0x4F57: 0xA6EF,
	0x4F58: 0xCA65,
	0x4F59: 0xA745,
	0x4F5A: 0xA748,
	0x4F5B: 0xA6F2,
	0x4F5C: 0xA740,
	0x4F5D: 0xA746,
	0x4F5E: 0xA6F0,
	0x4F5F: 0xCA63,
	0x4F60: 0xA741,
	0x4F61: 0xCA69,
	0x4F62: 0xCA5C,
	0x4F63: 0xA6FE,
	0x4F64: 0xCA5F,
	0x4F65: 0x8E40,
	0x4F66: 0xFFFD,
	0x4F67: 0xCA61,
	0x4F68: 0xFFFD,
	0x4F69: 0xA8D8,
	0x4F6A: 0xCBBF,
	0x4F6B: 0xCBCB,
	0x4F6C: 0xA8D0,
	0x4F6D: 0xFFFD,
	0x4F6E: 0xCBCC,
	0x4F6F: 0xA8CB,
	0x4F70: 0xA8D5,
	0x4F71: 0xFFFD,
	0x4F72: 0x98B5,
	0x4F73: 0xA8CE,
	0x4F74: 0xCBB9,
	0x4F75: 0xA8D6,
	0x4F76: 0xCBB8,
	0x4F77: 0xCBBC,
	0x4F78: 0xCBC3,
	0x4F79: 0xCBC1,
	0x4F7A: 0xA8DE,
	0x4F7B: 0xA8D9,
	0x4F7C: 0xCBB3,
	0x4F7D: 0xCBB5,
	0x4F7E: 0xA8DB,
	0x4F7F: 0xA8CF,
	0x4F80: 0xCBB6,
	0x4F81: 0xCBC2,
	0x4F82: 0xCBC9,
	0x4F83: 0xA8D4,
	0x4F84: 0xCBBB,
	0x4F85: 0xCBB4,
	0x4F86: 0xA8D3,
	0x4F87: 0xCBB7,
	0x4F88: 0xA8D7,
	0x4F89: 0xCBBA,
	0x4F8A: 0x814B,
	0x4F8B: 0xA8D2,
	0x4F8C: 0xFFFD,
	0x4F8D: 0xA8CD,
	0x4F8E: 0xFFFD,
	0x4F8F: 0xA8DC,
	0x4F90: 0xCBC4,
	0x4F91: 0xA8DD,
	0x4F92: 0xCBC8,
	0x4F93: 0xFFFD,
	0x4F94: 0xCBC6,
	0x4F95: 0xCBCA,
	0x4F96: 0xA8DA,
	0x4F97: 0xCBBE,
	0x4F98: 0xCBB2,
	0x4F99: 0xFFFD,
	0x4F9A: 0xCBC0,
	0x4F9B: 0xA8D1,
	0x4F9C: 0xCBC5,
	0x4F9D: 0xA8CC,
	0x4F9E: 0xCBC7,
	0x4F9F: 0xFFFD,
	0x4FA0: 0x8365,
	0x4FA1: 0x9255,
	0x4FA2: 0x98B6,
	0x4FA3: 0x8366,
	0x4FA4: 0xFFFD,
	0x4FA5: 0x86AB,
	0x4FA6: 0x83ED,
	0x4FA7: 0x83EE,
	0x4FA8: 0x86AC,
	0x4FA9: 0x87A7,
	0x4FAA: 0x88CA,
	0x4FAB: 0xFBBE,
	0x4FAC: 0x87A6,
	0x4FAD: 0x827D,
	0x4FAE: 0xAB56,
	0x4FAF: 0xAB4A,
	0x4FB0: 0x98B7,
	0x4FB1: 0xFFFD,
	0x4FB2: 0xCDE0,
	0x4FB3: 0xCDE8,
	0x4FB4: 0x98F7,
	0x4FB5: 0xAB49,
	0x4FB6: 0xAB51,
	0x4FB7: 0xAB5D,
	0x4FB8: 0xFFFD,
	0x4FB9: 0xCDEE,
	0x4FBA: 0xCDEC,
	0x4FBB: 0xCDE7,
	0x4FBC: 0xFFFD,
	0x4FBD: 0x98B8,
	0x4FBE: 0xFFFD,
	0x4FBF: 0xAB4B,
	0x4FC0: 0xCDED,
	0x4FC1: 0xCDE3,
	0x4FC2: 0xAB59,
	0x4FC3: 0xAB50,
	0x4FC4: 0xAB58,
	0x4FC5: 0xCDDE,
	0x4FC6: 0xFFFD,
	0x4FC7: 0xCDEA,
	0x4FC8: 0x98B9,
	0x4FC9: 0xCDE1,
	0x4FCA: 0xAB54,
	0x4FCB: 0xCDE2,
	0x4FCC: 0x98BA,
	0x4FCD: 0xCDDD,
	0x4FCE: 0xAB5B,
	0x4FCF: 0xAB4E,
	0x4FD0: 0xAB57,
	0x4FD1: 0xAB4D,
	0x4FD2: 0xFFFD,
	0x4FD3: 0xCDDF,
	0x4FD4: 0xCDE4,
	0x4FD5: 0xFFFD,
	0x4FD6: 0xCDEB,
	0x4FD7: 0xAB55,
	0x4FD8: 0xAB52,
	0x4FD9: 0xCDE6,
	0x4FDA: 0xAB5A,
	0x4FDB: 0xCDE9,
	0x4FDC: 0xCDE5,
	0x4FDD: 0xAB4F,
	0x4FDE: 0xAB5C,
	0x4FDF: 0xAB53,
	0x4FE0: 0xAB4C,
	0x4FE1: 0xAB48,
	0x4FE2: 0xFFFD,
	0x4FE3: 0x8DB9,
	0x4FE4: 0x945F,
	0x4FE5: 0x9460,
	0x4FE6: 0x88C8,
	0x4FE7: 0xFFFD,
	0x4FE8: 0x8CC8,
	0x4FE9: 0x83A7,
	0x4FEA: 0x8C6C,
	0x4FEB: 0xFFFD,
	0x4FEC: 0xCDEF,
	0x4FED: 0x87A8,
	0x4FEE: 0xADD7,
	0x4FEF: 0xADC1,
	0x4FF0: 0x98BB,
	0x4FF1: 0xADD1,
	0x4FF2: 0x98BC,
	0x4FF3: 0xADD6,
	0x4FF4: 0xD0D0,
	0x4FF5: 0xD0CF,
	0x4FF6: 0xD0D4,
	0x4FF7: 0xD0D5,
	0x4FF8: 0xADC4,
	0x4FF9: 0x98BD,
	0x4FFA: 0xADCD,
	0x4FFB: 0xFFFD,
	0x4FFC: 0xFFFD,
	0x4FFD: 0xFE7B,
	0x4FFE: 0xADDA,
	0x4FFF: 0x814C,
	0x5000: 0xADCE,
	0x5001: 0xFFFD,
	0x5002: 0xFFFD,
	0x5003: 0x98BE,
	0x5004: 0xFFFD,
	0x5005: 0xD0C9,
	0x5006: 0xADC7,
	0x5007: 0xD0CA,
	0x5008: 0x98BF,
	0x5009: 0xADDC,
	0x500A: 0xFFFD,
	0x500B: 0xADD3,
	0x500C: 0xADBE,
	0x500D: 0xADBF,
	0x500E: 0xD0DD,
	0x500F: 0xB0BF,
	0x5010: 0xFFFD,
	0x5011: 0xADCC,
	0x5012: 0xADCB,
	0x5013: 0xD0CB,
	0x5014: 0xADCF,
	0x5015: 0xD45B,
	0x5016: 0xADC6,
	0x5017: 0xD0D6,
	0x5018: 0xADD5,
	0x5019: 0xADD4,
	0x501A: 0xADCA,
	0x501B: 0xD0CE,
	0x501C: 0xD0D7,
	0x501D: 0xFFFD,
	0x501E: 0xD0C8,
	0x501F: 0xADC9,
	0x5020: 0xD0D8,
	0x5021: 0xADD2,
	0x5022: 0xD0CC,
	0x5023: 0xADC0,
	0x5024: 0x82A9,
	0x5025: 0xADC3,
	0x5026: 0xADC2,
	0x5027: 0xD0D9,
	0x5028: 0xADD0,
	0x5029: 0xADC5,
	0x502A: 0xADD9,
	0x502B: 0xADDB,
	0x502C: 0xD0D3,
	0x502D: 0xADD8,
	0x502E: 0xFBC1,
	0x502F: 0xD0DB,
	0x5030: 0xD0CD,
	0x5031: 0xD0DC,
	0x5032: 0xFFFD,
	0x5033: 0xD0D1,
	0x5034: 0x98C0,
	0x5035: 0xD0DA,
	0x5036: 0x82A3,
	0x5037: 0xD0D2,
	0x5038: 0xFFFD,
	0x5039: 0x92B2,
	0x503A: 0x85B0,
	0x503B: 0x98C1,
	0x503C: 0xADC8,
	0x503D: 0xFFFD,
	0x503E: 0x85B3,
	0x503F: 0xFFFD,
	0x5040: 0xD463,
	0x5041: 0xD457,
	0x5042: 0x814D,
	0x5043: 0xB0B3,
	0x5044: 0xFFFD,
	0x5045: 0xD45C,
	0x5046: 0xD462,
	0x5047: 0xB0B2,
	0x5048: 0xD455,
	0x5049: 0xB0B6,
	0x504A: 0xD459,
	0x504B: 0xD452,
	0x504C: 0xB0B4,
	0x504D: 0xD456,
	0x504E: 0xB0B9,
	0x504F: 0xB0BE,
	0x5050: 0x814E,
	0x5051: 0xD467,
	0x5052: 0xFFFD,
	0x5053: 0xD451,
	0x5054: 0xFFFD,
	0x5055: 0xB0BA,
	0x5056: 0xFBBF,
	0x5057: 0xD466,
	0x5058: 0x98C2,
	0x5059: 0xFFFD,
	0x505A: 0xB0B5,
	0x505B: 0xD458,
	0x505C: 0xB0B1,
	0x505D: 0xD453,
	0x505E: 0xD44F,
	0x505F: 0xD45D,
	0x5060: 0xD450,
	0x5061: 0xD44E,
	0x5062: 0xD45A,
	0x5063: 0xD460,
	0x5064: 0xD461,
	0x5065: 0xB0B7,
	0x5066: 0x98C3,
	0x5067: 0xFFFD,
	0x5068: 0xD85B,
	0x5069: 0xD45E,
	0x506A: 0xD44D,
	0x506B: 0xD45F,
	0x506C: 0x85B5,
	0x506D: 0xB0C1,
	0x506E: 0xD464,
	0x506F: 0xB0C0,
	0x5070: 0xD44C,
	0x5071: 0xFFFD,
	0x5072: 0xD454,
	0x5073: 0xD465,
	0x5074: 0xB0BC,
	0x5075: 0xB0BB,
	0x5076: 0xB0B8,
	0x5077: 0xB0BD,
	0x5078: 0x814F,
	0x5079: 0xFFFD,
	0x507A: 0xB0AF,
	0x507B: 0x8DFE,
	0x507C: 0xFFFD,
	0x507D: 0xB0B0,
	0x507E: 0x8E65,
	0x507F: 0x89C8,
	0x5080: 0xB3C8,
	0x5081: 0x98C4,
	0x5082: 0xD85E,
	0x5083: 0xD857,
	0x5084: 0xFFFD,
	0x5085: 0xB3C5,
	0x5086: 0xFFFD,
	0x5087: 0xD85F,
	0x5088: 0x90F0,
	0x5089: 0xFFFD,
	0x508A: 0xFFFD,
	0x508B: 0xD855,
	0x508C: 0xD858,
	0x508D: 0xB3C4,
	0x508E: 0xD859,
	0x508F: 0xFFFD,
	0x5090: 0x98C5,
	0x5091: 0xB3C7,
	0x5092: 0xD85D,
	0x5093: 0xFFFD,
	0x5094: 0xD853,
	0x5095: 0xD852,
	0x5096: 0xB3C9,
	0x5097: 0xFFFD,
	0x5098: 0xB3CA,
	0x5099: 0xB3C6,
	0x509A: 0xB3CB,
	0x509B: 0xD851,
	0x509C: 0xD85C,
	0x509D: 0xD85A,
	0x509E: 0xD854,
	0x509F: 0xFFFD,
	0x50A0: 0xFFFD,
	0x50A1: 0xFFFD,
	0x50A2: 0xB3C3,
	0x50A3: 0xD856,
	0x50A4: 0xFFFD,
	0x50A5: 0x8CC9,
	0x50A6: 0xFBC2,
	0x50A7: 0x88C9,
	0x50A8: 0x89C9,
	0x50A9: 0x8FFB,
	0x50AA: 0xFFFD,
	0x50AB: 0xFFFD,
	0x50AC: 0xB6CA,
	0x50AD: 0xB6C4,
	0x50AE: 0xDCB7,
	0x50AF: 0xB6CD,
	0x50B0: 0xDCBD,
	0x50B1: 0xDCC0,
	0x50B2: 0xB6C6,
	0x50B3: 0xB6C7,
	0x50B4: 0xDCBA,
	0x50B5: 0xB6C5,
	0x50B6: 0xDCC3,
	0x50B7: 0xB6CB,
	0x50B8: 0xDCC4,
	0x50B9: 0xFFFD,
	0x50BA: 0xDCBF,
	0x50BB: 0xB6CC,
	0x50BC: 0x98C6,
	0x50BD: 0xDCB4,
	0x50BE: 0xB6C9,
	0x50BF: 0xDCB5,
	0x50C0: 0xFFFD,
	0x50C1: 0xDCBE,
	0x50C2: 0xDCBC,
	0x50C3: 0xFFFD,
	0x50C4: 0xDCB8,
	0x50C5: 0xB6C8,
	0x50C6: 0xDCB6,
	0x50C7: 0xB6CE,
	0x50C8: 0xDCBB,
	0x50C9: 0xDCC2,
	0x50CA: 0xDCB9,
	0x50CB: 0xDCC1,
	0x50CC: 0xFFFD,
	0x50CD: 0x944F,
	0x50CE: 0xB9B6,
	0x50CF: 0xB9B3,
	0x50D0: 0x98C7,
	0x50D1: 0xB9B4,
	0x50D2: 0xFFFD,
	0x50D3: 0xE0F9,
	0x50D4: 0xE0F1,
	0x50D5: 0xB9B2,
	0x50D6: 0xB9AF,
	0x50D7: 0xE0F2,
	0x50D8: 0x8150,
	0x50D9: 0xFBC3,
	0x50DA: 0xB9B1,
	0x50DB: 0xE0F5,
	0x50DC: 0xFFFD,
	0x50DD: 0xE0F7,
	0x50DE: 0x8151,
	0x50DF: 0x98C8,
	0x50E0: 0xE0FE,
	0x50E1: 0x98C9,
	0x50E2: 0xFFFD,
	0x50E3: 0xE0FD,
	0x50E4: 0xE0F8,
	0x50E5: 0xB9AE,
	0x50E6: 0xE0F0,
	0x50E7: 0xB9AC,
	0x50E8: 0xE0F3,
	0x50E9: 0xB9B7,
	0x50EA: 0xE0F6,
	0x50EB: 0xFFFD,
	0x50EC: 0xE0FA,
	0x50ED: 0xB9B0,
	0x50EE: 0xB9AD,
	0x50EF: 0xE0FC,
	0x50F0: 0xE0FB,
	0x50F1: 0xB9B5,
	0x50F2: 0xFFFD,
	0x50F3: 0xE0F4,
	0x50F4: 0x8152,
	0x50F5: 0xBBF8,
	0x50F6: 0xE4EC,
	0x50F7: 0xFFFD,
	0x50F8: 0xE4E9,
	0x50F9: 0xBBF9,
	0x50FA: 0xFFFD,
	0x50FB: 0xBBF7,
	0x50FC: 0x98CA,
	0x50FD: 0xE4F0,
	0x50FE: 0xE4ED,
	0x50FF: 0xE4E6,
	0x5100: 0xBBF6,
	0x5101: 0xFBC6,
	0x5102: 0xBBFA,
	0x5103: 0xE4E7,
	0x5104: 0xBBF5,
	0x5105: 0xBBFD,
	0x5106: 0xE4EA,
	0x5107: 0xE4EB,
	0x5108: 0xBBFB,
	0x5109: 0xBBFC,
	0x510A: 0xE4F1,
	0x510B: 0xE4EE,
	0x510C: 0xE4EF,
	0x510D: 0x98CB,
	0x510E: 0xFBC4,
	0x510F: 0xFFFD,
	0x5110: 0xBEAA,
	0x5111: 0xE8F8,
	0x5112: 0xBEA7,
	0x5113: 0xE8F5,
	0x5114: 0xBEA9,
	0x5115: 0xBEAB,
	0x5116: 0x8153,
	0x5117: 0xE8F6,
	0x5118: 0xBEA8,
	0x5119: 0xFFFD,
	0x511A: 0xE8F7,
	0x511B: 0xFFFD,
	0x511C: 0xE8F4,
	0x511D: 0xFFFD,
	0x511E: 0xFFFD,
	0x511F: 0xC076,
	0x5120: 0xECBD,
	0x5121: 0xC077,
	0x5122: 0xECBB,
	0x5123: 0xFFFD,
	0x5124: 0xECBC,
	0x5125: 0xECBA,
	0x5126: 0xECB9,
	0x5127: 0xFFFD,
	0x5128: 0xFFFD,
	0x5129: 0xECBE,
	0x512A: 0xC075,
	0x512B: 0x98CC,
	0x512C: 0xFFFD,
	0x512D: 0xEFB8,
	0x512E: 0xEFB9,
	0x512F: 0xFFFD,
	0x5130: 0xE4E8,
	0x5131: 0xEFB7,
	0x5132: 0xC078,
	0x5133: 0xC35F,
	0x5134: 0xF1EB,
	0x5135: 0xF1EC,
	0x5136: 0xFFFD,
	0x5137: 0xC4D7,
	0x5138: 0xC4D8,
	0x5139: 0xF5C1,
	0x513A: 0xF5C0,
	0x513B: 0xC56C,
	0x513C: 0xC56B,
	0x513D: 0xF7D0,
	0x513E: 0xFFFD,
	0x513F: 0xA449,
	0x5140: 0xA461,
	0x5141: 0xA4B9,
	0x5142: 0xFFFD,
	0x5143: 0xA4B8,
	0x5144: 0xA553,
	0x5145: 0xA552,
	0x5146: 0xA5FC,
	0x5147: 0xA5FB,
	0x5148: 0xA5FD,
	0x5149: 0xA5FA,
	0x514A: 0x8154,
	0x514B: 0xA74A,
	0x514C: 0xA749,
	0x514D: 0xA74B,
	0x514E: 0x95FC,
	0x514F: 0xFFFD,
	0x5150: 0x92D1,
	0x5151: 0x8155,
	0x5152: 0xA8E0,
	0x5153: 0xFFFD,
	0x5154: 0xA8DF,
	0x5155: 0xA8E1,
	0x5156: 0x8367,
	0x5157: 0xAB5E,
	0x5158: 0xFFFD,
	0x5159: 0xA259,
	0x515A: 0xD0DE,
	0x515B: 0xA25A,
	0x515C: 0xB0C2,
	0x515D: 0xA25C,
	0x515E: 0xA25B,
	0x515F: 0xD860,
	0x5160: 0x98CD,
	0x5161: 0xA25D,
	0x5162: 0xB9B8,
	0x5163: 0xA25E,
	0x5164: 0x8156,
	0x5165: 0xA44A,
	0x5166: 0xFFFD,
	0x5167: 0xA4BA,
	0x5168: 0xA5FE,
	0x5169: 0xA8E2,
	0x516A: 0x8157,
	0x516B: 0xA44B,
	0x516C: 0xA4BD,
	0x516D: 0xA4BB,
	0x516E: 0xA4BC,
	0x516F: 0xFFFD,
	0x5170: 0x8CA3,
	0x5171: 0xA640,
	0x5172: 0xFFFD,
	0x5173: 0x8BD7,
	0x5174: 0x8955,
	0x5175: 0xA74C,
	0x5176: 0xA8E4,
	0x5177: 0xA8E3,
	0x5178: 0xA8E5,
	0x5179: 0x90BC,
	0x517A: 0xFFFD,
	0x517B: 0x88B5,
	0x517C: 0xADDD,
	0x517D: 0x8BA6,
	0x517E: 0xFFFD,
	0x517F: 0xFFFD,
	0x5180: 0xBEAC,
	0x5181: 0x9054,
	0x5182: 0xC6C3,
	0x5183: 0xFFFD,
	0x5184: 0xFFFD,
	0x5185: 0x8158,
	0x5186: 0x924C,
	0x5187: 0xC94E,
	0x5188: 0x8358,
	0x5189: 0xA554,
	0x518A: 0xA555,
	0x518B: 0xFFFD,
	0x518C: 0x95E4,
	0x518D: 0xA641,
	0x518E: 0xFFFD,
	0x518F: 0xCA6A,
	0x5190: 0x8159,
	0x5191: 0xAB60,
	0x5192: 0xAB5F,
	0x5193: 0xD0E0,
	0x5194: 0xD0DF,
	0x5195: 0xB0C3,
	0x5196: 0xC6C4,
	0x5197: 0xA4BE,
	0x5198: 0xC955,
	0x5199: 0x87C0,
	0x519A: 0xFB41,
	0x519B: 0x837E,
	0x519C: 0x8661,
	0x519D: 0x815A,
	0x519E: 0xCBCD,
	0x519F: 0xFFFD,
	0x51A0: 0xAB61,
	0x51A1: 0xFFFD,
	0x51A2: 0xADE0,
	0x51A3: 0xFFFD,
	0x51A4: 0xADDE,
	0x51A5: 0xADDF,
	0x51A6: 0x815B,
	0x51A7: 0xFB4E,
	0x51A8: 0x815C,
	0x51A9: 0x815D,
	0x51AA: 0xBEAD,
	0x51AB: 0xC6C5,
	0x51AC: 0xA556,
	0x51AD: 0xFFFD,
	0x51AE: 0x98CE,
	0x51AF: 0x85AD,
	0x51B0: 0xA642,
	0x51B1: 0xC9BC,
	0x51B2: 0x834C,
	0x51B3: 0x834B,
	0x51B4: 0x94FB,
	0x51B5: 0x95D5,
	0x51B6: 0xA74D,
	0x51B7: 0xA74E,
	0x51B8: 0x98CF,
	0x51B9: 0xCA6B,
	0x51BA: 0xFFFD,
	0x51BB: 0x83AD,
	0x51BC: 0xCBCE,
	0x51BD: 0xA8E6,
	0x51BE: 0xCBCF,
	0x51BF: 0xFFFD,
	0x51C0: 0x8460,
	0x51C1: 0xFFFD,
	0x51C2: 0xFFFD,
	0x51C3: 0x95F3,
	0x51C4: 0xD0E2,
	0x51C5: 0xD0E3,
	0x51C6: 0xADE3,
	0x51C7: 0x815E,
	0x51C8: 0xD0E4,
	0x51C9: 0x845B,
	0x51CA: 0xD0E1,
	0x51CB: 0xADE4,
	0x51CC: 0xADE2,
	0x51CD: 0xADE1,
	0x51CE: 0xD0E5,
	0x51CF: 0x90B6,
	0x51D0: 0xD468,
	0x51D1: 0x84EE,
	0x51D2: 0x98D0,
	0x51D3: 0xFBCF,
	0x51D4: 0xD861,
	0x51D5: 0xFFFD,
	0x51D6: 0x815F,
	0x51D7: 0xDCC5,
	0x51D8: 0xE140,
	0x51D9: 0xFFFD,
	0x51DA: 0xFFFD,
	0x51DB: 0x8160,
	0x51DC: 0xBBFE,
	0x51DD: 0xBEAE,
	0x51DE: 0xE8F9,
	0x51DF: 0xFBD0,
	0x51E0: 0xA44C,
	0x51E1: 0xA45A,
	0x51E2: 0x98D1,
	0x51E3: 0xFFFD,
	0x51E4: 0x87A1,
	0x51E5: 0xFFFD,
	0x51E6: 0x92E1,
	0x51E7: 0x944C,
	0x51E8: 0xFFFD,
	0x51E9: 0x9461,
	0x51EA: 0x9452,
	0x51EB: 0x8E63,
	0x51EC: 0x8161,
	0x51ED: 0x88D7,
	0x51EE: 0xFFFD,
	0x51EF: 0x84C5,
	0x51F0: 0xB0C4,
	0x51F1: 0xB3CD,
	0x51F2: 0xFFFD,
	0x51F3: 0xB9B9,
	0x51F4: 0xFBC7,
	0x51F5: 0xC942,
	0x51F6: 0xA4BF,
	0x51F7: 0xFFFD,
	0x51F8: 0xA559,
	0x51F9: 0xA557,
	0x51FA: 0xA558,
	0x51FB: 0x89DB,
	0x51FC: 0x8162,
	0x51FD: 0xA8E7,
	0x51FE: 0xFBD2,
	0x51FF: 0x8DAD,
	0x5200: 0xA44D,
	0x5201: 0xA44E,
	0x5202: 0xC87D,
	0x5203: 0xA462,
	0x5204: 0x95CF,
	0x5205: 0x98D2,
	0x5206: 0xA4C0,
	0x5207: 0xA4C1,
	0x5208: 0xA4C2,
	0x5209: 0xC9BE,
	0x520A: 0xA55A,
	0x520B: 0x8163,
	0x520C: 0xC96B,
	0x520D: 0x83D2,
	0x520E: 0xA646,
	0x520F: 0xFFFD,
	0x5210: 0xC9BF,
	0x5211: 0xA644,
	0x5212: 0xA645,
	0x5213: 0xC9BD,
	0x5214: 0x8164,
	0x5215: 0x8165,
	0x5216: 0xA647,
	0x5217: 0xA643,
	0x5218: 0x87AA,
	0x5219: 0x8368,
	0x521A: 0x83AE,
	0x521B: 0x84C7,
	0x521C: 0xCA6C,
	0x521D: 0xAAEC,
	0x521E: 0xCA6D,
	0x521F: 0xFBC8,
	0x5220: 0x8166,
	0x5221: 0xCA6E,
	0x5222: 0xFFFD,
	0x5223: 0xA07E,
	0x5224: 0xA750,
	0x5225: 0xA74F,
	0x5226: 0x957B,
	0x5227: 0x95E5,
	0x5228: 0xA753,
	0x5229: 0xA751,
	0x522A: 0xA752,
	0x522B: 0x8167,
	0x522C: 0xFFFD,
	0x522D: 0x8DBA,
	0x522E: 0xA8ED,
	0x522F: 0xFFFD,
	0x5230: 0xA8EC,
	0x5231: 0xCBD4,
	0x5232: 0xCBD1,
	0x5233: 0xCBD2,
	0x5234: 0x98D3,
	0x5235: 0xCBD0,
	0x5236: 0xA8EE,
	0x5237: 0xA8EA,
	0x5238: 0xA8E9,
	0x5239: 0x8168,
	0x523A: 0xA8EB,
	0x523B: 0xA8E8,
	0x523C: 0x98D4,
	0x523D: 0x87AC,
	0x523E: 0xFFFD,
	0x523F: 0x8EAF,
	0x5240: 0x84C6,
	0x5241: 0xA8EF,
	0x5242: 0x88CC,
	0x5243: 0xAB63,
	0x5244: 0xCDF0,
	0x5245: 0xFFFD,
	0x5246: 0xCBD3,
	0x5247: 0xAB68,
	0x5248: 0xFFFD,
	0x5249: 0xCDF1,
	0x524A: 0xAB64,
	0x524B: 0xAB67,
	0x524C: 0xAB66,
	0x524D: 0xAB65,
	0x524E: 0xAB62,
	0x524F: 0x8169,
	0x5250: 0x8DC8,
	0x5251: 0x87AB,
	0x5252: 0xD0E8,
	0x5253: 0xFFFD,
	0x5254: 0xADE7,
	0x5255: 0xD0EB,
	0x5256: 0xADE5,
	0x5257: 0xFBCA,
	0x5258: 0xFFFD,
	0x5259: 0x98D5,
	0x525A: 0xD0E7,
	0x525B: 0xADE8,
	0x525C: 0xADE6,
	0x525D: 0xADE9,
	0x525E: 0xD0E9,
	0x525F: 0xD0EA,
	0x5260: 0xFBC9,
	0x5261: 0xD0E6,
	0x5262: 0xD0EC,
	0x5263: 0x92B3,
	0x5264: 0x92C9,
	0x5265: 0x8276,
	0x5266: 0xFFFD,
	0x5267: 0x87A9,
	0x5268: 0x98D6,
	0x5269: 0xB3D1,
	0x526A: 0xB0C5,
	0x526B: 0xD469,
	0x526C: 0xD46B,
	0x526D: 0xD46A,
	0x526E: 0xD46C,
	0x526F: 0xB0C6,
	0x5270: 0x92EB,
	0x5271: 0x816A,
	0x5272: 0xB3CE,
	0x5273: 0xFCF5,
	0x5274: 0xB3CF,
	0x5275: 0xB3D0,
	0x5276: 0xFFFD,
	0x5277: 0xB6D0,
	0x5278: 0xDCC7,
	0x5279: 0x98D7,
	0x527A: 0xDCC6,
	0x527B: 0xDCC8,
	0x527C: 0xDCC9,
	0x527D: 0xB6D1,
	0x527E: 0xFFFD,
	0x527F: 0xB6CF,
	0x5280: 0xE141,
	0x5281: 0xE142,
	0x5282: 0xB9BB,
	0x5283: 0xB9BA,
	0x5284: 0xE35A,
	0x5285: 0xFFFD,
	0x5286: 0xFFFD,
	0x5287: 0xBC40,
	0x5288: 0xBC41,
	0x5289: 0xBC42,
	0x528A: 0xBC44,
	0x528B: 0xE4F2,
	0x528C: 0xE4F3,
	0x528D: 0xBC43,
	0x528E: 0xFFFD,
	0x528F: 0xFB69,
	0x5290: 0x816B,
	0x5291: 0xBEAF,
	0x5292: 0x816C,
	0x5293: 0xBEB0,
	0x5294: 0x816D,
	0x5295: 0xFFFD,
	0x5296: 0xF1ED,
	0x5297: 0xF5C3,
	0x5298: 0xF5C2,
	0x5299: 0xF7D1,
	0x529A: 0xFBCB,
	0x529B: 0xA44F,
	0x529C: 0x816E,
	0x529D: 0x8BEF,
	0x529E: 0x8974,
	0x529F: 0xA55C,
	0x52A0: 0xA55B,
	0x52A1: 0x83EF,
	0x52A2: 0x8EB0,
	0x52A3: 0xA648,
	0x52A4: 0x98D8,
	0x52A5: 0xFFFD,
	0x52A6: 0xC9C0,
	0x52A7: 0xFFFD,
	0x52A8: 0x83F0,
	0x52A9: 0xA755,
	0x52AA: 0xA756,
	0x52AB: 0xA754,
	0x52AC: 0xA757,
	0x52AD: 0xCA6F,
	0x52AE: 0xCA70,
	0x52AF: 0x816F,
	0x52B0: 0xFFFD,
	0x52B1: 0x89CA,
	0x52B2: 0x8369,
	0x52B3: 0x84C8,
	0x52B4: 0x93F5,
	0x52B5: 0x8170,
	0x52B6: 0xFFFD,
	0x52B7: 0xFFFD,
	0x52B8: 0xFFFD,
	0x52B9: 0x95A2,
	0x52BA: 0xFFFD,
	0x52BB: 0xA8F1,
	0x52BC: 0xCBD5,
	0x52BD: 0xFFFD,
	0x52BE: 0xA8F0,
	0x52BF: 0x85B7,
	0x52C0: 0xCDF2,
	0x52C1: 0xAB6C,
	0x52C2: 0xCDF3,
	0x52C3: 0xAB6B,
	0x52C4: 0xFFFD,
	0x52C5: 0x9544,
	0x52C6: 0xFFFD,
	0x52C7: 0xAB69,
	0x52C8: 0xFFFD,
	0x52C9: 0xAB6A,
	0x52CA: 0xFFFD,
	0x52CB: 0x84C9,
	0x52CC: 0x98D9,
	0x52CD: 0xD0ED,
	0x52CE: 0xFFFD,
	0x52CF: 0xFFFD,
	0x52D0: 0x8171,
	0x52D1: 0xFBCC,
	0x52D2: 0xB0C7,
	0x52D3: 0xD46E,
	0x52D4: 0xFFFD,
	0x52D5: 0xB0CA,
	0x52D6: 0xD46D,
	0x52D7: 0xB1E5,
	0x52D8: 0xB0C9,
	0x52D9: 0xB0C8,
	0x52DA: 0xFFFD,
	0x52DB: 0xB3D4,
	0x52DC: 0xFFFD,
	0x52DD: 0xB3D3,
	0x52DE: 0xB3D2,
	0x52DF: 0xB6D2,
	0x52E0: 0xFBCD,
	0x52E1: 0xFBCE,
	0x52E2: 0xB6D5,
	0x52E3: 0xB6D6,
	0x52E4: 0xB6D4,
	0x52E5: 0xFFFD,
	0x52E6: 0xB6D3,
	0x52E7: 0x9268,
	0x52E8: 0xFFFD,
	0x52E9: 0xE143,
	0x52EA: 0xFFFD,
	0x52EB: 0xE144,
	0x52EC: 0xFFFD,
	0x52ED: 0xFFFD,
	0x52EE: 0xFFFD,
	0x52EF: 0xE4F5,
	0x52F0: 0xBC45,
	0x52F1: 0xE4F4,
	0x52F2: 0x92A4,
	0x52F3: 0xBEB1,
	0x52F4: 0xECBF,
	0x52F5: 0xC079,
	0x52F6: 0xFFFD,
	0x52F7: 0xF1EE,
	0x52F8: 0xC455,
	0x52F9: 0xC6C6,
	0x52FA: 0xA463,
	0x52FB: 0xA4C3,
	0x52FC: 0xC956,
	0x52FD: 0xFFFD,
	0x52FE: 0xA4C4,
	0x52FF: 0xA4C5,
	0x5300: 0x8172,
	0x5301: 0x945E,
	0x5302: 0x9453,
	0x5303: 0x9CD0,
	0x5304: 0xFFFD,
	0x5305: 0xA55D,
	0x5306: 0xA55E,
	0x5307: 0x8173,
	0x5308: 0xA649,
	0x5309: 0xCA71,
	0x530A: 0xCBD6,
	0x530B: 0xCBD7,
	0x530C: 0xFFFD,
	0x530D: 0xAB6D,
	0x530E: 0xD0EE,
	0x530F: 0xB0CC,
	0x5310: 0xB0CB,
	0x5311: 0xD863,
	0x5312: 0xD862,
	0x5313: 0xFFFD,
	0x5314: 0xFFFD,
	0x5315: 0xA450,
	0x5316: 0xA4C6,
	0x5317: 0xA55F,
	0x5318: 0xFFFD,
	0x5319: 0xB0CD,
	0x531A: 0xC943,
	0x531B: 0xFFFD,
	0x531C: 0xC96C,
	0x531D: 0xA560,
	0x531E: 0xFFFD,
	0x531F: 0xC9C2,
	0x5320: 0xA64B,
	0x5321: 0xA64A,
	0x5322: 0xC9C1,
	0x5323: 0xA758,
	0x5324: 0x8174,
	0x5325: 0xFFFD,
	0x5326: 0x8DC9,
	0x5327: 0x98DA,
	0x5328: 0xFFFD,
	0x5329: 0xFFFD,
	0x532A: 0xADEA,
	0x532B: 0xFFFD,
	0x532C: 0xFBD4,
	0x532D: 0xD46F,
	0x532E: 0x86AD,
	0x532F: 0xB6D7,
	0x5330: 0xE145,
	0x5331: 0xB9BC,
	0x5332: 0xFBD3,
	0x5333: 0xFBD5,
	0x5334: 0xE8FA,
	0x5335: 0xFFFD,
	0x5336: 0xFFFD,
	0x5337: 0xF3FD,
	0x5338: 0xC6C7,
	0x5339: 0xA4C7,
	0x533A: 0x83F1,
	0x533B: 0x8B4B,
	0x533C: 0xCBD8,
	0x533D: 0xCDF4,
	0x533E: 0xB0D0,
	0x533F: 0xB0CE,
	0x5340: 0xB0CF,
	0x5341: 0xA451,
	0x5342: 0x98DB,
	0x5343: 0xA464,
	0x5344: 0xA2CD,
	0x5345: 0xA4CA,
	0x5346: 0x8175,
	0x5347: 0xA4C9,
	0x5348: 0xA4C8,
	0x5349: 0xA563,
	0x534A: 0xA562,
	0x534B: 0xFFFD,
	0x534C: 0xC96D,
	0x534D: 0xC9C3,
	0x534E: 0x854F,
	0x534F: 0x8356,
	0x5350: 0xFFFD,
	0x5351: 0xA8F5,
	0x5352: 0xA8F2,
	0x5353: 0xA8F4,
	0x5354: 0xA8F3,
	0x5355: 0x84CB,
	0x5356: 0x886F,
	0x5357: 0xAB6E,
	0x5358: 0x936D,
	0x5359: 0xFFFD,
	0x535A: 0xB3D5,
	0x535B: 0xFFFD,
	0x535C: 0xA452,
	0x535D: 0x98DC,
	0x535E: 0xA4CB,
	0x535F: 0x8176,
	0x5360: 0xA565,
	0x5361: 0xA564,
	0x5362: 0x8941,
	0x5363: 0xCA72,
	0x5364: 0x84C0,
	0x5365: 0xFFFD,
	0x5366: 0xA8F6,
	0x5367: 0x8360,
	0x5368: 0xFFFD,
	0x5369: 0xC6C8,
	0x536A: 0xFFFD,
	0x536B: 0x8855,
	0x536C: 0xC957,
	0x536D: 0x95F2,
	0x536E: 0xA567,
	0x536F: 0xA566,
	0x5370: 0xA64C,
	0x5371: 0xA64D,
	0x5372: 0xCA73,
	0x5373: 0xA759,
	0x5374: 0x836A,
	0x5375: 0xA75A,
	0x5376: 0xFFFD,
	0x5377: 0xA8F7,
	0x5378: 0xA8F8,
	0x5379: 0xA8F9,
	0x537A: 0x8DBD,
	0x537B: 0xAB6F,
	0x537C: 0xCDF5,
	0x537D: 0x98DD,
	0x537E: 0x98DE,
	0x537F: 0xADEB,
	0x5380: 0xFFFD,
	0x5381: 0xFFFD,
	0x5382: 0xC944,
	0x5383: 0xFFFD,
	0x5384: 0xA4CC,
	0x5385: 0x8D6D,
	0x5386: 0x88E5,
	0x5387: 0xFFFD,
	0x5388: 0xFFFD,
	0x5389: 0x87AD,
	0x538A: 0xC9C4,
	0x538B: 0x89CD,
	0x538C: 0x86AE,
	0x538D: 0x8DBB,
	0x538E: 0xCA74,
	0x538F: 0xCA75,
	0x5390: 0xFFFD,
	0x5391: 0xFFFD,
	0x5392: 0xCBD9,
	0x5393: 0x8177,
	0x5394: 0xCBDA,
	0x5395: 0x84DA,
	0x5396: 0xCDF7,
	0x5397: 0xCDF6,
	0x5398: 0xCDF9,
	0x5399: 0xCDF8,
	0x539A: 0xAB70,
	0x539B: 0xFFFD,
	0x539C: 0xD470,
	0x539D: 0xADED,
	0x539E: 0xD0EF,
	0x539F: 0xADEC,
	0x53A0: 0x95E8,
	0x53A1: 0xFFFD,
	0x53A2: 0x95E9,
	0x53A3: 0x8FB6,
	0x53A4: 0xD864,
	0x53A5: 0xB3D6,
	0x53A6: 0x957A,
	0x53A7: 0xD865,
	0x53A8: 0x87C5,
	0x53A9: 0x84DB,
	0x53AA: 0xFBD7,
	0x53AB: 0xFBD6,
	0x53AC: 0xE146,
	0x53AD: 0xB9BD,
	0x53AE: 0x87C7,
	0x53AF: 0xFFFD,
	0x53B0: 0x8178,
	0x53B1: 0xFFFD,
	0x53B2: 0xBC46,
	0x53B3: 0x92BA,
	0x53B4: 0xF1EF,
	0x53B5: 0xFFFD,
	0x53B6: 0xC6C9,
	0x53B7: 0xFFFD,
	0x53B8: 0xFFFD,
	0x53B9: 0xC958,
	0x53BA: 0xFFFD,
	0x53BB: 0xA568,
	0x53BC: 0xFFFD,
	0x53BD: 0xFFFD,
	0x53BE: 0xFFFD,
	0x53BF: 0x894F,
	0x53C0: 0xFFFD,
	0x53C1: 0x9548,
	0x53C2: 0x83F2,
	0x53C3: 0xB0D1,
	0x53C4: 0xFFFD,
	0x53C5: 0x98DF,
	0x53C6: 0xFFFD,
	0x53C7: 0xFFFD,
	0x53C8: 0xA453,
	0x53C9: 0xA465,
	0x53CA: 0xA4CE,
	0x53CB: 0xA4CD,
	0x53CC: 0x8B5A,
	0x53CD: 0xA4CF,
	0x53CE: 0x8342,
	0x53CF: 0xFFFD,
	0x53D0: 0x98E0,
	0x53D1: 0x84FA,
	0x53D2: 0x98E1,
	0x53D3: 0xFFFD,
	0x53D4: 0xA8FB,
	0x53D5: 0xFFFD,
	0x53D6: 0xA8FA,
	0x53D7: 0xA8FC,
	0x53D8: 0x8D40,
	0x53D9: 0x95B3,
	0x53DA: 0xFBDB,
	0x53DB: 0xAB71,
	0x53DC: 0xFFFD,
	0x53DD: 0x8179,
	0x53DE: 0xFFFD,
	0x53DF: 0xADEE,
	0x53E0: 0x8CD4,
	0x53E1: 0xE8FB,
	0x53E2: 0xC24F,
	0x53E3: 0xA466,
	0x53E4: 0xA56A,
	0x53E5: 0xA579,
	0x53E6: 0xA574,
	0x53E7: 0xFFFD,
	0x53E8: 0xA56F,
	0x53E9: 0xA56E,
	0x53EA: 0xA575,
	0x53EB: 0xA573,
	0x53EC: 0xA56C,
	0x53ED: 0xA57A,
	0x53EE: 0xA56D,
	0x53EF: 0xA569,
	0x53F0: 0xA578,
	0x53F1: 0xA577,
	0x53F2: 0xA576,
	0x53F3: 0xA56B,
	0x53F4: 0xFFFD,
	0x53F5: 0xA572,
	0x53F6: 0x85FC,
	0x53F7: 0x8641,
	0x53F8: 0xA571,
	0x53F9: 0x86B1,
	0x53FA: 0x9462,
	0x53FB: 0xA57B,
	0x53FC: 0xA570,
	0x53FD: 0x87B4,
	0x53FE: 0x98E2,
	0x53FF: 0xFFFD,
	0x5400: 0xFFFD,
	0x5401: 0xA653,
	0x5402: 0xFFFD,
	0x5403: 0xA659,
	0x5404: 0xA655,
	0x5405: 0xFFFD,
	0x5406: 0xA65B,
	0x5407: 0xC9C5,
	0x5408: 0xA658,
	0x5409: 0xA64E,
	0x540A: 0xA651,
	0x540B: 0xA654,
	0x540C: 0xA650,
	0x540D: 0xA657,
	0x540E: 0xA65A,
	0x540F: 0xA64F,
	0x5410: 0xA652,
	0x5411: 0xA656,
	0x5412: 0xA65C,
	0x5413: 0x89CC,
	0x5414: 0xFB43,
	0x5415: 0x90B8,
	0x5416: 0xFB42,
	0x5417: 0x85BA,
	0x5418: 0xCA7E,
	0x5419: 0xCA7B,
	0x541A: 0xA055,
	0x541B: 0xA767,
	0x541C: 0xCA7C,
	0x541D: 0xA75B,
	0x541E: 0xA75D,
	0x541F: 0xA775,
	0x5420: 0xA770,
	0x5421: 0x96B2,
	0x5422: 0xFFFD,
	0x5423: 0x817A,
	0x5424: 0xCAA5,
	0x5425: 0xCA7D,
	0x5426: 0xA75F,
	0x5427: 0xA761,
	0x5428: 0xCAA4,
	0x5429: 0xA768,
	0x542A: 0xCA78,
	0x542B: 0xA774,
	0x542C: 0xA776,
	0x542D: 0xA75C,
	0x542E: 0xA76D,
	0x542F: 0x8451,
	0x5430: 0xCA76,
	0x5431: 0xA773,
	0x5432: 0x96B4,
	0x5433: 0xA764,
	0x5434: 0x8345,
	0x5435: 0xA76E,
	0x5436: 0xA76F,
	0x5437: 0xCA77,
	0x5438: 0xA76C,
	0x5439: 0xA76A,
	0x543A: 0xFFFD,
	0x543B: 0xA76B,
	0x543C: 0xA771,
	0x543D: 0xCAA1,
	0x543E: 0xA75E,
	0x543F: 0xFFFD,
	0x5440: 0xA772,
	0x5441: 0xCAA3,
	0x5442: 0xA766,
	0x5443: 0xA763,
	0x5444: 0xFFFD,
	0x5445: 0xCA7A,
	0x5446: 0xA762,
	0x5447: 0xCAA6,
	0x5448: 0xA765,
	0x5449: 0x92BB,
	0x544A: 0xA769,
	0x544B: 0x96A4,
	0x544C: 0xFFFD,
	0x544D: 0xA05A,
	0x544E: 0xA760,
	0x544F: 0xCAA2,
	0x5450: 0x817B,
	0x5451: 0x817C,
	0x5452: 0x8EB2,
	0x5453: 0x8CCA,
	0x5454: 0xCA79,
	0x5455: 0x86B0,
	0x5456: 0x8FB7,
	0x5457: 0x8DC2,
	0x5458: 0x83B0,
	0x5459: 0x8DBC,
	0x545A: 0xFFFD,
	0x545B: 0x85BC,
	0x545C: 0x85BB,
	0x545D: 0xFFFD,
	0x545E: 0xFFFD,
	0x545F: 0x82AF,
	0x5460: 0xCBEB,
	0x5461: 0xCBEA,
	0x5462: 0xA94F,
	0x5463: 0xCBED,
	0x5464: 0xCBEF,
	0x5465: 0xCBE4,
	0x5466: 0xCBE7,
	0x5467: 0xCBEE,
	0x5468: 0xA950,
	0x5469: 0xFBD9,
	0x546A: 0x94FC,
	0x546B: 0xCBE1,
	0x546C: 0xCBE5,
	0x546D: 0x98E3,
	0x546E: 0xFFFD,
	0x546F: 0xCBE9,
	0x5470: 0xCE49,
	0x5471: 0xA94B,
	0x5472: 0xCE4D,
	0x5473: 0xA8FD,
	0x5474: 0xCBE6,
	0x5475: 0xA8FE,
	0x5476: 0xA94C,
	0x5477: 0xA945,
	0x5478: 0xA941,
	0x5479: 0xFFFD,
	0x547A: 0xCBE2,
	0x547B: 0xA944,
	0x547C: 0xA949,
	0x547D: 0xA952,
	0x547E: 0xCBE3,
	0x547F: 0xCBDC,
	0x5480: 0xA943,
	0x5481: 0xCBDD,
	0x5482: 0xCBDF,
	0x5483: 0xFFFD,
	0x5484: 0xA946,
	0x5485: 0x98E4,
	0x5486: 0xA948,
	0x5487: 0xCBDB,
	0x5488: 0xCBE0,
	0x5489: 0xFFFD,
	0x548A: 0x817D,
	0x548B: 0xA951,
	0x548C: 0xA94D,
	0x548D: 0xCBE8,
	0x548E: 0xA953,
	0x548F: 0x95A3,
	0x5490: 0xA94A,
	0x5491: 0xCBDE,
	0x5492: 0xA947,
	0x5493: 0x98E5,
	0x5494: 0x96B6,
	0x5495: 0xA942,
	0x5496: 0xA940,
	0x5497: 0xA057,
	0x5498: 0xCBEC,
	0x5499: 0x8BF0,
	0x549A: 0xA94E,
	0x549B: 0x89CB,
	0x549C: 0xFBDA,
	0x549D: 0x817E,
	0x549E: 0x98E6,
	0x549F: 0xFFFD,
	0x54A0: 0xCE48,
	0x54A1: 0xCDFB,
	0x54A2: 0xCE4B,
	0x54A3: 0x81A1,
	0x54A4: 0x9579,
	0x54A5: 0xCDFD,
	0x54A6: 0xAB78,
	0x54A7: 0xABA8,
	0x54A8: 0xAB74,
	0x54A9: 0xABA7,
	0x54AA: 0xAB7D,
	0x54AB: 0xABA4,
	0x54AC: 0xAB72,
	0x54AD: 0xCDFC,
	0x54AE: 0xCE43,
	0x54AF: 0xABA3,
	0x54B0: 0xCE4F,
	0x54B1: 0xABA5,
	0x54B2: 0x9446,
	0x54B3: 0xAB79,
	0x54B4: 0x81A2,
	0x54B5: 0xFFFD,
	0x54B6: 0xCE45,
	0x54B7: 0xCE42,
	0x54B8: 0xAB77,
	0x54B9: 0x98E7,
	0x54BA: 0xCDFA,
	0x54BB: 0xABA6,
	0x54BC: 0xCE4A,
	0x54BD: 0xAB7C,
	0x54BE: 0xCE4C,
	0x54BF: 0xABA9,
	0x54C0: 0xAB73,
	0x54C1: 0xAB7E,
	0x54C2: 0xAB7B,
	0x54C3: 0xCE40,
	0x54C4: 0xABA1,
	0x54C5: 0xCE46,
	0x54C6: 0xCE47,
	0x54C7: 0xAB7A,
	0x54C8: 0xABA2,
	0x54C9: 0xAB76,
	0x54CA: 0xFFFD,
	0x54CB: 0xFB4A,
	0x54CC: 0x96CF,
	0x54CD: 0x8CB7,
	0x54CE: 0xAB75,
	0x54CF: 0xCDFE,
	0x54D0: 0x81A3,
	0x54D1: 0x83F3,
	0x54D2: 0x8EE2,
	0x54D3: 0x8EB1,
	0x54D4: 0x86B4,
	0x54D5: 0x8EE3,
	0x54D6: 0xCE44,
	0x54D7: 0x87B0,
	0x54D8: 0x9463,
	0x54D9: 0x8EE4,
	0x54DA: 0x96B3,
	0x54DB: 0xFFFD,
	0x54DC: 0x8F4F,
	0x54DD: 0x88CE,
	0x54DE: 0xCE4E,
	0x54DF: 0x84CC,
	0x54E0: 0xD144,
	0x54E1: 0xADFB,
	0x54E2: 0xD0F1,
	0x54E3: 0x98E8,
	0x54E4: 0xD0F6,
	0x54E5: 0xADF4,
	0x54E6: 0xAE40,
	0x54E7: 0xD0F4,
	0x54E8: 0xADEF,
	0x54E9: 0xADF9,
	0x54EA: 0xADFE,
	0x54EB: 0xD0FB,
	0x54EC: 0xFFFD,
	0x54ED: 0xADFA,
	0x54EE: 0xADFD,
	0x54EF: 0x98E9,
	0x54F0: 0xFFFD,
	0x54F1: 0xD0FE,
	0x54F2: 0xADF5,
	0x54F3: 0xD0F5,
	0x54F4: 0xFFFD,
	0x54F5: 0xFFFD,
	0x54F6: 0xFFFD,
	0x54F7: 0xD142,
	0x54F8: 0xD143,
	0x54F9: 0xFFFD,
	0x54FA: 0xADF7,
	0x54FB: 0xD141,
	0x54FC: 0xADF3,
	0x54FD: 0xAE43,
	0x54FE: 0xFFFD,
	0x54FF: 0xD0F8,
	0x5500: 0xFFFD,
	0x5501: 0xADF1,
	0x5502: 0xFB5A,
	0x5503: 0xD146,
	0x5504: 0xD0F9,
	0x5505: 0xD0FD,
	0x5506: 0xADF6,
	0x5507: 0xAE42,
	0x5508: 0xD0FA,
	0x5509: 0xADFC,
	0x550A: 0xD140,
	0x550B: 0xD147,
	0x550C: 0xD4A1,
	0x550D: 0x98EA,
	0x550E: 0xD145,
	0x550F: 0xAE44,
	0x5510: 0xADF0,
	0x5511: 0xD0FC,
	0x5512: 0xD0F3,
	0x5513: 0xFB52,
	0x5514: 0xADF8,
	0x5515: 0xFFFD,
	0x5516: 0x8240,
	0x5517: 0xD0F2,
	0x5518: 0x98EB,
	0x5519: 0xFFFD,
	0x551A: 0xD0F7,
	0x551B: 0x8E66,
	0x551C: 0xFFFD,
	0x551D: 0xFFFD,
	0x551E: 0xFB55,
	0x551F: 0xFFFD,
	0x5520: 0x87AE,
	0x5521: 0xFFFD,
	0x5522: 0x8E41,
	0x5523: 0x81A4,
	0x5524: 0x84CD,
	0x5525: 0x98EC,
	0x5526: 0xD0F0,
	0x5527: 0xAE41,
	0x5528: 0x98ED,
	0x5529: 0xFFFD,
	0x552A: 0xD477,
	0x552B: 0x98EE,
	0x552C: 0xB0E4,
	0x552D: 0xD4A7,
	0x552E: 0xB0E2,
	0x552F: 0xB0DF,
	0x5530: 0xD47C,
	0x5531: 0xB0DB,
	0x5532: 0xD4A2,
	0x5533: 0xB0E6,
	0x5534: 0xD476,
	0x5535: 0xD47B,
	0x5536: 0xD47A,
	0x5537: 0xADF2,
	0x5538: 0xB0E1,
	0x5539: 0xD4A5,
	0x553A: 0xFFFD,
	0x553B: 0xD4A8,
	0x553C: 0xD473,
	0x553D: 0xFFFD,
	0x553E: 0xB3E8,
	0x553F: 0x81A5,
	0x5540: 0xD4A9,
	0x5541: 0xB0E7,
	0x5542: 0xFFFD,
	0x5543: 0xB0D9,
	0x5544: 0xB0D6,
	0x5545: 0xD47E,
	0x5546: 0xB0D3,
	0x5547: 0x98EF,
	0x5548: 0xD4A6,
	0x5549: 0x96B1,
	0x554A: 0xB0DA,
	0x554B: 0xD4AA,
	0x554C: 0x81A6,
	0x554D: 0xD474,
	0x554E: 0xD4A4,
	0x554F: 0xB0DD,
	0x5550: 0xD475,
	0x5551: 0xD478,
	0x5552: 0xD47D,
	0x5553: 0x81A7,
	0x5554: 0xFFFD,
	0x5555: 0xB0DE,
	0x5556: 0xB0DC,
	0x5557: 0xB0E8,
	0x5558: 0xFFFD,
	0x5559: 0xFFFD,
	0x555A: 0xFFFD,
	0x555B: 0xFFFD,
	0x555C: 0xB0E3,
	0x555D: 0x81A8,
	0x555E: 0xB0D7,
	0x555F: 0xB1D2,
	0x5560: 0xFFFD,
	0x5561: 0xB0D8,
	0x5562: 0xD479,
	0x5563: 0xB0E5,
	0x5564: 0xB0E0,
	0x5565: 0xD4A3,
	0x5566: 0xB0D5,
	0x5567: 0x86B3,
	0x5568: 0xFFFD,
	0x5569: 0xFB5B,
	0x556A: 0xB0D4,
	0x556B: 0xA046,
	0x556C: 0x81A9,
	0x556D: 0x8C6E,
	0x556E: 0x8CC7,
	0x556F: 0xFFFD,
	0x5570: 0xFFFD,
	0x5571: 0xA049,
	0x5572: 0xA045,
	0x5573: 0xFBDD,
	0x5574: 0xFFFD,
	0x5575: 0xD471,
	0x5576: 0xD472,
	0x5577: 0xD86A,
	0x5578: 0x87B3,
	0x5579: 0x98F0,
	0x557A: 0xFFFD,
	0x557B: 0xB3D7,
	0x557C: 0xB3DA,
	0x557D: 0xD875,
	0x557E: 0xB3EE,
	0x557F: 0xD878,
	0x5580: 0xB3D8,
	0x5581: 0xD871,
	0x5582: 0xB3DE,
	0x5583: 0xB3E4,
	0x5584: 0xB5BD,
	0x5585: 0xFFFD,
	0x5586: 0x95ED,
	0x5587: 0xB3E2,
	0x5588: 0xD86E,
	0x5589: 0xB3EF,
	0x558A: 0xB3DB,
	0x558B: 0xB3E3,
	0x558C: 0xD876,
	0x558D: 0xDCD7,
	0x558E: 0xD87B,
	0x558F: 0xD86F,
	0x5590: 0x98F1,
	0x5591: 0xD866,
	0x5592: 0xD873,
	0x5593: 0xD86D,
	0x5594: 0xB3E1,
	0x5595: 0xD879,
	0x5596: 0xFFFD,
	0x5597: 0xFFFD,
	0x5598: 0xB3DD,
	0x5599: 0xB3F1,
	0x559A: 0xB3EA,
	0x559B: 0xFFFD,
	0x559C: 0xB3DF,
	0x559D: 0xB3DC,
	0x559E: 0x81AA,
	0x559F: 0xB3E7,
	0x55A0: 0xFFFD,
	0x55A1: 0xD87A,
	0x55A2: 0xD86C,
	0x55A3: 0xD872,
	0x55A4: 0xD874,
	0x55A5: 0xD868,
	0x55A6: 0xD877,
	0x55A7: 0xB3D9,
	0x55A8: 0xD867,
	0x55A9: 0x81AB,
	0x55AA: 0xB3E0,
	0x55AB: 0xB3F0,
	0x55AC: 0xB3EC,
	0x55AD: 0xD869,
	0x55AE: 0xB3E6,
	0x55AF: 0xFFFD,
	0x55B0: 0x9442,
	0x55B1: 0xB3ED,
	0x55B2: 0xB3E9,
	0x55B3: 0xB3E5,
	0x55B4: 0x98F2,
	0x55B5: 0xD870,
	0x55B6: 0x9249,
	0x55B7: 0x87B2,
	0x55B8: 0xFFFD,
	0x55B9: 0x96B5,
	0x55BA: 0xA04A,
	0x55BB: 0xB3EB,
	0x55BC: 0xFB4C,
	0x55BD: 0x86B2,
	0x55BE: 0x8FD9,
	0x55BF: 0xDCD5,
	0x55C0: 0xDCD1,
	0x55C1: 0x98F3,
	0x55C2: 0xDCE0,
	0x55C3: 0xDCCA,
	0x55C4: 0xDCD3,
	0x55C5: 0xB6E5,
	0x55C6: 0xB6E6,
	0x55C7: 0xB6DE,
	0x55C8: 0xDCDC,
	0x55C9: 0xB6E8,
	0x55CA: 0xDCCF,
	0x55CB: 0xDCCE,
	0x55CC: 0xDCCC,
	0x55CD: 0xDCDE,
	0x55CE: 0xB6DC,
	0x55CF: 0xDCD8,
	0x55D0: 0xDCCD,
	0x55D1: 0xB6DF,
	0x55D2: 0xDCD6,
	0x55D3: 0xB6DA,
	0x55D4: 0xDCD2,
	0x55D5: 0xDCD9,
	0x55D6: 0xDCDB,
	0x55D7: 0x98F4,
	0x55D8: 0x98F5,
	0x55D9: 0xDCDF,
	0x55DA: 0xB6E3,
	0x55DB: 0xDCCB,
	0x55DC: 0xB6DD,
	0x55DD: 0xDCD0,
	0x55DE: 0xFB56,
	0x55DF: 0xB6D8,
	0x55E0: 0xFFFD,
	0x55E1: 0xB6E4,
	0x55E2: 0xDCDA,
	0x55E3: 0xB6E0,
	0x55E4: 0xB6E1,
	0x55E5: 0xB6E7,
	0x55E6: 0xB6DB,
	0x55E7: 0xA25F,
	0x55E8: 0xB6D9,
	0x55E9: 0xDCD4,
	0x55EA: 0x96C9,
	0x55EB: 0x8C6D,
	0x55EC: 0x81AC,
	0x55ED: 0xFFFD,
	0x55EE: 0xFFFD,
	0x55EF: 0xB6E2,
	0x55F0: 0xA04D,
	0x55F1: 0xA04B,
	0x55F2: 0xDCDD,
	0x55F3: 0x88CF,
	0x55F4: 0xFFFD,
	0x55F5: 0x81AD,
	0x55F6: 0xB9CD,
	0x55F7: 0xB9C8,
	0x55F8: 0xFFFD,
	0x55F9: 0xE155,
	0x55FA: 0xE151,
	0x55FB: 0x98F6,
	0x55FC: 0xE14B,
	0x55FD: 0xB9C2,
	0x55FE: 0xB9BE,
	0x55FF: 0xE154,
	0x5600: 0xB9BF,
	0x5601: 0xE14E,
	0x5602: 0xE150,
	0x5603: 0xFFFD,
	0x5604: 0xE153,
	0x5605: 0xA04E,
	0x5606: 0xB9C4,
	0x5607: 0xFFFD,
	0x5608: 0xB9CB,
	0x5609: 0xB9C5,
	0x560A: 0xFFFD,
	0x560B: 0xFFFD,
	0x560C: 0xE149,
	0x560D: 0xB9C6,
	0x560E: 0xB9C7,
	0x560F: 0xE14C,
	0x5610: 0xB9CC,
	0x5611: 0xFBE1,
	0x5612: 0xE14A,
	0x5613: 0xE14F,
	0x5614: 0xB9C3,
	0x5615: 0xE148,
	0x5616: 0xB9C9,
	0x5617: 0xB9C1,
	0x5618: 0x82B3,
	0x5619: 0xFFFD,
	0x561A: 0xFFFD,
	0x561B: 0xB9C0,
	0x561C: 0xE14D,
	0x561D: 0xE152,
	0x561E: 0xA052,
	0x561F: 0xB9CA,
	0x5620: 0xFCD9,
	0x5621: 0x98F8,
	0x5622: 0xA04F,
	0x5623: 0x81AE,
	0x5624: 0x8BF1,
	0x5625: 0xFB65,
	0x5626: 0xFFFD,
	0x5627: 0xE147,
	0x5628: 0xFFFD,
	0x5629: 0xBC4D,
	0x562A: 0xE547,
	0x562B: 0xFFFD,
	0x562C: 0xE544,
	0x562D: 0xA050,
	0x562E: 0xBC47,
	0x562F: 0xBC53,
	0x5630: 0xBC54,
	0x5631: 0x8D51,
	0x5632: 0xBC4A,
	0x5633: 0xE542,
	0x5634: 0xBC4C,
	0x5635: 0xE4F9,
	0x5636: 0xBC52,
	0x5637: 0xFE5D,
	0x5638: 0xE546,
	0x5639: 0xBC49,
	0x563A: 0xE548,
	0x563B: 0xBC48,
	0x563C: 0xFFFD,
	0x563D: 0xE543,
	0x563E: 0xE545,
	0x563F: 0xBC4B,
	0x5640: 0xE541,
	0x5641: 0xE4FA,
	0x5642: 0xE4F7,
	0x5643: 0xA051,
	0x5644: 0xFFFD,
	0x5645: 0xD86B,
	0x5646: 0xE4FD,
	0x5647: 0xFFFD,
	0x5648: 0xE4F6,
	0x5649: 0xE4FC,
	0x564A: 0xE4FB,
	0x564B: 0xFFFD,
	0x564C: 0xE4F8,
	0x564D: 0xFBE2,
	0x564E: 0xBC4F,
	0x564F: 0xFB6A,
	0x5650: 0x81AF,
	0x5651: 0xFFFD,
	0x5652: 0x98FA,
	0x5653: 0xBC4E,
	0x5654: 0xFBE4,
	0x5655: 0xFFFD,
	0x5656: 0xFFFD,
	0x5657: 0xBC50,
	0x5658: 0xE4FE,
	0x5659: 0xBEB2,
	0x565A: 0xE540,
	0x565B: 0x824F,
	0x565C: 0x8ABE,
	0x565D: 0x9940,
	0x565E: 0xE945,
	0x565F: 0xFFFD,
	0x5660: 0xE8FD,
	0x5661: 0x9955,
	0x5662: 0xBEBE,
	0x5663: 0xE942,
	0x5664: 0xBEB6,
	0x5665: 0xBEBA,
	0x5666: 0xE941,
	0x5667: 0xFFFD,
	0x5668: 0xBEB9,
	0x5669: 0xBEB5,
	0x566A: 0xBEB8,
	0x566B: 0xBEB3,
	0x566C: 0xBEBD,
	0x566D: 0xE943,
	0x566E: 0xE8FE,
	0x566F: 0xBEBC,
	0x5670: 0xE8FC,
	0x5671: 0xBEBB,
	0x5672: 0xE944,
	0x5673: 0xE940,
	0x5674: 0xBC51,
	0x5675: 0xFFFD,
	0x5676: 0xBEBF,
	0x5677: 0xE946,
	0x5678: 0xBEB7,
	0x5679: 0xBEB4,
	0x567A: 0x9457,
	0x567B: 0x96CA,
	0x567C: 0x81B0,
	0x567D: 0xFFFD,
	0x567E: 0xECC6,
	0x567F: 0xECC8,
	0x5680: 0xC07B,
	0x5681: 0xECC9,
	0x5682: 0xECC7,
	0x5683: 0xECC5,
	0x5684: 0xECC4,
	0x5685: 0xC07D,
	0x5686: 0xECC3,
	0x5687: 0xC07E,
	0x5688: 0xFFFD,
	0x5689: 0x9956,
	0x568A: 0x81B1,
	0x568B: 0x9957,
	0x568C: 0xECC1,
	0x568D: 0xECC2,
	0x568E: 0xC07A,
	0x568F: 0xC0A1,
	0x5690: 0xC07C,
	0x5691: 0xFFFD,
	0x5692: 0xA053,
	0x5693: 0xECC0,
	0x5694: 0x81B2,
	0x5695: 0xC250,
	0x5696: 0xFFFD,
	0x5697: 0xEFBC,
	0x5698: 0xEFBA,
	0x5699: 0xEFBF,
	0x569A: 0xEFBD,
	0x569B: 0xFFFD,
	0x569C: 0xEFBB,
	0x569D: 0xEFBE,
	0x569E: 0x9958,
	0x569F: 0xA05C,
	0x56A0: 0x81B3,
	0x56A1: 0x9959,
	0x56A2: 0x8274,
	0x56A3: 0x8C6F,
	0x56A4: 0xA05B,
	0x56A5: 0xC360,
	0x56A6: 0xF1F2,
	0x56A7: 0xF1F3,
	0x56A8: 0xC456,
	0x56A9: 0xFFFD,
	0x56AA: 0xF1F4,
	0x56AB: 0xF1F0,
	0x56AC: 0xF1F5,
	0x56AD: 0xF1F1,
	0x56AE: 0xC251,
	0x56AF: 0x81B4,
	0x56B0: 0xFFFD,
	0x56B1: 0x995A,
	0x56B2: 0xF3FE,
	0x56B3: 0xF441,
	0x56B4: 0xC459,
	0x56B5: 0xF440,
	0x56B6: 0xC458,
	0x56B7: 0xC457,
	0x56B8: 0xFFFD,
	0x56B9: 0x995B,
	0x56BA: 0xFFFD,
	0x56BB: 0xFFFD,
	0x56BC: 0xC45A,
	0x56BD: 0xF5C5,
	0x56BE: 0xF5C6,
	0x56BF: 0x995C,
	0x56C0: 0xC4DA,
	0x56C1: 0xC4D9,
	0x56C2: 0xC4DB,
	0x56C3: 0xF5C4,
	0x56C4: 0xFFFD,
	0x56C5: 0xF6D8,
	0x56C6: 0xF6D7,
	0x56C7: 0xFFFD,
	0x56C8: 0xC56D,
	0x56C9: 0xC56F,
	0x56CA: 0xC56E,
	0x56CB: 0xF6D9,
	0x56CC: 0xC5C8,
	0x56CD: 0xF8A6,
	0x56CE: 0x9464,
	0x56CF: 0xFFFD,
	0x56D0: 0xFFFD,
	0x56D1: 0xC5F1,
	0x56D2: 0xFFFD,
	0x56D3: 0xF8A5,
	0x56D4: 0xF8EE,
	0x56D5: 0xFFFD,
	0x56D6: 0x995D,
	0x56D7: 0xC949,
	0x56D8: 0x81B5,
	0x56D9: 0xFFFD,
	0x56DA: 0xA57D,
	0x56DB: 0xA57C,
	0x56DC: 0xFFFD,
	0x56DD: 0xA65F,
	0x56DE: 0xA65E,
	0x56DF: 0xC9C7,
	0x56E0: 0xA65D,
	0x56E1: 0xC9C6,
	0x56E2: 0x86B5,
	0x56E3: 0x936F,
	0x56E4: 0xA779,
	0x56E5: 0xCAA9,
	0x56E6: 0xFFFD,
	0x56E7: 0xCAA8,
	0x56E8: 0xFFFD,
	0x56E9: 0xFFFD,
	0x56EA: 0xA777,
	0x56EB: 0xA77A,
	0x56EC: 0xFFFD,
	0x56ED: 0x85BD,
	0x56EE: 0xCAA7,
	0x56EF: 0x995E,
	0x56F0: 0xA778,
	0x56F1: 0x8346,
	0x56F2: 0x9243,
	0x56F3: 0x92F6,
	0x56F4: 0x84CF,
	0x56F5: 0x8DCA,
	0x56F6: 0xFFFD,
	0x56F7: 0xCBF0,
	0x56F8: 0xFFFD,
	0x56F9: 0xCBF1,
	0x56FA: 0xA954,
	0x56FB: 0x9D56,
	0x56FC: 0xFFFD,
	0x56FD: 0x83F6,
	0x56FE: 0x86B6,
	0x56FF: 0xABAA,
	0x5700: 0x81B6,
	0x5701: 0xD148,
	0x5702: 0xD149,
	0x5703: 0xAE45,
	0x5704: 0xAE46,
	0x5705: 0xFFFD,
	0x5706: 0x85BE,
	0x5707: 0xD4AC,
	0x5708: 0xB0E9,
	0x5709: 0xB0EB,
	0x570A: 0xD4AB,
	0x570B: 0xB0EA,
	0x570C: 0xD87C,
	0x570D: 0xB3F2,
	0x570E: 0xFFFD,
	0x570F: 0x92B5,
	0x5710: 0xFFFD,
	0x5711: 0xFFFD,
	0x5712: 0xB6E9,
	0x5713: 0xB6EA,
	0x5714: 0xDCE1,
	0x5715: 0x995F,
	0x5716: 0xB9CF,
	0x5717: 0xFFFD,
	0x5718: 0xB9CE,
	0x5719: 0xFFFD,
	0x571A: 0xE549,
	0x571B: 0xE948,
	0x571C: 0xE947,
	0x571D: 0x9960,
	0x571E: 0xF96B,
	0x571F: 0xA467,
	0x5720: 0xC959,
	0x5721: 0xFFFD,
	0x5722: 0xC96E,
	0x5723: 0xC96F,
	0x5724: 0xFFFD,
	0x5725: 0xFFFD,
	0x5726: 0x9465,
	0x5727: 0x9242,
	0x5728: 0xA662,
	0x5729: 0xA666,
	0x572A: 0xC9C9,
	0x572B: 0xFFFD,
	0x572C: 0xA664,
	0x572D: 0xA663,
	0x572E: 0xC9C8,
	0x572F: 0xA665,
	0x5730: 0xA661,
	0x5731: 0xFFFD,
	0x5732: 0x9961,
	0x5733: 0xA660,
	0x5734: 0xC9CA,
	0x5735: 0xFFFD,
	0x5736: 0xFFFD,
	0x5737: 0x9466,
	0x5738: 0x9467,
	0x5739: 0x8ABF,
	0x573A: 0x84D1,
	0x573B: 0xA7A6,
	0x573C: 0xFFFD,
	0x573D: 0x9962,
	0x573E: 0xA7A3,
	0x573F: 0x9963,
	0x5740: 0xA77D,
	0x5741: 0xCAAA,
	0x5742: 0x95B5,
	0x5743: 0x9964,
	0x5744: 0xFFFD,
	0x5745: 0xCAAB,
	0x5746: 0xFBE7,
	0x5747: 0xA7A1,
	0x5748: 0xFFFD,
	0x5749: 0xCAAD,
	0x574A: 0xA77B,
	0x574B: 0xCAAE,
	0x574C: 0xCAAC,
	0x574D: 0xA77E,
	0x574E: 0xA7A2,
	0x574F: 0xA7A5,
	0x5750: 0xA7A4,
	0x5751: 0xA77C,
	0x5752: 0xCAAF,
	0x5753: 0xFFFD,
	0x5754: 0xFE6F,
	0x5755: 0xFFFD,
	0x5756: 0xFFFD,
	0x5757: 0x85C0,
	0x5758: 0xFFFD,
	0x5759: 0x81B7,
	0x575A: 0x83F7,
	0x575B: 0x88D1,
	0x575C: 0x8B6F,
	0x575D: 0x8D52,
	0x575E: 0x85C1,
	0x575F: 0x87B6,
	0x5760: 0x87B7,
	0x5761: 0xA959,
	0x5762: 0xCBFE,
	0x5763: 0xFFFD,
	0x5764: 0xA95B,
	0x5765: 0x81B8,
	0x5766: 0xA95A,
	0x5767: 0xFBE9,
	0x5768: 0xCC40,
	0x5769: 0xA958,
	0x576A: 0xA957,
	0x576B: 0xCBF5,
	0x576C: 0xFFFD,
	0x576D: 0xCBF4,
	0x576E: 0xFFFD,
	0x576F: 0xCBF2,
	0x5770: 0xCBF7,
	0x5771: 0xCBF6,
	0x5772: 0xCBF3,
	0x5773: 0xCBFC,
	0x5774: 0xCBFD,
	0x5775: 0xCBFA,
	0x5776: 0xCBF8,
	0x5777: 0xA956,
	0x5778: 0xFFFD,
	0x5779: 0xFFFD,
	0x577A: 0xFBE8,
	0x577B: 0xCBFB,
	0x577C: 0xA95C,
	0x577D: 0xCC41,
	0x577E: 0x9966,
	0x577F: 0x81B9,
	0x5780: 0xCBF9,
	0x5781: 0xFFFD,
	0x5782: 0xABAB,
	0x5783: 0xA955,
	0x5784: 0x8B6E,
	0x5785: 0x81BA,
	0x5786: 0x8FB8,
	0x5787: 0xFFFD,
	0x5788: 0x9468,
	0x5789: 0x81BB,
	0x578A: 0x9967,
	0x578B: 0xABAC,
	0x578C: 0xCE54,
	0x578D: 0x9968,
	0x578E: 0xFFFD,
	0x578F: 0xCE5A,
	0x5790: 0x9969,
	0x5791: 0xFFFD,
	0x5792: 0x8AC0,
	0x5793: 0xABB2,
	0x5794: 0xCE58,
	0x5795: 0xCE5E,
	0x5796: 0xFFFD,
	0x5797: 0xCE55,
	0x5798: 0xCE59,
	0x5799: 0xCE5B,
	0x579A: 0xCE5D,
	0x579B: 0xCE57,
	0x579C: 0x996A,
	0x579D: 0xCE56,
	0x579E: 0xCE51,
	0x579F: 0xCE52,
	0x57A0: 0xABAD,
	0x57A1: 0x81BC,
	0x57A2: 0xABAF,
	0x57A3: 0xABAE,
	0x57A4: 0xCE53,
	0x57A5: 0xCE5C,
	0x57A6: 0x88D0,
	0x57A7: 0x8DB6,
	0x57A8: 0xFFFD,
	0x57A9: 0x83F8,
	0x57AA: 0x946A,
	0x57AB: 0x86B8,
	0x57AC: 0x81BD,
	0x57AD: 0x8DCB,
	0x57AE: 0xABB1,
	0x57AF: 0xFFFD,
	0x57B0: 0x946B,
	0x57B1: 0xFFFD,
	0x57B2: 0x8E42,
	0x57B3: 0x9469,
	0x57B4: 0x81BE,
	0x57B5: 0xCE50,
	0x57B6: 0xD153,
	0x57B7: 0xFFFD,
	0x57B8: 0xD152,
	0x57B9: 0xD157,
	0x57BA: 0xD14E,
	0x57BB: 0x996B,
	0x57BC: 0xD151,
	0x57BD: 0xD150,
	0x57BE: 0x996C,
	0x57BF: 0xD154,
	0x57C0: 0x81BF,
	0x57C1: 0xD158,
	0x57C2: 0xAE47,
	0x57C3: 0xAE4A,
	0x57C4: 0x996D,
	0x57C5: 0xFFFD,
	0x57C6: 0xD14F,
	0x57C7: 0xD155,
	0x57C8: 0x81C0,
	0x57C9: 0xFFFD,
	0x57CA: 0xFFFD,
	0x57CB: 0xAE49,
	0x57CC: 0xD14A,
	0x57CD: 0xFFFD,
	0x57CE: 0xABB0,
	0x57CF: 0xD4BA,
	0x57D0: 0xD156,
	0x57D1: 0xFFFD,
	0x57D2: 0xD14D,
	0x57D3: 0x81C1,
	0x57D4: 0xAE48,
	0x57D5: 0xD14C,
	0x57D6: 0x946C,
	0x57D7: 0xFE49,
	0x57D8: 0x85C2,
	0x57D9: 0x89CE,
	0x57DA: 0x84D3,
	0x57DB: 0xFFFD,
	0x57DC: 0xD4B1,
	0x57DD: 0xFBEC,
	0x57DE: 0x996E,
	0x57DF: 0xB0EC,
	0x57E0: 0xB0F0,
	0x57E1: 0xD4C1,
	0x57E2: 0xD4AF,
	0x57E3: 0xD4BD,
	0x57E4: 0xB0F1,
	0x57E5: 0xD4BF,
	0x57E6: 0xFBEB,
	0x57E7: 0xD4C5,
	0x57E8: 0xFFFD,
	0x57E9: 0xD4C9,
	0x57EA: 0xFFFD,
	0x57EB: 0xFFFD,
	0x57EC: 0xD4C0,
	0x57ED: 0xD4B4,
	0x57EE: 0xD4BC,
	0x57EF: 0x81C2,
	0x57F0: 0xD4CA,
	0x57F1: 0xD4C8,
	0x57F2: 0xD4BE,
	0x57F3: 0xD4B9,
	0x57F4: 0xD4B2,
	0x57F5: 0xD8A6,
	0x57F6: 0xD4B0,
	0x57F7: 0xB0F5,
	0x57F8: 0xD4B7,
	0x57F9: 0xB0F6,
	0x57FA: 0xB0F2,
	0x57FB: 0xD4AD,
	0x57FC: 0xD4C3,
	0x57FD: 0xD4B5,
	0x57FE: 0x996F,
	0x57FF: 0xFFFD,
	0x5800: 0xD4B3,
	0x5801: 0xD4C6,
	0x5802: 0xB0F3,
	0x5803: 0x954A,
	0x5804: 0xD4CC,
	0x5805: 0xB0ED,
	0x5806: 0xB0EF,
	0x5807: 0xD4BB,
	0x5808: 0xD4B6,
	0x5809: 0xAE4B,
	0x580A: 0xB0EE,
	0x580B: 0xD4B8,
	0x580C: 0xD4C7,
	0x580D: 0xD4CB,
	0x580E: 0xD4C2,
	0x580F: 0xFFFD,
	0x5810: 0xD4C4,
	0x5811: 0x86B9,
	0x5812: 0x9970,
	0x5813: 0xFFFD,
	0x5814: 0xD4AE,
	0x5815: 0x87B8,
	0x5816: 0xFFFD,
	0x5817: 0xFFFD,
	0x5818: 0xFFFD,
	0x5819: 0xD8A1,
	0x581A: 0xFFFD,
	0x581B: 0xD8AA,
	0x581C: 0xD8A9,
	0x581D: 0xB3FA,
	0x581E: 0xD8A2,
	0x581F: 0xFFFD,
	0x5820: 0xB3FB,
	0x5821: 0xB3F9,
	0x5822: 0x9971,
	0x5823: 0xD8A4,
	0x5824: 0xB3F6,
	0x5825: 0xD8A8,
	0x5826: 0xFBEF,
	0x5827: 0xD8A3,
	0x5828: 0xD8A5,
	0x5829: 0xD87D,
	0x582A: 0xB3F4,
	0x582B: 0xFFFD,
	0x582C: 0xD8B2,
	0x582D: 0xD8B1,
	0x582E: 0xD8AE,
	0x582F: 0xB3F3,
	0x5830: 0xB3F7,
	0x5831: 0xB3F8,
	0x5832: 0xD14B,
	0x5833: 0xD8AB,
	0x5834: 0xB3F5,
	0x5835: 0xB0F4,
	0x5836: 0xD8AD,
	0x5837: 0xD87E,
	0x5838: 0xD8B0,
	0x5839: 0xD8AF,
	0x583A: 0xFBEA,
	0x583B: 0xD8B3,
	0x583C: 0xFFFD,
	0x583D: 0xDCEF,
	0x583E: 0xFFFD,
	0x583F: 0xD8AC,
	0x5840: 0x9459,
	0x5841: 0x93E9,
	0x5842: 0xFFFD,
	0x5843: 0xFFFD,
	0x5844: 0x81C3,
	0x5845: 0xFFFD,
	0x5846: 0xFFFD,
	0x5847: 0x9972,
	0x5848: 0xD8A7,
	0x5849: 0xDCE7,
	0x584A: 0xB6F4,
	0x584B: 0xB6F7,
	0x584C: 0xB6F2,
	0x584D: 0xDCE6,
	0x584E: 0xDCEA,
	0x584F: 0xDCE5,
	0x5850: 0xFFFD,
	0x5851: 0xB6EC,
	0x5852: 0xB6F6,
	0x5853: 0xDCE2,
	0x5854: 0xB6F0,
	0x5855: 0xDCE9,
	0x5856: 0xFFFD,
	0x5857: 0xB6EE,
	0x5858: 0xB6ED,
	0x5859: 0xDCEC,
	0x585A: 0xB6EF,
	0x585B: 0xDCEE,
	0x585C: 0x9973,
	0x585D: 0xDCEB,
	0x585E: 0xB6EB,
	0x585F: 0x9974,
	0x5860: 0xFFFD,
	0x5861: 0xFFFD,
	0x5862: 0xB6F5,
	0x5863: 0xDCF0,
	0x5864: 0xDCE4,
	0x5865: 0xDCED,
	0x5866: 0xFFFD,
	0x5867: 0xFFFD,
	0x5868: 0xDCE3,
	0x5869: 0x95CD,
	0x586A: 0xFFFD,
	0x586B: 0xB6F1,
	0x586C: 0x81C4,
	0x586D: 0xB6F3,
	0x586E: 0xFFFD,
	0x586F: 0xDCE8,
	0x5870: 0x946D,
	0x5871: 0xDCF1,
	0x5872: 0x9562,
	0x5873: 0x9975,
	0x5874: 0xE15D,
	0x5875: 0xB9D0,
	0x5876: 0xE163,
	0x5877: 0xFFFD,
	0x5878: 0xFFFD,
	0x5879: 0xB9D5,
	0x587A: 0xE15F,
	0x587B: 0xE166,
	0x587C: 0xE157,
	0x587D: 0xB9D7,
	0x587E: 0xB9D1,
	0x587F: 0xE15C,
	0x5880: 0xBC55,
	0x5881: 0xE15B,
	0x5882: 0xE164,
	0x5883: 0xB9D2,
	0x5884: 0xFFFD,
	0x5885: 0xB9D6,
	0x5886: 0xE15A,
	0x5887: 0xE160,
	0x5888: 0xE165,
	0x5889: 0xE156,
	0x588A: 0xB9D4,
	0x588B: 0xE15E,
	0x588C: 0xFFFD,
	0x588D: 0xFFFD,
	0x588E: 0xE162,
	0x588F: 0xE168,
	0x5890: 0xE158,
	0x5891: 0xE161,
	0x5892: 0x81C5,
	0x5893: 0xB9D3,
	0x5894: 0xE167,
	0x5895: 0xFFFD,
	0x5896: 0xFFFD,
	0x5897: 0x935E,
	0x5898: 0xE159,
	0x5899: 0x89F5,
	0x589A: 0x81C6,
	0x589B: 0xFFFD,
	0x589C: 0xBC59,
	0x589D: 0xE54B,
	0x589E: 0xBC57,
	0x589F: 0xBC56,
	0x58A0: 0xE54D,
	0x58A1: 0xE552,
	0x58A2: 0xFFFD,
	0x58A3: 0xE54E,
	0x58A4: 0xFFFD,
	0x58A5: 0xE551,
	0x58A6: 0xBC5C,
	0x58A7: 0x9976,
	0x58A8: 0xBEA5,
	0x58A9: 0xBC5B,
	0x58AA: 0x9977,
	0x58AB: 0xE54A,
	0x58AC: 0xE550,
	0x58AD: 0xFFFD,
	0x58AE: 0xBC5A,
	0x58AF: 0xE54F,
	0x58B0: 0x9978,
	0x58B1: 0xE54C,
	0x58B2: 0x81C7,
	0x58B3: 0xBC58,
	0x58B4: 0xFFFD,
	0x58B5: 0x9979,
	0x58B6: 0x997A,
	0x58B7: 0xFFFD,
	0x58B8: 0x81C8,
	0x58B9: 0x946E,
	0x58BA: 0xE94D,
	0x58BB: 0xF9D9,
	0x58BC: 0xE94F,
	0x58BD: 0xE94A,
	0x58BE: 0xBEC1,
	0x58BF: 0xE94C,
	0x58C0: 0xFFFD,
	0x58C1: 0xBEC0,
	0x58C2: 0xE94E,
	0x58C3: 0xFFFD,
	0x58C4: 0xFFFD,
	0x58C5: 0xBEC3,
	0x58C6: 0xE950,
	0x58C7: 0xBEC2,
	0x58C8: 0xE949,
	0x58C9: 0xE94B,
	0x58CA: 0x925C,
	0x58CB: 0x997B,
	0x58CC: 0x92EE,
	0x58CD: 0xFFFD,
	0x58CE: 0xC0A5,
	0x58CF: 0xECCC,
	0x58D0: 0x997C,
	0x58D1: 0xC0A4,
	0x58D2: 0xECCD,
	0x58D3: 0xC0A3,
	0x58D4: 0xECCB,
	0x58D5: 0xC0A2,
	0x58D6: 0xECCA,
	0x58D7: 0x946F,
	0x58D8: 0xC253,
	0x58D9: 0xC252,
	0x58DA: 0xF1F6,
	0x58DB: 0xF1F8,
	0x58DC: 0xFBF0,
	0x58DD: 0xF1F7,
	0x58DE: 0xC361,
	0x58DF: 0xC362,
	0x58E0: 0x997D,
	0x58E1: 0xFFFD,
	0x58E2: 0xC363,
	0x58E3: 0xF442,
	0x58E4: 0xC45B,
	0x58E5: 0x81C9,
	0x58E6: 0xFFFD,
	0x58E7: 0xF7D3,
	0x58E8: 0xF7D2,
	0x58E9: 0xC5F2,
	0x58EA: 0xFFFD,
	0x58EB: 0xA468,
	0x58EC: 0xA4D0,
	0x58ED: 0xFFFD,
	0x58EE: 0x8347,
	0x58EF: 0xA7A7,
	0x58F0: 0x8A52,
	0x58F1: 0x9245,
	0x58F2: 0x93B3,
	0x58F3: 0x84EA,
	0x58F4: 0xCE5F,
	0x58F5: 0xFFFD,
	0x58F6: 0x84D4,
	0x58F7: 0x8241,
	0x58F8: 0xFFFD,
	0x58F9: 0xB3FC,
	0x58FA: 0xB3FD,
	0x58FB: 0x81CA,
	0x58FC: 0xDCF2,
	0x58FD: 0xB9D8,
	0x58FE: 0xE169,
	0x58FF: 0xE553,
	0x5900: 0xFFFD,
	0x5901: 0xFFFD,
	0x5902: 0x81CB,
	0x5903: 0xC95A,
	0x5904: 0x847A,
	0x5905: 0x997E,
	0x5906: 0xCAB0,
	0x5907: 0x84C2,
	0x5908: 0xFFFD,
	0x5909: 0x93C4,
	0x590A: 0xC6CA,
	0x590B: 0x81CC,
	0x590C: 0xCC42,
	0x590D: 0xCE60,
	0x590E: 0xD159,
	0x590F: 0xAE4C,
	0x5910: 0x81CD,
	0x5911: 0x99A1,
	0x5912: 0xF1F9,
	0x5913: 0xFFFD,
	0x5914: 0xC4DC,
	0x5915: 0xA469,
	0x5916: 0xA57E,
	0x5917: 0xC970,
	0x5918: 0x81CE,
	0x5919: 0xA667,
	0x591A: 0xA668,
	0x591B: 0x81CF,
	0x591C: 0xA95D,
	0x591D: 0x9D58,
	0x591E: 0xFFFD,
	0x591F: 0x83FA,
	0x5920: 0xB0F7,
	0x5921: 0xFFFD,
	0x5922: 0xB9DA,
	0x5923: 0xFFFD,
	0x5924: 0xB9DB,
	0x5925: 0xB9D9,
	0x5926: 0xFFFD,
	0x5927: 0xA46A,
	0x5928: 0xFFFD,
	0x5929: 0xA4D1,
	0x592A: 0xA4D3,
	0x592B: 0xA4D2,
	0x592C: 0xC95B,
	0x592D: 0xA4D4,
	0x592E: 0xA5A1,
	0x592F: 0xC971,
	0x5930: 0xFFFD,
	0x5931: 0xA5A2,
	0x5932: 0x82B5,
	0x5933: 0xFFFD,
	0x5934: 0x89B3,
	0x5935: 0xFFFD,
	0x5936: 0xFFFD,
	0x5937: 0xA669,
	0x5938: 0xA66A,
	0x5939: 0x8348,
	0x593A: 0x86BC,
	0x593B: 0xFFFD,
	0x593C: 0xC9CB,
	0x593D: 0xFFFD,
	0x593E: 0xA7A8,
	0x593F: 0xFFFD,
	0x5940: 0xCAB1,
	0x5941: 0x86BD,
	0x5942: 0x836B,
	0x5943: 0xFFFD,
	0x5944: 0xA961,
	0x5945: 0xCC43,
	0x5946: 0xFFFD,
	0x5947: 0xA95F,
	0x5948: 0xA960,
	0x5949: 0xA95E,
	0x594A: 0xD15A,
	0x594B: 0x88D2,
	0x594C: 0xFFFD,
	0x594D: 0xFFFD,
	0x594E: 0xABB6,
	0x594F: 0xABB5,
	0x5950: 0xABB7,
	0x5951: 0xABB4,
	0x5952: 0xFFFD,
	0x5953: 0xCE61,
	0x5954: 0xA962,
	0x5955: 0xABB3,
	0x5956: 0x87F2,
	0x5957: 0xAE4D,
	0x5958: 0xAE4E,
	0x5959: 0xFFFD,
	0x595A: 0xAE4F,
	0x595B: 0x82B6,
	0x595C: 0xD4CD,
	0x595D: 0x82B7,
	0x595E: 0xFFFD,
	0x595F: 0xFFFD,
	0x5960: 0xB3FE,
	0x5961: 0xD8B4,
	0x5962: 0xB0F8,
	0x5963: 0x82B8,
	0x5964: 0xFFFD,
	0x5965: 0x85C4,
	0x5966: 0xFFFD,
	0x5967: 0xB6F8,
	0x5968: 0x92E6,
	0x5969: 0xB9DD,
	0x596A: 0xB9DC,
	0x596B: 0xE16A,
	0x596C: 0x82B9,
	0x596D: 0xBC5D,
	0x596E: 0xBEC4,
	0x596F: 0xFFFD,
	0x5970: 0xEFC0,
	0x5971: 0xF6DA,
	0x5972: 0xF7D4,
	0x5973: 0xA46B,
	0x5974: 0xA5A3,
	0x5975: 0xFE66,
	0x5976: 0xA5A4,
	0x5977: 0xC9D1,
	0x5978: 0xA66C,
	0x5979: 0xA66F,
	0x597A: 0xFFFD,
	0x597B: 0xC9CF,
	0x597C: 0xC9CD,
	0x597D: 0xA66E,
	0x597E: 0xC9D0,
	0x597F: 0xC9D2,
	0x5980: 0xC9CC,
	0x5981: 0xA671,
	0x5982: 0xA670,
	0x5983: 0xA66D,
	0x5984: 0xA66B,
	0x5985: 0xC9CE,
	0x5986: 0x8349,
	0x5987: 0x83FC,
	0x5988: 0x85C5,
	0x5989: 0x99A2,
	0x598A: 0xA7B3,
	0x598B: 0xFFFD,
	0x598C: 0xFFFD,
	0x598D: 0xA7B0,
	0x598E: 0xCAB6,
	0x598F: 0xCAB9,
	0x5990: 0xCAB8,
	0x5991: 0xFFFD,
	0x5992: 0xA7AA,
	0x5993: 0xA7B2,
	0x5994: 0x99A3,
	0x5995: 0xFFFD,
	0x5996: 0xA7AF,
	0x5997: 0xCAB5,
	0x5998: 0xCAB3,
	0x5999: 0xA7AE,
	0x599A: 0x99A4,
	0x599B: 0x82BA,
	0x599C: 0xFFFD,
	0x599D: 0xA7A9,
	0x599E: 0xA7AC,
	0x599F: 0x99A5,
	0x59A0: 0xCAB4,
	0x59A1: 0xCABB,
	0x59A2: 0xCAB7,
	0x59A3: 0xA7AD,
	0x59A4: 0xA7B1,
	0x59A5: 0xA7B4,
	0x59A6: 0xCAB2,
	0x59A7: 0xCABA,
	0x59A8: 0xA7AB,
	0x59A9: 0x87BB,
	0x59AA: 0x86BE,
	0x59AB: 0x8DDB,
	0x59AC: 0x95A5,
	0x59AD: 0xFFFD,
	0x59AE: 0xA967,
	0x59AF: 0xA96F,
	0x59B0: 0x99A6,
	0x59B1: 0xCC4F,
	0x59B2: 0xCC48,
	0x59B3: 0xA970,
	0x59B4: 0xCC53,
	0x59B5: 0xCC44,
	0x59B6: 0xCC4B,
	0x59B7: 0xFBF1,
	0x59B8: 0x99A7,
	0x59B9: 0xA966,
	0x59BA: 0xCC45,
	0x59BB: 0xA964,
	0x59BC: 0xCC4C,
	0x59BD: 0xCC50,
	0x59BE: 0xA963,
	0x59BF: 0x9B40,
	0x59C0: 0xCC51,
	0x59C1: 0xCC4A,
	0x59C2: 0xFFFD,
	0x59C3: 0xCC4D,
	0x59C4: 0x99A8,
	0x59C5: 0xA972,
	0x59C6: 0xA969,
	0x59C7: 0xCC54,
	0x59C8: 0xCC52,
	0x59C9: 0x93FC,
	0x59CA: 0xA96E,
	0x59CB: 0xA96C,
	0x59CC: 0xCC49,
	0x59CD: 0xA96B,
	0x59CE: 0xCC47,
	0x59CF: 0xCC46,
	0x59D0: 0xA96A,
	0x59D1: 0xA968,
	0x59D2: 0xA971,
	0x59D3: 0xA96D,
	0x59D4: 0xA965,
	0x59D5: 0xFFFD,
	0x59D6: 0xCC4E,
	0x59D7: 0x82BB,
	0x59D8: 0xABB9,
	0x59D9: 0xFBF2,
	0x59DA: 0xABC0,
	0x59DB: 0xCE6F,
	0x59DC: 0xABB8,
	0x59DD: 0xCE67,
	0x59DE: 0xCE63,
	0x59DF: 0xFFFD,
	0x59E0: 0xCE73,
	0x59E1: 0xCE62,
	0x59E2: 0xFFFD,
	0x59E3: 0xABBB,
	0x59E4: 0xCE6C,
	0x59E5: 0xABBE,
	0x59E6: 0xABC1,
	0x59E7: 0xFFFD,
	0x59E8: 0xABBC,
	0x59E9: 0xCE70,
	0x59EA: 0xABBF,
	0x59EB: 0x82BC,
	0x59EC: 0xAE56,
	0x59ED: 0xCE76,
	0x59EE: 0xCE64,
	0x59EF: 0x99A9,
	0x59F0: 0x99AA,
	0x59F1: 0xCE66,
	0x59F2: 0xCE6D,
	0x59F3: 0xCE71,
	0x59F4: 0xCE75,
	0x59F5: 0xCE72,
	0x59F6: 0xCE6B,
	0x59F7: 0xCE6E,
	0x59F8: 0x99AB,
	0x59F9: 0x95C0,
	0x59FA: 0xCE68,
	0x59FB: 0xABC3,
	0x59FC: 0xCE6A,
	0x59FD: 0xCE69,
	0x59FE: 0xCE74,
	0x59FF: 0xABBA,
	0x5A00: 0xCE65,
	0x5A01: 0xABC2,
	0x5A02: 0x99AC,
	0x5A03: 0xABBD,
	0x5A04: 0x83FB,
	0x5A05: 0x8DCC,
	0x5A06: 0x87BD,
	0x5A07: 0x87BC,
	0x5A08: 0x9055,
	0x5A09: 0xAE5C,
	0x5A0A: 0xD162,
	0x5A0B: 0x99AD,
	0x5A0C: 0xAE5B,
	0x5A0D: 0x99AE,
	0x5A0E: 0xFFFD,
	0x5A0F: 0xD160,
	0x5A10: 0xFFFD,
	0x5A11: 0xAE50,
	0x5A12: 0x99AF,
	0x5A13: 0xAE55,
	0x5A14: 0xFFFD,
	0x5A15: 0xD15F,
	0x5A16: 0xD15C,
	0x5A17: 0xD161,
	0x5A18: 0xAE51,
	0x5A19: 0xD15B,
	0x5A1A: 0x82BD,
	0x5A1B: 0xAE54,
	0x5A1C: 0xAE52,
	0x5A1D: 0xFFFD,
	0x5A1E: 0xD163,
	0x5A1F: 0xAE53,
	0x5A20: 0xAE57,
	0x5A21: 0x99B0,
	0x5A22: 0xFFFD,
	0x5A23: 0xAE58,
	0x5A24: 0x99B1,
	0x5A25: 0xAE5A,
	0x5A26: 0xFFFD,
	0x5A27: 0x99B2,
	0x5A28: 0xFFFD,
	0x5A29: 0xAE59,
	0x5A2A: 0x99B3,
	0x5A2B: 0x99B4,
	0x5A2C: 0x99B5,
	0x5A2D: 0xD15D,
	0x5A2E: 0xD15E,
	0x5A2F: 0x92BC,
	0x5A30: 0xFFFD,
	0x5A31: 0x83B1,
	0x5A32: 0x84D5,
	0x5A33: 0xD164,
	0x5A34: 0x87B9,
	0x5A35: 0xD4D4,
	0x5A36: 0xB0F9,
	0x5A37: 0xD8C2,
	0x5A38: 0xD4D3,
	0x5A39: 0xD4E6,
	0x5A3A: 0xFFFD,
	0x5A3B: 0xFFFD,
	0x5A3C: 0xB140,
	0x5A3D: 0x99B6,
	0x5A3E: 0xD4E4,
	0x5A3F: 0xFFFD,
	0x5A40: 0xB0FE,
	0x5A41: 0xB0FA,
	0x5A42: 0xD4ED,
	0x5A43: 0xD4DD,
	0x5A44: 0xD4E0,
	0x5A45: 0x99B7,
	0x5A46: 0xB143,
	0x5A47: 0xD4EA,
	0x5A48: 0xD4E2,
	0x5A49: 0xB0FB,
	0x5A4A: 0xB144,
	0x5A4B: 0xFFFD,
	0x5A4C: 0xD4E7,
	0x5A4D: 0xD4E5,
	0x5A4E: 0xFFFD,
	0x5A4F: 0xFFFD,
	0x5A50: 0xD4D6,
	0x5A51: 0xD4EB,
	0x5A52: 0xD4DF,
	0x5A53: 0xD4DA,
	0x5A54: 0x99B8,
	0x5A55: 0xD4D0,
	0x5A56: 0xD4EC,
	0x5A57: 0xD4DC,
	0x5A58: 0xD4CF,
	0x5A59: 0x99B9,
	0x5A5A: 0xB142,
	0x5A5B: 0xD4E1,
	0x5A5C: 0xD4EE,
	0x5A5D: 0xD4DE,
	0x5A5E: 0xD4D2,
	0x5A5F: 0xD4D7,
	0x5A60: 0xD4CE,
	0x5A61: 0x99BA,
	0x5A62: 0xB141,
	0x5A63: 0x9563,
	0x5A64: 0xD4DB,
	0x5A65: 0xD4D8,
	0x5A66: 0xB0FC,
	0x5A67: 0xD4D1,
	0x5A68: 0x99BB,
	0x5A69: 0xD4E9,
	0x5A6A: 0xB0FD,
	0x5A6B: 0x99BC,
	0x5A6C: 0xD4D9,
	0x5A6D: 0xD4D5,
	0x5A6E: 0x99BD,
	0x5A6F: 0xFFFD,
	0x5A70: 0xD4E8,
	0x5A71: 0x99BE,
	0x5A72: 0xFFFD,
	0x5A73: 0xFFFD,
	0x5A74: 0x89CF,
	0x5A75: 0x87BA,
	0x5A76: 0x8AC1,
	0x5A77: 0xB440,
	0x5A78: 0xD8BB,
	0x5A79: 0x99BF,
	0x5A7A: 0xD8B8,
	0x5A7B: 0xD8C9,
	0x5A7C: 0xD8BD,
	0x5A7D: 0xD8CA,
	0x5A7E: 0x99C0,
	0x5A7F: 0xB442,
	0x5A80: 0xFFFD,
	0x5A81: 0x99C1,
	0x5A82: 0x99C2,
	0x5A83: 0xD8C6,
	0x5A84: 0xD8C3,
	0x5A85: 0xFFFD,
	0x5A86: 0x99C3,
	0x5A87: 0xFFFD,
	0x5A88: 0x99C4,
	0x5A89: 0xFFFD,
	0x5A8A: 0xD8C4,
	0x5A8B: 0xD8C7,
	0x5A8C: 0xD8CB,
	0x5A8D: 0xFFFD,
	0x5A8E: 0xD4E3,
	0x5A8F: 0xD8CD,
	0x5A90: 0xDD47,
	0x5A91: 0x99C5,
	0x5A92: 0xB443,
	0x5A93: 0xD8CE,
	0x5A94: 0xD8B6,
	0x5A95: 0xD8C0,
	0x5A96: 0xFE78,
	0x5A97: 0xD8C5,
	0x5A98: 0xFFFD,
	0x5A99: 0x99C6,
	0x5A9A: 0xB441,
	0x5A9B: 0xB444,
	0x5A9C: 0xD8CC,
	0x5A9D: 0xD8CF,
	0x5A9E: 0xD8BA,
	0x5A9F: 0xD8B7,
	0x5AA0: 0x99C7,
	0x5AA1: 0x99C8,
	0x5AA2: 0xD8B9,
	0x5AA3: 0xFFFD,
	0x5AA4: 0x9C70,
	0x5AA5: 0xD8BE,
	0x5AA6: 0xD8BC,
	0x5AA7: 0xB445,
	0x5AA8: 0xFFFD,
	0x5AA9: 0xD8C8,
	0x5AAA: 0x82BE,
	0x5AAB: 0x99C9,
	0x5AAC: 0xD8BF,
	0x5AAD: 0xFFFD,
	0x5AAE: 0xD8C1,
	0x5AAF: 0xD8B5,
	0x5AB0: 0xDCFA,
	0x5AB1: 0xDCF8,
	0x5AB2: 0xB742,
	0x5AB3: 0xB740,
	0x5AB4: 0xDD43,
	0x5AB5: 0xDCF9,
	0x5AB6: 0xDD44,
	0x5AB7: 0xDD40,
	0x5AB8: 0xDCF7,
	0x5AB9: 0xDD46,
	0x5ABA: 0xDCF6,
	0x5ABB: 0xDCFD,
	0x5ABC: 0xB6FE,
	0x5ABD: 0xB6FD,
	0x5ABE: 0xB6FC,
	0x5ABF: 0xDCFB,
	0x5AC0: 0xDD41,
	0x5AC1: 0xB6F9,
	0x5AC2: 0xB741,
	0x5AC3: 0x99CA,
	0x5AC4: 0xDCF4,
	0x5AC5: 0xFFFD,
	0x5AC6: 0xDCFE,
	0x5AC7: 0xDCF3,
	0x5AC8: 0xDCFC,
	0x5AC9: 0xB6FA,
	0x5ACA: 0xDD42,
	0x5ACB: 0xDCF5,
	0x5ACC: 0xB6FB,
	0x5ACD: 0xDD45,
	0x5ACE: 0x99CB,
	0x5ACF: 0x99CC,
	0x5AD0: 0x82BF,
	0x5AD1: 0x9D67,
	0x5AD2: 0x8EE5,
	0x5AD3: 0x99CD,
	0x5AD4: 0x89D0,
	0x5AD5: 0xE16E,
	0x5AD6: 0xB9E2,
	0x5AD7: 0xB9E1,
	0x5AD8: 0xB9E3,
	0x5AD9: 0xE17A,
	0x5ADA: 0xE170,
	0x5ADB: 0xE176,
	0x5ADC: 0xE16B,
	0x5ADD: 0xE179,
	0x5ADE: 0xE178,
	0x5ADF: 0xE17C,
	0x5AE0: 0xE175,
	0x5AE1: 0xB9DE,
	0x5AE2: 0xE174,
	0x5AE3: 0xB9E4,
	0x5AE4: 0x99CE,
	0x5AE5: 0xE16D,
	0x5AE6: 0xB9DF,
	0x5AE7: 0xFFFD,
	0x5AE8: 0xE17B,
	0x5AE9: 0xB9E0,
	0x5AEA: 0xE16F,
	0x5AEB: 0xE172,
	0x5AEC: 0xE177,
	0x5AED: 0xE171,
	0x5AEE: 0xE16C,
	0x5AEF: 0xFFFD,
	0x5AF0: 0x99CF,
	0x5AF1: 0x82C0,
	0x5AF2: 0xFB67,
	0x5AF3: 0xE173,
	0x5AF4: 0xE555,
	0x5AF5: 0xBC61,
	0x5AF6: 0xE558,
	0x5AF7: 0xE557,
	0x5AF8: 0xE55A,
	0x5AF9: 0xE55C,
	0x5AFA: 0xF9DC,
	0x5AFB: 0xBC5F,
	0x5AFC: 0xFFFD,
	0x5AFD: 0xE556,
	0x5AFE: 0x99D0,
	0x5AFF: 0xE554,
	0x5B00: 0xFFFD,
	0x5B01: 0xE55D,
	0x5B02: 0xE55B,
	0x5B03: 0xE559,
	0x5B04: 0xFFFD,
	0x5B05: 0xE55F,
	0x5B06: 0xFFFD,
	0x5B07: 0xE55E,
	0x5B08: 0xBC63,
	0x5B09: 0xBC5E,
	0x5B0A: 0xFFFD,
	0x5B0B: 0xBC60,
	0x5B0C: 0xBC62,
	0x5B0D: 0x99D1,
	0x5B0E: 0xFFFD,
	0x5B0F: 0xE560,
	0x5B10: 0xE957,
	0x5B11: 0x99D2,
	0x5B12: 0xFFFD,
	0x5B13: 0xE956,
	0x5B14: 0xE955,
	0x5B15: 0x99D3,
	0x5B16: 0xE958,
	0x5B17: 0xE951,
	0x5B18: 0xFFFD,
	0x5B19: 0xE952,
	0x5B1A: 0xE95A,
	0x5B1B: 0xE953,
	0x5B1C: 0xFFFD,
	0x5B1D: 0xBEC5,
	0x5B1E: 0xE95C,
	0x5B1F: 0x99D4,
	0x5B20: 0xE95B,
	0x5B21: 0xE954,
	0x5B22: 0x92EF,
	0x5B23: 0xECD1,
	0x5B24: 0xC0A8,
	0x5B25: 0xECCF,
	0x5B26: 0xECD4,
	0x5B27: 0xECD3,
	0x5B28: 0xE959,
	0x5B29: 0xFFFD,
	0x5B2A: 0xC0A7,
	0x5B2B: 0x99D5,
	0x5B2C: 0xECD2,
	0x5B2D: 0xECCE,
	0x5B2E: 0xECD6,
	0x5B2F: 0xECD5,
	0x5B30: 0xC0A6,
	0x5B31: 0xFFFD,
	0x5B32: 0xECD0,
	0x5B33: 0xFFFD,
	0x5B34: 0xBEC6,
	0x5B35: 0xFFFD,
	0x5B36: 0x82C1,
	0x5B37: 0x89D1,
	0x5B38: 0xC254,
	0x5B39: 0xFFFD,
	0x5B3A: 0xFFFD,
	0x5B3B: 0xFFFD,
	0x5B3C: 0xEFC1,
	0x5B3D: 0xF1FA,
	0x5B3E: 0xF1FB,
	0x5B3F: 0xF1FC,
	0x5B40: 0xC45C,
	0x5B41: 0x99D6,
	0x5B42: 0xFFFD,
	0x5B43: 0xC45D,
	0x5B44: 0x99D7,
	0x5B45: 0xF443,
	0x5B46: 0x99D8,
	0x5B47: 0xF5C8,
	0x5B48: 0xF5C7,
	0x5B49: 0xFFFD,
	0x5B4A: 0x99D9,
	0x5B4B: 0xF6DB,
	0x5B4C: 0xF6DC,
	0x5B4D: 0xF7D5,
	0x5B4E: 0xF8A7,
	0x5B4F: 0x99DA,
	0x5B50: 0xA46C,
	0x5B51: 0xA46D,
	0x5B52: 0xFFFD,
	0x5B53: 0xA46E,
	0x5B54: 0xA4D5,
	0x5B55: 0xA5A5,
	0x5B56: 0xC9D3,
	0x5B57: 0xA672,
	0x5B58: 0xA673,
	0x5B59: 0x83B2,
	0x5B5A: 0xA7B7,
	0x5B5B: 0xA7B8,
	0x5B5C: 0xA7B6,
	0x5B5D: 0xA7B5,
	0x5B5E: 0xFFFD,
	0x5B5F: 0xA973,
	0x5B60: 0xFFFD,
	0x5B61: 0xFFFD,
	0x5B62: 0xCC55,
	0x5B63: 0xA975,
	0x5B64: 0xA974,
	0x5B65: 0xCC56,
	0x5B66: 0x88D4,
	0x5B67: 0xFFFD,
	0x5B68: 0x99DB,
	0x5B69: 0xABC4,
	0x5B6A: 0x8CCB,
	0x5B6B: 0xAE5D,
	0x5B6C: 0xD165,
	0x5B6D: 0xA041,
	0x5B6E: 0xD4F0,
	0x5B6F: 0xFFFD,
	0x5B70: 0xB145,
	0x5B71: 0xB447,
	0x5B72: 0xD4EF,
	0x5B73: 0xB446,
	0x5B74: 0x99DC,
	0x5B75: 0xB9E5,
	0x5B76: 0x99DD,
	0x5B77: 0xE17D,
	0x5B78: 0xBEC7,
	0x5B79: 0xFFFD,
	0x5B7A: 0xC0A9,
	0x5B7B: 0xECD7,
	0x5B7C: 0x99DE,
	0x5B7D: 0xC45E,
	0x5B7E: 0xFFFD,
	0x5B7F: 0xC570,
	0x5B80: 0xC6CB,
	0x5B81: 0xC972,
	0x5B82: 0x99DF,
	0x5B83: 0xA5A6,
	0x5B84: 0xC973,
	0x5B85: 0xA676,
	0x5B86: 0xFFFD,
	0x5B87: 0xA674,
	0x5B88: 0xA675,
	0x5B89: 0xA677,
	0x5B8A: 0xFFFD,
	0x5B8B: 0xA7BA,
	0x5B8C: 0xA7B9,
	0x5B8D: 0x93FD,
	0x5B8E: 0xCABC,
	0x5B8F: 0xA7BB,
	0x5B90: 0x99E0,
	0x5B91: 0xFFFD,
	0x5B92: 0xCABD,
	0x5B93: 0xCC57,
	0x5B94: 0xFFFD,
	0x5B95: 0xCC58,
	0x5B96: 0x9A40,
	0x5B97: 0xA976,
	0x5B98: 0xA978,
	0x5B99: 0xA97A,
	0x5B9A: 0xA977,
	0x5B9B: 0xA97B,
	0x5B9C: 0xA979,
	0x5B9D: 0x8BF3,
	0x5B9E: 0x86BF,
	0x5B9F: 0x92D4,
	0x5BA0: 0x8B70,
	0x5BA1: 0x87BF,
	0x5BA2: 0xABC8,
	0x5BA3: 0xABC5,
	0x5BA4: 0xABC7,
	0x5BA5: 0xABC9,
	0x5BA6: 0xABC6,
	0x5BA7: 0xD166,
	0x5BA8: 0xCE77,
	0x5BA9: 0xFFFD,
	0x5BAA: 0x88D6,
	0x5BAB: 0x90B3,
	0x5BAC: 0xD168,
	0x5BAD: 0xD167,
	0x5BAE: 0xAE63,
	0x5BAF: 0xFFFD,
	0x5BB0: 0xAE5F,
	0x5BB1: 0xFFFD,
	0x5BB2: 0xFFFD,
	0x5BB3: 0xAE60,
	0x5BB4: 0xAE62,
	0x5BB5: 0xAE64,
	0x5BB6: 0xAE61,
	0x5BB7: 0x9D68,
	0x5BB8: 0xAE66,
	0x5BB9: 0xAE65,
	0x5BBA: 0xFFFD,
	0x5BBB: 0xFFFD,
	0x5BBC: 0xFFFD,
	0x5BBD: 0x87BE,
	0x5BBE: 0x8759,
	0x5BBF: 0xB14A,
	0x5BC0: 0xD4F2,
	0x5BC1: 0xD4F1,
	0x5BC2: 0xB149,
	0x5BC3: 0xFC43,
	0x5BC4: 0xB148,
	0x5BC5: 0xB147,
	0x5BC6: 0xB14B,
	0x5BC7: 0xB146,
	0x5BC8: 0xFFFD,
	0x5BC9: 0x82C2,
	0x5BCA: 0xD8D5,
	0x5BCB: 0xD8D2,
	0x5BCC: 0xB449,
	0x5BCD: 0xD8D1,
	0x5BCE: 0xD8D6,
	0x5BCF: 0xFFFD,
	0x5BD0: 0xB44B,
	0x5BD1: 0xD8D4,
	0x5BD2: 0xB448,
	0x5BD3: 0xB44A,
	0x5BD4: 0xD8D3,
	0x5BD5: 0x9A55,
	0x5BD6: 0xDD48,
	0x5BD7: 0x9A56,
	0x5BD8: 0xDD49,
	0x5BD9: 0xDD4A,
	0x5BDA: 0xFFFD,
	0x5BDB: 0x9269,
	0x5BDC: 0xFFFD,
	0x5BDD: 0x86C0,
	0x5BDE: 0xB9E6,
	0x5BDF: 0xB9EE,
	0x5BE0: 0xE17E,
	0x5BE1: 0xB9E8,
	0x5BE2: 0xB9EC,
	0x5BE3: 0xE1A1,
	0x5BE4: 0xB9ED,
	0x5BE5: 0xB9E9,
	0x5BE6: 0xB9EA,
	0x5BE7: 0xB9E7,
	0x5BE8: 0xB9EB,
	0x5BE9: 0xBC66,
	0x5BEA: 0xD8D0,
	0x5BEB: 0xBC67,
	0x5BEC: 0xBC65,
	0x5BED: 0xFFFD,
	0x5BEE: 0xBC64,
	0x5BEF: 0xE95D,
	0x5BF0: 0xBEC8,
	0x5BF1: 0xECD8,
	0x5BF2: 0xECD9,
	0x5BF3: 0x82C3,
	0x5BF4: 0xFFFD,
	0x5BF5: 0xC364,
	0x5BF6: 0xC45F,
	0x5BF7: 0xFFFD,
	0x5BF8: 0xA46F,
	0x5BF9: 0x86C1,
	0x5BFA: 0xA678,
	0x5BFB: 0x84D6,
	0x5BFC: 0x88D5,
	0x5BFD: 0xFFFD,
	0x5BFE: 0x9366,
	0x5BFF: 0x86BA,
	0x5C00: 0xFFFD,
	0x5C01: 0xABCA,
	0x5C02: 0x9347,
	0x5C03: 0xD169,
	0x5C04: 0xAE67,
	0x5C05: 0x955B,
	0x5C06: 0x92E2,
	0x5C07: 0xB14E,
	0x5C08: 0xB14D,
	0x5C09: 0xB14C,
	0x5C0A: 0xB44C,
	0x5C0B: 0xB44D,
	0x5C0C: 0xD8D7,
	0x5C0D: 0xB9EF,
	0x5C0E: 0xBEC9,
	0x5C0F: 0xA470,
	0x5C10: 0xC95C,
	0x5C11: 0xA4D6,
	0x5C12: 0xC974,
	0x5C13: 0x82C4,
	0x5C14: 0x86E0,
	0x5C15: 0xC9D4,
	0x5C16: 0xA679,
	0x5C17: 0xFFFD,
	0x5C18: 0x86B7,
	0x5C19: 0xFFFD,
	0x5C1A: 0xA97C,
	0x5C1B: 0xFFFD,
	0x5C1C: 0x82C5,
	0x5C1D: 0x86AF,
	0x5C1E: 0x82C6,
	0x5C1F: 0xDD4B,
	0x5C20: 0xFBF3,
	0x5C21: 0xFFFD,
	0x5C22: 0xA471,
	0x5C23: 0x9A57,
	0x5C24: 0xA4D7,
	0x5C25: 0xC9D5,
	0x5C26: 0xFFFD,
	0x5C27: 0x84D0,
	0x5C28: 0xCABE,
	0x5C29: 0xFFFD,
	0x5C2A: 0xCABF,
	0x5C2B: 0xFFFD,
	0x5C2C: 0xA7BC,
	0x5C2D: 0x8259,
	0x5C2E: 0xFFFD,
	0x5C2F: 0xFFFD,
	0x5C30: 0xD8D8,
	0x5C31: 0xB44E,
	0x5C32: 0xFFFD,
	0x5C33: 0xDD4C,
	0x5C34: 0x89D2,
	0x5C35: 0xFFFD,
	0x5C36: 0xFFFD,
	0x5C37: 0xC0AA,
	0x5C38: 0xA472,
	0x5C39: 0xA4A8,
	0x5C3A: 0xA4D8,
	0x5C3B: 0xC975,
	0x5C3C: 0xA5A7,
	0x5C3D: 0x86E9,
	0x5C3E: 0xA7C0,
	0x5C3F: 0xA7BF,
	0x5C40: 0xA7BD,
	0x5C41: 0xA7BE,
	0x5C42: 0x87C1,
	0x5C43: 0xFFFD,
	0x5C44: 0xCC59,
	0x5C45: 0xA97E,
	0x5C46: 0xA9A1,
	0x5C47: 0xCC5A,
	0x5C48: 0xA97D,
	0x5C49: 0x8440,
	0x5C4A: 0x8357,
	0x5C4B: 0xABCE,
	0x5C4C: 0xCE78,
	0x5C4D: 0xABCD,
	0x5C4E: 0xABCB,
	0x5C4F: 0xABCC,
	0x5C50: 0xAE6A,
	0x5C51: 0xAE68,
	0x5C52: 0xFFFD,
	0x5C53: 0x82C7,
	0x5C54: 0xD16B,
	0x5C55: 0xAE69,
	0x5C56: 0xD16A,
	0x5C57: 0xFFFD,
	0x5C58: 0xAE5E,
	0x5C59: 0xD4F3,
	0x5C5A: 0xFFFD,
	0x5C5B: 0xFFFD,
	0x5C5C: 0xB150,
	0x5C5D: 0xB151,
	0x5C5E: 0x8C70,
	0x5C5F: 0xFFFD,
	0x5C60: 0xB14F,
	0x5C61: 0x86C2,
	0x5C62: 0xB9F0,
	0x5C63: 0xE1A2,
	0x5C64: 0xBC68,
	0x5C65: 0xBC69,
	0x5C66: 0x89D3,
	0x5C67: 0xE561,
	0x5C68: 0xC0AB,
	0x5C69: 0xEFC2,
	0x5C6A: 0xEFC3,
	0x5C6B: 0xFFFD,
	0x5C6C: 0xC4DD,
	0x5C6D: 0xF8A8,
	0x5C6E: 0xC94B,
	0x5C6F: 0xA4D9,
	0x5C70: 0xFFFD,
	0x5C71: 0xA473,
	0x5C72: 0xFFFD,
	0x5C73: 0xC977,
	0x5C74: 0xC976,
	0x5C75: 0xFFFD,
	0x5C76: 0x9470,
	0x5C77: 0xFFFD,
	0x5C78: 0x9D64,
	0x5C79: 0xA67A,
	0x5C7A: 0xC9D7,
	0x5C7B: 0xC9D8,
	0x5C7C: 0xC9D6,
	0x5C7D: 0xFFFD,
	0x5C7E: 0xC9D9,
	0x5C7F: 0x89D4,
	0x5C80: 0xFFFD,
	0x5C81: 0x85D7,
	0x5C82: 0x83DB,
	0x5C83: 0xFFFD,
	0x5C84: 0xFFFD,
	0x5C85: 0x9A58,
	0x5C86: 0xCAC7,
	0x5C87: 0xFFFD,
	0x5C88: 0xCAC2,
	0x5C89: 0xCAC4,
	0x5C8A: 0xCAC6,
	0x5C8B: 0xCAC3,
	0x5C8C: 0xA7C4,
	0x5C8D: 0xCAC0,
	0x5C8E: 0xFFFD,
	0x5C8F: 0xCAC1,
	0x5C90: 0xA7C1,
	0x5C91: 0xA7C2,
	0x5C92: 0xCAC5,
	0x5C93: 0xCAC8,
	0x5C94: 0xA7C3,
	0x5C95: 0xCAC9,
	0x5C96: 0x86C4,
	0x5C97: 0x8442,
	0x5C98: 0x83B5,
	0x5C99: 0x82C8,
	0x5C9A: 0x84D7,
	0x5C9B: 0x83B4,
	0x5C9C: 0x82C9,
	0x5C9D: 0xCC68,
	0x5C9E: 0x9A59,
	0x5C9F: 0xCC62,
	0x5CA0: 0xCC5D,
	0x5CA1: 0xA9A3,
	0x5CA2: 0xCC65,
	0x5CA3: 0xCC63,
	0x5CA4: 0xCC5C,
	0x5CA5: 0xCC69,
	0x5CA6: 0xCC6C,
	0x5CA7: 0xCC67,
	0x5CA8: 0xCC60,
	0x5CA9: 0xA9A5,
	0x5CAA: 0xCC66,
	0x5CAB: 0xA9A6,
	0x5CAC: 0xCC61,
	0x5CAD: 0xCC64,
	0x5CAE: 0xCC5B,
	0x5CAF: 0xCC5F,
	0x5CB0: 0xCC6B,
	0x5CB1: 0xA9A7,
	0x5CB2: 0xFFFD,
	0x5CB3: 0xA9A8,
	0x5CB4: 0xFFFD,
	0x5CB5: 0xCC5E,
	0x5CB6: 0xCC6A,
	0x5CB7: 0xA9A2,
	0x5CB8: 0xA9A4,
	0x5CB9: 0xFFFD,
	0x5CBA: 0x82CA,
	0x5CBB: 0x82CB,
	0x5CBC: 0x9471,
	0x5CBD: 0x8DCD,
	0x5CBE: 0x9473,
	0x5CBF: 0x8FFC,
	0x5CC0: 0xFFFD,
	0x5CC1: 0x82CC,
	0x5CC2: 0x9A5A,
	0x5CC3: 0xFFFD,
	0x5CC4: 0x8EE6,
	0x5CC5: 0x9472,
	0x5CC6: 0xCEAB,
	0x5CC7: 0xCEA4,
	0x5CC8: 0xCEAA,
	0x5CC9: 0xCEA3,
	0x5CCA: 0xCEA5,
	0x5CCB: 0xCE7D,
	0x5CCC: 0xCE7B,
	0x5CCD: 0xFFFD,
	0x5CCE: 0xCEAC,
	0x5CCF: 0xCEA9,
	0x5CD0: 0xCE79,
	0x5CD1: 0xFBF5,
	0x5CD2: 0xABD0,
	0x5CD3: 0xCEA7,
	0x5CD4: 0xCEA8,
	0x5CD5: 0x9D71,
	0x5CD6: 0xCEA6,
	0x5CD7: 0xCE7C,
	0x5CD8: 0xCE7A,
	0x5CD9: 0xABCF,
	0x5CDA: 0xCEA2,
	0x5CDB: 0xCE7E,
	0x5CDC: 0xFFFD,
	0x5CDD: 0xFFFD,
	0x5CDE: 0xCEA1,
	0x5CDF: 0xCEAD,
	0x5CE0: 0x9450,
	0x5CE1: 0x83B3,
	0x5CE2: 0xFFFD,
	0x5CE3: 0xFFFD,
	0x5CE4: 0x8EB4,
	0x5CE5: 0x8441,
	0x5CE6: 0x8CCD,
	0x5CE7: 0xFFFD,
	0x5CE8: 0xAE6F,
	0x5CE9: 0xFBF6,
	0x5CEA: 0xAE6E,
	0x5CEB: 0xFFFD,
	0x5CEC: 0xD16C,
	0x5CED: 0xAE6B,
	0x5CEE: 0xD16E,
	0x5CEF: 0x955D,
	0x5CF0: 0xAE70,
	0x5CF1: 0xD16F,
	0x5CF2: 0xFFFD,
	0x5CF3: 0xFFFD,
	0x5CF4: 0xAE73,
	0x5CF5: 0x82CD,
	0x5CF6: 0xAE71,
	0x5CF7: 0xD170,
	0x5CF8: 0xCEAE,
	0x5CF9: 0xD172,
	0x5CFA: 0x82CE,
	0x5CFB: 0xAE6D,
	0x5CFC: 0x9D69,
	0x5CFD: 0xAE6C,
	0x5CFE: 0xFFFD,
	0x5CFF: 0xD16D,
	0x5D00: 0xD171,
	0x5D01: 0xAE72,
	0x5D02: 0x8EB3,
	0x5D03: 0x8DCE,
	0x5D04: 0xFFFD,
	0x5D05: 0xFFFD,
	0x5D06: 0xB153,
	0x5D07: 0xB152,
	0x5D08: 0xFFFD,
	0x5D09: 0xFFFD,
	0x5D0A: 0xFFFD,
	0x5D0B: 0xD4F5,
	0x5D0C: 0xD4F9,
	0x5D0D: 0xD4FB,
	0x5D0E: 0xB154,
	0x5D0F: 0xD4FE,
	0x5D10: 0x9A5B,
	0x5D11: 0xB158,
	0x5D12: 0xD541,
	0x5D13: 0xFFFD,
	0x5D14: 0xB15A,
	0x5D15: 0x82CF,
	0x5D16: 0xB156,
	0x5D17: 0xB15E,
	0x5D18: 0x82D0,
	0x5D19: 0xB15B,
	0x5D1A: 0xD4F7,
	0x5D1B: 0xB155,
	0x5D1C: 0xFFFD,
	0x5D1D: 0xD4F6,
	0x5D1E: 0xD4F4,
	0x5D1F: 0xD543,
	0x5D20: 0xD4F8,
	0x5D21: 0xFFFD,
	0x5D22: 0xB157,
	0x5D23: 0xD542,
	0x5D24: 0xB15C,
	0x5D25: 0xD4FD,
	0x5D26: 0xD4FC,
	0x5D27: 0xB15D,
	0x5D28: 0xD4FA,
	0x5D29: 0xB159,
	0x5D2A: 0xFFFD,
	0x5D2B: 0xFFFD,
	0x5D2C: 0x9A5C,
	0x5D2D: 0x86C3,
	0x5D2E: 0xD544,
	0x5D2F: 0x9A5D,
	0x5D30: 0xD540,
	0x5D31: 0xD8E7,
	0x5D32: 0xD8EE,
	0x5D33: 0xD8E3,
	0x5D34: 0xB451,
	0x5D35: 0xD8DF,
	0x5D36: 0xD8EF,
	0x5D37: 0xD8D9,
	0x5D38: 0xD8EC,
	0x5D39: 0xD8EA,
	0x5D3A: 0xD8E4,
	0x5D3B: 0xFFFD,
	0x5D3C: 0xD8ED,
	0x5D3D: 0xD8E6,
	0x5D3E: 0x82D1,
	0x5D3F: 0xD8DE,
	0x5D40: 0xD8F0,
	0x5D41: 0xD8DC,
	0x5D42: 0xD8E9,
	0x5D43: 0xD8DA,
	0x5D44: 0xFFFD,
	0x5D45: 0xD8F1,
	0x5D46: 0xFBF7,
	0x5D47: 0xB452,
	0x5D48: 0x9A5E,
	0x5D49: 0xD8EB,
	0x5D4A: 0xDD4F,
	0x5D4B: 0xD8DD,
	0x5D4C: 0xB44F,
	0x5D4D: 0xFFFD,
	0x5D4E: 0xD8E1,
	0x5D4F: 0xFFFD,
	0x5D50: 0xB450,
	0x5D51: 0xD8E0,
	0x5D52: 0xD8E5,
	0x5D53: 0x82D2,
	0x5D54: 0xFFFD,
	0x5D55: 0xD8E2,
	0x5D56: 0x9A5F,
	0x5D57: 0x9565,
	0x5D58: 0x89D5,
	0x5D59: 0xD8E8,
	0x5D5A: 0xFFFD,
	0x5D5B: 0x8DDC,
	0x5D5C: 0x82D3,
	0x5D5D: 0x8E67,
	0x5D5E: 0xDD53,
	0x5D5F: 0xFFFD,
	0x5D60: 0xFFFD,
	0x5D61: 0xFFFD,
	0x5D62: 0xDD56,
	0x5D63: 0xDD4E,
	0x5D64: 0xFFFD,
	0x5D65: 0xDD50,
	0x5D66: 0xFFFD,
	0x5D67: 0xDD55,
	0x5D68: 0xDD54,
	0x5D69: 0xB743,
	0x5D6A: 0xFFFD,
	0x5D6B: 0xD8DB,
	0x5D6C: 0xDD52,
	0x5D6D: 0x82D4,
	0x5D6E: 0xFFFD,
	0x5D6F: 0xB744,
	0x5D70: 0x9A60,
	0x5D71: 0xDD4D,
	0x5D72: 0xDD51,
	0x5D73: 0x82D5,
	0x5D74: 0x82D6,
	0x5D75: 0xFE7E,
	0x5D76: 0x9474,
	0x5D77: 0xE1A9,
	0x5D78: 0x9D7A,
	0x5D79: 0xE1B0,
	0x5D7A: 0xE1A7,
	0x5D7B: 0x9A61,
	0x5D7C: 0xE1AE,
	0x5D7D: 0xE1A5,
	0x5D7E: 0xE1AD,
	0x5D7F: 0xE1B1,
	0x5D80: 0xE1A4,
	0x5D81: 0xE1A8,
	0x5D82: 0xE1A3,
	0x5D83: 0xFFFD,
	0x5D84: 0xB9F1,
	0x5D85: 0x9A62,
	0x5D86: 0xE1A6,
	0x5D87: 0xB9F2,
	0x5D88: 0xE1AC,
	0x5D89: 0xE1AB,
	0x5D8A: 0xE1AA,
	0x5D8B: 0x93FE,
	0x5D8C: 0x82D7,
	0x5D8D: 0xE1AF,
	0x5D8E: 0xFBF8,
	0x5D8F: 0xFFFD,
	0x5D90: 0x82D8,
	0x5D91: 0xFFFD,
	0x5D92: 0xE565,
	0x5D93: 0xE567,
	0x5D94: 0xBC6B,
	0x5D95: 0xE568,
	0x5D96: 0xFFFD,
	0x5D97: 0xE563,
	0x5D98: 0xFFFD,
	0x5D99: 0xE562,
	0x5D9A: 0xE56C,
	0x5D9B: 0xFFFD,
	0x5D9C: 0xE56A,
	0x5D9D: 0xBC6A,
	0x5D9E: 0xE56D,
	0x5D9F: 0xE564,
	0x5DA0: 0xE569,
	0x5DA1: 0xE56B,
	0x5DA2: 0xE566,
	0x5DA3: 0xFFFD,
	0x5DA4: 0x9A63,
	0x5DA5: 0xFFFD,
	0x5DA6: 0xFFFD,
	0x5DA7: 0xE961,
	0x5DA8: 0xE966,
	0x5DA9: 0xE960,
	0x5DAA: 0xE965,
	0x5DAB: 0x9A64,
	0x5DAC: 0xE95E,
	0x5DAD: 0xE968,
	0x5DAE: 0xE964,
	0x5DAF: 0xE969,
	0x5DB0: 0xE963,
	0x5DB1: 0xE95F,
	0x5DB2: 0xE967,
	0x5DB3: 0xFFFD,
	0x5DB4: 0xE96A,
	0x5DB5: 0xE962,
	0x5DB6: 0x9A65,
	0x5DB7: 0xECDA,
	0x5DB8: 0xC0AF,
	0x5DB9: 0x82D9,
	0x5DBA: 0xC0AD,
	0x5DBB: 0xFFFD,
	0x5DBC: 0xC0AC,
	0x5DBD: 0xC0AE,
	0x5DBE: 0xFFFD,
	0x5DBF: 0xFFFD,
	0x5DC0: 0xEFC4,
	0x5DC1: 0x9A66,
	0x5DC2: 0xF172,
	0x5DC3: 0xF1FD,
	0x5DC4: 0xFFFD,
	0x5DC5: 0x8CCC,
	0x5DC6: 0xF444,
	0x5DC7: 0xF445,
	0x5DC8: 0xFFFD,
	0x5DC9: 0xC460,
	0x5DCA: 0xFFFD,
	0x5DCB: 0xF5C9,
	0x5DCC: 0x8253,
	0x5DCD: 0xC4DE,
	0x5DCE: 0xFFFD,
	0x5DCF: 0xF5CA,
	0x5DD0: 0x82DA,
	0x5DD1: 0xF6DE,
	0x5DD2: 0xC572,
	0x5DD3: 0x82DB,
	0x5DD4: 0xC571,
	0x5DD5: 0xF6DD,
	0x5DD6: 0xC5C9,
	0x5DD7: 0x9A67,
	0x5DD8: 0xF7D6,
	0x5DD9: 0xFFFD,
	0x5DDA: 0xFFFD,
	0x5DDB: 0xC6CC,
	0x5DDC: 0xFFFD,
	0x5DDD: 0xA474,
	0x5DDE: 0xA67B,
	0x5DDF: 0xC9DA,
	0x5DE0: 0xCACA,
	0x5DE1: 0xA8B5,
	0x5DE2: 0xB15F,
	0x5DE3: 0x9357,
	0x5DE4: 0xFFFD,
	0x5DE5: 0xA475,
	0x5DE6: 0xA5AA,
	0x5DE7: 0xA5A9,
	0x5DE8: 0xA5A8,
	0x5DE9: 0x88B2,
	0x5DEA: 0xFFFD,
	0x5DEB: 0xA7C5,
	0x5DEC: 0xFFFD,
	0x5DED: 0xFFFD,
	0x5DEE: 0xAE74,
	0x5DEF: 0x8E43,
	0x5DF0: 0xDD57,
	0x5DF1: 0xA476,
	0x5DF2: 0xA477,
	0x5DF3: 0xA478,
	0x5DF4: 0xA4DA,
	0x5DF5: 0xFBFA,
	0x5DF6: 0xFFFD,
	0x5DF7: 0xABD1,
	0x5DF8: 0xFFFD,
	0x5DF9: 0xCEAF,
	0x5DFA: 0xFFFD,
	0x5DFB: 0x9266,
	0x5DFC: 0xFFFD,
	0x5DFD: 0xB453,
	0x5DFE: 0xA479,
	0x5DFF: 0xC95D,
	0x5E00: 0xFFFD,
	0x5E01: 0x86C5,
	0x5E02: 0xA5AB,
	0x5E03: 0xA5AC,
	0x5E04: 0xC978,
	0x5E05: 0x836C,
	0x5E06: 0xA67C,
	0x5E07: 0xFFFD,
	0x5E08: 0x83B6,
	0x5E09: 0x9A68,
	0x5E0A: 0xCACB,
	0x5E0B: 0xFBFB,
	0x5E0C: 0xA7C6,
	0x5E0D: 0xFFFD,
	0x5E0E: 0xCACC,
	0x5E0F: 0x84D9,
	0x5E10: 0x8444,
	0x5E11: 0xA9AE,
	0x5E12: 0xFBFC,
	0x5E13: 0xFFFD,
	0x5E14: 0xCC6E,
	0x5E15: 0xA9AC,
	0x5E16: 0xA9AB,
	0x5E17: 0xCC6D,
	0x5E18: 0xA9A9,
	0x5E19: 0xCC6F,
	0x5E1A: 0xA9AA,
	0x5E1B: 0xA9AD,
	0x5E1C: 0x87C3,
	0x5E1D: 0xABD2,
	0x5E1E: 0xFFFD,
	0x5E1F: 0xABD4,
	0x5E20: 0xCEB3,
	0x5E21: 0xCEB0,
	0x5E22: 0xCEB1,
	0x5E23: 0xCEB2,
	0x5E24: 0xCEB4,
	0x5E25: 0xABD3,
	0x5E26: 0x8443,
	0x5E27: 0x84D8,
	0x5E28: 0xD174,
	0x5E29: 0xD173,
	0x5E2A: 0xFFFD,
	0x5E2B: 0xAE76,
	0x5E2C: 0xFFFD,
	0x5E2D: 0xAE75,
	0x5E2E: 0x89D6,
	0x5E2F: 0x9367,
	0x5E30: 0x926F,
	0x5E31: 0x8F50,
	0x5E32: 0xFFFD,
	0x5E33: 0xB162,
	0x5E34: 0xD546,
	0x5E35: 0xFFFD,
	0x5E36: 0xB161,
	0x5E37: 0xB163,
	0x5E38: 0xB160,
	0x5E39: 0xFFFD,
	0x5E3A: 0xFFFD,
	0x5E3B: 0x8E68,
	0x5E3C: 0x86C6,
	0x5E3D: 0xB455,
	0x5E3E: 0xD545,
	0x5E3F: 0xFFFD,
	0x5E40: 0xB456,
	0x5E41: 0xD8F3,
	0x5E42: 0x88CB,
	0x5E43: 0xB457,
	0x5E44: 0xD8F2,
	0x5E45: 0xB454,
	0x5E46: 0xFFFD,
	0x5E47: 0x82DC,
	0x5E48: 0x9A69,
	0x5E49: 0xFFFD,
	0x5E4A: 0xDD5A,
	0x5E4B: 0xDD5C,
	0x5E4C: 0xB745,
	0x5E4D: 0xDD5B,
	0x5E4E: 0xDD59,
	0x5E4F: 0xDD58,
	0x5E50: 0xFFFD,
	0x5E51: 0xFFFD,
	0x5E52: 0xFFFD,
	0x5E53: 0xE1B4,
	0x5E54: 0xB9F7,
	0x5E55: 0xB9F5,
	0x5E56: 0xFFFD,
	0x5E57: 0xB9F6,
	0x5E58: 0xE1B2,
	0x5E59: 0xE1B3,
	0x5E5A: 0xFFFD,
	0x5E5B: 0xB9F3,
	0x5E5C: 0xE571,
	0x5E5D: 0xE56F,
	0x5E5E: 0xFBFE,
	0x5E5F: 0xBC6D,
	0x5E60: 0xE570,
	0x5E61: 0xBC6E,
	0x5E62: 0xBC6C,
	0x5E63: 0xB9F4,
	0x5E64: 0x82DD,
	0x5E65: 0xFFFD,
	0x5E66: 0xE96D,
	0x5E67: 0xE96B,
	0x5E68: 0xE96C,
	0x5E69: 0xE56E,
	0x5E6A: 0xECDC,
	0x5E6B: 0xC0B0,
	0x5E6C: 0xECDB,
	0x5E6D: 0xEFC5,
	0x5E6E: 0xEFC6,
	0x5E6F: 0xE96E,
	0x5E70: 0xF1FE,
	0x5E71: 0xFFFD,
	0x5E72: 0xA47A,
	0x5E73: 0xA5AD,
	0x5E74: 0xA67E,
	0x5E75: 0xC9DB,
	0x5E76: 0xA67D,
	0x5E77: 0xFFFD,
	0x5E78: 0xA9AF,
	0x5E79: 0xB746,
	0x5E7A: 0xC6CD,
	0x5E7B: 0xA4DB,
	0x5E7C: 0xA5AE,
	0x5E7D: 0xABD5,
	0x5E7E: 0xB458,
	0x5E7F: 0xC6CE,
	0x5E80: 0xC979,
	0x5E81: 0x9375,
	0x5E82: 0xC97A,
	0x5E83: 0x92BE,
	0x5E84: 0xC9DC,
	0x5E85: 0xFFFD,
	0x5E86: 0x87CA,
	0x5E87: 0xA7C8,
	0x5E88: 0xCAD0,
	0x5E89: 0xCACE,
	0x5E8A: 0xA7C9,
	0x5E8B: 0xCACD,
	0x5E8C: 0xCACF,
	0x5E8D: 0xCAD1,
	0x5E8E: 0xFFFD,
	0x5E8F: 0xA7C7,
	0x5E90: 0x8B72,
	0x5E91: 0x8EB5,
	0x5E92: 0x9A6A,
	0x5E93: 0x83B7,
	0x5E94: 0x89D8,
	0x5E95: 0xA9B3,
	0x5E96: 0xA9B4,
	0x5E97: 0xA9B1,
	0x5E98: 0xFFFD,
	0x5E99: 0x87C6,
	0x5E9A: 0xA9B0,
	0x5E9B: 0xCEB8,
	0x5E9C: 0xA9B2,
	0x5E9D: 0xFFFD,
	0x5E9E: 0x8B71,
	0x5E9F: 0x87C4,
	0x5EA0: 0xABD6,
	0x5EA1: 0xFFFD,
	0x5EA2: 0xCEB7,
	0x5EA3: 0xCEB9,
	0x5EA4: 0xCEB6,
	0x5EA5: 0xCEBA,
	0x5EA6: 0xABD7,
	0x5EA7: 0xAE79,
	0x5EA8: 0xD175,
	0x5EA9: 0xFFFD,
	0x5EAA: 0xD177,
	0x5EAB: 0xAE77,
	0x5EAC: 0xD178,
	0x5EAD: 0xAE78,
	0x5EAE: 0xD176,
	0x5EAF: 0xFFFD,
	0x5EB0: 0xCEB5,
	0x5EB1: 0xD547,
	0x5EB2: 0xD54A,
	0x5EB3: 0xD54B,
	0x5EB4: 0xD548,
	0x5EB5: 0xB167,
	0x5EB6: 0xB166,
	0x5EB7: 0xB164,
	0x5EB8: 0xB165,
	0x5EB9: 0xD549,
	0x5EBA: 0xFFFD,
	0x5EBB: 0xFFFD,
	0x5EBC: 0xFFFD,
	0x5EBD: 0x9A6B,
	0x5EBE: 0xB168,
	0x5EBF: 0xFFFD,
	0x5EC0: 0xFFFD,
	0x5EC1: 0xB45A,
	0x5EC2: 0xB45B,
	0x5EC3: 0x93B2,
	0x5EC4: 0xB45C,
	0x5EC5: 0xDD5D,
	0x5EC6: 0xDD5F,
	0x5EC7: 0xDD61,
	0x5EC8: 0xB748,
	0x5EC9: 0xB747,
	0x5ECA: 0xB459,
	0x5ECB: 0xDD60,
	0x5ECC: 0xDD5E,
	0x5ECD: 0xFEA4,
	0x5ECE: 0xE1B8,
	0x5ECF: 0x82DE,
	0x5ED0: 0x82DF,
	0x5ED1: 0xE1B6,
	0x5ED2: 0xE1BC,
	0x5ED3: 0xB9F8,
	0x5ED4: 0xE1BD,
	0x5ED5: 0xE1BA,
	0x5ED6: 0xB9F9,
	0x5ED7: 0xE1B7,
	0x5ED8: 0xE1B5,
	0x5ED9: 0xE1BB,
	0x5EDA: 0xBC70,
	0x5EDB: 0xE573,
	0x5EDC: 0xE1B9,
	0x5EDD: 0xBC72,
	0x5EDE: 0xE574,
	0x5EDF: 0xBC71,
	0x5EE0: 0xBC74,
	0x5EE1: 0xE575,
	0x5EE2: 0xBC6F,
	0x5EE3: 0xBC73,
	0x5EE4: 0xFFFD,
	0x5EE5: 0xE973,
	0x5EE6: 0xE971,
	0x5EE7: 0xE970,
	0x5EE8: 0xE972,
	0x5EE9: 0xE96F,
	0x5EEA: 0x82E0,
	0x5EEB: 0xFFFD,
	0x5EEC: 0xC366,
	0x5EED: 0xFFFD,
	0x5EEE: 0xF446,
	0x5EEF: 0xF447,
	0x5EF0: 0x82E1,
	0x5EF1: 0xF5CB,
	0x5EF2: 0xF6DF,
	0x5EF3: 0xC655,
	0x5EF4: 0xC6CF,
	0x5EF5: 0xFFFD,
	0x5EF6: 0xA9B5,
	0x5EF7: 0xA7CA,
	0x5EF8: 0x95A4,
	0x5EF9: 0x95A1,
	0x5EFA: 0xABD8,
	0x5EFB: 0x95EE,
	0x5EFC: 0x95FA,
	0x5EFD: 0xFFFD,
	0x5EFE: 0xA47B,
	0x5EFF: 0xA4DC,
	0x5F00: 0x857B,
	0x5F01: 0xA5AF,
	0x5F02: 0xC9DD,
	0x5F03: 0x8456,
	0x5F04: 0xA7CB,
	0x5F05: 0xCAD2,
	0x5F06: 0xFFFD,
	0x5F07: 0xCEBB,
	0x5F08: 0xABD9,
	0x5F09: 0x82E2,
	0x5F0A: 0xB9FA,
	0x5F0B: 0xA47C,
	0x5F0C: 0x82E3,
	0x5F0D: 0x95AA,
	0x5F0E: 0x9A6C,
	0x5F0F: 0xA6A1,
	0x5F10: 0x93AE,
	0x5F11: 0x82E4,
	0x5F12: 0xB749,
	0x5F13: 0xA47D,
	0x5F14: 0xA4DD,
	0x5F15: 0xA4DE,
	0x5F16: 0x9475,
	0x5F17: 0xA5B1,
	0x5F18: 0xA5B0,
	0x5F19: 0xFFFD,
	0x5F1A: 0xC9DE,
	0x5F1B: 0xA6A2,
	0x5F1C: 0xFFFD,
	0x5F1D: 0xCAD3,
	0x5F1E: 0xFFFD,
	0x5F1F: 0xA7CC,
	0x5F20: 0x8445,
	0x5F21: 0x82E5,
	0x5F22: 0xCC71,
	0x5F23: 0xCC72,
	0x5F24: 0xCC73,
	0x5F25: 0x93F9,
	0x5F26: 0xA9B6,
	0x5F27: 0xA9B7,
	0x5F28: 0xCC70,
	0x5F29: 0xA9B8,
	0x5F2A: 0x8DC3,
	0x5F2B: 0xFFFD,
	0x5F2C: 0xFFFD,
	0x5F2D: 0xABDA,
	0x5F2E: 0xCEBC,
	0x5F2F: 0x8CCE,
	0x5F30: 0xD17A,
	0x5F31: 0xAE7A,
	0x5F32: 0xFFFD,
	0x5F33: 0xD179,
	0x5F34: 0x82E6,
	0x5F35: 0xB169,
	0x5F36: 0xD54C,
	0x5F37: 0xB16A,
	0x5F38: 0xD54D,
	0x5F39: 0x87C9,
	0x5F3A: 0x8446,
	0x5F3B: 0x9D7B,
	0x5F3C: 0xB45D,
	0x5F3D: 0xFFFD,
	0x5F3E: 0x9371,
	0x5F3F: 0xFFFD,
	0x5F40: 0xDD62,
	0x5F41: 0x82E7,
	0x5F42: 0xFFFD,
	0x5F43: 0xE1BF,
	0x5F44: 0xE1BE,
	0x5F45: 0x82E8,
	0x5F46: 0xB9FB,
	0x5F47: 0xFFFD,
	0x5F48: 0xBC75,
	0x5F49: 0xE576,
	0x5F4A: 0xBECA,
	0x5F4B: 0xE974,
	0x5F4C: 0xC0B1,
	0x5F4D: 0xFC41,
	0x5F4E: 0xC573,
	0x5F4F: 0xF7D8,
	0x5F50: 0xC6D0,
	0x5F51: 0x82E9,
	0x5F52: 0x8AD0,
	0x5F53: 0x85E5,
	0x5F54: 0xCC74,
	0x5F55: 0x89A3,
	0x5F56: 0xCEBD,
	0x5F57: 0xB16B,
	0x5F58: 0xD8F4,
	0x5F59: 0xB74A,
	0x5F5A: 0xFFFD,
	0x5F5B: 0xFFFD,
	0x5F5C: 0x82EA,
	0x5F5D: 0xC255,
	0x5F5E: 0xC255,
	0x5F5F: 0xFFFD,
	0x5F60: 0xFFFD,
	0x5F61: 0xC6D1,
	0x5F62: 0xA7CE,
	0x5F63: 0xFEA8,
	0x5F64: 0xA7CD,
	0x5F65: 0xABDB,
	0x5F66: 0x82EB,
	0x5F67: 0xD17B,
	0x5F68: 0xFFFD,
	0x5F69: 0xB16D,
	0x5F6A: 0xB343,
	0x5F6B: 0xB16E,
	0x5F6C: 0xB16C,
	0x5F6D: 0xB45E,
	0x5F6E: 0xFFFD,
	0x5F6F: 0xE1C0,
	0x5F70: 0xB9FC,
	0x5F71: 0xBC76,
	0x5F72: 0x9A6D,
	0x5F73: 0xC94C,
	0x5F74: 0xC9DF,
	0x5F75: 0xFFFD,
	0x5F76: 0xCAD5,
	0x5F77: 0xA7CF,
	0x5F78: 0xCAD4,
	0x5F79: 0xA7D0,
	0x5F7A: 0xFFFD,
	0x5F7B: 0x86C7,
	0x5F7C: 0xA9BC,
	0x5F7D: 0xCC77,
	0x5F7E: 0xCC76,
	0x5F7F: 0xA9BB,
	0x5F80: 0xA9B9,
	0x5F81: 0xA9BA,
	0x5F82: 0xCC75,
	0x5F83: 0x82EC,
	0x5F84: 0x92A6,
	0x5F85: 0xABDD,
	0x5F86: 0xCEBE,
	0x5F87: 0xABE0,
	0x5F88: 0xABDC,
	0x5F89: 0xABE2,
	0x5F8A: 0xABDE,
	0x5F8B: 0xABDF,
	0x5F8C: 0xABE1,
	0x5F8D: 0xFFFD,
	0x5F8E: 0xFFFD,
	0x5F8F: 0xFFFD,
	0x5F90: 0xAE7D,
	0x5F91: 0xAE7C,
	0x5F92: 0xAE7B,
	0x5F93: 0x92DC,
	0x5F94: 0xFFFD,
	0x5F95: 0x8448,
	0x5F96: 0xD54F,
	0x5F97: 0xB16F,
	0x5F98: 0xB172,
	0x5F99: 0xB170,
	0x5F9A: 0xFFFD,
	0x5F9B: 0xD54E,
	0x5F9C: 0xB175,
	0x5F9D: 0xFFFD,
	0x5F9E: 0xB171,
	0x5F9F: 0xD550,
	0x5FA0: 0xB174,
	0x5FA1: 0xB173,
	0x5FA2: 0xFFFD,
	0x5FA3: 0xFFFD,
	0x5FA4: 0xFC47,
	0x5FA5: 0xD8F6,
	0x5FA6: 0xD8F5,
	0x5FA7: 0x955A,
	0x5FA8: 0xB461,
	0x5FA9: 0xB45F,
	0x5FAA: 0xB460,
	0x5FAB: 0xD8F7,
	0x5FAC: 0xB74B,
	0x5FAD: 0xDD64,
	0x5FAE: 0xB74C,
	0x5FAF: 0xDD63,
	0x5FB0: 0xFFFD,
	0x5FB1: 0x9A6E,
	0x5FB2: 0xE577,
	0x5FB3: 0x93A8,
	0x5FB4: 0x9376,
	0x5FB5: 0xBC78,
	0x5FB6: 0xE1C1,
	0x5FB7: 0xBC77,
	0x5FB8: 0xFFFD,
	0x5FB9: 0xB9FD,
	0x5FBA: 0xFC48,
	0x5FBB: 0xECDE,
	0x5FBC: 0xE975,
	0x5FBD: 0xC0B2,
	0x5FBE: 0xECDD,
	0x5FBF: 0xF240,
	0x5FC0: 0xF448,
	0x5FC1: 0xF449,
	0x5FC2: 0x9A6F,
	0x5FC3: 0xA4DF,
	0x5FC4: 0x9CF5,
	0x5FC5: 0xA5B2,
	0x5FC6: 0x88DA,
	0x5FC7: 0xFFFD,
	0x5FC8: 0xFFFD,
	0x5FC9: 0xC97B,
	0x5FCA: 0xFFFD,
	0x5FCB: 0xFFFD,
	0x5FCC: 0xA7D2,
	0x5FCD: 0xA7D4,
	0x5FCE: 0xFFFD,
	0x5FCF: 0xC9E2,
	0x5FD0: 0xCAD8,
	0x5FD1: 0xCAD7,
	0x5FD2: 0xCAD6,
	0x5FD3: 0xFFFD,
	0x5FD4: 0xC9E1,
	0x5FD5: 0xC9E0,
	0x5FD6: 0xA6A4,
	0x5FD7: 0xA7D3,
	0x5FD8: 0xA7D1,
	0x5FD9: 0xA6A3,
	0x5FDA: 0xFFFD,
	0x5FDB: 0x9A70,
	0x5FDC: 0x924E,
	0x5FDD: 0xA9BD,
	0x5FDE: 0xCC78,
	0x5FDF: 0x9A71,
	0x5FE0: 0xA9BE,
	0x5FE1: 0xCADD,
	0x5FE2: 0xFFFD,
	0x5FE3: 0xCADF,
	0x5FE4: 0xCADE,
	0x5FE5: 0xCC79,
	0x5FE6: 0xFFFD,
	0x5FE7: 0x87CC,
	0x5FE8: 0xCADA,
	0x5FE9: 0xFFFD,
	0x5FEA: 0xA7D8,
	0x5FEB: 0xA7D6,
	0x5FEC: 0xFFFD,
	0x5FED: 0xCAD9,
	0x5FEE: 0xCADB,
	0x5FEF: 0xCAE1,
	0x5FF0: 0x82ED,
	0x5FF1: 0xA7D5,
	0x5FF2: 0xFFFD,
	0x5FF3: 0xCADC,
	0x5FF4: 0xCAE5,
	0x5FF5: 0xA9C0,
	0x5FF6: 0xFFFD,
	0x5FF7: 0xCAE2,
	0x5FF8: 0xA7D7,
	0x5FF9: 0xFFFD,
	0x5FFA: 0xCAE0,
	0x5FFB: 0xCAE3,
	0x5FFC: 0xFFFD,
	0x5FFD: 0xA9BF,
	0x5FFE: 0x85C7,
	0x5FFF: 0xA9C1,
	0x6000: 0xCAE4,
	0x6001: 0x86C8,
	0x6002: 0x87CD,
	0x6003: 0x87D1,
	0x6004: 0x8E6B,
	0x6005: 0x844A,
	0x6006: 0x85C8,
	0x6007: 0xFFFD,
	0x6008: 0xFFFD,
	0x6009: 0xCCAF,
	0x600A: 0xCCA2,
	0x600B: 0xCC7E,
	0x600C: 0xCCAE,
	0x600D: 0xCCA9,
	0x600E: 0xABE7,
	0x600F: 0xA9C2,
	0x6010: 0xCCAA,
	0x6011: 0xCCAD,
	0x6012: 0xABE3,
	0x6013: 0xCCAC,
	0x6014: 0xA9C3,
	0x6015: 0xA9C8,
	0x6016: 0xA9C6,
	0x6017: 0xCCA3,
	0x6018: 0xFFFD,
	0x6019: 0xCC7C,
	0x601A: 0xCCA5,
	0x601B: 0xA9CD,
	0x601C: 0xCCB0,
	0x601D: 0xABE4,
	0x601E: 0xCCA6,
	0x601F: 0xFFFD,
	0x6020: 0xABE5,
	0x6021: 0xA9C9,
	0x6022: 0xCCA8,
	0x6023: 0x9A72,
	0x6024: 0xCECD,
	0x6025: 0xABE6,
	0x6026: 0xCC7B,
	0x6027: 0xA9CA,
	0x6028: 0xABE8,
	0x6029: 0xA9CB,
	0x602A: 0xA9C7,
	0x602B: 0xA9CC,
	0x602C: 0xCCA7,
	0x602D: 0xCC7A,
	0x602E: 0xCCAB,
	0x602F: 0xA9C4,
	0x6030: 0xFFFD,
	0x6031: 0x95A6,
	0x6032: 0xCC7D,
	0x6033: 0xCCA4,
	0x6034: 0xCCA1,
	0x6035: 0xA9C5,
	0x6036: 0xFFFD,
	0x6037: 0xCEBF,
	0x6038: 0xFFFD,
	0x6039: 0xCEC0,
	0x603A: 0x9476,
	0x603B: 0x8A4B,
	0x603C: 0x8F74,
	0x603D: 0xFFFD,
	0x603E: 0xFFFD,
	0x603F: 0x8EE7,
	0x6040: 0xCECA,
	0x6041: 0xD1A1,
	0x6042: 0xCECB,
	0x6043: 0xABEE,
	0x6044: 0xCECE,
	0x6045: 0xCEC4,
	0x6046: 0xABED,
	0x6047: 0xCEC6,
	0x6048: 0xFFFD,
	0x6049: 0xCEC7,
	0x604A: 0x82EE,
	0x604B: 0x8CF6,
	0x604C: 0xCEC9,
	0x604D: 0xABE9,
	0x604E: 0xFFFD,
	0x604F: 0xFFFD,
	0x6050: 0xAEA3,
	0x6051: 0xFFFD,
	0x6052: 0xF9DA,
	0x6053: 0xCEC5,
	0x6054: 0xCEC1,
	0x6055: 0xAEA4,
	0x6056: 0xFFFD,
	0x6057: 0xFFFD,
	0x6058: 0xCECF,
	0x6059: 0xAE7E,
	0x605A: 0xD17D,
	0x605B: 0xCEC8,
	0x605C: 0xFFFD,
	0x605D: 0xD17C,
	0x605E: 0xCEC3,
	0x605F: 0xCECC,
	0x6060: 0x82EF,
	0x6061: 0xFFFD,
	0x6062: 0xABEC,
	0x6063: 0xAEA1,
	0x6064: 0xABF2,
	0x6065: 0xAEA2,
	0x6066: 0xCED0,
	0x6067: 0xD17E,
	0x6068: 0xABEB,
	0x6069: 0xAEA6,
	0x606A: 0xABF1,
	0x606B: 0xABF0,
	0x606C: 0xABEF,
	0x606D: 0xAEA5,
	0x606E: 0xCED1,
	0x606F: 0xAEA7,
	0x6070: 0xABEA,
	0x6071: 0xFFFD,
	0x6072: 0xCEC2,
	0x6073: 0x89D9,
	0x6074: 0xFFFD,
	0x6075: 0x92A8,
	0x6076: 0x84DC,
	0x6077: 0xFC4B,
	0x6078: 0x86CA,
	0x6079: 0x8F51,
	0x607A: 0x85C9,
	0x607B: 0x84DF,
	0x607C: 0x84E0,
	0x607D: 0x8DDD,
	0x607E: 0x9A73,
	0x607F: 0xB176,
	0x6080: 0xD1A4,
	0x6081: 0xD1A6,
	0x6082: 0xFFFD,
	0x6083: 0xD1A8,
	0x6084: 0xAEA8,
	0x6085: 0xAEAE,
	0x6086: 0xD553,
	0x6087: 0xD1AC,
	0x6088: 0xD1A3,
	0x6089: 0xB178,
	0x608A: 0xD551,
	0x608B: 0x82F0,
	0x608C: 0xAEAD,
	0x608D: 0xAEAB,
	0x608E: 0xD1AE,
	0x608F: 0xFFFD,
	0x6090: 0xD552,
	0x6091: 0xFFFD,
	0x6092: 0xD1A5,
	0x6093: 0xFFFD,
	0x6094: 0xAEAC,
	0x6095: 0xD1A9,
	0x6096: 0xAEAF,
	0x6097: 0xD1AB,
	0x6098: 0xFFFD,
	0x6099: 0xFFFD,
	0x609A: 0xAEAA,
	0x609B: 0xD1AA,
	0x609C: 0xD1AD,
	0x609D: 0xD1A7,
	0x609E: 0xFB64,
	0x609F: 0xAEA9,
	0x60A0: 0xB179,
	0x60A1: 0xFFFD,
	0x60A2: 0xD1A2,
	0x60A3: 0xB177,
	0x60A4: 0xFC4C,
	0x60A5: 0xFFFD,
	0x60A6: 0x82F1,
	0x60A7: 0xFEA6,
	0x60A8: 0xB17A,
	0x60A9: 0x93AF,
	0x60AA: 0x9241,
	0x60AB: 0x8E69,
	0x60AC: 0x8BF4,
	0x60AD: 0x8E6A,
	0x60AE: 0xFFFD,
	0x60AF: 0x87CE,
	0x60B0: 0xD555,
	0x60B1: 0xD55E,
	0x60B2: 0xB464,
	0x60B3: 0xFC4D,
	0x60B4: 0xB17C,
	0x60B5: 0xB1A3,
	0x60B6: 0xB465,
	0x60B7: 0xD560,
	0x60B8: 0xB1AA,
	0x60B9: 0xD8F9,
	0x60BA: 0xD556,
	0x60BB: 0xB1A2,
	0x60BC: 0xB1A5,
	0x60BD: 0xB17E,
	0x60BE: 0xD554,
	0x60BF: 0xD562,
	0x60C0: 0xD565,
	0x60C1: 0xD949,
	0x60C2: 0xFFFD,
	0x60C3: 0xD563,
	0x60C4: 0xD8FD,
	0x60C5: 0xB1A1,
	0x60C6: 0xB1A8,
	0x60C7: 0xB1AC,
	0x60C8: 0xD55D,
	0x60C9: 0xD8F8,
	0x60CA: 0xD561,
	0x60CB: 0xB17B,
	0x60CC: 0xD8FA,
	0x60CD: 0xD564,
	0x60CE: 0xD8FC,
	0x60CF: 0xD559,
	0x60D0: 0xFFFD,
	0x60D1: 0xB462,
	0x60D2: 0xFFFD,
	0x60D3: 0xD557,
	0x60D4: 0xD558,
	0x60D5: 0xB1A7,
	0x60D6: 0xFFFD,
	0x60D7: 0x9A74,
	0x60D8: 0xB1A6,
	0x60D9: 0xD55B,
	0x60DA: 0xB1AB,
	0x60DB: 0xD55F,
	0x60DC: 0xB1A4,
	0x60DD: 0xD55C,
	0x60DE: 0x82F2,
	0x60DF: 0xB1A9,
	0x60E0: 0xB466,
	0x60E1: 0xB463,
	0x60E2: 0xD8FB,
	0x60E3: 0x82AD,
	0x60E4: 0xD55A,
	0x60E5: 0xFFFD,
	0x60E6: 0xB17D,
	0x60E7: 0x8C71,
	0x60E8: 0x86CC,
	0x60E9: 0x8B73,
	0x60EA: 0xFFFD,
	0x60EB: 0x88D8,
	0x60EC: 0x84DE,
	0x60ED: 0x86CB,
	0x60EE: 0x87CF,
	0x60EF: 0x86C9,
	0x60F0: 0xB46B,
	0x60F1: 0xB46F,
	0x60F2: 0xD940,
	0x60F3: 0xB751,
	0x60F4: 0xB46D,
	0x60F5: 0xD944,
	0x60F6: 0xB471,
	0x60F7: 0xDD65,
	0x60F8: 0xD946,
	0x60F9: 0xB753,
	0x60FA: 0xB469,
	0x60FB: 0xB46C,
	0x60FC: 0xD947,
	0x60FD: 0xFC4E,
	0x60FE: 0xD948,
	0x60FF: 0xD94E,
	0x6100: 0xB473,
	0x6101: 0xB754,
	0x6102: 0xFFFD,
	0x6103: 0xD94A,
	0x6104: 0xD94F,
	0x6105: 0xD943,
	0x6106: 0xB75E,
	0x6107: 0x9A75,
	0x6108: 0xB755,
	0x6109: 0xB472,
	0x610A: 0xD941,
	0x610B: 0xD950,
	0x610C: 0x9A76,
	0x610D: 0xB75D,
	0x610E: 0xB470,
	0x610F: 0xB74E,
	0x6110: 0xD94D,
	0x6111: 0x82F3,
	0x6112: 0xB474,
	0x6113: 0xD945,
	0x6114: 0xD8FE,
	0x6115: 0xB46A,
	0x6116: 0xD942,
	0x6117: 0xFFFD,
	0x6118: 0xD94B,
	0x6119: 0x9A77,
	0x611A: 0xB74D,
	0x611B: 0xB752,
	0x611C: 0xB467,
	0x611D: 0xD94C,
	0x611E: 0xFFFD,
	0x611F: 0xB750,
	0x6120: 0x82F4,
	0x6121: 0x82F5,
	0x6122: 0x9A78,
	0x6123: 0xB468,
	0x6124: 0x87D0,
	0x6125: 0xFFFD,
	0x6126: 0x8EB6,
	0x6127: 0xB75C,
	0x6128: 0xE1C3,
	0x6129: 0xDD70,
	0x612A: 0xFFFD,
	0x612B: 0xDD68,
	0x612C: 0xE1C2,
	0x612D: 0xFFFD,
	0x612E: 0xDD6C,
	0x612F: 0xDD6E,
	0x6130: 0xFC4F,
	0x6131: 0xFFFD,
	0x6132: 0xDD6B,
	0x6133: 0xFFFD,
	0x6134: 0xB75B,
	0x6135: 0xFFFD,
	0x6136: 0xDD6A,
	0x6137: 0xB75F,
	0x6138: 0xFFFD,
	0x6139: 0xFFFD,
	0x613A: 0xFFFD,
	0x613B: 0xE1D2,
	0x613C: 0x82F6,
	0x613D: 0x82F7,
	0x613E: 0xB75A,
	0x613F: 0xBA40,
	0x6140: 0xDD71,
	0x6141: 0xE1C4,
	0x6142: 0xFCC9,
	0x6143: 0xFFFD,
	0x6144: 0xB758,
	0x6145: 0xDD69,
	0x6146: 0xDD6D,
	0x6147: 0xB9FE,
	0x6148: 0xB74F,
	0x6149: 0xDD66,
	0x614A: 0xDD67,
	0x614B: 0xBA41,
	0x614C: 0xB757,
	0x614D: 0xB759,
	0x614E: 0xB756,
	0x614F: 0xDD6F,
	0x6150: 0x9A79,
	0x6151: 0x8C72,
	0x6152: 0xE1C8,
	0x6153: 0xE1C9,
	0x6154: 0xE1CE,
	0x6155: 0xBC7D,
	0x6156: 0xE1D5,
	0x6157: 0xFFFD,
	0x6158: 0xBA47,
	0x6159: 0xFC52,
	0x615A: 0xBA46,
	0x615B: 0xE1D0,
	0x615C: 0xFC54,
	0x615D: 0xBC7C,
	0x615E: 0xE1C5,
	0x615F: 0xBA45,
	0x6160: 0x9A7A,
	0x6161: 0xE1D4,
	0x6162: 0xBA43,
	0x6163: 0xBA44,
	0x6164: 0x95AD,
	0x6165: 0xE1D1,
	0x6166: 0xE5AA,
	0x6167: 0xBC7A,
	0x6168: 0xB46E,
	0x6169: 0xFFFD,
	0x616A: 0xE1D3,
	0x616B: 0xBCA3,
	0x616C: 0xE1CB,
	0x616D: 0xFFFD,
	0x616E: 0xBC7B,
	0x616F: 0x9566,
	0x6170: 0xBCA2,
	0x6171: 0xE1C6,
	0x6172: 0xE1CA,
	0x6173: 0xE1C7,
	0x6174: 0xE1CD,
	0x6175: 0xBA48,
	0x6176: 0xBC79,
	0x6177: 0xBA42,
	0x6178: 0xFFFD,
	0x6179: 0xE57A,
	0x617A: 0xE1CF,
	0x617B: 0xFFFD,
	0x617C: 0xBCA1,
	0x617D: 0xFC53,
	0x617E: 0xBCA4,
	0x617F: 0xFFFD,
	0x6180: 0xE1CC,
	0x6181: 0x9A7B,
	0x6182: 0xBC7E,
	0x6183: 0xE579,
	0x6184: 0xFFFD,
	0x6185: 0xFFFD,
	0x6186: 0xFFFD,
	0x6187: 0x95D1,
	0x6188: 0xFFFD,
	0x6189: 0xE57E,
	0x618A: 0xBECE,
	0x618B: 0xE578,
	0x618C: 0xE9A3,
	0x618D: 0xE5A9,
	0x618E: 0xBCA8,
	0x618F: 0xFFFD,
	0x6190: 0xBCA6,
	0x6191: 0xBECC,
	0x6192: 0xE5A6,
	0x6193: 0xE5A2,
	0x6194: 0xBCAC,
	0x6195: 0x9A7C,
	0x6196: 0xE978,
	0x6197: 0xFFFD,
	0x6198: 0x82F8,
	0x6199: 0xFE74,
	0x619A: 0xBCAA,
	0x619B: 0xE5A1,
	0x619C: 0xFC51,
	0x619D: 0xE976,
	0x619E: 0xFFFD,
	0x619F: 0xE5A5,
	0x61A0: 0xFFFD,
	0x61A1: 0xE5A8,
	0x61A2: 0xE57D,
	0x61A3: 0xFFFD,
	0x61A4: 0xBCAB,
	0x61A5: 0xFFFD,
	0x61A6: 0xFFFD,
	0x61A7: 0xBCA5,
	0x61A8: 0xE977,
	0x61A9: 0xBECD,
	0x61AA: 0xE5A7,
	0x61AB: 0xBCA7,
	0x61AC: 0xBCA9,
	0x61AD: 0xE5A4,
	0x61AE: 0xBCAD,
	0x61AF: 0xE5A3,
	0x61B0: 0xE57C,
	0x61B1: 0xE57B,
	0x61B2: 0xBECB,
	0x61B3: 0xE5AB,
	0x61B4: 0xE97A,
	0x61B5: 0xECE0,
	0x61B6: 0xBED0,
	0x61B7: 0x82F9,
	0x61B8: 0xE9A2,
	0x61B9: 0x9A7D,
	0x61BA: 0xE97E,
	0x61BB: 0xFFFD,
	0x61BC: 0xECE1,
	0x61BD: 0xFFFD,
	0x61BE: 0xBED1,
	0x61BF: 0xE9A1,
	0x61C0: 0x9A7E,
	0x61C1: 0xE97C,
	0x61C2: 0xC0B4,
	0x61C3: 0xECDF,
	0x61C4: 0xFFFD,
	0x61C5: 0xE979,
	0x61C6: 0xE97B,
	0x61C7: 0xC0B5,
	0x61C8: 0xBED3,
	0x61C9: 0xC0B3,
	0x61CA: 0xBED2,
	0x61CB: 0xC0B7,
	0x61CC: 0xE97D,
	0x61CD: 0xBECF,
	0x61CE: 0xFFFD,
	0x61CF: 0x9AA1,
	0x61D0: 0x925D,
	0x61D1: 0x8AC2,
	0x61D2: 0x8B75,
	0x61D3: 0x9AA2,
	0x61D4: 0x88D9,
	0x61D5: 0xFFFD,
	0x61D6: 0xEFCF,
	0x61D7: 0xFFFD,
	0x61D8: 0xEFC7,
	0x61D9: 0xFFFD,
	0x61DA: 0x9AA3,
	0x61DB: 0xFFFD,
	0x61DC: 0xFFFD,
	0x61DD: 0xFFFD,
	0x61DE: 0xECE7,
	0x61DF: 0xEFC8,
	0x61E0: 0xECE3,
	0x61E1: 0xFFFD,
	0x61E2: 0xFC56,
	0x61E3: 0xC256,
	0x61E4: 0xECE5,
	0x61E5: 0xECE4,
	0x61E6: 0xC0B6,
	0x61E7: 0xECE2,
	0x61E8: 0xECE6,
	0x61E9: 0xEFD0,
	0x61EA: 0xEFCC,
	0x61EB: 0xEFCE,
	0x61EC: 0xFFFD,
	0x61ED: 0xEFC9,
	0x61EE: 0xEFCA,
	0x61EF: 0xFFFD,
	0x61F0: 0xEFCD,
	0x61F1: 0xEFCB,
	0x61F2: 0xC367,
	0x61F3: 0xFFFD,
	0x61F4: 0x82FA,
	0x61F5: 0xC36A,
	0x61F6: 0xC369,
	0x61F7: 0xC368,
	0x61F8: 0xC461,
	0x61F9: 0xF44A,
	0x61FA: 0xC462,
	0x61FB: 0xF241,
	0x61FC: 0xC4DF,
	0x61FD: 0xF5CC,
	0x61FE: 0xC4E0,
	0x61FF: 0xC574,
	0x6200: 0xC5CA,
	0x6201: 0xF7D9,
	0x6202: 0xFFFD,
	0x6203: 0xF7DA,
	0x6204: 0xF7DB,
	0x6205: 0xFFFD,
	0x6206: 0x90AB,
	0x6207: 0xF9BA,
	0x6208: 0xA4E0,
	0x6209: 0xC97C,
	0x620A: 0xA5B3,
	0x620B: 0x8DB8,
	0x620C: 0xA6A6,
	0x620D: 0xA6A7,
	0x620E: 0xA6A5,
	0x620F: 0x89DA,
	0x6210: 0xA6A8,
	0x6211: 0xA7DA,
	0x6212: 0xA7D9,
	0x6213: 0x82FB,
	0x6214: 0xCCB1,
	0x6215: 0xA9CF,
	0x6216: 0xA9CE,
	0x6217: 0x8E6D,
	0x6218: 0x88DB,
	0x6219: 0xD1AF,
	0x621A: 0xB1AD,
	0x621B: 0xB1AE,
	0x621C: 0xFFFD,
	0x621D: 0x82FC,
	0x621E: 0x82FD,
	0x621F: 0xB475,
	0x6220: 0xDD72,
	0x6221: 0xB760,
	0x6222: 0xB761,
	0x6223: 0xDD74,
	0x6224: 0xDD76,
	0x6225: 0xDD75,
	0x6226: 0x9349,
	0x6227: 0xE1D7,
	0x6228: 0xFFFD,
	0x6229: 0xE1D6,
	0x622A: 0xBA49,
	0x622B: 0xE1D8,
	0x622C: 0x8E6C,
	0x622D: 0xE5AC,
	0x622E: 0xBCAE,
	0x622F: 0x9270,
	0x6230: 0xBED4,
	0x6231: 0xFFFD,
	0x6232: 0xC0B8,
	0x6233: 0xC257,
	0x6234: 0xC0B9,
	0x6235: 0xFFFD,
	0x6236: 0xA4E1,
	0x6237: 0x82FE,
	0x6238: 0x90BD,
	0x6239: 0xFC58,
	0x623A: 0xCAE6,
	0x623B: 0x93EC,
	0x623C: 0xFFFD,
	0x623D: 0xCCB2,
	0x623E: 0xA9D1,
	0x623F: 0xA9D0,
	0x6240: 0xA9D2,
	0x6241: 0xABF3,
	0x6242: 0xCED2,
	0x6243: 0xCED3,
	0x6244: 0xFFFD,
	0x6245: 0xFFFD,
	0x6246: 0xD1B0,
	0x6247: 0xAEB0,
	0x6248: 0xB1AF,
	0x6249: 0xB476,
	0x624A: 0xD951,
	0x624B: 0xA4E2,
	0x624C: 0x9CF2,
	0x624D: 0xA47E,
	0x624E: 0xA4E3,
	0x624F: 0xFFFD,
	0x6250: 0xC97D,
	0x6251: 0xA5B7,
	0x6252: 0xA5B6,
	0x6253: 0xA5B4,
	0x6254: 0xA5B5,
	0x6255: 0x93C1,
	0x6256: 0xFFFD,
	0x6257: 0xFFFD,
	0x6258: 0xA6AB,
	0x6259: 0xC9E9,
	0x625A: 0xC9EB,
	0x625B: 0xA6AA,
	0x625C: 0xC9E3,
	0x625D: 0xFFFD,
	0x625E: 0xC9E4,
	0x625F: 0xFFFD,
	0x6260: 0xC9EA,
	0x6261: 0xC9E6,
	0x6262: 0xC9E8,
	0x6263: 0xA6A9,
	0x6264: 0xC9E5,
	0x6265: 0xC9EC,
	0x6266: 0xC9E7,
	0x6267: 0x83F9,
	0x6268: 0xFC59,
	0x6269: 0x8AC3,
	0x626A: 0x844D,
	0x626B: 0x844B,
	0x626C: 0x84E4,
	0x626D: 0xA7E1,
	0x626E: 0xA7EA,
	0x626F: 0xA7E8,
	0x6270: 0xCAF0,
	0x6271: 0xCAED,
	0x6272: 0xCAF5,
	0x6273: 0xA7E6,
	0x6274: 0xCAF6,
	0x6275: 0xFFFD,
	0x6276: 0xA7DF,
	0x6277: 0xCAF3,
	0x6278: 0xFFFD,
	0x6279: 0xA7E5,
	0x627A: 0xCAEF,
	0x627B: 0xCAEE,
	0x627C: 0xA7E3,
	0x627D: 0xCAF4,
	0x627E: 0xA7E4,
	0x627F: 0xA9D3,
	0x6280: 0xA7DE,
	0x6281: 0xCAF1,
	0x6282: 0xFC5B,
	0x6283: 0xCAE7,
	0x6284: 0xA7DB,
	0x6285: 0xFC5A,
	0x6286: 0xA7EE,
	0x6287: 0xCAEC,
	0x6288: 0xCAF2,
	0x6289: 0xA7E0,
	0x628A: 0xA7E2,
	0x628B: 0xFFFD,
	0x628C: 0xCAE8,
	0x628D: 0xFFFD,
	0x628E: 0xCAE9,
	0x628F: 0xCAEA,
	0x6290: 0x9AA4,
	0x6291: 0xA7ED,
	0x6292: 0xA7E7,
	0x6293: 0xA7EC,
	0x6294: 0xCAEB,
	0x6295: 0xA7EB,
	0x6296: 0xA7DD,
	0x6297: 0xA7DC,
	0x6298: 0xA7E9,
	0x6299: 0xFFFD,
	0x629A: 0x87D7,
	0x629B: 0x90BE,
	0x629C: 0x93BB,
	0x629D: 0xFD57,
	0x629E: 0x936A,
	0x629F: 0x8E6E,
	0x62A0: 0x8E6F,
	0x62A1: 0x844E,
	0x62A2: 0x85CB,
	0x62A3: 0xFFFD,
	0x62A4: 0x8CA8,
	0x62A5: 0x84D2,
	0x62A6: 0xFC5C,
	0x62A7: 0xFFFD,
	0x62A8: 0xA9E1,
	0x62A9: 0xCCBE,
	0x62AA: 0xCCB7,
	0x62AB: 0xA9DC,
	0x62AC: 0xA9EF,
	0x62AD: 0xCCB3,
	0x62AE: 0xCCBA,
	0x62AF: 0xCCBC,
	0x62B0: 0xCCBF,
	0x62B1: 0xA9EA,
	0x62B2: 0xFFFD,
	0x62B3: 0xCCBB,
	0x62B4: 0xCCB4,
	0x62B5: 0xA9E8,
	0x62B6: 0xCCB8,
	0x62B7: 0xFFFD,
	0x62B8: 0xCCC0,
	0x62B9: 0xA9D9,
	0x62BA: 0xFFFD,
	0x62BB: 0xCCBD,
	0x62BC: 0xA9E3,
	0x62BD: 0xA9E2,
	0x62BE: 0xCCB6,
	0x62BF: 0xA9D7,
	0x62C0: 0xFFFD,
	0x62C1: 0xFFFD,
	0x62C2: 0xA9D8,
	0x62C3: 0xFB46,
	0x62C4: 0xA9D6,
	0x62C5: 0x88E3,
	0x62C6: 0xA9EE,
	0x62C7: 0xA9E6,
	0x62C8: 0xA9E0,
	0x62C9: 0xA9D4,
	0x62CA: 0xCCB9,
	0x62CB: 0xA9DF,
	0x62CC: 0xA9D5,
	0x62CD: 0xA9E7,
	0x62CE: 0xA9F0,
	0x62CF: 0xCED4,
	0x62D0: 0xA9E4,
	0x62D1: 0xCCB5,
	0x62D2: 0xA9DA,
	0x62D3: 0xA9DD,
	0x62D4: 0xA9DE,
	0x62D5: 0xFC5D,
	0x62D6: 0xA9EC,
	0x62D7: 0xA9ED,
	0x62D8: 0xA9EB,
	0x62D9: 0xA9E5,
	0x62DA: 0xA9E9,
	0x62DB: 0xA9DB,
	0x62DC: 0xABF4,
	0x62DD: 0x93B1,
	0x62DE: 0xFFFD,
	0x62DF: 0x89DE,
	0x62E0: 0x9275,
	0x62E1: 0x925E,
	0x62E2: 0x8B76,
	0x62E3: 0x84E1,
	0x62E4: 0xFFFD,
	0x62E5: 0x88DC,
	0x62E6: 0x8BF6,
	0x62E7: 0x89DD,
	0x62E8: 0x87D5,
	0x62E9: 0x88E1,
	0x62EA: 0xFFFD,
	0x62EB: 0xCEDA,
	0x62EC: 0xAC41,
	0x62ED: 0xABF8,
	0x62EE: 0xABFA,
	0x62EF: 0xAC40,
	0x62F0: 0xCEE6,
	0x62F1: 0xABFD,
	0x62F2: 0xD1B1,
	0x62F3: 0xAEB1,
	0x62F4: 0xAC43,
	0x62F5: 0xCED7,
	0x62F6: 0xCEDF,
	0x62F7: 0xABFE,
	0x62F8: 0xCEDE,
	0x62F9: 0xCEDB,
	0x62FA: 0xCEE3,
	0x62FB: 0xCEE5,
	0x62FC: 0xABF7,
	0x62FD: 0xABFB,
	0x62FE: 0xAC42,
	0x62FF: 0xAEB3,
	0x6300: 0xCEE0,
	0x6301: 0xABF9,
	0x6302: 0xAC45,
	0x6303: 0xCED9,
	0x6304: 0xFFFD,
	0x6305: 0xFFFD,
	0x6306: 0xFFFD,
	0x6307: 0xABFC,
	0x6308: 0xAEB2,
	0x6309: 0xABF6,
	0x630A: 0xFFFD,
	0x630B: 0xCED6,
	0x630C: 0xCEDD,
	0x630D: 0xCED5,
	0x630E: 0xCED8,
	0x630F: 0xCEDC,
	0x6310: 0xD1B2,
	0x6311: 0xAC44,
	0x6312: 0xFFFD,
	0x6313: 0xCEE1,
	0x6314: 0xCEE2,
	0x6315: 0xCEE4,
	0x6316: 0xABF5,
	0x6317: 0xFFFD,
	0x6318: 0x94F4,
	0x6319: 0x9276,
	0x631A: 0x87D2,
	0x631B: 0x8CF7,
	0x631C: 0xFFFD,
	0x631D: 0x88E4,
	0x631E: 0x88DE,
	0x631F: 0x83B9,
	0x6320: 0x87D6,
	0x6321: 0x88DD,
	0x6322: 0x8EB7,
	0x6323: 0x844F,
	0x6324: 0x89DC,
	0x6325: 0x84E2,
	0x6326: 0xFFFD,
	0x6327: 0x90BF,
	0x6328: 0xAEC1,
	0x6329: 0xD1BE,
	0x632A: 0xAEBF,
	0x632B: 0xAEC0,
	0x632C: 0xD1B4,
	0x632D: 0xD1C4,
	0x632E: 0xA05E,
	0x632F: 0xAEB6,
	0x6330: 0xFFFD,
	0x6331: 0x9AA5,
	0x6332: 0xD566,
	0x6333: 0xD1C6,
	0x6334: 0xD1C0,
	0x6335: 0xFC5F,
	0x6336: 0xD1B7,
	0x6337: 0x9AA7,
	0x6338: 0xD1C9,
	0x6339: 0xD1BA,
	0x633A: 0xAEBC,
	0x633B: 0xD57D,
	0x633C: 0xD1BD,
	0x633D: 0xAEBE,
	0x633E: 0xAEB5,
	0x633F: 0x9356,
	0x6340: 0xD1CB,
	0x6341: 0xD1BF,
	0x6342: 0xAEB8,
	0x6343: 0xD1B8,
	0x6344: 0xD1B5,
	0x6345: 0xD1B6,
	0x6346: 0xAEB9,
	0x6347: 0xD1C5,
	0x6348: 0xD1CC,
	0x6349: 0xAEBB,
	0x634A: 0xD1BC,
	0x634B: 0xD1BB,
	0x634C: 0xAEC3,
	0x634D: 0xAEC2,
	0x634E: 0xAEB4,
	0x634F: 0xAEBA,
	0x6350: 0xAEBD,
	0x6351: 0xD1C8,
	0x6352: 0xFFFD,
	0x6353: 0xFFFD,
	0x6354: 0xD1C2,
	0x6355: 0xAEB7,
	0x6356: 0xD1B3,
	0x6357: 0xD1CA,
	0x6358: 0xD1C1,
	0x6359: 0xD1C3,
	0x635A: 0xD1C7,
	0x635B: 0xFFFD,
	0x635C: 0x9355,
	0x635D: 0xFFFD,
	0x635E: 0x87D4,
	0x635F: 0x85CA,
	0x6360: 0xFFFD,
	0x6361: 0x88E2,
	0x6362: 0x84E3,
	0x6363: 0x85CC,
	0x6364: 0xFC5E,
	0x6365: 0xD567,
	0x6366: 0xFFFD,
	0x6367: 0xB1B7,
	0x6368: 0xB1CB,
	0x6369: 0xB1CA,
	0x636A: 0xFFFD,
	0x636B: 0xB1BF,
	0x636C: 0x9559,
	0x636D: 0xD579,
	0x636E: 0xD575,
	0x636F: 0xD572,
	0x6370: 0xD5A6,
	0x6371: 0xB1BA,
	0x6372: 0xB1B2,
	0x6373: 0xFFFD,
	0x6374: 0xFFFD,
	0x6375: 0xD577,
	0x6376: 0xB4A8,
	0x6377: 0xB1B6,
	0x6378: 0xD5A1,
	0x6379: 0x9AA8,
	0x637A: 0xB1CC,
	0x637B: 0xB1C9,
	0x637C: 0xD57B,
	0x637D: 0xD56A,
	0x637E: 0xFFFD,
	0x637F: 0xFC55,
	0x6380: 0xB1C8,
	0x6381: 0xD5A3,
	0x6382: 0xD569,
	0x6383: 0xB1BD,
	0x6384: 0xB1C1,
	0x6385: 0xD5A2,
	0x6386: 0xFFFD,
	0x6387: 0xD573,
	0x6388: 0xB1C2,
	0x6389: 0xB1BC,
	0x638A: 0xD568,
	0x638B: 0x9AA9,
	0x638C: 0xB478,
	0x638D: 0xD5A5,
	0x638E: 0xD571,
	0x638F: 0xB1C7,
	0x6390: 0xD574,
	0x6391: 0xD5A4,
	0x6392: 0xB1C6,
	0x6393: 0xFFFD,
	0x6394: 0xD952,
	0x6395: 0xFFFD,
	0x6396: 0xB1B3,
	0x6397: 0xD56F,
	0x6398: 0xB1B8,
	0x6399: 0xB1C3,
	0x639A: 0xFFFD,
	0x639B: 0xB1BE,
	0x639C: 0xD578,
	0x639D: 0xD56E,
	0x639E: 0xD56C,
	0x639F: 0xD57E,
	0x63A0: 0xB1B0,
	0x63A1: 0xB1C4,
	0x63A2: 0xB1B4,
	0x63A3: 0xB477,
	0x63A4: 0xD57C,
	0x63A5: 0xB1B5,
	0x63A6: 0xFFFD,
	0x63A7: 0xB1B1,
	0x63A8: 0xB1C0,
	0x63A9: 0xB1BB,
	0x63AA: 0xB1B9,
	0x63AB: 0xD570,
	0x63AC: 0xB1C5,
	0x63AD: 0xD56D,
	0x63AE: 0xD57A,
	0x63AF: 0xD576,
	0x63B0: 0xD954,
	0x63B1: 0xD953,
	0x63B2: 0x92A9,
	0x63B3: 0x88E0,
	0x63B4: 0x86CE,
	0x63B5: 0x9477,
	0x63B6: 0xFFFD,
	0x63B7: 0x8AC4,
	0x63B8: 0x87D8,
	0x63B9: 0xFB57,
	0x63BA: 0x86CF,
	0x63BB: 0x90C0,
	0x63BC: 0x8E70,
	0x63BD: 0xD56B,
	0x63BE: 0xD964,
	0x63BF: 0xFFFD,
	0x63C0: 0xB47A,
	0x63C1: 0x9AAA,
	0x63C2: 0xD96A,
	0x63C3: 0xD959,
	0x63C4: 0xD967,
	0x63C5: 0xDD77,
	0x63C6: 0xB47D,
	0x63C7: 0xD96B,
	0x63C8: 0xD96E,
	0x63C9: 0xB47C,
	0x63CA: 0xD95C,
	0x63CB: 0xD96D,
	0x63CC: 0xD96C,
	0x63CD: 0xB47E,
	0x63CE: 0xD955,
	0x63CF: 0xB479,
	0x63D0: 0xB4A3,
	0x63D1: 0xFD6C,
	0x63D2: 0xB4A1,
	0x63D3: 0xD969,
	0x63D4: 0xFFFD,
	0x63D5: 0xD95F,
	0x63D6: 0xB4A5,
	0x63D7: 0xD970,
	0x63D8: 0xD968,
	0x63D9: 0xD971,
	0x63DA: 0xB4AD,
	0x63DB: 0xB4AB,
	0x63DC: 0xD966,
	0x63DD: 0xD965,
	0x63DE: 0x90C1,
	0x63DF: 0xD963,
	0x63E0: 0xD95D,
	0x63E1: 0xB4A4,
	0x63E2: 0x9AAB,
	0x63E3: 0xB4A2,
	0x63E4: 0xD1B9,
	0x63E5: 0xD956,
	0x63E6: 0x9AAC,
	0x63E7: 0xDDB7,
	0x63E8: 0xD957,
	0x63E9: 0xB47B,
	0x63EA: 0xB4AA,
	0x63EB: 0xDD79,
	0x63EC: 0xFFFD,
	0x63ED: 0xB4A6,
	0x63EE: 0xB4A7,
	0x63EF: 0xD958,
	0x63F0: 0xD96F,
	0x63F1: 0xDD78,
	0x63F2: 0xD960,
	0x63F3: 0xD95B,
	0x63F4: 0xB4A9,
	0x63F5: 0xD961,
	0x63F6: 0xD95E,
	0x63F7: 0xFFFD,
	0x63F8: 0xA05F,
	0x63F9: 0xB4AE,
	0x63FA: 0x90C2,
	0x63FB: 0x9AAD,
	0x63FC: 0xFB5D,
	0x63FD: 0x8D53,
	0x63FE: 0x9AAE,
	0x63FF: 0x87D9,
	0x6400: 0x8BF7,
	0x6401: 0x89DF,
	0x6402: 0x86CD,
	0x6403: 0xFFFD,
	0x6404: 0xFFFD,
	0x6405: 0x8CF8,
	0x6406: 0xB770,
	0x6407: 0x9AAF,
	0x6408: 0xFFFD,
	0x6409: 0xDD7C,
	0x640A: 0xDDB1,
	0x640B: 0xDDB6,
	0x640C: 0xDDAA,
	0x640D: 0xB76C,
	0x640E: 0xDDBB,
	0x640F: 0xB769,
	0x6410: 0xDD7A,
	0x6411: 0xFFFD,
	0x6412: 0xDD7B,
	0x6413: 0xB762,
	0x6414: 0xB76B,
	0x6415: 0xDDA4,
	0x6416: 0xB76E,
	0x6417: 0xB76F,
	0x6418: 0xDDA5,
	0x6419: 0xFFFD,
	0x641A: 0xDDB2,
	0x641B: 0xDDB8,
	0x641C: 0xB76A,
	0x641D: 0xFFFD,
	0x641E: 0xB764,
	0x641F: 0xDDA3,
	0x6420: 0xDD7D,
	0x6421: 0xDDBA,
	0x6422: 0xDDA8,
	0x6423: 0xDDA9,
	0x6424: 0xDD7E,
	0x6425: 0xDDB4,
	0x6426: 0xDDAB,
	0x6427: 0xDDB5,
	0x6428: 0xDDAD,
	0x6429: 0xFFFD,
	0x642A: 0xB765,
	0x642B: 0xE1D9,
	0x642C: 0xB768,
	0x642D: 0xB766,
	0x642E: 0xDDB9,
	0x642F: 0xDDB0,
	0x6430: 0xDDAC,
	0x6431: 0xFFFD,
	0x6432: 0x9AB0,
	0x6433: 0xDDA1,
	0x6434: 0xBA53,
	0x6435: 0xDDAF,
	0x6436: 0xB76D,
	0x6437: 0xDDA7,
	0x6438: 0x9AB1,
	0x6439: 0xDDA6,
	0x643A: 0x8C74,
	0x643B: 0x9AB2,
	0x643C: 0xFFFD,
	0x643D: 0xB767,
	0x643E: 0xB763,
	0x643F: 0xE1EE,
	0x6440: 0xDDB3,
	0x6441: 0xDDAE,
	0x6442: 0x9345,
	0x6443: 0xDDA2,
	0x6444: 0x8C73,
	0x6445: 0x8F75,
	0x6446: 0x8AC7,
	0x6447: 0x93DA,
	0x6448: 0x8F52,
	0x6449: 0xFFFD,
	0x644A: 0x8CCF,
	0x644B: 0xE1E9,
	0x644C: 0xFFFD,
	0x644D: 0xE1DA,
	0x644E: 0xE1E5,
	0x644F: 0xFFFD,
	0x6450: 0xE1EC,
	0x6451: 0xBA51,
	0x6452: 0xB4AC,
	0x6453: 0xE1EA,
	0x6454: 0xBA4C,
	0x6455: 0xFFFD,
	0x6456: 0xFFFD,
	0x6457: 0xFFFD,
	0x6458: 0xBA4B,
	0x6459: 0xE1F1,
	0x645A: 0x9AB3,
	0x645B: 0xE1DB,
	0x645C: 0xE1E8,
	0x645D: 0xE1DC,
	0x645E: 0xE1E7,
	0x645F: 0xBA4F,
	0x6460: 0xE1EB,
	0x6461: 0xD962,
	0x6462: 0xFFFD,
	0x6463: 0xFFFD,
	0x6464: 0xFFFD,
	0x6465: 0xE1F2,
	0x6466: 0xE1E3,
	0x6467: 0xBA52,
	0x6468: 0xE5BA,
	0x6469: 0xBCAF,
	0x646A: 0xFFFD,
	0x646B: 0xE1F0,
	0x646C: 0xE1EF,
	0x646D: 0xBA54,
	0x646E: 0xE5AD,
	0x646F: 0xBCB0,
	0x6470: 0xE5AE,
	0x6471: 0x9AB4,
	0x6472: 0xE1DF,
	0x6473: 0xE1E0,
	0x6474: 0xE1DD,
	0x6475: 0xE1E2,
	0x6476: 0xE1DE,
	0x6477: 0xE1F3,
	0x6478: 0xBA4E,
	0x6479: 0xBCB1,
	0x647A: 0xBA50,
	0x647B: 0xBA55,
	0x647C: 0x9AB5,
	0x647D: 0xE1E1,
	0x647E: 0xFFFD,
	0x647F: 0xE1ED,
	0x6480: 0xFFFD,
	0x6481: 0xFFFD,
	0x6482: 0xE1E6,
	0x6483: 0x92B0,
	0x6484: 0x8FDA,
	0x6485: 0xE5B1,
	0x6486: 0xFFFD,
	0x6487: 0xBA4A,
	0x6488: 0xBCB4,
	0x6489: 0xE9AA,
	0x648A: 0xE5B6,
	0x648B: 0xE5B5,
	0x648C: 0xE5B7,
	0x648D: 0x9AB6,
	0x648E: 0xFFFD,
	0x648F: 0xE5B4,
	0x6490: 0xBCB5,
	0x6491: 0x90C3,
	0x6492: 0xBCBB,
	0x6493: 0xBCB8,
	0x6494: 0xFFFD,
	0x6495: 0xBCB9,
	0x6496: 0xE5AF,
	0x6497: 0xE5B2,
	0x6498: 0xE5BC,
	0x6499: 0xBCC1,
	0x649A: 0xBCBF,
	0x649B: 0xFFFD,
	0x649C: 0xE5B3,
	0x649D: 0xD95A,
	0x649E: 0xBCB2,
	0x649F: 0xE5B9,
	0x64A0: 0xE5B0,
	0x64A1: 0xFFFD,
	0x64A2: 0xBCC2,
	0x64A3: 0xE5B8,
	0x64A4: 0xBA4D,
	0x64A5: 0xBCB7,
	0x64A6: 0xE1E4,
	0x64A7: 0xFFFD,
	0x64A8: 0xFFFD,
	0x64A9: 0xBCBA,
	0x64AA: 0xFFFD,
	0x64AB: 0xBCBE,
	0x64AC: 0xBCC0,
	0x64AD: 0xBCBD,
	0x64AE: 0xBCBC,
	0x64AF: 0x9AB7,
	0x64B0: 0xBCB6,
	0x64B1: 0xE5BB,
	0x64B2: 0xBCB3,
	0x64B3: 0xBCC3,
	0x64B4: 0x9AB8,
	0x64B5: 0x8AC6,
	0x64B6: 0x9AB9,
	0x64B7: 0x8AC9,
	0x64B8: 0x8F76,
	0x64B9: 0x824D,
	0x64BA: 0x8FFE,
	0x64BB: 0xBED8,
	0x64BC: 0xBED9,
	0x64BD: 0xE9A9,
	0x64BE: 0xBEE2,
	0x64BF: 0xBEDF,
	0x64C0: 0x90C4,
	0x64C1: 0xBED6,
	0x64C2: 0xBEDD,
	0x64C3: 0xE9AB,
	0x64C4: 0xBEDB,
	0x64C5: 0xBED5,
	0x64C6: 0xFFFD,
	0x64C7: 0xBEDC,
	0x64C8: 0xFFFD,
	0x64C9: 0xE9A8,
	0x64CA: 0xC0BB,
	0x64CB: 0xBED7,
	0x64CC: 0xFFFD,
	0x64CD: 0xBEDE,
	0x64CE: 0xC0BA,
	0x64CF: 0xE9A7,
	0x64D0: 0xE9A6,
	0x64D1: 0xFFFD,
	0x64D2: 0xBEE0,
	0x64D3: 0xA05D,
	0x64D4: 0xBEE1,
	0x64D5: 0xFFFD,
	0x64D6: 0xE9A5,
	0x64D7: 0xE9A4,
	0x64D8: 0xC0BC,
	0x64D9: 0xE9AE,
	0x64DA: 0xBEDA,
	0x64DB: 0xE9AC,
	0x64DC: 0xFFFD,
	0x64DD: 0x9ABA,
	0x64DE: 0x8AC8,
	0x64DF: 0xFFFD,
	0x64E0: 0xC0BD,
	0x64E1: 0x90C5,
	0x64E2: 0xC0C2,
	0x64E3: 0xECEA,
	0x64E4: 0xECEC,
	0x64E5: 0x9ABB,
	0x64E6: 0xC0BF,
	0x64E7: 0xFBA3,
	0x64E8: 0xECED,
	0x64E9: 0xECE9,
	0x64EA: 0x95C8,
	0x64EB: 0xECEB,
	0x64EC: 0xC0C0,
	0x64ED: 0xC0C3,
	0x64EE: 0xFFFD,
	0x64EF: 0xECE8,
	0x64F0: 0xC0BE,
	0x64F1: 0xC0C1,
	0x64F2: 0xC259,
	0x64F3: 0xE9AD,
	0x64F4: 0xC258,
	0x64F5: 0xFFFD,
	0x64F6: 0x90C6,
	0x64F7: 0xC25E,
	0x64F8: 0xEFD4,
	0x64F9: 0xFFFD,
	0x64FA: 0xC25C,
	0x64FB: 0xC25D,
	0x64FC: 0xEFD7,
	0x64FD: 0xEFD3,
	0x64FE: 0xC25A,
	0x64FF: 0xEFD1,
	0x6500: 0xC36B,
	0x6501: 0xEFD5,
	0x6502: 0xFFFD,
	0x6503: 0xEFD6,
	0x6504: 0xEFD2,
	0x6505: 0x90C7,
	0x6506: 0xC25B,
	0x6507: 0xF242,
	0x6508: 0xFFFD,
	0x6509: 0xF245,
	0x650A: 0x9ABC,
	0x650B: 0xFFFD,
	0x650C: 0xF246,
	0x650D: 0xF244,
	0x650E: 0xF247,
	0x650F: 0xC36C,
	0x6510: 0xF243,
	0x6511: 0x9ABD,
	0x6512: 0x9057,
	0x6513: 0xF44E,
	0x6514: 0xC464,
	0x6515: 0xF44D,
	0x6516: 0xF44C,
	0x6517: 0xF44B,
	0x6518: 0xC463,
	0x6519: 0xC465,
	0x651A: 0xFFFD,
	0x651B: 0xF5CD,
	0x651C: 0xC4E2,
	0x651D: 0xC4E1,
	0x651E: 0xA060,
	0x651F: 0x9ABE,
	0x6520: 0xF6E1,
	0x6521: 0xF6E0,
	0x6522: 0xF6E3,
	0x6523: 0xC5CB,
	0x6524: 0xC575,
	0x6525: 0xF7DD,
	0x6526: 0xF6E2,
	0x6527: 0xFFFD,
	0x6528: 0xFFFD,
	0x6529: 0xF7DC,
	0x652A: 0xC5CD,
	0x652B: 0xC5CC,
	0x652C: 0xC5F3,
	0x652D: 0xF8A9,
	0x652E: 0xF8EF,
	0x652F: 0xA4E4,
	0x6530: 0xFE5B,
	0x6531: 0xFFFD,
	0x6532: 0xD972,
	0x6533: 0xE9AF,
	0x6534: 0xC6D2,
	0x6535: 0x90C8,
	0x6536: 0xA6AC,
	0x6537: 0xCAF7,
	0x6538: 0xA7F1,
	0x6539: 0xA7EF,
	0x653A: 0xFFFD,
	0x653B: 0xA7F0,
	0x653C: 0xFFFD,
	0x653D: 0xCCC1,
	0x653E: 0xA9F1,
	0x653F: 0xAC46,
	0x6540: 0xFFFD,
	0x6541: 0xCEE7,
	0x6542: 0xFFFD,
	0x6543: 0xCEE8,
	0x6544: 0xFFFD,
	0x6545: 0xAC47,
	0x6546: 0xD1CE,
	0x6547: 0xFFFD,
	0x6548: 0xAEC4,
	0x6549: 0xAEC5,
	0x654A: 0xD1CD,
	0x654B: 0xFFFD,
	0x654C: 0x87DA,
	0x654D: 0x95B4,
	0x654E: 0x90C9,
	0x654F: 0xB1D3,
	0x6550: 0xFFFD,
	0x6551: 0xB1CF,
	0x6552: 0xFFFD,
	0x6553: 0xD5A7,
	0x6554: 0xB1D6,
	0x6555: 0xB1D5,
	0x6556: 0xB1CE,
	0x6557: 0xB1D1,
	0x6558: 0xB1D4,
	0x6559: 0xB1D0,
	0x655A: 0xFFFD,
	0x655B: 0x89E0,
	0x655C: 0xD976,
	0x655D: 0xB1CD,
	0x655E: 0xB4AF,
	0x655F: 0x9ABF,
	0x6560: 0xFFFD,
	0x6561: 0xFFFD,
	0x6562: 0xB4B1,
	0x6563: 0xB4B2,
	0x6564: 0xD975,
	0x6565: 0xD978,
	0x6566: 0xB4B0,
	0x6567: 0xD973,
	0x6568: 0xD977,
	0x6569: 0xFFFD,
	0x656A: 0xD974,
	0x656B: 0x90CA,
	0x656C: 0xB771,
	0x656D: 0x9AC0,
	0x656E: 0xFFFD,
	0x656F: 0xDDBC,
	0x6570: 0x87DB,
	0x6571: 0xFFFD,
	0x6572: 0xBA56,
	0x6573: 0xE1F4,
	0x6574: 0xBEE3,
	0x6575: 0xBCC4,
	0x6576: 0xE5BD,
	0x6577: 0xBCC5,
	0x6578: 0xBCC6,
	0x6579: 0xE5BF,
	0x657A: 0xE5BE,
	0x657B: 0xE5C0,
	0x657C: 0xE9B1,
	0x657D: 0xFFFD,
	0x657E: 0xFFFD,
	0x657F: 0xE9B0,
	0x6580: 0xECEF,
	0x6581: 0xECEE,
	0x6582: 0xC0C4,
	0x6583: 0xC0C5,
	0x6584: 0xF248,
	0x6585: 0xFCB7,
	0x6586: 0x9AC1,
	0x6587: 0xA4E5,
	0x6588: 0x90CB,
	0x6589: 0x9342,
	0x658A: 0xFFFD,
	0x658B: 0x8ABC,
	0x658C: 0xD979,
	0x658D: 0xFFFD,
	0x658E: 0x92C7,
	0x658F: 0xFFFD,
	0x6590: 0xB4B4,
	0x6591: 0xB4B3,
	0x6592: 0xDDBD,
	0x6593: 0x8C75,
	0x6594: 0xEFD8,
	0x6595: 0xC4E3,
	0x6596: 0xF7DE,
	0x6597: 0xA4E6,
	0x6598: 0xFFFD,
	0x6599: 0xAEC6,
	0x659A: 0xFFFD,
	0x659B: 0xB1D8,
	0x659C: 0xB1D7,
	0x659D: 0xD97A,
	0x659E: 0xD97B,
	0x659F: 0xB772,
	0x65A0: 0xE1F5,
	0x65A1: 0xBA57,
	0x65A2: 0xE9B2,
	0x65A3: 0xFFFD,
	0x65A4: 0xA4E7,
	0x65A5: 0xA5B8,
	0x65A6: 0xFFFD,
	0x65A7: 0xA9F2,
	0x65A8: 0xCCC2,
	0x65A9: 0x8453,
	0x65AA: 0xCEE9,
	0x65AB: 0xAC48,
	0x65AC: 0xB1D9,
	0x65AD: 0x8ACA,
	0x65AE: 0xD97C,
	0x65AF: 0xB4B5,
	0x65B0: 0xB773,
	0x65B1: 0xFFFD,
	0x65B2: 0xE5C1,
	0x65B3: 0xE5C2,
	0x65B4: 0xFFFD,
	0x65B5: 0x9AC2,
	0x65B6: 0xECF0,
	0x65B7: 0xC25F,
	0x65B8: 0xF8F0,
	0x65B9: 0xA4E8,
	0x65BA: 0xFFFD,
	0x65BB: 0xCCC3,
	0x65BC: 0xA9F3,
	0x65BD: 0xAC49,
	0x65BE: 0x9AC3,
	0x65BF: 0xCEEA,
	0x65C0: 0xFFFD,
	0x65C1: 0xAEC7,
	0x65C2: 0xD1D2,
	0x65C3: 0xD1D0,
	0x65C4: 0xD1D1,
	0x65C5: 0xAEC8,
	0x65C6: 0xD1CF,
	0x65C7: 0xFFFD,
	0x65C8: 0xFFFD,
	0x65C9: 0xFFFD,
	0x65CA: 0xFFFD,
	0x65CB: 0xB1DB,
	0x65CC: 0xB1DC,
	0x65CD: 0xD5A8,
	0x65CE: 0xB1DD,
	0x65CF: 0xB1DA,
	0x65D0: 0xD97D,
	0x65D1: 0x9AC4,
	0x65D2: 0xD97E,
	0x65D3: 0xDDBE,
	0x65D4: 0x9AC5,
	0x65D5: 0xFFFD,
	0x65D6: 0xBA59,
	0x65D7: 0xBA58,
	0x65D8: 0xFFFD,
	0x65D9: 0x90CC,
	0x65DA: 0xECF1,
	0x65DB: 0xEFD9,
	0x65DC: 0xFFFD,
	0x65DD: 0xF24A,
	0x65DE: 0xF249,
	0x65DF: 0xF44F,
	0x65E0: 0xC6D3,
	0x65E1: 0xC95E,
	0x65E2: 0xAC4A,
	0x65E3: 0x9AC6,
	0x65E4: 0xFFFD,
	0x65E5: 0xA4E9,
	0x65E6: 0xA5B9,
	0x65E7: 0x8AF6,
	0x65E8: 0xA6AE,
	0x65E9: 0xA6AD,
	0x65EA: 0xFFFD,
	0x65EB: 0xFFFD,
	0x65EC: 0xA6AF,
	0x65ED: 0xA6B0,
	0x65EE: 0xC9EE,
	0x65EF: 0xC9ED,
	0x65F0: 0xCAF8,
	0x65F1: 0xA7F2,
	0x65F2: 0xCAFB,
	0x65F3: 0xCAFA,
	0x65F4: 0xCAF9,
	0x65F5: 0xCAFC,
	0x65F6: 0x83BA,
	0x65F7: 0x8B77,
	0x65F8: 0x85D0,
	0x65F9: 0xFFFD,
	0x65FA: 0xA9F4,
	0x65FB: 0xCCC9,
	0x65FC: 0xCCC5,
	0x65FD: 0xCCCE,
	0x65FE: 0xFFFD,
	0x65FF: 0x9AC7,
	0x6600: 0xA9FB,
	0x6601: 0xFFFD,
	0x6602: 0xA9F9,
	0x6603: 0xCCCA,
	0x6604: 0xCCC6,
	0x6605: 0xCCCD,
	0x6606: 0xA9F8,
	0x6607: 0xAA40,
	0x6608: 0xCCC8,
	0x6609: 0xCCC4,
	0x660A: 0xA9FE,
	0x660B: 0xCCCB,
	0x660C: 0xA9F7,
	0x660D: 0xCCCC,
	0x660E: 0xA9FA,
	0x660F: 0xA9FC,
	0x6610: 0xCCD0,
	0x6611: 0xCCCF,
	0x6612: 0xCCC7,
	0x6613: 0xA9F6,
	0x6614: 0xA9F5,
	0x6615: 0xA9FD,
	0x6616: 0xFFFD,
	0x6617: 0xFFFD,
	0x6618: 0x9AC8,
	0x6619: 0x88E8,
	0x661A: 0xFFFD,
	0x661B: 0xFFFD,
	0x661C: 0xCEEF,
	0x661D: 0xCEF5,
	0x661E: 0x90CD,
	0x661F: 0xAC50,
	0x6620: 0xAC4D,
	0x6621: 0xCEEC,
	0x6622: 0xCEF1,
	0x6623: 0x9AC9,
	0x6624: 0xAC53,
	0x6625: 0xAC4B,
	0x6626: 0xCEF0,
	0x6627: 0xAC4E,
	0x6628: 0xAC51,
	0x6629: 0xFFFD,
	0x662A: 0xFFFD,
	0x662B: 0xCEF3,
	0x662C: 0xFFFD,
	0x662D: 0xAC4C,
	0x662E: 0xCEF8,
	0x662F: 0xAC4F,
	0x6630: 0x95FE,
	0x6631: 0xAC52,
	0x6632: 0xCEED,
	0x6633: 0xCEF2,
	0x6634: 0xCEF6,
	0x6635: 0xCEEE,
	0x6636: 0xCEEB,
	0x6637: 0xFFFD,
	0x6638: 0xFFFD,
	0x6639: 0xCEF7,
	0x663A: 0xCEF4,
	0x663B: 0x90CE,
	0x663C: 0x8454,
	0x663D: 0xFFFD,
	0x663E: 0x8D46,
	0x663F: 0x90CF,
	0x6640: 0xFFFD,
	0x6641: 0xAED0,
	0x6642: 0xAEC9,
	0x6643: 0xAECC,
	0x6644: 0x90D0,
	0x6645: 0xAECF,
	0x6646: 0xFFFD,
	0x6647: 0xD1D5,
	0x6648: 0xFC62,
	0x6649: 0xAECA,
	0x664A: 0xD1D3,
	0x664B: 0x83BB,
	0x664C: 0xAECE,
	0x664D: 0x9D59,
	0x664E: 0xFFFD,
	0x664F: 0xAECB,
	0x6650: 0xFFFD,
	0x6651: 0xD1D6,
	0x6652: 0xAECD,
	0x6653: 0x88E6,
	0x6654: 0x88E7,
	0x6655: 0x85CF,
	0x6656: 0x85CE,
	0x6657: 0x90D1,
	0x6658: 0xFFFD,
	0x6659: 0xD5AC,
	0x665A: 0xB1DF,
	0x665B: 0xD5AB,
	0x665C: 0xD5AD,
	0x665D: 0xB1DE,
	0x665E: 0xB1E3,
	0x665F: 0xD1D4,
	0x6660: 0xFFFD,
	0x6661: 0xD5AA,
	0x6662: 0xD5AE,
	0x6663: 0x9ACA,
	0x6664: 0xB1E0,
	0x6665: 0xD5A9,
	0x6666: 0xB1E2,
	0x6667: 0xFC63,
	0x6668: 0xB1E1,
	0x6669: 0x90D2,
	0x666A: 0xD9A7,
	0x666B: 0x9ACB,
	0x666C: 0xD9A2,
	0x666D: 0xFFFD,
	0x666E: 0xB4B6,
	0x666F: 0xB4BA,
	0x6670: 0xB4B7,
	0x6671: 0xD9A5,
	0x6672: 0xD9A8,
	0x6673: 0x90D3,
	0x6674: 0xB4B8,
	0x6675: 0xFFFD,
	0x6676: 0xB4B9,
	0x6677: 0xB4BE,
	0x6678: 0xDDC7,
	0x6679: 0xD9A6,
	0x667A: 0xB4BC,
	0x667B: 0xD9A3,
	0x667C: 0xD9A1,
	0x667D: 0x9ACC,
	0x667E: 0xB4BD,
	0x667F: 0xFFFD,
	0x6680: 0xD9A4,
	0x6681: 0x927D,
	0x6682: 0x87DC,
	0x6683: 0x90D4,
	0x6684: 0xB779,
	0x6685: 0x9ACD,
	0x6686: 0xDDBF,
	0x6687: 0xB776,
	0x6688: 0xB777,
	0x6689: 0xB775,
	0x668A: 0xDDC4,
	0x668B: 0xDDC3,
	0x668C: 0xDDC0,
	0x668D: 0xB77B,
	0x668E: 0xFE7A,
	0x668F: 0xFFFD,
	0x6690: 0xDDC2,
	0x6691: 0xB4BB,
	0x6692: 0x9ACE,
	0x6693: 0xFFFD,
	0x6694: 0xDDC6,
	0x6695: 0xDDC1,
	0x6696: 0xB778,
	0x6697: 0xB774,
	0x6698: 0xB77A,
	0x6699: 0xDDC5,
	0x669A: 0x9ACF,
	0x669B: 0xFFFD,
	0x669C: 0xFFFD,
	0x669D: 0xBA5C,
	0x669E: 0xFFFD,
	0x669F: 0xE1F8,
	0x66A0: 0xE1F7,
	0x66A1: 0xE1F6,
	0x66A2: 0xBA5A,
	0x66A3: 0xFFFD,
	0x66A4: 0x9AD0,
	0x66A5: 0xFFFD,
	0x66A6: 0x93EF,
	0x66A7: 0x89E2,
	0x66A8: 0xBA5B,
	0x66A9: 0xE5C5,
	0x66AA: 0xE5C8,
	0x66AB: 0xBCC8,
	0x66AC: 0xFFFD,
	0x66AD: 0x9AD1,
	0x66AE: 0xBCC7,
	0x66AF: 0xE5C9,
	0x66B0: 0xE5C4,
	0x66B1: 0xBCCA,
	0x66B2: 0xE5C6,
	0x66B3: 0x9AD2,
	0x66B4: 0xBCC9,
	0x66B5: 0xE5C3,
	0x66B6: 0x9AD3,
	0x66B7: 0xE5C7,
	0x66B8: 0xBEE9,
	0x66B9: 0xBEE6,
	0x66BA: 0xE9BB,
	0x66BB: 0xE9BA,
	0x66BC: 0x90D5,
	0x66BD: 0xE9B9,
	0x66BE: 0xE9B4,
	0x66BF: 0x90D6,
	0x66C0: 0xE9B5,
	0x66C1: 0x90D7,
	0x66C2: 0xFFFD,
	0x66C3: 0xFFFD,
	0x66C4: 0xBEE7,
	0x66C5: 0xFFFD,
	0x66C6: 0xBEE4,
	0x66C7: 0xBEE8,
	0x66C8: 0xE9B3,
	0x66C9: 0xBEE5,
	0x66CA: 0xE9B6,
	0x66CB: 0xE9B7,
	0x66CC: 0xE9BC,
	0x66CD: 0x9AD4,
	0x66CE: 0x9AD5,
	0x66CF: 0xE9B8,
	0x66D0: 0xFFFD,
	0x66D1: 0xFFFD,
	0x66D2: 0xECF2,
	0x66D3: 0xFFFD,
	0x66D4: 0xFFFD,
	0x66D5: 0xFFFD,
	0x66D6: 0xC0C7,
	0x66D7: 0xFFFD,
	0x66D8: 0xEFDC,
	0x66D9: 0xC0C6,
	0x66DA: 0xEFDA,
	0x66DB: 0xEFDB,
	0x66DC: 0xC260,
	0x66DD: 0xC36E,
	0x66DE: 0xF24B,
	0x66DF: 0xFFFD,
	0x66E0: 0xC36D,
	0x66E1: 0xFFFD,
	0x66E2: 0xFFFD,
	0x66E3: 0xF451,
	0x66E4: 0xF452,
	0x66E5: 0xFFFD,
	0x66E6: 0xC466,
	0x66E7: 0x9DCA,
	0x66E8: 0xF450,
	0x66E9: 0xC4E4,
	0x66EA: 0xFFFD,
	0x66EB: 0xF7DF,
	0x66EC: 0xC5CE,
	0x66ED: 0xF8AA,
	0x66EE: 0xF8AB,
	0x66EF: 0xFFFD,
	0x66F0: 0xA4EA,
	0x66F1: 0xA058,
	0x66F2: 0xA6B1,
	0x66F3: 0xA6B2,
	0x66F4: 0xA7F3,
	0x66F5: 0x90D8,
	0x66F6: 0xCCD1,
	0x66F7: 0xAC54,
	0x66F8: 0xAED1,
	0x66F9: 0xB1E4,
	0x66FA: 0x90D9,
	0x66FB: 0x90DA,
	0x66FC: 0xB0D2,
	0x66FD: 0x93FB,
	0x66FE: 0xB4BF,
	0x66FF: 0xB4C0,
	0x6700: 0xB3CC,
	0x6701: 0xD9A9,
	0x6702: 0x9AD6,
	0x6703: 0xB77C,
	0x6704: 0xE1FA,
	0x6705: 0xE1F9,
	0x6706: 0xFFFD,
	0x6707: 0xFFFD,
	0x6708: 0xA4EB,
	0x6709: 0xA6B3,
	0x670A: 0xCCD2,
	0x670B: 0xAA42,
	0x670C: 0x9AD7,
	0x670D: 0xAA41,
	0x670E: 0x90DB,
	0x670F: 0xCEF9,
	0x6710: 0xCEFA,
	0x6711: 0xFFFD,
	0x6712: 0xD1D7,
	0x6713: 0xD1D8,
	0x6714: 0xAED2,
	0x6715: 0xAED3,
	0x6716: 0x90DC,
	0x6717: 0xAED4,
	0x6718: 0xD5AF,
	0x6719: 0x9AD8,
	0x671A: 0xFFFD,
	0x671B: 0xB1E6,
	0x671C: 0xFFFD,
	0x671D: 0xB4C2,
	0x671E: 0xFC64,
	0x671F: 0xB4C1,
	0x6720: 0xDDC8,
	0x6721: 0xDF7A,
	0x6722: 0xE1FB,
	0x6723: 0xE9BD,
	0x6724: 0xFFFD,
	0x6725: 0xFE5E,
	0x6726: 0xC261,
	0x6727: 0xC467,
	0x6728: 0xA4EC,
	0x6729: 0x91D1,
	0x672A: 0xA5BC,
	0x672B: 0xA5BD,
	0x672C: 0xA5BB,
	0x672D: 0xA5BE,
	0x672E: 0xA5BA,
	0x672F: 0x847B,
	0x6730: 0xFFFD,
	0x6731: 0xA6B6,
	0x6732: 0xFFFD,
	0x6733: 0xC9F6,
	0x6734: 0xA6B5,
	0x6735: 0xA6B7,
	0x6736: 0x957C,
	0x6737: 0x90DD,
	0x6738: 0xC9F1,
	0x6739: 0xC9F0,
	0x673A: 0xC9F3,
	0x673B: 0xC9F2,
	0x673C: 0xC9F5,
	0x673D: 0xA6B4,
	0x673E: 0xC9EF,
	0x673F: 0xC9F4,
	0x6740: 0x8459,
	0x6741: 0x9478,
	0x6742: 0x8B59,
	0x6743: 0x8CD0,
	0x6744: 0x9AD9,
	0x6745: 0xCAFD,
	0x6746: 0xA7FD,
	0x6747: 0xCAFE,
	0x6748: 0xCB43,
	0x6749: 0xA7FC,
	0x674A: 0xFFFD,
	0x674B: 0xCB47,
	0x674C: 0xCB42,
	0x674D: 0xCB45,
	0x674E: 0xA7F5,
	0x674F: 0xA7F6,
	0x6750: 0xA7F7,
	0x6751: 0xA7F8,
	0x6752: 0xFFFD,
	0x6753: 0xA840,
	0x6754: 0xFFFD,
	0x6755: 0xCB41,
	0x6756: 0xA7FA,
	0x6757: 0xA841,
	0x6758: 0xFFFD,
	0x6759: 0xCB40,
	0x675A: 0xCB46,
	0x675B: 0xFFFD,
	0x675C: 0xA7F9,
	0x675D: 0xCB44,
	0x675E: 0xA7FB,
	0x675F: 0xA7F4,
	0x6760: 0xA7FE,
	0x6761: 0x8457,
	0x6762: 0x945C,
	0x6763: 0x9479,
	0x6764: 0x90DE,
	0x6765: 0x8353,
	0x6766: 0x90DF,
	0x6767: 0xFBA6,
	0x6768: 0x85D4,
	0x6769: 0x8E72,
	0x676A: 0xAA57,
	0x676B: 0x9ADA,
	0x676C: 0xCCD4,
	0x676D: 0xAA43,
	0x676E: 0x9D72,
	0x676F: 0xAA4D,
	0x6770: 0xAA4E,
	0x6771: 0xAA46,
	0x6772: 0xAA58,
	0x6773: 0xAA48,
	0x6774: 0xCCDC,
	0x6775: 0xAA53,
	0x6776: 0xCCD7,
	0x6777: 0xAA49,
	0x6778: 0xCCE6,
	0x6779: 0xCCE7,
	0x677A: 0xCCDF,
	0x677B: 0xCCD8,
	0x677C: 0xAA56,
	0x677D: 0xCCE4,
	0x677E: 0xAA51,
	0x677F: 0xAA4F,
	0x6780: 0xFFFD,
	0x6781: 0xCCE5,
	0x6782: 0xFFFD,
	0x6783: 0xCCE3,
	0x6784: 0xCCDB,
	0x6785: 0xCCD3,
	0x6786: 0xCCDA,
	0x6787: 0xAA4A,
	0x6788: 0xFFFD,
	0x6789: 0xAA50,
	0x678A: 0xFFFD,
	0x678B: 0xAA44,
	0x678C: 0xCCDE,
	0x678D: 0xCCDD,
	0x678E: 0xCCD5,
	0x678F: 0x9ADB,
	0x6790: 0xAA52,
	0x6791: 0xCCE1,
	0x6792: 0xCCD6,
	0x6793: 0xAA55,
	0x6794: 0xCCE8,
	0x6795: 0xAA45,
	0x6796: 0xFFFD,
	0x6797: 0xAA4C,
	0x6798: 0xCCD9,
	0x6799: 0xCCE2,
	0x679A: 0xAA54,
	0x679B: 0xFFFD,
	0x679C: 0xAA47,
	0x679D: 0xAA4B,
	0x679E: 0x87E5,
	0x679F: 0xCCE0,
	0x67A0: 0x94FD,
	0x67A1: 0x947A,
	0x67A2: 0x87E0,
	0x67A3: 0x84E5,
	0x67A4: 0x9ADC,
	0x67A5: 0x8FDC,
	0x67A6: 0x90E0,
	0x67A7: 0x90E1,
	0x67A8: 0x8DDF,
	0x67A9: 0x90E2,
	0x67AA: 0x86D2,
	0x67AB: 0x85D6,
	0x67AC: 0xFC66,
	0x67AD: 0x8458,
	0x67AE: 0xCF5B,
	0x67AF: 0xAC5C,
	0x67B0: 0xAC69,
	0x67B1: 0x9545,
	0x67B2: 0xCF56,
	0x67B3: 0xCF4C,
	0x67B4: 0xAC62,
	0x67B5: 0xCF4A,
	0x67B6: 0xAC5B,
	0x67B7: 0xCF45,
	0x67B8: 0xAC65,
	0x67B9: 0xCF52,
	0x67BA: 0xCEFE,
	0x67BB: 0xCF41,
	0x67BC: 0xFFFD,
	0x67BD: 0xFFFD,
	0x67BE: 0xFFFD,
	0x67BF: 0x9ADD,
	0x67C0: 0xCF44,
	0x67C1: 0xCEFB,
	0x67C2: 0xCF51,
	0x67C3: 0xCF61,
	0x67C4: 0xAC60,
	0x67C5: 0xCF46,
	0x67C6: 0xCF58,
	0x67C7: 0xFFFD,
	0x67C8: 0xCEFD,
	0x67C9: 0xCF5F,
	0x67CA: 0xCF60,
	0x67CB: 0xCF63,
	0x67CC: 0xCF5A,
	0x67CD: 0xCF4B,
	0x67CE: 0xCF53,
	0x67CF: 0xAC66,
	0x67D0: 0xAC59,
	0x67D1: 0xAC61,
	0x67D2: 0xAC6D,
	0x67D3: 0xAC56,
	0x67D4: 0xAC58,
	0x67D5: 0xFFFD,
	0x67D6: 0x9ADE,
	0x67D7: 0x9ADF,
	0x67D8: 0xCF43,
	0x67D9: 0xAC6A,
	0x67DA: 0xAC63,
	0x67DB: 0xCF5D,
	0x67DC: 0xCF40,
	0x67DD: 0xAC6C,
	0x67DE: 0xAC67,
	0x67DF: 0xCF49,
	0x67E0: 0x8ACE,
	0x67E1: 0xFFFD,
	0x67E2: 0xAC6B,
	0x67E3: 0xCF50,
	0x67E4: 0xCF48,
	0x67E5: 0xAC64,
	0x67E6: 0xCF5C,
	0x67E7: 0xCF54,
	0x67E8: 0xFFFD,
	0x67E9: 0xAC5E,
	0x67EA: 0xCF62,
	0x67EB: 0xCF47,
	0x67EC: 0xAC5A,
	0x67ED: 0xCF59,
	0x67EE: 0xCF4F,
	0x67EF: 0xAC5F,
	0x67F0: 0xCF55,
	0x67F1: 0xAC57,
	0x67F2: 0xCEFC,
	0x67F3: 0xAC68,
	0x67F4: 0xAEE3,
	0x67F5: 0xAC5D,
	0x67F6: 0xCF4E,
	0x67F7: 0xCF4D,
	0x67F8: 0xCF42,
	0x67F9: 0xFC67,
	0x67FA: 0xCF5E,
	0x67FB: 0x90E3,
	0x67FC: 0xCF57,
	0x67FD: 0x90E4,
	0x67FE: 0x945A,
	0x67FF: 0xAC55,
	0x6800: 0x90E5,
	0x6801: 0x90E6,
	0x6802: 0x944D,
	0x6803: 0x9451,
	0x6804: 0x9248,
	0x6805: 0x90E7,
	0x6806: 0xFFFD,
	0x6807: 0x87E1,
	0x6808: 0x84E7,
	0x6809: 0x89E6,
	0x680A: 0x8FDB,
	0x680B: 0x84E6,
	0x680C: 0x8FDD,
	0x680D: 0x9AE1,
	0x680E: 0x8FBA,
	0x680F: 0x8C77,
	0x6810: 0x9AE2,
	0x6811: 0x88EB,
	0x6812: 0xD1EC,
	0x6813: 0xAEEA,
	0x6814: 0xD1ED,
	0x6815: 0xFFFD,
	0x6816: 0xD1E1,
	0x6817: 0xAEDF,
	0x6818: 0xAEEB,
	0x6819: 0xFFFD,
	0x681A: 0xD1DA,
	0x681B: 0x9AE3,
	0x681C: 0xD1E3,
	0x681D: 0xD1EB,
	0x681E: 0x90E8,
	0x681F: 0xD1D9,
	0x6820: 0xD1F4,
	0x6821: 0xAED5,
	0x6822: 0xFE45,
	0x6823: 0xFFFD,
	0x6824: 0xFFFD,
	0x6825: 0xD1F3,
	0x6826: 0xD1EE,
	0x6827: 0xFFFD,
	0x6828: 0xD1EF,
	0x6829: 0xAEDD,
	0x682A: 0xAEE8,
	0x682B: 0xD1E5,
	0x682C: 0xFFFD,
	0x682D: 0xD1E6,
	0x682E: 0xD1F0,
	0x682F: 0xD1E7,
	0x6830: 0xFFFD,
	0x6831: 0xD1E2,
	0x6832: 0xD1DC,
	0x6833: 0xD1DD,
	0x6834: 0xD1EA,
	0x6835: 0xD1E4,
	0x6836: 0x9AE4,
	0x6837: 0x87DE,
	0x6838: 0xAED6,
	0x6839: 0xAEDA,
	0x683A: 0xD1F2,
	0x683B: 0xD1DE,
	0x683C: 0xAEE6,
	0x683D: 0xAEE2,
	0x683E: 0x906A,
	0x683F: 0xFFFD,
	0x6840: 0xAEE5,
	0x6841: 0xAEEC,
	0x6842: 0xAEDB,
	0x6843: 0xAEE7,
	0x6844: 0xD1E9,
	0x6845: 0xAEE9,
	0x6846: 0xAED8,
	0x6847: 0x9AE5,
	0x6848: 0xAED7,
	0x6849: 0xD1DB,
	0x684A: 0x90E9,
	0x684B: 0xD1DF,
	0x684C: 0xAEE0,
	0x684D: 0xD1F1,
	0x684E: 0xD1E8,
	0x684F: 0xD1E0,
	0x6850: 0xAEE4,
	0x6851: 0xAEE1,
	0x6852: 0x90EA,
	0x6853: 0xAED9,
	0x6854: 0xAEDC,
	0x6855: 0x90EB,
	0x6856: 0x9AE6,
	0x6857: 0xFFFD,
	0x6858: 0xFFFD,
	0x6859: 0x90EC,
	0x685A: 0xFFFD,
	0x685B: 0xFFFD,
	0x685C: 0x9251,
	0x685D: 0x827C,
	0x685E: 0xFFFD,
	0x685F: 0x92CC,
	0x6860: 0x8DDE,
	0x6861: 0x88EF,
	0x6862: 0x85D5,
	0x6863: 0x89E3,
	0x6864: 0x8E71,
	0x6865: 0x88ED,
	0x6866: 0x88E9,
	0x6867: 0x89E5,
	0x6868: 0x87E3,
	0x6869: 0x87DF,
	0x686A: 0xFFFD,
	0x686B: 0xD5C4,
	0x686C: 0xFFFD,
	0x686D: 0xD5B4,
	0x686E: 0xD5B5,
	0x686F: 0xD5B9,
	0x6870: 0xFFFD,
	0x6871: 0xD5C8,
	0x6872: 0xD5C5,
	0x6873: 0xFFFD,
	0x6874: 0xD5BE,
	0x6875: 0xD5BD,
	0x6876: 0xB1ED,
	0x6877: 0xD5C1,
	0x6878: 0xD5D0,
	0x6879: 0xD5B0,
	0x687A: 0xFFFD,
	0x687B: 0xD5D1,
	0x687C: 0xD5C3,
	0x687D: 0xD5D5,
	0x687E: 0xD5C9,
	0x687F: 0xB1EC,
	0x6880: 0xD5C7,
	0x6881: 0xB1E7,
	0x6882: 0xB1FC,
	0x6883: 0xB1F2,
	0x6884: 0x9AE7,
	0x6885: 0xB1F6,
	0x6886: 0xB1F5,
	0x6887: 0xD5B1,
	0x6888: 0x9AE8,
	0x6889: 0xD5CE,
	0x688A: 0xD5D4,
	0x688B: 0xD5CC,
	0x688C: 0xD5D3,
	0x688D: 0x90ED,
	0x688E: 0xFFFD,
	0x688F: 0xD5C0,
	0x6890: 0xD5B2,
	0x6891: 0xD5D2,
	0x6892: 0xD5C2,
	0x6893: 0xB1EA,
	0x6894: 0xB1F7,
	0x6895: 0xFFFD,
	0x6896: 0xD5CB,
	0x6897: 0xB1F0,
	0x6898: 0xFB58,
	0x6899: 0xFFFD,
	0x689A: 0xFFFD,
	0x689B: 0xD5CA,
	0x689C: 0xD5B3,
	0x689D: 0xB1F8,
	0x689E: 0xFFFD,
	0x689F: 0xB1FA,
	0x68A0: 0xD5CD,
	0x68A1: 0xB1FB,
	0x68A2: 0xB1E9,
	0x68A3: 0xD5BA,
	0x68A4: 0xD5CF,
	0x68A5: 0xFFFD,
	0x68A6: 0x86BB,
	0x68A7: 0xB1EF,
	0x68A8: 0xB1F9,
	0x68A9: 0xD5BC,
	0x68AA: 0xD5C6,
	0x68AB: 0xD5B7,
	0x68AC: 0xD5BB,
	0x68AD: 0xB1F4,
	0x68AE: 0xD5B6,
	0x68AF: 0xB1E8,
	0x68B0: 0xB1F1,
	0x68B1: 0xB1EE,
	0x68B2: 0xD5BF,
	0x68B3: 0xAEDE,
	0x68B4: 0xD9C0,
	0x68B5: 0xB1EB,
	0x68B6: 0xFC68,
	0x68B7: 0xFFFD,
	0x68B8: 0xFFFD,
	0x68B9: 0x90EE,
	0x68BA: 0x947B,
	0x68BB: 0xFFFD,
	0x68BC: 0x826F,
	0x68BD: 0x9AE9,
	0x68BE: 0xFFFD,
	0x68BF: 0xFFFD,
	0x68C0: 0x89E4,
	0x68C1: 0xFFFD,
	0x68C2: 0x8C78,
	0x68C3: 0x9AEA,
	0x68C4: 0xB1F3,
	0x68C5: 0x9AEB,
	0x68C6: 0xD9C3,
	0x68C7: 0xD9D9,
	0x68C8: 0xD9CE,
	0x68C9: 0xB4D6,
	0x68CA: 0xFC6C,
	0x68CB: 0xB4D1,
	0x68CC: 0xD9BD,
	0x68CD: 0xB4D2,
	0x68CE: 0xD9CD,
	0x68CF: 0x90EF,
	0x68D0: 0xD9C6,
	0x68D1: 0xD9D3,
	0x68D2: 0xB4CE,
	0x68D3: 0xD9AB,
	0x68D4: 0xD9D5,
	0x68D5: 0xB4C4,
	0x68D6: 0xD9B3,
	0x68D7: 0xB4C7,
	0x68D8: 0xB4C6,
	0x68D9: 0xFFFD,
	0x68DA: 0xB4D7,
	0x68DB: 0xFFFD,
	0x68DC: 0xD9AD,
	0x68DD: 0xD9CF,
	0x68DE: 0xD9D0,
	0x68DF: 0xB4C9,
	0x68E0: 0xB4C5,
	0x68E1: 0xD9BB,
	0x68E2: 0xFFFD,
	0x68E3: 0xB4D0,
	0x68E4: 0xD9B6,
	0x68E5: 0xFFFD,
	0x68E6: 0xD9D1,
	0x68E7: 0xB4CC,
	0x68E8: 0xD9C9,
	0x68E9: 0xD9D6,
	0x68EA: 0xD9B0,
	0x68EB: 0xD9B5,
	0x68EC: 0xD9AF,
	0x68ED: 0xFFFD,
	0x68EE: 0xB4CB,
	0x68EF: 0xD9C2,
	0x68F0: 0xDDDE,
	0x68F1: 0xD9B1,
	0x68F2: 0xB4CF,
	0x68F3: 0xD9BA,
	0x68F4: 0xD9D2,
	0x68F5: 0xB4CA,
	0x68F6: 0xD9B7,
	0x68F7: 0xD9B4,
	0x68F8: 0xD9C5,
	0x68F9: 0xB4CD,
	0x68FA: 0xB4C3,
	0x68FB: 0xB4D9,
	0x68FC: 0xD9C8,
	0x68FD: 0xD9C7,
	0x68FE: 0xFFFD,
	0x68FF: 0xFFFD,
	0x6900: 0xFC6B,
	0x6901: 0xFC6A,
	0x6902: 0x9AEC,
	0x6903: 0x9AED,
	0x6904: 0xD9AC,
	0x6905: 0xB4C8,
	0x6906: 0xD9D4,
	0x6907: 0xD9BC,
	0x6908: 0xD9BE,
	0x6909: 0x9AEE,
	0x690A: 0xD9CB,
	0x690B: 0xD9CA,
	0x690C: 0xD9AA,
	0x690D: 0xB4D3,
	0x690E: 0xB4D5,
	0x690F: 0xD9B2,
	0x6910: 0xD9B9,
	0x6911: 0xD9C1,
	0x6912: 0xB4D4,
	0x6913: 0xD9B8,
	0x6914: 0xD9C4,
	0x6915: 0xD9D7,
	0x6916: 0xFFFD,
	0x6917: 0xD9CC,
	0x6918: 0x9AEF,
	0x6919: 0x9449,
	0x691A: 0xFE4F,
	0x691B: 0x9441,
	0x691C: 0x92B6,
	0x691D: 0xFFFD,
	0x691E: 0xFFFD,
	0x691F: 0x8B79,
	0x6920: 0x8EB8,
	0x6921: 0x94A2,
	0x6922: 0x90F3,
	0x6923: 0x94A1,
	0x6924: 0x906B,
	0x6925: 0xD9D8,
	0x6926: 0x90F4,
	0x6927: 0xFFFD,
	0x6928: 0x947D,
	0x6929: 0xFFFD,
	0x692A: 0xD9AE,
	0x692B: 0xFFFD,
	0x692C: 0xFC69,
	0x692D: 0x88EC,
	0x692E: 0xFFFD,
	0x692F: 0xDDF2,
	0x6930: 0xB7A6,
	0x6931: 0xFFFD,
	0x6932: 0xDDF0,
	0x6933: 0xDDDB,
	0x6934: 0xDDE0,
	0x6935: 0xDDD9,
	0x6936: 0x90FD,
	0x6937: 0xDDEC,
	0x6938: 0xDDCB,
	0x6939: 0xDDD2,
	0x693A: 0xFFFD,
	0x693B: 0xDDEA,
	0x693C: 0xDDF4,
	0x693D: 0xDDDC,
	0x693E: 0xFC6F,
	0x693F: 0xDDCF,
	0x6940: 0xDDE2,
	0x6941: 0xDDE7,
	0x6942: 0xDDD3,
	0x6943: 0x9AF0,
	0x6944: 0xDDE4,
	0x6945: 0xDDD0,
	0x6946: 0x9AF1,
	0x6947: 0xFFFD,
	0x6948: 0xDDD7,
	0x6949: 0xDDD8,
	0x694A: 0xB7A8,
	0x694B: 0xDDEB,
	0x694C: 0xDDE9,
	0x694D: 0xFFFD,
	0x694E: 0xDDCC,
	0x694F: 0xDDEE,
	0x6950: 0xFFFD,
	0x6951: 0xDDEF,
	0x6952: 0xDDF1,
	0x6953: 0xB7AC,
	0x6954: 0xB7A4,
	0x6955: 0x826C,
	0x6956: 0xD5B8,
	0x6957: 0xDDD4,
	0x6958: 0xDDE6,
	0x6959: 0xDDD5,
	0x695A: 0xB7A1,
	0x695B: 0xB7B1,
	0x695C: 0xDDED,
	0x695D: 0xB7AF,
	0x695E: 0xB7AB,
	0x695F: 0xDDCA,
	0x6960: 0xB7A3,
	0x6961: 0x90FE,
	0x6962: 0xDDCD,
	0x6963: 0xB7B0,
	0x6964: 0x9AF2,
	0x6965: 0xDDDD,
	0x6966: 0xDDC9,
	0x6967: 0x9AF3,
	0x6968: 0xB7A9,
	0x6969: 0xDDE1,
	0x696A: 0xDDD1,
	0x696B: 0xB7AA,
	0x696C: 0xDDDA,
	0x696D: 0xB77E,
	0x696E: 0xB4D8,
	0x696F: 0xDDE3,
	0x6970: 0xD9BF,
	0x6971: 0xDDCE,
	0x6972: 0x9AF4,
	0x6973: 0xFC6D,
	0x6974: 0xDDE8,
	0x6975: 0xB7A5,
	0x6976: 0xDDE5,
	0x6977: 0xB7A2,
	0x6978: 0xDDDF,
	0x6979: 0xB7AD,
	0x697A: 0xDDD6,
	0x697B: 0xDDF3,
	0x697C: 0x87E2,
	0x697D: 0x9262,
	0x697E: 0x94A3,
	0x697F: 0xFFFD,
	0x6980: 0xFC6E,
	0x6981: 0x94A4,
	0x6982: 0xB7A7,
	0x6983: 0xDEC6,
	0x6984: 0x8D6E,
	0x6985: 0x9AF5,
	0x6986: 0xB7AE,
	0x6987: 0x8BF9,
	0x6988: 0x8B7A,
	0x6989: 0x9040,
	0x698A: 0x9445,
	0x698B: 0xFFFD,
	0x698C: 0xFFFD,
	0x698D: 0xE24A,
	0x698E: 0xE248,
	0x698F: 0xFFFD,
	0x6990: 0xE25E,
	0x6991: 0xE246,
	0x6992: 0xFFFD,
	0x6993: 0xE258,
	0x6994: 0xB77D,
	0x6995: 0xBA5F,
	0x6996: 0xE242,
	0x6997: 0xE25D,
	0x6998: 0x9567,
	0x6999: 0xE247,
	0x699A: 0xE255,
	0x699B: 0xBA64,
	0x699C: 0xBA5D,
	0x699D: 0xFFFD,
	0x699E: 0xE25B,
	0x699F: 0x9AF6,
	0x69A0: 0xE240,
	0x69A1: 0xE25A,
	0x69A2: 0x9AF7,
	0x69A3: 0xBA6F,
	0x69A4: 0xE251,
	0x69A5: 0xE261,
	0x69A6: 0xBA6D,
	0x69A7: 0xE249,
	0x69A8: 0xBA5E,
	0x69A9: 0xE24B,
	0x69AA: 0xE259,
	0x69AB: 0xBA67,
	0x69AC: 0xE244,
	0x69AD: 0xBA6B,
	0x69AE: 0xBA61,
	0x69AF: 0xE24D,
	0x69B0: 0xE243,
	0x69B1: 0xE1FC,
	0x69B2: 0xFC71,
	0x69B3: 0xE257,
	0x69B4: 0xBA68,
	0x69B5: 0xE260,
	0x69B6: 0xE1FD,
	0x69B7: 0xBA65,
	0x69B8: 0xFFFD,
	0x69B9: 0xE253,
	0x69BA: 0xFFFD,
	0x69BB: 0xBA66,
	0x69BC: 0xE245,
	0x69BD: 0xE250,
	0x69BE: 0xE24C,
	0x69BF: 0xE24E,
	0x69C0: 0xFC72,
	0x69C1: 0xBA60,
	0x69C2: 0xE25F,
	0x69C3: 0xBA6E,
	0x69C4: 0xE24F,
	0x69C5: 0xFFFD,
	0x69C6: 0xE262,
	0x69C7: 0x91EE,
	0x69C8: 0xFFFD,
	0x69C9: 0xE1FE,
	0x69CA: 0xE254,
	0x69CB: 0xBA63,
	0x69CC: 0xBA6C,
	0x69CD: 0xBA6A,
	0x69CE: 0xE241,
	0x69CF: 0xE256,
	0x69D0: 0xBA69,
	0x69D1: 0x9AF8,
	0x69D2: 0xFFFD,
	0x69D3: 0xBA62,
	0x69D4: 0xE252,
	0x69D5: 0x9AF9,
	0x69D6: 0x9AFA,
	0x69D7: 0xFFFD,
	0x69D8: 0x93DB,
	0x69D9: 0xE25C,
	0x69DA: 0xFFFD,
	0x69DB: 0x8ACD,
	0x69DC: 0xFFFD,
	0x69DD: 0x94A5,
	0x69DE: 0x967D,
	0x69DF: 0x8ACB,
	0x69E0: 0x8FB9,
	0x69E1: 0x9B41,
	0x69E2: 0xE5D5,
	0x69E3: 0xFFFD,
	0x69E4: 0xE5D1,
	0x69E5: 0xE5CD,
	0x69E6: 0xE5E1,
	0x69E7: 0xE5DE,
	0x69E8: 0xBCCD,
	0x69E9: 0xFC75,
	0x69EA: 0xFFFD,
	0x69EB: 0xE5E5,
	0x69EC: 0xE5D4,
	0x69ED: 0xBCD8,
	0x69EE: 0xE5DB,
	0x69EF: 0xFFFD,
	0x69F0: 0xFFFD,
	0x69F1: 0xE5D0,
	0x69F2: 0xE5DA,
	0x69F3: 0xBCD5,
	0x69F4: 0xE5EE,
	0x69F5: 0xFFFD,
	0x69F6: 0xE5EB,
	0x69F7: 0xE5DD,
	0x69F8: 0xE5CE,
	0x69F9: 0x967E,
	0x69FA: 0xFC74,
	0x69FB: 0xE5E2,
	0x69FC: 0xE5E4,
	0x69FD: 0xBCD1,
	0x69FE: 0xE5D8,
	0x69FF: 0xE5D3,
	0x6A00: 0xE5CA,
	0x6A01: 0xBCCE,
	0x6A02: 0xBCD6,
	0x6A03: 0x9B42,
	0x6A04: 0xE5E7,
	0x6A05: 0xBCD7,
	0x6A06: 0xE5CB,
	0x6A07: 0xE5ED,
	0x6A08: 0xE5E0,
	0x6A09: 0xE5E6,
	0x6A0A: 0xBCD4,
	0x6A0B: 0xFE54,
	0x6A0C: 0x96CE,
	0x6A0D: 0xE5E3,
	0x6A0E: 0xFFFD,
	0x6A0F: 0xE5EA,
	0x6A10: 0xFFFD,
	0x6A11: 0xBCD9,
	0x6A12: 0x96EB,
	0x6A13: 0xBCD3,
	0x6A14: 0xE5DC,
	0x6A15: 0xE5CF,
	0x6A16: 0xE5EF,
	0x6A17: 0xE5CC,
	0x6A18: 0xE5E8,
	0x6A19: 0xBCD0,
	0x6A1A: 0x9B43,
	0x6A1B: 0xE5D6,
	0x6A1C: 0x9B44,
	0x6A1D: 0xE5D7,
	0x6A1E: 0xBCCF,
	0x6A1F: 0xBCCC,
	0x6A20: 0xE5D2,
	0x6A21: 0xBCD2,
	0x6A22: 0x96EC,
	0x6A23: 0xBCCB,
	0x6A24: 0xFFFD,
	0x6A25: 0xE5E9,
	0x6A26: 0xE5EC,
	0x6A27: 0xE5D9,
	0x6A28: 0xE9CA,
	0x6A29: 0x92B7,
	0x6A2A: 0x88EA,
	0x6A2B: 0x9440,
	0x6A2C: 0x9B45,
	0x6A2D: 0x9B46,
	0x6A2E: 0x94A6,
	0x6A2F: 0x89E7,
	0x6A30: 0x96ED,
	0x6A31: 0x8C76,
	0x6A32: 0xE9C2,
	0x6A33: 0x9B47,
	0x6A34: 0xE9BE,
	0x6A35: 0xBEF6,
	0x6A36: 0x96EE,
	0x6A37: 0xFFFD,
	0x6A38: 0xBEEB,
	0x6A39: 0xBEF0,
	0x6A3A: 0xBEEC,
	0x6A3B: 0xE9CC,
	0x6A3C: 0xE9D7,
	0x6A3D: 0xBEEA,
	0x6A3E: 0xE9C4,
	0x6A3F: 0xE9CD,
	0x6A40: 0xE5DF,
	0x6A41: 0xE9CE,
	0x6A42: 0xFFFD,
	0x6A43: 0x9B48,
	0x6A44: 0xBEF1,
	0x6A45: 0x9B49,
	0x6A46: 0xE9DD,
	0x6A47: 0xBEF5,
	0x6A48: 0xBEF8,
	0x6A49: 0xE9C0,
	0x6A4A: 0xFFFD,
	0x6A4B: 0xBEF4,
	0x6A4C: 0x9B4A,
	0x6A4D: 0xE9DB,
	0x6A4E: 0xE9DC,
	0x6A4F: 0xE9D2,
	0x6A50: 0xE9D1,
	0x6A51: 0xE9C9,
	0x6A52: 0xFC77,
	0x6A53: 0x9B4B,
	0x6A54: 0xE9D3,
	0x6A55: 0xE9DA,
	0x6A56: 0xE9D9,
	0x6A57: 0x9B4C,
	0x6A58: 0xBEEF,
	0x6A59: 0xBEED,
	0x6A5A: 0xE9CB,
	0x6A5B: 0xE9C8,
	0x6A5C: 0xFFFD,
	0x6A5D: 0xE9C5,
	0x6A5E: 0xE9D8,
	0x6A5F: 0xBEF7,
	0x6A60: 0xE9D6,
	0x6A61: 0xBEF3,
	0x6A62: 0xBEF2,
	0x6A63: 0x9B4D,
	0x6A64: 0xE9D0,
	0x6A65: 0x96EF,
	0x6A66: 0xE9BF,
	0x6A67: 0xE9C1,
	0x6A68: 0xE9C3,
	0x6A69: 0xE9D5,
	0x6A6A: 0xE9CF,
	0x6A6B: 0xBEEE,
	0x6A6C: 0xFFFD,
	0x6A6D: 0xE9C6,
	0x6A6E: 0xFFFD,
	0x6A6F: 0xE9D4,
	0x6A70: 0xFFFD,
	0x6A71: 0x8B78,
	0x6A72: 0x94A7,
	0x6A73: 0x96F8,
	0x6A74: 0x9B4E,
	0x6A75: 0xFFFD,
	0x6A76: 0xE9C7,
	0x6A77: 0xFFFD,
	0x6A78: 0x96F9,
	0x6A79: 0x8B7B,
	0x6A7A: 0x947E,
	0x6A7B: 0xFFFD,
	0x6A7C: 0x96FC,
	0x6A7D: 0xFFFD,
	0x6A7E: 0xC0CF,
	0x6A7F: 0xED45,
	0x6A80: 0xC0C8,
	0x6A81: 0xECF5,
	0x6A82: 0x9B4F,
	0x6A83: 0xED41,
	0x6A84: 0xC0CA,
	0x6A85: 0xED48,
	0x6A86: 0xFFFD,
	0x6A87: 0xECFC,
	0x6A88: 0xFFFD,
	0x6A89: 0xECF7,
	0x6A8A: 0x9B50,
	0x6A8B: 0xFFFD,
	0x6A8C: 0xED49,
	0x6A8D: 0xECF3,
	0x6A8E: 0xECFE,
	0x6A8F: 0x9B51,
	0x6A90: 0xC0D1,
	0x6A91: 0xED44,
	0x6A92: 0xED4A,
	0x6A93: 0xECFD,
	0x6A94: 0xC0C9,
	0x6A95: 0xED40,
	0x6A96: 0xECF4,
	0x6A97: 0xC0D0,
	0x6A98: 0xFFFD,
	0x6A99: 0x9B52,
	0x6A9A: 0xED47,
	0x6A9B: 0xECF9,
	0x6A9C: 0xC0CC,
	0x6A9D: 0xFC78,
	0x6A9E: 0xECFB,
	0x6A9F: 0xECF8,
	0x6AA0: 0xC0D2,
	0x6AA1: 0xECFA,
	0x6AA2: 0xC0CB,
	0x6AA3: 0xC0CE,
	0x6AA4: 0xED43,
	0x6AA5: 0xECF6,
	0x6AA6: 0xED46,
	0x6AA7: 0x9B53,
	0x6AA8: 0xED42,
	0x6AA9: 0x96FD,
	0x6AAA: 0x96FE,
	0x6AAB: 0x99FE,
	0x6AAC: 0xC263,
	0x6AAD: 0xEFE7,
	0x6AAE: 0xC268,
	0x6AAF: 0xC269,
	0x6AB0: 0xFFFD,
	0x6AB1: 0x9B54,
	0x6AB2: 0xFC76,
	0x6AB3: 0xC262,
	0x6AB4: 0xEFE6,
	0x6AB5: 0x9B55,
	0x6AB6: 0xEFE3,
	0x6AB7: 0xEFE4,
	0x6AB8: 0xC266,
	0x6AB9: 0xEFDE,
	0x6ABA: 0xEFE2,
	0x6ABB: 0xC265,
	0x6ABC: 0xFFFD,
	0x6ABD: 0xEFDF,
	0x6ABE: 0x9B56,
	0x6ABF: 0xFFFD,
	0x6AC0: 0xFFFD,
	0x6AC1: 0x9AFE,
	0x6AC2: 0xC267,
	0x6AC3: 0xC264,
	0x6AC4: 0xFFFD,
	0x6AC5: 0xEFDD,
	0x6AC6: 0xEFE1,
	0x6AC7: 0xEFE5,
	0x6AC8: 0x95E3,
	0x6AC9: 0x9B57,
	0x6ACA: 0xFBDC,
	0x6ACB: 0xF251,
	0x6ACC: 0xF24E,
	0x6ACD: 0xF257,
	0x6ACE: 0xFFFD,
	0x6ACF: 0xF256,
	0x6AD0: 0xF254,
	0x6AD1: 0xF24F,
	0x6AD2: 0xFFFD,
	0x6AD3: 0xC372,
	0x6AD4: 0x9B58,
	0x6AD5: 0xFFFD,
	0x6AD6: 0xFFFD,
	0x6AD7: 0xFFFD,
	0x6AD8: 0x9B59,
	0x6AD9: 0xF250,
	0x6ADA: 0xC371,
	0x6ADB: 0xC0CD,
	0x6ADC: 0xF253,
	0x6ADD: 0xC370,
	0x6ADE: 0xF258,
	0x6ADF: 0xF252,
	0x6AE0: 0xF24D,
	0x6AE1: 0xEFE0,
	0x6AE2: 0x9CF9,
	0x6AE3: 0xFFFD,
	0x6AE4: 0x9DE1,
	0x6AE5: 0xC36F,
	0x6AE6: 0xFFFD,
	0x6AE7: 0xF24C,
	0x6AE8: 0xF456,
	0x6AE9: 0xFFFD,
	0x6AEA: 0xF455,
	0x6AEB: 0xF255,
	0x6AEC: 0xC468,
	0x6AED: 0xFFFD,
	0x6AEE: 0xF459,
	0x6AEF: 0xF45A,
	0x6AF0: 0xF454,
	0x6AF1: 0xF458,
	0x6AF2: 0xFFFD,
	0x6AF3: 0xF453,
	0x6AF4: 0xFFFD,
	0x6AF5: 0xFFFD,
	0x6AF6: 0x9B5A,
	0x6AF7: 0xFFFD,
	0x6AF8: 0xF5D1,
	0x6AF9: 0xF457,
	0x6AFA: 0xC4E7,
	0x6AFB: 0xC4E5,
	0x6AFC: 0xF5CF,
	0x6AFD: 0xFFFD,
	0x6AFE: 0xFFFD,
	0x6AFF: 0xFFFD,
	0x6B00: 0xF5D2,
	0x6B01: 0xFFFD,
	0x6B02: 0xF5CE,
	0x6B03: 0xF5D0,
	0x6B04: 0xC4E6,
	0x6B05: 0x9DFE,
	0x6B06: 0xFFFD,
	0x6B07: 0xFFFD,
	0x6B08: 0xF6E5,
	0x6B09: 0xF6E6,
	0x6B0A: 0xC576,
	0x6B0B: 0xF6E4,
	0x6B0C: 0xFFFD,
	0x6B0D: 0xFFFD,
	0x6B0E: 0xFFFD,
	0x6B0F: 0xF7E2,
	0x6B10: 0xC5CF,
	0x6B11: 0xF7E0,
	0x6B12: 0xF7E1,
	0x6B13: 0xF8AC,
	0x6B14: 0xFFFD,
	0x6B15: 0xFFFD,
	0x6B16: 0xC656,
	0x6B17: 0xF8F3,
	0x6B18: 0xF8F1,
	0x6B19: 0xF8F2,
	0x6B1A: 0xF8F4,
	0x6B1B: 0xFFFD,
	0x6B1C: 0xFFFD,
	0x6B1D: 0xFC79,
	0x6B1E: 0xF9BB,
	0x6B1F: 0x94A8,
	0x6B20: 0xA4ED,
	0x6B21: 0xA6B8,
	0x6B22: 0x8CD1,
	0x6B23: 0xAA59,
	0x6B24: 0x8ACF,
	0x6B25: 0xCCE9,
	0x6B26: 0xFFFD,
	0x6B27: 0x87E6,
	0x6B28: 0xCF64,
	0x6B29: 0xFFFD,
	0x6B2A: 0xFFFD,
	0x6B2B: 0xFFFD,
	0x6B2C: 0xD1F5,
	0x6B2D: 0xD1F7,
	0x6B2E: 0xFFFD,
	0x6B2F: 0xD1F6,
	0x6B30: 0xFFFD,
	0x6B31: 0xD1F8,
	0x6B32: 0xB1FD,
	0x6B33: 0xD5D7,
	0x6B34: 0xD1F9,
	0x6B35: 0x95B9,
	0x6B36: 0xD5D6,
	0x6B37: 0xD5D8,
	0x6B38: 0xD5D9,
	0x6B39: 0xD9DA,
	0x6B3A: 0xB4DB,
	0x6B3B: 0xD9DB,
	0x6B3C: 0xD9DD,
	0x6B3D: 0xB4DC,
	0x6B3E: 0xB4DA,
	0x6B3F: 0xD9DC,
	0x6B40: 0xFFFD,
	0x6B41: 0xDDFA,
	0x6B42: 0xDDF8,
	0x6B43: 0xDDF7,
	0x6B44: 0xFFFD,
	0x6B45: 0xDDF6,
	0x6B46: 0xDDF5,
	0x6B47: 0xB7B2,
	0x6B48: 0xDDF9,
	0x6B49: 0xBA70,
	0x6B4A: 0xE263,
	0x6B4B: 0xE265,
	0x6B4C: 0xBA71,
	0x6B4D: 0xE264,
	0x6B4E: 0xBCDB,
	0x6B4F: 0xFFFD,
	0x6B50: 0xBCDA,
	0x6B51: 0xE5F0,
	0x6B52: 0xFC7A,
	0x6B53: 0x926C,
	0x6B54: 0xE9DF,
	0x6B55: 0xE9DE,
	0x6B56: 0xE9E0,
	0x6B57: 0x9B5B,
	0x6B58: 0xFFFD,
	0x6B59: 0xBEF9,
	0x6B5A: 0xFFFD,
	0x6B5B: 0xED4B,
	0x6B5C: 0xC0D3,
	0x6B5D: 0xFFFD,
	0x6B5E: 0xEFE8,
	0x6B5F: 0xC26A,
	0x6B60: 0xF259,
	0x6B61: 0xC577,
	0x6B62: 0xA4EE,
	0x6B63: 0xA5BF,
	0x6B64: 0xA6B9,
	0x6B65: 0xA842,
	0x6B66: 0xAA5A,
	0x6B67: 0xAA5B,
	0x6B68: 0xFFFD,
	0x6B69: 0x93C5,
	0x6B6A: 0xAC6E,
	0x6B6B: 0xFFFD,
	0x6B6C: 0xFFFD,
	0x6B6D: 0xD1FA,
	0x6B6E: 0xFFFD,
	0x6B6F: 0x92D0,
	0x6B70: 0xFFFD,
	0x6B71: 0xFFFD,
	0x6B72: 0xB7B3,
	0x6B73: 0x92C8,
	0x6B74: 0x93F0,
	0x6B75: 0xFFFD,
	0x6B76: 0xE6D1,
	0x6B77: 0xBEFA,
	0x6B78: 0xC26B,
	0x6B79: 0xA4EF,
	0x6B7A: 0x9B5C,
	0x6B7B: 0xA6BA,
	0x6B7C: 0x8C79,
	0x6B7D: 0xFFFD,
	0x6B7E: 0xCCEB,
	0x6B7F: 0xAA5C,
	0x6B80: 0xCCEA,
	0x6B81: 0x9F4E,
	0x6B82: 0xCF65,
	0x6B83: 0xAC6F,
	0x6B84: 0xCF66,
	0x6B85: 0xFFFD,
	0x6B86: 0xAC70,
	0x6B87: 0x87E7,
	0x6B88: 0xD1FC,
	0x6B89: 0xAEEE,
	0x6B8A: 0xAEED,
	0x6B8B: 0x92CF,
	0x6B8C: 0xD5DE,
	0x6B8D: 0xD5DC,
	0x6B8E: 0xD5DD,
	0x6B8F: 0xD5DB,
	0x6B90: 0xFFFD,
	0x6B91: 0xD5DA,
	0x6B92: 0x8DB5,
	0x6B93: 0x89E8,
	0x6B94: 0xD9DE,
	0x6B95: 0xD9E1,
	0x6B96: 0xB4DE,
	0x6B97: 0xD9DF,
	0x6B98: 0xB4DD,
	0x6B99: 0xD9E0,
	0x6B9A: 0x8EE8,
	0x6B9B: 0xDDFB,
	0x6B9C: 0xFFFD,
	0x6B9D: 0xFFFD,
	0x6B9E: 0xE266,
	0x6B9F: 0xE267,
	0x6BA0: 0xE268,
	0x6BA1: 0x8AD1,
	0x6BA2: 0xE5F3,
	0x6BA3: 0xE5F2,
	0x6BA4: 0xBCDC,
	0x6BA5: 0xE5F1,
	0x6BA6: 0xE5F4,
	0x6BA7: 0xE9E1,
	0x6BA8: 0xFFFD,
	0x6BA9: 0xFFFD,
	0x6BAA: 0xE9E2,
	0x6BAB: 0xE9E3,
	0x6BAC: 0xFFFD,
	0x6BAD: 0xED4C,
	0x6BAE: 0xC0D4,
	0x6BAF: 0xC26C,
	0x6BB0: 0xF25A,
	0x6BB1: 0x9F4F,
	0x6BB2: 0xC4E8,
	0x6BB3: 0xC95F,
	0x6BB4: 0x87E8,
	0x6BB5: 0xAC71,
	0x6BB6: 0xCF67,
	0x6BB7: 0xAEEF,
	0x6BB8: 0xFFFD,
	0x6BB9: 0xFFFD,
	0x6BBA: 0xB1FE,
	0x6BBB: 0x925F,
	0x6BBC: 0xB4DF,
	0x6BBD: 0xD9E2,
	0x6BBE: 0xFFFD,
	0x6BBF: 0xB7B5,
	0x6BC0: 0xB7B4,
	0x6BC1: 0x90B5,
	0x6BC2: 0x8A75,
	0x6BC3: 0xE269,
	0x6BC4: 0xE26A,
	0x6BC5: 0xBCDD,
	0x6BC6: 0xBCDE,
	0x6BC7: 0xE9E5,
	0x6BC8: 0xE9E4,
	0x6BC9: 0xEFE9,
	0x6BCA: 0xF7E3,
	0x6BCB: 0xA4F0,
	0x6BCC: 0xC960,
	0x6BCD: 0xA5C0,
	0x6BCE: 0x93D1,
	0x6BCF: 0xA843,
	0x6BD0: 0xCB48,
	0x6BD1: 0xFFFD,
	0x6BD2: 0xAC72,
	0x6BD3: 0xB7B6,
	0x6BD4: 0xA4F1,
	0x6BD5: 0x8465,
	0x6BD6: 0xCF68,
	0x6BD7: 0xAC73,
	0x6BD8: 0xCF69,
	0x6BD9: 0x89E1,
	0x6BDA: 0xC0D5,
	0x6BDB: 0xA4F2,
	0x6BDC: 0x9B5D,
	0x6BDD: 0xFFFD,
	0x6BDE: 0xCCEC,
	0x6BDF: 0x94A9,
	0x6BE0: 0xCF6A,
	0x6BE1: 0x89E9,
	0x6BE2: 0xD242,
	0x6BE3: 0xD241,
	0x6BE4: 0xD1FE,
	0x6BE5: 0xFFFD,
	0x6BE6: 0xD1FD,
	0x6BE7: 0xD243,
	0x6BE8: 0xD240,
	0x6BE9: 0xFFFD,
	0x6BEA: 0xA062,
	0x6BEB: 0xB240,
	0x6BEC: 0xB241,
	0x6BED: 0xFFFD,
	0x6BEE: 0xFFFD,
	0x6BEF: 0xB4E0,
	0x6BF0: 0xD9E3,
	0x6BF1: 0xFFFD,
	0x6BF2: 0xD9E4,
	0x6BF3: 0xD9E5,
	0x6BF4: 0xFFFD,
	0x6BF5: 0x8EB9,
	0x6BF6: 0xFFFD,
	0x6BF7: 0xDE41,
	0x6BF8: 0xDE42,
	0x6BF9: 0xDE40,
	0x6BFA: 0xFC7B,
	0x6BFB: 0xDDFD,
	0x6BFC: 0xDDFE,
	0x6BFD: 0xB7B7,
	0x6BFE: 0xE26B,
	0x6BFF: 0xE5F7,
	0x6C00: 0xE5F6,
	0x6C01: 0xE5F5,
	0x6C02: 0xE5F8,
	0x6C03: 0xE9E7,
	0x6C04: 0xE9E6,
	0x6C05: 0xBEFB,
	0x6C06: 0xE9E8,
	0x6C07: 0x8FBB,
	0x6C08: 0xC0D6,
	0x6C09: 0xED4D,
	0x6C0A: 0xFFFD,
	0x6C0B: 0xEFEA,
	0x6C0C: 0xF25B,
	0x6C0D: 0xF6E7,
	0x6C0E: 0xFFFD,
	0x6C0F: 0xA4F3,
	0x6C10: 0xA5C2,
	0x6C11: 0xA5C1,
	0x6C12: 0xFFFD,
	0x6C13: 0xAA5D,
	0x6C14: 0xC961,
	0x6C15: 0xC97E,
	0x6C16: 0xA6BB,
	0x6C17: 0x926E,
	0x6C18: 0xC9F7,
	0x6C19: 0xCB49,
	0x6C1A: 0xCB4A,
	0x6C1B: 0xAA5E,
	0x6C1C: 0x9B5E,
	0x6C1D: 0xCCED,
	0x6C1E: 0xFFFD,
	0x6C1F: 0xAC74,
	0x6C20: 0xCF6B,
	0x6C21: 0xCF6C,
	0x6C22: 0x845A,
	0x6C23: 0xAEF0,
	0x6C24: 0xAEF4,
	0x6C25: 0xD244,
	0x6C26: 0xAEF3,
	0x6C27: 0xAEF1,
	0x6C28: 0xAEF2,
	0x6C29: 0x84EC,
	0x6C2A: 0xD5DF,
	0x6C2B: 0xB242,
	0x6C2C: 0xB4E3,
	0x6C2D: 0xFFFD,
	0x6C2E: 0xB4E1,
	0x6C2F: 0xB4E2,
	0x6C30: 0xD9E6,
	0x6C31: 0x9B5F,
	0x6C32: 0xA063,
	0x6C33: 0xBA72,
	0x6C34: 0xA4F4,
	0x6C35: 0x9CF3,
	0x6C36: 0xC9A1,
	0x6C37: 0x95EB,
	0x6C38: 0xA5C3,
	0x6C39: 0xFE40,
	0x6C3A: 0x91D2,
	0x6C3B: 0xC9A4,
	0x6C3C: 0xFFFD,
	0x6C3D: 0xA064,
	0x6C3E: 0xA5C6,
	0x6C3F: 0xC9A3,
	0x6C40: 0xA5C5,
	0x6C41: 0xA5C4,
	0x6C42: 0xA844,
	0x6C43: 0xC9A2,
	0x6C44: 0xFFFD,
	0x6C45: 0xFFFD,
	0x6C46: 0xC9F8,
	0x6C47: 0x85B9,
	0x6C48: 0xFFFD,
	0x6C49: 0x86D5,
	0x6C4A: 0xC9FC,
	0x6C4B: 0xC9FE,
	0x6C4C: 0xCA40,
	0x6C4D: 0xA6C5,
	0x6C4E: 0xA6C6,
	0x6C4F: 0xC9FB,
	0x6C50: 0xA6C1,
	0x6C51: 0xFFFD,
	0x6C52: 0xC9F9,
	0x6C53: 0xFFFD,
	0x6C54: 0xC9FD,
	0x6C55: 0xA6C2,
	0x6C56: 0xFFFD,
	0x6C57: 0xA6BD,
	0x6C58: 0x9B60,
	0x6C59: 0xA6BE,
	0x6C5A: 0x95EA,
	0x6C5B: 0xA6C4,
	0x6C5C: 0xC9FA,
	0x6C5D: 0xA6BC,
	0x6C5E: 0xA845,
	0x6C5F: 0xA6BF,
	0x6C60: 0xA6C0,
	0x6C61: 0xA6C3,
	0x6C62: 0xA065,
	0x6C63: 0xFFFD,
	0x6C64: 0x84F1,
	0x6C65: 0xCB5B,
	0x6C66: 0xCB59,
	0x6C67: 0xCB4C,
	0x6C68: 0xA851,
	0x6C69: 0xCB53,
	0x6C6A: 0xA84C,
	0x6C6B: 0xCB4D,
	0x6C6C: 0xFFFD,
	0x6C6D: 0xCB55,
	0x6C6E: 0x9B61,
	0x6C6F: 0xCB52,
	0x6C70: 0xA84F,
	0x6C71: 0xCB51,
	0x6C72: 0xA856,
	0x6C73: 0xCB5A,
	0x6C74: 0xA858,
	0x6C75: 0x9B62,
	0x6C76: 0xA85A,
	0x6C77: 0xFFFD,
	0x6C78: 0xCB4B,
	0x6C79: 0x836E,
	0x6C7A: 0xA84D,
	0x6C7B: 0xCB5C,
	0x6C7C: 0xFFFD,
	0x6C7D: 0xA854,
	0x6C7E: 0xA857,
	0x6C7F: 0x9B63,
	0x6C80: 0xCD45,
	0x6C81: 0xA847,
	0x6C82: 0xA85E,
	0x6C83: 0xA855,
	0x6C84: 0xCB4E,
	0x6C85: 0xA84A,
	0x6C86: 0xA859,
	0x6C87: 0xCB56,
	0x6C88: 0xA848,
	0x6C89: 0xA849,
	0x6C8A: 0xCD43,
	0x6C8B: 0xCB4F,
	0x6C8C: 0xA850,
	0x6C8D: 0xA85B,
	0x6C8E: 0xCB5D,
	0x6C8F: 0xCB50,
	0x6C90: 0xA84E,
	0x6C91: 0xFFFD,
	0x6C92: 0xA853,
	0x6C93: 0xCCEE,
	0x6C94: 0xA85C,
	0x6C95: 0xCB57,
	0x6C96: 0xA852,
	0x6C97: 0xFFFD,
	0x6C98: 0xA85D,
	0x6C99: 0xA846,
	0x6C9A: 0xCB54,
	0x6C9B: 0xA84B,
	0x6C9C: 0xCB58,
	0x6C9D: 0xCD44,
	0x6C9E: 0xFFFD,
	0x6C9F: 0x85D8,
	0x6CA0: 0xFFFD,
	0x6CA1: 0x95CA,
	0x6CA2: 0x936B,
	0x6CA3: 0x88F4,
	0x6CA4: 0x8E75,
	0x6CA5: 0x8B7E,
	0x6CA6: 0x845F,
	0x6CA7: 0x85DC,
	0x6CA8: 0xFFFD,
	0x6CA9: 0x8DE0,
	0x6CAA: 0x86DB,
	0x6CAB: 0xAA6A,
	0x6CAC: 0xAA7A,
	0x6CAD: 0xCCF5,
	0x6CAE: 0xAA71,
	0x6CAF: 0x9B64,
	0x6CB0: 0xCD4B,
	0x6CB1: 0xAA62,
	0x6CB2: 0xA066,
	0x6CB3: 0xAA65,
	0x6CB4: 0xCD42,
	0x6CB5: 0xFFFD,
	0x6CB6: 0xCCF3,
	0x6CB7: 0xCCF7,
	0x6CB8: 0xAA6D,
	0x6CB9: 0xAA6F,
	0x6CBA: 0xCCFA,
	0x6CBB: 0xAA76,
	0x6CBC: 0xAA68,
	0x6CBD: 0xAA66,
	0x6CBE: 0xAA67,
	0x6CBF: 0xAA75,
	0x6CC0: 0xCD47,
	0x6CC1: 0xAA70,
	0x6CC2: 0xCCF9,
	0x6CC3: 0xCCFB,
	0x6CC4: 0xAA6E,
	0x6CC5: 0xAA73,
	0x6CC6: 0xCCFC,
	0x6CC7: 0xCD4A,
	0x6CC8: 0xFFFD,
	0x6CC9: 0xAC75,
	0x6CCA: 0xAA79,
	0x6CCB: 0x9B65,
	0x6CCC: 0xAA63,
	0x6CCD: 0xCD49,
	0x6CCE: 0xFC7D,
	0x6CCF: 0xCD4D,
	0x6CD0: 0xCCF8,
	0x6CD1: 0xCD4F,
	0x6CD2: 0xCD40,
	0x6CD3: 0xAA6C,
	0x6CD4: 0xCCF4,
	0x6CD5: 0xAA6B,
	0x6CD6: 0xAA7D,
	0x6CD7: 0xAA72,
	0x6CD8: 0xFFFD,
	0x6CD9: 0xCCF2,
	0x6CDA: 0xCF75,
	0x6CDB: 0xAA78,
	0x6CDC: 0xAA7C,
	0x6CDD: 0xCD41,
	0x6CDE: 0xCD46,
	0x6CDF: 0x9B66,
	0x6CE0: 0xAA7E,
	0x6CE1: 0xAA77,
	0x6CE2: 0xAA69,
	0x6CE3: 0xAA5F,
	0x6CE4: 0xFFFD,
	0x6CE5: 0xAA64,
	0x6CE6: 0xFFFD,
	0x6CE7: 0xCCF6,
	0x6CE8: 0xAA60,
	0x6CE9: 0xCD4E,
	0x6CEA: 0x845E,
	0x6CEB: 0xCCF0,
	0x6CEC: 0xCCEF,
	0x6CED: 0xCCFD,
	0x6CEE: 0xCCF1,
	0x6CEF: 0xAA7B,
	0x6CF0: 0xAEF5,
	0x6CF1: 0xAA74,
	0x6CF2: 0xCCFE,
	0x6CF3: 0xAA61,
	0x6CF4: 0xFFFD,
	0x6CF5: 0xACA6,
	0x6CF6: 0x8F54,
	0x6CF7: 0x8FBC,
	0x6CF8: 0x8BA2,
	0x6CF9: 0xCD4C,
	0x6CFA: 0x8F77,
	0x6CFB: 0x8AD2,
	0x6CFC: 0x87EA,
	0x6CFD: 0x88F2,
	0x6CFE: 0x83BD,
	0x6CFF: 0x9B67,
	0x6D00: 0xCF7C,
	0x6D01: 0xCFA1,
	0x6D02: 0x9B68,
	0x6D03: 0xCFA4,
	0x6D04: 0xCF77,
	0x6D05: 0x9B69,
	0x6D06: 0x9B6A,
	0x6D07: 0xCFA7,
	0x6D08: 0xCFAA,
	0x6D09: 0xCFAC,
	0x6D0A: 0xCF74,
	0x6D0B: 0xAC76,
	0x6D0C: 0xAC7B,
	0x6D0D: 0xD249,
	0x6D0E: 0xACAD,
	0x6D0F: 0xCFA5,
	0x6D10: 0xCFAD,
	0x6D11: 0xCF7B,
	0x6D12: 0xCF73,
	0x6D13: 0xFFFD,
	0x6D14: 0xFFFD,
	0x6D15: 0xFFFD,
	0x6D16: 0xD264,
	0x6D17: 0xAC7E,
	0x6D18: 0xCFA2,
	0x6D19: 0xCF78,
	0x6D1A: 0xCF7A,
	0x6D1B: 0xACA5,
	0x6D1C: 0xFFFD,
	0x6D1D: 0xCF7D,
	0x6D1E: 0xAC7D,
	0x6D1F: 0xCF70,
	0x6D20: 0xCFA8,
	0x6D21: 0xFFFD,
	0x6D22: 0xCFAB,
	0x6D23: 0xFFFD,
	0x6D24: 0x95B0,
	0x6D25: 0xAC7A,
	0x6D26: 0x9B6B,
	0x6D27: 0xACA8,
	0x6D28: 0xCF6D,
	0x6D29: 0xACAA,
	0x6D2A: 0xAC78,
	0x6D2B: 0xACAE,
	0x6D2C: 0xCFA9,
	0x6D2D: 0xCF6F,
	0x6D2E: 0xACAB,
	0x6D2F: 0xD25E,
	0x6D30: 0xCD48,
	0x6D31: 0xAC7C,
	0x6D32: 0xAC77,
	0x6D33: 0xCF76,
	0x6D34: 0xCF6E,
	0x6D35: 0xACAC,
	0x6D36: 0xACA4,
	0x6D37: 0xCFA3,
	0x6D38: 0xACA9,
	0x6D39: 0xACA7,
	0x6D3A: 0xCF79,
	0x6D3B: 0xACA1,
	0x6D3C: 0xCF71,
	0x6D3D: 0xACA2,
	0x6D3E: 0xACA3,
	0x6D3F: 0xCF72,
	0x6D40: 0xCFA6,
	0x6D41: 0xAC79,
	0x6D42: 0xCF7E,
	0x6D43: 0x83BE,
	0x6D44: 0x92EA,
	0x6D45: 0x9348,
	0x6D46: 0x87E9,
	0x6D47: 0x87EC,
	0x6D48: 0x8DE1,
	0x6D49: 0xFFFD,
	0x6D4A: 0x88F3,
	0x6D4B: 0x84F2,
	0x6D4C: 0xFFFD,
	0x6D4D: 0x8EE9,
	0x6D4E: 0x89EC,
	0x6D4F: 0x8AD7,
	0x6D50: 0xFFFD,
	0x6D51: 0x84F3,
	0x6D52: 0x8E74,
	0x6D53: 0x88F1,
	0x6D54: 0x87F0,
	0x6D55: 0xFFFD,
	0x6D56: 0xFFFD,
	0x6D57: 0x9B6C,
	0x6D58: 0xD24C,
	0x6D59: 0xAEFD,
	0x6D5A: 0xAF43,
	0x6D5B: 0x9B6D,
	0x6D5C: 0x93BD,
	0x6D5D: 0xFFFD,
	0x6D5E: 0xD255,
	0x6D5F: 0xD25B,
	0x6D60: 0xD257,
	0x6D61: 0xD24A,
	0x6D62: 0xD24D,
	0x6D63: 0xD246,
	0x6D64: 0xD247,
	0x6D65: 0xAF4A,
	0x6D66: 0xAEFA,
	0x6D67: 0xD256,
	0x6D68: 0xD25F,
	0x6D69: 0xAF45,
	0x6D6A: 0xAEF6,
	0x6D6B: 0xFFFD,
	0x6D6C: 0xAF40,
	0x6D6D: 0xD24E,
	0x6D6E: 0xAF42,
	0x6D6F: 0xD24F,
	0x6D70: 0xD259,
	0x6D71: 0x9B6E,
	0x6D72: 0xFBA7,
	0x6D73: 0xFFFD,
	0x6D74: 0xAF44,
	0x6D75: 0xD268,
	0x6D76: 0xD248,
	0x6D77: 0xAEFC,
	0x6D78: 0xAEFB,
	0x6D79: 0xAF48,
	0x6D7A: 0xD245,
	0x6D7B: 0xD266,
	0x6D7C: 0xD25A,
	0x6D7D: 0xD267,
	0x6D7E: 0xD261,
	0x6D7F: 0xD253,
	0x6D80: 0xD262,
	0x6D81: 0x9B6F,
	0x6D82: 0xD25C,
	0x6D83: 0xD265,
	0x6D84: 0xD263,
	0x6D85: 0xAF49,
	0x6D86: 0xD254,
	0x6D87: 0xAEF9,
	0x6D88: 0xAEF8,
	0x6D89: 0xAF41,
	0x6D8A: 0xAF47,
	0x6D8B: 0xD260,
	0x6D8C: 0xAF46,
	0x6D8D: 0xD251,
	0x6D8E: 0xB243,
	0x6D8F: 0x9B70,
	0x6D90: 0xD269,
	0x6D91: 0xD250,
	0x6D92: 0xD24B,
	0x6D93: 0xAEFE,
	0x6D94: 0xAF4B,
	0x6D95: 0xAEF7,
	0x6D96: 0xFE5C,
	0x6D97: 0xD258,
	0x6D98: 0xD25D,
	0x6D99: 0x93E8,
	0x6D9A: 0xFFFD,
	0x6D9B: 0x89ED,
	0x6D9C: 0x8271,
	0x6D9D: 0x8EBB,
	0x6D9E: 0x8DCF,
	0x6D9F: 0x86DA,
	0x6DA0: 0x8EBD,
	0x6DA1: 0x84F0,
	0x6DA2: 0xFFFD,
	0x6DA3: 0x84F4,
	0x6DA4: 0x86DE,
	0x6DA5: 0x9B71,
	0x6DA6: 0x87EE,
	0x6DA7: 0x87EF,
	0x6DA8: 0x86D9,
	0x6DA9: 0x89EF,
	0x6DAA: 0xB265,
	0x6DAB: 0xD5E1,
	0x6DAC: 0xD5E5,
	0x6DAD: 0xFFFD,
	0x6DAE: 0xB252,
	0x6DAF: 0xB250,
	0x6DB0: 0xFFFD,
	0x6DB1: 0x9B72,
	0x6DB2: 0xB247,
	0x6DB3: 0xD5E3,
	0x6DB4: 0xD5E2,
	0x6DB5: 0xB25B,
	0x6DB6: 0xFFFD,
	0x6DB7: 0xD5E8,
	0x6DB8: 0xB255,
	0x6DB9: 0xFCA1,
	0x6DBA: 0xD5FA,
	0x6DBB: 0xD647,
	0x6DBC: 0xB244,
	0x6DBD: 0xD5F7,
	0x6DBE: 0xD5F0,
	0x6DBF: 0xB267,
	0x6DC0: 0xD5E0,
	0x6DC1: 0xFFFD,
	0x6DC2: 0xD5FC,
	0x6DC3: 0xFFFD,
	0x6DC4: 0xB264,
	0x6DC5: 0xB258,
	0x6DC6: 0xB263,
	0x6DC7: 0xB24E,
	0x6DC8: 0xD5EC,
	0x6DC9: 0xD5FE,
	0x6DCA: 0xD5F6,
	0x6DCB: 0xB24F,
	0x6DCC: 0xB249,
	0x6DCD: 0xD645,
	0x6DCE: 0xFFFD,
	0x6DCF: 0xD5FD,
	0x6DD0: 0xD640,
	0x6DD1: 0xB251,
	0x6DD2: 0xB259,
	0x6DD3: 0xD642,
	0x6DD4: 0xD5EA,
	0x6DD5: 0xD5FB,
	0x6DD6: 0xD5EF,
	0x6DD7: 0xD644,
	0x6DD8: 0xB25E,
	0x6DD9: 0xB246,
	0x6DDA: 0xB25C,
	0x6DDB: 0xD5F4,
	0x6DDC: 0xD5F2,
	0x6DDD: 0xD5F3,
	0x6DDE: 0xB253,
	0x6DDF: 0xD5EE,
	0x6DE0: 0xD5ED,
	0x6DE1: 0xB248,
	0x6DE2: 0xD5E7,
	0x6DE3: 0xD646,
	0x6DE4: 0xB24A,
	0x6DE5: 0xD5F1,
	0x6DE6: 0xB268,
	0x6DE7: 0xFFFD,
	0x6DE8: 0xB262,
	0x6DE9: 0xD5E6,
	0x6DEA: 0xB25F,
	0x6DEB: 0xB25D,
	0x6DEC: 0xB266,
	0x6DED: 0xD5F8,
	0x6DEE: 0xB261,
	0x6DEF: 0xD252,
	0x6DF0: 0xD5F9,
	0x6DF1: 0xB260,
	0x6DF2: 0xD641,
	0x6DF3: 0xB245,
	0x6DF4: 0xD5F5,
	0x6DF5: 0xB257,
	0x6DF6: 0xD5E9,
	0x6DF7: 0xB256,
	0x6DF8: 0xA067,
	0x6DF9: 0xB254,
	0x6DFA: 0xB24C,
	0x6DFB: 0xB24B,
	0x6DFC: 0xD9E7,
	0x6DFD: 0xD643,
	0x6DFE: 0x9B73,
	0x6DFF: 0xFFFD,
	0x6E00: 0xD5EB,
	0x6E01: 0xFFFD,
	0x6E02: 0x9B74,
	0x6E03: 0xD9FC,
	0x6E04: 0x9B75,
	0x6E05: 0xB24D,
	0x6E06: 0xFFFD,
	0x6E07: 0x9264,
	0x6E08: 0x92C6,
	0x6E09: 0x92E4,
	0x6E0A: 0x845D,
	0x6E0B: 0x92DD,
	0x6E0C: 0x8DD0,
	0x6E0D: 0x86D4,
	0x6E0E: 0x8AD5,
	0x6E0F: 0x9B76,
	0x6E10: 0x86D8,
	0x6E11: 0x88F6,
	0x6E12: 0xFFFD,
	0x6E13: 0x92AA,
	0x6E14: 0x86DC,
	0x6E15: 0x94AA,
	0x6E16: 0x8AD3,
	0x6E17: 0x86DD,
	0x6E18: 0x9B77,
	0x6E19: 0xB541,
	0x6E1A: 0xB25A,
	0x6E1B: 0xB4EE,
	0x6E1C: 0xD9F6,
	0x6E1D: 0xB4FC,
	0x6E1E: 0xFFFD,
	0x6E1F: 0xD9EA,
	0x6E20: 0xB4EB,
	0x6E21: 0xB4E7,
	0x6E22: 0xDA49,
	0x6E23: 0xB4ED,
	0x6E24: 0xB4F1,
	0x6E25: 0xB4EC,
	0x6E26: 0xB4F5,
	0x6E27: 0xDA4D,
	0x6E28: 0xDA44,
	0x6E29: 0xA068,
	0x6E2A: 0x9B78,
	0x6E2B: 0xD9F1,
	0x6E2C: 0xB4FA,
	0x6E2D: 0xB4F4,
	0x6E2E: 0xD9FD,
	0x6E2F: 0xB4E4,
	0x6E30: 0xDA4A,
	0x6E31: 0xDA43,
	0x6E32: 0xB4E8,
	0x6E33: 0xD9F7,
	0x6E34: 0xB4F7,
	0x6E35: 0xDA55,
	0x6E36: 0xDA56,
	0x6E37: 0xFFFD,
	0x6E38: 0xB4E5,
	0x6E39: 0xDA48,
	0x6E3A: 0xB4F9,
	0x6E3B: 0xD9FB,
	0x6E3C: 0xD9ED,
	0x6E3D: 0xD9EE,
	0x6E3E: 0xB4FD,
	0x6E3F: 0xD9F2,
	0x6E40: 0xD9F9,
	0x6E41: 0xD9F3,
	0x6E42: 0xFFFD,
	0x6E43: 0xB4FB,
	0x6E44: 0xB544,
	0x6E45: 0xD9EF,
	0x6E46: 0xD9E8,
	0x6E47: 0xD9E9,
	0x6E48: 0xFFFD,
	0x6E49: 0xD9EB,
	0x6E4A: 0xB4EA,
	0x6E4B: 0xD9F8,
	0x6E4C: 0xFFFD,
	0x6E4D: 0xB4F8,
	0x6E4E: 0xB542,
	0x6E4F: 0xFC7E,
	0x6E50: 0x9B79,
	0x6E51: 0xD9FA,
	0x6E52: 0xDA53,
	0x6E53: 0xDA4B,
	0x6E54: 0xB4E6,
	0x6E55: 0xDA51,
	0x6E56: 0xB4F2,
	0x6E57: 0x9DCB,
	0x6E58: 0xB4F0,
	0x6E59: 0x9B7A,
	0x6E5A: 0xDA57,
	0x6E5B: 0xB4EF,
	0x6E5C: 0xDA41,
	0x6E5D: 0xD9F4,
	0x6E5E: 0xD9FE,
	0x6E5F: 0xB547,
	0x6E60: 0xDA45,
	0x6E61: 0xDA42,
	0x6E62: 0xD9F0,
	0x6E63: 0xB543,
	0x6E64: 0xDA4F,
	0x6E65: 0xDA4C,
	0x6E66: 0xDA54,
	0x6E67: 0xB4E9,
	0x6E68: 0xDA40,
	0x6E69: 0xB546,
	0x6E6A: 0xFFFD,
	0x6E6B: 0xDA47,
	0x6E6C: 0xFFFD,
	0x6E6D: 0xFFFD,
	0x6E6E: 0xB4F3,
	0x6E6F: 0xB4F6,
	0x6E70: 0xFFFD,
	0x6E71: 0xDA46,
	0x6E72: 0xB545,
	0x6E73: 0xD9F5,
	0x6E74: 0xD5E4,
	0x6E75: 0xFFFD,
	0x6E76: 0xA069,
	0x6E77: 0xDA50,
	0x6E78: 0xDA4E,
	0x6E79: 0xDA52,
	0x6E7A: 0xFFFD,
	0x6E7B: 0xFFFD,
	0x6E7C: 0x95CB,
	0x6E7D: 0xFFFD,
	0x6E7E: 0x8D6F,
	0x6E7F: 0x85DA,
	0x6E80: 0x93D2,
	0x6E81: 0xFFFD,
	0x6E82: 0xA06A,
	0x6E83: 0x87ED,
	0x6E84: 0xFFFD,
	0x6E85: 0x8AD6,
	0x6E86: 0xA06B,
	0x6E87: 0xFFFD,
	0x6E88: 0xD9EC,
	0x6E89: 0xB540,
	0x6E8A: 0xFFFD,
	0x6E8B: 0xFE6A,
	0x6E8C: 0x8278,
	0x6E8D: 0xDE61,
	0x6E8E: 0xDE60,
	0x6E8F: 0xDE46,
	0x6E90: 0xB7BD,
	0x6E91: 0xFFFD,
	0x6E92: 0xDE5F,
	0x6E93: 0xDE49,
	0x6E94: 0xDE4A,
	0x6E95: 0xFFFD,
	0x6E96: 0xB7C7,
	0x6E97: 0xDE68,
	0x6E98: 0xB7C2,
	0x6E99: 0xDE5E,
	0x6E9A: 0x9B7B,
	0x6E9B: 0xDE43,
	0x6E9C: 0xB7C8,
	0x6E9D: 0xB7BE,
	0x6E9E: 0xDE52,
	0x6E9F: 0xDE48,
	0x6EA0: 0xDE4B,
	0x6EA1: 0xDE63,
	0x6EA2: 0xB7B8,
	0x6EA3: 0xDE6A,
	0x6EA4: 0xDE62,
	0x6EA5: 0xB7C1,
	0x6EA6: 0xDE57,
	0x6EA7: 0xB7CC,
	0x6EA8: 0xFFFD,
	0x6EA9: 0xFFFD,
	0x6EAA: 0xB7CB,
	0x6EAB: 0xB7C5,
	0x6EAC: 0xFFFD,
	0x6EAD: 0xFFFD,
	0x6EAE: 0xDE69,
	0x6EAF: 0xB7B9,
	0x6EB0: 0xDE55,
	0x6EB1: 0xDE4C,
	0x6EB2: 0xDE59,
	0x6EB3: 0xDE65,
	0x6EB4: 0xB7CD,
	0x6EB5: 0x9B7C,
	0x6EB6: 0xB7BB,
	0x6EB7: 0xDE54,
	0x6EB8: 0x9B7D,
	0x6EB9: 0xDE4D,
	0x6EBA: 0xB7C4,
	0x6EBB: 0xA06C,
	0x6EBC: 0xB7C3,
	0x6EBD: 0xDE50,
	0x6EBE: 0xDE5A,
	0x6EBF: 0xDE64,
	0x6EC0: 0xDE47,
	0x6EC1: 0xDE51,
	0x6EC2: 0xB7BC,
	0x6EC3: 0xDE5B,
	0x6EC4: 0xB7C9,
	0x6EC5: 0xB7C0,
	0x6EC6: 0xDE4E,
	0x6EC7: 0xB7BF,
	0x6EC8: 0xDE45,
	0x6EC9: 0xDE53,
	0x6ECA: 0xDE67,
	0x6ECB: 0xB4FE,
	0x6ECC: 0xBAB0,
	0x6ECD: 0xDE56,
	0x6ECE: 0xE26C,
	0x6ECF: 0xDE58,
	0x6ED0: 0xDE66,
	0x6ED1: 0xB7C6,
	0x6ED2: 0xDE4F,
	0x6ED3: 0xB7BA,
	0x6ED4: 0xB7CA,
	0x6ED5: 0xBCF0,
	0x6ED6: 0xDE44,
	0x6ED7: 0x8EBE,
	0x6ED8: 0xDE5D,
	0x6ED9: 0x9550,
	0x6EDA: 0x86D3,
	0x6EDB: 0x9B7E,
	0x6EDC: 0xDE5C,
	0x6EDD: 0x9369,
	0x6EDE: 0x86D7,
	0x6EDF: 0xA06D,
	0x6EE0: 0x9041,
	0x6EE1: 0x86D6,
	0x6EE2: 0xA06E,
	0x6EE3: 0xFFFD,
	0x6EE4: 0x8AD4,
	0x6EE5: 0x89EE,
	0x6EE6: 0x8D7B,
	0x6EE7: 0xFFFD,
	0x6EE8: 0x89EB,
	0x6EE9: 0x8CD2,
	0x6EEA: 0xFFFD,
	0x6EEB: 0xE2AA,
	0x6EEC: 0xBAAD,
	0x6EED: 0xE27D,
	0x6EEE: 0xE2A4,
	0x6EEF: 0xBAA2,
	0x6EF0: 0xFFFD,
	0x6EF1: 0xE26E,
	0x6EF2: 0xBAAF,
	0x6EF3: 0xFFFD,
	0x6EF4: 0xBA77,
	0x6EF5: 0xE26D,
	0x6EF6: 0xE2B0,
	0x6EF7: 0xBAB1,
	0x6EF8: 0xE271,
	0x6EF9: 0xE2A3,
	0x6EFA: 0x9BA1,
	0x6EFB: 0xE273,
	0x6EFC: 0xE2B3,
	0x6EFD: 0xE2AF,
	0x6EFE: 0xBA75,
	0x6EFF: 0xBAA1,
	0x6F00: 0xE653,
	0x6F01: 0xBAAE,
	0x6F02: 0xBA7D,
	0x6F03: 0xE26F,
	0x6F04: 0x9BA2,
	0x6F05: 0xE2AE,
	0x6F06: 0xBAA3,
	0x6F07: 0xE2AB,
	0x6F08: 0xE2B8,
	0x6F09: 0xE275,
	0x6F0A: 0xE27E,
	0x6F0B: 0x9BA3,
	0x6F0C: 0x9BA4,
	0x6F0D: 0xE2B6,
	0x6F0E: 0xE2AC,
	0x6F0F: 0xBA7C,
	0x6F10: 0xFFFD,
	0x6F11: 0xA06F,
	0x6F12: 0xE27C,
	0x6F13: 0xBA76,
	0x6F14: 0xBA74,
	0x6F15: 0xBAA8,
	0x6F16: 0x9BA5,
	0x6F17: 0x9BA6,
	0x6F18: 0xE27A,
	0x6F19: 0xE277,
	0x6F1A: 0xE278,
	0x6F1B: 0xFFFD,
	0x6F1C: 0xE2B2,
	0x6F1D: 0xFFFD,
	0x6F1E: 0xE2B7,
	0x6F1F: 0xE2B5,
	0x6F20: 0xBA7A,
	0x6F21: 0xE2B9,
	0x6F22: 0xBA7E,
	0x6F23: 0xBAA7,
	0x6F24: 0xA070,
	0x6F25: 0xE270,
	0x6F26: 0xE5FA,
	0x6F27: 0xE279,
	0x6F28: 0xFFFD,
	0x6F29: 0xBA78,
	0x6F2A: 0xBAAC,
	0x6F2B: 0xBAA9,
	0x6F2C: 0xBA7B,
	0x6F2D: 0xE2A5,
	0x6F2E: 0xE274,
	0x6F2F: 0xBAAA,
	0x6F30: 0xE2A7,
	0x6F31: 0xBAA4,
	0x6F32: 0xBAA6,
	0x6F33: 0xBA73,
	0x6F34: 0x9BA7,
	0x6F35: 0xE2A9,
	0x6F36: 0xE2A1,
	0x6F37: 0xE272,
	0x6F38: 0xBAA5,
	0x6F39: 0xE2B1,
	0x6F3A: 0xE2B4,
	0x6F3B: 0xE27B,
	0x6F3C: 0xE2A8,
	0x6F3D: 0x9BA8,
	0x6F3E: 0xBA79,
	0x6F3F: 0xBCDF,
	0x6F40: 0xE2A6,
	0x6F41: 0xE5F9,
	0x6F42: 0xFFFD,
	0x6F43: 0xE2AD,
	0x6F44: 0xFCA2,
	0x6F45: 0x8250,
	0x6F46: 0x8FBD,
	0x6F47: 0x8B7C,
	0x6F48: 0xFFFD,
	0x6F49: 0xFFFD,
	0x6F4A: 0xFFFD,
	0x6F4B: 0x8BFB,
	0x6F4C: 0xFFFD,
	0x6F4D: 0x89F0,
	0x6F4E: 0xE276,
	0x6F4F: 0xE644,
	0x6F50: 0xE64E,
	0x6F51: 0xBCE2,
	0x6F52: 0xE64D,
	0x6F53: 0xE659,
	0x6F54: 0xBCE4,
	0x6F55: 0xE64B,
	0x6F56: 0x9BA9,
	0x6F57: 0xE64F,
	0x6F58: 0xBCEF,
	0x6F59: 0xFFFD,
	0x6F5A: 0xE646,
	0x6F5B: 0xBCE7,
	0x6F5C: 0x90B9,
	0x6F5D: 0xE652,
	0x6F5E: 0xE9F0,
	0x6F5F: 0xBCF3,
	0x6F60: 0xBCF2,
	0x6F61: 0xE654,
	0x6F62: 0xE643,
	0x6F63: 0xE65E,
	0x6F64: 0xBCED,
	0x6F65: 0xFFFD,
	0x6F66: 0xBCE3,
	0x6F67: 0xE657,
	0x6F68: 0xFFFD,
	0x6F69: 0xE65B,
	0x6F6A: 0xE660,
	0x6F6B: 0xE655,
	0x6F6C: 0xE649,
	0x6F6D: 0xBCE6,
	0x6F6E: 0xBCE9,
	0x6F6F: 0xBCF1,
	0x6F70: 0xBCEC,
	0x6F71: 0xFFFD,
	0x6F72: 0xE64C,
	0x6F73: 0xE2A2,
	0x6F74: 0xA071,
	0x6F75: 0xFFFD,
	0x6F76: 0xE648,
	0x6F77: 0xE65F,
	0x6F78: 0xBCE8,
	0x6F79: 0x9BAA,
	0x6F7A: 0xBCEB,
	0x6F7B: 0xE661,
	0x6F7C: 0xBCE0,
	0x6F7D: 0xE656,
	0x6F7E: 0xE5FB,
	0x6F7F: 0xE65C,
	0x6F80: 0xC0DF,
	0x6F81: 0x956B,
	0x6F82: 0xE64A,
	0x6F83: 0xFFFD,
	0x6F84: 0xBCE1,
	0x6F85: 0xE645,
	0x6F86: 0xBCE5,
	0x6F87: 0xE5FC,
	0x6F88: 0xBAAB,
	0x6F89: 0xE641,
	0x6F8A: 0x9BAB,
	0x6F8B: 0xE65A,
	0x6F8C: 0xE642,
	0x6F8D: 0xE640,
	0x6F8E: 0xBCEA,
	0x6F8F: 0xFFFD,
	0x6F90: 0xE658,
	0x6F91: 0xA072,
	0x6F92: 0xE5FE,
	0x6F93: 0xE651,
	0x6F94: 0xE650,
	0x6F95: 0xE65D,
	0x6F96: 0xE647,
	0x6F97: 0xBCEE,
	0x6F98: 0xFFFD,
	0x6F99: 0xFFFD,
	0x6F9A: 0xFFFD,
	0x6F9B: 0xFFFD,
	0x6F9C: 0x8BFA,
	0x6F9D: 0x9BAC,
	0x6F9E: 0xE9F3,
	0x6F9F: 0x9BAD,
	0x6FA0: 0xBF49,
	0x6FA1: 0xBEFE,
	0x6FA2: 0xEA40,
	0x6FA3: 0xE9EB,
	0x6FA4: 0xBF41,
	0x6FA5: 0xE9F7,
	0x6FA6: 0xBF48,
	0x6FA7: 0xBF43,
	0x6FA8: 0xE9F5,
	0x6FA9: 0xED4F,
	0x6FAA: 0xE9FB,
	0x6FAB: 0xEA42,
	0x6FAC: 0xE9FA,
	0x6FAD: 0xE9E9,
	0x6FAE: 0xE9F8,
	0x6FAF: 0xEA44,
	0x6FB0: 0xEA46,
	0x6FB1: 0xBEFD,
	0x6FB2: 0xEA45,
	0x6FB3: 0xBF44,
	0x6FB4: 0xBF4A,
	0x6FB5: 0xA073,
	0x6FB6: 0xBF47,
	0x6FB7: 0xFFFD,
	0x6FB8: 0xE9FE,
	0x6FB9: 0xBF46,
	0x6FBA: 0xE9F9,
	0x6FBB: 0x9BAE,
	0x6FBC: 0xE9ED,
	0x6FBD: 0xE9F2,
	0x6FBE: 0x9BAF,
	0x6FBF: 0xE9FD,
	0x6FC0: 0xBF45,
	0x6FC1: 0xBF42,
	0x6FC2: 0xBEFC,
	0x6FC3: 0xBF40,
	0x6FC4: 0xE9F1,
	0x6FC5: 0xFFFD,
	0x6FC6: 0xE5FD,
	0x6FC7: 0xE9EC,
	0x6FC8: 0xE9EF,
	0x6FC9: 0xEA41,
	0x6FCA: 0xE9F4,
	0x6FCB: 0xE9EA,
	0x6FCC: 0xED4E,
	0x6FCD: 0xEA43,
	0x6FCE: 0xE9EE,
	0x6FCF: 0xE9FC,
	0x6FD0: 0xFFFD,
	0x6FD1: 0x8B7D,
	0x6FD2: 0x8BA1,
	0x6FD3: 0x9BB0,
	0x6FD4: 0xED51,
	0x6FD5: 0xC0E3,
	0x6FD6: 0xFFFD,
	0x6FD7: 0xFFFD,
	0x6FD8: 0xC0D7,
	0x6FD9: 0x9BB1,
	0x6FDA: 0xFCA4,
	0x6FDB: 0xC0DB,
	0x6FDC: 0xED53,
	0x6FDD: 0xED59,
	0x6FDE: 0xED57,
	0x6FDF: 0xC0D9,
	0x6FE0: 0xC0DA,
	0x6FE1: 0xC0E1,
	0x6FE2: 0xED5A,
	0x6FE3: 0xED52,
	0x6FE4: 0xC0DC,
	0x6FE5: 0xFFFD,
	0x6FE6: 0xED56,
	0x6FE7: 0xED55,
	0x6FE8: 0xED5B,
	0x6FE9: 0xC0E2,
	0x6FEA: 0xFFFD,
	0x6FEB: 0xC0DD,
	0x6FEC: 0xC0E0,
	0x6FED: 0xED54,
	0x6FEE: 0xC0E4,
	0x6FEF: 0xC0DE,
	0x6FF0: 0xC0E5,
	0x6FF1: 0xC0D8,
	0x6FF2: 0xED58,
	0x6FF3: 0xA074,
	0x6FF4: 0xED50,
	0x6FF5: 0xA075,
	0x6FF6: 0x95C6,
	0x6FF7: 0xEFF7,
	0x6FF8: 0x9BB2,
	0x6FF9: 0xFFFD,
	0x6FFA: 0xC271,
	0x6FFB: 0xEFF4,
	0x6FFC: 0xEFF6,
	0x6FFD: 0xFFFD,
	0x6FFE: 0xC26F,
	0x6FFF: 0xEFF2,
	0x7000: 0xEFF3,
	0x7001: 0xEFEE,
	0x7002: 0xFFFD,
	0x7003: 0x9BB3,
	0x7004: 0xE9F6,
	0x7005: 0xEFEF,
	0x7006: 0xC270,
	0x7007: 0xEFEB,
	0x7008: 0xFFFD,
	0x7009: 0xC26D,
	0x700A: 0xEFF8,
	0x700B: 0xC26E,
	0x700C: 0xEFEC,
	0x700D: 0xEFED,
	0x700E: 0xEFF1,
	0x700F: 0xC273,
	0x7010: 0xFFFD,
	0x7011: 0xC272,
	0x7012: 0xFFFD,
	0x7013: 0xFFFD,
	0x7014: 0xEFF0,
	0x7015: 0xC378,
	0x7016: 0xF25F,
	0x7017: 0xF265,
	0x7018: 0xC379,
	0x7019: 0xF25C,
	0x701A: 0xC376,
	0x701B: 0xC373,
	0x701C: 0xF267,
	0x701D: 0xC377,
	0x701E: 0xFEA1,
	0x701F: 0xC374,
	0x7020: 0xF25E,
	0x7021: 0xF261,
	0x7022: 0xF262,
	0x7023: 0xF263,
	0x7024: 0xF266,
	0x7025: 0xFFFD,
	0x7026: 0xEFF5,
	0x7027: 0xF25D,
	0x7028: 0xC375,
	0x7029: 0xF264,
	0x702A: 0xF268,
	0x702B: 0xF260,
	0x702C: 0x9340,
	0x702D: 0xFFFD,
	0x702E: 0xFFFD,
	0x702F: 0xF45D,
	0x7030: 0xC46A,
	0x7031: 0xF460,
	0x7032: 0xC46B,
	0x7033: 0xF468,
	0x7034: 0xF45F,
	0x7035: 0xF45C,
	0x7036: 0xFFFD,
	0x7037: 0xF45E,
	0x7038: 0xF462,
	0x7039: 0xF465,
	0x703A: 0xF464,
	0x703B: 0xF467,
	0x703C: 0xF45B,
	0x703D: 0xFFFD,
	0x703E: 0xC469,
	0x703F: 0xF463,
	0x7040: 0xF466,
	0x7041: 0xF469,
	0x7042: 0xF461,
	0x7043: 0xF5D3,
	0x7044: 0xF5D4,
	0x7045: 0xF5D8,
	0x7046: 0xF5D9,
	0x7047: 0xFFFD,
	0x7048: 0xF5D6,
	0x7049: 0xF5D7,
	0x704A: 0xF5D5,
	0x704B: 0x9BB4,
	0x704C: 0xC4E9,
	0x704D: 0x9BB5,
	0x704E: 0xFFFD,
	0x704F: 0x9076,
	0x7050: 0x9BB6,
	0x7051: 0xC578,
	0x7052: 0xF6EB,
	0x7053: 0xFFFD,
	0x7054: 0x9BB7,
	0x7055: 0xF6E8,
	0x7056: 0xF6E9,
	0x7057: 0xF6EA,
	0x7058: 0xC579,
	0x7059: 0xFFFD,
	0x705A: 0xF7E5,
	0x705B: 0xF7E4,
	0x705C: 0x9BB8,
	0x705D: 0xF8AF,
	0x705E: 0xC5F4,
	0x705F: 0xF8AD,
	0x7060: 0xF8B0,
	0x7061: 0xF8AE,
	0x7062: 0xF8F5,
	0x7063: 0xC657,
	0x7064: 0xC665,
	0x7065: 0xF9A3,
	0x7066: 0xF96C,
	0x7067: 0x9BB9,
	0x7068: 0xF9A2,
	0x7069: 0xF9D0,
	0x706A: 0xF9D1,
	0x706B: 0xA4F5,
	0x706C: 0x9CF6,
	0x706D: 0x85D9,
	0x706E: 0xFFFD,
	0x706F: 0x88F9,
	0x7070: 0xA6C7,
	0x7071: 0xCA41,
	0x7072: 0xFFFD,
	0x7073: 0xFFFD,
	0x7074: 0xCB5E,
	0x7075: 0x8D5F,
	0x7076: 0xA85F,
	0x7077: 0x9BBA,
	0x7078: 0xA862,
	0x7079: 0x9BBB,
	0x707A: 0xCB5F,
	0x707B: 0xFFFD,
	0x707C: 0xA860,
	0x707D: 0xA861,
	0x707E: 0x834D,
	0x707F: 0x89F2,
	0x7080: 0x85DF,
	0x7081: 0xFCA5,
	0x7082: 0xCD58,
	0x7083: 0xCD5A,
	0x7084: 0xCD55,
	0x7085: 0xCD52,
	0x7086: 0xCD54,
	0x7087: 0xFFFD,
	0x7088: 0xFFFD,
	0x7089: 0x93F4,
	0x708A: 0xAAA4,
	0x708B: 0x9BBC,
	0x708C: 0xFFFD,
	0x708D: 0xFEA3,
	0x708E: 0xAAA2,
	0x708F: 0x9BBD,
	0x7090: 0xFFFD,
	0x7091: 0xCD56,
	0x7092: 0xAAA3,
	0x7093: 0xCD53,
	0x7094: 0xCD50,
	0x7095: 0xAAA1,
	0x7096: 0xCD57,
	0x7097: 0xFFFD,
	0x7098: 0xCD51,
	0x7099: 0xAAA5,
	0x709A: 0xCD59,
	0x709B: 0xFFFD,
	0x709C: 0x8E45,
	0x709D: 0x8E76,
	0x709E: 0xFFFD,
	0x709F: 0xCFAF,
	0x70A0: 0x9BBE,
	0x70A1: 0xCFB3,
	0x70A2: 0xFFFD,
	0x70A3: 0x9BBF,
	0x70A4: 0xACB7,
	0x70A5: 0x9BC0,
	0x70A6: 0x9BC1,
	0x70A7: 0x9BC2,
	0x70A8: 0xFFFD,
	0x70A9: 0xCFB6,
	0x70AA: 0xFFFD,
	0x70AB: 0xACAF,
	0x70AC: 0xACB2,
	0x70AD: 0xACB4,
	0x70AE: 0xACB6,
	0x70AF: 0xACB3,
	0x70B0: 0xCFB2,
	0x70B1: 0xCFB1,
	0x70B2: 0xFFFD,
	0x70B3: 0xACB1,
	0x70B4: 0xCFB4,
	0x70B5: 0xCFB5,
	0x70B6: 0xFFFD,
	0x70B7: 0xCFAE,
	0x70B8: 0xACB5,
	0x70B9: 0x8ABB,
	0x70BA: 0xACB0,
	0x70BB: 0xA076,
	0x70BC: 0x85DE,
	0x70BD: 0x88F7,
	0x70BE: 0xCFB0,
	0x70BF: 0xFFFD,
	0x70C0: 0xA077,
	0x70C1: 0x8BA3,
	0x70C2: 0x8C7A,
	0x70C3: 0x8DD1,
	0x70C4: 0x9BC3,
	0x70C5: 0xD277,
	0x70C6: 0xD278,
	0x70C7: 0xD279,
	0x70C8: 0xAF50,
	0x70C9: 0xFFFD,
	0x70CA: 0xAF4C,
	0x70CB: 0xD26E,
	0x70CC: 0x9BC4,
	0x70CD: 0xD276,
	0x70CE: 0xD27B,
	0x70CF: 0xAF51,
	0x70D0: 0x9BC5,
	0x70D1: 0xD26C,
	0x70D2: 0xD272,
	0x70D3: 0xD26B,
	0x70D4: 0xD275,
	0x70D5: 0xFC57,
	0x70D6: 0x9BC6,
	0x70D7: 0xD271,
	0x70D8: 0xAF4D,
	0x70D9: 0xAF4F,
	0x70DA: 0xD27A,
	0x70DB: 0x89F3,
	0x70DC: 0xD26A,
	0x70DD: 0xD26D,
	0x70DE: 0xD273,
	0x70DF: 0x95AF,
	0x70E0: 0xD274,
	0x70E1: 0xD27C,
	0x70E2: 0xD270,
	0x70E3: 0xFFFD,
	0x70E4: 0xAF4E,
	0x70E5: 0xFFFD,
	0x70E6: 0x85DD,
	0x70E7: 0x88F8,
	0x70E8: 0x8EEA,
	0x70E9: 0x89F4,
	0x70EA: 0xFFFD,
	0x70EB: 0x88FA,
	0x70EC: 0x8AD8,
	0x70ED: 0x87F1,
	0x70EE: 0xFFFD,
	0x70EF: 0xB26D,
	0x70F0: 0xD64E,
	0x70F1: 0x9549,
	0x70F2: 0xFFFD,
	0x70F3: 0xD650,
	0x70F4: 0xD64C,
	0x70F5: 0x9C40,
	0x70F6: 0xD658,
	0x70F7: 0xD64A,
	0x70F8: 0xD657,
	0x70F9: 0xB269,
	0x70FA: 0xD648,
	0x70FB: 0xDA5B,
	0x70FC: 0xD652,
	0x70FD: 0xB26C,
	0x70FE: 0x9C4B,
	0x70FF: 0xD653,
	0x7100: 0xD656,
	0x7101: 0xFFFD,
	0x7102: 0xD65A,
	0x7103: 0xFFFD,
	0x7104: 0xD64F,
	0x7105: 0x9C4C,
	0x7106: 0xD654,
	0x7107: 0xFFFD,
	0x7108: 0xFFFD,
	0x7109: 0xB26A,
	0x710A: 0xB26B,
	0x710B: 0xD659,
	0x710C: 0xD64D,
	0x710D: 0xD649,
	0x710E: 0xD65B,
	0x710F: 0xA078,
	0x7110: 0xD651,
	0x7111: 0xFFFD,
	0x7112: 0xFFFD,
	0x7113: 0xD655,
	0x7114: 0x8244,
	0x7115: 0x85E0,
	0x7116: 0x88FB,
	0x7117: 0xD64B,
	0x7118: 0x8AD9,
	0x7119: 0xB548,
	0x711A: 0xB549,
	0x711B: 0xDA65,
	0x711C: 0xB54F,
	0x711D: 0x9C4D,
	0x711E: 0xDA59,
	0x711F: 0xDA62,
	0x7120: 0xDA58,
	0x7121: 0xB54C,
	0x7122: 0xDA60,
	0x7123: 0xDA5E,
	0x7124: 0xFFFD,
	0x7125: 0xDA5F,
	0x7126: 0xB54A,
	0x7127: 0xFFFD,
	0x7128: 0xDA63,
	0x7129: 0x9C4E,
	0x712A: 0xFFFD,
	0x712B: 0x9C4F,
	0x712C: 0x9C50,
	0x712D: 0xFFFD,
	0x712E: 0xDA5C,
	0x712F: 0xDA5A,
	0x7130: 0xB54B,
	0x7131: 0xDA5D,
	0x7132: 0xDA61,
	0x7133: 0x9C51,
	0x7134: 0xFCA7,
	0x7135: 0x9C52,
	0x7136: 0xB54D,
	0x7137: 0xFFFD,
	0x7138: 0xFFFD,
	0x7139: 0xFFFD,
	0x713A: 0xDA64,
	0x713B: 0x9C53,
	0x713C: 0x92E5,
	0x713D: 0xFFFD,
	0x713E: 0x9C54,
	0x713F: 0xFE76,
	0x7140: 0x9C55,
	0x7141: 0xDE70,
	0x7142: 0xDE77,
	0x7143: 0xDE79,
	0x7144: 0xDEA1,
	0x7145: 0xFB66,
	0x7146: 0xB7DA,
	0x7147: 0xDE6B,
	0x7148: 0xFFFD,
	0x7149: 0xB7D2,
	0x714A: 0x954F,
	0x714B: 0xDE7A,
	0x714C: 0xB7D7,
	0x714D: 0xDEA2,
	0x714E: 0xB7CE,
	0x714F: 0x9C56,
	0x7150: 0xDE7D,
	0x7151: 0x955F,
	0x7152: 0xDE6D,
	0x7153: 0xDE7E,
	0x7154: 0xDE6C,
	0x7155: 0xA07A,
	0x7156: 0xB7DC,
	0x7157: 0x9DCD,
	0x7158: 0xDE78,
	0x7159: 0xB7CF,
	0x715A: 0xDEA3,
	0x715B: 0xFFFD,
	0x715C: 0xB7D4,
	0x715D: 0xDE71,
	0x715E: 0xB7D9,
	0x715F: 0xDE7C,
	0x7160: 0xDE6F,
	0x7161: 0xDE76,
	0x7162: 0xDE72,
	0x7163: 0xDE6E,
	0x7164: 0xB7D1,
	0x7165: 0xB7D8,
	0x7166: 0xB7D6,
	0x7167: 0xB7D3,
	0x7168: 0xB7DB,
	0x7169: 0xB7D0,
	0x716A: 0xDE75,
	0x716B: 0x9C57,
	0x716C: 0xB7D5,
	0x716D: 0xFFFD,
	0x716E: 0xB54E,
	0x716F: 0xFFFD,
	0x7170: 0xDE7B,
	0x7171: 0xFE53,
	0x7172: 0xDE73,
	0x7173: 0xA07B,
	0x7174: 0xFFFD,
	0x7175: 0x9C58,
	0x7176: 0xFCA9,
	0x7177: 0x9C59,
	0x7178: 0xDE74,
	0x7179: 0xFFFD,
	0x717A: 0xA07C,
	0x717B: 0xE2C1,
	0x717C: 0x9C5A,
	0x717D: 0xBAB4,
	0x717E: 0x9C5B,
	0x717F: 0xFFFD,
	0x7180: 0xE2BD,
	0x7181: 0xE2C3,
	0x7182: 0xE2BF,
	0x7183: 0xFFFD,
	0x7184: 0xBAB6,
	0x7185: 0xE2BE,
	0x7186: 0xE2C2,
	0x7187: 0xE2BA,
	0x7188: 0xA0D8,
	0x7189: 0xE2BC,
	0x718A: 0xBAB5,
	0x718B: 0xFFFD,
	0x718C: 0x9C5C,
	0x718D: 0xFFFD,
	0x718E: 0x9C5D,
	0x718F: 0xE2C0,
	0x7190: 0xE2BB,
	0x7191: 0x9C5E,
	0x7192: 0xBAB7,
	0x7193: 0xFFFD,
	0x7194: 0xBAB2,
	0x7195: 0x94AB,
	0x7196: 0x9C5F,
	0x7197: 0xE2C4,
	0x7198: 0xA0E7,
	0x7199: 0xBAB3,
	0x719A: 0xE667,
	0x719B: 0xE664,
	0x719C: 0xE670,
	0x719D: 0xE66A,
	0x719E: 0xE66C,
	0x719F: 0xBCF4,
	0x71A0: 0xE666,
	0x71A1: 0xE66E,
	0x71A2: 0x9C60,
	0x71A3: 0x9C61,
	0x71A4: 0xE66D,
	0x71A5: 0xE66B,
	0x71A6: 0xFFFD,
	0x71A7: 0xE671,
	0x71A8: 0xBCF7,
	0x71A9: 0xE668,
	0x71AA: 0xE66F,
	0x71AB: 0xFFFD,
	0x71AC: 0xBCF5,
	0x71AD: 0x9C62,
	0x71AE: 0xFFFD,
	0x71AF: 0xE663,
	0x71B0: 0xE665,
	0x71B1: 0xBCF6,
	0x71B2: 0xE662,
	0x71B3: 0xE672,
	0x71B4: 0x9C63,
	0x71B5: 0xE669,
	0x71B6: 0xFFFD,
	0x71B7: 0x9C64,
	0x71B8: 0xEA4A,
	0x71B9: 0xBF51,
	0x71BA: 0x9C65,
	0x71BB: 0xFFFD,
	0x71BC: 0xEA55,
	0x71BD: 0xEA53,
	0x71BE: 0xBF4B,
	0x71BF: 0xEA49,
	0x71C0: 0xEA4C,
	0x71C1: 0xEA4D,
	0x71C2: 0xEA48,
	0x71C3: 0xBF55,
	0x71C4: 0xBF56,
	0x71C5: 0xEA47,
	0x71C6: 0xEA56,
	0x71C7: 0xEA51,
	0x71C8: 0xBF4F,
	0x71C9: 0xBF4C,
	0x71CA: 0xEA50,
	0x71CB: 0xEA4E,
	0x71CC: 0xFFFD,
	0x71CD: 0xFFFD,
	0x71CE: 0xBF52,
	0x71CF: 0xEA52,
	0x71D0: 0xBF4D,
	0x71D1: 0x9C66,
	0x71D2: 0xBF4E,
	0x71D3: 0xFFFD,
	0x71D4: 0xEA4F,
	0x71D5: 0xBF50,
	0x71D6: 0xEA4B,
	0x71D7: 0xA0E8,
	0x71D8: 0xEA54,
	0x71D9: 0xBF53,
	0x71DA: 0xEA57,
	0x71DB: 0xEA58,
	0x71DC: 0xBF54,
	0x71DD: 0x9C67,
	0x71DE: 0xFFFD,
	0x71DF: 0xC0E7,
	0x71E0: 0xC0EE,
	0x71E1: 0xED5C,
	0x71E2: 0xED62,
	0x71E3: 0xFFFD,
	0x71E4: 0xED60,
	0x71E5: 0xC0EA,
	0x71E6: 0xC0E9,
	0x71E7: 0xC0E6,
	0x71E8: 0xED5E,
	0x71E9: 0xFFFD,
	0x71EA: 0xFFFD,
	0x71EB: 0x9C68,
	0x71EC: 0xC0EC,
	0x71ED: 0xC0EB,
	0x71EE: 0xC0E8,
	0x71EF: 0xFFFD,
	0x71F0: 0xED61,
	0x71F1: 0xED5D,
	0x71F2: 0xED5F,
	0x71F3: 0xFFFD,
	0x71F4: 0xC0ED,
	0x71F5: 0xA0F5,
	0x71F6: 0xFB70,
	0x71F7: 0xFFFD,
	0x71F8: 0xC277,
	0x71F9: 0xEFFB,
	0x71FA: 0xFFFD,
	0x71FB: 0xC274,
	0x71FC: 0xC275,
	0x71FD: 0xEFFD,
	0x71FE: 0xC276,
	0x71FF: 0xEFFA,
	0x7200: 0x9C69,
	0x7201: 0xEFF9,
	0x7202: 0xF26C,
	0x7203: 0xEFFC,
	0x7204: 0xFFFD,
	0x7205: 0xF26D,
	0x7206: 0xC37A,
	0x7207: 0xF26B,
	0x7208: 0xFFFD,
	0x7209: 0x9C6A,
	0x720A: 0xF26A,
	0x720B: 0xFFFD,
	0x720C: 0xF269,
	0x720D: 0xC37B,
	0x720E: 0x9C6B,
	0x720F: 0x9C6C,
	0x7210: 0xC46C,
	0x7211: 0xFFFD,
	0x7212: 0xFFFD,
	0x7213: 0xF46A,
	0x7214: 0xF46B,
	0x7215: 0xFCAC,
	0x7216: 0x9C6D,
	0x7217: 0x9C6E,
	0x7218: 0xFFFD,
	0x7219: 0xF5DC,
	0x721A: 0xF5DB,
	0x721B: 0xC4EA,
	0x721C: 0xFFFD,
	0x721D: 0xF5DA,
	0x721E: 0xF6EC,
	0x721F: 0xF6ED,
	0x7220: 0xFFFD,
	0x7221: 0xFFFD,
	0x7222: 0xF7E6,
	0x7223: 0xF8B1,
	0x7224: 0x9C6F,
	0x7225: 0x9D5A,
	0x7226: 0xF8F6,
	0x7227: 0xF9BC,
	0x7228: 0xC679,
	0x7229: 0xF9C6,
	0x722A: 0xA4F6,
	0x722B: 0x91C9,
	0x722C: 0xAAA6,
	0x722D: 0xAAA7,
	0x722E: 0x9C71,
	0x722F: 0xFFFD,
	0x7230: 0xACB8,
	0x7231: 0x85C6,
	0x7232: 0xFA64,
	0x7233: 0xFFFD,
	0x7234: 0xFFFD,
	0x7235: 0xC0EF,
	0x7236: 0xA4F7,
	0x7237: 0x85E1,
	0x7238: 0xAAA8,
	0x7239: 0xAF52,
	0x723A: 0xB7DD,
	0x723B: 0xA4F8,
	0x723C: 0xFA65,
	0x723D: 0xB26E,
	0x723E: 0xBAB8,
	0x723F: 0xC962,
	0x7240: 0x95A7,
	0x7241: 0xCFB7,
	0x7242: 0xD27D,
	0x7243: 0xFFFD,
	0x7244: 0xE2C5,
	0x7245: 0xFFFD,
	0x7246: 0xC0F0,
	0x7247: 0xA4F9,
	0x7248: 0xAAA9,
	0x7249: 0xCFB8,
	0x724A: 0xCFB9,
	0x724B: 0xDA66,
	0x724C: 0xB550,
	0x724D: 0x8BA4,
	0x724E: 0xFFFD,
	0x724F: 0xDEA4,
	0x7250: 0xFCAD,
	0x7251: 0xFFFD,
	0x7252: 0xB7DE,
	0x7253: 0xE2C6,
	0x7254: 0xFFFD,
	0x7255: 0x956E,
	0x7256: 0xBCF8,
	0x7257: 0x9C73,
	0x7258: 0xC37C,
	0x7259: 0xA4FA,
	0x725A: 0xDA67,
	0x725B: 0xA4FB,
	0x725C: 0x9C74,
	0x725D: 0xA6C9,
	0x725E: 0xCA42,
	0x725F: 0xA6C8,
	0x7260: 0xA865,
	0x7261: 0xA864,
	0x7262: 0xA863,
	0x7263: 0xCB60,
	0x7264: 0xFFFD,
	0x7265: 0xFFFD,
	0x7266: 0xFA66,
	0x7267: 0xAAAA,
	0x7268: 0xFFFD,
	0x7269: 0xAAAB,
	0x726A: 0xCD5B,
	0x726B: 0xFFFD,
	0x726C: 0xCFBA,
	0x726D: 0xFFFD,
	0x726E: 0xCFBD,
	0x726F: 0xACBA,
	0x7270: 0xCFBB,
	0x7271: 0xFFFD,
	0x7272: 0xACB9,
	0x7273: 0xCFBC,
	0x7274: 0xACBB,
	0x7275: 0x8461,
	0x7276: 0xD2A2,
	0x7277: 0xD2A1,
	0x7278: 0xD27E,
	0x7279: 0xAF53,
	0x727A: 0x8C7B,
	0x727B: 0xD65D,
	0x727C: 0xD65E,
	0x727D: 0xB26F,
	0x727E: 0xD65C,
	0x727F: 0xD65F,
	0x7280: 0xB552,
	0x7281: 0xB270,
	0x7282: 0xFA67,
	0x7283: 0xFFFD,
	0x7284: 0xB551,
	0x7285: 0xDA6B,
	0x7286: 0xDA6A,
	0x7287: 0xFCAE,
	0x7288: 0xDA68,
	0x7289: 0xDA69,
	0x728A: 0x8BA5,
	0x728B: 0xDA6C,
	0x728C: 0xDEA6,
	0x728D: 0xDEA5,
	0x728E: 0xDEA9,
	0x728F: 0xFA68,
	0x7290: 0xDEA8,
	0x7291: 0xDEA7,
	0x7292: 0xBAB9,
	0x7293: 0xE2C9,
	0x7294: 0x9C75,
	0x7295: 0xE2C8,
	0x7296: 0xBABA,
	0x7297: 0xE2C7,
	0x7298: 0xE673,
	0x7299: 0xFFFD,
	0x729A: 0xE674,
	0x729B: 0xBCF9,
	0x729C: 0xFFFD,
	0x729D: 0xEA59,
	0x729E: 0xEA5A,
	0x729F: 0xFA69,
	0x72A0: 0x9271,
	0x72A1: 0xF272,
	0x72A2: 0xC37D,
	0x72A3: 0xF271,
	0x72A4: 0xF270,
	0x72A5: 0xF26E,
	0x72A6: 0xF26F,
	0x72A7: 0xC4EB,
	0x72A8: 0xF46C,
	0x72A9: 0xF6EE,
	0x72AA: 0xF8F7,
	0x72AB: 0xFFFD,
	0x72AC: 0xA4FC,
	0x72AD: 0xFA6A,
	0x72AE: 0xC9A5,
	0x72AF: 0xA5C7,
	0x72B0: 0xC9A6,
	0x72B1: 0xFA6B,
	0x72B2: 0xFCB0,
	0x72B3: 0xFFFD,
	0x72B4: 0xCA43,
	0x72B5: 0xCA44,
	0x72B6: 0x835D,
	0x72B7: 0x8ADA,
	0x72B8: 0xFA6C,
	0x72B9: 0x84F6,
	0x72BA: 0xCB66,
	0x72BB: 0xFFFD,
	0x72BC: 0xFFFD,
	0x72BD: 0xCB62,
	0x72BE: 0xFA6D,
	0x72BF: 0xCB61,
	0x72C0: 0xAAAC,
	0x72C1: 0xCB65,
	0x72C2: 0xA867,
	0x72C3: 0xCB63,
	0x72C4: 0xA866,
	0x72C5: 0xCB67,
	0x72C6: 0xCB64,
	0x72C7: 0xFFFD,
	0x72C8: 0x83C1,
	0x72C9: 0xCD5F,
	0x72CA: 0xCFBE,
	0x72CB: 0xCD5D,
	0x72CC: 0xCD64,
	0x72CD: 0xFA6E,
	0x72CE: 0xAAAD,
	0x72CF: 0xFFFD,
	0x72D0: 0xAAB0,
	0x72D1: 0xCD65,
	0x72D2: 0xCD61,
	0x72D3: 0xFFFD,
	0x72D4: 0xCD62,
	0x72D5: 0xFFFD,
	0x72D6: 0xCD5C,
	0x72D7: 0xAAAF,
	0x72D8: 0xCD5E,
	0x72D9: 0xAAAE,
	0x72DA: 0xCD63,
	0x72DB: 0xFA6F,
	0x72DC: 0xCD60,
	0x72DD: 0xFFFD,
	0x72DE: 0x89F6,
	0x72DF: 0xCFC2,
	0x72E0: 0xACBD,
	0x72E1: 0xACBE,
	0x72E2: 0xFCB1,
	0x72E3: 0xCFC5,
	0x72E4: 0xCFBF,
	0x72E5: 0xFFFD,
	0x72E6: 0xCFC4,
	0x72E7: 0xFFFD,
	0x72E8: 0xCFC0,
	0x72E9: 0xACBC,
	0x72EA: 0xCFC3,
	0x72EB: 0xCFC1,
	0x72EC: 0x88FC,
	0x72ED: 0x83C0,
	0x72EE: 0x85E2,
	0x72EF: 0x8EEC,
	0x72F0: 0x8462,
	0x72F1: 0x86E2,
	0x72F2: 0x8E47,
	0x72F3: 0xD2A8,
	0x72F4: 0xD2A5,
	0x72F5: 0xFFFD,
	0x72F6: 0xD2A7,
	0x72F7: 0xAF58,
	0x72F8: 0xAF57,
	0x72F9: 0xAF55,
	0x72FA: 0xD2A4,
	0x72FB: 0xD2A9,
	0x72FC: 0xAF54,
	0x72FD: 0xAF56,
	0x72FE: 0xD2A6,
	0x72FF: 0xD667,
	0x7300: 0xD2A3,
	0x7301: 0xD2AA,
	0x7302: 0xFCB2,
	0x7303: 0x8EEB,
	0x7304: 0x9C76,
	0x7305: 0xFFFD,
	0x7306: 0xFFFD,
	0x7307: 0xD662,
	0x7308: 0xD666,
	0x7309: 0xFFFD,
	0x730A: 0xD665,
	0x730B: 0xDA6E,
	0x730C: 0xDA79,
	0x730D: 0xFFFD,
	0x730E: 0x8ADB,
	0x730F: 0xD668,
	0x7310: 0x9C77,
	0x7311: 0xD663,
	0x7312: 0xDA6D,
	0x7313: 0xB274,
	0x7314: 0xFFFD,
	0x7315: 0x8F55,
	0x7316: 0xB273,
	0x7317: 0xD661,
	0x7318: 0xD664,
	0x7319: 0xB275,
	0x731A: 0xFFFD,
	0x731B: 0xB272,
	0x731C: 0xB271,
	0x731D: 0xD660,
	0x731E: 0xD669,
	0x731F: 0x93E6,
	0x7320: 0xFFFD,
	0x7321: 0x8CD3,
	0x7322: 0xDA70,
	0x7323: 0xDA77,
	0x7324: 0xFA70,
	0x7325: 0xB554,
	0x7326: 0xDA76,
	0x7327: 0xDA73,
	0x7328: 0xFCB4,
	0x7329: 0xB556,
	0x732A: 0x95BD,
	0x732B: 0x95BC,
	0x732C: 0xFCAF,
	0x732D: 0xDA75,
	0x732E: 0x9552,
	0x732F: 0xFA71,
	0x7330: 0xDA6F,
	0x7331: 0xDA71,
	0x7332: 0xDA74,
	0x7333: 0xDA72,
	0x7334: 0xB555,
	0x7335: 0xDA78,
	0x7336: 0xB553,
	0x7337: 0xB7DF,
	0x7338: 0xFA72,
	0x7339: 0xFA73,
	0x733A: 0xDEAD,
	0x733B: 0xDEAC,
	0x733C: 0xDEAA,
	0x733D: 0xFFFD,
	0x733E: 0xB7E2,
	0x733F: 0xB7E1,
	0x7340: 0xDEAE,
	0x7341: 0x9C78,
	0x7342: 0xDEAB,
	0x7343: 0xE2CA,
	0x7344: 0xBABB,
	0x7345: 0xB7E0,
	0x7346: 0xFFFD,
	0x7347: 0xFFFD,
	0x7348: 0xFCB3,
	0x7349: 0xDEB0,
	0x734A: 0xDEAF,
	0x734B: 0xFFFD,
	0x734C: 0xE2CD,
	0x734D: 0xE2CB,
	0x734E: 0xBCFA,
	0x734F: 0xFCB5,
	0x7350: 0xBABC,
	0x7351: 0xE2CC,
	0x7352: 0xE676,
	0x7353: 0xFFFD,
	0x7354: 0xFFFD,
	0x7355: 0xFFFD,
	0x7356: 0xFFFD,
	0x7357: 0xBCFB,
	0x7358: 0xE675,
	0x7359: 0xE67E,
	0x735A: 0xE67D,
	0x735B: 0xE67B,
	0x735C: 0xFFFD,
	0x735D: 0xE67A,
	0x735E: 0xE677,
	0x735F: 0xE678,
	0x7360: 0xE679,
	0x7361: 0xE67C,
	0x7362: 0xE6A1,
	0x7363: 0x92DE,
	0x7364: 0xFFFD,
	0x7365: 0xEA5F,
	0x7366: 0xEA5C,
	0x7367: 0xEA5D,
	0x7368: 0xBF57,
	0x7369: 0xEA5B,
	0x736A: 0xEA61,
	0x736B: 0xEA60,
	0x736C: 0xEA5E,
	0x736D: 0x8BA7,
	0x736E: 0xED64,
	0x736F: 0xED65,
	0x7370: 0xC0F1,
	0x7371: 0xFCB6,
	0x7372: 0xC0F2,
	0x7373: 0xED63,
	0x7374: 0x9C79,
	0x7375: 0xC279,
	0x7376: 0xEFFE,
	0x7377: 0xC278,
	0x7378: 0xC37E,
	0x7379: 0xFFFD,
	0x737A: 0xC3A1,
	0x737B: 0xC46D,
	0x737C: 0xF46E,
	0x737D: 0xF46D,
	0x737E: 0xF5DD,
	0x737F: 0xF6EF,
	0x7380: 0xC57A,
	0x7381: 0xF7E8,
	0x7382: 0xF7E7,
	0x7383: 0xF7E9,
	0x7384: 0xA5C8,
	0x7385: 0xCFC6,
	0x7386: 0xAF59,
	0x7387: 0xB276,
	0x7388: 0xD66A,
	0x7389: 0xA5C9,
	0x738A: 0xC9A7,
	0x738B: 0xA4FD,
	0x738C: 0x9C7A,
	0x738D: 0xFFFD,
	0x738E: 0xCA45,
	0x738F: 0x9C7B,
	0x7390: 0xFFFD,
	0x7391: 0x88FD,
	0x7392: 0xCB6C,
	0x7393: 0xCB6A,
	0x7394: 0xCB6B,
	0x7395: 0xCB68,
	0x7396: 0xA868,
	0x7397: 0xCB69,
	0x7398: 0x9C7C,
	0x7399: 0xFFFD,
	0x739A: 0xFFFD,
	0x739B: 0x86E4,
	0x739C: 0x9C7D,
	0x739D: 0xCD6D,
	0x739E: 0x9C7E,
	0x739F: 0xAAB3,
	0x73A0: 0xCD6B,
	0x73A1: 0xCD67,
	0x73A2: 0xCD6A,
	0x73A3: 0xFFFD,
	0x73A4: 0xCD66,
	0x73A5: 0xAAB5,
	0x73A6: 0xCD69,
	0x73A7: 0x9CA1,
	0x73A8: 0xAAB2,
	0x73A9: 0xAAB1,
	0x73AA: 0x9CA2,
	0x73AB: 0xAAB4,
	0x73AC: 0xCD6C,
	0x73AD: 0xCD68,
	0x73AE: 0x8E48,
	0x73AF: 0x89F8,
	0x73B0: 0x8463,
	0x73B1: 0xFFFD,
	0x73B2: 0xACC2,
	0x73B3: 0xACC5,
	0x73B4: 0xCFCE,
	0x73B5: 0xCFCD,
	0x73B6: 0xCFCC,
	0x73B7: 0xACBF,
	0x73B8: 0xCFD5,
	0x73B9: 0xCFCB,
	0x73BA: 0x8BA8,
	0x73BB: 0xACC1,
	0x73BC: 0xD2AF,
	0x73BD: 0xFA74,
	0x73BE: 0xCFD2,
	0x73BF: 0xCFD0,
	0x73C0: 0xACC4,
	0x73C1: 0xFFFD,
	0x73C2: 0xCFC8,
	0x73C3: 0xCFD3,
	0x73C4: 0xFFFD,
	0x73C5: 0xCFCA,
	0x73C6: 0xCFD4,
	0x73C7: 0xCFD1,
	0x73C8: 0xCFC9,
	0x73C9: 0x95BE,
	0x73CA: 0xACC0,
	0x73CB: 0xCFD6,
	0x73CC: 0xCFC7,
	0x73CD: 0xACC3,
	0x73CE: 0xFA75,
	0x73CF: 0x95B6,
	0x73D0: 0x90B2,
	0x73D1: 0x8BFD,
	0x73D2: 0xD2B4,
	0x73D3: 0xD2AB,
	0x73D4: 0xD2B6,
	0x73D5: 0x9CA3,
	0x73D6: 0xD2AE,
	0x73D7: 0xD2B9,
	0x73D8: 0xD2BA,
	0x73D9: 0xD2AC,
	0x73DA: 0xD2B8,
	0x73DB: 0xD2B5,
	0x73DC: 0xD2B3,
	0x73DD: 0xD2B7,
	0x73DE: 0xAF5F,
	0x73DF: 0xFFFD,
	0x73E0: 0xAF5D,
	0x73E1: 0x9CA4,
	0x73E2: 0x9CA5,
	0x73E3: 0xD2B1,
	0x73E4: 0x9CA6,
	0x73E5: 0xD2AD,
	0x73E6: 0x9CA7,
	0x73E7: 0xD2B0,
	0x73E8: 0xD2BB,
	0x73E9: 0xD2B2,
	0x73EA: 0xAF5E,
	0x73EB: 0xCFCF,
	0x73EC: 0xFFFD,
	0x73ED: 0xAF5A,
	0x73EE: 0xAF5C,
	0x73EF: 0x9CA8,
	0x73F0: 0xFFFD,
	0x73F1: 0xFA76,
	0x73F2: 0x85E4,
	0x73F3: 0x9CA9,
	0x73F4: 0xD678,
	0x73F5: 0xD66D,
	0x73F6: 0xD66B,
	0x73F7: 0xFEAA,
	0x73F8: 0xD66C,
	0x73F9: 0x9CAB,
	0x73FA: 0xD673,
	0x73FB: 0x9CAC,
	0x73FC: 0xD674,
	0x73FD: 0xD670,
	0x73FE: 0xB27B,
	0x73FF: 0xD675,
	0x7400: 0xD672,
	0x7401: 0xD66F,
	0x7402: 0x9CAD,
	0x7403: 0xB279,
	0x7404: 0xD66E,
	0x7405: 0xB277,
	0x7406: 0xB27A,
	0x7407: 0xD671,
	0x7408: 0xD679,
	0x7409: 0xAF5B,
	0x740A: 0xB278,
	0x740B: 0xD677,
	0x740C: 0xD676,
	0x740D: 0xB27C,
	0x740E: 0xFFFD,
	0x740F: 0x8EBF,
	0x7410: 0x86E3,
	0x7411: 0x9CAE,
	0x7412: 0x9CAF,
	0x7413: 0xFFFD,
	0x7414: 0x9CB0,
	0x7415: 0x9CB1,
	0x7416: 0xDA7E,
	0x7417: 0x9CB2,
	0x7418: 0xFFFD,
	0x7419: 0x9CB3,
	0x741A: 0xDAA1,
	0x741B: 0xB560,
	0x741C: 0x9CB4,
	0x741D: 0xDAA7,
	0x741E: 0x9CB5,
	0x741F: 0x9CB6,
	0x7420: 0xDAA9,
	0x7421: 0xDAA2,
	0x7422: 0xB55A,
	0x7423: 0xDAA6,
	0x7424: 0xDAA5,
	0x7425: 0xB55B,
	0x7426: 0xB561,
	0x7427: 0xFFFD,
	0x7428: 0xB562,
	0x7429: 0xDAA8,
	0x742A: 0xB558,
	0x742B: 0xDA7D,
	0x742C: 0xDA7B,
	0x742D: 0xDAA3,
	0x742E: 0xDA7A,
	0x742F: 0xB55F,
	0x7430: 0xDA7C,
	0x7431: 0xDAA4,
	0x7432: 0xDAAA,
	0x7433: 0xB559,
	0x7434: 0xB55E,
	0x7435: 0xB55C,
	0x7436: 0xB55D,
	0x7437: 0x9CB7,
	0x7438: 0x9CB8,
	0x7439: 0x9CB9,
	0x743A: 0xB557,
	0x743B: 0xFFFD,
	0x743C: 0x8BA9,
	0x743D: 0xFFFD,
	0x743E: 0xFFFD,
	0x743F: 0xB7E9,
	0x7440: 0xDEB7,
	0x7441: 0xB7E8,
	0x7442: 0xDEBB,
	0x7443: 0x9CBA,
	0x7444: 0xDEB1,
	0x7445: 0x9CBB,
	0x7446: 0xDEBC,
	0x7447: 0x9CBC,
	0x7448: 0x9CBD,
	0x7449: 0x9CBE,
	0x744A: 0xDEB2,
	0x744B: 0xDEB3,
	0x744C: 0xFFFD,
	0x744D: 0xDEBD,
	0x744E: 0xDEBA,
	0x744F: 0xDEB8,
	0x7450: 0xDEB9,
	0x7451: 0xDEB5,
	0x7452: 0xDEB4,
	0x7453: 0x9CBF,
	0x7454: 0xDEBE,
	0x7455: 0xB7E5,
	0x7456: 0x9CC0,
	0x7457: 0xDEB6,
	0x7458: 0xFFFD,
	0x7459: 0xB7EA,
	0x745A: 0xB7E4,
	0x745B: 0xB7EB,
	0x745C: 0xB7EC,
	0x745D: 0xFCB9,
	0x745E: 0xB7E7,
	0x745F: 0xB7E6,
	0x7460: 0xFE75,
	0x7461: 0x9D73,
	0x7462: 0xE2CE,
	0x7463: 0xBABE,
	0x7464: 0xBABD,
	0x7465: 0x9CC1,
	0x7466: 0xFFFD,
	0x7467: 0xE2D3,
	0x7468: 0xFEAC,
	0x7469: 0xBCFC,
	0x746A: 0xBABF,
	0x746B: 0x9CC2,
	0x746C: 0x9CC3,
	0x746D: 0xBAC1,
	0x746E: 0xE2D4,
	0x746F: 0xB7E3,
	0x7470: 0xBAC0,
	0x7471: 0xE2D0,
	0x7472: 0xE2D2,
	0x7473: 0xE2CF,
	0x7474: 0x9CC4,
	0x7475: 0xE2D1,
	0x7476: 0xFA77,
	0x7477: 0x89F9,
	0x7478: 0xFFFD,
	0x7479: 0xE6AB,
	0x747A: 0x9CC5,
	0x747B: 0xFFFD,
	0x747C: 0xE6AA,
	0x747D: 0xE6A7,
	0x747E: 0xBD40,
	0x747F: 0xEA62,
	0x7480: 0xBD41,
	0x7481: 0xE6A6,
	0x7482: 0x9CC6,
	0x7483: 0xBCFE,
	0x7484: 0xFFFD,
	0x7485: 0xE6A8,
	0x7486: 0xE6A5,
	0x7487: 0xE6A2,
	0x7488: 0xE6A9,
	0x7489: 0xE6A3,
	0x748A: 0xE6A4,
	0x748B: 0xBCFD,
	0x748C: 0x81D0,
	0x748D: 0x81D1,
	0x748E: 0x8C7D,
	0x748F: 0xFFFD,
	0x7490: 0xED69,
	0x7491: 0xFFFD,
	0x7492: 0xEA66,
	0x7493: 0xFFFD,
	0x7494: 0xEA65,
	0x7495: 0xEA67,
	0x7496: 0xFFFD,
	0x7497: 0xED66,
	0x7498: 0xBF5A,
	0x7499: 0x81D2,
	0x749A: 0xEA63,
	0x749B: 0x81D3,
	0x749C: 0xBF58,
	0x749D: 0x9D74,
	0x749E: 0xBF5C,
	0x749F: 0xBF5B,
	0x74A0: 0xEA64,
	0x74A1: 0xEA68,
	0x74A2: 0xFA78,
	0x74A3: 0xBF59,
	0x74A4: 0x81D4,
	0x74A5: 0xED6D,
	0x74A6: 0xC0F5,
	0x74A7: 0xC27A,
	0x74A8: 0xC0F6,
	0x74A9: 0xC0F3,
	0x74AA: 0xED6A,
	0x74AB: 0xED68,
	0x74AC: 0xFFFD,
	0x74AD: 0xED6B,
	0x74AE: 0xFFFD,
	0x74AF: 0xED6E,
	0x74B0: 0xC0F4,
	0x74B1: 0xED6C,
	0x74B2: 0xED67,
	0x74B3: 0xFFFD,
	0x74B4: 0x81D5,
	0x74B5: 0xF042,
	0x74B6: 0xF045,
	0x74B7: 0xF275,
	0x74B8: 0xF040,
	0x74B9: 0x81D6,
	0x74BA: 0xF46F,
	0x74BB: 0xF046,
	0x74BC: 0xFFFD,
	0x74BD: 0xC3A2,
	0x74BE: 0xF044,
	0x74BF: 0xC27B,
	0x74C0: 0xF041,
	0x74C1: 0xF043,
	0x74C2: 0xF047,
	0x74C3: 0xF276,
	0x74C4: 0xFFFD,
	0x74C5: 0xF274,
	0x74C6: 0xFFFD,
	0x74C7: 0xFFFD,
	0x74C8: 0x81D7,
	0x74C9: 0xFFFD,
	0x74CA: 0xC3A3,
	0x74CB: 0xF273,
	0x74CC: 0x81D8,
	0x74CD: 0xFFFD,
	0x74CE: 0xFFFD,
	0x74CF: 0xC46E,
	0x74D0: 0x81D9,
	0x74D1: 0xFFFD,
	0x74D2: 0x8CF9,
	0x74D3: 0x81DA,
	0x74D4: 0xC4ED,
	0x74D5: 0xF6F1,
	0x74D6: 0xC4EC,
	0x74D7: 0xF6F3,
	0x74D8: 0xF6F0,
	0x74D9: 0xF6F2,
	0x74DA: 0xC5D0,
	0x74DB: 0xF8B2,
	0x74DC: 0xA5CA,
	0x74DD: 0xCD6E,
	0x74DE: 0xD2BC,
	0x74DF: 0xD2BD,
	0x74E0: 0xB27D,
	0x74E1: 0xDEBF,
	0x74E2: 0xBF5D,
	0x74E3: 0xC3A4,
	0x74E4: 0xC57B,
	0x74E5: 0xF8B3,
	0x74E6: 0xA5CB,
	0x74E7: 0x94AC,
	0x74E8: 0xCD6F,
	0x74E9: 0xA260,
	0x74EA: 0xFFFD,
	0x74EB: 0xFFFD,
	0x74EC: 0xCFD7,
	0x74ED: 0xFFFD,
	0x74EE: 0xCFD8,
	0x74EF: 0x88FE,
	0x74F0: 0x94AE,
	0x74F1: 0x94AF,
	0x74F2: 0x94AD,
	0x74F3: 0xFFFD,
	0x74F4: 0xD2BE,
	0x74F5: 0xD2BF,
	0x74F6: 0xB27E,
	0x74F7: 0xB2A1,
	0x74F8: 0x94B0,
	0x74F9: 0xFFFD,
	0x74FA: 0xFFFD,
	0x74FB: 0xDAAB,
	0x74FC: 0xFFFD,
	0x74FD: 0xDEC2,
	0x74FE: 0xDEC1,
	0x74FF: 0xDEC0,
	0x7500: 0xE2D5,
	0x7501: 0xFA79,
	0x7502: 0xE2D6,
	0x7503: 0xE2D7,
	0x7504: 0xBAC2,
	0x7505: 0x94B1,
	0x7506: 0xFFFD,
	0x7507: 0xE6AD,
	0x7508: 0xE6AC,
	0x7509: 0xFFFD,
	0x750A: 0xFFFD,
	0x750B: 0xEA69,
	0x750C: 0xBF5E,
	0x750D: 0xBF5F,
	0x750E: 0x95C2,
	0x750F: 0xED72,
	0x7510: 0xED6F,
	0x7511: 0xED70,
	0x7512: 0xED71,
	0x7513: 0xF049,
	0x7514: 0xF048,
	0x7515: 0xC27C,
	0x7516: 0xF277,
	0x7517: 0xF5DE,
	0x7518: 0xA5CC,
	0x7519: 0xFA7A,
	0x751A: 0xACC6,
	0x751B: 0xFFFD,
	0x751C: 0xB2A2,
	0x751D: 0xDEC3,
	0x751E: 0xFCBB,
	0x751F: 0xA5CD,
	0x7520: 0xFFFD,
	0x7521: 0xD2C0,
	0x7522: 0xB2A3,
	0x7523: 0xFA7B,
	0x7524: 0xFFFD,
	0x7525: 0xB563,
	0x7526: 0xB564,
	0x7527: 0xFFFD,
	0x7528: 0xA5CE,
	0x7529: 0xA5CF,
	0x752A: 0xCA46,
	0x752B: 0xA86A,
	0x752C: 0xA869,
	0x752D: 0xACC7,
	0x752E: 0xCFD9,
	0x752F: 0xDAAC,
	0x7530: 0xA5D0,
	0x7531: 0xA5D1,
	0x7532: 0xA5D2,
	0x7533: 0xA5D3,
	0x7534: 0xA059,
	0x7535: 0x867A,
	0x7536: 0xFFFD,
	0x7537: 0xA86B,
	0x7538: 0xA86C,
	0x7539: 0xCB6E,
	0x753A: 0xCB6D,
	0x753B: 0x84F8,
	0x753C: 0xFA7C,
	0x753D: 0xAAB6,
	0x753E: 0xCD72,
	0x753F: 0xCD70,
	0x7540: 0xCD71,
	0x7541: 0xFFFD,
	0x7542: 0x81DB,
	0x7543: 0xFFFD,
	0x7544: 0xFA7D,
	0x7545: 0x86D0,
	0x7546: 0xFBD1,
	0x7547: 0xCFDA,
	0x7548: 0xCFDB,
	0x7549: 0xFA7E,
	0x754A: 0x95BF,
	0x754B: 0xACCB,
	0x754C: 0xACC9,
	0x754D: 0xFAA1,
	0x754E: 0xACCA,
	0x754F: 0xACC8,
	0x7550: 0xFFFD,
	0x7551: 0x9455,
	0x7552: 0xFFFD,
	0x7553: 0xFCBC,
	0x7554: 0xAF60,
	0x7555: 0x81DC,
	0x7556: 0xFFFD,
	0x7557: 0xFFFD,
	0x7558: 0xFFFD,
	0x7559: 0xAF64,
	0x755A: 0xAF63,
	0x755B: 0xD2C1,
	0x755C: 0xAF62,
	0x755D: 0xAF61,
	0x755E: 0xFFFD,
	0x755F: 0xD2C2,
	0x7560: 0x9456,
	0x7561: 0xFFFD,
	0x7562: 0xB2A6,
	0x7563: 0xD67B,
	0x7564: 0xD67A,
	0x7565: 0xB2A4,
	0x7566: 0xB2A5,
	0x7567: 0x95CC,
	0x7568: 0xFFFD,
	0x7569: 0x94B2,
	0x756A: 0xB566,
	0x756B: 0xB565,
	0x756C: 0xDAAE,
	0x756D: 0xFAA2,
	0x756E: 0x81DD,
	0x756F: 0xDAAD,
	0x7570: 0xB2A7,
	0x7571: 0xFFFD,
	0x7572: 0x8DE2,
	0x7573: 0x92EC,
	0x7574: 0x8BAA,
	0x7575: 0xFFFD,
	0x7576: 0xB7ED,
	0x7577: 0xDEC5,
	0x7578: 0xB7EE,
	0x7579: 0xDEC4,
	0x757A: 0xFCBD,
	0x757B: 0xFFFD,
	0x757C: 0xFFFD,
	0x757D: 0xE2D8,
	0x757E: 0xE6AE,
	0x757F: 0xBD42,
	0x7580: 0xEA6A,
	0x7581: 0xFFFD,
	0x7582: 0xFAA3,
	0x7583: 0xFAA4,
	0x7584: 0xED73,
	0x7585: 0xFFFD,
	0x7586: 0xC3A6,
	0x7587: 0xC3A5,
	0x7588: 0xFFFD,
	0x7589: 0xFAA5,
	0x758A: 0xC57C,
	0x758B: 0xA5D4,
	0x758C: 0xCD73,
	0x758D: 0x81DE,
	0x758E: 0x9351,
	0x758F: 0xB2A8,
	0x7590: 0xE2D9,
	0x7591: 0xBAC3,
	0x7592: 0xC6D4,
	0x7593: 0xFFFD,
	0x7594: 0xCB6F,
	0x7595: 0xCB70,
	0x7596: 0x8F78,
	0x7597: 0x89FB,
	0x7598: 0xCD74,
	0x7599: 0xAAB8,
	0x759A: 0xAAB9,
	0x759B: 0xFFFD,
	0x759C: 0xFFFD,
	0x759D: 0xAAB7,
	0x759E: 0x81DF,
	0x759F: 0x86E5,
	0x75A0: 0x8ADD,
	0x75A1: 0x86E6,
	0x75A2: 0xACCF,
	0x75A3: 0xACD0,
	0x75A4: 0xACCD,
	0x75A5: 0xACCE,
	0x75A6: 0xFFFD,
	0x75A7: 0xCFDC,
	0x75A8: 0xFFFD,
	0x75A9: 0xFFFD,
	0x75AA: 0xCFDD,
	0x75AB: 0xACCC,
	0x75AC: 0xFAA6,
	0x75AD: 0xFFFD,
	0x75AE: 0x87F4,
	0x75AF: 0x86E7,
	0x75B0: 0xD2C3,
	0x75B1: 0xFE51,
	0x75B2: 0xAF68,
	0x75B3: 0xAF69,
	0x75B4: 0xFB5C,
	0x75B5: 0xB2AB,
	0x75B6: 0xD2C9,
	0x75B7: 0xFFFD,
	0x75B8: 0xAF6E,
	0x75B9: 0xAF6C,
	0x75BA: 0xD2CA,
	0x75BB: 0xD2C5,
	0x75BC: 0xAF6B,
	0x75BD: 0xAF6A,
	0x75BE: 0xAF65,
	0x75BF: 0xD2C8,
	0x75C0: 0xD2C7,
	0x75C1: 0xD2C4,
	0x75C2: 0xAF6D,
	0x75C3: 0xFCD3,
	0x75C4: 0xD2C6,
	0x75C5: 0xAF66,
	0x75C6: 0xFFFD,
	0x75C7: 0xAF67,
	0x75C8: 0x8FFD,
	0x75C9: 0x84F9,
	0x75CA: 0xB2AC,
	0x75CB: 0xD6A1,
	0x75CC: 0xD6A2,
	0x75CD: 0xB2AD,
	0x75CE: 0xD67C,
	0x75CF: 0xD67E,
	0x75D0: 0xD6A4,
	0x75D1: 0xD6A3,
	0x75D2: 0xD67D,
	0x75D3: 0xFFFD,
	0x75D4: 0xB2A9,
	0x75D5: 0xB2AA,
	0x75D6: 0xFAA7,
	0x75D7: 0xDAB6,
	0x75D8: 0xB56B,
	0x75D9: 0xB56A,
	0x75DA: 0xDAB0,
	0x75DB: 0xB568,
	0x75DC: 0x81E0,
	0x75DD: 0xDAB3,
	0x75DE: 0xB56C,
	0x75DF: 0xDAB4,
	0x75E0: 0xB56D,
	0x75E1: 0xDAB1,
	0x75E2: 0xB567,
	0x75E3: 0xB569,
	0x75E4: 0xDAB5,
	0x75E5: 0xFFFD,
	0x75E6: 0xDAB2,
	0x75E7: 0xDAAF,
	0x75E8: 0x89FA,
	0x75E9: 0xFAA8,
	0x75EA: 0x86E8,
	0x75EB: 0x8F58,
	0x75EC: 0xFFFD,
	0x75ED: 0xDED2,
	0x75EE: 0xFFFD,
	0x75EF: 0xDEC7,
	0x75F0: 0xB7F0,
	0x75F1: 0xB7F3,
	0x75F2: 0xB7F2,
	0x75F3: 0xB7F7,
	0x75F4: 0xB7F6,
	0x75F5: 0xDED3,
	0x75F6: 0xDED1,
	0x75F7: 0xDECA,
	0x75F8: 0xDECE,
	0x75F9: 0xDECD,
	0x75FA: 0xB7F4,
	0x75FB: 0xDED0,
	0x75FC: 0xDECC,
	0x75FD: 0xDED4,
	0x75FE: 0xDECB,
	0x75FF: 0xB7F5,
	0x7600: 0xB7EF,
	0x7601: 0xB7F1,
	0x7602: 0xFCD5,
	0x7603: 0xDEC9,
	0x7604: 0xFFFD,
	0x7605: 0x8F57,
	0x7606: 0xFFFD,
	0x7607: 0xFCD4,
	0x7608: 0xE2DB,
	0x7609: 0xBAC7,
	0x760A: 0xE2DF,
	0x760B: 0xBAC6,
	0x760C: 0xE2DC,
	0x760D: 0xBAC5,
	0x760E: 0xFFFD,
	0x760F: 0xDEC8,
	0x7610: 0xDECF,
	0x7611: 0xE2DE,
	0x7612: 0xFFFD,
	0x7613: 0xBAC8,
	0x7614: 0xE2E0,
	0x7615: 0xE2DD,
	0x7616: 0xE2DA,
	0x7617: 0x8EC1,
	0x7618: 0x8940,
	0x7619: 0xE6B1,
	0x761A: 0xE6B5,
	0x761B: 0xE6B7,
	0x761C: 0xE6B3,
	0x761D: 0xE6B2,
	0x761E: 0xE6B0,
	0x761F: 0xBD45,
	0x7620: 0xBD43,
	0x7621: 0xBD48,
	0x7622: 0xBD49,
	0x7623: 0xE6B4,
	0x7624: 0xBD46,
	0x7625: 0xE6AF,
	0x7626: 0xBD47,
	0x7627: 0xBAC4,
	0x7628: 0xE6B6,
	0x7629: 0xBD44,
	0x762A: 0x8BAB,
	0x762B: 0x8D54,
	0x762C: 0x81E1,
	0x762D: 0xEA6C,
	0x762E: 0xFFFD,
	0x762F: 0xEA6B,
	0x7630: 0xEA73,
	0x7631: 0xEA6D,
	0x7632: 0xEA72,
	0x7633: 0xEA6F,
	0x7634: 0xBF60,
	0x7635: 0xEA71,
	0x7636: 0xFFFD,
	0x7637: 0xFFFD,
	0x7638: 0xBF61,
	0x7639: 0xFFFD,
	0x763A: 0xBF62,
	0x763B: 0x95A9,
	0x763C: 0xEA70,
	0x763D: 0xEA6E,
	0x763E: 0x8CD5,
	0x763F: 0x9058,
	0x7640: 0xFAA9,
	0x7641: 0xFFFD,
	0x7642: 0xC0F8,
	0x7643: 0xED74,
	0x7644: 0xFFFD,
	0x7645: 0xFFFD,
	0x7646: 0xC0F7,
	0x7647: 0xED77,
	0x7648: 0xED75,
	0x7649: 0xED76,
	0x764A: 0xFFFD,
	0x764B: 0xFFFD,
	0x764C: 0xC0F9,
	0x764D: 0xFAAA,
	0x764E: 0x956F,
	0x764F: 0x81E2,
	0x7650: 0xF04D,
	0x7651: 0x81E3,
	0x7652: 0xC2A1,
	0x7653: 0xF04E,
	0x7654: 0xFAAB,
	0x7655: 0xFFFD,
	0x7656: 0xC27D,
	0x7657: 0xF04F,
	0x7658: 0xC27E,
	0x7659: 0xF04C,
	0x765A: 0xF050,
	0x765B: 0xFFFD,
	0x765C: 0xF04A,
	0x765D: 0xFFFD,
	0x765E: 0x8C7E,
	0x765F: 0xC3A7,
	0x7660: 0xF278,
	0x7661: 0xC3A8,
	0x7662: 0xC46F,
	0x7663: 0x8CD6,
	0x7664: 0xF04B,
	0x7665: 0xC470,
	0x7666: 0xFB76,
	0x7667: 0xFCD7,
	0x7668: 0xFAAC,
	0x7669: 0xC4EE,
	0x766A: 0xF5DF,
	0x766B: 0x8D55,
	0x766C: 0xC57E,
	0x766D: 0xF6F4,
	0x766E: 0xC57D,
	0x766F: 0xFCD8,
	0x7670: 0xF7EA,
	0x7671: 0xC5F5,
	0x7672: 0xC5F6,
	0x7673: 0x81E4,
	0x7674: 0x81E5,
	0x7675: 0xF9CC,
	0x7676: 0xC6D5,
	0x7677: 0xFFFD,
	0x7678: 0xACD1,
	0x7679: 0xCFDE,
	0x767A: 0x93B9,
	0x767B: 0xB56E,
	0x767C: 0xB56F,
	0x767D: 0xA5D5,
	0x767E: 0xA6CA,
	0x767F: 0xCA47,
	0x7680: 0xFAAD,
	0x7681: 0xCB71,
	0x7682: 0xA86D,
	0x7683: 0xFAAE,
	0x7684: 0xAABA,
	0x7685: 0xFFFD,
	0x7686: 0xACD2,
	0x7687: 0xACD3,
	0x7688: 0xACD4,
	0x7689: 0xD6A6,
	0x768A: 0xD2CB,
	0x768B: 0xAF6F,
	0x768C: 0xFFFD,
	0x768D: 0xFFFD,
	0x768E: 0xB2AE,
	0x768F: 0xD6A5,
	0x7690: 0xFAAF,
	0x7691: 0x87F5,
	0x7692: 0xDAB8,
	0x7693: 0xB571,
	0x7694: 0xFFFD,
	0x7695: 0xDAB7,
	0x7696: 0xB570,
	0x7697: 0xFFFD,
	0x7698: 0xFFFD,
	0x7699: 0xDED5,
	0x769A: 0xBD4A,
	0x769B: 0xE6BB,
	0x769C: 0xE6B8,
	0x769D: 0xE6B9,
	0x769E: 0xE6BA,
	0x769F: 0xFFFD,
	0x76A0: 0xFFFD,
	0x76A1: 0xFCBE,
	0x76A2: 0xFFFD,
	0x76A3: 0xFFFD,
	0x76A4: 0xED78,
	0x76A5: 0x81E6,
	0x76A6: 0xF051,
	0x76A7: 0xFFFD,
	0x76A8: 0xFFFD,
	0x76A9: 0xFFFD,
	0x76AA: 0xF471,
	0x76AB: 0xF470,
	0x76AC: 0xFFFD,
	0x76AD: 0xF6F5,
	0x76AE: 0xA5D6,
	0x76AF: 0xCD75,
	0x76B0: 0xAF70,
	0x76B1: 0x87F6,
	0x76B2: 0x8E77,
	0x76B3: 0xFFFD,
	0x76B4: 0xB572,
	0x76B5: 0xDED6,
	0x76B6: 0xFFFD,
	0x76B7: 0xFAB0,
	0x76B8: 0xE2E1,
	0x76B9: 0xFAB1,
	0x76BA: 0xBD4B,
	0x76BB: 0xEA74,
	0x76BC: 0xFFFD,
	0x76BD: 0xF052,
	0x76BE: 0xF472,
	0x76BF: 0xA5D7,
	0x76C0: 0xFFFD,
	0x76C1: 0xFFFD,
	0x76C2: 0xAABB,
	0x76C3: 0xACD7,
	0x76C4: 0xCFDF,
	0x76C5: 0xACD8,
	0x76C6: 0xACD6,
	0x76C7: 0xFFFD,
	0x76C8: 0xACD5,
	0x76C9: 0xD2CC,
	0x76CA: 0xAF71,
	0x76CB: 0xFFFD,
	0x76CC: 0xFCBF,
	0x76CD: 0xAF72,
	0x76CE: 0xAF73,
	0x76CF: 0x85E6,
	0x76D0: 0x8D69,
	0x76D1: 0x86EA,
	0x76D2: 0xB2B0,
	0x76D3: 0xD6A7,
	0x76D4: 0xB2AF,
	0x76D5: 0xFFFD,
	0x76D6: 0x8749,
	0x76D7: 0x84FB,
	0x76D8: 0x87F7,
	0x76D9: 0x81E7,
	0x76DA: 0xDAB9,
	0x76DB: 0xB2B1,
	0x76DC: 0xB573,
	0x76DD: 0xDED7,
	0x76DE: 0xB7F8,
	0x76DF: 0xB7F9,
	0x76E0: 0xFFFD,
	0x76E1: 0xBAC9,
	0x76E2: 0xFFFD,
	0x76E3: 0xBACA,
	0x76E4: 0xBD4C,
	0x76E5: 0xBF64,
	0x76E6: 0xEA75,
	0x76E7: 0xBF63,
	0x76E8: 0xFFFD,
	0x76E9: 0xED79,
	0x76EA: 0xC0FA,
	0x76EB: 0xFFFD,
	0x76EC: 0xF053,
	0x76ED: 0xF473,
	0x76EE: 0xA5D8,
	0x76EF: 0xA86E,
	0x76F0: 0xCD78,
	0x76F1: 0xCD77,
	0x76F2: 0xAABC,
	0x76F3: 0xCD76,
	0x76F4: 0xAABD,
	0x76F5: 0xCD79,
	0x76F6: 0xFFFD,
	0x76F7: 0xCFE5,
	0x76F8: 0xACDB,
	0x76F9: 0xACDA,
	0x76FA: 0xCFE7,
	0x76FB: 0xCFE6,
	0x76FC: 0xACDF,
	0x76FD: 0xFFFD,
	0x76FE: 0xACDE,
	0x76FF: 0xFFFD,
	0x7700: 0xFFFD,
	0x7701: 0xACD9,
	0x7702: 0xFFFD,
	0x7703: 0xCFE1,
	0x7704: 0xCFE2,
	0x7705: 0xCFE3,
	0x7706: 0xFFFD,
	0x7707: 0xACE0,
	0x7708: 0xCFE0,
	0x7709: 0xACDC,
	0x770A: 0xCFE4,
	0x770B: 0xACDD,
	0x770C: 0x92B1,
	0x770D: 0xFAB2,
	0x770E: 0x81E8,
	0x770F: 0x81E9,
	0x7710: 0xD2CF,
	0x7711: 0xD2D3,
	0x7712: 0xD2D1,
	0x7713: 0xD2D0,
	0x7714: 0xFFFD,
	0x7715: 0xD2D4,
	0x7716: 0xFFFD,
	0x7717: 0xFFFD,
	0x7718: 0xFFFD,
	0x7719: 0xD2D5,
	0x771A: 0xD2D6,
	0x771B: 0xD2CE,
	0x771C: 0xFFFD,
	0x771D: 0xD2CD,
	0x771E: 0xFAB3,
	0x771F: 0xAF75,
	0x7720: 0xAF76,
	0x7721: 0xFFFD,
	0x7722: 0xD2D7,
	0x7723: 0xD2D2,
	0x7724: 0xFCC0,
	0x7725: 0xD6B0,
	0x7726: 0x8DD2,
	0x7727: 0xD2D8,
	0x7728: 0xAF77,
	0x7729: 0xAF74,
	0x772A: 0xFFFD,
	0x772B: 0xFCC1,
	0x772C: 0xFFFD,
	0x772D: 0xD6AA,
	0x772E: 0xFFFD,
	0x772F: 0xD6A9,
	0x7730: 0xFFFD,
	0x7731: 0xD6AB,
	0x7732: 0xD6AC,
	0x7733: 0xD6AE,
	0x7734: 0xD6AD,
	0x7735: 0xD6B2,
	0x7736: 0xB2B5,
	0x7737: 0xB2B2,
	0x7738: 0xB2B6,
	0x7739: 0xD6A8,
	0x773A: 0xB2B7,
	0x773B: 0xD6B1,
	0x773C: 0xB2B4,
	0x773D: 0xD6AF,
	0x773E: 0xB2B3,
	0x773F: 0xFFFD,
	0x7740: 0x954D,
	0x7741: 0x85E8,
	0x7742: 0xFFFD,
	0x7743: 0xFAB4,
	0x7744: 0xDABC,
	0x7745: 0xDABE,
	0x7746: 0xDABA,
	0x7747: 0xDABB,
	0x7748: 0xFFFD,
	0x7749: 0xFFFD,
	0x774A: 0xDABF,
	0x774B: 0xDAC1,
	0x774C: 0xDAC2,
	0x774D: 0xDABD,
	0x774E: 0xDAC0,
	0x774F: 0xB574,
	0x7750: 0x85E7,
	0x7751: 0x8ADE,
	0x7752: 0xDEDB,
	0x7753: 0xFFFD,
	0x7754: 0xDEE0,
	0x7755: 0xDED8,
	0x7756: 0xDEDC,
	0x7757: 0xFFFD,
	0x7758: 0x81EA,
	0x7759: 0xDEE1,
	0x775A: 0xDEDD,
	0x775B: 0xB7FA,
	0x775C: 0xB843,
	0x775D: 0xFFFD,
	0x775E: 0xB7FD,
	0x775F: 0xDED9,
	0x7760: 0xDEDA,
	0x7761: 0xBACE,
	0x7762: 0xB846,
	0x7763: 0xB7FE,
	0x7764: 0xFFFD,
	0x7765: 0xB844,
	0x7766: 0xB7FC,
	0x7767: 0xDEDF,
	0x7768: 0xB845,
	0x7769: 0xDEDE,
	0x776A: 0xB841,
	0x776B: 0xB7FB,
	0x776C: 0xB842,
	0x776D: 0xDEE2,
	0x776E: 0xE2E6,
	0x776F: 0xE2E8,
	0x7770: 0xFFFD,
	0x7771: 0xFFFD,
	0x7772: 0x81EB,
	0x7773: 0xFFFD,
	0x7774: 0xFFFD,
	0x7775: 0xFFFD,
	0x7776: 0xFFFD,
	0x7777: 0x81EC,
	0x7778: 0x81ED,
	0x7779: 0xB840,
	0x777A: 0x81EE,
	0x777B: 0x81EF,
	0x777C: 0xE2E3,
	0x777D: 0xBACC,
	0x777E: 0xE2E9,
	0x777F: 0xBACD,
	0x7780: 0xE2E7,
	0x7781: 0xE2E2,
	0x7782: 0xE2E5,
	0x7783: 0xE2EA,
	0x7784: 0xBACB,
	0x7785: 0xE2E4,
	0x7786: 0xFFFD,
	0x7787: 0xBD4E,
	0x7788: 0xE6BF,
	0x7789: 0xE6BE,
	0x778A: 0xFFFD,
	0x778B: 0xBD51,
	0x778C: 0xBD4F,
	0x778D: 0xE6BC,
	0x778E: 0xBD4D,
	0x778F: 0xE6BD,
	0x7790: 0xFFFD,
	0x7791: 0xBD50,
	0x7792: 0x8942,
	0x7793: 0xFB6B,
	0x7794: 0xFFFD,
	0x7795: 0xEA7D,
	0x7796: 0xFFFD,
	0x7797: 0xEAA1,
	0x7798: 0x81F0,
	0x7799: 0xEA7E,
	0x779A: 0xEA76,
	0x779B: 0xEA7A,
	0x779C: 0xEA79,
	0x779D: 0xEA77,
	0x779E: 0xBF66,
	0x779F: 0xBF67,
	0x77A0: 0xBF65,
	0x77A1: 0xEA78,
	0x77A2: 0xEA7B,
	0x77A3: 0xEA7C,
	0x77A4: 0xFFFD,
	0x77A5: 0xBF68,
	0x77A6: 0xFFFD,
	0x77A7: 0xC140,
	0x77A8: 0xEDA3,
	0x77A9: 0x8D7C,
	0x77AA: 0xC0FC,
	0x77AB: 0xED7B,
	0x77AC: 0xC0FE,
	0x77AD: 0xC141,
	0x77AE: 0xFFFD,
	0x77AF: 0x81F1,
	0x77B0: 0xC0FD,
	0x77B1: 0xEDA2,
	0x77B2: 0xED7C,
	0x77B3: 0xC0FB,
	0x77B4: 0xEDA1,
	0x77B5: 0xED7A,
	0x77B6: 0xED7E,
	0x77B7: 0xED7D,
	0x77B8: 0xFFFD,
	0x77B9: 0xFE5A,
	0x77BA: 0xF055,
	0x77BB: 0xC2A4,
	0x77BC: 0xC2A5,
	0x77BD: 0xC2A2,
	0x77BE: 0x81F2,
	0x77BF: 0xC2A3,
	0x77C0: 0xFFFD,
	0x77C1: 0xFFFD,
	0x77C2: 0xF054,
	0x77C3: 0x81F3,
	0x77C4: 0xF27B,
	0x77C5: 0x81F4,
	0x77C6: 0xFFFD,
	0x77C7: 0xC3A9,
	0x77C8: 0xFFFD,
	0x77C9: 0xF279,
	0x77CA: 0xF27A,
	0x77CB: 0x81F5,
	0x77CC: 0xF474,
	0x77CD: 0xF477,
	0x77CE: 0xF475,
	0x77CF: 0xF476,
	0x77D0: 0xF5E0,
	0x77D1: 0xFFFD,
	0x77D2: 0xFFFD,
	0x77D3: 0xC4EF,
	0x77D4: 0xF7EB,
	0x77D5: 0xF8B4,
	0x77D6: 0xFFFD,
	0x77D7: 0xC5F7,
	0x77D8: 0xF8F8,
	0x77D9: 0xF8F9,
	0x77DA: 0xC666,
	0x77DB: 0xA5D9,
	0x77DC: 0xACE1,
	0x77DD: 0x81F6,
	0x77DE: 0xDAC3,
	0x77DF: 0xFFFD,
	0x77E0: 0xDEE3,
	0x77E1: 0xFFFD,
	0x77E2: 0xA5DA,
	0x77E3: 0xA86F,
	0x77E4: 0xFFFD,
	0x77E5: 0xAABE,
	0x77E6: 0x81F7,
	0x77E7: 0xCFE8,
	0x77E8: 0xCFE9,
	0x77E9: 0xAF78,
	0x77EA: 0xFFFD,
	0x77EB: 0x89FC,
	0x77EC: 0xDAC4,
	0x77ED: 0xB575,
	0x77EE: 0xB847,
	0x77EF: 0xC142,
	0x77F0: 0xEDA4,
	0x77F1: 0xF27C,
	0x77F2: 0xF478,
	0x77F3: 0xA5DB,
	0x77F4: 0x81F8,
	0x77F5: 0xFFFD,
	0x77F6: 0x89FE,
	0x77F7: 0xCDA1,
	0x77F8: 0xCD7A,
	0x77F9: 0xCD7C,
	0x77FA: 0xCD7E,
	0x77FB: 0xCD7D,
	0x77FC: 0xCD7B,
	0x77FD: 0xAABF,
	0x77FE: 0x8C41,
	0x77FF: 0x8BFE,
	0x7800: 0x8E78,
	0x7801: 0x87F9,
	0x7802: 0xACE2,
	0x7803: 0xCFF2,
	0x7804: 0xFFFD,
	0x7805: 0xCFED,
	0x7806: 0xCFEA,
	0x7807: 0xFFFD,
	0x7808: 0x9641,
	0x7809: 0xCFF1,
	0x780A: 0xFFFD,
	0x780B: 0xFFFD,
	0x780C: 0xACE4,
	0x780D: 0xACE5,
	0x780E: 0xCFF0,
	0x780F: 0xCFEF,
	0x7810: 0xCFEE,
	0x7811: 0xCFEB,
	0x7812: 0xCFEC,
	0x7813: 0xCFF3,
	0x7814: 0xACE3,
	0x7815: 0x92C5,
	0x7816: 0x8943,
	0x7817: 0x8DE3,
	0x7818: 0xFAB5,
	0x7819: 0xFFFD,
	0x781A: 0x84FC,
	0x781B: 0xFFFD,
	0x781C: 0xFAB6,
	0x781D: 0xAF7C,
	0x781E: 0x81F9,
	0x781F: 0xAFA4,
	0x7820: 0xAFA3,
	0x7821: 0xD2E1,
	0x7822: 0xD2DB,
	0x7823: 0xD2D9,
	0x7824: 0xFFFD,
	0x7825: 0xAFA1,
	0x7826: 0xD6B9,
	0x7827: 0xAF7A,
	0x7828: 0xD2DE,
	0x7829: 0xD2E2,
	0x782A: 0xD2E4,
	0x782B: 0xD2E0,
	0x782C: 0xD2DA,
	0x782D: 0xAFA2,
	0x782E: 0xD2DF,
	0x782F: 0xD2DD,
	0x7830: 0xAF79,
	0x7831: 0xD2E5,
	0x7832: 0xAFA5,
	0x7833: 0xD2E3,
	0x7834: 0xAF7D,
	0x7835: 0xD2DC,
	0x7836: 0xFFFD,
	0x7837: 0xAF7E,
	0x7838: 0xAF7B,
	0x7839: 0xFAB7,
	0x783A: 0x8C40,
	0x783B: 0x9042,
	0x783C: 0xFAB8,
	0x783D: 0x81FA,
	0x783E: 0x8C42,
	0x783F: 0x825F,
	0x7840: 0x8ADF,
	0x7841: 0xFFFD,
	0x7842: 0x81FB,
	0x7843: 0xB2B9,
	0x7844: 0x81FC,
	0x7845: 0xD6BA,
	0x7846: 0xFFFD,
	0x7847: 0xFAB9,
	0x7848: 0xD6B3,
	0x7849: 0xD6B5,
	0x784A: 0xD6B7,
	0x784B: 0x81FD,
	0x784C: 0xD6B8,
	0x784D: 0xD6B6,
	0x784E: 0xB2BA,
	0x784F: 0xFFFD,
	0x7850: 0xD6BB,
	0x7851: 0x81FE,
	0x7852: 0xD6B4,
	0x7853: 0xFCC3,
	0x7854: 0x964B,
	0x7855: 0x86EB,
	0x7856: 0xFABA,
	0x7857: 0x8F59,
	0x7858: 0xFFFD,
	0x7859: 0xFFFD,
	0x785A: 0xFFFD,
	0x785B: 0xFFFD,
	0x785C: 0xDAC8,
	0x785D: 0xB576,
	0x785E: 0xDAD0,
	0x785F: 0xFFFD,
	0x7860: 0xDAC5,
	0x7861: 0xFFFD,
	0x7862: 0xDAD1,
	0x7863: 0xFFFD,
	0x7864: 0xDAC6,
	0x7865: 0xDAC7,
	0x7866: 0x964C,
	0x7867: 0xFFFD,
	0x7868: 0xDACF,
	0x7869: 0xDACE,
	0x786A: 0xDACB,
	0x786B: 0xB2B8,
	0x786C: 0xB577,
	0x786D: 0xDAC9,
	0x786E: 0xDACC,
	0x786F: 0xB578,
	0x7870: 0xDACD,
	0x7871: 0xDACA,
	0x7872: 0x9454,
	0x7873: 0xFFFD,
	0x7874: 0x94B4,
	0x7875: 0xFFFD,
	0x7876: 0xFFFD,
	0x7877: 0x8D68,
	0x7878: 0xFFFD,
	0x7879: 0xDEEE,
	0x787A: 0xFABB,
	0x787B: 0xDEF2,
	0x787C: 0xB84E,
	0x787D: 0xFFFD,
	0x787E: 0xE2F0,
	0x787F: 0xB851,
	0x7880: 0xDEF0,
	0x7881: 0xF9D6,
	0x7882: 0xFFFD,
	0x7883: 0xDEED,
	0x7884: 0xDEE8,
	0x7885: 0xDEEA,
	0x7886: 0xDEEB,
	0x7887: 0xDEE4,
	0x7888: 0x964D,
	0x7889: 0xB84D,
	0x788A: 0xFFFD,
	0x788B: 0xFFFD,
	0x788C: 0xB84C,
	0x788D: 0x8BAC,
	0x788E: 0xB848,
	0x788F: 0xDEE7,
	0x7890: 0xFFFD,
	0x7891: 0xB84F,
	0x7892: 0xFFFD,
	0x7893: 0xB850,
	0x7894: 0xDEE6,
	0x7895: 0xDEE9,
	0x7896: 0xDEF1,
	0x7897: 0xB84A,
	0x7898: 0xB84B,
	0x7899: 0xDEEF,
	0x789A: 0xDEE5,
	0x789B: 0x8944,
	0x789C: 0x8EED,
	0x789D: 0xFFFD,
	0x789E: 0xE2F2,
	0x789F: 0xBAD0,
	0x78A0: 0xE2F4,
	0x78A1: 0xDEEC,
	0x78A2: 0xE2F6,
	0x78A3: 0xBAD4,
	0x78A4: 0xE2F7,
	0x78A5: 0xE2F3,
	0x78A6: 0xFFFD,
	0x78A7: 0xBAD1,
	0x78A8: 0xE2EF,
	0x78A9: 0xBAD3,
	0x78AA: 0xE2EC,
	0x78AB: 0xE2F1,
	0x78AC: 0xE2F5,
	0x78AD: 0xE2EE,
	0x78AE: 0xFFFD,
	0x78AF: 0xFCC7,
	0x78B0: 0xB849,
	0x78B1: 0x95F0,
	0x78B2: 0xE2EB,
	0x78B3: 0xBAD2,
	0x78B4: 0xE2ED,
	0x78B5: 0xFABC,
	0x78B6: 0x964E,
	0x78B7: 0xFFFD,
	0x78B8: 0x96CD,
	0x78B9: 0xFABD,
	0x78BA: 0xBD54,
	0x78BB: 0xE6C1,
	0x78BC: 0xBD58,
	0x78BD: 0xFFFD,
	0x78BE: 0xBD56,
	0x78BF: 0xFFFD,
	0x78C0: 0xFFFD,
	0x78C1: 0xBACF,
	0x78C2: 0xFFFD,
	0x78C3: 0xE6C8,
	0x78C4: 0xE6C9,
	0x78C5: 0xBD53,
	0x78C6: 0xFABE,
	0x78C7: 0x964F,
	0x78C8: 0xE6C7,
	0x78C9: 0xE6CA,
	0x78CA: 0xBD55,
	0x78CB: 0xBD52,
	0x78CC: 0xE6C3,
	0x78CD: 0xE6C0,
	0x78CE: 0xE6C5,
	0x78CF: 0xE6C2,
	0x78D0: 0xBD59,
	0x78D1: 0xE6C4,
	0x78D2: 0x9650,
	0x78D3: 0xFCC4,
	0x78D4: 0xE6C6,
	0x78D5: 0xBD57,
	0x78D6: 0xFFFD,
	0x78D7: 0x9651,
	0x78D8: 0xFCC5,
	0x78D9: 0xFABF,
	0x78DA: 0xBF6A,
	0x78DB: 0xEAA8,
	0x78DC: 0xFFFD,
	0x78DD: 0xEAA2,
	0x78DE: 0xEAA6,
	0x78DF: 0xEAAC,
	0x78E0: 0xEAAD,
	0x78E1: 0xEAA9,
	0x78E2: 0xEAAA,
	0x78E3: 0xEAA7,
	0x78E4: 0x9654,
	0x78E5: 0xEAA4,
	0x78E6: 0xFFFD,
	0x78E7: 0xBF6C,
	0x78E8: 0xBF69,
	0x78E9: 0xEAA3,
	0x78EA: 0xEAA5,
	0x78EB: 0xFFFD,
	0x78EC: 0xBF6B,
	0x78ED: 0xEAAB,
	0x78EE: 0x9655,
	0x78EF: 0xC146,
	0x78F0: 0x9656,
	0x78F1: 0x9657,
	0x78F2: 0xEDAA,
	0x78F3: 0xEDA5,
	0x78F4: 0xC145,
	0x78F5: 0x9658,
	0x78F6: 0xFFFD,
	0x78F7: 0xC143,
	0x78F8: 0xFFFD,
	0x78F9: 0xEDAC,
	0x78FA: 0xC144,
	0x78FB: 0xEDA8,
	0x78FC: 0xEDA9,
	0x78FD: 0xEDA6,
	0x78FE: 0xEDAD,
	0x78FF: 0xF056,
	0x7900: 0xFFFD,
	0x7901: 0xC147,
	0x7902: 0xEDA7,
	0x7903: 0xFFFD,
	0x7904: 0xEDAE,
	0x7905: 0xEDAB,
	0x7906: 0xFBA8,
	0x7907: 0xFAC0,
	0x7908: 0xFFFD,
	0x7909: 0xF05A,
	0x790A: 0xFFFD,
	0x790B: 0xFFFD,
	0x790C: 0xF057,
	0x790D: 0xFFFD,
	0x790E: 0xC2A6,
	0x790F: 0xFFFD,
	0x7910: 0xF05B,
	0x7911: 0xF05D,
	0x7912: 0xF05C,
	0x7913: 0xF058,
	0x7914: 0xF059,
	0x7915: 0xFFFD,
	0x7916: 0xFFFD,
	0x7917: 0xF2A3,
	0x7918: 0xFFFD,
	0x7919: 0xC3AA,
	0x791A: 0xFFFD,
	0x791B: 0xF27E,
	0x791C: 0xF2A2,
	0x791D: 0xF27D,
	0x791E: 0xF2A4,
	0x791F: 0xFFFD,
	0x7920: 0xFFFD,
	0x7921: 0xF2A1,
	0x7922: 0xFFFD,
	0x7923: 0xF47A,
	0x7924: 0xF47D,
	0x7925: 0xF479,
	0x7926: 0xC471,
	0x7927: 0xF47B,
	0x7928: 0xF47C,
	0x7929: 0xF47E,
	0x792A: 0xC472,
	0x792B: 0xC474,
	0x792C: 0xC473,
	0x792D: 0xF5E1,
	0x792E: 0xFE77,
	0x792F: 0xF5E3,
	0x7930: 0xFAC1,
	0x7931: 0xF5E2,
	0x7932: 0x9659,
	0x7933: 0x965A,
	0x7934: 0xFAC2,
	0x7935: 0xF6F6,
	0x7936: 0x965B,
	0x7937: 0xFFFD,
	0x7938: 0xF8B5,
	0x7939: 0xF8FA,
	0x793A: 0xA5DC,
	0x793B: 0xFAC3,
	0x793C: 0x8AE0,
	0x793D: 0xCB72,
	0x793E: 0xAAC0,
	0x793F: 0xCDA3,
	0x7940: 0xAAC1,
	0x7941: 0xAAC2,
	0x7942: 0xCDA2,
	0x7943: 0xFFFD,
	0x7944: 0xCFF8,
	0x7945: 0xCFF7,
	0x7946: 0xACE6,
	0x7947: 0xACE9,
	0x7948: 0xACE8,
	0x7949: 0xACE7,
	0x794A: 0xCFF4,
	0x794B: 0xCFF6,
	0x794C: 0xCFF5,
	0x794D: 0xFFFD,
	0x794E: 0xFFFD,
	0x794F: 0xD2E8,
	0x7950: 0xAFA7,
	0x7951: 0xD2EC,
	0x7952: 0xD2EB,
	0x7953: 0xD2EA,
	0x7954: 0xD2E6,
	0x7955: 0xAFA6,
	0x7956: 0xAFAA,
	0x7957: 0xAFAD,
	0x7958: 0x965C,
	0x7959: 0x965E,
	0x795A: 0xAFAE,
	0x795B: 0xD2E7,
	0x795C: 0xD2E9,
	0x795D: 0xAFAC,
	0x795E: 0xAFAB,
	0x795F: 0xAFA9,
	0x7960: 0xAFA8,
	0x7961: 0xD6C2,
	0x7962: 0x8FBE,
	0x7963: 0xD6C0,
	0x7964: 0xD6BC,
	0x7965: 0xB2BB,
	0x7966: 0xFFFD,
	0x7967: 0xD6BD,
	0x7968: 0xB2BC,
	0x7969: 0xD6BE,
	0x796A: 0xD6BF,
	0x796B: 0xD6C1,
	0x796C: 0xFFFD,
	0x796D: 0xB2BD,
	0x796E: 0xFFFD,
	0x796F: 0x86EC,
	0x7970: 0xDAD5,
	0x7971: 0x965F,
	0x7972: 0xDAD4,
	0x7973: 0xDAD3,
	0x7974: 0xDAD2,
	0x7975: 0xFFFD,
	0x7976: 0xFFFD,
	0x7977: 0x8270,
	0x7978: 0x86ED,
	0x7979: 0xDEF6,
	0x797A: 0xB852,
	0x797B: 0xFFFD,
	0x797C: 0xDEF3,
	0x797D: 0xDEF5,
	0x797E: 0x9660,
	0x797F: 0xB853,
	0x7980: 0xFAC4,
	0x7981: 0xB854,
	0x7982: 0xDEF4,
	0x7983: 0x9661,
	0x7984: 0x8277,
	0x7985: 0x9350,
	0x7986: 0x9662,
	0x7987: 0x9663,
	0x7988: 0xE341,
	0x7989: 0xFFFD,
	0x798A: 0xE2F9,
	0x798B: 0xE2FA,
	0x798C: 0xFFFD,
	0x798D: 0xBAD7,
	0x798E: 0xBAD5,
	0x798F: 0xBAD6,
	0x7990: 0xE343,
	0x7991: 0x9664,
	0x7992: 0xE342,
	0x7993: 0xE2FE,
	0x7994: 0xE2FD,
	0x7995: 0xE2FC,
	0x7996: 0xE2FB,
	0x7997: 0xE340,
	0x7998: 0xE2F8,
	0x7999: 0x9665,
	0x799A: 0xE6CB,
	0x799B: 0xE6D0,
	0x799C: 0xE6CE,
	0x799D: 0xFAC5,
	0x799E: 0xFFFD,
	0x799F: 0x9666,
	0x79A0: 0xE6CD,
	0x79A1: 0xE6CC,
	0x79A2: 0xE6CF,
	0x79A3: 0xFFFD,
	0x79A4: 0xEAAE,
	0x79A5: 0x9667,
	0x79A6: 0xBF6D,
	0x79A7: 0xC148,
	0x79A8: 0xEDB0,
	0x79A9: 0xFCCA,
	0x79AA: 0xC149,
	0x79AB: 0xEDAF,
	0x79AC: 0xF05F,
	0x79AD: 0xF05E,
	0x79AE: 0xC2A7,
	0x79AF: 0xFFFD,
	0x79B0: 0xF2A5,
	0x79B1: 0xC3AB,
	0x79B2: 0xF4A1,
	0x79B3: 0xC5A1,
	0x79B4: 0xF6F7,
	0x79B5: 0xFFFD,
	0x79B6: 0xF8B7,
	0x79B7: 0xF8B6,
	0x79B8: 0xC9A8,
	0x79B9: 0xACEA,
	0x79BA: 0xACEB,
	0x79BB: 0xD6C3,
	0x79BC: 0xFFFD,
	0x79BD: 0xB856,
	0x79BE: 0xA5DD,
	0x79BF: 0xA872,
	0x79C0: 0xA871,
	0x79C1: 0xA870,
	0x79C2: 0xFFFD,
	0x79C3: 0xFAC6,
	0x79C4: 0xFBA9,
	0x79C5: 0xCDA4,
	0x79C6: 0x84FD,
	0x79C7: 0xFFFD,
	0x79C8: 0xAAC4,
	0x79C9: 0xAAC3,
	0x79CA: 0x9DCE,
	0x79CB: 0xACEE,
	0x79CC: 0xFCA6,
	0x79CD: 0xCFFA,
	0x79CE: 0xCFFD,
	0x79CF: 0xCFFB,
	0x79D0: 0xFFFD,
	0x79D1: 0xACEC,
	0x79D2: 0xACED,
	0x79D3: 0xFFFD,
	0x79D4: 0xFCCC,
	0x79D5: 0xCFF9,
	0x79D6: 0xCFFC,
	0x79D7: 0xFFFD,
	0x79D8: 0xAFB5,
	0x79D9: 0xFFFD,
	0x79DA: 0xFFFD,
	0x79DB: 0xFFFD,
	0x79DC: 0xD2F3,
	0x79DD: 0xD2F5,
	0x79DE: 0xD2F4,
	0x79DF: 0xAFB2,
	0x79E0: 0xD2EF,
	0x79E1: 0xFAC7,
	0x79E2: 0x9668,
	0x79E3: 0xAFB0,
	0x79E4: 0xAFAF,
	0x79E5: 0xFFFD,
	0x79E6: 0xAFB3,
	0x79E7: 0xAFB1,
	0x79E8: 0xFFFD,
	0x79E9: 0xAFB4,
	0x79EA: 0xD2F2,
	0x79EB: 0xD2ED,
	0x79EC: 0xD2EE,
	0x79ED: 0xD2F1,
	0x79EE: 0xD2F0,
	0x79EF: 0x85B8,
	0x79F0: 0x86EF,
	0x79F1: 0x9669,
	0x79F2: 0xFFFD,
	0x79F3: 0xFFFD,
	0x79F4: 0x966A,
	0x79F5: 0xFFFD,
	0x79F6: 0xD6C6,
	0x79F7: 0xD6C7,
	0x79F8: 0xD6C5,
	0x79F9: 0xFFFD,
	0x79FA: 0xD6C4,
	0x79FB: 0xB2BE,
	0x79FC: 0xFFFD,
	0x79FD: 0x8AE2,
	0x79FE: 0xFFFD,
	0x79FF: 0xFFFD,
	0x7A00: 0xB57D,
	0x7A01: 0xFFFD,
	0x7A02: 0xDAD6,
	0x7A03: 0xDAD8,
	0x7A04: 0xDADA,
	0x7A05: 0xB57C,
	0x7A06: 0xFAC8,
	0x7A07: 0xFFFD,
	0x7A08: 0xB57A,
	0x7A09: 0xFFFD,
	0x7A0A: 0xDAD7,
	0x7A0B: 0xB57B,
	0x7A0C: 0xDAD9,
	0x7A0D: 0xB579,
	0x7A0E: 0xFAC9,
	0x7A0F: 0xFFFD,
	0x7A10: 0xDF41,
	0x7A11: 0xDEF7,
	0x7A12: 0xDEFA,
	0x7A13: 0xDEFE,
	0x7A14: 0xB85A,
	0x7A15: 0xDEFC,
	0x7A16: 0xFFFD,
	0x7A17: 0xDEFB,
	0x7A18: 0xDEF8,
	0x7A19: 0xDEF9,
	0x7A1A: 0xB858,
	0x7A1B: 0xDF40,
	0x7A1C: 0xB857,
	0x7A1D: 0xFFFD,
	0x7A1E: 0xB85C,
	0x7A1F: 0xB85B,
	0x7A20: 0xB859,
	0x7A21: 0xFFFD,
	0x7A22: 0xDEFD,
	0x7A23: 0x8947,
	0x7A24: 0xFFFD,
	0x7A25: 0xFFFD,
	0x7A26: 0xE349,
	0x7A27: 0xFFFD,
	0x7A28: 0xE348,
	0x7A29: 0xFFFD,
	0x7A2A: 0x966B,
	0x7A2B: 0xE344,
	0x7A2C: 0xFFFD,
	0x7A2D: 0xFCCE,
	0x7A2E: 0xBAD8,
	0x7A2F: 0xE347,
	0x7A30: 0xE346,
	0x7A31: 0xBAD9,
	0x7A32: 0x93A6,
	0x7A33: 0x8BAE,
	0x7A34: 0xFFFD,
	0x7A35: 0xFFFD,
	0x7A36: 0xFFFD,
	0x7A37: 0xBD5E,
	0x7A38: 0xFFFD,
	0x7A39: 0xE6D2,
	0x7A3A: 0x966C,
	0x7A3B: 0xBD5F,
	0x7A3C: 0xBD5B,
	0x7A3D: 0xBD5D,
	0x7A3E: 0xFCCF,
	0x7A3F: 0xBD5A,
	0x7A40: 0xBD5C,
	0x7A41: 0xFFFD,
	0x7A42: 0x92F9,
	0x7A43: 0xFACA,
	0x7A44: 0xEAAF,
	0x7A45: 0x966D,
	0x7A46: 0xBF70,
	0x7A47: 0xEAB1,
	0x7A48: 0xEAB0,
	0x7A49: 0xFCD0,
	0x7A4A: 0xE345,
	0x7A4B: 0xBF72,
	0x7A4C: 0xBF71,
	0x7A4D: 0xBF6E,
	0x7A4E: 0xBF6F,
	0x7A4F: 0x9253,
	0x7A50: 0xFACB,
	0x7A51: 0x8AE1,
	0x7A52: 0xFFFD,
	0x7A53: 0xFFFD,
	0x7A54: 0xEDB5,
	0x7A55: 0xFFFD,
	0x7A56: 0xEDB3,
	0x7A57: 0xC14A,
	0x7A58: 0xEDB4,
	0x7A59: 0xFFFD,
	0x7A5A: 0xEDB6,
	0x7A5B: 0xEDB2,
	0x7A5C: 0xEDB1,
	0x7A5D: 0xFFFD,
	0x7A5E: 0xFFFD,
	0x7A5F: 0xF060,
	0x7A60: 0xC2AA,
	0x7A61: 0xC2A8,
	0x7A62: 0xC2A9,
	0x7A63: 0x8267,
	0x7A64: 0xFFFD,
	0x7A65: 0x966E,
	0x7A66: 0xFFFD,
	0x7A67: 0xF2A6,
	0x7A68: 0xF2A7,
	0x7A69: 0xC3AD,
	0x7A6A: 0xFFFD,
	0x7A6B: 0xC3AC,
	0x7A6C: 0xF4A3,
	0x7A6D: 0xF4A4,
	0x7A6E: 0xF4A2,
	0x7A6F: 0xFFFD,
	0x7A70: 0xF6F8,
	0x7A71: 0xF6F9,
	0x7A72: 0xFFFD,
	0x7A73: 0xFFFD,
	0x7A74: 0xA5DE,
	0x7A75: 0xCA48,
	0x7A76: 0xA873,
	0x7A77: 0x87FB,
	0x7A78: 0xCDA5,
	0x7A79: 0xAAC6,
	0x7A7A: 0xAAC5,
	0x7A7B: 0xCDA6,
	0x7A7C: 0xFFFD,
	0x7A7D: 0xFC42,
	0x7A7E: 0xD040,
	0x7A7F: 0xACEF,
	0x7A80: 0xCFFE,
	0x7A81: 0xACF0,
	0x7A82: 0xFFFD,
	0x7A83: 0x8CFA,
	0x7A84: 0xAFB6,
	0x7A85: 0xD2F8,
	0x7A86: 0xD2F6,
	0x7A87: 0xD2FC,
	0x7A88: 0xAFB7,
	0x7A89: 0xD2F7,
	0x7A8A: 0xD2FB,
	0x7A8B: 0xD2F9,
	0x7A8C: 0xD2FA,
	0x7A8D: 0x8AE4,
	0x7A8E: 0xFFFD,
	0x7A8F: 0xD6C8,
	0x7A90: 0xD6CA,
	0x7A91: 0x87FA,
	0x7A92: 0xB2BF,
	0x7A93: 0x9358,
	0x7A94: 0xD6C9,
	0x7A95: 0xB2C0,
	0x7A96: 0xB5A2,
	0x7A97: 0xB5A1,
	0x7A98: 0xB57E,
	0x7A99: 0xDADB,
	0x7A9A: 0xFFFD,
	0x7A9B: 0xFFFD,
	0x7A9C: 0x8AE3,
	0x7A9D: 0x86F1,
	0x7A9E: 0xDF44,
	0x7A9F: 0xB85D,
	0x7AA0: 0xB85E,
	0x7AA1: 0xFFFD,
	0x7AA2: 0xDF43,
	0x7AA3: 0xDF42,
	0x7AA4: 0xFFFD,
	0x7AA5: 0x8948,
	0x7AA6: 0x8C43,
	0x7AA7: 0xFFFD,
	0x7AA8: 0xE34A,
	0x7AA9: 0xBADB,
	0x7AAA: 0xBADA,
	0x7AAB: 0xE34B,
	0x7AAC: 0xE34C,
	0x7AAD: 0x8EEE,
	0x7AAE: 0xBD61,
	0x7AAF: 0xBD60,
	0x7AB0: 0xFEA7,
	0x7AB1: 0xEAB5,
	0x7AB2: 0xE6D3,
	0x7AB3: 0xE6D5,
	0x7AB4: 0xE6D4,
	0x7AB5: 0xEAB4,
	0x7AB6: 0xEAB2,
	0x7AB7: 0xEAB6,
	0x7AB8: 0xEAB3,
	0x7AB9: 0xFFFD,
	0x7ABA: 0xBF73,
	0x7ABB: 0xFC44,
	0x7ABC: 0x966F,
	0x7ABD: 0xFFFD,
	0x7ABE: 0xEDB7,
	0x7ABF: 0xC14B,
	0x7AC0: 0xEDB8,
	0x7AC1: 0xEDB9,
	0x7AC2: 0x9670,
	0x7AC3: 0xFACC,
	0x7AC4: 0xC2AB,
	0x7AC5: 0xC2AC,
	0x7AC6: 0xFFFD,
	0x7AC7: 0xC475,
	0x7AC8: 0xFDE5,
	0x7AC9: 0x9671,
	0x7ACA: 0xC5D1,
	0x7ACB: 0xA5DF,
	0x7ACC: 0xFFFD,
	0x7ACD: 0x94B5,
	0x7ACE: 0xFFFD,
	0x7ACF: 0x94B6,
	0x7AD0: 0xFFFD,
	0x7AD1: 0xD041,
	0x7AD2: 0xFACD,
	0x7AD3: 0x94B8,
	0x7AD4: 0xFFFD,
	0x7AD5: 0x94B7,
	0x7AD6: 0x8867,
	0x7AD7: 0xFFFD,
	0x7AD8: 0xD2FD,
	0x7AD9: 0xAFB8,
	0x7ADA: 0xFCD2,
	0x7ADB: 0x9672,
	0x7ADC: 0x93E2,
	0x7ADD: 0xFCD1,
	0x7ADE: 0x8C44,
	0x7ADF: 0xB3BA,
	0x7AE0: 0xB3B9,
	0x7AE1: 0x94B9,
	0x7AE2: 0xFACE,
	0x7AE3: 0xB5A4,
	0x7AE4: 0xDADD,
	0x7AE5: 0xB5A3,
	0x7AE6: 0xDADC,
	0x7AE7: 0xFACF,
	0x7AE8: 0xFFFD,
	0x7AE9: 0x9673,
	0x7AEA: 0x826D,
	0x7AEB: 0xDF45,
	0x7AEC: 0xFFFD,
	0x7AED: 0xBADC,
	0x7AEE: 0xE34D,
	0x7AEF: 0xBADD,
	0x7AF0: 0x94BA,
	0x7AF1: 0xFFFD,
	0x7AF2: 0xFFFD,
	0x7AF3: 0xFFFD,
	0x7AF4: 0xFFFD,
	0x7AF5: 0xFFFD,
	0x7AF6: 0xC476,
	0x7AF7: 0xF4A5,
	0x7AF8: 0xFAD0,
	0x7AF9: 0xA6CB,
	0x7AFA: 0xAAC7,
	0x7AFB: 0xCDA7,
	0x7AFC: 0xFFFD,
	0x7AFD: 0xACF2,
	0x7AFE: 0x9674,
	0x7AFF: 0xACF1,
	0x7B00: 0xD042,
	0x7B01: 0xD043,
	0x7B02: 0x94BB,
	0x7B03: 0x8949,
	0x7B04: 0xD340,
	0x7B05: 0xD342,
	0x7B06: 0xAFB9,
	0x7B07: 0xFFFD,
	0x7B08: 0xD344,
	0x7B09: 0xD347,
	0x7B0A: 0xD345,
	0x7B0B: 0x8541,
	0x7B0C: 0x9675,
	0x7B0D: 0xFFFD,
	0x7B0E: 0xD346,
	0x7B0F: 0xD343,
	0x7B10: 0xD2FE,
	0x7B11: 0xAFBA,
	0x7B12: 0xD348,
	0x7B13: 0xD341,
	0x7B14: 0x8540,
	0x7B15: 0x85EC,
	0x7B16: 0xFFFD,
	0x7B17: 0xFFFD,
	0x7B18: 0xD6D3,
	0x7B19: 0xB2C6,
	0x7B1A: 0xD6DC,
	0x7B1B: 0xB2C3,
	0x7B1C: 0xFFFD,
	0x7B1D: 0xD6D5,
	0x7B1E: 0xB2C7,
	0x7B1F: 0xFCDC,
	0x7B20: 0xB2C1,
	0x7B21: 0xFFFD,
	0x7B22: 0xD6D0,
	0x7B23: 0xD6DD,
	0x7B24: 0xD6D1,
	0x7B25: 0xD6CE,
	0x7B26: 0xB2C5,
	0x7B27: 0x9676,
	0x7B28: 0xB2C2,
	0x7B29: 0x9677,
	0x7B2A: 0xD6D4,
	0x7B2B: 0xD6D7,
	0x7B2C: 0xB2C4,
	0x7B2D: 0xD6D8,
	0x7B2E: 0xB2C8,
	0x7B2F: 0xD6D9,
	0x7B30: 0xD6CF,
	0x7B31: 0xD6D6,
	0x7B32: 0xD6DA,
	0x7B33: 0xD6D2,
	0x7B34: 0xD6CD,
	0x7B35: 0xD6CB,
	0x7B36: 0xFAD1,
	0x7B37: 0xFFFD,
	0x7B38: 0xD6DB,
	0x7B39: 0xFE64,
	0x7B3A: 0x86F2,
	0x7B3B: 0xDADF,
	0x7B3C: 0x8CD7,
	0x7B3D: 0xFFFD,
	0x7B3E: 0x907A,
	0x7B3F: 0xFFFD,
	0x7B40: 0xDAE4,
	0x7B41: 0xFFFD,
	0x7B42: 0x9678,
	0x7B43: 0x9679,
	0x7B44: 0xDAE0,
	0x7B45: 0xDAE6,
	0x7B46: 0xB5A7,
	0x7B47: 0xD6CC,
	0x7B48: 0xDAE1,
	0x7B49: 0xB5A5,
	0x7B4A: 0xDADE,
	0x7B4B: 0xB5AC,
	0x7B4C: 0xDAE2,
	0x7B4D: 0xB5AB,
	0x7B4E: 0xDAE3,
	0x7B4F: 0xB5AD,
	0x7B50: 0xB5A8,
	0x7B51: 0xB5AE,
	0x7B52: 0xB5A9,
	0x7B53: 0xFFFD,
	0x7B54: 0xB5AA,
	0x7B55: 0x967A,
	0x7B56: 0xB5A6,
	0x7B57: 0xFFFD,
	0x7B58: 0xDAE5,
	0x7B59: 0xFFFD,
	0x7B5A: 0x8F5B,
	0x7B5B: 0x894A,
	0x7B5C: 0xFFFD,
	0x7B5D: 0x86F3,
	0x7B5E: 0xFFFD,
	0x7B5F: 0xFFFD,
	0x7B60: 0xB861,
	0x7B61: 0xDF50,
	0x7B62: 0xFAD2,
	0x7B63: 0xDF53,
	0x7B64: 0xDF47,
	0x7B65: 0xDF4C,
	0x7B66: 0xDF46,
	0x7B67: 0xB863,
	0x7B68: 0xFFFD,
	0x7B69: 0xDF4A,
	0x7B6A: 0xFFFD,
	0x7B6B: 0xFFFD,
	0x7B6C: 0xFAD3,
	0x7B6D: 0xDF48,
	0x7B6E: 0xB862,
	0x7B6F: 0x967B,
	0x7B70: 0xDF4F,
	0x7B71: 0xDF4E,
	0x7B72: 0xDF4B,
	0x7B73: 0xDF4D,
	0x7B74: 0xDF49,
	0x7B75: 0xBAE1,
	0x7B76: 0xDF52,
	0x7B77: 0xB85F,
	0x7B78: 0xDF51,
	0x7B79: 0x8C45,
	0x7B7A: 0xFAD4,
	0x7B7B: 0xFAD5,
	0x7B7C: 0xFFFD,
	0x7B7D: 0xFFFD,
	0x7B7E: 0x8BAF,
	0x7B7F: 0xFFFD,
	0x7B80: 0x8AE9,
	0x7B81: 0xFFFD,
	0x7B82: 0xE35D,
	0x7B83: 0xFFFD,
	0x7B84: 0xBAE8,
	0x7B85: 0xE358,
	0x7B86: 0x827A,
	0x7B87: 0xBAE7,
	0x7B88: 0xE34E,
	0x7B89: 0xFFFD,
	0x7B8A: 0xE350,
	0x7B8B: 0xBAE0,
	0x7B8C: 0xE355,
	0x7B8D: 0xE354,
	0x7B8E: 0xE357,
	0x7B8F: 0xBAE5,
	0x7B90: 0xE352,
	0x7B91: 0xE351,
	0x7B92: 0xFCDD,
	0x7B93: 0xFFFD,
	0x7B94: 0xBAE4,
	0x7B95: 0xBADF,
	0x7B96: 0xE353,
	0x7B97: 0xBAE2,
	0x7B98: 0xE359,
	0x7B99: 0xE35B,
	0x7B9A: 0xFAD6,
	0x7B9B: 0xE356,
	0x7B9C: 0xE34F,
	0x7B9D: 0xBAE3,
	0x7B9E: 0xFAD7,
	0x7B9F: 0xFAD8,
	0x7BA0: 0xBD69,
	0x7BA1: 0xBADE,
	0x7BA2: 0xFAD9,
	0x7BA3: 0xFCDE,
	0x7BA4: 0xE35C,
	0x7BA5: 0xFFFD,
	0x7BA6: 0x8F5A,
	0x7BA7: 0xFADA,
	0x7BA8: 0x9059,
	0x7BA9: 0x8D71,
	0x7BAA: 0x8AE7,
	0x7BAB: 0x8AE5,
	0x7BAC: 0xE6D9,
	0x7BAD: 0xBD62,
	0x7BAE: 0xFFFD,
	0x7BAF: 0xE6DB,
	0x7BB0: 0xFFFD,
	0x7BB1: 0xBD63,
	0x7BB2: 0x967C,
	0x7BB3: 0xFFFD,
	0x7BB4: 0xBD65,
	0x7BB5: 0xE6DE,
	0x7BB6: 0xFFFD,
	0x7BB7: 0xE6D6,
	0x7BB8: 0xBAE6,
	0x7BB9: 0xE6DC,
	0x7BBA: 0xFFFD,
	0x7BBB: 0xFFFD,
	0x7BBC: 0xFFFD,
	0x7BBD: 0xFFFD,
	0x7BBE: 0xE6D8,
	0x7BBF: 0xFFFD,
	0x7BC0: 0xB860,
	0x7BC1: 0xBD68,
	0x7BC2: 0xFFFD,
	0x7BC3: 0xFFFD,
	0x7BC4: 0xBD64,
	0x7BC5: 0xFFFD,
	0x7BC6: 0xBD66,
	0x7BC7: 0xBD67,
	0x7BC8: 0xFFFD,
	0x7BC9: 0xBF76,
	0x7BCA: 0xE6DD,
	0x7BCB: 0xE6D7,
	0x7BCC: 0xBD6A,
	0x7BCD: 0xFFFD,
	0x7BCE: 0xE6DA,
	0x7BCF: 0xFCDF,
	0x7BD0: 0x96D0,
	0x7BD1: 0x8AE8,
	0x7BD2: 0xFFFD,
	0x7BD3: 0x8A40,
	0x7BD4: 0xEAC0,
	0x7BD5: 0xEABB,
	0x7BD6: 0xFFFD,
	0x7BD7: 0xFFFD,
	0x7BD8: 0xEAC5,
	0x7BD9: 0xBF74,
	0x7BDA: 0xEABD,
	0x7BDB: 0xBF78,
	0x7BDC: 0xEAC3,
	0x7BDD: 0xEABA,
	0x7BDE: 0xEAB7,
	0x7BDF: 0xEAC6,
	0x7BE0: 0xC151,
	0x7BE1: 0xBF79,
	0x7BE2: 0xEAC2,
	0x7BE3: 0xEAB8,
	0x7BE4: 0xBF77,
	0x7BE5: 0xEABC,
	0x7BE6: 0xBF7B,
	0x7BE7: 0xEAB9,
	0x7BE8: 0xEABE,
	0x7BE9: 0xBF7A,
	0x7BEA: 0xEAC1,
	0x7BEB: 0xEAC4,
	0x7BEC: 0x96D1,
	0x7BED: 0x82A1,
	0x7BEE: 0x8C46,
	0x7BEF: 0xFFFD,
	0x7BF0: 0xEDCB,
	0x7BF1: 0xEDCC,
	0x7BF2: 0xEDBC,
	0x7BF3: 0xEDC3,
	0x7BF4: 0xEDC1,
	0x7BF5: 0xFFFD,
	0x7BF6: 0xFADB,
	0x7BF7: 0xC14F,
	0x7BF8: 0xEDC8,
	0x7BF9: 0xEABF,
	0x7BFA: 0x96D2,
	0x7BFB: 0xEDBF,
	0x7BFC: 0xFCE1,
	0x7BFD: 0xEDC9,
	0x7BFE: 0xC14E,
	0x7BFF: 0xEDBE,
	0x7C00: 0xEDBD,
	0x7C01: 0xEDC7,
	0x7C02: 0xEDC4,
	0x7C03: 0xEDC6,
	0x7C04: 0xFFFD,
	0x7C05: 0xEDBA,
	0x7C06: 0xEDCA,
	0x7C07: 0xC14C,
	0x7C08: 0xFFFD,
	0x7C09: 0xEDC5,
	0x7C0A: 0xEDCE,
	0x7C0B: 0xEDC2,
	0x7C0C: 0xC150,
	0x7C0D: 0xC14D,
	0x7C0E: 0xEDC0,
	0x7C0F: 0xEDBB,
	0x7C10: 0xEDCD,
	0x7C11: 0xBF75,
	0x7C12: 0xFADC,
	0x7C13: 0x94BC,
	0x7C14: 0xFADD,
	0x7C15: 0x96D3,
	0x7C16: 0x9077,
	0x7C17: 0x94BD,
	0x7C18: 0xFFFD,
	0x7C19: 0xF063,
	0x7C1A: 0xFFFD,
	0x7C1B: 0x96D4,
	0x7C1C: 0xF061,
	0x7C1D: 0xF067,
	0x7C1E: 0xC2B0,
	0x7C1F: 0xF065,
	0x7C20: 0xF064,
	0x7C21: 0xC2B2,
	0x7C22: 0xF06A,
	0x7C23: 0xC2B1,
	0x7C24: 0xFFFD,
	0x7C25: 0xF06B,
	0x7C26: 0xF068,
	0x7C27: 0xC2AE,
	0x7C28: 0xF069,
	0x7C29: 0xF062,
	0x7C2A: 0xC2AF,
	0x7C2B: 0xC2AD,
	0x7C2C: 0xF2AB,
	0x7C2D: 0xF066,
	0x7C2E: 0xFFFD,
	0x7C2F: 0xFFFD,
	0x7C30: 0xF06C,
	0x7C31: 0xFFFD,
	0x7C32: 0xFFFD,
	0x7C33: 0xF2A8,
	0x7C34: 0xFFFD,
	0x7C35: 0x96D5,
	0x7C36: 0xFFFD,
	0x7C37: 0xC3B2,
	0x7C38: 0xC3B0,
	0x7C39: 0xF2AA,
	0x7C3A: 0xFFFD,
	0x7C3B: 0xF2AC,
	0x7C3C: 0xF2A9,
	0x7C3D: 0xC3B1,
	0x7C3E: 0xC3AE,
	0x7C3F: 0xC3AF,
	0x7C40: 0xC3B3,
	0x7C41: 0x8CD8,
	0x7C42: 0xFCE2,
	0x7C43: 0xC478,
	0x7C44: 0x96D6,
	0x7C45: 0xF4AA,
	0x7C46: 0xFFFD,
	0x7C47: 0xF4A9,
	0x7C48: 0xF4A7,
	0x7C49: 0xF4A6,
	0x7C4A: 0xF4A8,
	0x7C4B: 0xFFFD,
	0x7C4C: 0xC477,
	0x7C4D: 0xC479,
	0x7C4E: 0xFFFD,
	0x7C4F: 0xFADE,
	0x7C50: 0xC4F0,
	0x7C51: 0xFCE3,
	0x7C52: 0xFFFD,
	0x7C53: 0xF5E5,
	0x7C54: 0xF5E4,
	0x7C55: 0xFFFD,
	0x7C56: 0xFADF,
	0x7C57: 0xF6FA,
	0x7C58: 0xFAE0,
	0x7C59: 0xF6FC,
	0x7C5A: 0xF6FE,
	0x7C5B: 0xF6FD,
	0x7C5C: 0xF6FB,
	0x7C5D: 0xFCE4,
	0x7C5E: 0xFFFD,
	0x7C5F: 0xC5A3,
	0x7C60: 0xC5A2,
	0x7C61: 0xFFFD,
	0x7C62: 0xFFFD,
	0x7C63: 0xC5D3,
	0x7C64: 0xC5D2,
	0x7C65: 0xC5D4,
	0x7C66: 0xF7ED,
	0x7C67: 0xF7EC,
	0x7C68: 0xFFFD,
	0x7C69: 0xF8FB,
	0x7C6A: 0xF8B8,
	0x7C6B: 0xF8FC,
	0x7C6C: 0xC658,
	0x7C6D: 0x96D7,
	0x7C6E: 0xC659,
	0x7C6F: 0xF96D,
	0x7C70: 0xFCE5,
	0x7C71: 0xFFFD,
	0x7C72: 0xC67E,
	0x7C73: 0xA6CC,
	0x7C74: 0x905A,
	0x7C75: 0xCDA8,
	0x7C76: 0xFFFD,
	0x7C77: 0xFFFD,
	0x7C78: 0xD045,
	0x7C79: 0xD046,
	0x7C7A: 0xD044,
	0x7C7B: 0x8BDD,
	0x7C7C: 0x835E,
	0x7C7D: 0xACF3,
	0x7C7E: 0xFCE6,
	0x7C7F: 0xD047,
	0x7C80: 0xD048,
	0x7C81: 0xD049,
	0x7C82: 0x9443,
	0x7C83: 0xFCE8,
	0x7C84: 0xD349,
	0x7C85: 0xD34F,
	0x7C86: 0xFCE7,
	0x7C87: 0xFFFD,
	0x7C88: 0xD34D,
	0x7C89: 0xAFBB,
	0x7C8A: 0xD34B,
	0x7C8B: 0x92F7,
	0x7C8C: 0xD34C,
	0x7C8D: 0xD34E,
	0x7C8E: 0x96D8,
	0x7C8F: 0xFFFD,
	0x7C90: 0x94BE,
	0x7C91: 0xD34A,
	0x7C92: 0xB2C9,
	0x7C93: 0xFFFD,
	0x7C94: 0xD6DE,
	0x7C95: 0xB2CB,
	0x7C96: 0xD6E0,
	0x7C97: 0xB2CA,
	0x7C98: 0xD6DF,
	0x7C99: 0xFFFD,
	0x7C9A: 0xFFFD,
	0x7C9B: 0x92E0,
	0x7C9C: 0x907B,
	0x7C9D: 0x9043,
	0x7C9E: 0xDAE8,
	0x7C9F: 0xB5AF,
	0x7CA0: 0xFFFD,
	0x7CA1: 0xDAEA,
	0x7CA2: 0xDAE7,
	0x7CA3: 0xD6E1,
	0x7CA4: 0x85ED,
	0x7CA5: 0xB5B0,
	0x7CA6: 0xFE63,
	0x7CA7: 0xF9DB,
	0x7CA8: 0xDAE9,
	0x7CA9: 0xFFFD,
	0x7CAA: 0x8A41,
	0x7CAB: 0xFAE1,
	0x7CAC: 0xFCE9,
	0x7CAD: 0x94BF,
	0x7CAE: 0x8AEA,
	0x7CAF: 0xDF56,
	0x7CB0: 0xFFFD,
	0x7CB1: 0xB864,
	0x7CB2: 0xDF54,
	0x7CB3: 0xB865,
	0x7CB4: 0xDF55,
	0x7CB5: 0xB866,
	0x7CB6: 0xFFFD,
	0x7CB7: 0xFFFD,
	0x7CB8: 0x96D9,
	0x7CB9: 0xBAE9,
	0x7CBA: 0xE361,
	0x7CBB: 0xE35E,
	0x7CBC: 0xE360,
	0x7CBD: 0xBAEA,
	0x7CBE: 0xBAEB,
	0x7CBF: 0xE35F,
	0x7CC0: 0x94C0,
	0x7CC1: 0x8A43,
	0x7CC2: 0xFCEB,
	0x7CC3: 0x96DA,
	0x7CC4: 0xFFFD,
	0x7CC5: 0xE6DF,
	0x7CC6: 0xFFFD,
	0x7CC7: 0xFCEA,
	0x7CC8: 0xE6E0,
	0x7CC9: 0x95B2,
	0x7CCA: 0xBD6B,
	0x7CCB: 0xE6E2,
	0x7CCC: 0xE6E1,
	0x7CCD: 0xA054,
	0x7CCE: 0xA261,
	0x7CCF: 0xFFFD,
	0x7CD0: 0xEACA,
	0x7CD1: 0xEACB,
	0x7CD2: 0xEAC7,
	0x7CD3: 0xFB7E,
	0x7CD4: 0xEAC8,
	0x7CD5: 0xBF7C,
	0x7CD6: 0xBF7D,
	0x7CD7: 0xEAC9,
	0x7CD8: 0x94C1,
	0x7CD9: 0xC157,
	0x7CDA: 0xFCED,
	0x7CDB: 0xFFFD,
	0x7CDC: 0xC153,
	0x7CDD: 0xC158,
	0x7CDE: 0xC154,
	0x7CDF: 0xC156,
	0x7CE0: 0xC152,
	0x7CE1: 0xFFFD,
	0x7CE2: 0xC155,
	0x7CE3: 0xFFFD,
	0x7CE4: 0xFFFD,
	0x7CE5: 0xFFFD,
	0x7CE6: 0x96DB,
	0x7CE7: 0xC2B3,
	0x7CE8: 0xEDCF,
	0x7CE9: 0xFFFD,
	0x7CEA: 0xF2AE,
	0x7CEB: 0xFFFD,
	0x7CEC: 0xF2AD,
	0x7CED: 0x96DC,
	0x7CEE: 0xF4AB,
	0x7CEF: 0xC47A,
	0x7CF0: 0xC47B,
	0x7CF1: 0xF741,
	0x7CF2: 0xF5E6,
	0x7CF3: 0x96DD,
	0x7CF4: 0xF740,
	0x7CF5: 0x96DE,
	0x7CF6: 0xF8FD,
	0x7CF7: 0xF9A4,
	0x7CF8: 0xA6CD,
	0x7CF9: 0x96DF,
	0x7CFA: 0xFAE2,
	0x7CFB: 0xA874,
	0x7CFC: 0x96E1,
	0x7CFD: 0xCDA9,
	0x7CFE: 0xAAC8,
	0x7CFF: 0xFFFD,
	0x7D00: 0xACF6,
	0x7D01: 0xD04C,
	0x7D02: 0xACF4,
	0x7D03: 0xD04A,
	0x7D04: 0xACF9,
	0x7D05: 0xACF5,
	0x7D06: 0xACFA,
	0x7D07: 0xACF8,
	0x7D08: 0xD04B,
	0x7D09: 0xACF7,
	0x7D0A: 0xAFBF,
	0x7D0B: 0xAFBE,
	0x7D0C: 0xD35A,
	0x7D0D: 0xAFC7,
	0x7D0E: 0xD353,
	0x7D0F: 0xD359,
	0x7D10: 0xAFC3,
	0x7D11: 0xD352,
	0x7D12: 0xD358,
	0x7D13: 0xD356,
	0x7D14: 0xAFC2,
	0x7D15: 0xAFC4,
	0x7D16: 0xD355,
	0x7D17: 0xAFBD,
	0x7D18: 0xD354,
	0x7D19: 0xAFC8,
	0x7D1A: 0xAFC5,
	0x7D1B: 0xAFC9,
	0x7D1C: 0xAFC6,
	0x7D1D: 0xD351,
	0x7D1E: 0xD350,
	0x7D1F: 0xD357,
	0x7D20: 0xAFC0,
	0x7D21: 0xAFBC,
	0x7D22: 0xAFC1,
	0x7D23: 0xFFFD,
	0x7D24: 0xFFFD,
	0x7D25: 0x95E2,
	0x7D26: 0xFFFD,
	0x7D27: 0x86FA,
	0x7D28: 0xD6F0,
	0x7D29: 0xD6E9,
	0x7D2A: 0xFFFD,
	0x7D2B: 0xB5B5,
	0x7D2C: 0xD6E8,
	0x7D2D: 0xFFFD,
	0x7D2E: 0xB2CF,
	0x7D2F: 0xB2D6,
	0x7D30: 0xB2D3,
	0x7D31: 0xB2D9,
	0x7D32: 0xB2D8,
	0x7D33: 0xB2D4,
	0x7D34: 0xFFFD,
	0x7D35: 0xD6E2,
	0x7D36: 0xD6E5,
	0x7D37: 0xFFFD,
	0x7D38: 0xD6E4,
	0x7D39: 0xB2D0,
	0x7D3A: 0xD6E6,
	0x7D3B: 0xD6EF,
	0x7D3C: 0xB2D1,
	0x7D3D: 0xD6E3,
	0x7D3E: 0xD6EC,
	0x7D3F: 0xD6ED,
	0x7D40: 0xB2D2,
	0x7D41: 0xD6EA,
	0x7D42: 0xB2D7,
	0x7D43: 0xB2CD,
	0x7D44: 0xB2D5,
	0x7D45: 0xD6E7,
	0x7D46: 0xB2CC,
	0x7D47: 0xD6EB,
	0x7D48: 0xFAE3,
	0x7D49: 0xFFFD,
	0x7D4A: 0xD6EE,
	0x7D4B: 0xFAE4,
	0x7D4C: 0x92AB,
	0x7D4D: 0xFCEF,
	0x7D4E: 0xDAFB,
	0x7D4F: 0xDAF2,
	0x7D50: 0xB5B2,
	0x7D51: 0xDAF9,
	0x7D52: 0xDAF6,
	0x7D53: 0xDAEE,
	0x7D54: 0xDAF7,
	0x7D55: 0xB5B4,
	0x7D56: 0xDAEF,
	0x7D57: 0xFFFD,
	0x7D58: 0xDAEB,
	0x7D59: 0xFFFD,
	0x7D5A: 0xFCF0,
	0x7D5B: 0xB86C,
	0x7D5C: 0xDAF4,
	0x7D5D: 0xFE60,
	0x7D5E: 0xB5B1,
	0x7D5F: 0xDAFA,
	0x7D60: 0xFFFD,
	0x7D61: 0xB5B8,
	0x7D62: 0xB5BA,
	0x7D63: 0xDAED,
	0x7D64: 0xFFFD,
	0x7D65: 0xFFFD,
	0x7D66: 0xB5B9,
	0x7D67: 0xDAF0,
	0x7D68: 0xB5B3,
	0x7D69: 0xDAF8,
	0x7D6A: 0xDAF1,
	0x7D6B: 0xDAF5,
	0x7D6C: 0xFFFD,
	0x7D6D: 0xDAF3,
	0x7D6E: 0xB5B6,
	0x7D6F: 0xDAEC,
	0x7D70: 0xB5BB,
	0x7D71: 0xB2CE,
	0x7D72: 0xB5B7,
	0x7D73: 0xB5BC,
	0x7D74: 0xFFFD,
	0x7D75: 0x925B,
	0x7D76: 0x9346,
	0x7D77: 0xFAE5,
	0x7D78: 0xFFFD,
	0x7D79: 0xB868,
	0x7D7A: 0xDF5D,
	0x7D7B: 0xDF5F,
	0x7D7C: 0xDF61,
	0x7D7D: 0xDF65,
	0x7D7E: 0xFFFD,
	0x7D7F: 0xDF5B,
	0x7D80: 0xDF59,
	0x7D81: 0xB86A,
	0x7D82: 0xFFFD,
	0x7D83: 0xDF60,
	0x7D84: 0xDF64,
	0x7D85: 0xDF5C,
	0x7D86: 0xDF58,
	0x7D87: 0xFFFD,
	0x7D88: 0xDF57,
	0x7D89: 0x9568,
	0x7D8A: 0xFFFD,
	0x7D8B: 0x96E2,
	0x7D8C: 0xDF62,
	0x7D8D: 0xDF5A,
	0x7D8E: 0xDF5E,
	0x7D8F: 0xB86B,
	0x7D90: 0xFFFD,
	0x7D91: 0xB869,
	0x7D92: 0xDF66,
	0x7D93: 0xB867,
	0x7D94: 0xDF63,
	0x7D95: 0x9DB9,
	0x7D96: 0xE372,
	0x7D97: 0x96E3,
	0x7D98: 0xFFFD,
	0x7D99: 0x92AE,
	0x7D9A: 0x9364,
	0x7D9B: 0x94C2,
	0x7D9C: 0xBAEE,
	0x7D9D: 0xE36A,
	0x7D9E: 0xBD78,
	0x7D9F: 0xE374,
	0x7DA0: 0xBAF1,
	0x7DA1: 0xE378,
	0x7DA2: 0xBAF7,
	0x7DA3: 0xE365,
	0x7DA4: 0x96E4,
	0x7DA5: 0xFFFD,
	0x7DA6: 0xE375,
	0x7DA7: 0xE362,
	0x7DA8: 0x96E5,
	0x7DA9: 0xE377,
	0x7DAA: 0xE366,
	0x7DAB: 0x9556,
	0x7DAC: 0xBAFE,
	0x7DAD: 0xBAFB,
	0x7DAE: 0xE376,
	0x7DAF: 0xE370,
	0x7DB0: 0xBAED,
	0x7DB1: 0xBAF5,
	0x7DB2: 0xBAF4,
	0x7DB3: 0x956A,
	0x7DB4: 0xBAF3,
	0x7DB5: 0xBAF9,
	0x7DB6: 0xFFFD,
	0x7DB7: 0xE363,
	0x7DB8: 0xBAFA,
	0x7DB9: 0xE371,
	0x7DBA: 0xBAF6,
	0x7DBB: 0xBAEC,
	0x7DBC: 0xE373,
	0x7DBD: 0xBAEF,
	0x7DBE: 0xBAF0,
	0x7DBF: 0xBAF8,
	0x7DC0: 0xE368,
	0x7DC1: 0xE367,
	0x7DC2: 0xE364,
	0x7DC3: 0xFFFD,
	0x7DC4: 0xE36C,
	0x7DC5: 0xE369,
	0x7DC6: 0xE36D,
	0x7DC7: 0xBAFD,
	0x7DC8: 0xFFFD,
	0x7DC9: 0xE379,
	0x7DCA: 0xBAF2,
	0x7DCB: 0xE36E,
	0x7DCC: 0xE36F,
	0x7DCD: 0x96E6,
	0x7DCE: 0xE36B,
	0x7DCF: 0x935C,
	0x7DD0: 0x96E7,
	0x7DD1: 0x93E7,
	0x7DD2: 0xBAFC,
	0x7DD3: 0x96E8,
	0x7DD4: 0xFAE6,
	0x7DD5: 0xFAE7,
	0x7DD6: 0xFAE8,
	0x7DD7: 0xE6E7,
	0x7DD8: 0xBD70,
	0x7DD9: 0xBD79,
	0x7DDA: 0xBD75,
	0x7DDB: 0xE6E4,
	0x7DDC: 0x95C3,
	0x7DDD: 0xBD72,
	0x7DDE: 0xBD76,
	0x7DDF: 0xE6F0,
	0x7DE0: 0xBD6C,
	0x7DE1: 0xE6E8,
	0x7DE2: 0xFFFD,
	0x7DE3: 0xBD74,
	0x7DE4: 0xFAE9,
	0x7DE5: 0x96E9,
	0x7DE6: 0xE6EB,
	0x7DE7: 0xE6E6,
	0x7DE8: 0xBD73,
	0x7DE9: 0xBD77,
	0x7DEA: 0xE6E5,
	0x7DEB: 0xFFFD,
	0x7DEC: 0xBD71,
	0x7DED: 0xFFFD,
	0x7DEE: 0xE6EF,
	0x7DEF: 0xBD6E,
	0x7DF0: 0xE6EE,
	0x7DF1: 0xE6ED,
	0x7DF2: 0xBD7A,
	0x7DF3: 0xE572,
	0x7DF4: 0xBD6D,
	0x7DF5: 0xFCF1,
	0x7DF6: 0xE6EC,
	0x7DF7: 0xE6E3,
	0x7DF8: 0xFFFD,
	0x7DF9: 0xBD7B,
	0x7DFA: 0xE6EA,
	0x7DFB: 0xBD6F,
	0x7DFC: 0xFFFD,
	0x7DFD: 0x96EA,
	0x7DFE: 0x9F7E,
	0x7DFF: 0xFFFD,
	0x7E00: 0xFFFD,
	0x7E01: 0x924D,
	0x7E02: 0xFFFD,
	0x7E03: 0xE6E9,
	0x7E04: 0x92ED,
	0x7E05: 0x94C3,
	0x7E06: 0xFFFD,
	0x7E07: 0x9FA1,
	0x7E08: 0xBFA2,
	0x7E09: 0xBFA7,
	0x7E0A: 0xBF7E,
	0x7E0B: 0xEAD8,
	0x7E0C: 0xEACF,
	0x7E0D: 0xEADB,
	0x7E0E: 0xEAD3,
	0x7E0F: 0xEAD9,
	0x7E10: 0xBFA8,
	0x7E11: 0xBFA1,
	0x7E12: 0xEACC,
	0x7E13: 0xEAD2,
	0x7E14: 0xEADC,
	0x7E15: 0xEAD5,
	0x7E16: 0xEADA,
	0x7E17: 0xEACE,
	0x7E18: 0xFFFD,
	0x7E19: 0xFFFD,
	0x7E1A: 0xEAD6,
	0x7E1B: 0xBFA3,
	0x7E1C: 0xEAD4,
	0x7E1D: 0xBFA6,
	0x7E1E: 0xBFA5,
	0x7E1F: 0xEAD0,
	0x7E20: 0xEAD1,
	0x7E21: 0xEACD,
	0x7E22: 0xEAD7,
	0x7E23: 0xBFA4,
	0x7E24: 0xEADE,
	0x7E25: 0xEADD,
	0x7E26: 0x92DF,
	0x7E27: 0xFCF2,
	0x7E28: 0xFFFD,
	0x7E29: 0xEDDA,
	0x7E2A: 0xEDD6,
	0x7E2B: 0xC15F,
	0x7E2C: 0xFFFD,
	0x7E2D: 0xEDD0,
	0x7E2E: 0xC159,
	0x7E2F: 0xC169,
	0x7E30: 0xEDDC,
	0x7E31: 0xC161,
	0x7E32: 0xC15D,
	0x7E33: 0xEDD3,
	0x7E34: 0xC164,
	0x7E35: 0xC167,
	0x7E36: 0xEDDE,
	0x7E37: 0xC15C,
	0x7E38: 0xEDD5,
	0x7E39: 0xC165,
	0x7E3A: 0xEDE0,
	0x7E3B: 0xEDDD,
	0x7E3C: 0xEDD1,
	0x7E3D: 0xC160,
	0x7E3E: 0xC15A,
	0x7E3F: 0xC168,
	0x7E40: 0xEDD8,
	0x7E41: 0xC163,
	0x7E42: 0xEDD2,
	0x7E43: 0xC15E,
	0x7E44: 0xEDDF,
	0x7E45: 0xC162,
	0x7E46: 0xC15B,
	0x7E47: 0xEDD9,
	0x7E48: 0xC166,
	0x7E49: 0xEDD7,
	0x7E4A: 0x934F,
	0x7E4B: 0x825A,
	0x7E4C: 0xEDDB,
	0x7E4D: 0xFAEA,
	0x7E4E: 0xFFFD,
	0x7E4F: 0xFFFD,
	0x7E50: 0xF06E,
	0x7E51: 0xF074,
	0x7E52: 0xC2B9,
	0x7E53: 0xF077,
	0x7E54: 0xC2B4,
	0x7E55: 0xC2B5,
	0x7E56: 0xF06F,
	0x7E57: 0xF076,
	0x7E58: 0xF071,
	0x7E59: 0xC2BA,
	0x7E5A: 0xC2B7,
	0x7E5B: 0x9FA2,
	0x7E5C: 0xF06D,
	0x7E5D: 0xFAEB,
	0x7E5E: 0xC2B6,
	0x7E5F: 0xF073,
	0x7E60: 0xF075,
	0x7E61: 0xC2B8,
	0x7E62: 0xF072,
	0x7E63: 0xF070,
	0x7E64: 0xFFFD,
	0x7E65: 0x9FA3,
	0x7E66: 0x8A50,
	0x7E67: 0x94C4,
	0x7E68: 0xF2B8,
	0x7E69: 0xC3B7,
	0x7E6A: 0xC3B8,
	0x7E6B: 0xC3B4,
	0x7E6C: 0x9FA4,
	0x7E6D: 0xC3B5,
	0x7E6E: 0x8CE8,
	0x7E6F: 0xF2B4,
	0x7E70: 0xF2B2,
	0x7E71: 0xFFFD,
	0x7E72: 0xF2B6,
	0x7E73: 0xC3BA,
	0x7E74: 0xF2B7,
	0x7E75: 0xF2B0,
	0x7E76: 0xF2AF,
	0x7E77: 0xF2B3,
	0x7E78: 0xF2B1,
	0x7E79: 0xC3B6,
	0x7E7A: 0xF2B5,
	0x7E7B: 0xF4AC,
	0x7E7C: 0xC47E,
	0x7E7D: 0xC47D,
	0x7E7E: 0xF4AD,
	0x7E7F: 0xFAEC,
	0x7E80: 0xF4AF,
	0x7E81: 0xF4AE,
	0x7E82: 0xC4A1,
	0x7E83: 0x94C5,
	0x7E84: 0xFFFD,
	0x7E85: 0xFFFD,
	0x7E86: 0xF5EB,
	0x7E87: 0xF5E8,
	0x7E88: 0xF5E9,
	0x7E89: 0xFAED,
	0x7E8A: 0xF5E7,
	0x7E8B: 0xF5EA,
	0x7E8C: 0xC4F2,
	0x7E8D: 0xF5EC,
	0x7E8E: 0xFAEE,
	0x7E8F: 0xC4F1,
	0x7E90: 0x94C6,
	0x7E91: 0xF742,
	0x7E92: 0xFAEF,
	0x7E93: 0xC5D5,
	0x7E94: 0xC5D7,
	0x7E95: 0xF7EE,
	0x7E96: 0xC5D6,
	0x7E97: 0xF8B9,
	0x7E98: 0xF940,
	0x7E99: 0xF942,
	0x7E9A: 0xF8FE,
	0x7E9B: 0xF941,
	0x7E9C: 0xC66C,
	0x7E9D: 0xFFFD,
	0x7E9E: 0xFFFD,
	0x7E9F: 0x9CEB,
	0x7EA0: 0x835F,
	0x7EA1: 0x8376,
	0x7EA2: 0x8371,
	0x7EA3: 0x8370,
	0x7EA4: 0x8A4E,
	0x7EA5: 0x8374,
	0x7EA6: 0x8375,
	0x7EA7: 0x83CB,
	0x7EA8: 0x8DBE,
	0x7EA9: 0x9044,
	0x7EAA: 0x8372,
	0x7EAB: 0x8373,
	0x7EAC: 0x87FE,
	0x7EAD: 0x83CC,
	0x7EAE: 0xFFFD,
	0x7EAF: 0x83C8,
	0x7EB0: 0x83CA,
	0x7EB1: 0x83C6,
	0x7EB2: 0x86FC,
	0x7EB3: 0x83CD,
	0x7EB4: 0xFFFD,
	0x7EB5: 0x8A4C,
	0x7EB6: 0x8741,
	0x7EB7: 0x83CF,
	0x7EB8: 0x83CE,
	0x7EB9: 0x83C7,
	0x7EBA: 0x83C5,
	0x7EBB: 0xFFFD,
	0x7EBC: 0xFFFD,
	0x7EBD: 0x83C9,
	0x7EBE: 0x8DC5,
	0x7EBF: 0x8845,
	0x7EC0: 0x8DD3,
	0x7EC1: 0x8471,
	0x7EC2: 0x8472,
	0x7EC3: 0x87FD,
	0x7EC4: 0x846F,
	0x7EC5: 0x846E,
	0x7EC6: 0x846D,
	0x7EC7: 0x8AEB,
	0x7EC8: 0x8470,
	0x7EC9: 0x8953,
	0x7ECA: 0x8468,
	0x7ECB: 0x846B,
	0x7ECC: 0x846C,
	0x7ECD: 0x846A,
	0x7ECE: 0x8BB1,
	0x7ECF: 0x85EE,
	0x7ED0: 0x8DD4,
	0x7ED1: 0x85F0,
	0x7ED2: 0x8544,
	0x7ED3: 0x8543,
	0x7ED4: 0xFAF0,
	0x7ED5: 0x8AED,
	0x7ED6: 0x854A,
	0x7ED7: 0x8DE4,
	0x7ED8: 0x8BB3,
	0x7ED9: 0x8548,
	0x7EDA: 0x8549,
	0x7EDB: 0x854B,
	0x7EDC: 0x8547,
	0x7EDD: 0x8545,
	0x7EDE: 0x8542,
	0x7EDF: 0x8469,
	0x7EE0: 0x8E4A,
	0x7EE1: 0x8E4B,
	0x7EE2: 0x85EF,
	0x7EE3: 0x8AEF,
	0x7EE4: 0xFFFD,
	0x7EE5: 0x85F1,
	0x7EE6: 0x85F2,
	0x7EE7: 0x8C49,
	0x7EE8: 0x8E49,
	0x7EE9: 0x8A45,
	0x7EEA: 0x8743,
	0x7EEB: 0x86F8,
	0x7EEC: 0xFFFD,
	0x7EED: 0x8CA2,
	0x7EEE: 0x86FD,
	0x7EEF: 0x8E7B,
	0x7EF0: 0x86F7,
	0x7EF1: 0xFAF1,
	0x7EF2: 0x8E7A,
	0x7EF3: 0x8BB2,
	0x7EF4: 0x8742,
	0x7EF5: 0x8740,
	0x7EF6: 0x8745,
	0x7EF7: 0x8A49,
	0x7EF8: 0x86FE,
	0x7EF9: 0xFFFD,
	0x7EFA: 0x8E7C,
	0x7EFB: 0x8E79,
	0x7EFC: 0x86F6,
	0x7EFD: 0x86F4,
	0x7EFE: 0x86F5,
	0x7EFF: 0x86F9,
	0x7F00: 0x86FB,
	0x7F01: 0x8744,
	0x7F02: 0x8849,
	0x7F03: 0x8EC2,
	0x7F04: 0x8840,
	0x7F05: 0x8841,
	0x7F06: 0x8DA3,
	0x7F07: 0x884B,
	0x7F08: 0x884A,
	0x7F09: 0x8842,
	0x7F0A: 0xFFFD,
	0x7F0B: 0x8F79,
	0x7F0C: 0x8EC4,
	0x7F0D: 0x8848,
	0x7F0E: 0x8846,
	0x7F0F: 0x8EC5,
	0x7F10: 0xFFFD,
	0x7F11: 0x8EC6,
	0x7F12: 0xFAF2,
	0x7F13: 0x8847,
	0x7F14: 0x87FC,
	0x7F15: 0x8A47,
	0x7F16: 0x8843,
	0x7F17: 0x8EC3,
	0x7F18: 0x8844,
	0x7F19: 0x8952,
	0x7F1A: 0x894E,
	0x7F1B: 0x8EF0,
	0x7F1C: 0x8951,
	0x7F1D: 0x8A4A,
	0x7F1E: 0xFFFD,
	0x7F1F: 0x8950,
	0x7F20: 0x8CA1,
	0x7F21: 0x8F5D,
	0x7F22: 0x894B,
	0x7F23: 0x894C,
	0x7F24: 0x8C48,
	0x7F25: 0x8A4F,
	0x7F26: 0x8A51,
	0x7F27: 0x8A48,
	0x7F28: 0x8CFB,
	0x7F29: 0x8A44,
	0x7F2A: 0x8A46,
	0x7F2B: 0x8A4D,
	0x7F2C: 0x9045,
	0x7F2D: 0x8AEE,
	0x7F2E: 0x8AEC,
	0x7F2F: 0x8AF0,
	0x7F30: 0xFAF3,
	0x7F31: 0x8FDE,
	0x7F32: 0x8FBF,
	0x7F33: 0x8FC0,
	0x7F34: 0x8BB5,
	0x7F35: 0x907C,
	0x7F36: 0xA6CE,
	0x7F37: 0x9FA5,
	0x7F38: 0xACFB,
	0x7F39: 0xD26F,
	0x7F3A: 0xAFCA,
	0x7F3B: 0xFFFD,
	0x7F3C: 0xFFFD,
	0x7F3D: 0xB2DA,
	0x7F3E: 0xDAFC,
	0x7F3F: 0xDAFD,
	0x7F40: 0x9FA6,
	0x7F41: 0x9FA7,
	0x7F42: 0x8C4A,
	0x7F43: 0xEADF,
	0x7F44: 0xC16A,
	0x7F45: 0xEDE1,
	0x7F46: 0xFFFD,
	0x7F47: 0x9574,
	0x7F48: 0xC2BB,
	0x7F49: 0x9FA8,
	0x7F4A: 0xF2BA,
	0x7F4B: 0xF2B9,
	0x7F4C: 0xC4A2,
	0x7F4D: 0xF5ED,
	0x7F4E: 0xFBAA,
	0x7F4F: 0xF743,
	0x7F50: 0xC5F8,
	0x7F51: 0xCA49,
	0x7F52: 0x9FA9,
	0x7F53: 0x9D75,
	0x7F54: 0xAAC9,
	0x7F55: 0xA875,
	0x7F56: 0xFFFD,
	0x7F57: 0x8BB4,
	0x7F58: 0xD04D,
	0x7F59: 0xFFFD,
	0x7F5A: 0x8746,
	0x7F5B: 0xD360,
	0x7F5C: 0xD35B,
	0x7F5D: 0xD35F,
	0x7F5E: 0xD35D,
	0x7F5F: 0xAFCB,
	0x7F60: 0xD35E,
	0x7F61: 0xD35C,
	0x7F62: 0x884D,
	0x7F63: 0xD6F1,
	0x7F64: 0xFFFD,
	0x7F65: 0xDAFE,
	0x7F66: 0xDB40,
	0x7F67: 0xDF69,
	0x7F68: 0xDF6A,
	0x7F69: 0xB86E,
	0x7F6A: 0xB86F,
	0x7F6B: 0xDF68,
	0x7F6C: 0xDF6B,
	0x7F6D: 0xDF67,
	0x7F6E: 0xB86D,
	0x7F6F: 0xFFFD,
	0x7F70: 0xBB40,
	0x7F71: 0xFAF4,
	0x7F72: 0xB870,
	0x7F73: 0xE37A,
	0x7F74: 0x8FC1,
	0x7F75: 0xBD7C,
	0x7F76: 0xE6F1,
	0x7F77: 0xBD7D,
	0x7F78: 0x9564,
	0x7F79: 0xBFA9,
	0x7F7A: 0xEAE2,
	0x7F7B: 0xEAE0,
	0x7F7C: 0xEAE1,
	0x7F7D: 0xEDE4,
	0x7F7E: 0xEDE3,
	0x7F7F: 0xEDE2,
	0x7F80: 0xFFFD,
	0x7F81: 0x8D56,
	0x7F82: 0xFAF5,
	0x7F83: 0xF2BB,
	0x7F84: 0xFFFD,
	0x7F85: 0xC3B9,
	0x7F86: 0xF2BC,
	0x7F87: 0xF744,
	0x7F88: 0xC5F9,
	0x7F89: 0xF8BA,
	0x7F8A: 0xA6CF,
	0x7F8B: 0xAACB,
	0x7F8C: 0xAACA,
	0x7F8D: 0xD04F,
	0x7F8E: 0xACFC,
	0x7F8F: 0x9FAA,
	0x7F90: 0xFFFD,
	0x7F91: 0xD04E,
	0x7F92: 0xD362,
	0x7F93: 0x9FAB,
	0x7F94: 0xAFCC,
	0x7F95: 0xD6F2,
	0x7F96: 0xD361,
	0x7F97: 0x95E0,
	0x7F98: 0xFFFD,
	0x7F99: 0xFFFD,
	0x7F9A: 0xB2DC,
	0x7F9B: 0xD6F5,
	0x7F9C: 0xD6F3,
	0x7F9D: 0xD6F4,
	0x7F9E: 0xB2DB,
	0x7F9F: 0x8E4C,
	0x7FA0: 0xDB42,
	0x7FA1: 0xDB43,
	0x7FA2: 0xDB41,
	0x7FA3: 0x9555,
	0x7FA4: 0xB873,
	0x7FA5: 0xDF6D,
	0x7FA6: 0xDF6C,
	0x7FA7: 0xDF6E,
	0x7FA8: 0xB872,
	0x7FA9: 0xB871,
	0x7FAA: 0xFFFD,
	0x7FAB: 0xFFFD,
	0x7FAC: 0xE6F2,
	0x7FAD: 0xE6F4,
	0x7FAE: 0xFAF6,
	0x7FAF: 0xBD7E,
	0x7FB0: 0xE6F3,
	0x7FB1: 0xEAE3,
	0x7FB2: 0xBFAA,
	0x7FB3: 0xF079,
	0x7FB4: 0x9FAC,
	0x7FB5: 0xF078,
	0x7FB6: 0xC3BB,
	0x7FB7: 0xF2BD,
	0x7FB8: 0xC3BD,
	0x7FB9: 0xC3BC,
	0x7FBA: 0xF4B0,
	0x7FBB: 0xF5EE,
	0x7FBC: 0xC4F3,
	0x7FBD: 0xA6D0,
	0x7FBE: 0xD050,
	0x7FBF: 0xACFD,
	0x7FC0: 0xD365,
	0x7FC1: 0xAFCE,
	0x7FC2: 0xD364,
	0x7FC3: 0xD363,
	0x7FC4: 0xFFFD,
	0x7FC5: 0xAFCD,
	0x7FC6: 0xFAF7,
	0x7FC7: 0xD6FB,
	0x7FC8: 0xFFFD,
	0x7FC9: 0xD6FD,
	0x7FCA: 0xD6F6,
	0x7FCB: 0xD6F7,
	0x7FCC: 0xB2DD,
	0x7FCD: 0xD6F8,
	0x7FCE: 0xB2DE,
	0x7FCF: 0xD6FC,
	0x7FD0: 0xD6F9,
	0x7FD1: 0xD6FA,
	0x7FD2: 0xB2DF,
	0x7FD3: 0xFFFD,
	0x7FD4: 0xB5BE,
	0x7FD5: 0xB5BF,
	0x7FD6: 0xFFFD,
	0x7FD7: 0xDB44,
	0x7FD8: 0x8AF1,
	0x7FD9: 0xFFFD,
	0x7FDA: 0xFFFD,
	0x7FDB: 0xDF6F,
	0x7FDC: 0xDF70,
	0x7FDD: 0x9FAD,
	0x7FDE: 0xE37E,
	0x7FDF: 0xBB43,
	0x7FE0: 0xBB41,
	0x7FE1: 0xBB42,
	0x7FE2: 0xE37B,
	0x7FE3: 0xE37C,
	0x7FE4: 0xFFFD,
	0x7FE5: 0xE37D,
	0x7FE6: 0xE6F9,
	0x7FE7: 0x9FAE,
	0x7FE8: 0xE6FA,
	0x7FE9: 0xBDA1,
	0x7FEA: 0xE6F7,
	0x7FEB: 0xE6F6,
	0x7FEC: 0xE6F8,
	0x7FED: 0xE6F5,
	0x7FEE: 0xBFAD,
	0x7FEF: 0xEAE4,
	0x7FF0: 0xBFAB,
	0x7FF1: 0xBFAC,
	0x7FF2: 0xEDE6,
	0x7FF3: 0xC16B,
	0x7FF4: 0xEDE5,
	0x7FF5: 0xEFA8,
	0x7FF6: 0xFFFD,
	0x7FF7: 0xF07A,
	0x7FF8: 0xF07B,
	0x7FF9: 0xC2BC,
	0x7FFA: 0x9FAF,
	0x7FFB: 0xC2BD,
	0x7FFC: 0xC16C,
	0x7FFD: 0xF2BE,
	0x7FFE: 0xF2BF,
	0x7FFF: 0xF4B1,
	0x8000: 0xC4A3,
	0x8001: 0xA6D1,
	0x8002: 0x9FB0,
	0x8003: 0xA6D2,
	0x8004: 0xACFE,
	0x8005: 0xAACC,
	0x8006: 0xAFCF,
	0x8007: 0xD051,
	0x8008: 0x9FB1,
	0x8009: 0xFFFD,
	0x800A: 0xFFFD,
	0x800B: 0xB5C0,
	0x800C: 0xA6D3,
	0x800D: 0xAD41,
	0x800E: 0xD052,
	0x800F: 0xD053,
	0x8010: 0xAD40,
	0x8011: 0xAD42,
	0x8012: 0xA6D4,
	0x8013: 0xFFFD,
	0x8014: 0xD054,
	0x8015: 0xAFD1,
	0x8016: 0xD366,
	0x8017: 0xAFD3,
	0x8018: 0xAFD0,
	0x8019: 0xAFD2,
	0x801A: 0xFFFD,
	0x801B: 0xD741,
	0x801C: 0xB2E0,
	0x801D: 0xFCF6,
	0x801E: 0xD740,
	0x801F: 0xD6FE,
	0x8020: 0xFAF8,
	0x8021: 0xDF71,
	0x8022: 0xFAF9,
	0x8023: 0xFFFD,
	0x8024: 0xE3A1,
	0x8025: 0xFAFA,
	0x8026: 0xBDA2,
	0x8027: 0x8F5E,
	0x8028: 0xBFAE,
	0x8029: 0xEAE6,
	0x802A: 0xEAE5,
	0x802B: 0xFFFD,
	0x802C: 0xEDE7,
	0x802D: 0xFFFD,
	0x802E: 0x9FB2,
	0x802F: 0x9FB3,
	0x8030: 0xF5EF,
	0x8031: 0xFAFB,
	0x8032: 0xFFFD,
	0x8033: 0xA6D5,
	0x8034: 0xCB73,
	0x8035: 0xCDAA,
	0x8036: 0xAD43,
	0x8037: 0xD055,
	0x8038: 0x8A55,
	0x8039: 0xD368,
	0x803A: 0xFFFD,
	0x803B: 0x955C,
	0x803C: 0x9FB4,
	0x803D: 0xAFD4,
	0x803E: 0xD367,
	0x803F: 0xAFD5,
	0x8040: 0xFFFD,
	0x8041: 0xFFFD,
	0x8042: 0x8AF3,
	0x8043: 0xD743,
	0x8044: 0xFFFD,
	0x8045: 0xFFFD,
	0x8046: 0xB2E2,
	0x8047: 0xD742,
	0x8048: 0xD744,
	0x8049: 0xFFFD,
	0x804A: 0xB2E1,
	0x804B: 0x8CD9,
	0x804C: 0x8AF2,
	0x804D: 0x8FDF,
	0x804E: 0xFFFD,
	0x804F: 0xDB46,
	0x8050: 0xDB47,
	0x8051: 0xDB45,
	0x8052: 0xB5C1,
	0x8053: 0xFFFD,
	0x8054: 0x8A54,
	0x8055: 0xFFFD,
	0x8056: 0xB874,
	0x8057: 0xFFFD,
	0x8058: 0xB875,
	0x8059: 0xFFFD,
	0x805A: 0xBB45,
	0x805B: 0xFCFA,
	0x805C: 0xE3A3,
	0x805D: 0xE3A2,
	0x805E: 0xBB44,
	0x805F: 0xFAFC,
	0x8060: 0xFFFD,
	0x8061: 0x826B,
	0x8062: 0xFCF7,
	0x8063: 0xFCF8,
	0x8064: 0xE6FB,
	0x8065: 0xFFFD,
	0x8066: 0xFCF9,
	0x8067: 0xE6FC,
	0x8068: 0xFAFD,
	0x8069: 0x8F7A,
	0x806A: 0x8A53,
	0x806B: 0xFFFD,
	0x806C: 0xEAE7,
	0x806D: 0xFFFD,
	0x806E: 0xFFFD,
	0x806F: 0xC170,
	0x8070: 0xC16F,
	0x8071: 0xC16D,
	0x8072: 0xC16E,
	0x8073: 0xC171,
	0x8074: 0x9377,
	0x8075: 0xF07C,
	0x8076: 0xC2BF,
	0x8077: 0xC2BE,
	0x8078: 0xF2C0,
	0x8079: 0xF4B2,
	0x807A: 0xFFFD,
	0x807B: 0xFFFD,
	0x807C: 0xFFFD,
	0x807D: 0xC5A5,
	0x807E: 0xC5A4,
	0x807F: 0xA6D6,
	0x8080: 0x91D5,
	0x8081: 0xFFFD,
	0x8082: 0xD1FB,
	0x8083: 0x854C,
	0x8084: 0xB877,
	0x8085: 0xB5C2,
	0x8086: 0xB876,
	0x8087: 0xBB46,
	0x8088: 0xFFFD,
	0x8089: 0xA6D7,
	0x808A: 0xC9A9,
	0x808B: 0xA6D8,
	0x808C: 0xA6D9,
	0x808D: 0xFFFD,
	0x808E: 0xFFFD,
	0x808F: 0xCDAB,
	0x8090: 0xCB76,
	0x8091: 0xFFFD,
	0x8092: 0xCB77,
	0x8093: 0xA877,
	0x8094: 0xFFFD,
	0x8095: 0xCB74,
	0x8096: 0xA876,
	0x8097: 0xFFFD,
	0x8098: 0xA879,
	0x8099: 0xCB75,
	0x809A: 0xA87B,
	0x809B: 0xA87A,
	0x809C: 0xCB78,
	0x809D: 0xA878,
	0x809E: 0xFFFD,
	0x809F: 0x96AF,
	0x80A0: 0x85F6,
	0x80A1: 0xAAD1,
	0x80A2: 0xAACF,
	0x80A3: 0xCDAD,
	0x80A4: 0x884F,
	0x80A5: 0xAACE,
	0x80A6: 0xFCFB,
	0x80A7: 0x9FB5,
	0x80A8: 0xFFFD,
	0x80A9: 0xAAD3,
	0x80AA: 0xAAD5,
	0x80AB: 0xAAD2,
	0x80AC: 0xFAFE,
	0x80AD: 0xCDB0,
	0x80AE: 0xCDAC,
	0x80AF: 0xAAD6,
	0x80B0: 0xFFFD,
	0x80B1: 0xAAD0,
	0x80B2: 0xA87C,
	0x80B3: 0xFFFD,
	0x80B4: 0xAAD4,
	0x80B5: 0xCDAF,
	0x80B6: 0xFB4D,
	0x80B7: 0xFB40,
	0x80B8: 0xCDAE,
	0x80B9: 0xFFFD,
	0x80BA: 0xAACD,
	0x80BB: 0xFFFD,
	0x80BC: 0x96CB,
	0x80BD: 0x96A6,
	0x80BE: 0x854D,
	0x80BF: 0x85F8,
	0x80C0: 0x854E,
	0x80C1: 0x83D0,
	0x80C2: 0xD05B,
	0x80C3: 0xAD47,
	0x80C4: 0xAD48,
	0x80C5: 0xD05D,
	0x80C6: 0x8A57,
	0x80C7: 0xD057,
	0x80C8: 0xD05A,
	0x80C9: 0xD063,
	0x80CA: 0xD061,
	0x80CB: 0xFFFD,
	0x80CC: 0xAD49,
	0x80CD: 0xD067,
	0x80CE: 0xAD4C,
	0x80CF: 0xD064,
	0x80D0: 0xD05C,
	0x80D1: 0xD059,
	0x80D2: 0xFFFD,
	0x80D3: 0xFFFD,
	0x80D4: 0xDB49,
	0x80D5: 0xD062,
	0x80D6: 0xAD44,
	0x80D7: 0xD065,
	0x80D8: 0xD056,
	0x80D9: 0xD05F,
	0x80DA: 0xAD46,
	0x80DB: 0xAD4B,
	0x80DC: 0xD060,
	0x80DD: 0xAD4F,
	0x80DE: 0xAD4D,
	0x80DF: 0xFFFD,
	0x80E0: 0xD058,
	0x80E1: 0xAD4A,
	0x80E2: 0xFFFD,
	0x80E3: 0xD05E,
	0x80E4: 0xAD4E,
	0x80E5: 0xAD45,
	0x80E6: 0xD066,
	0x80E7: 0x8BF8,
	0x80E8: 0xFDFB,
	0x80E9: 0xFDFC,
	0x80EA: 0x8C4B,
	0x80EB: 0x8DD5,
	0x80EC: 0xFDFD,
	0x80ED: 0xAFDA,
	0x80EE: 0xFFFD,
	0x80EF: 0xAFE3,
	0x80F0: 0xAFD8,
	0x80F1: 0xAFD6,
	0x80F2: 0xD36A,
	0x80F3: 0xAFDE,
	0x80F4: 0xAFDB,
	0x80F5: 0xD36C,
	0x80F6: 0x884E,
	0x80F7: 0xFFFD,
	0x80F8: 0xAFDD,
	0x80F9: 0xD36B,
	0x80FA: 0xD369,
	0x80FB: 0xD36E,
	0x80FC: 0xAFE2,
	0x80FD: 0xAFE0,
	0x80FE: 0xDB48,
	0x80FF: 0xFFFD,
	0x8100: 0xD36F,
	0x8101: 0xD36D,
	0x8102: 0xAFD7,
	0x8103: 0xFCFC,
	0x8104: 0xFFFD,
	0x8105: 0xAFD9,
	0x8106: 0xAFDC,
	0x8107: 0xFE48,
	0x8108: 0xAFDF,
	0x8109: 0x83D1,
	0x810A: 0xAFE1,
	0x810B: 0xFFFD,
	0x810C: 0x9FB6,
	0x810D: 0x8A59,
	0x810E: 0xFDFE,
	0x810F: 0x8CDA,
	0x8110: 0x8AF4,
	0x8111: 0x85F9,
	0x8112: 0xFEEE,
	0x8113: 0x8A56,
	0x8114: 0x907D,
	0x8115: 0xD74E,
	0x8116: 0xB2E4,
	0x8117: 0x95A8,
	0x8118: 0xD745,
	0x8119: 0xD747,
	0x811A: 0x85F7,
	0x811B: 0xD748,
	0x811C: 0xFFFD,
	0x811D: 0xD750,
	0x811E: 0xD74C,
	0x811F: 0xD74A,
	0x8120: 0xFFFD,
	0x8121: 0xD74D,
	0x8122: 0xD751,
	0x8123: 0xB2E5,
	0x8124: 0xB2E9,
	0x8125: 0xD746,
	0x8126: 0xFFFD,
	0x8127: 0xD74F,
	0x8128: 0xFFFD,
	0x8129: 0xB2E7,
	0x812A: 0x9FB7,
	0x812B: 0xB2E6,
	0x812C: 0xD74B,
	0x812D: 0xD749,
	0x812E: 0xFFFD,
	0x812F: 0xB2E3,
	0x8130: 0xB2E8,
	0x8131: 0xFEEF,
	0x8132: 0x96A5,
	0x8133: 0x93B0,
	0x8134: 0x9FB8,
	0x8135: 0xFFFD,
	0x8136: 0xFEF0,
	0x8137: 0xA042,
	0x8138: 0x8A58,
	0x8139: 0xB5C8,
	0x813A: 0xDB51,
	0x813B: 0xFFFD,
	0x813C: 0xFFFD,
	0x813D: 0xDB4F,
	0x813E: 0xB5CA,
	0x813F: 0xFFFD,
	0x8140: 0xFFFD,
	0x8141: 0xFFFD,
	0x8142: 0x9FB9,
	0x8143: 0xDB4A,
	0x8144: 0xDFA1,
	0x8145: 0xFFFD,
	0x8146: 0xB5C9,
	0x8147: 0xDB4E,
	0x8148: 0x96AB,
	0x8149: 0xFFFD,
	0x814A: 0xDB4B,
	0x814B: 0xB5C5,
	0x814C: 0xB5CB,
	0x814D: 0xDB50,
	0x814E: 0xB5C7,
	0x814F: 0xDB4D,
	0x8150: 0xBB47,
	0x8151: 0xB5C6,
	0x8152: 0xDB4C,
	0x8153: 0xB5CC,
	0x8154: 0xB5C4,
	0x8155: 0xB5C3,
	0x8156: 0x9FBA,
	0x8157: 0xFFFD,
	0x8158: 0xFFFD,
	0x8159: 0x96AE,
	0x815A: 0x96A2,
	0x815B: 0xDF77,
	0x815C: 0xDF75,
	0x815D: 0xFFFD,
	0x815E: 0xDF7B,
	0x815F: 0xFEF1,
	0x8160: 0xDF73,
	0x8161: 0xDFA2,
	0x8162: 0xDF78,
	0x8163: 0xFFFD,
	0x8164: 0xDF72,
	0x8165: 0xB87B,
	0x8166: 0xB8A3,
	0x8167: 0xDF7D,
	0x8168: 0xFFFD,
	0x8169: 0xDF76,
	0x816A: 0xFFFD,
	0x816B: 0xB87E,
	0x816C: 0x9DD0,
	0x816D: 0xFEF2,
	0x816E: 0xB87C,
	0x816F: 0xDF7E,
	0x8170: 0xB879,
	0x8171: 0xB878,
	0x8172: 0xDF79,
	0x8173: 0xB87D,
	0x8174: 0xB5CD,
	0x8175: 0xFFFD,
	0x8176: 0xDF7C,
	0x8177: 0xDF74,
	0x8178: 0xB87A,
	0x8179: 0xB8A1,
	0x817A: 0xB8A2,
	0x817B: 0x8954,
	0x817C: 0x89AE,
	0x817D: 0xFEF3,
	0x817E: 0x8C65,
	0x817F: 0xBB4C,
	0x8180: 0xBB48,
	0x8181: 0xFFFD,
	0x8182: 0xBB4D,
	0x8183: 0xE3A6,
	0x8184: 0x9FBB,
	0x8185: 0xFFFD,
	0x8186: 0xE3A5,
	0x8187: 0xE3A7,
	0x8188: 0xBB4A,
	0x8189: 0xE3A4,
	0x818A: 0xBB4B,
	0x818B: 0xE3AA,
	0x818C: 0xE3A9,
	0x818D: 0xE3A8,
	0x818E: 0xFFFD,
	0x818F: 0xBB49,
	0x8190: 0xFFFD,
	0x8191: 0x8AF5,
	0x8192: 0xFFFD,
	0x8193: 0xFEF4,
	0x8194: 0xFFFD,
	0x8195: 0xE741,
	0x8196: 0xFFFD,
	0x8197: 0xE744,
	0x8198: 0xBDA8,
	0x8199: 0xE743,
	0x819A: 0xBDA7,
	0x819B: 0xBDA3,
	0x819C: 0xBDA4,
	0x819D: 0xBDA5,
	0x819E: 0xE740,
	0x819F: 0xE6FE,
	0x81A0: 0xBDA6,
	0x81A1: 0xFFFD,
	0x81A2: 0xE742,
	0x81A3: 0xE6FD,
	0x81A4: 0x94C7,
	0x81A5: 0x9FBC,
	0x81A6: 0xEAE9,
	0x81A7: 0xEAF3,
	0x81A8: 0xBFB1,
	0x81A9: 0xBFB0,
	0x81AA: 0xFEF5,
	0x81AB: 0xEAED,
	0x81AC: 0xEAEF,
	0x81AD: 0xFFFD,
	0x81AE: 0xEAEA,
	0x81AF: 0xFFFD,
	0x81B0: 0xEAEE,
	0x81B1: 0xEAE8,
	0x81B2: 0xEAF1,
	0x81B3: 0xBFAF,
	0x81B4: 0xEAF0,
	0x81B5: 0xEAEC,
	0x81B6: 0xFB6E,
	0x81B7: 0xEAF2,
	0x81B8: 0xFEF6,
	0x81B9: 0xEAEB,
	0x81BA: 0xC174,
	0x81BB: 0xEDE8,
	0x81BC: 0xEDEE,
	0x81BD: 0xC178,
	0x81BE: 0xC17A,
	0x81BF: 0xC177,
	0x81C0: 0xC176,
	0x81C1: 0xFEF7,
	0x81C2: 0xC175,
	0x81C3: 0xC173,
	0x81C4: 0xEDE9,
	0x81C5: 0xEDEC,
	0x81C6: 0xC172,
	0x81C7: 0xEDED,
	0x81C8: 0xFCFE,
	0x81C9: 0xC179,
	0x81CA: 0xEDEB,
	0x81CB: 0xFFFD,
	0x81CC: 0xEDEA,
	0x81CD: 0xC2C0,
	0x81CE: 0xFFFD,
	0x81CF: 0xC2C1,
	0x81D0: 0xF0A1,
	0x81D1: 0xF07D,
	0x81D2: 0xF07E,
	0x81D3: 0x9362,
	0x81D4: 0xFFFD,
	0x81D5: 0xF2C2,
	0x81D6: 0xFFFD,
	0x81D7: 0xF2C1,
	0x81D8: 0xC3BE,
	0x81D9: 0xF4B4,
	0x81DA: 0xC4A4,
	0x81DB: 0xF4B3,
	0x81DC: 0xFFFD,
	0x81DD: 0xF5F0,
	0x81DE: 0xF745,
	0x81DF: 0xC5A6,
	0x81E0: 0xF943,
	0x81E1: 0xF944,
	0x81E2: 0xC5D8,
	0x81E3: 0xA6DA,
	0x81E4: 0x9FBD,
	0x81E5: 0xAAD7,
	0x81E6: 0xDB52,
	0x81E7: 0xBB4E,
	0x81E8: 0xC17B,
	0x81E9: 0xEDEF,
	0x81EA: 0xA6DB,
	0x81EB: 0xFFFD,
	0x81EC: 0xAFE5,
	0x81ED: 0xAFE4,
	0x81EE: 0xDB53,
	0x81EF: 0x95D3,
	0x81F0: 0xFFFD,
	0x81F1: 0xFFFD,
	0x81F2: 0xEAF4,
	0x81F3: 0xA6DC,
	0x81F4: 0xAD50,
	0x81F5: 0xFFFD,
	0x81F6: 0xFD42,
	0x81F7: 0xDB54,
	0x81F8: 0xDB55,
	0x81F9: 0xDB56,
	0x81FA: 0xBB4F,
	0x81FB: 0xBFB2,
	0x81FC: 0xA6DD,
	0x81FD: 0xFFFD,
	0x81FE: 0xAAD8,
	0x81FF: 0xD068,
	0x8200: 0xAFE6,
	0x8201: 0xD370,
	0x8202: 0xB2EA,
	0x8203: 0xFFFD,
	0x8204: 0xDB57,
	0x8205: 0xB8A4,
	0x8206: 0x8A77,
	0x8207: 0xBB50,
	0x8208: 0xBFB3,
	0x8209: 0xC17C,
	0x820A: 0xC2C2,
	0x820B: 0xF4B5,
	0x820C: 0xA6DE,
	0x820D: 0xAAD9,
	0x820E: 0x92D6,
	0x820F: 0xFFFD,
	0x8210: 0xAFE7,
	0x8211: 0xD752,
	0x8212: 0xB5CE,
	0x8213: 0xFFFD,
	0x8214: 0xBB51,
	0x8215: 0xE3AB,
	0x8216: 0xE745,
	0x8217: 0x93C6,
	0x8218: 0x95EC,
	0x8219: 0xFFFD,
	0x821A: 0xFD43,
	0x821B: 0xA6DF,
	0x821C: 0xB5CF,
	0x821D: 0xDFA3,
	0x821E: 0xBB52,
	0x821F: 0xA6E0,
	0x8220: 0xCDB1,
	0x8221: 0xD069,
	0x8222: 0xAD51,
	0x8223: 0x8FC2,
	0x8224: 0xFFFD,
	0x8225: 0xD372,
	0x8226: 0xFB53,
	0x8227: 0xFFFD,
	0x8228: 0xAFEA,
	0x8229: 0xFEF8,
	0x822A: 0xAFE8,
	0x822B: 0xAFE9,
	0x822C: 0xAFEB,
	0x822D: 0xFEF9,
	0x822E: 0xFEFA,
	0x822F: 0xD371,
	0x8230: 0x8C4C,
	0x8231: 0x8956,
	0x8232: 0xD757,
	0x8233: 0xD754,
	0x8234: 0xD756,
	0x8235: 0xB2EB,
	0x8236: 0xB2ED,
	0x8237: 0xB2EC,
	0x8238: 0xD753,
	0x8239: 0xB2EE,
	0x823A: 0xD755,
	0x823B: 0x905B,
	0x823C: 0xDB58,
	0x823D: 0xDB59,
	0x823E: 0xFEFB,
	0x823F: 0xDB5A,
	0x8240: 0xDFA6,
	0x8241: 0xFFFD,
	0x8242: 0xDFA7,
	0x8243: 0xFFFD,
	0x8244: 0xDFA5,
	0x8245: 0xDFA8,
	0x8246: 0xFFFD,
	0x8247: 0xB8A5,
	0x8248: 0xFFFD,
	0x8249: 0xDFA4,
	0x824A: 0xFFFD,
	0x824B: 0xBB53,
	0x824C: 0xFFFD,
	0x824D: 0xFFFD,
	0x824E: 0xE74A,
	0x824F: 0xE746,
	0x8250: 0xE749,
	0x8251: 0xE74B,
	0x8252: 0xE748,
	0x8253: 0xE747,
	0x8254: 0x9FBE,
	0x8255: 0xEAF5,
	0x8256: 0xEAF6,
	0x8257: 0xEAF7,
	0x8258: 0xBFB4,
	0x8259: 0xBFB5,
	0x825A: 0xEDF1,
	0x825B: 0xEDF0,
	0x825C: 0xEDF2,
	0x825D: 0x94C8,
	0x825E: 0xF0A3,
	0x825F: 0xF0A2,
	0x8260: 0xFFFD,
	0x8261: 0xF2C4,
	0x8262: 0xFEFC,
	0x8263: 0xF2C5,
	0x8264: 0xF2C3,
	0x8265: 0x9FBF,
	0x8266: 0xC4A5,
	0x8267: 0xFFFD,
	0x8268: 0xF4B6,
	0x8269: 0xF4B7,
	0x826A: 0xFEFD,
	0x826B: 0xF746,
	0x826C: 0xF7EF,
	0x826D: 0xF8BB,
	0x826E: 0xA6E1,
	0x826F: 0xA87D,
	0x8270: 0x8A5C,
	0x8271: 0xC17D,
	0x8272: 0xA6E2,
	0x8273: 0x8D5B,
	0x8274: 0xD758,
	0x8275: 0xDB5B,
	0x8276: 0x8245,
	0x8277: 0xC641,
	0x8278: 0xCA4A,
	0x8279: 0x9CD2,
	0x827A: 0x8BB7,
	0x827B: 0x9FC0,
	0x827C: 0xCA4B,
	0x827D: 0xCA4D,
	0x827E: 0xA6E3,
	0x827F: 0xCA4E,
	0x8280: 0xCA4C,
	0x8281: 0xFFFD,
	0x8282: 0x85EB,
	0x8283: 0xCBA2,
	0x8284: 0xCBA3,
	0x8285: 0xCB7B,
	0x8286: 0xFFFD,
	0x8287: 0x9FC1,
	0x8288: 0xFEFE,
	0x8289: 0xFFFD,
	0x828A: 0xCBA1,
	0x828B: 0xA8A1,
	0x828C: 0xFFFD,
	0x828D: 0xA8A2,
	0x828E: 0xCB7C,
	0x828F: 0xCB7A,
	0x8290: 0xCB79,
	0x8291: 0xCB7D,
	0x8292: 0xA87E,
	0x8293: 0xCB7E,
	0x8294: 0xD06A,
	0x8295: 0xFFFD,
	0x8296: 0xFFFD,
	0x8297: 0x8EF6,
	0x8298: 0xCDB6,
	0x8299: 0xAADC,
	0x829A: 0xCDB5,
	0x829B: 0xCDB7,
	0x829C: 0x8959,
	0x829D: 0xAADB,
	0x829E: 0xCDBC,
	0x829F: 0xAADF,
	0x82A0: 0xCDB2,
	0x82A1: 0xCDC0,
	0x82A2: 0xCDC6,
	0x82A3: 0xAAE6,
	0x82A4: 0xCDC3,
	0x82A5: 0xAAE3,
	0x82A6: 0x8C4F,
	0x82A7: 0xCDB9,
	0x82A8: 0xCDBF,
	0x82A9: 0xCDC1,
	0x82AA: 0xFBA5,
	0x82AB: 0xCDB4,
	0x82AC: 0xAAE2,
	0x82AD: 0xAADD,
	0x82AE: 0xCDBA,
	0x82AF: 0xAAE4,
	0x82B0: 0xAAE7,
	0x82B1: 0xAAE1,
	0x82B2: 0xFFFD,
	0x82B3: 0xAADA,
	0x82B4: 0xCDBE,
	0x82B5: 0xCDB8,
	0x82B6: 0xCDC5,
	0x82B7: 0xAAE9,
	0x82B8: 0xAAE5,
	0x82B9: 0xAAE0,
	0x82BA: 0xCDBD,
	0x82BB: 0xAFEC,
	0x82BC: 0xCDBB,
	0x82BD: 0xAADE,
	0x82BE: 0xAAE8,
	0x82BF: 0x9FC2,
	0x82C0: 0xCDB3,
	0x82C1: 0x8ECA,
	0x82C2: 0xCDC2,
	0x82C3: 0xCDC4,
	0x82C4: 0x96BE,
	0x82C5: 0x9140,
	0x82C6: 0xFFFD,
	0x82C7: 0x85FB,
	0x82C8: 0x8FE1,
	0x82C9: 0xFFFD,
	0x82CA: 0x9141,
	0x82CB: 0x8479,
	0x82CC: 0x8551,
	0x82CD: 0x874B,
	0x82CE: 0x8378,
	0x82CF: 0x84F7,
	0x82D0: 0xFD5F,
	0x82D1: 0xAD62,
	0x82D2: 0xAD5C,
	0x82D3: 0xAD64,
	0x82D4: 0xAD61,
	0x82D5: 0xD071,
	0x82D6: 0xD074,
	0x82D7: 0xAD5D,
	0x82D8: 0x9142,
	0x82D9: 0xD06B,
	0x82DA: 0xFFFD,
	0x82DB: 0xAD56,
	0x82DC: 0xAD60,
	0x82DD: 0xFFFD,
	0x82DE: 0xAD63,
	0x82DF: 0xAD65,
	0x82E0: 0xD0A2,
	0x82E1: 0xD077,
	0x82E2: 0x9FC3,
	0x82E3: 0xAD55,
	0x82E4: 0xD0A1,
	0x82E5: 0xAD59,
	0x82E6: 0xAD57,
	0x82E7: 0xAD52,
	0x82E8: 0xD06F,
	0x82E9: 0xFFFD,
	0x82EA: 0xD07E,
	0x82EB: 0xD073,
	0x82EC: 0xD076,
	0x82ED: 0xD0A5,
	0x82EE: 0x9FC4,
	0x82EF: 0xAD66,
	0x82F0: 0xD07D,
	0x82F1: 0xAD5E,
	0x82F2: 0xD078,
	0x82F3: 0xD0A4,
	0x82F4: 0xD075,
	0x82F5: 0xD079,
	0x82F6: 0xD07C,
	0x82F7: 0x96A3,
	0x82F8: 0x9FC5,
	0x82F9: 0xD06D,
	0x82FA: 0xD0A3,
	0x82FB: 0xD07B,
	0x82FC: 0x9FC6,
	0x82FD: 0xFD5D,
	0x82FE: 0xD06C,
	0x82FF: 0x9FC7,
	0x8300: 0xD070,
	0x8301: 0xAD5F,
	0x8302: 0xAD5A,
	0x8303: 0xAD53,
	0x8304: 0xAD58,
	0x8305: 0xAD54,
	0x8306: 0xAD67,
	0x8307: 0xD06E,
	0x8308: 0xD3A5,
	0x8309: 0xAD5B,
	0x830A: 0xFFFD,
	0x830B: 0x9FC8,
	0x830C: 0xD07A,
	0x830D: 0xCE41,
	0x830E: 0x92A7,
	0x830F: 0x8FE0,
	0x8310: 0xFFFD,
	0x8311: 0x8EC9,
	0x8312: 0xFFFD,
	0x8313: 0xFFFD,
	0x8314: 0x85C3,
	0x8315: 0x8E46,
	0x8316: 0xD3A8,
	0x8317: 0xAFFA,
	0x8318: 0x9143,
	0x8319: 0xD376,
	0x831A: 0x9144,
	0x831B: 0xD3A3,
	0x831C: 0xD37D,
	0x831D: 0x9FC9,
	0x831E: 0xD3B2,
	0x831F: 0xFFFD,
	0x8320: 0xD3AA,
	0x8321: 0xFFFD,
	0x8322: 0xD37E,
	0x8323: 0x9145,
	0x8324: 0xD3A9,
	0x8325: 0xD378,
	0x8326: 0xD37C,
	0x8327: 0xD3B5,
	0x8328: 0xAFFD,
	0x8329: 0xD3AD,
	0x832A: 0xD3A4,
	0x832B: 0xAFED,
	0x832C: 0xD3B3,
	0x832D: 0xD374,
	0x832E: 0xFFFD,
	0x832F: 0xD3AC,
	0x8330: 0xFFFD,
	0x8331: 0xAFFC,
	0x8332: 0xAFF7,
	0x8333: 0xD373,
	0x8334: 0xAFF5,
	0x8335: 0xAFF4,
	0x8336: 0xAFF9,
	0x8337: 0xD3AB,
	0x8338: 0xAFF1,
	0x8339: 0xAFF8,
	0x833A: 0xD072,
	0x833B: 0xDB5C,
	0x833C: 0xD3A6,
	0x833D: 0x9FCA,
	0x833E: 0xFFFD,
	0x833F: 0xD37A,
	0x8340: 0xAFFB,
	0x8341: 0xD37B,
	0x8342: 0xD3A1,
	0x8343: 0xAFFE,
	0x8344: 0xD375,
	0x8345: 0xD3AF,
	0x8346: 0x9146,
	0x8347: 0xD3AE,
	0x8348: 0xD3B6,
	0x8349: 0xAFF3,
	0x834A: 0xAFF0,
	0x834B: 0xD3B4,
	0x834C: 0xD3B0,
	0x834D: 0xD3A7,
	0x834E: 0xD3A2,
	0x834F: 0xAFF6,
	0x8350: 0xAFF2,
	0x8351: 0xD377,
	0x8352: 0xAFEE,
	0x8353: 0xD3B1,
	0x8354: 0xAFEF,
	0x8355: 0xFFFD,
	0x8356: 0xD379,
	0x8357: 0x9FCB,
	0x8358: 0x9354,
	0x8359: 0xFFFD,
	0x835A: 0x8475,
	0x835B: 0x9147,
	0x835C: 0x8EC7,
	0x835D: 0xFFFD,
	0x835E: 0x8EF4,
	0x835F: 0x8F5F,
	0x8360: 0x8AF9,
	0x8361: 0x8957,
	0x8362: 0x9148,
	0x8363: 0x86D1,
	0x8364: 0x85FA,
	0x8365: 0x8E73,
	0x8366: 0x86E1,
	0x8367: 0x86DF,
	0x8368: 0x8EF2,
	0x8369: 0x8F7B,
	0x836A: 0x874A,
	0x836B: 0x8851,
	0x836C: 0x9149,
	0x836D: 0x8E4D,
	0x836E: 0x914A,
	0x836F: 0x8BB9,
	0x8370: 0xFFFD,
	0x8371: 0xFFFD,
	0x8372: 0xFFFD,
	0x8373: 0xD75E,
	0x8374: 0xD760,
	0x8375: 0xD765,
	0x8376: 0xD779,
	0x8377: 0xB2FC,
	0x8378: 0xB2F2,
	0x8379: 0xFFFD,
	0x837A: 0xD75D,
	0x837B: 0xB2FD,
	0x837C: 0xB2FE,
	0x837D: 0xD768,
	0x837E: 0xD76F,
	0x837F: 0xD775,
	0x8380: 0xFFFD,
	0x8381: 0xD762,
	0x8382: 0xFFFD,
	0x8383: 0xD769,
	0x8384: 0xFFFD,
	0x8385: 0x8748,
	0x8386: 0xB340,
	0x8387: 0xD777,
	0x8388: 0xD772,
	0x8389: 0xB2FA,
	0x838A: 0xB2F8,
	0x838B: 0xD76E,
	0x838C: 0xD76A,
	0x838D: 0xD75C,
	0x838E: 0xB2EF,
	0x838F: 0xD761,
	0x8390: 0xD759,
	0x8391: 0x9FCC,
	0x8392: 0xB2F7,
	0x8393: 0xB2F9,
	0x8394: 0xD766,
	0x8395: 0xD763,
	0x8396: 0xB2F4,
	0x8397: 0xD773,
	0x8398: 0xB2F1,
	0x8399: 0xD764,
	0x839A: 0xD77A,
	0x839B: 0xD76C,
	0x839C: 0x914B,
	0x839D: 0xD76B,
	0x839E: 0xB2F0,
	0x839F: 0x914C,
	0x83A0: 0xB2FB,
	0x83A1: 0xFFFD,
	0x83A2: 0xB2F3,
	0x83A3: 0xD75A,
	0x83A4: 0xD75F,
	0x83A5: 0xD770,
	0x83A6: 0xD776,
	0x83A7: 0xB341,
	0x83A8: 0xD75B,
	0x83A9: 0xD767,
	0x83AA: 0xD76D,
	0x83AB: 0xB2F6,
	0x83AC: 0x9FCD,
	0x83AD: 0xFFFD,
	0x83AE: 0xD778,
	0x83AF: 0xD771,
	0x83B0: 0xD774,
	0x83B1: 0x8550,
	0x83B2: 0x8850,
	0x83B3: 0x8E7D,
	0x83B4: 0x85FD,
	0x83B5: 0x914D,
	0x83B6: 0x8F60,
	0x83B7: 0x89F7,
	0x83B8: 0x8EF5,
	0x83B9: 0x87F3,
	0x83BA: 0x8CC2,
	0x83BB: 0xFFFD,
	0x83BC: 0x914E,
	0x83BD: 0xB2F5,
	0x83BE: 0xFBAD,
	0x83BF: 0xDB6C,
	0x83C0: 0xDB60,
	0x83C1: 0xB5D7,
	0x83C2: 0xDB7D,
	0x83C3: 0xDBA7,
	0x83C4: 0xDBAA,
	0x83C5: 0xB5D5,
	0x83C6: 0xDB68,
	0x83C7: 0xDBA3,
	0x83C8: 0xDB69,
	0x83C9: 0xDB77,
	0x83CA: 0xB5E2,
	0x83CB: 0xDB73,
	0x83CC: 0xB5DF,
	0x83CD: 0x9FCE,
	0x83CE: 0xDB74,
	0x83CF: 0xDB5D,
	0x83D0: 0xFFFD,
	0x83D1: 0xDBA4,
	0x83D2: 0xFFFD,
	0x83D3: 0xFE52,
	0x83D4: 0xB5E8,
	0x83D5: 0xDBA1,
	0x83D6: 0xDB75,
	0x83D7: 0xDBAC,
	0x83D8: 0xDB70,
	0x83D9: 0xDFC8,
	0x83DA: 0xFFFD,
	0x83DB: 0xDBAF,
	0x83DC: 0xB5E6,
	0x83DD: 0xDB6E,
	0x83DE: 0xDB7A,
	0x83DF: 0xB5E9,
	0x83E0: 0xB5D4,
	0x83E1: 0xDB72,
	0x83E2: 0xDBAD,
	0x83E3: 0xDB6B,
	0x83E4: 0xDB64,
	0x83E5: 0xDB6F,
	0x83E6: 0xFFFD,
	0x83E7: 0xDB63,
	0x83E8: 0xDB61,
	0x83E9: 0xB5D0,
	0x83EA: 0xDBA5,
	0x83EB: 0xDB6A,
	0x83EC: 0xDBA8,
	0x83ED: 0x9FCF,
	0x83EE: 0xDBA9,
	0x83EF: 0xB5D8,
	0x83F0: 0xB5DD,
	0x83F1: 0xB5D9,
	0x83F2: 0xB5E1,
	0x83F3: 0xDB7E,
	0x83F4: 0xB5DA,
	0x83F5: 0xDB76,
	0x83F6: 0xDB66,
	0x83F7: 0x914F,
	0x83F8: 0xB5D2,
	0x83F9: 0xDB5E,
	0x83FA: 0xDBA2,
	0x83FB: 0xDBAB,
	0x83FC: 0xDB65,
	0x83FD: 0xB5E0,
	0x83FE: 0xDBB0,
	0x83FF: 0xDB71,
	0x8400: 0xFFFD,
	0x8401: 0xDB6D,
	0x8402: 0xFFFD,
	0x8403: 0xB5D1,
	0x8404: 0xB5E5,
	0x8405: 0x9FD0,
	0x8406: 0xDB7C,
	0x8407: 0xB5E7,
	0x8408: 0xFFFD,
	0x8409: 0xDB78,
	0x840A: 0xB5DC,
	0x840B: 0xB5D6,
	0x840C: 0xB5DE,
	0x840D: 0xB5D3,
	0x840E: 0xB5E4,
	0x840F: 0xDB79,
	0x8410: 0xDB67,
	0x8411: 0xDB7B,
	0x8412: 0xDB62,
	0x8413: 0xDBA6,
	0x8414: 0x9FD1,
	0x8415: 0xFFFD,
	0x8416: 0x9FD2,
	0x8417: 0xFFFD,
	0x8418: 0x96A7,
	0x8419: 0xFFFD,
	0x841A: 0xFFFD,
	0x841B: 0xDBAE,
	0x841C: 0x96BD,
	0x841D: 0x8CFD,
	0x841E: 0xFFFD,
	0x841F: 0xFFFD,
	0x8420: 0xFD63,
	0x8421: 0x9FD3,
	0x8422: 0x94C9,
	0x8423: 0xDB5F,
	0x8424: 0x895B,
	0x8425: 0x89F1,
	0x8426: 0x894D,
	0x8427: 0x8958,
	0x8428: 0x8AF7,
	0x8429: 0xDFC7,
	0x842A: 0x9150,
	0x842B: 0xDFDD,
	0x842C: 0xB855,
	0x842D: 0xDFCC,
	0x842E: 0x9FD4,
	0x842F: 0xDFCA,
	0x8430: 0xDFB5,
	0x8431: 0xB8A9,
	0x8432: 0xDFC5,
	0x8433: 0xDFD9,
	0x8434: 0xDFC1,
	0x8435: 0xB8B1,
	0x8436: 0xDFD8,
	0x8437: 0xDFBF,
	0x8438: 0xB5E3,
	0x8439: 0xDFCF,
	0x843A: 0xDFC0,
	0x843B: 0xDFD6,
	0x843C: 0xB8B0,
	0x843D: 0xB8A8,
	0x843E: 0x9FD5,
	0x843F: 0xDFAA,
	0x8440: 0xDFB2,
	0x8441: 0xFFFD,
	0x8442: 0xDFCB,
	0x8443: 0xDFC3,
	0x8444: 0xDFDC,
	0x8445: 0xDFC6,
	0x8446: 0xB8B6,
	0x8447: 0xDFD7,
	0x8448: 0x9151,
	0x8449: 0xB8AD,
	0x844A: 0x9FD6,
	0x844B: 0xDFC9,
	0x844C: 0xDFD1,
	0x844D: 0xDFB6,
	0x844E: 0xDFD0,
	0x844F: 0xFFFD,
	0x8450: 0xDFE1,
	0x8451: 0xDFB1,
	0x8452: 0xDFD2,
	0x8453: 0x9FD7,
	0x8454: 0xDFDF,
	0x8455: 0x9FD8,
	0x8456: 0xDFAB,
	0x8457: 0xB5DB,
	0x8458: 0x9FD9,
	0x8459: 0xDFB9,
	0x845A: 0xDFB8,
	0x845B: 0xB8AF,
	0x845C: 0x9152,
	0x845D: 0xDFBC,
	0x845E: 0xDFBE,
	0x845F: 0xDFCD,
	0x8460: 0xDFDE,
	0x8461: 0xB8B2,
	0x8462: 0x9153,
	0x8463: 0xB8B3,
	0x8464: 0x9FDA,
	0x8465: 0xDFB0,
	0x8466: 0xB8AB,
	0x8467: 0xDFB4,
	0x8468: 0xDFDA,
	0x8469: 0xB8B4,
	0x846A: 0xFFFD,
	0x846B: 0xB8AC,
	0x846C: 0xB8AE,
	0x846D: 0xB8B5,
	0x846E: 0xDFE0,
	0x846F: 0xDFD3,
	0x8470: 0xDFCE,
	0x8471: 0x95F5,
	0x8472: 0x9FDB,
	0x8473: 0xDFBB,
	0x8474: 0xDFBA,
	0x8475: 0xB8AA,
	0x8476: 0xDFAC,
	0x8477: 0xB8A7,
	0x8478: 0xDFC4,
	0x8479: 0xDFAD,
	0x847A: 0xDFC2,
	0x847B: 0x96C0,
	0x847C: 0xFFFD,
	0x847D: 0xDFB7,
	0x847E: 0xDFDB,
	0x847F: 0x9FDC,
	0x8480: 0x9FDD,
	0x8481: 0xFFFD,
	0x8482: 0xB8A6,
	0x8483: 0xFFFD,
	0x8484: 0x9154,
	0x8485: 0xFFFD,
	0x8486: 0xDFB3,
	0x8487: 0x8EF1,
	0x8488: 0x9155,
	0x8489: 0x8EF3,
	0x848A: 0xFFFD,
	0x848B: 0x8852,
	0x848C: 0x8EC8,
	0x848D: 0xDFAF,
	0x848E: 0xDFD5,
	0x848F: 0xDFAE,
	0x8490: 0xBB60,
	0x8491: 0xE3D3,
	0x8492: 0x9FDE,
	0x8493: 0x9FDF,
	0x8494: 0xE3C2,
	0x8495: 0xFFFD,
	0x8496: 0x9FE0,
	0x8497: 0xE3AC,
	0x8498: 0xE3CA,
	0x8499: 0xBB58,
	0x849A: 0xE3BB,
	0x849B: 0xE3C5,
	0x849C: 0xBB5B,
	0x849D: 0xE3BE,
	0x849E: 0xBB59,
	0x849F: 0xE3AF,
	0x84A0: 0xE3CD,
	0x84A1: 0xE3AE,
	0x84A2: 0xE3C1,
	0x84A3: 0x9FE1,
	0x84A4: 0xE3AD,
	0x84A5: 0xFFFD,
	0x84A6: 0xFFFD,
	0x84A7: 0xE3BF,
	0x84A8: 0xE3C8,
	0x84A9: 0xE3C6,
	0x84AA: 0xE3BA,
	0x84AB: 0xE3B5,
	0x84AC: 0xE3B3,
	0x84AD: 0xFD66,
	0x84AE: 0xE3B4,
	0x84AF: 0xE3C7,
	0x84B0: 0xE3D2,
	0x84B1: 0xE3BC,
	0x84B2: 0xBB5A,
	0x84B3: 0xFFFD,
	0x84B4: 0xE3B7,
	0x84B5: 0xFFFD,
	0x84B6: 0xE3CB,
	0x84B7: 0xFFFD,
	0x84B8: 0xBB5D,
	0x84B9: 0xE3B6,
	0x84BA: 0xE3B0,
	0x84BB: 0xE3C0,
	0x84BC: 0xBB61,
	0x84BD: 0x96BC,
	0x84BE: 0x9FE2,
	0x84BF: 0xBB55,
	0x84C0: 0xBB5E,
	0x84C1: 0xE3B8,
	0x84C2: 0xE3B2,
	0x84C3: 0xFFFD,
	0x84C4: 0xBB57,
	0x84C5: 0xDFD4,
	0x84C6: 0xBB56,
	0x84C7: 0xE3C3,
	0x84C8: 0xFFFD,
	0x84C9: 0xBB54,
	0x84CA: 0xBB63,
	0x84CB: 0xBB5C,
	0x84CC: 0xE3C4,
	0x84CD: 0xE3B9,
	0x84CE: 0xE3B1,
	0x84CF: 0xE3CC,
	0x84D0: 0xE3BD,
	0x84D1: 0xBB62,
	0x84D2: 0xE3D0,
	0x84D3: 0xBB5F,
	0x84D4: 0xE3CF,
	0x84D5: 0xFFFD,
	0x84D6: 0xE3C9,
	0x84D7: 0xE3CE,
	0x84D8: 0xFFFD,
	0x84D9: 0x94CA,
	0x84DA: 0xFD65,
	0x84DB: 0xE3D1,
	0x84DC: 0x9156,
	0x84DD: 0x8AF8,
	0x84DE: 0x9FE3,
	0x84DF: 0x8A5E,
	0x84E0: 0x906C,
	0x84E1: 0x9FE4,
	0x84E2: 0x9FE5,
	0x84E3: 0x9157,
	0x84E4: 0x9FE6,
	0x84E5: 0x8FAA,
	0x84E6: 0x8CBD,
	0x84E7: 0xE773,
	0x84E8: 0xE774,
	0x84E9: 0xE767,
	0x84EA: 0xE766,
	0x84EB: 0xE762,
	0x84EC: 0xBDB4,
	0x84ED: 0xFFFD,
	0x84EE: 0xBDAC,
	0x84EF: 0xE776,
	0x84F0: 0xE775,
	0x84F1: 0xDFA9,
	0x84F2: 0xE75F,
	0x84F3: 0xE763,
	0x84F4: 0xE75D,
	0x84F5: 0xFFFD,
	0x84F6: 0xE770,
	0x84F7: 0xE761,
	0x84F8: 0x9FE7,
	0x84F9: 0xE777,
	0x84FA: 0xE75A,
	0x84FB: 0xE758,
	0x84FC: 0xE764,
	0x84FD: 0xE76E,
	0x84FE: 0xE769,
	0x84FF: 0xBDB6,
	0x8500: 0xE74F,
	0x8501: 0xFFFD,
	0x8502: 0xE76D,
	0x8503: 0x9FE8,
	0x8504: 0xFFFD,
	0x8505: 0x9FE9,
	0x8506: 0xBDB7,
	0x8507: 0xDFBD,
	0x8508: 0xE75B,
	0x8509: 0xE752,
	0x850A: 0xE755,
	0x850B: 0xE77B,
	0x850C: 0xE75C,
	0x850D: 0xE753,
	0x850E: 0xE751,
	0x850F: 0xE74E,
	0x8510: 0x9FEA,
	0x8511: 0xBDB0,
	0x8512: 0xE765,
	0x8513: 0xBDAF,
	0x8514: 0xBDB3,
	0x8515: 0xE760,
	0x8516: 0xE768,
	0x8517: 0xBDA9,
	0x8518: 0xE778,
	0x8519: 0xE77C,
	0x851A: 0xBDAB,
	0x851B: 0xFFFD,
	0x851C: 0xE757,
	0x851D: 0xE76B,
	0x851E: 0xE76F,
	0x851F: 0xE754,
	0x8520: 0xE779,
	0x8521: 0xBDB2,
	0x8522: 0xFFFD,
	0x8523: 0xBDB1,
	0x8524: 0xE74C,
	0x8525: 0xBDB5,
	0x8526: 0xE772,
	0x8527: 0xE756,
	0x8528: 0xE76A,
	0x8529: 0xE750,
	0x852A: 0xE75E,
	0x852B: 0xE759,
	0x852C: 0xBDAD,
	0x852D: 0xBDAE,
	0x852E: 0xE76C,
	0x852F: 0xE77D,
	0x8530: 0xE77A,
	0x8531: 0xE771,
	0x8532: 0xFFFD,
	0x8533: 0x9FEB,
	0x8534: 0xFE4C,
	0x8535: 0x9360,
	0x8536: 0xFFFD,
	0x8537: 0x8A5D,
	0x8538: 0x9158,
	0x8539: 0x9046,
	0x853A: 0x8C4E,
	0x853B: 0xE74D,
	0x853C: 0x8C4D,
	0x853D: 0xBDAA,
	0x853E: 0xEB49,
	0x853F: 0xFFFD,
	0x8540: 0xEB40,
	0x8541: 0xEB43,
	0x8542: 0x9FED,
	0x8543: 0xBFBB,
	0x8544: 0xEB45,
	0x8545: 0xEAF9,
	0x8546: 0xEB41,
	0x8547: 0xEB47,
	0x8548: 0xBFB8,
	0x8549: 0xBFBC,
	0x854A: 0xBFB6,
	0x854B: 0xFD68,
	0x854C: 0x9FEE,
	0x854D: 0xEAFB,
	0x854E: 0xEB4C,
	0x854F: 0xFFFD,
	0x8550: 0xFFFD,
	0x8551: 0xEB46,
	0x8552: 0x9FEF,
	0x8553: 0xEAFC,
	0x8554: 0xEB55,
	0x8555: 0xEB4F,
	0x8556: 0xEAF8,
	0x8557: 0xEE46,
	0x8558: 0xEAFE,
	0x8559: 0xBFB7,
	0x855A: 0x9159,
	0x855B: 0xEB4A,
	0x855C: 0xFFFD,
	0x855D: 0xEB54,
	0x855E: 0xBFBF,
	0x855F: 0x9FF0,
	0x8560: 0xEB51,
	0x8561: 0xEAFD,
	0x8562: 0xEB44,
	0x8563: 0xEB48,
	0x8564: 0xEB42,
	0x8565: 0xEB56,
	0x8566: 0xEB53,
	0x8567: 0xEB50,
	0x8568: 0xBFB9,
	0x8569: 0xBFBA,
	0x856A: 0xBFBE,
	0x856B: 0xEAFA,
	0x856C: 0xEB57,
	0x856D: 0xBFBD,
	0x856E: 0xEB4D,
	0x856F: 0x9FF1,
	0x8570: 0x9FF2,
	0x8571: 0xEB4B,
	0x8572: 0x8FE2,
	0x8573: 0x9FF3,
	0x8574: 0x8C51,
	0x8575: 0xEB4E,
	0x8576: 0xEE53,
	0x8577: 0xEE40,
	0x8578: 0xEE45,
	0x8579: 0xEE52,
	0x857A: 0xEE44,
	0x857B: 0xEDFB,
	0x857C: 0xEE41,
	0x857D: 0xFFFD,
	0x857E: 0xC1A2,
	0x857F: 0xFFFD,
	0x8580: 0xEDF4,
	0x8581: 0xEE4D,
	0x8582: 0xEE4F,
	0x8583: 0xEDF3,
	0x8584: 0xC1A1,
	0x8585: 0xEE51,
	0x8586: 0xEE49,
	0x8587: 0xC1A8,
	0x8588: 0xEE50,
	0x8589: 0xEE42,
	0x858A: 0xC1AA,
	0x858B: 0xEDF9,
	0x858C: 0xEB52,
	0x858D: 0xEE4A,
	0x858E: 0xEE47,
	0x858F: 0xEDF5,
	0x8590: 0xEE55,
	0x8591: 0xC1A4,
	0x8592: 0xFFFD,
	0x8593: 0x9D76,
	0x8594: 0xC1A5,
	0x8595: 0xEDF7,
	0x8596: 0xEE48,
	0x8597: 0x915A,
	0x8598: 0xEE54,
	0x8599: 0xEE4B,
	0x859A: 0xEDFD,
	0x859B: 0xC1A7,
	0x859C: 0xC1A3,
	0x859D: 0xEE4C,
	0x859E: 0xEDFE,
	0x859F: 0xEE56,
	0x85A0: 0xEDF8,
	0x85A1: 0xEE43,
	0x85A2: 0xEE4E,
	0x85A3: 0xEDFA,
	0x85A4: 0xEDFC,
	0x85A5: 0xFFFD,
	0x85A6: 0xC2CB,
	0x85A7: 0xEDF6,
	0x85A8: 0xC1A9,
	0x85A9: 0xC2C4,
	0x85AA: 0xC17E,
	0x85AB: 0x915B,
	0x85AC: 0x93D6,
	0x85AD: 0xFFFD,
	0x85AE: 0x827E,
	0x85AF: 0xC1A6,
	0x85B0: 0xC2C8,
	0x85B1: 0xF0B3,
	0x85B2: 0xFFFD,
	0x85B3: 0xF0A9,
	0x85B4: 0xF0A4,
	0x85B5: 0xF0AA,
	0x85B6: 0xF0B4,
	0x85B7: 0xF0B8,
	0x85B8: 0xF0B7,
	0x85B9: 0xC2CA,
	0x85BA: 0xC2C9,
	0x85BB: 0xFFFD,
	0x85BC: 0xFFFD,
	0x85BD: 0xF0AB,
	0x85BE: 0xF0B9,
	0x85BF: 0xF0AE,
	0x85C0: 0xF0A6,
	0x85C1: 0x915C,
	0x85C2: 0xF0A8,
	0x85C3: 0xF0A7,
	0x85C4: 0xF0AD,
	0x85C5: 0xF0B2,
	0x85C6: 0xF0A5,
	0x85C7: 0xF0AC,
	0x85C8: 0xF0B1,
	0x85C9: 0xC2C7,
	0x85CA: 0xFFFD,
	0x85CB: 0xF0AF,
	0x85CC: 0xFFFD,
	0x85CD: 0xC2C5,
	0x85CE: 0xF0B0,
	0x85CF: 0xC2C3,
	0x85D0: 0xC2C6,
	0x85D1: 0xF2D5,
	0x85D2: 0xF0B5,
	0x85D3: 0x8CA4,
	0x85D4: 0xFFFD,
	0x85D5: 0xC3C2,
	0x85D6: 0x9FF4,
	0x85D7: 0xF2CD,
	0x85D8: 0xF2D1,
	0x85D9: 0xF2C9,
	0x85DA: 0xF2CC,
	0x85DB: 0xFFFD,
	0x85DC: 0xF2D4,
	0x85DD: 0xC3C0,
	0x85DE: 0xF2D9,
	0x85DF: 0xF2D2,
	0x85E0: 0x9FF5,
	0x85E1: 0xF2CA,
	0x85E2: 0xF2DA,
	0x85E3: 0xF2D3,
	0x85E4: 0xC3C3,
	0x85E5: 0xC3C4,
	0x85E6: 0xF2D7,
	0x85E7: 0xFFFD,
	0x85E8: 0xF2CB,
	0x85E9: 0xC3BF,
	0x85EA: 0xC3C1,
	0x85EB: 0xF2C6,
	0x85EC: 0xF2CE,
	0x85ED: 0xF2C8,
	0x85EE: 0x9FF6,
	0x85EF: 0xF2D8,
	0x85F0: 0xF2D6,
	0x85F1: 0xF2C7,
	0x85F2: 0xF2CF,
	0x85F3: 0xFFFD,
	0x85F4: 0xFFFD,
	0x85F5: 0xFFFD,
	0x85F6: 0xF4BE,
	0x85F7: 0xC3C5,
	0x85F8: 0xF2D0,
	0x85F9: 0xC4A7,
	0x85FA: 0xC4A9,
	0x85FB: 0xC4A6,
	0x85FC: 0x9FF7,
	0x85FD: 0xF4C3,
	0x85FE: 0xF4BB,
	0x85FF: 0xF4B9,
	0x8600: 0xF4BD,
	0x8601: 0xF4BA,
	0x8602: 0xFD6A,
	0x8603: 0xFFFD,
	0x8604: 0xF4BF,
	0x8605: 0xF4C1,
	0x8606: 0xC4AA,
	0x8607: 0xC4AC,
	0x8608: 0xFFFD,
	0x8609: 0xF4C0,
	0x860A: 0xC4AD,
	0x860B: 0xC4AB,
	0x860C: 0xF4C2,
	0x860D: 0x9FF8,
	0x860E: 0xFFFD,
	0x860F: 0x9FF9,
	0x8610: 0xFD6B,
	0x8611: 0xC4A8,
	0x8612: 0xFFFD,
	0x8613: 0x915D,
	0x8614: 0x9FFA,
	0x8615: 0xFFFD,
	0x8616: 0x915E,
	0x8617: 0xC4F4,
	0x8618: 0xF5F1,
	0x8619: 0xF5F7,
	0x861A: 0xC4F6,
	0x861B: 0xF4BC,
	0x861C: 0xF5F6,
	0x861D: 0xFFFD,
	0x861E: 0xF5FD,
	0x861F: 0xF5F4,
	0x8620: 0xF5FB,
	0x8621: 0xF5FA,
	0x8622: 0xF4B8,
	0x8623: 0xF5F5,
	0x8624: 0xF0B6,
	0x8625: 0xF5FE,
	0x8626: 0xF5F3,
	0x8627: 0xF5F8,
	0x8628: 0x9FFB,
	0x8629: 0xF5FC,
	0x862A: 0xF5F2,
	0x862B: 0xFFFD,
	0x862C: 0xF74A,
	0x862D: 0xC4F5,
	0x862E: 0xF5F9,
	0x862F: 0xFBAE,
	0x8630: 0x94CB,
	0x8631: 0xF7F4,
	0x8632: 0xF74B,
	0x8633: 0xF749,
	0x8634: 0xF747,
	0x8635: 0xF748,
	0x8636: 0xF74C,
	0x8637: 0xFFFD,
	0x8638: 0xC5D9,
	0x8639: 0xF7F2,
	0x863A: 0xF7F0,
	0x863B: 0xF7F5,
	0x863C: 0xF7F3,
	0x863D: 0xFFFD,
	0x863E: 0xF7F6,
	0x863F: 0xC5DA,
	0x8640: 0xF7F1,
	0x8641: 0xFFFD,
	0x8642: 0x9FFC,
	0x8643: 0xF8BC,
	0x8644: 0xFFFD,
	0x8645: 0x9FFD,
	0x8646: 0xF945,
	0x8647: 0xF946,
	0x8648: 0xF947,
	0x8649: 0xFFFD,
	0x864A: 0xFFFD,
	0x864B: 0xF9C7,
	0x864C: 0xF9BD,
	0x864D: 0xCA4F,
	0x864E: 0xAAEA,
	0x864F: 0x8640,
	0x8650: 0xAD68,
	0x8651: 0x87CB,
	0x8652: 0xD3B8,
	0x8653: 0xD3B7,
	0x8654: 0xB040,
	0x8655: 0xB342,
	0x8656: 0xD77C,
	0x8657: 0xFFFD,
	0x8658: 0xFFFD,
	0x8659: 0xD77B,
	0x865A: 0x8552,
	0x865B: 0xB5EA,
	0x865C: 0xB8B8,
	0x865D: 0xFFFD,
	0x865E: 0xB8B7,
	0x865F: 0xB8B9,
	0x8660: 0xFFFD,
	0x8661: 0xE3D4,
	0x8662: 0xE77E,
	0x8663: 0xEB58,
	0x8664: 0xEB5A,
	0x8665: 0xEB59,
	0x8666: 0xFFFD,
	0x8667: 0xC1AB,
	0x8668: 0xEE57,
	0x8669: 0xF0BA,
	0x866A: 0xF9A5,
	0x866B: 0xA6E4,
	0x866C: 0x9578,
	0x866D: 0xCDC9,
	0x866E: 0xCDCA,
	0x866F: 0xCDC8,
	0x8670: 0xCDC7,
	0x8671: 0xAAEB,
	0x8672: 0x9FFE,
	0x8673: 0xD0A9,
	0x8674: 0xD0A7,
	0x8675: 0xFFFD,
	0x8676: 0xFFFD,
	0x8677: 0xD0A6,
	0x8678: 0xFFFD,
	0x8679: 0xAD69,
	0x867A: 0xAD6B,
	0x867B: 0xAD6A,
	0x867C: 0xD0A8,
	0x867D: 0x8AAF,
	0x867E: 0x8853,
	0x867F: 0x8FC4,
	0x8680: 0x874C,
	0x8681: 0x8BBA,
	0x8682: 0x895A,
	0x8683: 0xFFFD,
	0x8684: 0xFFFD,
	0x8685: 0xD3C4,
	0x8686: 0xD3C1,
	0x8687: 0xD3BF,
	0x8688: 0xFFFD,
	0x8689: 0xFFFD,
	0x868A: 0xB041,
	0x868B: 0xD3C2,
	0x868C: 0xB046,
	0x868D: 0xD3BC,
	0x868E: 0xD3CB,
	0x868F: 0xFFFD,
	0x8690: 0xD3CD,
	0x8691: 0xD3BD,
	0x8692: 0xFEBB,
	0x8693: 0xB043,
	0x8694: 0xD3CE,
	0x8695: 0xD3C9,
	0x8696: 0xD3BB,
	0x8697: 0xD3C0,
	0x8698: 0xD3CA,
	0x8699: 0xD3C6,
	0x869A: 0xD3C3,
	0x869B: 0xFFFD,
	0x869C: 0xB048,
	0x869D: 0xD3CC,
	0x869E: 0xD3BE,
	0x869F: 0xFFFD,
	0x86A0: 0xFEBC,
	0x86A1: 0xD3C7,
	0x86A2: 0xD3B9,
	0x86A3: 0xB047,
	0x86A4: 0xB044,
	0x86A5: 0xD3C5,
	0x86A6: 0xFFFD,
	0x86A7: 0xD3C8,
	0x86A8: 0xD3BA,
	0x86A9: 0xB045,
	0x86AA: 0xB042,
	0x86AB: 0x94CC,
	0x86AC: 0x8643,
	0x86AD: 0xFEBD,
	0x86AE: 0xFFFD,
	0x86AF: 0xB34C,
	0x86B0: 0xD7A5,
	0x86B1: 0xB34B,
	0x86B2: 0xFEBE,
	0x86B3: 0xD7A8,
	0x86B4: 0xD7AB,
	0x86B5: 0xB348,
	0x86B6: 0xB346,
	0x86B7: 0xD77E,
	0x86B8: 0xD7A9,
	0x86B9: 0xD7A7,
	0x86BA: 0xD7A4,
	0x86BB: 0xD7AC,
	0x86BC: 0xD7AD,
	0x86BD: 0xD7AF,
	0x86BE: 0xD7B0,
	0x86BF: 0xD77D,
	0x86C0: 0xB345,
	0x86C1: 0xD7A2,
	0x86C2: 0xD7A1,
	0x86C3: 0xD7AE,
	0x86C4: 0xB347,
	0x86C5: 0xD7A3,
	0x86C6: 0xB349,
	0x86C7: 0xB344,
	0x86C8: 0xD7A6,
	0x86C9: 0xB34D,
	0x86CA: 0x8CFE,
	0x86CB: 0xB34A,
	0x86CC: 0xD7AA,
	0x86CD: 0x92AC,
	0x86CE: 0x824C,
	0x86CF: 0x8FC3,
	0x86D0: 0xB5F1,
	0x86D1: 0xDBBF,
	0x86D2: 0xFFFD,
	0x86D3: 0xDBB4,
	0x86D4: 0xB5EE,
	0x86D5: 0xFFFD,
	0x86D6: 0xDFE7,
	0x86D7: 0xDBBD,
	0x86D8: 0xDBB1,
	0x86D9: 0xB5EC,
	0x86DA: 0xDBB6,
	0x86DB: 0xB5EF,
	0x86DC: 0xDBBA,
	0x86DD: 0xDBB8,
	0x86DE: 0xB5F2,
	0x86DF: 0xB5EB,
	0x86E0: 0xFFFD,
	0x86E1: 0xFFFD,
	0x86E2: 0xDBB2,
	0x86E3: 0xDBB5,
	0x86E4: 0xB5F0,
	0x86E5: 0xFFFD,
	0x86E6: 0xDBB3,
	0x86E7: 0xFFFD,
	0x86E8: 0xDBBE,
	0x86E9: 0xDBBC,
	0x86EA: 0xDBB7,
	0x86EB: 0xDBB9,
	0x86EC: 0xDBBB,
	0x86ED: 0xB5ED,
	0x86EE: 0x8D72,
	0x86EF: 0x94CD,
	0x86F0: 0x8F61,
	0x86F1: 0x8E4E,
	0x86F2: 0x8AFA,
	0x86F3: 0x8EF7,
	0x86F4: 0x8FE3,
	0x86F5: 0xDFE8,
	0x86F6: 0xDFEE,
	0x86F7: 0xDFE4,
	0x86F8: 0xDFEA,
	0x86F9: 0xB8BA,
	0x86FA: 0xDFE6,
	0x86FB: 0xB8C0,
	0x86FC: 0xFFFD,
	0x86FD: 0xFFFD,
	0x86FE: 0xB8BF,
	0x86FF: 0xFFFD,
	0x8700: 0xB8BE,
	0x8701: 0xDFED,
	0x8702: 0xB8C1,
	0x8703: 0xB8C2,
	0x8704: 0xDFE3,
	0x8705: 0xDFF0,
	0x8706: 0xB8C3,
	0x8707: 0xB8BD,
	0x8708: 0xB8BC,
	0x8709: 0xDFEC,
	0x870A: 0xB8C4,
	0x870B: 0xDFE2,
	0x870C: 0xDFE5,
	0x870D: 0xDFEF,
	0x870E: 0xDFEB,
	0x870F: 0xFFFD,
	0x8710: 0xFFFD,
	0x8711: 0xE3F4,
	0x8712: 0xE3E9,
	0x8713: 0xB8BB,
	0x8714: 0xFFFD,
	0x8715: 0x9160,
	0x8716: 0xFFFD,
	0x8717: 0x8854,
	0x8718: 0xBB6A,
	0x8719: 0xE3DD,
	0x871A: 0xE3F2,
	0x871B: 0xE3DE,
	0x871C: 0xBB65,
	0x871D: 0xFFFD,
	0x871E: 0xE3DB,
	0x871F: 0xFFFD,
	0x8720: 0xE3E4,
	0x8721: 0xE3DC,
	0x8722: 0xBB67,
	0x8723: 0xE3D6,
	0x8724: 0xE3F1,
	0x8725: 0xBB68,
	0x8726: 0xE3EE,
	0x8727: 0xE3EF,
	0x8728: 0xE3D7,
	0x8729: 0xBB6D,
	0x872A: 0xE3E6,
	0x872B: 0xFFFD,
	0x872C: 0xE3E0,
	0x872D: 0xE3E7,
	0x872E: 0xE3DA,
	0x872F: 0xFFFD,
	0x8730: 0xE3F3,
	0x8731: 0xE3EB,
	0x8732: 0xE3E5,
	0x8733: 0xE3D5,
	0x8734: 0xBB69,
	0x8735: 0xE3EC,
	0x8736: 0xFFFD,
	0x8737: 0xBB6C,
	0x8738: 0xE3F0,
	0x8739: 0xFFFD,
	0x873A: 0xE3EA,
	0x873B: 0xBB66,
	0x873C: 0xE3E8,
	0x873D: 0xFFFD,
	0x873E: 0xE3E2,
	0x873F: 0xBB64,
	0x8740: 0xE3D9,
	0x8741: 0xE3E1,
	0x8742: 0xE3ED,
	0x8743: 0xE3DF,
	0x8744: 0xFFFD,
	0x8745: 0xFFFD,
	0x8746: 0xE3E3,
	0x8747: 0x8BBB,
	0x8748: 0x8A61,
	0x8749: 0x8AFB,
	0x874A: 0xFFFD,
	0x874B: 0x82A2,
	0x874C: 0xBDC1,
	0x874D: 0xDFE9,
	0x874E: 0xE7B2,
	0x874F: 0xE7BB,
	0x8750: 0xE7B1,
	0x8751: 0xE7AD,
	0x8752: 0xE7AA,
	0x8753: 0xBDC2,
	0x8754: 0xE7A8,
	0x8755: 0xBB6B,
	0x8756: 0xE7A1,
	0x8757: 0xBDC0,
	0x8758: 0xE7A7,
	0x8759: 0xBDBF,
	0x875A: 0xE7AC,
	0x875B: 0xE7A9,
	0x875C: 0xE7B9,
	0x875D: 0xE7B4,
	0x875E: 0xE7AE,
	0x875F: 0xE7B3,
	0x8760: 0xBDBB,
	0x8761: 0xE7AB,
	0x8762: 0xE7BE,
	0x8763: 0xE7A2,
	0x8764: 0xE7A3,
	0x8765: 0xE7BA,
	0x8766: 0xBDBC,
	0x8767: 0xE7BF,
	0x8768: 0xBDBE,
	0x8769: 0xE7C0,
	0x876A: 0xE7B0,
	0x876B: 0xE3D8,
	0x876C: 0xE7B6,
	0x876D: 0xE7AF,
	0x876E: 0xE7B8,
	0x876F: 0xE7B5,
	0x8770: 0x9161,
	0x8771: 0xFD45,
	0x8772: 0xFFFD,
	0x8773: 0xE7A6,
	0x8774: 0xBDB9,
	0x8775: 0xE7BD,
	0x8776: 0xBDBA,
	0x8777: 0xE7A4,
	0x8778: 0xBDBD,
	0x8779: 0xEB64,
	0x877A: 0xE7B7,
	0x877B: 0xE7BC,
	0x877C: 0x8A60,
	0x877D: 0x9162,
	0x877E: 0x8FE4,
	0x877F: 0x8275,
	0x8780: 0xFFFD,
	0x8781: 0xEB61,
	0x8782: 0xBDB8,
	0x8783: 0xBFC0,
	0x8784: 0xEB6B,
	0x8785: 0xEB67,
	0x8786: 0xFB6C,
	0x8787: 0xEB65,
	0x8788: 0xEB60,
	0x8789: 0xEB6F,
	0x878A: 0xFFFD,
	0x878B: 0x9163,
	0x878C: 0xFD47,
	0x878D: 0xBFC4,
	0x878E: 0xFFFD,
	0x878F: 0xEB5C,
	0x8790: 0xEB68,
	0x8791: 0xEB69,
	0x8792: 0xEB5F,
	0x8793: 0xEB5E,
	0x8794: 0xEB6C,
	0x8795: 0xFFFD,
	0x8796: 0xEB62,
	0x8797: 0xEB5D,
	0x8798: 0xEB63,
	0x8799: 0xFFFD,
	0x879A: 0xEB6E,
	0x879B: 0xEB5B,
	0x879C: 0xEB6D,
	0x879D: 0xEB6A,
	0x879E: 0xBFC2,
	0x879F: 0xBFC1,
	0x87A0: 0xFFFD,
	0x87A1: 0xFFFD,
	0x87A2: 0xBFC3,
	0x87A3: 0xEB66,
	0x87A4: 0xF0CB,
	0x87A5: 0xFEBF,
	0x87A6: 0xFFFD,
	0x87A7: 0xFFFD,
	0x87A8: 0x9164,
	0x87A9: 0xFD46,
	0x87AA: 0xEE59,
	0x87AB: 0xC1B1,
	0x87AC: 0xEE5D,
	0x87AD: 0xEE5A,
	0x87AE: 0xEE61,
	0x87AF: 0xEE67,
	0x87B0: 0xEE5C,
	0x87B1: 0xFEC0,
	0x87B2: 0xEE70,
	0x87B3: 0xC1AE,
	0x87B4: 0xEE6A,
	0x87B5: 0xEE5F,
	0x87B6: 0xEE6B,
	0x87B7: 0xEE66,
	0x87B8: 0xEE6D,
	0x87B9: 0xEE5E,
	0x87BA: 0xC1B3,
	0x87BB: 0xC1B2,
	0x87BC: 0xEE60,
	0x87BD: 0xEE6E,
	0x87BE: 0xEE58,
	0x87BF: 0xEE6C,
	0x87C0: 0xC1AC,
	0x87C1: 0xFD49,
	0x87C2: 0xEE64,
	0x87C3: 0xEE63,
	0x87C4: 0xEE68,
	0x87C5: 0xEE5B,
	0x87C6: 0xC1B0,
	0x87C7: 0x9165,
	0x87C8: 0xC1B4,
	0x87C9: 0xEE62,
	0x87CA: 0xEE69,
	0x87CB: 0xC1B5,
	0x87CC: 0xEE65,
	0x87CD: 0xFFFD,
	0x87CE: 0x96C7,
	0x87CF: 0xFFFD,
	0x87D0: 0x9166,
	0x87D1: 0xC1AD,
	0x87D2: 0xC1AF,
	0x87D3: 0xF0C7,
	0x87D4: 0xF0C5,
	0x87D5: 0xFFFD,
	0x87D6: 0xFD4C,
	0x87D7: 0xF0CC,
	0x87D8: 0xF0C9,
	0x87D9: 0xF0CD,
	0x87DA: 0xFEC5,
	0x87DB: 0xF0BE,
	0x87DC: 0xF0C6,
	0x87DD: 0xF0D1,
	0x87DE: 0xEE6F,
	0x87DF: 0xF0C2,
	0x87E0: 0xC2CF,
	0x87E1: 0xE7A5,
	0x87E2: 0xF0BD,
	0x87E3: 0xF0CA,
	0x87E4: 0xF0C4,
	0x87E5: 0xF0C1,
	0x87E6: 0xF0BC,
	0x87E7: 0xF0BB,
	0x87E8: 0xF0D0,
	0x87E9: 0xFFFD,
	0x87EA: 0xF0C0,
	0x87EB: 0xF0BF,
	0x87EC: 0xC2CD,
	0x87ED: 0xF0C8,
	0x87EE: 0xFBAB,
	0x87EF: 0xC2CC,
	0x87F0: 0xFFFD,
	0x87F1: 0xFFFD,
	0x87F2: 0xC2CE,
	0x87F3: 0xF0C3,
	0x87F4: 0xF0CF,
	0x87F5: 0xFD4D,
	0x87F6: 0xF2DE,
	0x87F7: 0xF2DF,
	0x87F8: 0xFFFD,
	0x87F9: 0xC3C9,
	0x87FA: 0xF2DC,
	0x87FB: 0xC3C6,
	0x87FC: 0xF2E4,
	0x87FD: 0xFFFD,
	0x87FE: 0xC3CA,
	0x87FF: 0xF2E6,
	0x8800: 0xF2DB,
	0x8801: 0xF0CE,
	0x8802: 0xF2E8,
	0x8803: 0xF2DD,
	0x8804: 0xFB72,
	0x8805: 0xC3C7,
	0x8806: 0xF2E3,
	0x8807: 0x9167,
	0x8808: 0xF2E5,
	0x8809: 0xF2E0,
	0x880A: 0xF2E7,
	0x880B: 0xF2E2,
	0x880C: 0xF2E1,
	0x880D: 0xC3C8,
	0x880E: 0x9168,
	0x880F: 0xFD4E,
	0x8810: 0xF4C5,
	0x8811: 0xF4C6,
	0x8812: 0xFFFD,
	0x8813: 0xF4C8,
	0x8814: 0xC4AE,
	0x8815: 0xC4AF,
	0x8816: 0xF4C9,
	0x8817: 0xF4C7,
	0x8818: 0xFD4F,
	0x8819: 0xF4C4,
	0x881A: 0xFFFD,
	0x881B: 0xF642,
	0x881C: 0xF645,
	0x881D: 0xF641,
	0x881E: 0xFFFD,
	0x881F: 0xC4FA,
	0x8820: 0xF643,
	0x8821: 0xC4F9,
	0x8822: 0xC4F8,
	0x8823: 0xC4F7,
	0x8824: 0xF644,
	0x8825: 0xF751,
	0x8826: 0xF74F,
	0x8827: 0x9169,
	0x8828: 0xF74E,
	0x8829: 0xF640,
	0x882A: 0xF750,
	0x882B: 0xF646,
	0x882C: 0xF74D,
	0x882D: 0xFD50,
	0x882E: 0xF7F9,
	0x882F: 0xF7D7,
	0x8830: 0xF7F7,
	0x8831: 0xC5DB,
	0x8832: 0xF7F8,
	0x8833: 0xF7FA,
	0x8834: 0xFFFD,
	0x8835: 0xF8BF,
	0x8836: 0xC5FA,
	0x8837: 0xF8BE,
	0x8838: 0xF8BD,
	0x8839: 0xC5FB,
	0x883A: 0xFFFD,
	0x883B: 0xC65A,
	0x883C: 0xF96E,
	0x883D: 0xF9A7,
	0x883E: 0xF9A6,
	0x883F: 0xF9A8,
	0x8840: 0xA6E5,
	0x8841: 0xD0AA,
	0x8842: 0xFD51,
	0x8843: 0xD3CF,
	0x8844: 0xD3D0,
	0x8845: 0x8D75,
	0x8846: 0x92DB,
	0x8847: 0xFFFD,
	0x8848: 0xDBC0,
	0x8849: 0xFFFD,
	0x884A: 0xF647,
	0x884B: 0xF8C0,
	0x884C: 0xA6E6,
	0x884D: 0xAD6C,
	0x884E: 0xD0AB,
	0x884F: 0xFEC6,
	0x8850: 0xFFFD,
	0x8851: 0xFFFD,
	0x8852: 0xD7B1,
	0x8853: 0xB34E,
	0x8854: 0x83F5,
	0x8855: 0xDBC2,
	0x8856: 0xDBC1,
	0x8857: 0xB5F3,
	0x8858: 0xFFFD,
	0x8859: 0xB8C5,
	0x885A: 0xE7C1,
	0x885B: 0xBDC3,
	0x885C: 0xFFFD,
	0x885D: 0xBDC4,
	0x885E: 0xFD5B,
	0x885F: 0xFFFD,
	0x8860: 0xFEC7,
	0x8861: 0xBFC5,
	0x8862: 0xC5FC,
	0x8863: 0xA6E7,
	0x8864: 0x91D6,
	0x8865: 0x8644,
	0x8866: 0xFFFD,
	0x8867: 0xD0AC,
	0x8868: 0xAAED,
	0x8869: 0xD0AE,
	0x886A: 0xD0AD,
	0x886B: 0xAD6D,
	0x886C: 0x8CDC,
	0x886D: 0xD3D1,
	0x886E: 0x847C,
	0x886F: 0xD3D8,
	0x8870: 0xB049,
	0x8871: 0xD3D6,
	0x8872: 0xD3D4,
	0x8873: 0xFFFD,
	0x8874: 0xD3DB,
	0x8875: 0xD3D2,
	0x8876: 0xD3D3,
	0x8877: 0xB04A,
	0x8878: 0xFFFD,
	0x8879: 0xB04E,
	0x887A: 0xFFFD,
	0x887B: 0xFFFD,
	0x887C: 0xD3DC,
	0x887D: 0xB04D,
	0x887E: 0xD3DA,
	0x887F: 0xD3D7,
	0x8880: 0xD3D5,
	0x8881: 0xB04B,
	0x8882: 0xB04C,
	0x8883: 0xD3D9,
	0x8884: 0x8BBD,
	0x8885: 0x88D3,
	0x8886: 0xFFFD,
	0x8887: 0xFEC8,
	0x8888: 0xB350,
	0x8889: 0xD7B2,
	0x888A: 0xFFFD,
	0x888B: 0xB355,
	0x888C: 0xD7C2,
	0x888D: 0xB354,
	0x888E: 0xD7C4,
	0x888F: 0xFEC9,
	0x8890: 0xFECA,
	0x8891: 0xD7B8,
	0x8892: 0xB352,
	0x8893: 0xD7C3,
	0x8894: 0xFFFD,
	0x8895: 0xD7B3,
	0x8896: 0xB353,
	0x8897: 0xD7BF,
	0x8898: 0xD7BB,
	0x8899: 0xD7BD,
	0x889A: 0xD7B7,
	0x889B: 0xD7BE,
	0x889C: 0x90BA,
	0x889D: 0xFFFD,
	0x889E: 0xB34F,
	0x889F: 0xD7BA,
	0x88A0: 0xFD56,
	0x88A1: 0xD7B9,
	0x88A2: 0xD7B5,
	0x88A3: 0xFFFD,
	0x88A4: 0xD7C0,
	0x88A5: 0xFFFD,
	0x88A6: 0xFFFD,
	0x88A7: 0xD7BC,
	0x88A8: 0xD7B4,
	0x88A9: 0xFFFD,
	0x88AA: 0xD7B6,
	0x88AB: 0xB351,
	0x88AC: 0xD7C1,
	0x88AD: 0x8CDB,
	0x88AE: 0x916A,
	0x88AF: 0xFFFD,
	0x88B0: 0x94CE,
	0x88B1: 0xB5F6,
	0x88B2: 0xDBCD,
	0x88B3: 0xFFFD,
	0x88B4: 0x95DD,
	0x88B5: 0x916C,
	0x88B6: 0xDBC9,
	0x88B7: 0xDBCB,
	0x88B8: 0xDBC6,
	0x88B9: 0xDBC5,
	0x88BA: 0xDBC3,
	0x88BB: 0xFFFD,
	0x88BC: 0xDBCA,
	0x88BD: 0xDBCC,
	0x88BE: 0xDBC8,
	0x88BF: 0x916D,
	0x88C0: 0xDBC7,
	0x88C1: 0xB5F4,
	0x88C2: 0xB5F5,
	0x88C3: 0x94CF,
	0x88C4: 0x94D0,
	0x88C5: 0x8645,
	0x88C6: 0x8BBC,
	0x88C7: 0xFB63,
	0x88C8: 0xFFFD,
	0x88C9: 0xDBCF,
	0x88CA: 0xB8CD,
	0x88CB: 0xDFF2,
	0x88CC: 0xDFF8,
	0x88CD: 0xDFF3,
	0x88CE: 0xDFF4,
	0x88CF: 0xF9D8,
	0x88D0: 0xDFF9,
	0x88D1: 0xFFFD,
	0x88D2: 0xB8CF,
	0x88D3: 0xFFFD,
	0x88D4: 0xB8C7,
	0x88D5: 0xB8CE,
	0x88D6: 0xDFF1,
	0x88D7: 0xDBC4,
	0x88D8: 0xB8CA,
	0x88D9: 0xB8C8,
	0x88DA: 0xDFF7,
	0x88DB: 0xDFF6,
	0x88DC: 0xB8C9,
	0x88DD: 0xB8CB,
	0x88DE: 0xDFF5,
	0x88DF: 0xB8C6,
	0x88E0: 0xFFFD,
	0x88E1: 0xB8CC,
	0x88E2: 0x8F62,
	0x88E3: 0x8FC5,
	0x88E4: 0x895C,
	0x88E5: 0x916E,
	0x88E6: 0xFECB,
	0x88E7: 0xE3F6,
	0x88E8: 0xBB74,
	0x88E9: 0xFFFD,
	0x88EA: 0xFFFD,
	0x88EB: 0xE442,
	0x88EC: 0xE441,
	0x88ED: 0xFFFD,
	0x88EE: 0xE3FB,
	0x88EF: 0xBB76,
	0x88F0: 0xE440,
	0x88F1: 0xE3F7,
	0x88F2: 0xE3F8,
	0x88F3: 0xBB6E,
	0x88F4: 0xBB70,
	0x88F5: 0x916F,
	0x88F6: 0xE3FD,
	0x88F7: 0xE3F5,
	0x88F8: 0xBB72,
	0x88F9: 0xBB71,
	0x88FA: 0xE3F9,
	0x88FB: 0xE3FE,
	0x88FC: 0xE3FC,
	0x88FD: 0xBB73,
	0x88FE: 0xE3FA,
	0x88FF: 0xFECC,
	0x8900: 0xFECD,
	0x8901: 0xDBCE,
	0x8902: 0xBB6F,
	0x8903: 0xFFFD,
	0x8904: 0x94D1,
	0x8905: 0xE7C2,
	0x8906: 0xE7C9,
	0x8907: 0xBDC6,
	0x8908: 0xFFFD,
	0x8909: 0xE7CD,
	0x890A: 0xBDCA,
	0x890B: 0xE7C5,
	0x890C: 0xE7C3,
	0x890D: 0xFFFD,
	0x890E: 0xE7CC,
	0x890F: 0xFFFD,
	0x8910: 0xBDC5,
	0x8911: 0xE7CB,
	0x8912: 0xBDC7,
	0x8913: 0xBDC8,
	0x8914: 0xE7C4,
	0x8915: 0xBDC9,
	0x8916: 0xE7CA,
	0x8917: 0xE7C6,
	0x8918: 0xE7C7,
	0x8919: 0xE7C8,
	0x891A: 0xBB75,
	0x891B: 0x8A63,
	0x891C: 0x9170,
	0x891D: 0x9171,
	0x891E: 0xEB70,
	0x891F: 0xEB7C,
	0x8920: 0xFFFD,
	0x8921: 0xBFCA,
	0x8922: 0xEB77,
	0x8923: 0xEB79,
	0x8924: 0xFECE,
	0x8925: 0xBFC8,
	0x8926: 0xEB71,
	0x8927: 0xEB75,
	0x8928: 0xFFFD,
	0x8929: 0xEB78,
	0x892A: 0xBFC6,
	0x892B: 0xBFC9,
	0x892C: 0xEB7B,
	0x892D: 0xEB73,
	0x892E: 0xEB74,
	0x892F: 0xEB7A,
	0x8930: 0xEB72,
	0x8931: 0xEB76,
	0x8932: 0xBFC7,
	0x8933: 0xEE72,
	0x8934: 0x8C53,
	0x8935: 0xEE71,
	0x8936: 0xC1B7,
	0x8937: 0xEE77,
	0x8938: 0xC1B9,
	0x8939: 0xFFFD,
	0x893A: 0xFFFD,
	0x893B: 0xC1B6,
	0x893C: 0xEE73,
	0x893D: 0xC1BA,
	0x893E: 0xEE74,
	0x893F: 0xFFFD,
	0x8940: 0xFFFD,
	0x8941: 0xEE75,
	0x8942: 0xEE78,
	0x8943: 0xFD58,
	0x8944: 0xC1B8,
	0x8945: 0xFFFD,
	0x8946: 0xF0D6,
	0x8947: 0xFECF,
	0x8948: 0xFFFD,
	0x8949: 0xF0D9,
	0x894A: 0xFFFD,
	0x894B: 0xF0D3,
	0x894C: 0xF0D5,
	0x894D: 0xFD59,
	0x894E: 0xFFFD,
	0x894F: 0xF0D4,
	0x8950: 0xF0D7,
	0x8951: 0xF0D8,
	0x8952: 0xEE76,
	0x8953: 0xF0D2,
	0x8954: 0xFED0,
	0x8955: 0xFFFD,
	0x8956: 0xC3CD,
	0x8957: 0xF2EC,
	0x8958: 0xF2EF,
	0x8959: 0xF2F1,
	0x895A: 0xF2EA,
	0x895B: 0xF2EB,
	0x895C: 0xF2EE,
	0x895D: 0xF2F0,
	0x895E: 0xC3CE,
	0x895F: 0xC3CC,
	0x8960: 0xC3CB,
	0x8961: 0xF2ED,
	0x8962: 0xF2E9,
	0x8963: 0xF4CA,
	0x8964: 0xC4B0,
	0x8965: 0xFED1,
	0x8966: 0xF4CB,
	0x8967: 0xFFFD,
	0x8968: 0xFFFD,
	0x8969: 0xF649,
	0x896A: 0xC4FB,
	0x896B: 0xF64B,
	0x896C: 0xC4FC,
	0x896D: 0xF648,
	0x896E: 0xF64A,
	0x896F: 0xC5A8,
	0x8970: 0xFFFD,
	0x8971: 0xF752,
	0x8972: 0xC5A7,
	0x8973: 0xF7FD,
	0x8974: 0xF7FC,
	0x8975: 0xFFFD,
	0x8976: 0xF7FB,
	0x8977: 0x9172,
	0x8978: 0xFFFD,
	0x8979: 0xF948,
	0x897A: 0xF949,
	0x897B: 0xF94B,
	0x897C: 0xF94A,
	0x897D: 0xFFFD,
	0x897E: 0xCA50,
	0x897F: 0xA6E8,
	0x8980: 0xFED2,
	0x8981: 0xAD6E,
	0x8982: 0xD7C5,
	0x8983: 0xB5F7,
	0x8984: 0xFFFD,
	0x8985: 0xDFFA,
	0x8986: 0xC2D0,
	0x8987: 0x95F6,
	0x8988: 0xF2F2,
	0x8989: 0xFD6D,
	0x898A: 0xFD6E,
	0x898B: 0xA8A3,
	0x898C: 0xFFFD,
	0x898D: 0xFFFD,
	0x898E: 0xFFFD,
	0x898F: 0xB357,
	0x8990: 0xFFFD,
	0x8991: 0xFED3,
	0x8992: 0xFFFD,
	0x8993: 0xB356,
	0x8994: 0xFD6F,
	0x8995: 0xDBD0,
	0x8996: 0xB5F8,
	0x8997: 0xDBD2,
	0x8998: 0xDBD1,
	0x8999: 0xFFFD,
	0x899A: 0x9260,
	0x899B: 0xDFFB,
	0x899C: 0xB8D0,
	0x899D: 0xE443,
	0x899E: 0xE446,
	0x899F: 0xE445,
	0x89A0: 0xFFFD,
	0x89A1: 0xE444,
	0x89A2: 0xE7CE,
	0x89A3: 0xE7D0,
	0x89A4: 0xE7CF,
	0x89A5: 0xFBAF,
	0x89A6: 0xBFCC,
	0x89A7: 0x93E1,
	0x89A8: 0xFFFD,
	0x89A9: 0x95C5,
	0x89AA: 0xBFCB,
	0x89AB: 0xFFFD,
	0x89AC: 0xC1BB,
	0x89AD: 0xEE79,
	0x89AE: 0xEE7B,
	0x89AF: 0xEE7A,
	0x89B0: 0xFFFD,
	0x89B1: 0xFFFD,
	0x89B2: 0xC2D1,
	0x89B3: 0x926D,
	0x89B4: 0xFFFD,
	0x89B5: 0xFFFD,
	0x89B6: 0xF2F4,
	0x89B7: 0xF2F3,
	0x89B8: 0xFFFD,
	0x89B9: 0xF4CC,
	0x89BA: 0xC4B1,
	0x89BB: 0xFFFD,
	0x89BC: 0xFD71,
	0x89BD: 0xC4FD,
	0x89BE: 0xF754,
	0x89BF: 0xF753,
	0x89C0: 0xC65B,
	0x89C1: 0x834E,
	0x89C2: 0x8D73,
	0x89C3: 0xFFFD,
	0x89C4: 0x847E,
	0x89C5: 0x847D,
	0x89C6: 0x8553,
	0x89C7: 0x8DE6,
	0x89C8: 0x8CA6,
	0x89C9: 0x8C54,
	0x89CA: 0x8A64,
	0x89CB: 0x8E7E,
	0x89CC: 0x905C,
	0x89CD: 0xFFFD,
	0x89CE: 0x895E,
	0x89CF: 0x8F63,
	0x89D0: 0x8AFC,
	0x89D1: 0x8FC6,
	0x89D2: 0xA8A4,
	0x89D3: 0xD0AF,
	0x89D4: 0xAD6F,
	0x89D5: 0xD7C8,
	0x89D6: 0xD7C6,
	0x89D7: 0xFFFD,
	0x89D8: 0xFFFD,
	0x89D9: 0xD7C7,
	0x89DA: 0xDBD4,
	0x89DB: 0xDBD5,
	0x89DC: 0xE043,
	0x89DD: 0xDBD3,
	0x89DE: 0x8AFD,
	0x89DF: 0xDFFC,
	0x89E0: 0xE041,
	0x89E1: 0xE040,
	0x89E2: 0xE042,
	0x89E3: 0xB8D1,
	0x89E4: 0xDFFE,
	0x89E5: 0xDFFD,
	0x89E6: 0xE044,
	0x89E7: 0x9173,
	0x89E8: 0xE449,
	0x89E9: 0xE447,
	0x89EA: 0xFFFD,
	0x89EB: 0xE448,
	0x89EC: 0xE7D3,
	0x89ED: 0xE7D1,
	0x89EE: 0xFFFD,
	0x89EF: 0x8FC7,
	0x89F0: 0xE7D2,
	0x89F1: 0xEB7D,
	0x89F2: 0xEE7C,
	0x89F3: 0xEE7D,
	0x89F4: 0xC2D2,
	0x89F5: 0xFFFD,
	0x89F6: 0xF2F5,
	0x89F7: 0xF4CD,
	0x89F8: 0xC4B2,
	0x89F9: 0xFFFD,
	0x89FA: 0xF64C,
	0x89FB: 0xF755,
	0x89FC: 0xC5A9,
	0x89FD: 0xFFFD,
	0x89FE: 0xF7FE,
	0x89FF: 0xF94C,
	0x8A00: 0xA8A5,
	0x8A01: 0xFFFD,
	0x8A02: 0xAD71,
	0x8A03: 0xAD72,
	0x8A04: 0xD0B0,
	0x8A05: 0xFFFD,
	0x8A06: 0xFFFD,
	0x8A07: 0xD0B1,
	0x8A08: 0xAD70,
	0x8A09: 0xFFFD,
	0x8A0A: 0xB054,
	0x8A0B: 0xFFFD,
	0x8A0C: 0xB052,
	0x8A0D: 0xFFFD,
	0x8A0E: 0xB051,
	0x8A0F: 0xB058,
	0x8A10: 0xB050,
	0x8A11: 0xB059,
	0x8A12: 0xD3DD,
	0x8A13: 0xB056,
	0x8A14: 0xFFFD,
	0x8A15: 0xB053,
	0x8A16: 0xB057,
	0x8A17: 0xB055,
	0x8A18: 0xB04F,
	0x8A19: 0xFFFD,
	0x8A1A: 0xFFFD,
	0x8A1B: 0xB35F,
	0x8A1C: 0xFED4,
	0x8A1D: 0xB359,
	0x8A1E: 0xD7CC,
	0x8A1F: 0xB35E,
	0x8A20: 0xFFFD,
	0x8A21: 0xFFFD,
	0x8A22: 0xB360,
	0x8A23: 0xB35A,
	0x8A24: 0xFFFD,
	0x8A25: 0xB35B,
	0x8A26: 0xFFFD,
	0x8A27: 0xD7CA,
	0x8A28: 0xFFFD,
	0x8A29: 0xFED5,
	0x8A2A: 0xB358,
	0x8A2B: 0xFED6,
	0x8A2C: 0xD7CB,
	0x8A2D: 0xB35D,
	0x8A2E: 0xFFFD,
	0x8A2F: 0xFFFD,
	0x8A30: 0xD7C9,
	0x8A31: 0xB35C,
	0x8A32: 0xFFFD,
	0x8A33: 0x93D5,
	0x8A34: 0xB644,
	0x8A35: 0xFFFD,
	0x8A36: 0xB646,
	0x8A37: 0x9174,
	0x8A38: 0xFED7,
	0x8A39: 0xDBD8,
	0x8A3A: 0xB645,
	0x8A3B: 0xB5F9,
	0x8A3C: 0xB5FD,
	0x8A3D: 0xFED8,
	0x8A3E: 0xB8E4,
	0x8A3F: 0xE049,
	0x8A40: 0xDBDA,
	0x8A41: 0xB5FE,
	0x8A42: 0xFFFD,
	0x8A43: 0xFFFD,
	0x8A44: 0xDBDD,
	0x8A45: 0xDBDE,
	0x8A46: 0xB643,
	0x8A47: 0xFFFD,
	0x8A48: 0xDBE0,
	0x8A49: 0xFD73,
	0x8A4A: 0xDBE2,
	0x8A4B: 0xFFFD,
	0x8A4C: 0xDBE3,
	0x8A4D: 0xDBD7,
	0x8A4E: 0xDBD6,
	0x8A4F: 0xDBE4,
	0x8A50: 0xB642,
	0x8A51: 0xDBE1,
	0x8A52: 0xDBDF,
	0x8A53: 0xFFFD,
	0x8A54: 0xB640,
	0x8A55: 0xB5FB,
	0x8A56: 0xB647,
	0x8A57: 0xDBDB,
	0x8A58: 0xDBDC,
	0x8A59: 0xDBD9,
	0x8A5A: 0xFFFD,
	0x8A5B: 0xB641,
	0x8A5C: 0xFFFD,
	0x8A5D: 0xFFFD,
	0x8A5E: 0xB5FC,
	0x8A5F: 0xFFFD,
	0x8A60: 0xB5FA,
	0x8A61: 0xE048,
	0x8A62: 0xB8DF,
	0x8A63: 0xB8DA,
	0x8A64: 0xFFFD,
	0x8A65: 0xFFFD,
	0x8A66: 0xB8D5,
	0x8A67: 0xFCDA,
	0x8A68: 0xB8E5,
	0x8A69: 0xB8D6,
	0x8A6A: 0xFFFD,
	0x8A6B: 0xB8D2,
	0x8A6C: 0xB8E1,
	0x8A6D: 0xB8DE,
	0x8A6E: 0xB8E0,
	0x8A6F: 0xFFFD,
	0x8A70: 0xB8D7,
	0x8A71: 0xB8DC,
	0x8A72: 0xB8D3,
	0x8A73: 0xB8D4,
	0x8A74: 0xE050,
	0x8A75: 0xE04D,
	0x8A76: 0xE045,
	0x8A77: 0xE04A,
	0x8A78: 0xFFFD,
	0x8A79: 0xB8E2,
	0x8A7A: 0xE051,
	0x8A7B: 0xB8E3,
	0x8A7C: 0xB8D9,
	0x8A7D: 0xFFFD,
	0x8A7E: 0xFD72,
	0x8A7F: 0xE047,
	0x8A80: 0xFFFD,
	0x8A81: 0xE04F,
	0x8A82: 0xE04B,
	0x8A83: 0xE04E,
	0x8A84: 0xE04C,
	0x8A85: 0xB8DD,
	0x8A86: 0xE046,
	0x8A87: 0xB8D8,
	0x8A88: 0xFFFD,
	0x8A89: 0x8CA9,
	0x8A8A: 0x8A6C,
	0x8A8B: 0xE44C,
	0x8A8C: 0xBB78,
	0x8A8D: 0xBB7B,
	0x8A8E: 0xFFFD,
	0x8A8F: 0xE44E,
	0x8A90: 0xFEDA,
	0x8A91: 0xBBA5,
	0x8A92: 0xE44D,
	0x8A93: 0xBB7D,
	0x8A94: 0xFEDB,
	0x8A95: 0xBDCF,
	0x8A96: 0xE44F,
	0x8A97: 0xFFFD,
	0x8A98: 0xBBA4,
	0x8A99: 0xE44B,
	0x8A9A: 0xBBA6,
	0x8A9B: 0xFFFD,
	0x8A9C: 0xFEDC,
	0x8A9D: 0xFFFD,
	0x8A9E: 0xBB79,
	0x8A9F: 0xFFFD,
	0x8AA0: 0xB8DB,
	0x8AA1: 0xBB7C,
	0x8AA2: 0xFFFD,
	0x8AA3: 0xBB7A,
	0x8AA4: 0xBB7E,
	0x8AA5: 0xBBA2,
	0x8AA6: 0xBB77,
	0x8AA7: 0xBBA7,
	0x8AA8: 0xBBA3,
	0x8AA9: 0xFEDD,
	0x8AAA: 0xBBA1,
	0x8AAB: 0xE44A,
	0x8AAC: 0x9175,
	0x8AAD: 0x93AB,
	0x8AAE: 0xFFFD,
	0x8AAF: 0xFEDE,
	0x8AB0: 0xBDD6,
	0x8AB1: 0xFFFD,
	0x8AB2: 0xBDD2,
	0x8AB3: 0xFFFD,
	0x8AB4: 0xFEDF,
	0x8AB5: 0xFFFD,
	0x8AB6: 0xBDD9,
	0x8AB7: 0xFFFD,
	0x8AB8: 0xE7D6,
	0x8AB9: 0xBDDA,
	0x8ABA: 0xE7E2,
	0x8ABB: 0xE7DB,
	0x8ABC: 0xBDCB,
	0x8ABD: 0xE7E3,
	0x8ABE: 0xE7DD,
	0x8ABF: 0xBDD5,
	0x8AC0: 0xE7DE,
	0x8AC1: 0xFFFD,
	0x8AC2: 0xBDD4,
	0x8AC3: 0xE7E1,
	0x8AC4: 0xBDCE,
	0x8AC5: 0xE7DF,
	0x8AC6: 0xE7D5,
	0x8AC7: 0xBDCD,
	0x8AC8: 0xEBAA,
	0x8AC9: 0xBDD3,
	0x8ACA: 0xFFFD,
	0x8ACB: 0xBDD0,
	0x8ACC: 0x8251,
	0x8ACD: 0xBDD8,
	0x8ACE: 0xFFFD,
	0x8ACF: 0xE7D4,
	0x8AD0: 0xFFFD,
	0x8AD1: 0xE7D8,
	0x8AD2: 0xBDCC,
	0x8AD3: 0xE7D7,
	0x8AD4: 0xE7D9,
	0x8AD5: 0xE7DA,
	0x8AD6: 0xBDD7,
	0x8AD7: 0xE7DC,
	0x8AD8: 0xE7E0,
	0x8AD9: 0xE7E4,
	0x8ADA: 0x9176,
	0x8ADB: 0xBDDB,
	0x8ADC: 0xBFD2,
	0x8ADD: 0xEBA5,
	0x8ADE: 0xEBAB,
	0x8ADF: 0xEBA8,
	0x8AE0: 0xEB7E,
	0x8AE1: 0xEBAC,
	0x8AE2: 0xEBA1,
	0x8AE3: 0xFFFD,
	0x8AE4: 0xEBA7,
	0x8AE5: 0xFFFD,
	0x8AE6: 0xBFCD,
	0x8AE7: 0xBFD3,
	0x8AE8: 0xEBAD,
	0x8AE9: 0xFFFD,
	0x8AEA: 0xFEE0,
	0x8AEB: 0xBFCF,
	0x8AEC: 0xFFFD,
	0x8AED: 0xBFD9,
	0x8AEE: 0xBFD4,
	0x8AEF: 0xEBAF,
	0x8AF0: 0xEBA9,
	0x8AF1: 0xBFD0,
	0x8AF2: 0xEBA2,
	0x8AF3: 0xBFDA,
	0x8AF4: 0xEBA3,
	0x8AF5: 0xEBA4,
	0x8AF6: 0xBFDB,
	0x8AF7: 0xBFD8,
	0x8AF8: 0xBDD1,
	0x8AF9: 0x9DD1,
	0x8AFA: 0xBFCE,
	0x8AFB: 0xEBB0,
	0x8AFC: 0xBFDC,
	0x8AFD: 0xFFFD,
	0x8AFE: 0xBFD5,
	0x8AFF: 0xEBAE,
	0x8B00: 0xBFD1,
	0x8B01: 0xBFD6,
	0x8B02: 0xBFD7,
	0x8B03: 0xFFFD,
	0x8B04: 0xC1C3,
	0x8B05: 0xEEA4,
	0x8B06: 0xEEAD,
	0x8B07: 0xEEAA,
	0x8B08: 0xEEAC,
	0x8B09: 0xFFFD,
	0x8B0A: 0xC1C0,
	0x8B0B: 0xEEA5,
	0x8B0C: 0xFD74,
	0x8B0D: 0xEEAB,
	0x8B0E: 0xC1BC,
	0x8B0F: 0xEEA7,
	0x8B10: 0xC1C4,
	0x8B11: 0xEEA3,
	0x8B12: 0xEEA8,
	0x8B13: 0xEEAF,
	0x8B14: 0xEBA6,
	0x8B15: 0xEEA9,
	0x8B16: 0xEEA2,
	0x8B17: 0xC1BD,
	0x8B18: 0xEEA1,
	0x8B19: 0xC1BE,
	0x8B1A: 0xEEB0,
	0x8B1B: 0xC1BF,
	0x8B1C: 0xEEAE,
	0x8B1D: 0xC1C2,
	0x8B1E: 0xEE7E,
	0x8B1F: 0xFEE1,
	0x8B20: 0xC1C1,
	0x8B21: 0x93DC,
	0x8B22: 0xEEA6,
	0x8B23: 0xF0DC,
	0x8B24: 0xF0EA,
	0x8B25: 0xF0E5,
	0x8B26: 0xF0E7,
	0x8B27: 0xF0DB,
	0x8B28: 0xC2D3,
	0x8B29: 0xFFFD,
	0x8B2A: 0xF0DA,
	0x8B2B: 0xC2D6,
	0x8B2C: 0xC2D5,
	0x8B2D: 0x96C1,
	0x8B2E: 0xF0E9,
	0x8B2F: 0xF0E1,
	0x8B30: 0xF0DE,
	0x8B31: 0xF0E4,
	0x8B32: 0xFFFD,
	0x8B33: 0xF0DD,
	0x8B34: 0xFFFD,
	0x8B35: 0xF0DF,
	0x8B36: 0xF0E8,
	0x8B37: 0xF0E6,
	0x8B38: 0xFFFD,
	0x8B39: 0xC2D4,
	0x8B3A: 0xF0ED,
	0x8B3B: 0xF0EB,
	0x8B3C: 0xF0E2,
	0x8B3D: 0xF0EC,
	0x8B3E: 0xF0E3,
	0x8B3F: 0xFEE3,
	0x8B40: 0xF2F9,
	0x8B41: 0xC3CF,
	0x8B42: 0xF341,
	0x8B43: 0xFD75,
	0x8B44: 0xFFFD,
	0x8B45: 0xF64F,
	0x8B46: 0xC3D6,
	0x8B47: 0xF0E0,
	0x8B48: 0xF2F7,
	0x8B49: 0xC3D2,
	0x8B4A: 0xF2F8,
	0x8B4B: 0xF2FD,
	0x8B4C: 0xFD77,
	0x8B4D: 0xFEE4,
	0x8B4E: 0xC3D4,
	0x8B4F: 0xC3D5,
	0x8B50: 0xF2F6,
	0x8B51: 0xF340,
	0x8B52: 0xF342,
	0x8B53: 0xF2FA,
	0x8B54: 0xF2FC,
	0x8B55: 0xF2FE,
	0x8B56: 0xF2FB,
	0x8B57: 0xF343,
	0x8B58: 0xC3D1,
	0x8B59: 0xC3D7,
	0x8B5A: 0xC3D3,
	0x8B5B: 0x9177,
	0x8B5C: 0xC3D0,
	0x8B5D: 0xF4D0,
	0x8B5E: 0xFEE5,
	0x8B5F: 0xC4B7,
	0x8B60: 0xF4CE,
	0x8B61: 0xFFFD,
	0x8B62: 0xFEE6,
	0x8B63: 0xF4D2,
	0x8B64: 0xFFFD,
	0x8B65: 0xF4D3,
	0x8B66: 0xC4B5,
	0x8B67: 0xF4D4,
	0x8B68: 0xF4D1,
	0x8B69: 0xFEE7,
	0x8B6A: 0xF4CF,
	0x8B6B: 0xC4B8,
	0x8B6C: 0xC4B4,
	0x8B6D: 0xF4D5,
	0x8B6E: 0xFFFD,
	0x8B6F: 0xC4B6,
	0x8B70: 0xC4B3,
	0x8B71: 0x9178,
	0x8B72: 0x92F0,
	0x8B73: 0xFFFD,
	0x8B74: 0xC4FE,
	0x8B75: 0xFFFD,
	0x8B76: 0xFFFD,
	0x8B77: 0xC540,
	0x8B78: 0xF64E,
	0x8B79: 0xF64D,
	0x8B7A: 0xF650,
	0x8B7B: 0xF651,
	0x8B7C: 0xFFFD,
	0x8B7D: 0xC541,
	0x8B7E: 0xF756,
	0x8B7F: 0xF75B,
	0x8B80: 0xC5AA,
	0x8B81: 0xFD76,
	0x8B82: 0xF758,
	0x8B83: 0x8263,
	0x8B84: 0xF757,
	0x8B85: 0xF75A,
	0x8B86: 0xF759,
	0x8B87: 0xFFFD,
	0x8B88: 0xF843,
	0x8B89: 0xFFFD,
	0x8B8A: 0xC5DC,
	0x8B8B: 0xF842,
	0x8B8C: 0xF840,
	0x8B8D: 0xFFFD,
	0x8B8E: 0xF841,
	0x8B8F: 0xFFFD,
	0x8B90: 0x95F8,
	0x8B91: 0xFFFD,
	0x8B92: 0xC5FE,
	0x8B93: 0xC5FD,
	0x8B94: 0xF8C1,
	0x8B95: 0xF8C2,
	0x8B96: 0xC640,
	0x8B97: 0xFFFD,
	0x8B98: 0xF94D,
	0x8B99: 0xF94E,
	0x8B9A: 0xC667,
	0x8B9B: 0xFEE8,
	0x8B9C: 0xC66D,
	0x8B9D: 0xFFFD,
	0x8B9E: 0xF9A9,
	0x8B9F: 0xF9C8,
	0x8BA0: 0x9CEC,
	0x8BA1: 0x8379,
	0x8BA2: 0x837A,
	0x8BA3: 0x837B,
	0x8BA4: 0x8750,
	0x8BA5: 0x8BC2,
	0x8BA6: 0x83D4,
	0x8BA7: 0x83D6,
	0x8BA8: 0x83D5,
	0x8BA9: 0x8D58,
	0x8BAA: 0x83D7,
	0x8BAB: 0x83DA,
	0x8BAC: 0xFFFD,
	0x8BAD: 0x83D9,
	0x8BAE: 0x8C56,
	0x8BAF: 0x83D8,
	0x8BB0: 0x83D3,
	0x8BB1: 0xFFFD,
	0x8BB2: 0x8A68,
	0x8BB3: 0x8962,
	0x8BB4: 0x8F7E,
	0x8BB5: 0x8DE7,
	0x8BB6: 0x84A2,
	0x8BB7: 0x84A4,
	0x8BB8: 0x84A5,
	0x8BB9: 0x84A8,
	0x8BBA: 0x8862,
	0x8BBB: 0xFFFD,
	0x8BBC: 0x84A7,
	0x8BBD: 0x896A,
	0x8BBE: 0x84A6,
	0x8BBF: 0x84A1,
	0x8BC0: 0x84A3,
	0x8BC1: 0x8556,
	0x8BC2: 0x8557,
	0x8BC3: 0x855E,
	0x8BC4: 0x8554,
	0x8BC5: 0x8559,
	0x8BC6: 0x8BBF,
	0x8BC7: 0xFFFD,
	0x8BC8: 0x855A,
	0x8BC9: 0x855C,
	0x8BCA: 0x855D,
	0x8BCB: 0x855B,
	0x8BCC: 0x8F65,
	0x8BCD: 0x8555,
	0x8BCE: 0x8DE8,
	0x8BCF: 0x8558,
	0x8BD0: 0xFFFD,
	0x8BD1: 0x8C57,
	0x8BD2: 0x8DE9,
	0x8BD3: 0x8E4F,
	0x8BD4: 0x8E52,
	0x8BD5: 0x8649,
	0x8BD6: 0x8E50,
	0x8BD7: 0x864A,
	0x8BD8: 0x864B,
	0x8BD9: 0x864C,
	0x8BDA: 0x864E,
	0x8BDB: 0x8650,
	0x8BDC: 0x8E53,
	0x8BDD: 0x864F,
	0x8BDE: 0x885A,
	0x8BDF: 0x8654,
	0x8BE0: 0x8653,
	0x8BE1: 0x8651,
	0x8BE2: 0x8652,
	0x8BE3: 0x864D,
	0x8BE4: 0x8863,
	0x8BE5: 0x8647,
	0x8BE6: 0x8648,
	0x8BE7: 0x8646,
	0x8BE8: 0x8EF8,
	0x8BE9: 0x8E51,
	0x8BEA: 0xFFFD,
	0x8BEB: 0x8751,
	0x8BEC: 0x874F,
	0x8BED: 0x874E,
	0x8BEE: 0x8758,
	0x8BEF: 0x8752,
	0x8BF0: 0x8754,
	0x8BF1: 0x8756,
	0x8BF2: 0x8755,
	0x8BF3: 0x8757,
	0x8BF4: 0x8753,
	0x8BF5: 0x874D,
	0x8BF6: 0x8EA1,
	0x8BF7: 0x885B,
	0x8BF8: 0x885C,
	0x8BF9: 0x8ECB,
	0x8BFA: 0x8967,
	0x8BFB: 0x8CDD,
	0x8BFC: 0x8ECC,
	0x8BFD: 0x8865,
	0x8BFE: 0x885D,
	0x8BFF: 0x885E,
	0x8C00: 0x8866,
	0x8C01: 0x8861,
	0x8C02: 0x8ECD,
	0x8C03: 0x8860,
	0x8C04: 0x885F,
	0x8C05: 0x8857,
	0x8C06: 0x8859,
	0x8C07: 0x8864,
	0x8C08: 0x8858,
	0x8C09: 0xFFFD,
	0x8C0A: 0x8856,
	0x8C0B: 0x8963,
	0x8C0C: 0x896D,
	0x8C0D: 0x8964,
	0x8C0E: 0x8A69,
	0x8C0F: 0x8961,
	0x8C10: 0x8965,
	0x8C11: 0x8EF9,
	0x8C12: 0x8968,
	0x8C13: 0x8969,
	0x8C14: 0x8EFA,
	0x8C15: 0x896B,
	0x8C16: 0x896E,
	0x8C17: 0x8D59,
	0x8C18: 0x8966,
	0x8C19: 0x896C,
	0x8C1A: 0x8960,
	0x8C1B: 0x895F,
	0x8C1C: 0x8A65,
	0x8C1D: 0x8EFB,
	0x8C1E: 0xFFFD,
	0x8C1F: 0x8AFE,
	0x8C20: 0x8DA4,
	0x8C21: 0x8F64,
	0x8C22: 0x8A6B,
	0x8C23: 0x8A6A,
	0x8C24: 0x8A66,
	0x8C25: 0x8F66,
	0x8C26: 0x8A67,
	0x8C27: 0x8A6D,
	0x8C28: 0x8B40,
	0x8C29: 0x8FA1,
	0x8C2A: 0x8B42,
	0x8C2B: 0x9179,
	0x8C2C: 0x8B41,
	0x8C2D: 0x8BC0,
	0x8C2E: 0x8FC8,
	0x8C2F: 0x8BC3,
	0x8C30: 0x9078,
	0x8C31: 0x8BBE,
	0x8C32: 0x8BC1,
	0x8C33: 0x90A6,
	0x8C34: 0x8CA7,
	0x8C35: 0x8C58,
	0x8C36: 0x8D5A,
	0x8C37: 0xA8A6,
	0x8C38: 0xFFFD,
	0x8C39: 0xD7CD,
	0x8C3A: 0x917A,
	0x8C3B: 0xD7CE,
	0x8C3C: 0xE052,
	0x8C3D: 0xE450,
	0x8C3E: 0xE7E5,
	0x8C3F: 0xC1C6,
	0x8C40: 0xFFFD,
	0x8C41: 0xC1C5,
	0x8C42: 0xF0EE,
	0x8C43: 0xF344,
	0x8C44: 0xFFFD,
	0x8C45: 0xF844,
	0x8C46: 0xA8A7,
	0x8C47: 0xD3DE,
	0x8C48: 0xB05A,
	0x8C49: 0xB361,
	0x8C4A: 0xE054,
	0x8C4B: 0xE053,
	0x8C4C: 0xBDDC,
	0x8C4D: 0xE7E6,
	0x8C4E: 0xBDDD,
	0x8C4F: 0xEEB1,
	0x8C50: 0xC2D7,
	0x8C51: 0xFEE9,
	0x8C52: 0xFFFD,
	0x8C53: 0xFFFD,
	0x8C54: 0xC676,
	0x8C55: 0xA8A8,
	0x8C56: 0xCDCB,
	0x8C57: 0xD3DF,
	0x8C58: 0xFFFD,
	0x8C59: 0xFFFD,
	0x8C5A: 0xB362,
	0x8C5B: 0xFFFD,
	0x8C5C: 0xD7CF,
	0x8C5D: 0xD7D0,
	0x8C5E: 0xFFFD,
	0x8C5F: 0xDBE5,
	0x8C60: 0xFFFD,
	0x8C61: 0xB648,
	0x8C62: 0xB8E6,
	0x8C63: 0xFFFD,
	0x8C64: 0xE056,
	0x8C65: 0xE055,
	0x8C66: 0xE057,
	0x8C67: 0xFFFD,
	0x8C68: 0xE451,
	0x8C69: 0xE452,
	0x8C6A: 0xBBA8,
	0x8C6B: 0xBFDD,
	0x8C6C: 0xBDDE,
	0x8C6D: 0xBFDE,
	0x8C6E: 0xFFFD,
	0x8C6F: 0xEEB5,
	0x8C70: 0xEEB2,
	0x8C71: 0xEEB4,
	0x8C72: 0xEEB3,
	0x8C73: 0xC1C7,
	0x8C74: 0xFFFD,
	0x8C75: 0xF0EF,
	0x8C76: 0xF346,
	0x8C77: 0xF345,
	0x8C78: 0xCBA4,
	0x8C79: 0xB05C,
	0x8C7A: 0xB05B,
	0x8C7B: 0xD3E0,
	0x8C7C: 0x917B,
	0x8C7D: 0xD7D1,
	0x8C7E: 0xFFFD,
	0x8C7F: 0xFFFD,
	0x8C80: 0xDBE7,
	0x8C81: 0xDBE6,
	0x8C82: 0xB649,
	0x8C83: 0xFFFD,
	0x8C84: 0xE059,
	0x8C85: 0xE05A,
	0x8C86: 0xE058,
	0x8C87: 0xFFFD,
	0x8C88: 0xFFFD,
	0x8C89: 0xB8E8,
	0x8C8A: 0xB8E7,
	0x8C8B: 0xFFFD,
	0x8C8C: 0xBBAA,
	0x8C8D: 0xBBA9,
	0x8C8E: 0x917C,
	0x8C8F: 0xE7E7,
	0x8C90: 0xEBB3,
	0x8C91: 0xEBB1,
	0x8C92: 0xEBB2,
	0x8C93: 0xBFDF,
	0x8C94: 0xEEB7,
	0x8C95: 0xEEB6,
	0x8C96: 0xFFFD,
	0x8C97: 0xF0F2,
	0x8C98: 0xF0F1,
	0x8C99: 0xF0F0,
	0x8C9A: 0xF347,
	0x8C9B: 0xFEEA,
	0x8C9C: 0xF9AA,
	0x8C9D: 0xA8A9,
	0x8C9E: 0xAD73,
	0x8C9F: 0xFEEB,
	0x8CA0: 0xAD74,
	0x8CA1: 0xB05D,
	0x8CA2: 0xB05E,
	0x8CA3: 0xD3E2,
	0x8CA4: 0xD3E1,
	0x8CA5: 0xD7D2,
	0x8CA6: 0xFFFD,
	0x8CA7: 0xB368,
	0x8CA8: 0xB366,
	0x8CA9: 0xB363,
	0x8CAA: 0xB367,
	0x8CAB: 0xB365,
	0x8CAC: 0xB364,
	0x8CAD: 0xFD79,
	0x8CAE: 0x917D,
	0x8CAF: 0xB64A,
	0x8CB0: 0xDBEA,
	0x8CB1: 0xFFFD,
	0x8CB2: 0xB8ED,
	0x8CB3: 0xB64C,
	0x8CB4: 0xB651,
	0x8CB5: 0xDBEC,
	0x8CB6: 0xB653,
	0x8CB7: 0xB652,
	0x8CB8: 0xB655,
	0x8CB9: 0xDBEB,
	0x8CBA: 0xDBE8,
	0x8CBB: 0xB64F,
	0x8CBC: 0xB64B,
	0x8CBD: 0xB64D,
	0x8CBE: 0xDBE9,
	0x8CBF: 0xB654,
	0x8CC0: 0xB650,
	0x8CC1: 0xB64E,
	0x8CC2: 0xB8EF,
	0x8CC3: 0xB8EE,
	0x8CC4: 0xB8EC,
	0x8CC5: 0xB8F0,
	0x8CC6: 0xFFFD,
	0x8CC7: 0xB8EA,
	0x8CC8: 0xB8EB,
	0x8CC9: 0xFFFD,
	0x8CCA: 0xB8E9,
	0x8CCB: 0xFFFD,
	0x8CCC: 0xE05B,
	0x8CCD: 0x9560,
	0x8CCE: 0x8262,
	0x8CCF: 0xE454,
	0x8CD0: 0xFFFD,
	0x8CD1: 0xBBAC,
	0x8CD2: 0xBBAD,
	0x8CD3: 0xBBAB,
	0x8CD4: 0xFEEC,
	0x8CD5: 0xE453,
	0x8CD6: 0xFEED,
	0x8CD7: 0xE455,
	0x8CD8: 0xFFFD,
	0x8CD9: 0xE7EA,
	0x8CDA: 0xE7EC,
	0x8CDB: 0x92CE,
	0x8CDC: 0xBDE7,
	0x8CDD: 0xE7ED,
	0x8CDE: 0xBDE0,
	0x8CDF: 0xE7E9,
	0x8CE0: 0xBDDF,
	0x8CE1: 0xBDE9,
	0x8CE2: 0xBDE5,
	0x8CE3: 0xBDE6,
	0x8CE4: 0xBDE2,
	0x8CE5: 0xE7E8,
	0x8CE6: 0xBDE1,
	0x8CE7: 0xE7EE,
	0x8CE8: 0xE7EB,
	0x8CE9: 0x9E40,
	0x8CEA: 0xBDE8,
	0x8CEB: 0xFD7A,
	0x8CEC: 0xBDE3,
	0x8CED: 0xBDE4,
	0x8CEE: 0xEBB5,
	0x8CEF: 0xFFFD,
	0x8CF0: 0xEBB7,
	0x8CF1: 0xEBB6,
	0x8CF2: 0x9E41,
	0x8CF3: 0xEBB8,
	0x8CF4: 0xBFE0,
	0x8CF5: 0xEBB4,
	0x8CF6: 0xFFFD,
	0x8CF7: 0xFD7B,
	0x8CF8: 0xC1CB,
	0x8CF9: 0xEEB8,
	0x8CFA: 0xC1C8,
	0x8CFB: 0xC1CC,
	0x8CFC: 0xC1CA,
	0x8CFD: 0xC1C9,
	0x8CFE: 0xF0F3,
	0x8CFF: 0xFFFD,
	0x8D00: 0xF0F6,
	0x8D01: 0xFFFD,
	0x8D02: 0xF0F5,
	0x8D03: 0x9E42,
	0x8D04: 0xF0F4,
	0x8D05: 0xC2D8,
	0x8D06: 0xF348,
	0x8D07: 0xF349,
	0x8D08: 0xC3D8,
	0x8D09: 0xF34A,
	0x8D0A: 0xC3D9,
	0x8D0B: 0x8257,
	0x8D0C: 0xFD7C,
	0x8D0D: 0xC4BA,
	0x8D0E: 0xFFFD,
	0x8D0F: 0xC4B9,
	0x8D10: 0xF652,
	0x8D11: 0x9E43,
	0x8D12: 0x917E,
	0x8D13: 0xC542,
	0x8D14: 0xF653,
	0x8D15: 0xF75C,
	0x8D16: 0xC5AB,
	0x8D17: 0xC5AC,
	0x8D18: 0x9576,
	0x8D19: 0xF845,
	0x8D1A: 0xFFFD,
	0x8D1B: 0xC642,
	0x8D1C: 0x9E44,
	0x8D1D: 0x8350,
	0x8D1E: 0x837C,
	0x8D1F: 0x837D,
	0x8D20: 0xFFFD,
	0x8D21: 0x83DD,
	0x8D22: 0x83DC,
	0x8D23: 0x84AA,
	0x8D24: 0x886E,
	0x8D25: 0x8450,
	0x8D26: 0x886C,
	0x8D27: 0x84AC,
	0x8D28: 0x8871,
	0x8D29: 0x84A9,
	0x8D2A: 0x84AD,
	0x8D2B: 0x84AE,
	0x8D2C: 0x8568,
	0x8D2D: 0x8A70,
	0x8D2E: 0x855F,
	0x8D2F: 0x84AB,
	0x8D30: 0x8561,
	0x8D31: 0x886B,
	0x8D32: 0x8563,
	0x8D33: 0x8DEB,
	0x8D34: 0x8560,
	0x8D35: 0x8566,
	0x8D36: 0x8DEA,
	0x8D37: 0x856A,
	0x8D38: 0x8569,
	0x8D39: 0x8564,
	0x8D3A: 0x8565,
	0x8D3B: 0x8562,
	0x8D3C: 0x8655,
	0x8D3D: 0x8FA3,
	0x8D3E: 0x8657,
	0x8D3F: 0x8658,
	0x8D40: 0x8659,
	0x8D41: 0x865A,
	0x8D42: 0x865B,
	0x8D43: 0x8CAA,
	0x8D44: 0x8656,
	0x8D45: 0x865C,
	0x8D46: 0x9047,
	0x8D47: 0x8EA2,
	0x8D48: 0x875A,
	0x8D49: 0x91A1,
	0x8D4A: 0x875B,
	0x8D4B: 0x886A,
	0x8D4C: 0x886D,
	0x8D4D: 0x91A2,
	0x8D4E: 0x8CDE,
	0x8D4F: 0x8869,
	0x8D50: 0x8870,
	0x8D51: 0xFFFD,
	0x8D52: 0xFFFD,
	0x8D53: 0x8872,
	0x8D54: 0x8868,
	0x8D55: 0x8ECE,
	0x8D56: 0x896F,
	0x8D57: 0xFFFD,
	0x8D58: 0x8B43,
	0x8D59: 0x8A71,
	0x8D5A: 0x8A6E,
	0x8D5B: 0x8A6F,
	0x8D5C: 0x8FA2,
	0x8D5D: 0x8CDF,
	0x8D5E: 0x8BC5,
	0x8D5F: 0xFFFD,
	0x8D60: 0x8BC4,
	0x8D61: 0x8C5A,
	0x8D62: 0x8C59,
	0x8D63: 0x8D5C,
	0x8D64: 0xA8AA,
	0x8D65: 0xFFFD,
	0x8D66: 0xB36A,
	0x8D67: 0xB369,
	0x8D68: 0xE05C,
	0x8D69: 0xE05D,
	0x8D6A: 0xFFFD,
	0x8D6B: 0xBBAE,
	0x8D6C: 0xEBB9,
	0x8D6D: 0xBDEA,
	0x8D6E: 0xEBBA,
	0x8D6F: 0xEEB9,
	0x8D70: 0xA8AB,
	0x8D71: 0x91A3,
	0x8D72: 0xD0B2,
	0x8D73: 0xAD76,
	0x8D74: 0xAD75,
	0x8D75: 0x875C,
	0x8D76: 0xD3E3,
	0x8D77: 0xB05F,
	0x8D78: 0xD3E4,
	0x8D79: 0xD7D5,
	0x8D7A: 0x9E45,
	0x8D7B: 0xD7D4,
	0x8D7C: 0xFFFD,
	0x8D7D: 0xD7D3,
	0x8D7E: 0xFFFD,
	0x8D7F: 0xFFFD,
	0x8D80: 0xDBEE,
	0x8D81: 0xB658,
	0x8D82: 0xFD7D,
	0x8D83: 0xFFFD,
	0x8D84: 0xDBED,
	0x8D85: 0xB657,
	0x8D86: 0xFFFD,
	0x8D87: 0xFFFD,
	0x8D88: 0xFFFD,
	0x8D89: 0xDBEF,
	0x8D8A: 0xB656,
	0x8D8B: 0x8A72,
	0x8D8C: 0xE05F,
	0x8D8D: 0xE062,
	0x8D8E: 0xE060,
	0x8D8F: 0xE061,
	0x8D90: 0xE065,
	0x8D91: 0xE05E,
	0x8D92: 0xE066,
	0x8D93: 0xE063,
	0x8D94: 0xE064,
	0x8D95: 0xBBB0,
	0x8D96: 0xE456,
	0x8D97: 0xFFFD,
	0x8D98: 0xFFFD,
	0x8D99: 0xBBAF,
	0x8D9A: 0xFFFD,
	0x8D9B: 0xE7F2,
	0x8D9C: 0xE7F0,
	0x8D9D: 0xFFFD,
	0x8D9E: 0xFFFD,
	0x8D9F: 0xBDEB,
	0x8DA0: 0xE7EF,
	0x8DA1: 0xE7F1,
	0x8DA2: 0xFFFD,
	0x8DA3: 0xBDEC,
	0x8DA4: 0xFFFD,
	0x8DA5: 0xEBBB,
	0x8DA6: 0xFD7E,
	0x8DA7: 0xEBBC,
	0x8DA8: 0xC1CD,
	0x8DA9: 0x9E46,
	0x8DAA: 0xF34C,
	0x8DAB: 0xF34E,
	0x8DAC: 0xF34B,
	0x8DAD: 0xF34D,
	0x8DAE: 0xF4D6,
	0x8DAF: 0xF654,
	0x8DB0: 0xFFFD,
	0x8DB1: 0x90A3,
	0x8DB2: 0xF96F,
	0x8DB3: 0xA8AC,
	0x8DB4: 0xAD77,
	0x8DB5: 0xD3E5,
	0x8DB6: 0xD3E7,
	0x8DB7: 0xD3E6,
	0x8DB8: 0x8C5B,
	0x8DB9: 0xD7D8,
	0x8DBA: 0xB36C,
	0x8DBB: 0xFFFD,
	0x8DBC: 0xD7D6,
	0x8DBD: 0xFFFD,
	0x8DBE: 0xB36B,
	0x8DBF: 0xD7D9,
	0x8DC0: 0x9E47,
	0x8DC1: 0xD7DA,
	0x8DC2: 0xD7D7,
	0x8DC3: 0x8CAC,
	0x8DC4: 0x8F67,
	0x8DC5: 0xDBFB,
	0x8DC6: 0xB660,
	0x8DC7: 0xDBF3,
	0x8DC8: 0xDBF9,
	0x8DC9: 0xFFFD,
	0x8DCA: 0xFFFD,
	0x8DCB: 0xB65B,
	0x8DCC: 0xB65E,
	0x8DCD: 0xDBF2,
	0x8DCE: 0xB659,
	0x8DCF: 0xDBF6,
	0x8DD0: 0xE06C,
	0x8DD1: 0xB65D,
	0x8DD2: 0xFFFD,
	0x8DD3: 0xDBF1,
	0x8DD4: 0xFDA1,
	0x8DD5: 0xDBF7,
	0x8DD6: 0xDBF4,
	0x8DD7: 0xDBFA,
	0x8DD8: 0xDBF0,
	0x8DD9: 0xDBF8,
	0x8DDA: 0xB65C,
	0x8DDB: 0xB65F,
	0x8DDC: 0xDBF5,
	0x8DDD: 0xB65A,
	0x8DDE: 0x905E,
	0x8DDF: 0xB8F2,
	0x8DE0: 0xE068,
	0x8DE1: 0xB8F1,
	0x8DE2: 0xE06F,
	0x8DE3: 0xE06E,
	0x8DE4: 0xB8F8,
	0x8DE5: 0xFFFD,
	0x8DE6: 0xB8F9,
	0x8DE7: 0xE070,
	0x8DE8: 0xB8F3,
	0x8DE9: 0xE06D,
	0x8DEA: 0xB8F7,
	0x8DEB: 0xE072,
	0x8DEC: 0xE069,
	0x8DED: 0xFFFD,
	0x8DEE: 0xE06B,
	0x8DEF: 0xB8F4,
	0x8DF0: 0xE067,
	0x8DF1: 0xE06A,
	0x8DF2: 0xE071,
	0x8DF3: 0xB8F5,
	0x8DF4: 0xE073,
	0x8DF5: 0x8873,
	0x8DF6: 0xFFFD,
	0x8DF7: 0x8BC6,
	0x8DF8: 0x8B46,
	0x8DF9: 0x905D,
	0x8DFA: 0xB8F6,
	0x8DFB: 0x8CAD,
	0x8DFC: 0xBBB1,
	0x8DFD: 0xE45B,
	0x8DFE: 0xE461,
	0x8DFF: 0xE459,
	0x8E00: 0xE462,
	0x8E01: 0x9E48,
	0x8E02: 0xE458,
	0x8E03: 0xE45D,
	0x8E04: 0xE463,
	0x8E05: 0xE460,
	0x8E06: 0xE45F,
	0x8E07: 0xE45E,
	0x8E08: 0x91A4,
	0x8E09: 0xE457,
	0x8E0A: 0xE45C,
	0x8E0B: 0xFFFD,
	0x8E0C: 0x8CAB,
	0x8E0D: 0xE45A,
	0x8E0E: 0x9E49,
	0x8E0F: 0xBDF1,
	0x8E10: 0xBDEE,
	0x8E11: 0xE7FB,
	0x8E12: 0xE841,
	0x8E13: 0xE843,
	0x8E14: 0xE840,
	0x8E15: 0xE7F8,
	0x8E16: 0xE7FA,
	0x8E17: 0xE845,
	0x8E18: 0xE842,
	0x8E19: 0xE7FC,
	0x8E1A: 0xE846,
	0x8E1B: 0xE7F9,
	0x8E1C: 0xE844,
	0x8E1D: 0xBDEF,
	0x8E1E: 0xBDF5,
	0x8E1F: 0xBDF3,
	0x8E20: 0xE7F3,
	0x8E21: 0xBDF4,
	0x8E22: 0xBDF0,
	0x8E23: 0xE7F4,
	0x8E24: 0xE7F6,
	0x8E25: 0xE7F5,
	0x8E26: 0xE7FD,
	0x8E27: 0xE7FE,
	0x8E28: 0xFDA2,
	0x8E29: 0xBDF2,
	0x8E2A: 0x9557,
	0x8E2B: 0xBDED,
	0x8E2C: 0x8CE1,
	0x8E2D: 0xFB6D,
	0x8E2E: 0xE7F7,
	0x8E2F: 0x8CE0,
	0x8E30: 0xEBC6,
	0x8E31: 0xBFE2,
	0x8E32: 0xFFFD,
	0x8E33: 0xEBBD,
	0x8E34: 0xBFE3,
	0x8E35: 0xBFE6,
	0x8E36: 0xEBC2,
	0x8E37: 0xFFFD,
	0x8E38: 0xEBBF,
	0x8E39: 0xBFE5,
	0x8E3A: 0x91A5,
	0x8E3B: 0xFFFD,
	0x8E3C: 0xEBC3,
	0x8E3D: 0xEBC4,
	0x8E3E: 0xEBBE,
	0x8E3F: 0xEBC7,
	0x8E40: 0xEBC0,
	0x8E41: 0xEBC5,
	0x8E42: 0xBFE4,
	0x8E43: 0xFFFD,
	0x8E44: 0xBFE1,
	0x8E45: 0xEBC1,
	0x8E46: 0x9E4A,
	0x8E47: 0xEEBF,
	0x8E48: 0xC1D0,
	0x8E49: 0xC1CE,
	0x8E4A: 0xC1D1,
	0x8E4B: 0xC1CF,
	0x8E4C: 0xEEBE,
	0x8E4D: 0xEEBB,
	0x8E4E: 0xEEBA,
	0x8E4F: 0xFDA3,
	0x8E50: 0xEEBD,
	0x8E51: 0x8D74,
	0x8E52: 0x8B44,
	0x8E53: 0xEEBC,
	0x8E54: 0xF145,
	0x8E55: 0xC2DE,
	0x8E56: 0xF0FB,
	0x8E57: 0xF0FA,
	0x8E58: 0xFFFD,
	0x8E59: 0xC2D9,
	0x8E5A: 0xF141,
	0x8E5B: 0xF140,
	0x8E5C: 0xF0F7,
	0x8E5D: 0xF143,
	0x8E5E: 0xF0FC,
	0x8E5F: 0xC2DD,
	0x8E60: 0xF0F9,
	0x8E61: 0xF142,
	0x8E62: 0xF0F8,
	0x8E63: 0xC2DA,
	0x8E64: 0xC2DC,
	0x8E65: 0xF0FD,
	0x8E66: 0xC2DB,
	0x8E67: 0xF0FE,
	0x8E68: 0x9E4B,
	0x8E69: 0xF144,
	0x8E6A: 0xF352,
	0x8E6B: 0xFFFD,
	0x8E6C: 0xC3DE,
	0x8E6D: 0xF34F,
	0x8E6E: 0xFFFD,
	0x8E6F: 0xF353,
	0x8E70: 0x91A6,
	0x8E71: 0x9E4C,
	0x8E72: 0xC3DB,
	0x8E73: 0xF351,
	0x8E74: 0xC3E0,
	0x8E75: 0xFDA5,
	0x8E76: 0xC3DD,
	0x8E77: 0xFDA4,
	0x8E78: 0xF350,
	0x8E79: 0xFFFD,
	0x8E7A: 0xC3DF,
	0x8E7B: 0xF354,
	0x8E7C: 0xC3DA,
	0x8E7D: 0xFFFD,
	0x8E7E: 0x9E4D,
	0x8E7F: 0x907E,
	0x8E80: 0x9E4E,
	0x8E81: 0xC4BC,
	0x8E82: 0xC4BE,
	0x8E83: 0xFFFD,
	0x8E84: 0xF4D9,
	0x8E85: 0xC4BD,
	0x8E86: 0xF4D7,
	0x8E87: 0xC3DC,
	0x8E88: 0xF4D8,
	0x8E89: 0xC4BB,
	0x8E8A: 0xC543,
	0x8E8B: 0xC545,
	0x8E8C: 0xF656,
	0x8E8D: 0xC544,
	0x8E8E: 0xF655,
	0x8E8F: 0x8DA5,
	0x8E90: 0xF761,
	0x8E91: 0xC5AD,
	0x8E92: 0xF760,
	0x8E93: 0xC5AE,
	0x8E94: 0xF75E,
	0x8E95: 0xF75D,
	0x8E96: 0xF762,
	0x8E97: 0xF763,
	0x8E98: 0xF846,
	0x8E99: 0x91A7,
	0x8E9A: 0xF75F,
	0x8E9B: 0xFFFD,
	0x8E9C: 0x90A4,
	0x8E9D: 0xF8C6,
	0x8E9E: 0xF8C3,
	0x8E9F: 0xF8C4,
	0x8EA0: 0xF8C5,
	0x8EA1: 0xC65C,
	0x8EA2: 0xFFFD,
	0x8EA3: 0xF951,
	0x8EA4: 0xF950,
	0x8EA5: 0xF94F,
	0x8EA6: 0xF970,
	0x8EA7: 0xFDA6,
	0x8EA8: 0xF9BE,
	0x8EA9: 0xF9AB,
	0x8EAA: 0xC66E,
	0x8EAB: 0xA8AD,
	0x8EAC: 0xB060,
	0x8EAD: 0x95DF,
	0x8EAE: 0xFFFD,
	0x8EAF: 0x8249,
	0x8EB0: 0x91A8,
	0x8EB1: 0x91A9,
	0x8EB2: 0xB8FA,
	0x8EB3: 0xFFFD,
	0x8EB4: 0xFFFD,
	0x8EB5: 0xFFFD,
	0x8EB6: 0x9E4F,
	0x8EB7: 0xFFFD,
	0x8EB8: 0xFFFD,
	0x8EB9: 0x9E50,
	0x8EBA: 0xBDF6,
	0x8EBB: 0xFFFD,
	0x8EBC: 0x9E51,
	0x8EBD: 0xEBC8,
	0x8EBE: 0x94D3,
	0x8EBF: 0xFFFD,
	0x8EC0: 0xC2DF,
	0x8EC1: 0xFFFD,
	0x8EC2: 0xF355,
	0x8EC3: 0x9E52,
	0x8EC4: 0xFFFD,
	0x8EC5: 0x91AA,
	0x8EC6: 0x91AB,
	0x8EC7: 0xFFFD,
	0x8EC8: 0x94D4,
	0x8EC9: 0xF9AC,
	0x8ECA: 0xA8AE,
	0x8ECB: 0xAAEE,
	0x8ECC: 0xAD79,
	0x8ECD: 0xAD78,
	0x8ECE: 0x91AC,
	0x8ECF: 0xB063,
	0x8ED0: 0xFFFD,
	0x8ED1: 0xD3E8,
	0x8ED2: 0xB061,
	0x8ED3: 0xD3E9,
	0x8ED4: 0xB062,
	0x8ED5: 0xFFFD,
	0x8ED6: 0xFFFD,
	0x8ED7: 0xD7DF,
	0x8ED8: 0xD7DB,
	0x8ED9: 0xFFFD,
	0x8EDA: 0xFBA1,
	0x8EDB: 0xB36D,
	0x8EDC: 0xD7DE,
	0x8EDD: 0xD7DD,
	0x8EDE: 0xD7DC,
	0x8EDF: 0xB36E,
	0x8EE0: 0xD7E0,
	0x8EE1: 0xD7E1,
	0x8EE2: 0x937D,
	0x8EE3: 0x91AD,
	0x8EE4: 0x9E53,
	0x8EE5: 0xDC43,
	0x8EE6: 0xDC41,
	0x8EE7: 0xDC45,
	0x8EE8: 0xDC46,
	0x8EE9: 0xDC4C,
	0x8EEA: 0xFFFD,
	0x8EEB: 0xDC48,
	0x8EEC: 0xDC4A,
	0x8EED: 0x9E54,
	0x8EEE: 0xDC42,
	0x8EEF: 0xDBFC,
	0x8EF0: 0xFFFD,
	0x8EF1: 0xDC49,
	0x8EF2: 0x9E55,
	0x8EF3: 0xFFFD,
	0x8EF4: 0xDC4B,
	0x8EF5: 0xDC44,
	0x8EF6: 0xDC47,
	0x8EF7: 0xDBFD,
	0x8EF8: 0xB662,
	0x8EF9: 0xDC40,
	0x8EFA: 0xDBFE,
	0x8EFB: 0xB661,
	0x8EFC: 0xB663,
	0x8EFD: 0x92AD,
	0x8EFE: 0xB8FD,
	0x8EFF: 0xE075,
	0x8F00: 0xE077,
	0x8F01: 0xE076,
	0x8F02: 0xE07B,
	0x8F03: 0xB8FB,
	0x8F04: 0xFFFD,
	0x8F05: 0xE078,
	0x8F06: 0xE074,
	0x8F07: 0xE079,
	0x8F08: 0xE07A,
	0x8F09: 0xB8FC,
	0x8F0A: 0xB8FE,
	0x8F0B: 0xE07C,
	0x8F0C: 0x91AE,
	0x8F0D: 0xE467,
	0x8F0E: 0xE466,
	0x8F0F: 0xFFFD,
	0x8F10: 0xE464,
	0x8F11: 0xE465,
	0x8F12: 0xBBB3,
	0x8F13: 0xBBB5,
	0x8F14: 0xBBB2,
	0x8F15: 0xBBB4,
	0x8F16: 0xE84D,
	0x8F17: 0xE84E,
	0x8F18: 0xE849,
	0x8F19: 0xFDA7,
	0x8F1A: 0xE84A,
	0x8F1B: 0xBDF8,
	0x8F1C: 0xBDFD,
	0x8F1D: 0xBDF7,
	0x8F1E: 0xBDFE,
	0x8F1F: 0xBDF9,
	0x8F20: 0xE84B,
	0x8F21: 0xFFFD,
	0x8F22: 0xFFFD,
	0x8F23: 0xE84C,
	0x8F24: 0xE848,
	0x8F25: 0xBE40,
	0x8F26: 0xBDFB,
	0x8F27: 0xFFFD,
	0x8F28: 0xFFFD,
	0x8F29: 0xBDFA,
	0x8F2A: 0xBDFC,
	0x8F2B: 0xFFFD,
	0x8F2C: 0xE847,
	0x8F2D: 0x9570,
	0x8F2E: 0xEBCA,
	0x8F2F: 0xBFE8,
	0x8F30: 0x9E56,
	0x8F31: 0xFFFD,
	0x8F32: 0xEBCC,
	0x8F33: 0xBFEA,
	0x8F34: 0xEBCF,
	0x8F35: 0xEBCB,
	0x8F36: 0xEBC9,
	0x8F37: 0xEBCE,
	0x8F38: 0xBFE9,
	0x8F39: 0xEBCD,
	0x8F3A: 0xFFFD,
	0x8F3B: 0xBFE7,
	0x8F3C: 0xFFFD,
	0x8F3D: 0xFFFD,
	0x8F3E: 0xC1D3,
	0x8F3F: 0xC1D6,
	0x8F40: 0xEEC1,
	0x8F41: 0x9E57,
	0x8F42: 0xC1D4,
	0x8F43: 0xEEC0,
	0x8F44: 0xC1D2,
	0x8F45: 0xC1D5,
	0x8F46: 0xF146,
	0x8F47: 0xF147,
	0x8F48: 0xF148,
	0x8F49: 0xC2E0,
	0x8F4A: 0x9E58,
	0x8F4B: 0xF149,
	0x8F4C: 0x94D5,
	0x8F4D: 0xC2E1,
	0x8F4E: 0xC3E2,
	0x8F4F: 0xF358,
	0x8F50: 0xF359,
	0x8F51: 0xF357,
	0x8F52: 0xF356,
	0x8F53: 0xF35A,
	0x8F54: 0xC3E1,
	0x8F55: 0xF4DD,
	0x8F56: 0xF4DB,
	0x8F57: 0xF4DC,
	0x8F58: 0xF4DE,
	0x8F59: 0xF4DA,
	0x8F5A: 0xF4DF,
	0x8F5B: 0xF658,
	0x8F5C: 0xFDA9,
	0x8F5D: 0xF659,
	0x8F5E: 0xF657,
	0x8F5F: 0xC546,
	0x8F60: 0xF764,
	0x8F61: 0xC5AF,
	0x8F62: 0xF765,
	0x8F63: 0xF848,
	0x8F64: 0xF847,
	0x8F65: 0xFFFD,
	0x8F66: 0x8351,
	0x8F67: 0x8361,
	0x8F68: 0x83A1,
	0x8F69: 0x83DE,
	0x8F6A: 0xFFFD,
	0x8F6B: 0x83DF,
	0x8F6C: 0x8B48,
	0x8F6D: 0x84AF,
	0x8F6E: 0x8879,
	0x8F6F: 0x84B0,
	0x8F70: 0x8CAE,
	0x8F71: 0x91AF,
	0x8F72: 0x856B,
	0x8F73: 0x906E,
	0x8F74: 0x856C,
	0x8F75: 0x8DED,
	0x8F76: 0x856D,
	0x8F77: 0x91B0,
	0x8F78: 0x8DEE,
	0x8F79: 0x905F,
	0x8F7A: 0x8DEC,
	0x8F7B: 0x8760,
	0x8F7C: 0x865F,
	0x8F7D: 0x865E,
	0x8F7E: 0x8660,
	0x8F7F: 0x8BC8,
	0x8F80: 0xFFFD,
	0x8F81: 0x8E56,
	0x8F82: 0x8E55,
	0x8F83: 0x865D,
	0x8F84: 0x875F,
	0x8F85: 0x875E,
	0x8F86: 0x8875,
	0x8F87: 0x8878,
	0x8F88: 0x8877,
	0x8F89: 0x8874,
	0x8F8A: 0x887C,
	0x8F8B: 0x887B,
	0x8F8C: 0xFFFD,
	0x8F8D: 0x8876,
	0x8F8E: 0x887A,
	0x8F8F: 0x8973,
	0x8F90: 0x8970,
	0x8F91: 0x8971,
	0x8F92: 0xFFFD,
	0x8F93: 0x8972,
	0x8F94: 0x8CE2,
	0x8F95: 0x8A76,
	0x8F96: 0x8A73,
	0x8F97: 0x8A74,
	0x8F98: 0x8FA4,
	0x8F99: 0x8B49,
	0x8F9A: 0x8BC7,
	0x8F9B: 0xA8AF,
	0x8F9C: 0xB664,
	0x8F9D: 0xFFFD,
	0x8F9E: 0x8BC9,
	0x8F9F: 0xB940,
	0x8FA0: 0xFD41,
	0x8FA1: 0xFFFD,
	0x8FA2: 0xFFFD,
	0x8FA3: 0xBBB6,
	0x8FA4: 0xFFFD,
	0x8FA5: 0x9E59,
	0x8FA6: 0xBFEC,
	0x8FA7: 0x91B1,
	0x8FA8: 0xBFEB,
	0x8FA9: 0x8CAF,
	0x8FAA: 0xFFFD,
	0x8FAB: 0x8C47,
	0x8FAC: 0xFFFD,
	0x8FAD: 0xC3E3,
	0x8FAE: 0xC47C,
	0x8FAF: 0xC547,
	0x8FB0: 0xA8B0,
	0x8FB1: 0xB064,
	0x8FB2: 0xB941,
	0x8FB3: 0x9E5A,
	0x8FB4: 0xF35B,
	0x8FB5: 0xC6D6,
	0x8FB6: 0x9CE0,
	0x8FB7: 0x94D6,
	0x8FB8: 0x9E5B,
	0x8FB9: 0x8BCA,
	0x8FBA: 0x93C3,
	0x8FBB: 0x944E,
	0x8FBC: 0x9444,
	0x8FBD: 0x8977,
	0x8FBE: 0x8663,
	0x8FBF: 0xCBA6,
	0x8FC0: 0xFFFD,
	0x8FC1: 0x887E,
	0x8FC2: 0xA8B1,
	0x8FC3: 0xFFFD,
	0x8FC4: 0xA8B4,
	0x8FC5: 0xA8B3,
	0x8FC6: 0xA8B2,
	0x8FC7: 0x8665,
	0x8FC8: 0x8A79,
	0x8FC9: 0xCBA5,
	0x8FCA: 0x9E5C,
	0x8FCB: 0xCDCD,
	0x8FCC: 0xA0A4,
	0x8FCD: 0xCDCF,
	0x8FCE: 0xAAEF,
	0x8FCF: 0x9E5D,
	0x8FD0: 0x8662,
	0x8FD1: 0xAAF1,
	0x8FD2: 0xCDCC,
	0x8FD3: 0xCDCE,
	0x8FD4: 0xAAF0,
	0x8FD5: 0xCDD1,
	0x8FD6: 0xCDD0,
	0x8FD7: 0xCDD2,
	0x8FD8: 0x8A78,
	0x8FD9: 0x84B1,
	0x8FDA: 0x94D7,
	0x8FDB: 0x856E,
	0x8FDC: 0x8761,
	0x8FDD: 0x8664,
	0x8FDE: 0x84B2,
	0x8FDF: 0x8976,
	0x8FE0: 0xD0B6,
	0x8FE1: 0xD0B4,
	0x8FE2: 0xAD7C,
	0x8FE3: 0xD0B3,
	0x8FE4: 0xADA3,
	0x8FE5: 0xAD7E,
	0x8FE6: 0xAD7B,
	0x8FE7: 0xFFFD,
	0x8FE8: 0xADA4,
	0x8FE9: 0x8B4A,
	0x8FEA: 0xAD7D,
	0x8FEB: 0xADA2,
	0x8FEC: 0xFFFD,
	0x8FED: 0xADA1,
	0x8FEE: 0xD0B5,
	0x8FEF: 0x91B2,
	0x8FF0: 0xAD7A,
	0x8FF1: 0xFFFD,
	0x8FF2: 0xFFFD,
	0x8FF3: 0x84B3,
	0x8FF4: 0xB06A,
	0x8FF5: 0xD3EB,
	0x8FF6: 0xD3F1,
	0x8FF7: 0xB067,
	0x8FF8: 0xB06E,
	0x8FF9: 0x95D9,
	0x8FFA: 0xB069,
	0x8FFB: 0xD3EE,
	0x8FFC: 0xD3F0,
	0x8FFD: 0xB06C,
	0x8FFE: 0xD3EA,
	0x8FFF: 0xD3ED,
	0x9000: 0xB068,
	0x9001: 0xB065,
	0x9002: 0xD3EC,
	0x9003: 0xB06B,
	0x9004: 0xD3EF,
	0x9005: 0xB06D,
	0x9006: 0xB066,
	0x9007: 0xFFFD,
	0x9008: 0x9E5E,
	0x9009: 0x8975,
	0x900A: 0x8762,
	0x900B: 0xD7E3,
	0x900C: 0xD7E6,
	0x900D: 0xB370,
	0x900E: 0x91B3,
	0x900F: 0xB37A,
	0x9010: 0xB376,
	0x9011: 0xD7E4,
	0x9012: 0x8763,
	0x9013: 0x937A,
	0x9014: 0xB37E,
	0x9015: 0xB377,
	0x9016: 0xB37C,
	0x9017: 0xB372,
	0x9018: 0xFFFD,
	0x9019: 0xB36F,
	0x901A: 0xB371,
	0x901B: 0xB37D,
	0x901C: 0xD7E5,
	0x901D: 0xB375,
	0x901E: 0xB378,
	0x901F: 0xB374,
	0x9020: 0xB379,
	0x9021: 0xD7E7,
	0x9022: 0xB37B,
	0x9023: 0xB373,
	0x9024: 0xD7E2,
	0x9025: 0xFFFD,
	0x9026: 0x8D41,
	0x9027: 0x94D8,
	0x9028: 0xFFFD,
	0x9029: 0xFFFD,
	0x902A: 0xFFFD,
	0x902B: 0xFFFD,
	0x902C: 0xFFFD,
	0x902D: 0xDC4D,
	0x902E: 0xB665,
	0x902F: 0xDC4F,
	0x9030: 0xFFFD,
	0x9031: 0xB667,
	0x9032: 0xB669,
	0x9033: 0x9E5F,
	0x9034: 0xDC4E,
	0x9035: 0xB666,
	0x9036: 0xB66A,
	0x9037: 0x9E60,
	0x9038: 0xB668,
	0x9039: 0x91B4,
	0x903A: 0xFFFD,
	0x903B: 0x8D42,
	0x903C: 0xB947,
	0x903D: 0xE0A3,
	0x903E: 0xB94F,
	0x903F: 0xE07E,
	0x9040: 0xFFFD,
	0x9041: 0xB950,
	0x9042: 0xB945,
	0x9043: 0xFFFD,
	0x9044: 0xE0A1,
	0x9045: 0x9372,
	0x9046: 0xFFFD,
	0x9047: 0xB94A,
	0x9048: 0xFFFD,
	0x9049: 0xE0A2,
	0x904A: 0xB943,
	0x904B: 0xB942,
	0x904C: 0xFDB6,
	0x904D: 0xB94D,
	0x904E: 0xB94C,
	0x904F: 0xB94B,
	0x9050: 0xB949,
	0x9051: 0xB94E,
	0x9052: 0xE07D,
	0x9053: 0xB944,
	0x9054: 0xB946,
	0x9055: 0xB948,
	0x9056: 0xFDB5,
	0x9057: 0x8978,
	0x9058: 0xBBB8,
	0x9059: 0xBBBB,
	0x905A: 0xFFFD,
	0x905B: 0xBBBF,
	0x905C: 0xBBB9,
	0x905D: 0xBBBE,
	0x905E: 0xBBBC,
	0x905F: 0xFFFD,
	0x9060: 0xBBB7,
	0x9061: 0xFE61,
	0x9062: 0xBBBD,
	0x9063: 0xBBBA,
	0x9064: 0x9E61,
	0x9065: 0x91B5,
	0x9066: 0xFFFD,
	0x9067: 0xE852,
	0x9068: 0xBE43,
	0x9069: 0xBE41,
	0x906A: 0xFFFD,
	0x906B: 0xE853,
	0x906C: 0x9E62,
	0x906D: 0xBE44,
	0x906E: 0xBE42,
	0x906F: 0xE851,
	0x9070: 0xE850,
	0x9071: 0xFFFD,
	0x9072: 0xBFF0,
	0x9073: 0xE84F,
	0x9074: 0xBFEE,
	0x9075: 0xBFED,
	0x9076: 0xEBD0,
	0x9077: 0xBE45,
	0x9078: 0xBFEF,
	0x9079: 0xEBD1,
	0x907A: 0xBFF2,
	0x907B: 0xEBD2,
	0x907C: 0xBFF1,
	0x907D: 0xC1D8,
	0x907E: 0xEEC3,
	0x907F: 0xC1D7,
	0x9080: 0xC1DC,
	0x9081: 0xC1DA,
	0x9082: 0xC1DB,
	0x9083: 0xC2E3,
	0x9084: 0xC1D9,
	0x9085: 0xEEC2,
	0x9086: 0xEBD3,
	0x9087: 0xC2E2,
	0x9088: 0xC2E4,
	0x9089: 0x91B6,
	0x908A: 0xC3E4,
	0x908B: 0xC3E5,
	0x908C: 0xFFFD,
	0x908D: 0xF4E0,
	0x908E: 0xFFFD,
	0x908F: 0xC5DE,
	0x9090: 0xC5DD,
	0x9091: 0xA8B6,
	0x9092: 0xFFFD,
	0x9093: 0x88A3,
	0x9094: 0xCA55,
	0x9095: 0xB06F,
	0x9096: 0xFFFD,
	0x9097: 0xCA52,
	0x9098: 0xCA53,
	0x9099: 0xCA51,
	0x909A: 0xFFFD,
	0x909B: 0xCA54,
	0x909C: 0xFFFD,
	0x909D: 0x8FA5,
	0x909E: 0xCBAA,
	0x909F: 0xCBA7,
	0x90A0: 0xCBAC,
	0x90A1: 0xCBA8,
	0x90A2: 0xA8B7,
	0x90A3: 0xA8BA,
	0x90A4: 0xFFFD,
	0x90A5: 0xCBA9,
	0x90A6: 0xA8B9,
	0x90A7: 0xCBAB,
	0x90A8: 0x9540,
	0x90A9: 0xFFFD,
	0x90AA: 0xA8B8,
	0x90AB: 0xFFFD,
	0x90AC: 0x8E57,
	0x90AD: 0xFFFD,
	0x90AE: 0x856F,
	0x90AF: 0xCDD5,
	0x90B0: 0xCDD7,
	0x90B1: 0xAAF4,
	0x90B2: 0xCDD3,
	0x90B3: 0xCDD6,
	0x90B4: 0xCDD4,
	0x90B5: 0xAAF2,
	0x90B6: 0xAAF5,
	0x90B7: 0xFFFD,
	0x90B8: 0xAAF3,
	0x90B9: 0x8666,
	0x90BA: 0x8979,
	0x90BB: 0x88A1,
	0x90BC: 0xFFFD,
	0x90BD: 0xD0B8,
	0x90BE: 0xD0BC,
	0x90BF: 0xD0B9,
	0x90C0: 0xFFFD,
	0x90C1: 0xADA7,
	0x90C2: 0xFFFD,
	0x90C3: 0xADA8,
	0x90C4: 0xFDAB,
	0x90C5: 0xD0BB,
	0x90C6: 0xFFFD,
	0x90C7: 0xD0BD,
	0x90C8: 0xD0BF,
	0x90C9: 0xFFFD,
	0x90CA: 0xADA5,
	0x90CB: 0xD0BE,
	0x90CC: 0xFFFD,
	0x90CD: 0xFFFD,
	0x90CE: 0xADA6,
	0x90CF: 0x8DC6,
	0x90D0: 0x8EFC,
	0x90D1: 0x88A2,
	0x90D2: 0xFFFD,
	0x90D3: 0x8DF0,
	0x90D4: 0xD7EE,
	0x90D5: 0xD0BA,
	0x90D6: 0xD3F2,
	0x90D7: 0xD3FB,
	0x90D8: 0xD3F9,
	0x90D9: 0xD3F4,
	0x90DA: 0xD3F5,
	0x90DB: 0xD3FA,
	0x90DC: 0xD3FC,
	0x90DD: 0xB071,
	0x90DE: 0x91B7,
	0x90DF: 0xD3F7,
	0x90E0: 0xD3F3,
	0x90E1: 0xB070,
	0x90E2: 0xB072,
	0x90E3: 0xD3F6,
	0x90E4: 0xD3FD,
	0x90E5: 0xD3F8,
	0x90E6: 0x8CE3,
	0x90E7: 0x90BB,
	0x90E8: 0xB3A1,
	0x90E9: 0xD7F1,
	0x90EA: 0xD7E9,
	0x90EB: 0xD7EF,
	0x90EC: 0xD7F0,
	0x90ED: 0xB3A2,
	0x90EE: 0xFFFD,
	0x90EF: 0xD7E8,
	0x90F0: 0xD7EA,
	0x90F1: 0xD0B7,
	0x90F2: 0xD7EC,
	0x90F3: 0xD7ED,
	0x90F4: 0xD7EB,
	0x90F5: 0xB66C,
	0x90F6: 0xFFFD,
	0x90F7: 0x927B,
	0x90F8: 0x8ECF,
	0x90F9: 0xDC56,
	0x90FA: 0xEBD4,
	0x90FB: 0xDC57,
	0x90FC: 0xDC54,
	0x90FD: 0xB3A3,
	0x90FE: 0xB66E,
	0x90FF: 0xDC53,
	0x9100: 0xDC59,
	0x9101: 0xDC58,
	0x9102: 0xB66B,
	0x9103: 0xDC5C,
	0x9104: 0xDC52,
	0x9105: 0xDC5B,
	0x9106: 0xDC50,
	0x9107: 0xDC5A,
	0x9108: 0xDC55,
	0x9109: 0xB66D,
	0x910A: 0xFFFD,
	0x910B: 0xE0AA,
	0x910C: 0xFFFD,
	0x910D: 0xE0A5,
	0x910E: 0xE0AB,
	0x910F: 0xE0A6,
	0x9110: 0xE0A4,
	0x9111: 0xE0A7,
	0x9112: 0xB951,
	0x9113: 0xFFFD,
	0x9114: 0xE0A9,
	0x9115: 0x91B8,
	0x9116: 0xE0A8,
	0x9117: 0xB952,
	0x9118: 0xBBC1,
	0x9119: 0xBBC0,
	0x911A: 0xE46E,
	0x911B: 0xE471,
	0x911C: 0xE469,
	0x911D: 0xE46D,
	0x911E: 0xBBC2,
	0x911F: 0xE46C,
	0x9120: 0xE46A,
	0x9121: 0xE470,
	0x9122: 0xE46B,
	0x9123: 0xE468,
	0x9124: 0xE46F,
	0x9125: 0xFFFD,
	0x9126: 0xE859,
	0x9127: 0xBE48,
	0x9128: 0xF14A,
	0x9129: 0xE856,
	0x912A: 0xE857,
	0x912B: 0xE855,
	0x912C: 0xDC51,
	0x912D: 0xBE47,
	0x912E: 0xE85A,
	0x912F: 0xE854,
	0x9130: 0xBE46,
	0x9131: 0xBE49,
	0x9132: 0xE858,
	0x9133: 0xEBD5,
	0x9134: 0xBFF3,
	0x9135: 0xEBD6,
	0x9136: 0xEBD7,
	0x9137: 0xFFFD,
	0x9138: 0xEEC4,
	0x9139: 0xC1DD,
	0x913A: 0xF14B,
	0x913B: 0xF14C,
	0x913C: 0xFFFD,
	0x913D: 0xFFFD,
	0x913E: 0xF14D,
	0x913F: 0xF35D,
	0x9140: 0xF35C,
	0x9141: 0xF4E2,
	0x9142: 0xFFFD,
	0x9143: 0xF4E1,
	0x9144: 0xF65B,
	0x9145: 0xF65C,
	0x9146: 0xF65A,
	0x9147: 0xF766,
	0x9148: 0xC5B0,
	0x9149: 0xA8BB,
	0x914A: 0xADAA,
	0x914B: 0xADA9,
	0x914C: 0xB075,
	0x914D: 0xB074,
	0x914E: 0xD440,
	0x914F: 0xD441,
	0x9150: 0xD3FE,
	0x9151: 0xFDAC,
	0x9152: 0xB073,
	0x9153: 0xD7F5,
	0x9154: 0x92F8,
	0x9155: 0xD7F6,
	0x9156: 0xD7F2,
	0x9157: 0xB3A4,
	0x9158: 0xD7F3,
	0x9159: 0xFDAF,
	0x915A: 0xD7F4,
	0x915B: 0xFFFD,
	0x915C: 0xFDAE,
	0x915D: 0x8A7A,
	0x915E: 0x96A8,
	0x915F: 0xDC5F,
	0x9160: 0xDC61,
	0x9161: 0xDC5D,
	0x9162: 0xDC60,
	0x9163: 0xB66F,
	0x9164: 0xDC5E,
	0x9165: 0xB670,
	0x9166: 0xFFFD,
	0x9167: 0xFDB0,
	0x9168: 0xDD73,
	0x9169: 0xB955,
	0x916A: 0xB954,
	0x916B: 0xFFFD,
	0x916C: 0xB953,
	0x916D: 0xFFFD,
	0x916E: 0xE0AC,
	0x916F: 0xE0AD,
	0x9170: 0x96A9,
	0x9171: 0x8B4C,
	0x9172: 0xE473,
	0x9173: 0xE475,
	0x9174: 0xBBC6,
	0x9175: 0xBBC3,
	0x9176: 0x96A1,
	0x9177: 0xBBC5,
	0x9178: 0xBBC4,
	0x9179: 0xE474,
	0x917A: 0xE472,
	0x917B: 0xFFFD,
	0x917C: 0xFDB1,
	0x917D: 0x8DA6,
	0x917E: 0x90A5,
	0x917F: 0x8D5D,
	0x9180: 0xE861,
	0x9181: 0xE85E,
	0x9182: 0xE85F,
	0x9183: 0xBE4D,
	0x9184: 0xE860,
	0x9185: 0xE85B,
	0x9186: 0xE85C,
	0x9187: 0xBE4A,
	0x9188: 0xFFFD,
	0x9189: 0xBE4B,
	0x918A: 0xE85D,
	0x918B: 0xBE4C,
	0x918C: 0x96AA,
	0x918D: 0xEBDB,
	0x918E: 0xFDB2,
	0x918F: 0xEBDC,
	0x9190: 0xEBD9,
	0x9191: 0xEBDA,
	0x9192: 0xBFF4,
	0x9193: 0xEBD8,
	0x9194: 0xFFFD,
	0x9195: 0xFFFD,
	0x9196: 0xFFFD,
	0x9197: 0x8279,
	0x9198: 0xFFFD,
	0x9199: 0xEEC8,
	0x919A: 0xEEC5,
	0x919B: 0xEEC7,
	0x919C: 0xC1E0,
	0x919D: 0xEECB,
	0x919E: 0xC1DF,
	0x919F: 0xEEC9,
	0x91A0: 0xEECC,
	0x91A1: 0xEECA,
	0x91A2: 0xEEC6,
	0x91A3: 0xC1DE,
	0x91A4: 0x8266,
	0x91A5: 0xF14F,
	0x91A6: 0xFFFD,
	0x91A7: 0xF150,
	0x91A8: 0xF14E,
	0x91A9: 0x9E63,
	0x91AA: 0xF152,
	0x91AB: 0xC2E5,
	0x91AC: 0xC2E6,
	0x91AD: 0xF35F,
	0x91AE: 0xC3E7,
	0x91AF: 0xF151,
	0x91B0: 0xF35E,
	0x91B1: 0xC3E6,
	0x91B2: 0xF4E5,
	0x91B3: 0xF4E6,
	0x91B4: 0xC4BF,
	0x91B5: 0xF4E4,
	0x91B6: 0x9E64,
	0x91B7: 0xF4E3,
	0x91B8: 0x92F1,
	0x91B9: 0xF65D,
	0x91BA: 0xC548,
	0x91BB: 0xFDB3,
	0x91BC: 0xF849,
	0x91BD: 0xF8C8,
	0x91BE: 0xF8C7,
	0x91BF: 0xFFFD,
	0x91C0: 0xC643,
	0x91C1: 0xC65D,
	0x91C2: 0xF8C9,
	0x91C3: 0xF971,
	0x91C4: 0x9E65,
	0x91C5: 0xC66F,
	0x91C6: 0xA8BC,
	0x91C7: 0xAAF6,
	0x91C8: 0x92D8,
	0x91C9: 0xB956,
	0x91CA: 0x8C5C,
	0x91CB: 0xC4C0,
	0x91CC: 0xA8BD,
	0x91CD: 0xADAB,
	0x91CE: 0xB3A5,
	0x91CF: 0xB671,
	0x91D0: 0xC2E7,
	0x91D1: 0xAAF7,
	0x91D2: 0xFFFD,
	0x91D3: 0xD0C1,
	0x91D4: 0xD0C0,
	0x91D5: 0xD442,
	0x91D6: 0x91B9,
	0x91D7: 0xB078,
	0x91D8: 0xB076,
	0x91D9: 0xB07A,
	0x91DA: 0xD444,
	0x91DB: 0x91BA,
	0x91DC: 0xB079,
	0x91DD: 0xB077,
	0x91DE: 0x91BB,
	0x91DF: 0x9649,
	0x91E0: 0xFFFD,
	0x91E1: 0x91BC,
	0x91E2: 0xD443,
	0x91E3: 0xB3A8,
	0x91E4: 0xD7FC,
	0x91E5: 0x91BD,
	0x91E6: 0xB3A7,
	0x91E7: 0xB3A9,
	0x91E8: 0xD842,
	0x91E9: 0xB3AB,
	0x91EA: 0xD7FE,
	0x91EB: 0xD840,
	0x91EC: 0xD7F7,
	0x91ED: 0xB3AA,
	0x91EE: 0xD843,
	0x91EF: 0xFFFD,
	0x91F0: 0xFFFD,
	0x91F1: 0xD7F9,
	0x91F2: 0xFFFD,
	0x91F3: 0xD7FA,
	0x91F4: 0xD7F8,
	0x91F5: 0xB3A6,
	0x91F6: 0x91BE,
	0x91F7: 0xD841,
	0x91F8: 0xD7FB,
	0x91F9: 0xD7FD,
	0x91FA: 0x9E66,
	0x91FB: 0xFFFD,
	0x91FC: 0x91BF,
	0x91FD: 0xDC6D,
	0x91FE: 0xFDB7,
	0x91FF: 0xDC6C,
	0x9200: 0xDC6A,
	0x9201: 0xDC62,
	0x9202: 0xDC71,
	0x9203: 0xDC65,
	0x9204: 0xDC6F,
	0x9205: 0xDC76,
	0x9206: 0xDC6E,
	0x9207: 0xB679,
	0x9208: 0x9E67,
	0x9209: 0xB675,
	0x920A: 0xDC63,
	0x920B: 0xFFFD,
	0x920C: 0xDC69,
	0x920D: 0xB677,
	0x920E: 0x954C,
	0x920F: 0xDC68,
	0x9210: 0xB678,
	0x9211: 0xB67A,
	0x9212: 0xDC6B,
	0x9213: 0x9E68,
	0x9214: 0xB672,
	0x9215: 0xB673,
	0x9216: 0xDC77,
	0x9217: 0xDC75,
	0x9218: 0xFFFD,
	0x9219: 0xDC74,
	0x921A: 0xDC66,
	0x921B: 0xFFFD,
	0x921C: 0xDC72,
	0x921D: 0xFFFD,
	0x921E: 0xB676,
	0x921F: 0xFFFD,
	0x9220: 0xFFFD,
	0x9221: 0x9E69,
	0x9222: 0xFFFD,
	0x9223: 0xB674,
	0x9224: 0xDC73,
	0x9225: 0xDC64,
	0x9226: 0xDC67,
	0x9227: 0xDC70,
	0x9228: 0x9E6A,
	0x9229: 0x91C0,
	0x922A: 0xFB5F,
	0x922B: 0x9E6B,
	0x922C: 0x91C1,
	0x922D: 0xE4BA,
	0x922E: 0xE0B7,
	0x922F: 0xFFFD,
	0x9230: 0xE0B0,
	0x9231: 0xE0C3,
	0x9232: 0xE0CC,
	0x9233: 0xE0B3,
	0x9234: 0xB961,
	0x9235: 0x9E6C,
	0x9236: 0xE0C0,
	0x9237: 0xB957,
	0x9238: 0xB959,
	0x9239: 0xB965,
	0x923A: 0xE0B1,
	0x923B: 0xFFFD,
	0x923C: 0x9E6D,
	0x923D: 0xB95A,
	0x923E: 0xB95C,
	0x923F: 0xB966,
	0x9240: 0xB95B,
	0x9241: 0x9E6E,
	0x9242: 0xFFFD,
	0x9243: 0xFFFD,
	0x9244: 0x937B,
	0x9245: 0xB964,
	0x9246: 0xE0B9,
	0x9247: 0xFFFD,
	0x9248: 0xE0AE,
	0x9249: 0xB962,
	0x924A: 0xE0B8,
	0x924B: 0xB95E,
	0x924C: 0xE0CA,
	0x924D: 0xB963,
	0x924E: 0xE0C8,
	0x924F: 0xE0BC,
	0x9250: 0xE0C6,
	0x9251: 0xB960,
	0x9252: 0xE0AF,
	0x9253: 0xE0C9,
	0x9254: 0xE0C4,
	0x9255: 0x9640,
	0x9256: 0xE0CB,
	0x9257: 0xB958,
	0x9258: 0x9E6F,
	0x9259: 0x91C3,
	0x925A: 0xB967,
	0x925B: 0xB95D,
	0x925C: 0xFFFD,
	0x925D: 0x9E70,
	0x925E: 0xE0B5,
	0x925F: 0x9E71,
	0x9260: 0xE0BD,
	0x9261: 0xE0C1,
	0x9262: 0x95F1,
	0x9263: 0xE0C5,
	0x9264: 0xB95F,
	0x9265: 0xE0B4,
	0x9266: 0xE0B2,
	0x9267: 0xE0BE,
	0x9268: 0xFFFD,
	0x9269: 0xFFFD,
	0x926A: 0xFFFD,
	0x926B: 0x9E72,
	0x926C: 0xE0BB,
	0x926D: 0xE0BA,
	0x926E: 0x9E73,
	0x926F: 0xE0BF,
	0x9270: 0xE0C2,
	0x9271: 0x92C0,
	0x9272: 0xE0C7,
	0x9273: 0x9643,
	0x9274: 0x8CE5,
	0x9275: 0xFFFD,
	0x9276: 0xE478,
	0x9277: 0x91C4,
	0x9278: 0xBBC7,
	0x9279: 0xE4A4,
	0x927A: 0xE47A,
	0x927B: 0xBBCC,
	0x927C: 0xBBD0,
	0x927D: 0xE4AD,
	0x927E: 0xE4B5,
	0x927F: 0xE4A6,
	0x9280: 0xBBC8,
	0x9281: 0x9E74,
	0x9282: 0xE4AA,
	0x9283: 0xE0B6,
	0x9284: 0x9E75,
	0x9285: 0xBBC9,
	0x9286: 0xE4B1,
	0x9287: 0xE4B6,
	0x9288: 0xE4AE,
	0x9289: 0x9E76,
	0x928A: 0xE4B0,
	0x928B: 0xE4B9,
	0x928C: 0xE4B2,
	0x928D: 0xE47E,
	0x928E: 0xE4A9,
	0x928F: 0x9E77,
	0x9290: 0xFFFD,
	0x9291: 0xBBD1,
	0x9292: 0xFFFD,
	0x9293: 0xBBCD,
	0x9294: 0xE47C,
	0x9295: 0xE4AB,
	0x9296: 0xBBCB,
	0x9297: 0xE4A5,
	0x9298: 0xBBCA,
	0x9299: 0xE4B3,
	0x929A: 0xE4A2,
	0x929B: 0xE479,
	0x929C: 0xBBCE,
	0x929D: 0xE4B8,
	0x929E: 0xFFFD,
	0x929F: 0xFFFD,
	0x92A0: 0xE47B,
	0x92A1: 0xE4AF,
	0x92A2: 0xE4AC,
	0x92A3: 0xE4A7,
	0x92A4: 0xE477,
	0x92A5: 0xE476,
	0x92A6: 0xE4A1,
	0x92A7: 0xE4B4,
	0x92A8: 0xBBCF,
	0x92A9: 0xE4B7,
	0x92AA: 0xE47D,
	0x92AB: 0xE4A3,
	0x92AC: 0xBE52,
	0x92AD: 0x934B,
	0x92AE: 0x8DA8,
	0x92AF: 0xFFFD,
	0x92B0: 0xFFFD,
	0x92B1: 0x9E78,
	0x92B2: 0xBE5A,
	0x92B3: 0xBE55,
	0x92B4: 0xE8A4,
	0x92B5: 0xE8A1,
	0x92B6: 0xE867,
	0x92B7: 0xBE50,
	0x92B8: 0xFFFD,
	0x92B9: 0xF9D7,
	0x92BA: 0x9E79,
	0x92BB: 0xBE4F,
	0x92BC: 0xBE56,
	0x92BD: 0xFFFD,
	0x92BE: 0xFDB9,
	0x92BF: 0x9E7A,
	0x92C0: 0xE865,
	0x92C1: 0xBE54,
	0x92C2: 0xE871,
	0x92C3: 0xE863,
	0x92C4: 0xE864,
	0x92C5: 0xBE4E,
	0x92C6: 0xE8A3,
	0x92C7: 0xBE58,
	0x92C8: 0xE874,
	0x92C9: 0xE879,
	0x92CA: 0xE873,
	0x92CB: 0xEBEE,
	0x92CC: 0xE86F,
	0x92CD: 0xE877,
	0x92CE: 0xE875,
	0x92CF: 0xE868,
	0x92D0: 0xE862,
	0x92D1: 0xE87D,
	0x92D2: 0xBE57,
	0x92D3: 0xE87E,
	0x92D4: 0x9E7B,
	0x92D5: 0xE878,
	0x92D6: 0xFFFD,
	0x92D7: 0xE86D,
	0x92D8: 0xE86B,
	0x92D9: 0xE866,
	0x92DA: 0xFFFD,
	0x92DB: 0x9E7C,
	0x92DC: 0xFFFD,
	0x92DD: 0xE86E,
	0x92DE: 0xE87B,
	0x92DF: 0xE86A,
	0x92E0: 0xE87A,
	0x92E1: 0xE8A2,
	0x92E2: 0xFFFD,
	0x92E3: 0x9E7D,
	0x92E4: 0xBE53,
	0x92E5: 0x9E7E,
	0x92E6: 0xE876,
	0x92E7: 0xE87C,
	0x92E8: 0xE872,
	0x92E9: 0xE86C,
	0x92EA: 0xBE51,
	0x92EB: 0x9EA1,
	0x92EC: 0x9EA2,
	0x92ED: 0x91C5,
	0x92EE: 0xE4A8,
	0x92EF: 0xE870,
	0x92F0: 0xBE59,
	0x92F1: 0xE869,
	0x92F2: 0x9458,
	0x92F3: 0x9374,
	0x92F4: 0x9EA3,
	0x92F5: 0xFFFD,
	0x92F6: 0x9EA4,
	0x92F7: 0xEBF4,
	0x92F8: 0xBFF7,
	0x92F9: 0xEBF3,
	0x92FA: 0xEBF0,
	0x92FB: 0xEC44,
	0x92FC: 0xBFFB,
	0x92FD: 0x9EA5,
	0x92FE: 0xEC41,
	0x92FF: 0xEBF8,
	0x9300: 0xEC43,
	0x9301: 0xEBE9,
	0x9302: 0xEBF6,
	0x9303: 0x9EA6,
	0x9304: 0xBFFD,
	0x9305: 0xFFFD,
	0x9306: 0xEBE1,
	0x9307: 0x9EA7,
	0x9308: 0xEBDF,
	0x9309: 0xEC42,
	0x930A: 0xFFFD,
	0x930B: 0xEC40,
	0x930C: 0xEBFE,
	0x930D: 0xEBED,
	0x930E: 0xEBEC,
	0x930F: 0xEBE2,
	0x9310: 0xC040,
	0x9311: 0xFFFD,
	0x9312: 0xEBE8,
	0x9313: 0xEBF2,
	0x9314: 0xEBFD,
	0x9315: 0xC043,
	0x9316: 0xEC45,
	0x9317: 0xFFFD,
	0x9318: 0xC1E8,
	0x9319: 0xC045,
	0x931A: 0xBFFE,
	0x931B: 0xEBE6,
	0x931C: 0xFFFD,
	0x931D: 0xEBEF,
	0x931E: 0xEBDE,
	0x931F: 0xEBE0,
	0x9320: 0xBFF5,
	0x9321: 0xC042,
	0x9322: 0xBFFA,
	0x9323: 0xEBE7,
	0x9324: 0xEBF7,
	0x9325: 0xEBF1,
	0x9326: 0xC041,
	0x9327: 0xEBDD,
	0x9328: 0xC1E3,
	0x9329: 0xEBF9,
	0x932A: 0xEBFC,
	0x932B: 0xBFFC,
	0x932C: 0x93F3,
	0x932D: 0xEBEB,
	0x932E: 0xC044,
	0x932F: 0xBFF9,
	0x9330: 0x9EA8,
	0x9331: 0x9EA9,
	0x9332: 0x93F7,
	0x9333: 0xBFF8,
	0x9334: 0xEBF5,
	0x9335: 0xEBFB,
	0x9336: 0xBFF6,
	0x9337: 0xFFFD,
	0x9338: 0xEBE4,
	0x9339: 0xEBFA,
	0x933A: 0x91C6,
	0x933B: 0x94DB,
	0x933C: 0xEBE5,
	0x933D: 0xFFFD,
	0x933E: 0x8BD6,
	0x933F: 0xFFFD,
	0x9340: 0x9EAA,
	0x9341: 0xFE7C,
	0x9342: 0x9EAB,
	0x9343: 0x9EAC,
	0x9344: 0x9755,
	0x9345: 0x9642,
	0x9346: 0xEBEA,
	0x9347: 0xEED2,
	0x9348: 0xFE79,
	0x9349: 0xEED7,
	0x934A: 0xC1E5,
	0x934B: 0xC1E7,
	0x934C: 0xEEDD,
	0x934D: 0xC1E1,
	0x934E: 0xEEEC,
	0x934F: 0xEEE3,
	0x9350: 0xEED8,
	0x9351: 0xEED9,
	0x9352: 0xEEE2,
	0x9353: 0xFFFD,
	0x9354: 0xC1EE,
	0x9355: 0xEEE1,
	0x9356: 0xEED1,
	0x9357: 0xEEE0,
	0x9358: 0xEED4,
	0x9359: 0xEEED,
	0x935A: 0xC1ED,
	0x935B: 0xC1EB,
	0x935C: 0xEED5,
	0x935D: 0xFFFD,
	0x935E: 0xEEE8,
	0x935F: 0x9EAD,
	0x9360: 0xEEDA,
	0x9361: 0xEEE7,
	0x9362: 0x9EAE,
	0x9363: 0xEEE9,
	0x9364: 0xEED0,
	0x9365: 0xC1E6,
	0x9366: 0x9EAF,
	0x9367: 0xEEEA,
	0x9368: 0x9EB0,
	0x9369: 0x9644,
	0x936A: 0xEEDE,
	0x936B: 0xFDBA,
	0x936C: 0xC1EA,
	0x936D: 0xEEDB,
	0x936E: 0xFDBB,
	0x936F: 0xFFFD,
	0x9370: 0xC1EC,
	0x9371: 0xEEE4,
	0x9372: 0xFFFD,
	0x9373: 0x9EB1,
	0x9374: 0x9EB2,
	0x9375: 0xC1E4,
	0x9376: 0xEED6,
	0x9377: 0xEEE5,
	0x9378: 0x9EB3,
	0x9379: 0xEEDF,
	0x937A: 0xEBE3,
	0x937B: 0xEEE6,
	0x937C: 0xEED3,
	0x937D: 0x9EB4,
	0x937E: 0xC1E9,
	0x937F: 0xFFFD,
	0x9380: 0xEEEB,
	0x9381: 0x9EB5,
	0x9382: 0xC1E2,
	0x9383: 0xEECE,
	0x9384: 0x9EB6,
	0x9385: 0xFB73,
	0x9386: 0x9EB7,
	0x9387: 0x9EB8,
	0x9388: 0xF160,
	0x9389: 0xF159,
	0x938A: 0xC2E9,
	0x938B: 0xFFFD,
	0x938C: 0xF154,
	0x938D: 0xF163,
	0x938E: 0xF15B,
	0x938F: 0xEEDC,
	0x9390: 0x9EB9,
	0x9391: 0xF165,
	0x9392: 0xF155,
	0x9393: 0xFFFD,
	0x9394: 0xC2E8,
	0x9395: 0xF15F,
	0x9396: 0xC2EA,
	0x9397: 0xC2F2,
	0x9398: 0xC2F0,
	0x9399: 0xF161,
	0x939A: 0xC2F1,
	0x939B: 0xF157,
	0x939C: 0x9EBA,
	0x939D: 0xF158,
	0x939E: 0xF15D,
	0x939F: 0xF162,
	0x93A0: 0x9EBB,
	0x93A1: 0xEECD,
	0x93A2: 0xC2EB,
	0x93A3: 0xF16A,
	0x93A4: 0xF167,
	0x93A5: 0xF16B,
	0x93A6: 0xF15E,
	0x93A7: 0xF15A,
	0x93A8: 0xF168,
	0x93A9: 0xF36A,
	0x93AA: 0xF15C,
	0x93AB: 0xFFFD,
	0x93AC: 0xC2EE,
	0x93AD: 0x9756,
	0x93AE: 0xC2ED,
	0x93AF: 0xEECF,
	0x93B0: 0xC2EF,
	0x93B1: 0xF164,
	0x93B2: 0xF166,
	0x93B3: 0xC2EC,
	0x93B4: 0xF169,
	0x93B5: 0xF153,
	0x93B6: 0xFFFD,
	0x93B7: 0xF156,
	0x93B8: 0x9EBC,
	0x93B9: 0x94DC,
	0x93BA: 0xFDBC,
	0x93BB: 0x9EBD,
	0x93BC: 0xFFFD,
	0x93BD: 0x9EBE,
	0x93BE: 0xFFFD,
	0x93BF: 0x9EBF,
	0x93C0: 0xF373,
	0x93C1: 0xFFFD,
	0x93C2: 0xF363,
	0x93C3: 0xC3EB,
	0x93C4: 0xF371,
	0x93C5: 0xFFFD,
	0x93C6: 0x9757,
	0x93C7: 0xF361,
	0x93C8: 0xC3EC,
	0x93C9: 0xFFFD,
	0x93CA: 0xF36C,
	0x93CB: 0x9EC0,
	0x93CC: 0xF368,
	0x93CD: 0xC3F1,
	0x93CE: 0xF372,
	0x93CF: 0xF362,
	0x93D0: 0xF365,
	0x93D1: 0xC3E9,
	0x93D2: 0xF374,
	0x93D3: 0x9EC1,
	0x93D4: 0xF36D,
	0x93D5: 0xF370,
	0x93D6: 0xC3EF,
	0x93D7: 0xC3F4,
	0x93D8: 0xC3F2,
	0x93D9: 0xF369,
	0x93DA: 0xF364,
	0x93DB: 0x9EC2,
	0x93DC: 0xC3ED,
	0x93DD: 0xC3EE,
	0x93DE: 0xF360,
	0x93DF: 0xC3EA,
	0x93E0: 0x9EC3,
	0x93E1: 0xC3E8,
	0x93E2: 0xC3F0,
	0x93E3: 0xF36F,
	0x93E4: 0xC3F3,
	0x93E5: 0x9758,
	0x93E6: 0xF36B,
	0x93E7: 0xF375,
	0x93E8: 0xC3F5,
	0x93E9: 0xFFFD,
	0x93EA: 0xFFFD,
	0x93EB: 0xFFFD,
	0x93EC: 0xF367,
	0x93ED: 0xFFFD,
	0x93EE: 0xF36E,
	0x93EF: 0xFFFD,
	0x93F0: 0x9EC4,
	0x93F1: 0x9EC5,
	0x93F2: 0xFFFD,
	0x93F3: 0x9EC6,
	0x93F4: 0x9EC7,
	0x93F5: 0xF4F3,
	0x93F6: 0xF542,
	0x93F7: 0xF4F5,
	0x93F8: 0xF4FC,
	0x93F9: 0xF366,
	0x93FA: 0xF4FA,
	0x93FB: 0xF4E9,
	0x93FC: 0xF540,
	0x93FD: 0xC4C3,
	0x93FE: 0xF4ED,
	0x93FF: 0xF4FE,
	0x9400: 0xF4F4,
	0x9401: 0x9EC8,
	0x9402: 0xFFFD,
	0x9403: 0xC4C2,
	0x9404: 0x9EC9,
	0x9405: 0xFFFD,
	0x9406: 0xF544,
	0x9407: 0xF4F6,
	0x9408: 0x9ECA,
	0x9409: 0xF4FB,
	0x940A: 0xF4FD,
	0x940B: 0xF4E7,
	0x940C: 0xF541,
	0x940D: 0xF4F2,
	0x940E: 0xF4F7,
	0x940F: 0xF4EB,
	0x9410: 0xF4EF,
	0x9411: 0xF543,
	0x9412: 0xF4F9,
	0x9413: 0xF4E8,
	0x9414: 0xF4EC,
	0x9415: 0xF4EE,
	0x9416: 0xF4F8,
	0x9417: 0x9ECB,
	0x9418: 0xC4C1,
	0x9419: 0xF4F1,
	0x941A: 0x9759,
	0x941B: 0x9ECC,
	0x941C: 0xFFFD,
	0x941D: 0x9ECD,
	0x941E: 0xFFFD,
	0x941F: 0xFFFD,
	0x9420: 0xF4EA,
	0x9421: 0x975A,
	0x9422: 0xFFFD,
	0x9423: 0xFFFD,
	0x9424: 0x9ECE,
	0x9425: 0x9ECF,
	0x9426: 0x9ED0,
	0x9427: 0xFDBD,
	0x9428: 0xF4F0,
	0x9429: 0xF661,
	0x942A: 0xF666,
	0x942B: 0xC54F,
	0x942C: 0xF668,
	0x942D: 0x9ED1,
	0x942E: 0xC549,
	0x942F: 0xFFFD,
	0x9430: 0xF664,
	0x9431: 0xF66A,
	0x9432: 0xC54E,
	0x9433: 0xC54A,
	0x9434: 0xFFFD,
	0x9435: 0xC54B,
	0x9436: 0xF660,
	0x9437: 0xF667,
	0x9438: 0xC54D,
	0x9439: 0xF665,
	0x943A: 0xC54C,
	0x943B: 0xF65F,
	0x943C: 0xF663,
	0x943D: 0xF662,
	0x943E: 0x975B,
	0x943F: 0xF65E,
	0x9440: 0xF669,
	0x9441: 0x975C,
	0x9442: 0x9ED2,
	0x9443: 0x9ED3,
	0x9444: 0xC5B1,
	0x9445: 0xF76D,
	0x9446: 0xF770,
	0x9447: 0xF76C,
	0x9448: 0xF76E,
	0x9449: 0xF76F,
	0x944A: 0xF769,
	0x944B: 0xF76A,
	0x944C: 0xF767,
	0x944D: 0x9ED4,
	0x944E: 0xFFFD,
	0x944F: 0xF76B,
	0x9450: 0xF768,
	0x9451: 0xC5B2,
	0x9452: 0xC5B3,
	0x9453: 0x975D,
	0x9454: 0x9ED5,
	0x9455: 0xF84B,
	0x9456: 0xFFFD,
	0x9457: 0xF84D,
	0x9458: 0x9ED6,
	0x9459: 0xFFFD,
	0x945A: 0x975E,
	0x945B: 0x9558,
	0x945C: 0xFFFD,
	0x945D: 0xF84C,
	0x945E: 0xF84E,
	0x945F: 0xFFFD,
	0x9460: 0xC5E0,
	0x9461: 0xFFFD,
	0x9462: 0xF84A,
	0x9463: 0xC5DF,
	0x9464: 0xC5E1,
	0x9465: 0x9ED7,
	0x9466: 0xFFFD,
	0x9467: 0x9ED8,
	0x9468: 0xF8CB,
	0x9469: 0xF8CC,
	0x946A: 0xC644,
	0x946B: 0xF8CA,
	0x946C: 0x9ED9,
	0x946D: 0xF953,
	0x946E: 0xF952,
	0x946F: 0xF954,
	0x9470: 0xC65F,
	0x9471: 0xF955,
	0x9472: 0xC65E,
	0x9473: 0xF956,
	0x9474: 0xF972,
	0x9475: 0xF975,
	0x9476: 0xF974,
	0x9477: 0xC668,
	0x9478: 0xF973,
	0x9479: 0x9EDA,
	0x947A: 0xFFFD,
	0x947B: 0x9EDB,
	0x947C: 0xC672,
	0x947D: 0xC670,
	0x947E: 0xC671,
	0x947F: 0xC677,
	0x9480: 0xF9C0,
	0x9481: 0xF9C1,
	0x9482: 0xF9BF,
	0x9483: 0xF9C9,
	0x9484: 0xFFFD,
	0x9485: 0x9CF0,
	0x9486: 0x8DC1,
	0x9487: 0x8DC0,
	0x9488: 0x83E1,
	0x9489: 0x83E0,
	0x948A: 0x83E2,
	0x948B: 0x83E3,
	0x948C: 0x8DC7,
	0x948D: 0x8DD9,
	0x948E: 0x8DD6,
	0x948F: 0x84B6,
	0x9490: 0x8DD7,
	0x9491: 0xFFFD,
	0x9492: 0x84B7,
	0x9493: 0x84B5,
	0x9494: 0x8F46,
	0x9495: 0x8DD8,
	0x9496: 0xFFFD,
	0x9497: 0x84B4,
	0x9498: 0xFFFD,
	0x9499: 0x8573,
	0x949A: 0x975F,
	0x949B: 0x8DF4,
	0x949C: 0x8673,
	0x949D: 0x8576,
	0x949E: 0x8571,
	0x949F: 0x8C5D,
	0x94A0: 0x8574,
	0x94A1: 0x88AE,
	0x94A2: 0x89A1,
	0x94A3: 0x8578,
	0x94A4: 0x8577,
	0x94A5: 0x8D76,
	0x94A6: 0x84E8,
	0x94A7: 0x8575,
	0x94A8: 0x8B4F,
	0x94A9: 0x866E,
	0x94AA: 0x8DF7,
	0x94AB: 0x8DF2,
	0x94AC: 0x8DF3,
	0x94AD: 0x8DF6,
	0x94AE: 0x8572,
	0x94AF: 0x8DF5,
	0x94B0: 0x8E5A,
	0x94B1: 0x897E,
	0x94B2: 0x8E5B,
	0x94B3: 0x8668,
	0x94B4: 0x8667,
	0x94B5: 0x8473,
	0x94B6: 0x8E5C,
	0x94B7: 0x9760,
	0x94B8: 0x866A,
	0x94B9: 0x8669,
	0x94BA: 0x8DB2,
	0x94BB: 0x8DA7,
	0x94BC: 0x8E60,
	0x94BD: 0x8E5F,
	0x94BE: 0x866B,
	0x94BF: 0x8675,
	0x94C0: 0x866C,
	0x94C1: 0x8CB2,
	0x94C2: 0x866F,
	0x94C3: 0x8670,
	0x94C4: 0x8D44,
	0x94C5: 0x866D,
	0x94C6: 0x8676,
	0x94C7: 0xFFFD,
	0x94C8: 0x8E59,
	0x94C9: 0x8671,
	0x94CA: 0x8E58,
	0x94CB: 0x8672,
	0x94CC: 0x8E5E,
	0x94CD: 0x8674,
	0x94CE: 0x8CB4,
	0x94CF: 0xFFFD,
	0x94D0: 0x88A8,
	0x94D1: 0x8EA5,
	0x94D2: 0x8EA4,
	0x94D3: 0xFFFD,
	0x94D4: 0xFFFD,
	0x94D5: 0x8EA6,
	0x94D6: 0x8EAC,
	0x94D7: 0x8ED1,
	0x94D8: 0x9761,
	0x94D9: 0x8C5E,
	0x94DA: 0xFFFD,
	0x94DB: 0x8CB3,
	0x94DC: 0x8766,
	0x94DD: 0x88AA,
	0x94DE: 0x9762,
	0x94DF: 0x8EA7,
	0x94E0: 0x8FA7,
	0x94E1: 0x8F6A,
	0x94E2: 0x8768,
	0x94E3: 0x876C,
	0x94E4: 0x8ED5,
	0x94E5: 0x8EAD,
	0x94E6: 0xFFFD,
	0x94E7: 0x8FEC,
	0x94E8: 0x876A,
	0x94E9: 0x8FCD,
	0x94EA: 0x8EAA,
	0x94EB: 0x8EA8,
	0x94EC: 0x8769,
	0x94ED: 0x8767,
	0x94EE: 0x89A4,
	0x94EF: 0x8EA9,
	0x94F0: 0x8764,
	0x94F1: 0x8EA3,
	0x94F2: 0x85B6,
	0x94F3: 0x9763,
	0x94F4: 0x8FE5,
	0x94F5: 0x876B,
	0x94F6: 0x8765,
	0x94F7: 0x8EAB,
	0x94F8: 0x8CE4,
	0x94F9: 0x8FEE,
	0x94FA: 0x88A7,
	0x94FB: 0xFFFD,
	0x94FC: 0x8F42,
	0x94FD: 0x8ED2,
	0x94FE: 0x8BCE,
	0x94FF: 0x8BD5,
	0x9500: 0x88A6,
	0x9501: 0x8B4E,
	0x9502: 0x88AF,
	0x9503: 0x9764,
	0x9504: 0x88A9,
	0x9505: 0x8AA2,
	0x9506: 0x8ED6,
	0x9507: 0x8ED7,
	0x9508: 0x8C5F,
	0x9509: 0x88AC,
	0x950A: 0x8ED4,
	0x950B: 0x88AD,
	0x950C: 0x88A4,
	0x950D: 0x8E5D,
	0x950E: 0x9765,
	0x950F: 0x9766,
	0x9510: 0x88AB,
	0x9511: 0x88A5,
	0x9512: 0x8ED0,
	0x9513: 0x8ED3,
	0x9514: 0x8ED8,
	0x9515: 0x8F44,
	0x9516: 0x8F40,
	0x9517: 0x8F41,
	0x9518: 0x9767,
	0x9519: 0x897D,
	0x951A: 0x8A7D,
	0x951B: 0x8F43,
	0x951C: 0xFFFD,
	0x951D: 0x9768,
	0x951E: 0x8F45,
	0x951F: 0x89A7,
	0x9520: 0xFFFD,
	0x9521: 0x89A2,
	0x9522: 0x89A8,
	0x9523: 0x8DA9,
	0x9524: 0x8AA3,
	0x9525: 0x89A5,
	0x9526: 0x89A6,
	0x9527: 0xFFFD,
	0x9528: 0x90F1,
	0x9529: 0x8EFD,
	0x952A: 0x9769,
	0x952B: 0x976A,
	0x952C: 0x8EFE,
	0x952D: 0x897A,
	0x952E: 0x8A7E,
	0x952F: 0x897B,
	0x9530: 0x897C,
	0x9531: 0x89A9,
	0x9532: 0x8AA1,
	0x9533: 0xFFFD,
	0x9534: 0x8F69,
	0x9535: 0x8BD3,
	0x9536: 0x8F6B,
	0x9537: 0x8AA8,
	0x9538: 0x8F68,
	0x9539: 0x8AA5,
	0x953A: 0x8AA4,
	0x953B: 0x8AA6,
	0x953C: 0x8FA8,
	0x953D: 0xFFFD,
	0x953E: 0x8AA7,
	0x953F: 0x976B,
	0x9540: 0x8A7B,
	0x9541: 0x8A7C,
	0x9542: 0x8BD4,
	0x9543: 0xFFFD,
	0x9544: 0x8FEA,
	0x9545: 0x976C,
	0x9546: 0x8A42,
	0x9547: 0x8B51,
	0x9548: 0xFFFD,
	0x9549: 0x8B54,
	0x954A: 0x8D7D,
	0x954B: 0xFFFD,
	0x954C: 0x8CB6,
	0x954D: 0x8B50,
	0x954E: 0x976D,
	0x954F: 0x8FA9,
	0x9550: 0x8B52,
	0x9551: 0x8B4D,
	0x9552: 0x8B53,
	0x9553: 0x8FA6,
	0x9554: 0x9060,
	0x9555: 0xFFFD,
	0x9556: 0x8BD1,
	0x9557: 0x8BCF,
	0x9558: 0x8BD0,
	0x9559: 0x8BD2,
	0x955A: 0xFFFD,
	0x955B: 0x8FC9,
	0x955C: 0x8BCB,
	0x955D: 0x8BCC,
	0x955E: 0x8BCD,
	0x955F: 0x8FCA,
	0x9560: 0xFFFD,
	0x9561: 0x8FE8,
	0x9562: 0x976E,
	0x9563: 0x8FE9,
	0x9564: 0x8FED,
	0x9565: 0x976F,
	0x9566: 0x8FE6,
	0x9567: 0x90A1,
	0x9568: 0x8FE7,
	0x9569: 0x9770,
	0x956A: 0x8FCB,
	0x956B: 0x8FEB,
	0x956C: 0x9061,
	0x956D: 0x8CB1,
	0x956E: 0xFFFD,
	0x956F: 0x8CB5,
	0x9570: 0x8CB0,
	0x9571: 0x9048,
	0x9572: 0x9771,
	0x9573: 0x8D43,
	0x9574: 0xFFFD,
	0x9575: 0xFFFD,
	0x9576: 0x8C7C,
	0x9577: 0xAAF8,
	0x9578: 0x9EDC,
	0x9579: 0xFFFD,
	0x957A: 0xD844,
	0x957B: 0xDC78,
	0x957C: 0xE8A5,
	0x957D: 0xF376,
	0x957E: 0xFFFD,
	0x957F: 0x8363,
	0x9580: 0xAAF9,
	0x9581: 0xFFFD,
	0x9582: 0xADAC,
	0x9583: 0xB07B,
	0x9584: 0xFFFD,
	0x9585: 0x9EDD,
	0x9586: 0xD845,
	0x9587: 0x9772,
	0x9588: 0xD846,
	0x9589: 0xB3AC,
	0x958A: 0x94DD,
	0x958B: 0xB67D,
	0x958C: 0xDC7A,
	0x958D: 0xDC79,
	0x958E: 0xB6A3,
	0x958F: 0xB67C,
	0x9590: 0xDC7B,
	0x9591: 0xB67E,
	0x9592: 0xB6A2,
	0x9593: 0xB6A1,
	0x9594: 0xB67B,
	0x9595: 0xFFFD,
	0x9596: 0x94DE,
	0x9597: 0xFDBE,
	0x9598: 0xB968,
	0x9599: 0x9773,
	0x959A: 0xFFFD,
	0x959B: 0xE0D0,
	0x959C: 0xE0CE,
	0x959D: 0xFFFD,
	0x959E: 0xE0CF,
	0x959F: 0xE0CD,
	0x95A0: 0x9774,
	0x95A1: 0xBBD2,
	0x95A2: 0x926B,
	0x95A3: 0xBBD5,
	0x95A4: 0xBBD7,
	0x95A5: 0xBBD6,
	0x95A6: 0x9EDE,
	0x95A7: 0xFDBF,
	0x95A8: 0xBBD3,
	0x95A9: 0xBBD4,
	0x95AA: 0x9EDF,
	0x95AB: 0xE8A7,
	0x95AC: 0xE8A6,
	0x95AD: 0xBE5B,
	0x95AE: 0xE8A8,
	0x95AF: 0xFFFD,
	0x95B0: 0xE8A9,
	0x95B1: 0xBE5C,
	0x95B2: 0x9775,
	0x95B3: 0xFFFD,
	0x95B4: 0xFFFD,
	0x95B5: 0xEC4D,
	0x95B6: 0xEC4B,
	0x95B7: 0xEEF3,
	0x95B8: 0xFFFD,
	0x95B9: 0xEC49,
	0x95BA: 0xEC4A,
	0x95BB: 0xC046,
	0x95BC: 0xEC46,
	0x95BD: 0xEC4E,
	0x95BE: 0xEC48,
	0x95BF: 0xEC4C,
	0x95C0: 0xEEEF,
	0x95C1: 0xFFFD,
	0x95C2: 0xFFFD,
	0x95C3: 0xEEF1,
	0x95C4: 0xFFFD,
	0x95C5: 0xEEF2,
	0x95C6: 0xC1F3,
	0x95C7: 0xEEEE,
	0x95C8: 0xC1F2,
	0x95C9: 0xEEF0,
	0x95CA: 0xC1EF,
	0x95CB: 0xC1F0,
	0x95CC: 0xC1F1,
	0x95CD: 0xEC47,
	0x95CE: 0xFFFD,
	0x95CF: 0xFFFD,
	0x95D0: 0xC2F5,
	0x95D1: 0xF16E,
	0x95D2: 0xF16C,
	0x95D3: 0xF16D,
	0x95D4: 0xC2F3,
	0x95D5: 0xC2F6,
	0x95D6: 0xC2F4,
	0x95D7: 0xFFFD,
	0x95D8: 0x93A7,
	0x95D9: 0xFFFD,
	0x95DA: 0xF377,
	0x95DB: 0xF378,
	0x95DC: 0xC3F6,
	0x95DD: 0xFFFD,
	0x95DE: 0xF545,
	0x95DF: 0xF547,
	0x95E0: 0xF546,
	0x95E1: 0xC4C4,
	0x95E2: 0xC550,
	0x95E3: 0xF66D,
	0x95E4: 0xF66C,
	0x95E5: 0xF66B,
	0x95E6: 0xFFFD,
	0x95E7: 0xFFFD,
	0x95E8: 0x8364,
	0x95E9: 0x83A2,
	0x95EA: 0x83E4,
	0x95EB: 0x8DDA,
	0x95EC: 0xFFFD,
	0x95ED: 0x84B8,
	0x95EE: 0x83F4,
	0x95EF: 0x8B56,
	0x95F0: 0x857A,
	0x95F1: 0x8AAC,
	0x95F2: 0x857C,
	0x95F3: 0x857E,
	0x95F4: 0x857D,
	0x95F5: 0x8579,
	0x95F6: 0x8DF8,
	0x95F7: 0x84DD,
	0x95F8: 0x8677,
	0x95F9: 0x88C1,
	0x95FA: 0x876E,
	0x95FB: 0x8747,
	0x95FC: 0x9049,
	0x95FD: 0x876F,
	0x95FE: 0x88B0,
	0x95FF: 0xFFFD,
	0x9600: 0x8771,
	0x9601: 0x8770,
	0x9602: 0x876D,
	0x9603: 0x8EDA,
	0x9604: 0x90AC,
	0x9605: 0x88B1,
	0x9606: 0x8ED9,
	0x9607: 0xFFFD,
	0x9608: 0x8F48,
	0x9609: 0x8F49,
	0x960A: 0x8F4A,
	0x960B: 0x8FB0,
	0x960C: 0x8F4B,
	0x960D: 0x8F4C,
	0x960E: 0x89AA,
	0x960F: 0x8F47,
	0x9610: 0x8C60,
	0x9611: 0x8AAB,
	0x9612: 0x8F6C,
	0x9613: 0xFFFD,
	0x9614: 0x8AA9,
	0x9615: 0x8AAA,
	0x9616: 0x8B55,
	0x9617: 0x8B57,
	0x9618: 0xFFFD,
	0x9619: 0x8B58,
	0x961A: 0x8FEF,
	0x961B: 0xFFFD,
	0x961C: 0xAAFA,
	0x961D: 0x9CF1,
	0x961E: 0xC9AA,
	0x961F: 0x85A1,
	0x9620: 0xCA58,
	0x9621: 0xA6E9,
	0x9622: 0xCA56,
	0x9623: 0xCA59,
	0x9624: 0xCA57,
	0x9625: 0xFFFD,
	0x9626: 0xFFFD,
	0x9627: 0xFFFD,
	0x9628: 0xCBAE,
	0x9629: 0xFFFD,
	0x962A: 0xA8C1,
	0x962B: 0xFFFD,
	0x962C: 0xA8C2,
	0x962D: 0xCBB0,
	0x962E: 0xA8BF,
	0x962F: 0xCBAF,
	0x9630: 0xCBAD,
	0x9631: 0xA8C0,
	0x9632: 0xA8BE,
	0x9633: 0x85A3,
	0x9634: 0x84BB,
	0x9635: 0x83E5,
	0x9636: 0x85A2,
	0x9637: 0xFFFD,
	0x9638: 0xFDC1,
	0x9639: 0xCDD8,
	0x963A: 0xCDDB,
	0x963B: 0xAAFD,
	0x963C: 0xCDDA,
	0x963D: 0xCDD9,
	0x963E: 0xFFFD,
	0x963F: 0xAAFC,
	0x9640: 0xAAFB,
	0x9641: 0xFE42,
	0x9642: 0xAB40,
	0x9643: 0xCDDC,
	0x9644: 0xAAFE,
	0x9645: 0x8772,
	0x9646: 0x84BA,
	0x9647: 0x8BD8,
	0x9648: 0x84B9,
	0x9649: 0x83E7,
	0x964A: 0xD0C6,
	0x964B: 0xADAE,
	0x964C: 0xADAF,
	0x964D: 0xADB0,
	0x964E: 0xD0C7,
	0x964F: 0xD0C3,
	0x9650: 0xADAD,
	0x9651: 0xD0C4,
	0x9652: 0xFFFD,
	0x9653: 0xD0C5,
	0x9654: 0xD0C2,
	0x9655: 0x83E6,
	0x9656: 0x9EE0,
	0x9657: 0xFFFD,
	0x9658: 0xB0A4,
	0x9659: 0xFFFD,
	0x965A: 0xFFFD,
	0x965B: 0xB0A1,
	0x965C: 0xD445,
	0x965D: 0xB0A2,
	0x965E: 0xB0A5,
	0x965F: 0xD446,
	0x9660: 0xFFFD,
	0x9661: 0xB07E,
	0x9662: 0xB07C,
	0x9663: 0xB07D,
	0x9664: 0xB0A3,
	0x9665: 0x9267,
	0x9666: 0x9776,
	0x9667: 0x8DF9,
	0x9668: 0x8678,
	0x9669: 0x89AC,
	0x966A: 0xB3AD,
	0x966B: 0xD849,
	0x966C: 0xB3B5,
	0x966D: 0xD848,
	0x966E: 0xFFFD,
	0x966F: 0xD84B,
	0x9670: 0xB3B1,
	0x9671: 0xD84A,
	0x9672: 0xB6AB,
	0x9673: 0xB3AF,
	0x9674: 0xB3B2,
	0x9675: 0xB3AE,
	0x9676: 0xB3B3,
	0x9677: 0xB3B4,
	0x9678: 0xB3B0,
	0x9679: 0xFFFD,
	0x967A: 0x92B4,
	0x967B: 0x9EE1,
	0x967C: 0xD847,
	0x967D: 0xB6A7,
	0x967E: 0xDC7D,
	0x967F: 0xFFFD,
	0x9680: 0xDCA3,
	0x9681: 0xFDC5,
	0x9682: 0xFFFD,
	0x9683: 0xDCA2,
	0x9684: 0xB6AC,
	0x9685: 0xB6A8,
	0x9686: 0xB6A9,
	0x9687: 0xDC7C,
	0x9688: 0xDC7E,
	0x9689: 0xDCA1,
	0x968A: 0xB6A4,
	0x968B: 0xB6A6,
	0x968C: 0xFFFD,
	0x968D: 0xB6AA,
	0x968E: 0xB6A5,
	0x968F: 0x92FA,
	0x9690: 0x8AAD,
	0x9691: 0xE0D3,
	0x9692: 0xE0D1,
	0x9693: 0xE0D2,
	0x9694: 0xB96A,
	0x9695: 0xB96B,
	0x9696: 0xFDC4,
	0x9697: 0xE0D4,
	0x9698: 0xB969,
	0x9699: 0xBBD8,
	0x969A: 0xFFFD,
	0x969B: 0xBBDA,
	0x969C: 0xBBD9,
	0x969D: 0x9777,
	0x969E: 0xE4BB,
	0x969F: 0xFFFD,
	0x96A0: 0x9247,
	0x96A1: 0xE4BC,
	0x96A2: 0xE8AB,
	0x96A3: 0x95F9,
	0x96A4: 0xE8AA,
	0x96A5: 0x9EE2,
	0x96A6: 0xFFFD,
	0x96A7: 0xC047,
	0x96A8: 0xC048,
	0x96A9: 0xEC4F,
	0x96AA: 0xC049,
	0x96AB: 0xFFFD,
	0x96AC: 0xEEF6,
	0x96AD: 0xFFFD,
	0x96AE: 0xEEF4,
	0x96AF: 0x9778,
	0x96B0: 0xEEF5,
	0x96B1: 0xC1F4,
	0x96B2: 0x9779,
	0x96B3: 0xF16F,
	0x96B4: 0xC3F7,
	0x96B5: 0xFFFD,
	0x96B6: 0xC6D7,
	0x96B7: 0x95FB,
	0x96B8: 0xC1F5,
	0x96B9: 0xAB41,
	0x96BA: 0xFFFD,
	0x96BB: 0xB0A6,
	0x96BC: 0xD447,
	0x96BD: 0x8679,
	0x96BE: 0x8BD9,
	0x96BF: 0xD84C,
	0x96C0: 0xB3B6,
	0x96C1: 0xB6AD,
	0x96C2: 0xDCA4,
	0x96C3: 0xDCA6,
	0x96C4: 0xB6AF,
	0x96C5: 0xB6AE,
	0x96C6: 0xB6B0,
	0x96C7: 0xB6B1,
	0x96C8: 0xDCA5,
	0x96C9: 0xB96E,
	0x96CA: 0xB96F,
	0x96CB: 0xB96D,
	0x96CC: 0xBBDB,
	0x96CD: 0xB96C,
	0x96CE: 0xE0D5,
	0x96CF: 0x8B5B,
	0x96D0: 0xFFFD,
	0x96D1: 0x92CA,
	0x96D2: 0xBBDC,
	0x96D3: 0xE8AC,
	0x96D4: 0xEC50,
	0x96D5: 0xC04A,
	0x96D6: 0xC1F6,
	0x96D7: 0xF170,
	0x96D8: 0xF174,
	0x96D9: 0xC2F9,
	0x96DA: 0xF171,
	0x96DB: 0xC2FA,
	0x96DC: 0xC2F8,
	0x96DD: 0xF175,
	0x96DE: 0xC2FB,
	0x96DF: 0xF173,
	0x96E0: 0x906D,
	0x96E1: 0xF379,
	0x96E2: 0xC2F7,
	0x96E3: 0xC3F8,
	0x96E4: 0xFFFD,
	0x96E5: 0xF8CD,
	0x96E6: 0xFFFD,
	0x96E7: 0xFFFD,
	0x96E8: 0xAB42,
	0x96E9: 0xB3B8,
	0x96EA: 0xB3B7,
	0x96EB: 0x9448,
	0x96EC: 0xFFFD,
	0x96ED: 0xFFFD,
	0x96EE: 0xFFFD,
	0x96EF: 0xB6B2,
	0x96F0: 0xDCA8,
	0x96F1: 0xDCA7,
	0x96F2: 0xB6B3,
	0x96F3: 0x8D5E,
	0x96F4: 0x9EE3,
	0x96F5: 0xE0D9,
	0x96F6: 0xB973,
	0x96F7: 0xB970,
	0x96F8: 0xE0D8,
	0x96F9: 0xB972,
	0x96FA: 0xE0D6,
	0x96FB: 0xB971,
	0x96FC: 0xFFFD,
	0x96FD: 0xE0D7,
	0x96FE: 0x8BDA,
	0x96FF: 0xE4BD,
	0x9700: 0xBBDD,
	0x9701: 0x8CE6,
	0x9702: 0xE8AF,
	0x9703: 0xFDC7,
	0x9704: 0xBE5D,
	0x9705: 0xE8AD,
	0x9706: 0xBE5E,
	0x9707: 0xBE5F,
	0x9708: 0xE8AE,
	0x9709: 0xBE60,
	0x970A: 0x93ED,
	0x970B: 0xEC51,
	0x970C: 0xFFFD,
	0x970D: 0xC04E,
	0x970E: 0xC04B,
	0x970F: 0xC050,
	0x9710: 0xEC53,
	0x9711: 0xC04C,
	0x9712: 0xEC52,
	0x9713: 0xC04F,
	0x9714: 0xFFFD,
	0x9715: 0xFFFD,
	0x9716: 0xC04D,
	0x9717: 0xFFFD,
	0x9718: 0xEEF9,
	0x9719: 0xEEFB,
	0x971A: 0xFFFD,
	0x971B: 0x9EE4,
	0x971C: 0xC1F7,
	0x971D: 0xEEFA,
	0x971E: 0xC1F8,
	0x971F: 0xEEF8,
	0x9720: 0xEEF7,
	0x9721: 0xFDC8,
	0x9722: 0xF177,
	0x9723: 0xF176,
	0x9724: 0xC2FC,
	0x9725: 0xF178,
	0x9726: 0xF37E,
	0x9727: 0xC3FA,
	0x9728: 0xF37D,
	0x9729: 0xF37A,
	0x972A: 0xC3F9,
	0x972B: 0xF37B,
	0x972C: 0xF37C,
	0x972D: 0x8D60,
	0x972E: 0xF548,
	0x972F: 0xF549,
	0x9730: 0xC4C5,
	0x9731: 0xFDC9,
	0x9732: 0xC553,
	0x9733: 0x977A,
	0x9734: 0x9DBB,
	0x9735: 0xF66E,
	0x9736: 0x9EE5,
	0x9737: 0xFFFD,
	0x9738: 0xC551,
	0x9739: 0xC552,
	0x973A: 0xF66F,
	0x973B: 0x977B,
	0x973C: 0xFFFD,
	0x973D: 0xC5B4,
	0x973E: 0xC5B5,
	0x973F: 0xF771,
	0x9740: 0x9EE6,
	0x9741: 0x9EE7,
	0x9742: 0xC645,
	0x9743: 0xF8CF,
	0x9744: 0xC647,
	0x9745: 0xFFFD,
	0x9746: 0xF8CE,
	0x9747: 0xF8D0,
	0x9748: 0xC646,
	0x9749: 0xF957,
	0x974A: 0xFFFD,
	0x974B: 0xF9AD,
	0x974C: 0xFFFD,
	0x974D: 0x977C,
	0x974E: 0xFFFD,
	0x974F: 0x977D,
	0x9750: 0xFFFD,
	0x9751: 0x977E,
	0x9752: 0xAB43,
	0x9753: 0x8EDB,
	0x9754: 0xFFFD,
	0x9755: 0x97A1,
	0x9756: 0xB974,
	0x9757: 0x9EE8,
	0x9758: 0xE4BE,
	0x9759: 0x9343,
	0x975A: 0xE8B0,
	0x975B: 0xC051,
	0x975C: 0xC052,
	0x975D: 0xFE6D,
	0x975E: 0xAB44,
	0x975F: 0xFDCA,
	0x9760: 0xBE61,
	0x9761: 0xC3FB,
	0x9762: 0xADB1,
	0x9763: 0xFFFD,
	0x9764: 0x97A2,
	0x9765: 0x8D45,
	0x9766: 0xC053,
	0x9767: 0xFFFD,
	0x9768: 0xC5E2,
	0x9769: 0xADB2,
	0x976A: 0xD84D,
	0x976B: 0x97A3,
	0x976C: 0xDCA9,
	0x976D: 0x95F7,
	0x976E: 0xDCAB,
	0x976F: 0xFFFD,
	0x9770: 0xDCAA,
	0x9771: 0x97A4,
	0x9772: 0xE0DD,
	0x9773: 0xE0DA,
	0x9774: 0xB975,
	0x9775: 0xFFFD,
	0x9776: 0xB976,
	0x9777: 0xE0DB,
	0x9778: 0xE0DC,
	0x9779: 0x94DF,
	0x977A: 0xE4C0,
	0x977B: 0xE4C5,
	0x977C: 0xBBDE,
	0x977D: 0xE4BF,
	0x977E: 0xE4C1,
	0x977F: 0xE4C8,
	0x9780: 0xE4C3,
	0x9781: 0xE4C7,
	0x9782: 0xE4C4,
	0x9783: 0xE4C2,
	0x9784: 0xE4C6,
	0x9785: 0xBBDF,
	0x9786: 0x94E0,
	0x9787: 0x9EE9,
	0x9788: 0xE8B3,
	0x9789: 0x9EEA,
	0x978A: 0xE8B1,
	0x978B: 0xBE63,
	0x978C: 0xFFFD,
	0x978D: 0xBE62,
	0x978E: 0xE8B2,
	0x978F: 0xBE64,
	0x9790: 0x94E1,
	0x9791: 0x8CE7,
	0x9792: 0x97A5,
	0x9793: 0xFFFD,
	0x9794: 0xEC56,
	0x9795: 0xFFFD,
	0x9796: 0xFFFD,
	0x9797: 0xEC55,
	0x9798: 0xC054,
	0x9799: 0xEC54,
	0x979A: 0xEEFC,
	0x979B: 0x9EEB,
	0x979C: 0xEEFE,
	0x979D: 0xEF41,
	0x979E: 0xEF40,
	0x979F: 0xFDCB,
	0x97A0: 0xC1F9,
	0x97A1: 0xEEFD,
	0x97A2: 0xF1A1,
	0x97A3: 0xC2FD,
	0x97A4: 0xF17D,
	0x97A5: 0xF1A2,
	0x97A6: 0xC2FE,
	0x97A7: 0xFFFD,
	0x97A8: 0xF17B,
	0x97A9: 0xFFFD,
	0x97AA: 0xF17E,
	0x97AB: 0xF17C,
	0x97AC: 0xF179,
	0x97AD: 0xC340,
	0x97AE: 0xF17A,
	0x97AF: 0x8D7E,
	0x97B0: 0xFFFD,
	0x97B1: 0x9EEC,
	0x97B2: 0x97A6,
	0x97B3: 0xF3A1,
	0x97B4: 0xFDCC,
	0x97B5: 0xFFFD,
	0x97B6: 0xF3A3,
	0x97B7: 0xF3A2,
	0x97B8: 0xFDCD,
	0x97B9: 0xF54A,
	0x97BA: 0xFDCE,
	0x97BB: 0xF54B,
	0x97BC: 0xFFFD,
	0x97BD: 0x9EED,
	0x97BE: 0xFDCF,
	0x97BF: 0xF670,
	0x97C0: 0x9EEE,
	0x97C1: 0xC5B7,
	0x97C2: 0x9EEF,
	0x97C3: 0xC5B6,
	0x97C4: 0xF84F,
	0x97C5: 0xF850,
	0x97C6: 0xC648,
	0x97C7: 0xF8D1,
	0x97C8: 0xFDD0,
	0x97C9: 0xC669,
	0x97CA: 0xFFFD,
	0x97CB: 0xADB3,
	0x97CC: 0xB6B4,
	0x97CD: 0xE4CA,
	0x97CE: 0xE4C9,
	0x97CF: 0xE8B5,
	0x97D0: 0xE8B4,
	0x97D1: 0xFFFD,
	0x97D2: 0x9EF0,
	0x97D3: 0xC1FA,
	0x97D4: 0xEF43,
	0x97D5: 0xEF42,
	0x97D6: 0xF1A5,
	0x97D7: 0xF1A3,
	0x97D8: 0xF1A6,
	0x97D9: 0xF1A4,
	0x97DA: 0xFFFD,
	0x97DB: 0xFFFD,
	0x97DC: 0xC3FC,
	0x97DD: 0xF3A4,
	0x97DE: 0xF3A5,
	0x97DF: 0xF3A6,
	0x97E0: 0x9EF1,
	0x97E1: 0xF671,
	0x97E2: 0xFFFD,
	0x97E3: 0xF772,
	0x97E4: 0xFFFD,
	0x97E5: 0xF8D2,
	0x97E6: 0x83A3,
	0x97E7: 0x85A4,
	0x97E8: 0xFFFD,
	0x97E9: 0x8AB0,
	0x97EA: 0x8FAB,
	0x97EB: 0x8FCE,
	0x97EC: 0x8BDB,
	0x97ED: 0xADB4,
	0x97EE: 0x9561,
	0x97EF: 0xFFFD,
	0x97F0: 0xEC57,
	0x97F1: 0xEF44,
	0x97F2: 0x97A7,
	0x97F3: 0xADB5,
	0x97F4: 0xFFFD,
	0x97F5: 0x8BDC,
	0x97F6: 0xBBE0,
	0x97F7: 0xFFFD,
	0x97F8: 0xEC58,
	0x97F9: 0xC341,
	0x97FA: 0xF1A7,
	0x97FB: 0xC3FD,
	0x97FC: 0xFFFD,
	0x97FD: 0xF54C,
	0x97FE: 0xF54D,
	0x97FF: 0xC554,
	0x9800: 0xF851,
	0x9801: 0xADB6,
	0x9802: 0xB3BB,
	0x9803: 0xB3BC,
	0x9804: 0xD84E,
	0x9805: 0xB6B5,
	0x9806: 0xB6B6,
	0x9807: 0xDCAC,
	0x9808: 0xB6B7,
	0x9809: 0xFFFD,
	0x980A: 0xB97A,
	0x980B: 0xFFFD,
	0x980C: 0xB97C,
	0x980D: 0xE0DF,
	0x980E: 0xE0E0,
	0x980F: 0xE0DE,
	0x9810: 0xB977,
	0x9811: 0xB978,
	0x9812: 0xB97B,
	0x9813: 0xB979,
	0x9814: 0x9EF2,
	0x9815: 0x9EF3,
	0x9816: 0xE4CB,
	0x9817: 0xBBE1,
	0x9818: 0xBBE2,
	0x9819: 0xFFFD,
	0x981A: 0x825B,
	0x981B: 0xE8BC,
	0x981C: 0xBE67,
	0x981D: 0xE8B7,
	0x981E: 0xE8B6,
	0x981F: 0xFDD2,
	0x9820: 0xE8BB,
	0x9821: 0xBE65,
	0x9822: 0xFFFD,
	0x9823: 0x9EF4,
	0x9824: 0xC05B,
	0x9825: 0xFFFD,
	0x9826: 0xE8B8,
	0x9827: 0xE8BD,
	0x9828: 0xE8BA,
	0x9829: 0xE8B9,
	0x982A: 0xFFFD,
	0x982B: 0xBE66,
	0x982C: 0x827B,
	0x982D: 0xC059,
	0x982E: 0xFDD3,
	0x982F: 0xEC5A,
	0x9830: 0xC055,
	0x9831: 0xFFFD,
	0x9832: 0xEC5B,
	0x9833: 0x9EF5,
	0x9834: 0x8242,
	0x9835: 0xEC59,
	0x9836: 0xFFFD,
	0x9837: 0xC058,
	0x9838: 0xC056,
	0x9839: 0xC05A,
	0x983A: 0xFFFD,
	0x983B: 0xC057,
	0x983C: 0x93DF,
	0x983D: 0x97A8,
	0x983E: 0xFFFD,
	0x983F: 0xFFFD,
	0x9840: 0xFFFD,
	0x9841: 0xEF45,
	0x9842: 0xFFFD,
	0x9843: 0xEF4A,
	0x9844: 0xEF46,
	0x9845: 0xEF49,
	0x9846: 0xC1FB,
	0x9847: 0xFDD5,
	0x9848: 0xEDD4,
	0x9849: 0xEF48,
	0x984A: 0xEF47,
	0x984B: 0xFDD6,
	0x984C: 0xC344,
	0x984D: 0xC342,
	0x984E: 0xC345,
	0x984F: 0xC343,
	0x9850: 0xF1A8,
	0x9851: 0xF1A9,
	0x9852: 0xF1AA,
	0x9853: 0xC346,
	0x9854: 0x97A9,
	0x9855: 0x92B8,
	0x9856: 0x9DD2,
	0x9857: 0xF3AA,
	0x9858: 0xC440,
	0x9859: 0xF3A8,
	0x985A: 0xFFFD,
	0x985B: 0xC441,
	0x985C: 0xF3A7,
	0x985D: 0xF3A9,
	0x985E: 0xC3FE,
	0x985F: 0xF551,
	0x9860: 0xF54E,
	0x9861: 0xFFFD,
	0x9862: 0xF54F,
	0x9863: 0xF550,
	0x9864: 0xF672,
	0x9865: 0xC556,
	0x9866: 0xFDD7,
	0x9867: 0xC555,
	0x9868: 0x9EF6,
	0x9869: 0xF774,
	0x986A: 0xF773,
	0x986B: 0xC5B8,
	0x986C: 0xFDD8,
	0x986D: 0xFFFD,
	0x986E: 0xFFFD,
	0x986F: 0xC5E3,
	0x9870: 0xC649,
	0x9871: 0xC660,
	0x9872: 0xF958,
	0x9873: 0xF9AE,
	0x9874: 0xF9AF,
	0x9875: 0x83A4,
	0x9876: 0x84BC,
	0x9877: 0x84BD,
	0x9878: 0x8DFA,
	0x9879: 0x85A5,
	0x987A: 0x85A6,
	0x987B: 0x85A7,
	0x987C: 0x867E,
	0x987D: 0x867C,
	0x987E: 0x8CB8,
	0x987F: 0x867D,
	0x9880: 0x8E62,
	0x9881: 0x86A1,
	0x9882: 0x86A2,
	0x9883: 0x8E61,
	0x9884: 0x867B,
	0x9885: 0x8D77,
	0x9886: 0x8774,
	0x9887: 0x8773,
	0x9888: 0x89B0,
	0x9889: 0x88B3,
	0x988A: 0x89AF,
	0x988B: 0xFFFD,
	0x988C: 0x88B4,
	0x988D: 0x8EBA,
	0x988E: 0xFFFD,
	0x988F: 0x8EDC,
	0x9890: 0x89B5,
	0x9891: 0x89B1,
	0x9892: 0xFFFD,
	0x9893: 0x89B4,
	0x9894: 0x89B2,
	0x9895: 0xFFFD,
	0x9896: 0x8946,
	0x9897: 0x8AB1,
	0x9898: 0x8B5F,
	0x9899: 0xFFFD,
	0x989A: 0x8B60,
	0x989B: 0x8B61,
	0x989C: 0x8B5E,
	0x989D: 0x8B5D,
	0x989E: 0x90A7,
	0x989F: 0x8FF0,
	0x98A0: 0x8BDE,
	0x98A1: 0x8FCF,
	0x98A2: 0x8CB9,
	0x98A3: 0xFFFD,
	0x98A4: 0x8CE9,
	0x98A5: 0x97AA,
	0x98A6: 0x8D61,
	0x98A7: 0x90A8,
	0x98A8: 0xADB7,
	0x98A9: 0xDCAD,
	0x98AA: 0x94E2,
	0x98AB: 0xFFFD,
	0x98AC: 0xE0E1,
	0x98AD: 0xE4CC,
	0x98AE: 0xE4CD,
	0x98AF: 0xBBE3,
	0x98B0: 0xFFFD,
	0x98B1: 0xBBE4,
	0x98B2: 0xE8BE,
	0x98B3: 0xBE68,
	0x98B4: 0xFDD9,
	0x98B5: 0xFFFD,
	0x98B6: 0xC1FC,
	0x98B7: 0x9EF7,
	0x98B8: 0xF1AB,
	0x98B9: 0x9EF8,
	0x98BA: 0xC347,
	0x98BB: 0xF3AD,
	0x98BC: 0xC442,
	0x98BD: 0xF3AC,
	0x98BE: 0xF3AE,
	0x98BF: 0xF3AB,
	0x98C0: 0xF675,
	0x98C1: 0xF552,
	0x98C2: 0xF553,
	0x98C3: 0x97AB,
	0x98C4: 0xC4C6,
	0x98C5: 0xFFFD,
	0x98C6: 0xF674,
	0x98C7: 0x9EF9,
	0x98C8: 0xFBB2,
	0x98C9: 0xF673,
	0x98CA: 0x9EFA,
	0x98CB: 0xF775,
	0x98CC: 0xF9B0,
	0x98CD: 0xFFFD,
	0x98CE: 0x83A5,
	0x98CF: 0xFFFD,
	0x98D0: 0xFFFD,
	0x98D1: 0x8EAE,
	0x98D2: 0x8775,
	0x98D3: 0x8AB2,
	0x98D4: 0xFFFD,
	0x98D5: 0x8BDF,
	0x98D6: 0xFFFD,
	0x98D7: 0xFFFD,
	0x98D8: 0x8C61,
	0x98D9: 0x904A,
	0x98DA: 0x97AC,
	0x98DB: 0xADB8,
	0x98DC: 0xFDDB,
	0x98DD: 0xFFFD,
	0x98DE: 0x83A6,
	0x98DF: 0xADB9,
	0x98E0: 0x9EFB,
	0x98E1: 0x9EFC,
	0x98E2: 0xB0A7,
	0x98E3: 0xD448,
	0x98E4: 0xFFFD,
	0x98E5: 0xD84F,
	0x98E6: 0xFDDC,
	0x98E7: 0xB6B8,
	0x98E8: 0x8CBA,
	0x98E9: 0xB6BB,
	0x98EA: 0xB6B9,
	0x98EB: 0xDCAE,
	0x98EC: 0x9EFD,
	0x98ED: 0xB6BD,
	0x98EE: 0x97AD,
	0x98EF: 0xB6BA,
	0x98F0: 0xFFFD,
	0x98F1: 0x95DA,
	0x98F2: 0xB6BC,
	0x98F3: 0xFFFD,
	0x98F4: 0xB97E,
	0x98F5: 0x9EFE,
	0x98F6: 0xE0E2,
	0x98F7: 0xFFFD,
	0x98F8: 0xFFFD,
	0x98F9: 0xE0E3,
	0x98FA: 0xE8C0,
	0x98FB: 0xFFFD,
	0x98FC: 0xB97D,
	0x98FD: 0xB9A1,
	0x98FE: 0xB9A2,
	0x98FF: 0xFFFD,
	0x9900: 0xE4CF,
	0x9901: 0xFFFD,
	0x9902: 0xE4CE,
	0x9903: 0xBBE5,
	0x9904: 0xFFFD,
	0x9905: 0xBBE6,
	0x9906: 0xFFFD,
	0x9907: 0xE4D0,
	0x9908: 0xE8BF,
	0x9909: 0xBBE8,
	0x990A: 0xBE69,
	0x990B: 0xFFFD,
	0x990C: 0xBBE7,
	0x990D: 0x8D47,
	0x990E: 0x9F70,
	0x990F: 0xFFFD,
	0x9910: 0xC05C,
	0x9911: 0xE8C1,
	0x9912: 0xBE6B,
	0x9913: 0xBE6A,
	0x9914: 0xE8C2,
	0x9915: 0xE8C5,
	0x9916: 0xE8C3,
	0x9917: 0xE8C4,
	0x9918: 0xBE6C,
	0x9919: 0x9F71,
	0x991A: 0xC061,
	0x991B: 0xC05F,
	0x991C: 0x9F72,
	0x991D: 0x97AE,
	0x991E: 0xC05E,
	0x991F: 0xEC5D,
	0x9920: 0x97AF,
	0x9921: 0xC060,
	0x9922: 0xFFFD,
	0x9923: 0xFFFD,
	0x9924: 0xEC5C,
	0x9925: 0xEF4B,
	0x9926: 0xFFFD,
	0x9927: 0xEC5E,
	0x9928: 0xC05D,
	0x9929: 0xEC5F,
	0x992A: 0xEF4E,
	0x992B: 0xEF4C,
	0x992C: 0xEF4D,
	0x992D: 0xEF52,
	0x992E: 0xC34B,
	0x992F: 0xEF51,
	0x9930: 0xEF54,
	0x9931: 0xEF53,
	0x9932: 0xEF50,
	0x9933: 0xEF4F,
	0x9934: 0xFFFD,
	0x9935: 0xC1FD,
	0x9936: 0xFFFD,
	0x9937: 0x9F73,
	0x9938: 0xA044,
	0x9939: 0xFDDE,
	0x993A: 0xF1AE,
	0x993B: 0xFDDF,
	0x993C: 0xF1AD,
	0x993D: 0xC34A,
	0x993E: 0xC348,
	0x993F: 0xC349,
	0x9940: 0xFBB3,
	0x9941: 0xF1AC,
	0x9942: 0xFDDD,
	0x9943: 0xF3B1,
	0x9944: 0xFFFD,
	0x9945: 0xC443,
	0x9946: 0xFFFD,
	0x9947: 0xF3B0,
	0x9948: 0xF3AF,
	0x9949: 0xC444,
	0x994A: 0xFDE1,
	0x994B: 0xF558,
	0x994C: 0xF557,
	0x994D: 0xFBB4,
	0x994E: 0xF555,
	0x994F: 0xFFFD,
	0x9950: 0xF554,
	0x9951: 0xC4C8,
	0x9952: 0xC4C7,
	0x9953: 0xF559,
	0x9954: 0xF776,
	0x9955: 0xC5B9,
	0x9956: 0xF677,
	0x9957: 0xC557,
	0x9958: 0xF676,
	0x9959: 0xF556,
	0x995A: 0xFFFD,
	0x995B: 0xF777,
	0x995C: 0xC5E4,
	0x995D: 0x9F74,
	0x995E: 0xC661,
	0x995F: 0xF959,
	0x9960: 0xFFFD,
	0x9961: 0xF9B1,
	0x9962: 0x9F75,
	0x9963: 0x97B0,
	0x9964: 0xFFFD,
	0x9965: 0x83E8,
	0x9966: 0xFFFD,
	0x9967: 0x8F6D,
	0x9968: 0x85AA,
	0x9969: 0x8FAC,
	0x996A: 0x85A8,
	0x996B: 0x8DFB,
	0x996C: 0x85AC,
	0x996D: 0x85A9,
	0x996E: 0x85AB,
	0x996F: 0x89B7,
	0x9970: 0x86A6,
	0x9971: 0x86A5,
	0x9972: 0x86A3,
	0x9973: 0xFFFD,
	0x9974: 0x86A4,
	0x9975: 0x8778,
	0x9976: 0x8C62,
	0x9977: 0x8779,
	0x9978: 0xFFFD,
	0x9979: 0xFFFD,
	0x997A: 0x8776,
	0x997B: 0xFFFD,
	0x997C: 0x8777,
	0x997D: 0x8EDD,
	0x997E: 0xFFFD,
	0x997F: 0x88B6,
	0x9980: 0x97B1,
	0x9981: 0x88B7,
	0x9982: 0xFFFD,
	0x9983: 0xFFFD,
	0x9984: 0x89B8,
	0x9985: 0x89B9,
	0x9986: 0x89B6,
	0x9987: 0x97B2,
	0x9988: 0x8B64,
	0x9989: 0xFFFD,
	0x998A: 0x8B63,
	0x998B: 0x8D78,
	0x998C: 0xFFFD,
	0x998D: 0x97B3,
	0x998E: 0xFFFD,
	0x998F: 0x8B62,
	0x9990: 0x8FD0,
	0x9991: 0x8BE1,
	0x9992: 0x8BE0,
	0x9993: 0x97B4,
	0x9994: 0x8FF1,
	0x9995: 0x97B5,
	0x9996: 0xADBA,
	0x9997: 0xD850,
	0x9998: 0xEF55,
	0x9999: 0xADBB,
	0x999A: 0xFFFD,
	0x999B: 0x9F76,
	0x999C: 0xE4D2,
	0x999D: 0xE4D1,
	0x999E: 0xEC60,
	0x999F: 0xFFFD,
	0x99A0: 0xFFFD,
	0x99A1: 0xEF57,
	0x99A2: 0xFFFD,
	0x99A3: 0xEF56,
	0x99A4: 0x9F77,
	0x99A5: 0xC34C,
	0x99A6: 0xF3B2,
	0x99A7: 0xF3B3,
	0x99A8: 0xC4C9,
	0x99A9: 0xFFFD,
	0x99AA: 0x9F78,
	0x99AB: 0xF9B2,
	0x99AC: 0xB0A8,
	0x99AD: 0xB6BF,
	0x99AE: 0xB6BE,
	0x99AF: 0xE0E4,
	0x99B0: 0xE0E6,
	0x99B1: 0xB9A4,
	0x99B2: 0xE0E5,
	0x99B3: 0xB9A3,
	0x99B4: 0xB9A5,
	0x99B5: 0xE0E7,
	0x99B6: 0xFFFD,
	0x99B7: 0xFFFD,
	0x99B8: 0x9F79,
	0x99B9: 0xE4D4,
	0x99BA: 0xE4D6,
	0x99BB: 0xE4D5,
	0x99BC: 0x97B6,
	0x99BD: 0xE4D8,
	0x99BE: 0xFFFD,
	0x99BF: 0xFFFD,
	0x99C0: 0xFFFD,
	0x99C1: 0xBBE9,
	0x99C2: 0xE4D7,
	0x99C3: 0xE4D3,
	0x99C4: 0x944B,
	0x99C5: 0x924A,
	0x99C6: 0x92A3,
	0x99C7: 0xE4D9,
	0x99C8: 0x97B7,
	0x99C9: 0xE8CC,
	0x99CA: 0xFFFD,
	0x99CB: 0xE8CF,
	0x99CC: 0xE8D1,
	0x99CD: 0xE8C7,
	0x99CE: 0xE8CB,
	0x99CF: 0xE8C8,
	0x99D0: 0xBE6E,
	0x99D1: 0xBE71,
	0x99D2: 0xBE73,
	0x99D3: 0xE8C9,
	0x99D4: 0xE8CA,
	0x99D5: 0xBE72,
	0x99D6: 0xE8CD,
	0x99D7: 0xE8D0,
	0x99D8: 0xE8CE,
	0x99D9: 0xBE74,
	0x99DA: 0xFDE4,
	0x99DB: 0xBE70,
	0x99DC: 0xE8C6,
	0x99DD: 0xBE6D,
	0x99DE: 0xFFFD,
	0x99DF: 0xBE6F,
	0x99E0: 0x9F7A,
	0x99E1: 0x95C4,
	0x99E2: 0xC063,
	0x99E3: 0xEC66,
	0x99E4: 0xEC64,
	0x99E5: 0xEC63,
	0x99E6: 0x9F7B,
	0x99E7: 0xEC69,
	0x99E8: 0xFFFD,
	0x99E9: 0xEC68,
	0x99EA: 0xEC67,
	0x99EB: 0xFFFD,
	0x99EC: 0xEC62,
	0x99ED: 0xC062,
	0x99EE: 0xEC61,
	0x99EF: 0xFFFD,
	0x99F0: 0xEC65,
	0x99F1: 0xC064,
	0x99F2: 0x97B8,
	0x99F3: 0xFFFD,
	0x99F4: 0xEF5A,
	0x99F5: 0x9F7C,
	0x99F6: 0xEF5E,
	0x99F7: 0xEF5B,
	0x99F8: 0xEF5D,
	0x99F9: 0xEF5C,
	0x99FA: 0xEF59,
	0x99FB: 0xEF5F,
	0x99FC: 0xEF62,
	0x99FD: 0xEF60,
	0x99FE: 0xEF61,
	0x99FF: 0xC240,
	0x9A00: 0xFFFD,
	0x9A01: 0xC1FE,
	0x9A02: 0xEF58,
	0x9A03: 0xEF63,
	0x9A04: 0xF1B3,
	0x9A05: 0xF1B6,
	0x9A06: 0xF1B8,
	0x9A07: 0xF1B7,
	0x9A08: 0xFFFD,
	0x9A09: 0xF1B1,
	0x9A0A: 0xF1B5,
	0x9A0B: 0xF1B0,
	0x9A0C: 0xFBB5,
	0x9A0D: 0xF1B2,
	0x9A0E: 0xC34D,
	0x9A0F: 0xF1AF,
	0x9A10: 0x95E1,
	0x9A11: 0xF1B4,
	0x9A12: 0x935D,
	0x9A13: 0x92B9,
	0x9A14: 0xF3C0,
	0x9A15: 0xF3B5,
	0x9A16: 0xC445,
	0x9A17: 0xFFFD,
	0x9A18: 0xFFFD,
	0x9A19: 0xC446,
	0x9A1A: 0xF3B4,
	0x9A1B: 0xF3B9,
	0x9A1C: 0xF3BF,
	0x9A1D: 0xF3B7,
	0x9A1E: 0xF3BE,
	0x9A1F: 0x9F7D,
	0x9A20: 0xF3BB,
	0x9A21: 0x9AFB,
	0x9A22: 0xF3BA,
	0x9A23: 0xF3BD,
	0x9A24: 0xF3B8,
	0x9A25: 0xF3B6,
	0x9A26: 0x9AFC,
	0x9A27: 0xF3BC,
	0x9A28: 0x8255,
	0x9A29: 0xF560,
	0x9A2A: 0xF55E,
	0x9A2B: 0xC4CA,
	0x9A2C: 0xF55D,
	0x9A2D: 0xF563,
	0x9A2E: 0xF561,
	0x9A2F: 0x9AFD,
	0x9A30: 0xC4CB,
	0x9A31: 0xF55C,
	0x9A32: 0xF55A,
	0x9A33: 0xFFFD,
	0x9A34: 0xF55B,
	0x9A35: 0xC4CD,
	0x9A36: 0xF55F,
	0x9A37: 0xC4CC,
	0x9A38: 0xF562,
	0x9A39: 0xF678,
	0x9A3A: 0xF67E,
	0x9A3B: 0x9CFA,
	0x9A3C: 0x9CFB,
	0x9A3D: 0xF679,
	0x9A3E: 0xC55B,
	0x9A3F: 0xF6A1,
	0x9A40: 0xC55A,
	0x9A41: 0xF67D,
	0x9A42: 0xF67C,
	0x9A43: 0xC559,
	0x9A44: 0xF67B,
	0x9A45: 0xC558,
	0x9A46: 0xF67A,
	0x9A47: 0xFFFD,
	0x9A48: 0xF77D,
	0x9A49: 0xF7A1,
	0x9A4A: 0xF77E,
	0x9A4B: 0xFFFD,
	0x9A4C: 0xF77B,
	0x9A4D: 0xC5BB,
	0x9A4E: 0xF778,
	0x9A4F: 0xF77C,
	0x9A50: 0xF7A3,
	0x9A51: 0xFFFD,
	0x9A52: 0xF7A2,
	0x9A53: 0xF779,
	0x9A54: 0xF77A,
	0x9A55: 0xC5BA,
	0x9A56: 0xF852,
	0x9A57: 0xC5E7,
	0x9A58: 0x9CFC,
	0x9A59: 0xF853,
	0x9A5A: 0xC5E5,
	0x9A5B: 0xC5E6,
	0x9A5C: 0x9CFD,
	0x9A5D: 0xFFFD,
	0x9A5E: 0xF8D3,
	0x9A5F: 0xC64A,
	0x9A60: 0xF976,
	0x9A61: 0xFFFD,
	0x9A62: 0xC66A,
	0x9A63: 0x9CFE,
	0x9A64: 0xF9B3,
	0x9A65: 0xC66B,
	0x9A66: 0xF9B4,
	0x9A67: 0xF9B5,
	0x9A68: 0xF9C3,
	0x9A69: 0xF9C2,
	0x9A6A: 0xC67A,
	0x9A6B: 0xF9CD,
	0x9A6C: 0x83E9,
	0x9A6D: 0x85AE,
	0x9A6E: 0x86A8,
	0x9A6F: 0x86A9,
	0x9A70: 0x86A7,
	0x9A71: 0x8CBB,
	0x9A72: 0xFFFD,
	0x9A73: 0x877A,
	0x9A74: 0x8DA1,
	0x9A75: 0x8EDE,
	0x9A76: 0x88BB,
	0x9A77: 0x88BA,
	0x9A78: 0x88BF,
	0x9A79: 0x88BE,
	0x9A7A: 0x8FF2,
	0x9A7B: 0x88B9,
	0x9A7C: 0x88B8,
	0x9A7D: 0x88BC,
	0x9A7E: 0x88BD,
	0x9A7F: 0x8D49,
	0x9A80: 0x8EDF,
	0x9A81: 0x8CEB,
	0x9A82: 0x884C,
	0x9A83: 0xFFFD,
	0x9A84: 0x8CEA,
	0x9A85: 0x9063,
	0x9A86: 0x89BC,
	0x9A87: 0x89BA,
	0x9A88: 0x89BB,
	0x9A89: 0xFFFD,
	0x9A8A: 0x8DAF,
	0x9A8B: 0x8AB3,
	0x9A8C: 0x8D4A,
	0x9A8D: 0xFFFD,
	0x9A8E: 0xFFFD,
	0x9A8F: 0x8AB4,
	0x9A90: 0x8FAD,
	0x9A91: 0x8B65,
	0x9A92: 0x8FAE,
	0x9A93: 0x8FAF,
	0x9A94: 0xFFFD,
	0x9A95: 0xFFFD,
	0x9A96: 0x904C,
	0x9A97: 0x8BE3,
	0x9A98: 0x8FF5,
	0x9A99: 0xFFFD,
	0x9A9A: 0x8C66,
	0x9A9B: 0x8BE2,
	0x9A9C: 0x904D,
	0x9A9D: 0x8FF3,
	0x9A9E: 0x8C64,
	0x9A9F: 0x8FF4,
	0x9AA0: 0x8CBC,
	0x9AA1: 0x8CBE,
	0x9AA2: 0x904B,
	0x9AA3: 0x9062,
	0x9AA4: 0x8D62,
	0x9AA5: 0x8DA2,
	0x9AA6: 0xFFFD,
	0x9AA7: 0x90A9,
	0x9AA8: 0xB0A9,
	0x9AA9: 0xFFFD,
	0x9AAA: 0xFFFD,
	0x9AAB: 0xE0E9,
	0x9AAC: 0xFFFD,
	0x9AAD: 0xE0E8,
	0x9AAE: 0xFFFD,
	0x9AAF: 0xBBEA,
	0x9AB0: 0xBBEB,
	0x9AB1: 0xE4DA,
	0x9AB2: 0x9DB0,
	0x9AB3: 0xE8D2,
	0x9AB4: 0xEC6C,
	0x9AB5: 0xFFFD,
	0x9AB6: 0x97B9,
	0x9AB7: 0xBE75,
	0x9AB8: 0xC065,
	0x9AB9: 0xEC6A,
	0x9ABA: 0xFDE6,
	0x9ABB: 0xEC6D,
	0x9ABC: 0xC066,
	0x9ABD: 0xFDE7,
	0x9ABE: 0xEF64,
	0x9ABF: 0xEC6B,
	0x9AC0: 0xF1B9,
	0x9AC1: 0xC34E,
	0x9AC2: 0xF3C1,
	0x9AC3: 0xFFFD,
	0x9AC4: 0x92FB,
	0x9AC5: 0x8CBF,
	0x9AC6: 0xF566,
	0x9AC7: 0xF564,
	0x9AC8: 0xFFFD,
	0x9AC9: 0xFFFD,
	0x9ACA: 0xF565,
	0x9ACB: 0x8D79,
	0x9ACC: 0x9079,
	0x9ACD: 0xF6A2,
	0x9ACE: 0xFFFD,
	0x9ACF: 0xC55C,
	0x9AD0: 0xF7A4,
	0x9AD1: 0xC5EA,
	0x9AD2: 0xC5BC,
	0x9AD3: 0xC5E8,
	0x9AD4: 0xC5E9,
	0x9AD5: 0xF8D4,
	0x9AD6: 0xC662,
	0x9AD7: 0xFBB6,
	0x9AD8: 0xB0AA,
	0x9AD9: 0x97BA,
	0x9ADA: 0xFFFD,
	0x9ADB: 0xFFFD,
	0x9ADC: 0xF1BA,
	0x9ADD: 0xFFFD,
	0x9ADE: 0x97BB,
	0x9ADF: 0xD449,
	0x9AE0: 0x9DB1,
	0x9AE1: 0xB9A6,
	0x9AE2: 0xFDEC,
	0x9AE3: 0xE4DB,
	0x9AE4: 0xFFFD,
	0x9AE5: 0xFFFD,
	0x9AE6: 0xBBEC,
	0x9AE7: 0xE4DC,
	0x9AE8: 0xFFFD,
	0x9AE9: 0xFFFD,
	0x9AEA: 0x93BA,
	0x9AEB: 0xE8D4,
	0x9AEC: 0xE8D3,
	0x9AED: 0xC068,
	0x9AEE: 0xBE76,
	0x9AEF: 0xBE77,
	0x9AF0: 0xFFFD,
	0x9AF1: 0xE8D7,
	0x9AF2: 0xE8D6,
	0x9AF3: 0xE8D5,
	0x9AF4: 0xFE57,
	0x9AF5: 0xFFFD,
	0x9AF6: 0xEC6E,
	0x9AF7: 0xEC71,
	0x9AF8: 0xFFFD,
	0x9AF9: 0xEC70,
	0x9AFA: 0xEC6F,
	0x9AFB: 0xC067,
	0x9AFC: 0xEF68,
	0x9AFD: 0xEF66,
	0x9AFE: 0xEF65,
	0x9AFF: 0xFDEE,
	0x9B00: 0xFFFD,
	0x9B01: 0xEF67,
	0x9B02: 0xFDED,
	0x9B03: 0xC34F,
	0x9B04: 0xF1BC,
	0x9B05: 0xF1BD,
	0x9B06: 0xC350,
	0x9B07: 0xFFFD,
	0x9B08: 0xF1BB,
	0x9B09: 0xFDF0,
	0x9B0A: 0xF3C3,
	0x9B0B: 0xF3C2,
	0x9B0C: 0xF3C5,
	0x9B0D: 0xC447,
	0x9B0E: 0xF3C4,
	0x9B0F: 0x97BC,
	0x9B10: 0xF567,
	0x9B11: 0xF569,
	0x9B12: 0xF568,
	0x9B13: 0x8D63,
	0x9B14: 0x9DB2,
	0x9B15: 0xF6A3,
	0x9B16: 0xF6A6,
	0x9B17: 0xF6A4,
	0x9B18: 0xF6A5,
	0x9B19: 0xF7A5,
	0x9B1A: 0xC5BD,
	0x9B1B: 0xFFFD,
	0x9B1C: 0xFFFD,
	0x9B1D: 0xFFFD,
	0x9B1E: 0xF854,
	0x9B1F: 0xF855,
	0x9B20: 0xF856,
	0x9B21: 0xFFFD,
	0x9B22: 0xC64B,
	0x9B23: 0xC663,
	0x9B24: 0xF9B6,
	0x9B25: 0xB0AB,
	0x9B26: 0xFFFD,
	0x9B27: 0xBE78,
	0x9B28: 0xC069,
	0x9B29: 0xF1BE,
	0x9B2A: 0xFDE9,
	0x9B2B: 0xF7A6,
	0x9B2C: 0xFFFD,
	0x9B2D: 0xFDEB,
	0x9B2E: 0xF9C4,
	0x9B2F: 0xD44A,
	0x9B30: 0xFFFD,
	0x9B31: 0xC67B,
	0x9B32: 0xB0AC,
	0x9B33: 0xEC72,
	0x9B34: 0x9DB3,
	0x9B35: 0xF1BF,
	0x9B36: 0xFFFD,
	0x9B37: 0xF3C6,
	0x9B38: 0xFFFD,
	0x9B39: 0x9DB4,
	0x9B3A: 0xF6A7,
	0x9B3B: 0xF7A7,
	0x9B3C: 0xB0AD,
	0x9B3D: 0xFFFD,
	0x9B3E: 0xE4DD,
	0x9B3F: 0xE4DE,
	0x9B40: 0x9DB5,
	0x9B41: 0xBBED,
	0x9B42: 0xBBEE,
	0x9B43: 0xE8D9,
	0x9B44: 0xBE7A,
	0x9B45: 0xBE79,
	0x9B46: 0xE8D8,
	0x9B47: 0x8D64,
	0x9B48: 0xEF69,
	0x9B49: 0x97BD,
	0x9B4A: 0xF1C0,
	0x9B4B: 0xF1C2,
	0x9B4C: 0xF1C1,
	0x9B4D: 0xC353,
	0x9B4E: 0xC352,
	0x9B4F: 0xC351,
	0x9B50: 0x9DB6,
	0x9B51: 0xC55E,
	0x9B52: 0xF6A8,
	0x9B53: 0xFFFD,
	0x9B54: 0xC55D,
	0x9B55: 0xF7A9,
	0x9B56: 0xF7A8,
	0x9B57: 0xFFFD,
	0x9B58: 0xC64C,
	0x9B59: 0xF8D5,
	0x9B5A: 0xB3BD,
	0x9B5B: 0xE0EA,
	0x9B5C: 0xFFFD,
	0x9B5D: 0xFFFD,
	0x9B5E: 0xFFFD,
	0x9B5F: 0xE4E1,
	0x9B60: 0xE4DF,
	0x9B61: 0xE4E0,
	0x9B62: 0xFFFD,
	0x9B63: 0xFFFD,
	0x9B64: 0xE8E2,
	0x9B65: 0xFFFD,
	0x9B66: 0xE8DD,
	0x9B67: 0xE8DA,
	0x9B68: 0xE8E1,
	0x9B69: 0xFEAF,
	0x9B6A: 0xFFFD,
	0x9B6B: 0xFFFD,
	0x9B6C: 0xE8E3,
	0x9B6D: 0xFFFD,
	0x9B6E: 0xFFFD,
	0x9B6F: 0xBE7C,
	0x9B70: 0xE8E0,
	0x9B71: 0xE8DC,
	0x9B72: 0x97BE,
	0x9B73: 0xFFFD,
	0x9B74: 0xE8DB,
	0x9B75: 0xE8DF,
	0x9B76: 0xE8DE,
	0x9B77: 0xBE7B,
	0x9B78: 0xFFFD,
	0x9B79: 0xFFFD,
	0x9B7A: 0xEC7D,
	0x9B7B: 0xEC78,
	0x9B7C: 0xEC76,
	0x9B7D: 0xECA1,
	0x9B7E: 0xEC77,
	0x9B7F: 0x9DB7,
	0x9B80: 0xEC73,
	0x9B81: 0x9DEE,
	0x9B82: 0xEC79,
	0x9B83: 0x97BF,
	0x9B84: 0xFFFD,
	0x9B85: 0xEC74,
	0x9B86: 0xEF72,
	0x9B87: 0xEC75,
	0x9B88: 0xECA2,
	0x9B89: 0xFFFD,
	0x9B8A: 0xFFFD,
	0x9B8B: 0x9DEF,
	0x9B8C: 0xFFFD,
	0x9B8D: 0x9DF0,
	0x9B8E: 0x94FE,
	0x9B8F: 0xFDF3,
	0x9B90: 0xEC7C,
	0x9B91: 0xC06A,
	0x9B92: 0xEC7B,
	0x9B93: 0xEC7A,
	0x9B94: 0xFFFD,
	0x9B95: 0xEC7E,
	0x9B96: 0x94E3,
	0x9B97: 0x94E4,
	0x9B98: 0xFFFD,
	0x9B99: 0xFFFD,
	0x9B9A: 0xEF6A,
	0x9B9B: 0xEF6D,
	0x9B9C: 0xFFFD,
	0x9B9D: 0xFDF4,
	0x9B9E: 0xEF6C,
	0x9B9F: 0x97C0,
	0x9BA0: 0xEF74,
	0x9BA1: 0xEF6F,
	0x9BA2: 0xEF73,
	0x9BA3: 0xFFFD,
	0x9BA4: 0xEF71,
	0x9BA5: 0xEF70,
	0x9BA6: 0xEF6E,
	0x9BA7: 0xFFFD,
	0x9BA8: 0xEF6B,
	0x9BA9: 0xFFFD,
	0x9BAA: 0xC243,
	0x9BAB: 0xC242,
	0x9BAC: 0xFFFD,
	0x9BAD: 0xC244,
	0x9BAE: 0xC241,
	0x9BAF: 0xEF75,
	0x9BB0: 0xFDF5,
	0x9BB1: 0x94F5,
	0x9BB2: 0xFFFD,
	0x9BB3: 0xFFFD,
	0x9BB4: 0x94E5,
	0x9BB5: 0xF1C8,
	0x9BB6: 0xF1CB,
	0x9BB7: 0xFFFD,
	0x9BB8: 0xF1C9,
	0x9BB9: 0xF1CD,
	0x9BBA: 0xFFFD,
	0x9BBB: 0x97C1,
	0x9BBC: 0xFFFD,
	0x9BBD: 0xF1CE,
	0x9BBE: 0xFFFD,
	0x9BBF: 0xF1C6,
	0x9BC0: 0xC358,
	0x9BC1: 0xF1C7,
	0x9BC2: 0xFFFD,
	0x9BC3: 0xF1C5,
	0x9BC4: 0xF1CC,
	0x9BC5: 0xFFFD,
	0x9BC6: 0xF1C4,
	0x9BC7: 0xF1C3,
	0x9BC8: 0xC357,
	0x9BC9: 0xC355,
	0x9BCA: 0xC354,
	0x9BCB: 0xFFFD,
	0x9BCC: 0xFFFD,
	0x9BCD: 0xFFFD,
	0x9BCE: 0xFFFD,
	0x9BCF: 0x94E6,
	0x9BD0: 0xFFFD,
	0x9BD1: 0x94E7,
	0x9BD2: 0x94E8,
	0x9BD3: 0xF1CA,
	0x9BD4: 0xF3CF,
	0x9BD5: 0xF3D5,
	0x9BD6: 0xC44A,
	0x9BD7: 0xF3D0,
	0x9BD8: 0xFFFD,
	0x9BD9: 0xF3D3,
	0x9BDA: 0xF3D7,
	0x9BDB: 0xC44B,
	0x9BDC: 0xF3D2,
	0x9BDD: 0x9DF1,
	0x9BDE: 0xF3CA,
	0x9BDF: 0xFFFD,
	0x9BE0: 0xF3C9,
	0x9BE1: 0xF3D6,
	0x9BE2: 0xF3CD,
	0x9BE3: 0x97C2,
	0x9BE4: 0xF3CB,
	0x9BE5: 0xF3D4,
	0x9BE6: 0xF3CC,
	0x9BE7: 0xC449,
	0x9BE8: 0xC448,
	0x9BE9: 0x9DF2,
	0x9BEA: 0xF3C7,
	0x9BEB: 0xF3C8,
	0x9BEC: 0xF3D1,
	0x9BED: 0x9DF3,
	0x9BEE: 0xFFFD,
	0x9BEF: 0xFFFD,
	0x9BF0: 0xF3CE,
	0x9BF1: 0x94EA,
	0x9BF2: 0x94E9,
	0x9BF3: 0xFFFD,
	0x9BF4: 0x9DF4,
	0x9BF5: 0x97C3,
	0x9BF6: 0xFFFD,
	0x9BF7: 0xF56C,
	0x9BF8: 0xF56F,
	0x9BF9: 0xFFFD,
	0x9BFA: 0xFFFD,
	0x9BFB: 0xFFFD,
	0x9BFC: 0xFFFD,
	0x9BFD: 0xC356,
	0x9BFE: 0xFFFD,
	0x9BFF: 0xFDF9,
	0x9C00: 0x97C4,
	0x9C01: 0xFFFD,
	0x9C02: 0xFE50,
	0x9C03: 0xFFFD,
	0x9C04: 0x97C5,
	0x9C05: 0xF56D,
	0x9C06: 0xF573,
	0x9C07: 0xF571,
	0x9C08: 0xF56B,
	0x9C09: 0xF576,
	0x9C0A: 0xFDF8,
	0x9C0B: 0xF56A,
	0x9C0C: 0xFDF6,
	0x9C0D: 0xC4CF,
	0x9C0E: 0xF572,
	0x9C0F: 0xFFFD,
	0x9C10: 0x95FD,
	0x9C11: 0xFFFD,
	0x9C12: 0xF56E,
	0x9C13: 0xC4CE,
	0x9C14: 0xF575,
	0x9C15: 0xFDF7,
	0x9C16: 0xFFFD,
	0x9C17: 0xF574,
	0x9C18: 0xFFFD,
	0x9C19: 0xFFFD,
	0x9C1A: 0xFFFD,
	0x9C1B: 0x97C6,
	0x9C1C: 0xF6AB,
	0x9C1D: 0xF6AA,
	0x9C1E: 0xFFFD,
	0x9C1F: 0x9DF5,
	0x9C20: 0x9DF6,
	0x9C21: 0xF6B1,
	0x9C22: 0xFFFD,
	0x9C23: 0xF6AD,
	0x9C24: 0xF6B0,
	0x9C25: 0xC560,
	0x9C26: 0x9DF7,
	0x9C27: 0xFFFD,
	0x9C28: 0xF6AE,
	0x9C29: 0xF6AF,
	0x9C2A: 0xFFFD,
	0x9C2B: 0xF6A9,
	0x9C2C: 0xF6AC,
	0x9C2D: 0xC55F,
	0x9C2E: 0xFDFA,
	0x9C2F: 0x94F9,
	0x9C30: 0x94EB,
	0x9C31: 0xC5BF,
	0x9C32: 0xF7B4,
	0x9C33: 0xF7AF,
	0x9C34: 0xF7B3,
	0x9C35: 0xFD53,
	0x9C36: 0xF7B6,
	0x9C37: 0xF7B2,
	0x9C38: 0xFFFD,
	0x9C39: 0xF7AE,
	0x9C3A: 0xFCCB,
	0x9C3B: 0xC5C1,
	0x9C3C: 0xF7B1,
	0x9C3D: 0xF7B5,
	0x9C3E: 0xC5C0,
	0x9C3F: 0xF7AC,
	0x9C40: 0xF570,
	0x9C41: 0xF7B0,
	0x9C42: 0xFFFD,
	0x9C43: 0xFFFD,
	0x9C44: 0xF7AD,
	0x9C45: 0xFD70,
	0x9C46: 0xF7AA,
	0x9C47: 0x94EC,
	0x9C48: 0xF7AB,
	0x9C49: 0xC5BE,
	0x9C4A: 0xF85A,
	0x9C4B: 0xF85C,
	0x9C4C: 0xF85F,
	0x9C4D: 0xF85B,
	0x9C4E: 0xF860,
	0x9C4F: 0x9F50,
	0x9C50: 0xF859,
	0x9C51: 0xFFFD,
	0x9C52: 0xF857,
	0x9C53: 0x9DF8,
	0x9C54: 0xC5EB,
	0x9C55: 0xF85D,
	0x9C56: 0xC5ED,
	0x9C57: 0xC5EC,
	0x9C58: 0xF858,
	0x9C59: 0xF85E,
	0x9C5A: 0x94ED,
	0x9C5B: 0xFFFD,
	0x9C5C: 0xFFFD,
	0x9C5D: 0x9DF9,
	0x9C5E: 0xF8DA,
	0x9C5F: 0xC64D,
	0x9C60: 0xF8DB,
	0x9C61: 0xFFFD,
	0x9C62: 0xF8D9,
	0x9C63: 0xF8D6,
	0x9C64: 0xFFFD,
	0x9C65: 0xFFFD,
	0x9C66: 0xF8D8,
	0x9C67: 0xF8D7,
	0x9C68: 0xF95A,
	0x9C69: 0x94F6,
	0x9C6A: 0xFFFD,
	0x9C6B: 0xFFFD,
	0x9C6C: 0xFFFD,
	0x9C6D: 0xF95C,
	0x9C6E: 0xF95B,
	0x9C6F: 0xFFFD,
	0x9C70: 0xFFFD,
	0x9C71: 0xF979,
	0x9C72: 0xFB78,
	0x9C73: 0xF978,
	0x9C74: 0xF977,
	0x9C75: 0xF97A,
	0x9C76: 0x9840,
	0x9C77: 0xC673,
	0x9C78: 0xC674,
	0x9C79: 0xF9CA,
	0x9C7A: 0xF9CE,
	0x9C7B: 0x9DFA,
	0x9C7C: 0x84BE,
	0x9C7D: 0xFFFD,
	0x9C7E: 0xFFFD,
	0x9C7F: 0x88C2,
	0x9C80: 0xFFFD,
	0x9C81: 0x88C3,
	0x9C82: 0x8EE0,
	0x9C83: 0xFFFD,
	0x9C84: 0xFFFD,
	0x9C85: 0x984B,
	0x9C86: 0x984C,
	0x9C87: 0x984D,
	0x9C88: 0x8DAB,
	0x9C89: 0xFFFD,
	0x9C8A: 0xFFFD,
	0x9C8B: 0x984E,
	0x9C8C: 0xFFFD,
	0x9C8D: 0x89BF,
	0x9C8E: 0x8D65,
	0x9C8F: 0xFFFD,
	0x9C90: 0x984F,
	0x9C91: 0x8AB8,
	0x9C92: 0x8F6E,
	0x9C93: 0xFFFD,
	0x9C94: 0x8AB7,
	0x9C95: 0x8F6F,
	0x9C96: 0xFFFD,
	0x9C97: 0x90F2,
	0x9C98: 0xFFFD,
	0x9C99: 0xFFFD,
	0x9C9A: 0x90A2,
	0x9C9B: 0x8AB6,
	0x9C9C: 0x8AB5,
	0x9C9D: 0xFFFD,
	0x9C9E: 0x9850,
	0x9C9F: 0x9070,
	0x9CA0: 0x8FB2,
	0x9CA1: 0x90AD,
	0x9CA2: 0x8CED,
	0x9CA3: 0x9065,
	0x9CA4: 0x8B68,
	0x9CA5: 0x904E,
	0x9CA6: 0x9066,
	0x9CA7: 0x8B6A,
	0x9CA8: 0x8B67,
	0x9CA9: 0x8FB1,
	0x9CAA: 0xFFFD,
	0x9CAB: 0x8B69,
	0x9CAC: 0xFFFD,
	0x9CAD: 0x8BE6,
	0x9CAE: 0x9851,
	0x9CAF: 0xFFFD,
	0x9CB0: 0x9852,
	0x9CB1: 0x8FD5,
	0x9CB2: 0x9853,
	0x9CB3: 0x8BE5,
	0x9CB4: 0x9854,
	0x9CB5: 0x8FD2,
	0x9CB6: 0x8FD3,
	0x9CB7: 0x8BE7,
	0x9CB8: 0x8BE4,
	0x9CB9: 0xFFFD,
	0x9CBA: 0x9855,
	0x9CBB: 0x8FD4,
	0x9CBC: 0x9856,
	0x9CBD: 0x9857,
	0x9CBE: 0xFFFD,
	0x9CBF: 0xFFFD,
	0x9CC0: 0xFFFD,
	0x9CC1: 0xFFFD,
	0x9CC2: 0xFFFD,
	0x9CC3: 0x8C67,
	0x9CC4: 0x8DAA,
	0x9CC5: 0x8C68,
	0x9CC6: 0x9858,
	0x9CC7: 0x9859,
	0x9CC8: 0xFFFD,
	0x9CC9: 0xFFFD,
	0x9CCA: 0x985A,
	0x9CCB: 0x985B,
	0x9CCC: 0x8D6A,
	0x9CCD: 0x8CC0,
	0x9CCE: 0x904F,
	0x9CCF: 0x8CC1,
	0x9CD0: 0x9050,
	0x9CD1: 0xFFFD,
	0x9CD2: 0xFFFD,
	0x9CD3: 0x985C,
	0x9CD4: 0x8CEE,
	0x9CD5: 0x9064,
	0x9CD6: 0x8CEC,
	0x9CD7: 0x8CEF,
	0x9CD8: 0x985D,
	0x9CD9: 0x985E,
	0x9CDA: 0xFFFD,
	0x9CDB: 0xFFFD,
	0x9CDC: 0x8D4F,
	0x9CDD: 0x8D4D,
	0x9CDE: 0x8D4E,
	0x9CDF: 0x906F,
	0x9CE0: 0xFFFD,
	0x9CE1: 0xFFFD,
	0x9CE2: 0x985F,
	0x9CE3: 0xFFFD,
	0x9CE4: 0xFFFD,
	0x9CE5: 0xB3BE,
	0x9CE6: 0xDCAF,
	0x9CE7: 0xE0ED,
	0x9CE8: 0xFFFD,
	0x9CE9: 0xB9A7,
	0x9CEA: 0xE0EB,
	0x9CEB: 0x9860,
	0x9CEC: 0x9861,
	0x9CED: 0xE0EC,
	0x9CEE: 0xFFFD,
	0x9CEF: 0xFFFD,
	0x9CF0: 0x94EE,
	0x9CF1: 0xE4E2,
	0x9CF2: 0xE4E3,
	0x9CF3: 0xBBF1,
	0x9CF4: 0xBBEF,
	0x9CF5: 0xE4E4,
	0x9CF6: 0xBBF0,
	0x9CF7: 0xE8E8,
	0x9CF8: 0xFFFD,
	0x9CF9: 0xE8EB,
	0x9CFA: 0xE8E5,
	0x9CFB: 0xE8EC,
	0x9CFC: 0xE8E4,
	0x9CFD: 0xE8E6,
	0x9CFE: 0xFFFD,
	0x9CFF: 0xE8E7,
	0x9D00: 0xE8EA,
	0x9D01: 0xFFFD,
	0x9D02: 0xFD61,
	0x9D03: 0xBEA1,
	0x9D04: 0xE8EF,
	0x9D05: 0xE8EE,
	0x9D06: 0xBE7D,
	0x9D07: 0xE8E9,
	0x9D08: 0xE8ED,
	0x9D09: 0xBE7E,
	0x9D0A: 0xFFFD,
	0x9D0B: 0xFFFD,
	0x9D0C: 0x9DFB,
	0x9D0D: 0xFFFD,
	0x9D0E: 0x8248,
	0x9D0F: 0xFFFD,
	0x9D10: 0xECAC,
	0x9D11: 0xFFFD,
	0x9D12: 0xC06F,
	0x9D13: 0xFFFD,
	0x9D14: 0xECA7,
	0x9D15: 0xC06B,
	0x9D16: 0x9DFC,
	0x9D17: 0xECA4,
	0x9D18: 0xECAA,
	0x9D19: 0xECAD,
	0x9D1A: 0xFFFD,
	0x9D1B: 0xC070,
	0x9D1C: 0xFFFD,
	0x9D1D: 0xECA9,
	0x9D1E: 0xECA6,
	0x9D1F: 0xECAE,
	0x9D20: 0xECA5,
	0x9D21: 0x9F40,
	0x9D22: 0xECAB,
	0x9D23: 0xC06C,
	0x9D24: 0xFFFD,
	0x9D25: 0xECA3,
	0x9D26: 0xC06D,
	0x9D27: 0xFFFD,
	0x9D28: 0xC06E,
	0x9D29: 0xECA8,
	0x9D2A: 0x9862,
	0x9D2B: 0x9447,
	0x9D2C: 0x8247,
	0x9D2D: 0xEFA9,
	0x9D2E: 0xEF7A,
	0x9D2F: 0xEF7B,
	0x9D30: 0xEF7E,
	0x9D31: 0xEF7C,
	0x9D32: 0xFFFD,
	0x9D33: 0xEF76,
	0x9D34: 0x9F41,
	0x9D35: 0xFFFD,
	0x9D36: 0xEF79,
	0x9D37: 0xEFA5,
	0x9D38: 0xEF7D,
	0x9D39: 0x9F42,
	0x9D3A: 0xFFFD,
	0x9D3B: 0xC245,
	0x9D3C: 0xFFFD,
	0x9D3D: 0xEFA7,
	0x9D3E: 0xEFA4,
	0x9D3F: 0xC246,
	0x9D40: 0xEFA6,
	0x9D41: 0xEF77,
	0x9D42: 0xEFA2,
	0x9D43: 0xEFA3,
	0x9D44: 0xFDAA,
	0x9D45: 0xEFA1,
	0x9D46: 0x94EF,
	0x9D47: 0x94F7,
	0x9D48: 0x9863,
	0x9D49: 0x9F43,
	0x9D4A: 0xF1D2,
	0x9D4B: 0xF1D4,
	0x9D4C: 0xF1D7,
	0x9D4D: 0xFFFD,
	0x9D4E: 0x9F44,
	0x9D4F: 0xF1D1,
	0x9D50: 0x9864,
	0x9D51: 0xC359,
	0x9D52: 0xF1D9,
	0x9D53: 0xF1D0,
	0x9D54: 0xF1DA,
	0x9D55: 0xFFFD,
	0x9D56: 0xF1D6,
	0x9D57: 0xF1D8,
	0x9D58: 0xF1DC,
	0x9D59: 0xF1D5,
	0x9D5A: 0xF1DD,
	0x9D5B: 0xF1D3,
	0x9D5C: 0xF1CF,
	0x9D5D: 0xC35A,
	0x9D5E: 0x9572,
	0x9D5F: 0xF1DB,
	0x9D60: 0xC35B,
	0x9D61: 0xC44D,
	0x9D62: 0xFFFD,
	0x9D63: 0xFFFD,
	0x9D64: 0x94F0,
	0x9D65: 0x94F8,
	0x9D66: 0xFFFD,
	0x9D67: 0xEF78,
	0x9D68: 0xF3F1,
	0x9D69: 0xF3E8,
	0x9D6A: 0xC44F,
	0x9D6B: 0xF3E4,
	0x9D6C: 0xC450,
	0x9D6D: 0x9F45,
	0x9D6E: 0x9F47,
	0x9D6F: 0xF3ED,
	0x9D70: 0xF3E7,
	0x9D71: 0xF3DD,
	0x9D72: 0xC44E,
	0x9D73: 0xF3EA,
	0x9D74: 0xF3E5,
	0x9D75: 0xF3E6,
	0x9D76: 0xFFFD,
	0x9D77: 0xF3D8,
	0x9D78: 0xF3DF,
	0x9D79: 0xF3EE,
	0x9D7A: 0x9865,
	0x9D7B: 0xF3EB,
	0x9D7C: 0x9F48,
	0x9D7D: 0xF3E3,
	0x9D7E: 0xFCC6,
	0x9D7F: 0xF3EF,
	0x9D80: 0xF3DE,
	0x9D81: 0xF3D9,
	0x9D82: 0xF3EC,
	0x9D83: 0x9F49,
	0x9D84: 0xF3DB,
	0x9D85: 0xF3E9,
	0x9D86: 0xF3E0,
	0x9D87: 0xF3F0,
	0x9D88: 0xF3DC,
	0x9D89: 0xC44C,
	0x9D8A: 0xF3DA,
	0x9D8B: 0xF3E1,
	0x9D8C: 0xF3E2,
	0x9D8D: 0xFFFD,
	0x9D8E: 0xFFFD,
	0x9D8F: 0x92AF,
	0x9D90: 0xF57D,
	0x9D91: 0xFFFD,
	0x9D92: 0xF57B,
	0x9D93: 0x9F4A,
	0x9D94: 0xF5A2,
	0x9D95: 0xFFFD,
	0x9D96: 0xF5AE,
	0x9D97: 0xF5A5,
	0x9D98: 0xF57C,
	0x9D99: 0xF578,
	0x9D9A: 0xF5A7,
	0x9D9B: 0xF57E,
	0x9D9C: 0xF5A3,
	0x9D9D: 0xF57A,
	0x9D9E: 0xF5AA,
	0x9D9F: 0xF577,
	0x9DA0: 0xF5A1,
	0x9DA1: 0xF5A6,
	0x9DA2: 0xF5A8,
	0x9DA3: 0xF5AB,
	0x9DA4: 0xF579,
	0x9DA5: 0x9F4B,
	0x9DA6: 0xF5AF,
	0x9DA7: 0xF5B0,
	0x9DA8: 0xF5A9,
	0x9DA9: 0xF5AD,
	0x9DAA: 0xF5A4,
	0x9DAB: 0x94F1,
	0x9DAC: 0xF6C1,
	0x9DAD: 0xF6C4,
	0x9DAE: 0xFFFD,
	0x9DAF: 0xC561,
	0x9DB0: 0xFFFD,
	0x9DB1: 0xF6C3,
	0x9DB2: 0xF6C8,
	0x9DB3: 0xF6C6,
	0x9DB4: 0xC562,
	0x9DB5: 0xF6BD,
	0x9DB6: 0xF6B3,
	0x9DB7: 0xF6B2,
	0x9DB8: 0xC564,
	0x9DB9: 0xF6BF,
	0x9DBA: 0xF6C0,
	0x9DBB: 0xF6BC,
	0x9DBC: 0xF6B4,
	0x9DBD: 0x9F4D,
	0x9DBE: 0xF6B9,
	0x9DBF: 0xF5AC,
	0x9DC0: 0x9F52,
	0x9DC1: 0xF6B5,
	0x9DC2: 0xC563,
	0x9DC3: 0xF6BB,
	0x9DC4: 0x9575,
	0x9DC5: 0xF6BA,
	0x9DC6: 0x9866,
	0x9DC7: 0xF6B6,
	0x9DC8: 0xF6C2,
	0x9DC9: 0x9F5E,
	0x9DCA: 0xF6B7,
	0x9DCB: 0xF7BB,
	0x9DCC: 0xF6C5,
	0x9DCD: 0xF6C7,
	0x9DCE: 0xF6BE,
	0x9DCF: 0xF6B8,
	0x9DD0: 0xF7BC,
	0x9DD1: 0xF7BE,
	0x9DD2: 0xF7B8,
	0x9DD3: 0xC5C2,
	0x9DD4: 0x9F5F,
	0x9DD5: 0xF7C5,
	0x9DD6: 0xF7C3,
	0x9DD7: 0xC5C3,
	0x9DD8: 0xF7C2,
	0x9DD9: 0xF7C1,
	0x9DDA: 0xF7BA,
	0x9DDB: 0xF7B7,
	0x9DDC: 0xF7BD,
	0x9DDD: 0xF7C6,
	0x9DDE: 0xF7B9,
	0x9DDF: 0xF7BF,
	0x9DE0: 0xFFFD,
	0x9DE1: 0xF869,
	0x9DE2: 0xF86E,
	0x9DE3: 0xF864,
	0x9DE4: 0xF867,
	0x9DE5: 0xC5EE,
	0x9DE6: 0xF86B,
	0x9DE7: 0xFFFD,
	0x9DE8: 0xF872,
	0x9DE9: 0xF7C0,
	0x9DEA: 0xFFFD,
	0x9DEB: 0xF865,
	0x9DEC: 0xF86F,
	0x9DED: 0xF873,
	0x9DEE: 0xF86A,
	0x9DEF: 0xF863,
	0x9DF0: 0xF86D,
	0x9DF1: 0xFFFD,
	0x9DF2: 0xF86C,
	0x9DF3: 0xF871,
	0x9DF4: 0xF870,
	0x9DF5: 0xF7C4,
	0x9DF6: 0xF868,
	0x9DF7: 0xF862,
	0x9DF8: 0xF866,
	0x9DF9: 0xC64E,
	0x9DFA: 0xC64F,
	0x9DFB: 0xF861,
	0x9DFC: 0x9F60,
	0x9DFD: 0xF8E6,
	0x9DFE: 0xF8DD,
	0x9DFF: 0xF8E5,
	0x9E00: 0xF8E2,
	0x9E01: 0xF8E3,
	0x9E02: 0xF8DC,
	0x9E03: 0xF8DF,
	0x9E04: 0xF8E7,
	0x9E05: 0xF8E1,
	0x9E06: 0xF8E0,
	0x9E07: 0xF8DE,
	0x9E08: 0xFFFD,
	0x9E09: 0xF8E4,
	0x9E0A: 0x9F61,
	0x9E0B: 0xF95D,
	0x9E0C: 0x9F62,
	0x9E0D: 0xF95E,
	0x9E0E: 0x9F63,
	0x9E0F: 0xF960,
	0x9E10: 0xF95F,
	0x9E11: 0xF962,
	0x9E12: 0xF961,
	0x9E13: 0xF97C,
	0x9E14: 0xF97B,
	0x9E15: 0xF9B7,
	0x9E16: 0xFFFD,
	0x9E17: 0xF9B8,
	0x9E18: 0x9F64,
	0x9E19: 0xF9C5,
	0x9E1A: 0xC678,
	0x9E1B: 0xC67C,
	0x9E1C: 0xFD4A,
	0x9E1D: 0xF9CF,
	0x9E1E: 0xC67D,
	0x9E1F: 0x84BF,
	0x9E20: 0x86AA,
	0x9E21: 0x8B5C,
	0x9E22: 0x877E,
	0x9E23: 0x877D,
	0x9E24: 0xFFFD,
	0x9E25: 0x8CF1,
	0x9E26: 0x88C5,
	0x9E27: 0xFFFD,
	0x9E28: 0x8EE1,
	0x9E29: 0x88C4,
	0x9E2A: 0x89C1,
	0x9E2B: 0x8FD7,
	0x9E2C: 0x90AA,
	0x9E2D: 0x89C3,
	0x9E2E: 0xFFFD,
	0x9E2F: 0x89C2,
	0x9E30: 0xFFFD,
	0x9E31: 0x8F4E,
	0x9E32: 0x8F4D,
	0x9E33: 0x89C4,
	0x9E34: 0xFFFD,
	0x9E35: 0x89C0,
	0x9E36: 0x8D50,
	0x9E37: 0x9068,
	0x9E38: 0x8F70,
	0x9E39: 0x8F71,
	0x9E3A: 0x8F72,
	0x9E3B: 0xFFFD,
	0x9E3C: 0xFFFD,
	0x9E3D: 0x8ABA,
	0x9E3E: 0x8DB1,
	0x9E3F: 0x8AB9,
	0x9E40: 0xFFFD,
	0x9E41: 0x8FB4,
	0x9E42: 0x90AE,
	0x9E43: 0x8B6B,
	0x9E44: 0x8B6D,
	0x9E45: 0x8B6C,
	0x9E46: 0x8FB5,
	0x9E47: 0x9075,
	0x9E48: 0x8FB3,
	0x9E49: 0x8BE9,
	0x9E4A: 0x8BEA,
	0x9E4B: 0x9867,
	0x9E4C: 0x8BEB,
	0x9E4D: 0xFFFD,
	0x9E4E: 0x8FD6,
	0x9E4F: 0x8BEC,
	0x9E50: 0xFFFD,
	0x9E51: 0x8BE8,
	0x9E52: 0xFFFD,
	0x9E53: 0xFFFD,
	0x9E54: 0xFFFD,
	0x9E55: 0x9868,
	0x9E56: 0xFFFD,
	0x9E57: 0x8FF6,
	0x9E58: 0x9052,
	0x9E59: 0xFFFD,
	0x9E5A: 0x8FF7,
	0x9E5B: 0x9869,
	0x9E5C: 0x8FF8,
	0x9E5D: 0xFFFD,
	0x9E5E: 0x8CC4,
	0x9E5F: 0xFFFD,
	0x9E60: 0xFFFD,
	0x9E61: 0xFFFD,
	0x9E62: 0xFFFD,
	0x9E63: 0x9051,
	0x9E64: 0x8CC3,
	0x9E65: 0xFFFD,
	0x9E66: 0x8DAE,
	0x9E67: 0x8CF0,
	0x9E68: 0x9067,
	0x9E69: 0x9071,
	0x9E6A: 0x9073,
	0x9E6B: 0x9074,
	0x9E6C: 0x9072,
	0x9E6D: 0x8D67,
	0x9E6E: 0xFFFD,
	0x9E6F: 0xFFFD,
	0x9E70: 0x8D66,
	0x9E71: 0x986A,
	0x9E72: 0xFFFD,
	0x9E73: 0x8DB0,
	0x9E74: 0xFFFD,
	0x9E75: 0xB3BF,
	0x9E76: 0xFFFD,
	0x9E77: 0xFFFD,
	0x9E78: 0x825E,
	0x9E79: 0xC4D0,
	0x9E7A: 0xF6C9,
	0x9E7B: 0x9F65,
	0x9E7C: 0xC650,
	0x9E7D: 0xC651,
	0x9E7E: 0x9053,
	0x9E7F: 0xB3C0,
	0x9E80: 0xE0EE,
	0x9E81: 0xFCFD,
	0x9E82: 0xB9A8,
	0x9E83: 0xE8F0,
	0x9E84: 0xFB5E,
	0x9E85: 0x9F66,
	0x9E86: 0xECB0,
	0x9E87: 0xECB1,
	0x9E88: 0xECAF,
	0x9E89: 0xEFAB,
	0x9E8A: 0xEFAA,
	0x9E8B: 0xC247,
	0x9E8C: 0xF1DF,
	0x9E8D: 0xEFAC,
	0x9E8E: 0xF1DE,
	0x9E8F: 0xFFFD,
	0x9E90: 0x9F51,
	0x9E91: 0xF3F3,
	0x9E92: 0xC451,
	0x9E93: 0xC453,
	0x9E94: 0xF3F2,
	0x9E95: 0xFCF4,
	0x9E96: 0xFB7C,
	0x9E97: 0xC452,
	0x9E98: 0xFBB7,
	0x9E99: 0xF5B1,
	0x9E9A: 0xF5B3,
	0x9E9B: 0xF5B2,
	0x9E9C: 0xF6CA,
	0x9E9D: 0xC565,
	0x9E9E: 0xFD48,
	0x9E9F: 0xC5EF,
	0x9EA0: 0xF8E8,
	0x9EA1: 0xF963,
	0x9EA2: 0x9F67,
	0x9EA3: 0xFFFD,
	0x9EA4: 0xF9D2,
	0x9EA5: 0xB3C1,
	0x9EA6: 0x84C1,
	0x9EA7: 0xE4E5,
	0x9EA8: 0xFDB4,
	0x9EA9: 0xBEA2,
	0x9EAA: 0x986B,
	0x9EAB: 0xFBA2,
	0x9EAC: 0x9F68,
	0x9EAD: 0xECB3,
	0x9EAE: 0xECB2,
	0x9EAF: 0x9573,
	0x9EB0: 0xEFAD,
	0x9EB1: 0x9F69,
	0x9EB2: 0xFFFD,
	0x9EB3: 0xFFFD,
	0x9EB4: 0xC454,
	0x9EB5: 0xC4D1,
	0x9EB6: 0xF7C7,
	0x9EB7: 0xF9CB,
	0x9EB8: 0x88C6,
	0x9EB9: 0x8260,
	0x9EBA: 0x8261,
	0x9EBB: 0xB3C2,
	0x9EBC: 0xBBF2,
	0x9EBD: 0x986C,
	0x9EBE: 0xBEA3,
	0x9EBF: 0x94FA,
	0x9EC0: 0xF3F4,
	0x9EC1: 0x9F6A,
	0x9EC2: 0xF874,
	0x9EC3: 0xB6C0,
	0x9EC4: 0x986D,
	0x9EC5: 0xFFFD,
	0x9EC6: 0x9F6B,
	0x9EC7: 0x9F6C,
	0x9EC8: 0xEFAE,
	0x9EC9: 0x8D7A,
	0x9ECA: 0xFFFD,
	0x9ECB: 0xFFFD,
	0x9ECC: 0xC664,
	0x9ECD: 0xB6C1,
	0x9ECE: 0xBEA4,
	0x9ECF: 0xC248,
	0x9ED0: 0xF875,
	0x9ED1: 0xB6C2,
	0x9ED2: 0x92C3,
	0x9ED3: 0xE8F1,
	0x9ED4: 0xC072,
	0x9ED5: 0xECB4,
	0x9ED6: 0xECB5,
	0x9ED7: 0xFFFD,
	0x9ED8: 0xC071,
	0x9ED9: 0x93D4,
	0x9EDA: 0xEFAF,
	0x9EDB: 0xC24C,
	0x9EDC: 0xC24A,
	0x9EDD: 0xC24B,
	0x9EDE: 0xC249,
	0x9EDF: 0xF1E0,
	0x9EE0: 0xC35C,
	0x9EE1: 0xFFFD,
	0x9EE2: 0x986E,
	0x9EE3: 0xFFFD,
	0x9EE4: 0xF5B5,
	0x9EE5: 0xF5B4,
	0x9EE6: 0xF5B7,
	0x9EE7: 0xF5B6,
	0x9EE8: 0xC4D2,
	0x9EE9: 0x8DAC,
	0x9EEA: 0x986F,
	0x9EEB: 0xF6CB,
	0x9EEC: 0xFFFD,
	0x9EED: 0xF6CD,
	0x9EEE: 0xF6CC,
	0x9EEF: 0xC566,
	0x9EF0: 0xF7C8,
	0x9EF1: 0x9F6D,
	0x9EF2: 0xF876,
	0x9EF3: 0xF877,
	0x9EF4: 0xC5F0,
	0x9EF5: 0xF964,
	0x9EF6: 0xF97D,
	0x9EF7: 0xC675,
	0x9EF8: 0x9F6E,
	0x9EF9: 0xDCB0,
	0x9EFA: 0xECB6,
	0x9EFB: 0xEFB0,
	0x9EFC: 0xF3F5,
	0x9EFD: 0xE0EF,
	0x9EFE: 0x8E64,
	0x9EFF: 0xEFB1,
	0x9F00: 0xF1E2,
	0x9F01: 0xF1E1,
	0x9F02: 0xFDE8,
	0x9F03: 0xFFFD,
	0x9F04: 0xFFFD,
	0x9F05: 0xFFFD,
	0x9F06: 0xF878,
	0x9F07: 0xC652,
	0x9F08: 0x9870,
	0x9F09: 0xF965,
	0x9F0A: 0xF97E,
	0x9F0B: 0x9871,
	0x9F0C: 0xFFFD,
	0x9F0D: 0x9872,
	0x9F0E: 0xB9A9,
	0x9F0F: 0xE8F2,
	0x9F10: 0xE8F3,
	0x9F11: 0xFFFD,
	0x9F12: 0xECB7,
	0x9F13: 0xB9AA,
	0x9F14: 0xFFFD,
	0x9F15: 0xC35D,
	0x9F16: 0xF1E3,
	0x9F17: 0xFCDB,
	0x9F18: 0xF6CF,
	0x9F19: 0xC567,
	0x9F1A: 0xF6D0,
	0x9F1B: 0xF6CE,
	0x9F1C: 0xF879,
	0x9F1D: 0xFFFD,
	0x9F1E: 0xF8E9,
	0x9F1F: 0xFFFD,
	0x9F20: 0xB9AB,
	0x9F21: 0x9873,
	0x9F22: 0xEFB4,
	0x9F23: 0xEFB3,
	0x9F24: 0xEFB2,
	0x9F25: 0xF1E4,
	0x9F26: 0xFBB8,
	0x9F27: 0x9F6F,
	0x9F28: 0xF1E8,
	0x9F29: 0xF1E7,
	0x9F2A: 0xF1E6,
	0x9F2B: 0xF1E5,
	0x9F2C: 0xC35E,
	0x9F2D: 0xF3F6,
	0x9F2E: 0xF5B9,
	0x9F2F: 0xC4D3,
	0x9F30: 0xF5B8,
	0x9F31: 0xF6D1,
	0x9F32: 0xF7CB,
	0x9F33: 0xF7CA,
	0x9F34: 0xC5C4,
	0x9F35: 0xF7C9,
	0x9F36: 0xF87C,
	0x9F37: 0xF87B,
	0x9F38: 0xF87A,
	0x9F39: 0x8CF2,
	0x9F3A: 0xFFFD,
	0x9F3B: 0xBBF3,
	0x9F3C: 0xFFFD,
	0x9F3D: 0xECB8,
	0x9F3E: 0xC24D,
	0x9F3F: 0xFFFD,
	0x9F40: 0xF3F7,
	0x9F41: 0xF3F8,
	0x9F42: 0xF7CC,
	0x9F43: 0xF87D,
	0x9F44: 0x9874,
	0x9F45: 0xFDE2,
	0x9F46: 0xF8EA,
	0x9F47: 0xF966,
	0x9F48: 0xF9B9,
	0x9F49: 0xF9D4,
	0x9F4A: 0xBBF4,
	0x9F4B: 0xC24E,
	0x9F4C: 0xF1E9,
	0x9F4D: 0xF3F9,
	0x9F4E: 0xF6D2,
	0x9F4F: 0xF87E,
	0x9F50: 0x87A2,
	0x9F51: 0x9875,
	0x9F52: 0xBEA6,
	0x9F53: 0xFDE0,
	0x9F54: 0xEFB5,
	0x9F55: 0xF1EA,
	0x9F56: 0xF3FA,
	0x9F57: 0xF3FB,
	0x9F58: 0xF3FC,
	0x9F59: 0xF5BE,
	0x9F5A: 0xFDDA,
	0x9F5B: 0xF5BA,
	0x9F5C: 0xC568,
	0x9F5D: 0xF5BD,
	0x9F5E: 0xF5BC,
	0x9F5F: 0xC4D4,
	0x9F60: 0xF5BB,
	0x9F61: 0xC4D6,
	0x9F62: 0x93EE,
	0x9F63: 0xC4D5,
	0x9F64: 0xF6D4,
	0x9F65: 0xF6D3,
	0x9F66: 0xC569,
	0x9F67: 0xC56A,
	0x9F68: 0xFFFD,
	0x9F69: 0xFD62,
	0x9F6A: 0xC5C6,
	0x9F6B: 0xF7CD,
	0x9F6C: 0xC5C5,
	0x9F6D: 0xFFFD,
	0x9F6E: 0xF8A3,
	0x9F6F: 0xF8A4,
	0x9F70: 0xF8A2,
	0x9F71: 0xF8A1,
	0x9F72: 0xC654,
	0x9F73: 0xFFFD,
	0x9F74: 0xF8EB,
	0x9F75: 0xF8EC,
	0x9F76: 0xF8ED,
	0x9F77: 0xC653,
	0x9F78: 0xF967,
	0x9F79: 0xF96A,
	0x9F7A: 0xF969,
	0x9F7B: 0xF968,
	0x9F7C: 0xFFFD,
	0x9F7D: 0xFFFD,
	0x9F7E: 0xF9D3,
	0x9F7F: 0x88C7,
	0x9F80: 0x8F73,
	0x9F81: 0xFFFD,
	0x9F82: 0xFFFD,
	0x9F83: 0x8C6A,
	0x9F84: 0x8C6B,
	0x9F85: 0x8FFA,
	0x9F86: 0x8FF9,
	0x9F87: 0x8CC5,
	0x9F88: 0x8CC6,
	0x9F89: 0x8CF3,
	0x9F8A: 0x8CF4,
	0x9F8B: 0x8D6C,
	0x9F8C: 0x8D6B,
	0x9F8D: 0xC073,
	0x9F8E: 0xFBD8,
	0x9F8F: 0xFFFD,
	0x9F90: 0xC365,
	0x9F91: 0xF5BF,
	0x9F92: 0xF6D5,
	0x9F93: 0xFFFD,
	0x9F94: 0xC5C7,
	0x9F95: 0xF7CE,
	0x9F96: 0xFFFD,
	0x9F97: 0xFFFD,
	0x9F98: 0xF9D5,
	0x9F99: 0x89C5,
	0x9F9A: 0x8CF5,
	0x9F9B: 0x9069,
	0x9F9C: 0xC074,
	0x9F9D: 0x9876,
	0x9F9E: 0xFFFD,
	0x9F9F: 0x89C6,
	0x9FA0: 0xEFB6,
	0x9FA1: 0xFFFD,
	0x9FA2: 0xF7CF,
	0x9FA3: 0xFFFD,
	0x9FA4: 0xF9A1,
	0x9FA5: 0xFDD4,
	0x9FA6: 0xFFFD,
	0x9FA7: 0xFFFD,
	0x9FA8: 0xFFFD,
	0x9FA9: 0xFFFD,
	0x9FAA: 0xFFFD,
	0x9FAB: 0xFFFD,
	0x9FAC: 0xFFFD,
	0x9FAD: 0xFFFD,
	0x9FAE: 0xFFFD,
	0x9FAF: 0xFFFD,
	0x9FB0: 0xC8A1,
	0x9FB1: 0xC8A3,
	0x9FB2: 0xFFFD,
	0x9FB3: 0xFFFD,
	0x9FB4: 0xFFFD,
	0x9FB5: 0xFFFD,
	0x9FB6: 0xFFFD,
	0x9FB7: 0xFFFD,
	0x9FB8: 0xFFFD,
	0x9FB9: 0xFFFD,
	0x9FBA: 0xFFFD,
	0x9FBB: 0xFFFD,
	0x9FBC: 0xFFFD,
	0x9FBD: 0xFFFD,
	0x9FBE: 0xFFFD,
	0x9FBF: 0xFFFD,
	0x9FC0: 0xFFFD,
	0x9FC1: 0xFFFD,
	0x9FC2: 0xFFFD,
	0x9FC3: 0xFFFD,
	0x9FC4: 0xFFFD,
	0x9FC5: 0xFFFD,
	0x9FC6: 0xFFFD,
	0x9FC7: 0xFFFD,
	0x9FC8: 0xFFFD,
	0x9FC9: 0xFFFD,
	0x9FCA: 0xFFFD,
	0x9FCB: 0xFFFD,
	0x9FCC: 0xFFFD,
	0x9FCD: 0xFFFD,
	0x9FCE: 0xFFFD,
	0x9FCF: 0xFFFD,
	0x9FD0: 0xFFFD,
	0x9FD1: 0xFFFD,
	0x9FD2: 0xFFFD,
	0x9FD3: 0xFFFD,
	0x9FD4: 0xFFFD,
	0x9FD5: 0xFFFD,
	0x9FD6: 0xFFFD,
	0x9FD7: 0xFFFD,
	0x9FD8: 0xFFFD,
	0x9FD9: 0xFFFD,
	0x9FDA: 0xFFFD,
	0x9FDB: 0xFFFD,
	0x9FDC: 0xFFFD,
	0x9FDD: 0xFFFD,
	0x9FDE: 0xFFFD,
	0x9FDF: 0xFFFD,
	0x9FE0: 0xFFFD,
	0x9FE1: 0xFFFD,
	0x9FE2: 0xFFFD,
	0x9FE3: 0xFFFD,
	0x9FE4: 0xFFFD,
	0x9FE5: 0xFFFD,
	0x9FE6: 0xFFFD,
	0x9FE7: 0xFFFD,
	0x9FE8: 0xFFFD,
	0x9FE9: 0xFFFD,
	0x9FEA: 0xFFFD,
	0x9FEB: 0xFFFD,
	0x9FEC: 0xFFFD,
	0x9FED: 0xFFFD,
	0x9FEE: 0xFFFD,
	0x9FEF: 0xFFFD,
	0x9FF0: 0xFFFD,
	0x9FF1: 0xFFFD,
	0x9FF2: 0xFFFD,
	0x9FF3: 0xFFFD,
	0x9FF4: 0xFFFD,
	0x9FF5: 0xFFFD,
	0x9FF6: 0xFFFD,
	0x9FF7: 0xFFFD,
	0x9FF8: 0xFFFD,
	0x9FF9: 0xFFFD,
	0x9FFA: 0xFFFD,
	0x9FFB: 0xFFFD,
	0x9FFC: 0xFFFD,
	0x9FFD: 0xFFFD,
	0x9FFE: 0xFFFD,
	0x9FFF: 0xFFFD,
	0xA000: 0xFFFD,
	0xA001: 0xFFFD,
	0xA002: 0xFFFD,
	0xA003: 0xFFFD,
	0xA004: 0xFFFD,
	0xA005: 0xFFFD,
	0xA006: 0xFFFD,
	0xA007: 0xFFFD,
	0xA008: 0xFFFD,
	0xA009: 0xFFFD,
	0xA00A: 0xFFFD,
	0xA00B: 0xFFFD,
	0xA00C: 0xFFFD,
	0xA00D: 0xFFFD,
	0xA00E: 0xFFFD,
	0xA00F: 0xFFFD,
	0xA010: 0xFFFD,
	0xA011: 0xFFFD,
	0xA012: 0xFFFD,
	0xA013: 0xFFFD,
	0xA014: 0xFFFD,
	0xA015: 0xFFFD,
	0xA016: 0xFFFD,
	0xA017: 0xFFFD,
	0xA018: 0xFFFD,
	0xA019: 0xFFFD,
	0xA01A: 0xFFFD,
	0xA01B: 0xFFFD,
	0xA01C: 0xFFFD,
	0xA01D: 0xFFFD,
	0xA01E: 0xFFFD,
	0xA01F: 0xFFFD,
	0xA020: 0xFFFD,
	0xA021: 0xFFFD,
	0xA022: 0xFFFD,
	0xA023: 0xFFFD,
	0xA024: 0xFFFD,
	0xA025: 0xFFFD,
	0xA026: 0xFFFD,
	0xA027: 0xFFFD,
	0xA028: 0xFFFD,
	0xA029: 0xFFFD,
	0xA02A: 0xFFFD,
	0xA02B: 0xFFFD,
	0xA02C: 0xFFFD,
	0xA02D: 0xFFFD,
	0xA02E: 0xFFFD,
	0xA02F: 0xFFFD,
	0xA030: 0xFFFD,
	0xA031: 0xFFFD,
	0xA032: 0xFFFD,
	0xA033: 0xFFFD,
	0xA034: 0xFFFD,
	0xA035: 0xFFFD,
	0xA036: 0xFFFD,
	0xA037: 0xFFFD,
	0xA038: 0xFFFD,
	0xA039: 0xFFFD,
	0xA03A: 0xFFFD,
	0xA03B: 0xFFFD,
	0xA03C: 0xFFFD,
	0xA03D: 0xFFFD,
	0xA03E: 0xFFFD,
	0xA03F: 0xFFFD,
	0xA040: 0xFFFD,
	0xA041: 0xFFFD,
	0xA042: 0xFFFD,
	0xA043: 0xFFFD,
	0xA044: 0xFFFD,
	0xA045: 0xFFFD,
	0xA046: 0xFFFD,
	0xA047: 0xFFFD,
	0xA048: 0xFFFD,
	0xA049: 0xFFFD,
	0xA04A: 0xFFFD,
	0xA04B: 0xFFFD,
	0xA04C: 0xFFFD,
	0xA04D: 0xFFFD,
	0xA04E: 0xFFFD,
	0xA04F: 0xFFFD,
	0xA050: 0xFFFD,
	0xA051: 0xFFFD,
	0xA052: 0xFFFD,
	0xA053: 0xFFFD,
	0xA054: 0xFFFD,
	0xA055: 0xFFFD,
	0xA056: 0xFFFD,
	0xA057: 0xFFFD,
	0xA058: 0xFFFD,
	0xA059: 0xFFFD,
	0xA05A: 0xFFFD,
	0xA05B: 0xFFFD,
	0xA05C: 0xFFFD,
	0xA05D: 0xFFFD,
	0xA05E: 0xFFFD,
	0xA05F: 0xFFFD,
	0xA060: 0xFFFD,
	0xA061: 0xFFFD,
	0xA062: 0xFFFD,
	0xA063: 0xFFFD,
	0xA064: 0xFFFD,
	0xA065: 0xFFFD,
	0xA066: 0xFFFD,
	0xA067: 0xFFFD,
	0xA068: 0xFFFD,
	0xA069: 0xFFFD,
	0xA06A: 0xFFFD,
	0xA06B: 0xFFFD,
	0xA06C: 0xFFFD,
	0xA06D: 0xFFFD,
	0xA06E: 0xFFFD,
	0xA06F: 0xFFFD,
	0xA070: 0xFFFD,
	0xA071: 0xFFFD,
	0xA072: 0xFFFD,
	0xA073: 0xFFFD,
	0xA074: 0xFFFD,
	0xA075: 0xFFFD,
	0xA076: 0xFFFD,
	0xA077: 0xFFFD,
	0xA078: 0xFFFD,
	0xA079: 0xFFFD,
	0xA07A: 0xFFFD,
	0xA07B: 0xFFFD,
	0xA07C: 0xFFFD,
	0xA07D: 0xFFFD,
	0xA07E: 0xFFFD,
	0xA07F: 0xFFFD,
	0xA080: 0xFFFD,
	0xA081: 0xFFFD,
	0xA082: 0xFFFD,
	0xA083: 0xFFFD,
	0xA084: 0xFFFD,
	0xA085: 0xFFFD,
	0xA086: 0xFFFD,
	0xA087: 0xFFFD,
	0xA088: 0xFFFD,
	0xA089: 0xFFFD,
	0xA08A: 0xFFFD,
	0xA08B: 0xFFFD,
	0xA08C: 0xFFFD,
	0xA08D: 0xFFFD,
	0xA08E: 0xFFFD,
	0xA08F: 0xFFFD,
	0xA090: 0xFFFD,
	0xA091: 0xFFFD,
	0xA092: 0xFFFD,
	0xA093: 0xFFFD,
	0xA094: 0xFFFD,
	0xA095: 0xFFFD,
	0xA096: 0xFFFD,
	0xA097: 0xFFFD,
	0xA098: 0xFFFD,
	0xA099: 0xFFFD,
	0xA09A: 0xFFFD,
	0xA09B: 0xFFFD,
	0xA09C: 0xFFFD,
	0xA09D: 0xFFFD,
	0xA09E: 0xFFFD,
	0xA09F: 0xFFFD,
	0xA0A0: 0xFFFD,
	0xA0A1: 0xFFFD,
	0xA0A2: 0xFFFD,
	0xA0A3: 0xFFFD,
	0xA0A4: 0xFFFD,
	0xA0A5: 0xFFFD,
	0xA0A6: 0xFFFD,
	0xA0A7: 0xFFFD,
	0xA0A8: 0xFFFD,
	0xA0A9: 0xFFFD,
	0xA0AA: 0xFFFD,
	0xA0AB: 0xFFFD,
	0xA0AC: 0xFFFD,
	0xA0AD: 0xFFFD,
	0xA0AE: 0xFFFD,
	0xA0AF: 0xFFFD,
	0xA0B0: 0xFFFD,
	0xA0B1: 0xFFFD,
	0xA0B2: 0xFFFD,
	0xA0B3: 0xFFFD,
	0xA0B4: 0xFFFD,
	0xA0B5: 0xFFFD,
	0xA0B6: 0xFFFD,
	0xA0B7: 0xFFFD,
	0xA0B8: 0xFFFD,
	0xA0B9: 0xFFFD,
	0xA0BA: 0xFFFD,
	0xA0BB: 0xFFFD,
	0xA0BC: 0xFFFD,
	0xA0BD: 0xFFFD,
	0xA0BE: 0xFFFD,
	0xA0BF: 0xFFFD,
	0xA0C0: 0xFFFD,
	0xA0C1: 0xFFFD,
	0xA0C2: 0xFFFD,
	0xA0C3: 0xFFFD,
	0xA0C4: 0xFFFD,
	0xA0C5: 0xFFFD,
	0xA0C6: 0xFFFD,
	0xA0C7: 0xFFFD,
	0xA0C8: 0xFFFD,
	0xA0C9: 0xFFFD,
	0xA0CA: 0xFFFD,
	0xA0CB: 0xFFFD,
	0xA0CC: 0xFFFD,
	0xA0CD: 0xFFFD,
	0xA0CE: 0xFFFD,
	0xA0CF: 0xFFFD,
	0xA0D0: 0xFFFD,
	0xA0D1: 0xFFFD,
	0xA0D2: 0xFFFD,
	0xA0D3: 0xFFFD,
	0xA0D4: 0xFFFD,
	0xA0D5: 0xFFFD,
	0xA0D6: 0xFFFD,
	0xA0D7: 0xFFFD,
	0xA0D8: 0xFFFD,
	0xA0D9: 0xFFFD,
	0xA0DA: 0xFFFD,
	0xA0DB: 0xFFFD,
	0xA0DC: 0xFFFD,
	0xA0DD: 0xFFFD,
	0xA0DE: 0xFFFD,
	0xA0DF: 0xFFFD,
	0xA0E0: 0xFFFD,
	0xA0E1: 0xFFFD,
	0xA0E2: 0xFFFD,
	0xA0E3: 0xFFFD,
	0xA0E4: 0xFFFD,
	0xA0E5: 0xFFFD,
	0xA0E6: 0xFFFD,
	0xA0E7: 0xFFFD,
	0xA0E8: 0xFFFD,
	0xA0E9: 0xFFFD,
	0xA0EA: 0xFFFD,
	0xA0EB: 0xFFFD,
	0xA0EC: 0xFFFD,
	0xA0ED: 0xFFFD,
	0xA0EE: 0xFFFD,
	0xA0EF: 0xFFFD,
	0xA0F0: 0xFFFD,
	0xA0F1: 0xFFFD,
	0xA0F2: 0xFFFD,
	0xA0F3: 0xFFFD,
	0xA0F4: 0xFFFD,
	0xA0F5: 0xFFFD,
	0xA0F6: 0xFFFD,
	0xA0F7: 0xFFFD,
	0xA0F8: 0xFFFD,
	0xA0F9: 0xFFFD,
	0xA0FA: 0xFFFD,
	0xA0FB: 0xFFFD,
	0xA0FC: 0xFFFD,
	0xA0FD: 0xFFFD,
	0xA0FE: 0xFFFD,
	0xA0FF: 0xFFFD,
	0xA100: 0xFFFD,
	0xA101: 0xFFFD,
	0xA102: 0xFFFD,
	0xA103: 0xFFFD,
	0xA104: 0xFFFD,
	0xA105: 0xFFFD,
	0xA106: 0xFFFD,
	0xA107: 0xFFFD,
	0xA108: 0xFFFD,
	0xA109: 0xFFFD,
	0xA10A: 0xFFFD,
	0xA10B: 0xFFFD,
	0xA10C: 0xFFFD,
	0xA10D: 0xFFFD,
	0xA10E: 0xFFFD,
	0xA10F: 0xFFFD,
	0xA110: 0xFFFD,
	0xA111: 0xFFFD,
	0xA112: 0xFFFD,
	0xA113: 0xFFFD,
	0xA114: 0xFFFD,
	0xA115: 0xFFFD,
	0xA116: 0xFFFD,
	0xA117: 0xFFFD,
	0xA118: 0xFFFD,
	0xA119: 0xFFFD,
	0xA11A: 0xFFFD,
	0xA11B: 0xFFFD,
	0xA11C: 0xFFFD,
	0xA11D: 0xFFFD,
	0xA11E: 0xFFFD,
	0xA11F: 0xFFFD,
	0xA120: 0xFFFD,
	0xA121: 0xFFFD,
	0xA122: 0xFFFD,
	0xA123: 0xFFFD,
	0xA124: 0xFFFD,
	0xA125: 0xFFFD,
	0xA126: 0xFFFD,
	0xA127: 0xFFFD,
	0xA128: 0xFFFD,
	0xA129: 0xFFFD,
	0xA12A: 0xFFFD,
	0xA12B: 0xFFFD,
	0xA12C: 0xFFFD,
	0xA12D: 0xFFFD,
	0xA12E: 0xFFFD,
	0xA12F: 0xFFFD,
	0xA130: 0xFFFD,
	0xA131: 0xFFFD,
	0xA132: 0xFFFD,
	0xA133: 0xFFFD,
	0xA134: 0xFFFD,
	0xA135: 0xFFFD,
	0xA136: 0xFFFD,
	0xA137: 0xFFFD,
	0xA138: 0xFFFD,
	0xA139: 0xFFFD,
	0xA13A: 0xFFFD,
	0xA13B: 0xFFFD,
	0xA13C: 0xFFFD,
	0xA13D: 0xFFFD,
	0xA13E: 0xFFFD,
	0xA13F: 0xFFFD,
	0xA140: 0xFFFD,
	0xA141: 0xFFFD,
	0xA142: 0xFFFD,
	0xA143: 0xFFFD,
	0xA144: 0xFFFD,
	0xA145: 0xFFFD,
	0xA146: 0xFFFD,
	0xA147: 0xFFFD,
	0xA148: 0xFFFD,
	0xA149: 0xFFFD,
	0xA14A: 0xFFFD,
	0xA14B: 0xFFFD,
	0xA14C: 0xFFFD,
	0xA14D: 0xFFFD,
	0xA14E: 0xFFFD,
	0xA14F: 0xFFFD,
	0xA150: 0xFFFD,
	0xA151: 0xFFFD,
	0xA152: 0xFFFD,
	0xA153: 0xFFFD,
	0xA154: 0xFFFD,
	0xA155: 0xFFFD,
	0xA156: 0xFFFD,
	0xA157: 0xFFFD,
	0xA158: 0xFFFD,
	0xA159: 0xFFFD,
	0xA15A: 0xFFFD,
	0xA15B: 0xFFFD,
	0xA15C: 0xFFFD,
	0xA15D: 0xFFFD,
	0xA15E: 0xFFFD,
	0xA15F: 0xFFFD,
	0xA160: 0xFFFD,
	0xA161: 0xFFFD,
	0xA162: 0xFFFD,
	0xA163: 0xFFFD,
	0xA164: 0xFFFD,
	0xA165: 0xFFFD,
	0xA166: 0xFFFD,
	0xA167: 0xFFFD,
	0xA168: 0xFFFD,
	0xA169: 0xFFFD,
	0xA16A: 0xFFFD,
	0xA16B: 0xFFFD,
	0xA16C: 0xFFFD,
	0xA16D: 0xFFFD,
	0xA16E: 0xFFFD,
	0xA16F: 0xFFFD,
	0xA170: 0xFFFD,
	0xA171: 0xFFFD,
	0xA172: 0xFFFD,
	0xA173: 0xFFFD,
	0xA174: 0xFFFD,
	0xA175: 0xFFFD,
	0xA176: 0xFFFD,
	0xA177: 0xFFFD,
	0xA178: 0xFFFD,
	0xA179: 0xFFFD,
	0xA17A: 0xFFFD,
	0xA17B: 0xFFFD,
	0xA17C: 0xFFFD,
	0xA17D: 0xFFFD,
	0xA17E: 0xFFFD,
	0xA17F: 0xFFFD,
	0xA180: 0xFFFD,
	0xA181: 0xFFFD,
	0xA182: 0xFFFD,
	0xA183: 0xFFFD,
	0xA184: 0xFFFD,
	0xA185: 0xFFFD,
	0xA186: 0xFFFD,
	0xA187: 0xFFFD,
	0xA188: 0xFFFD,
	0xA189: 0xFFFD,
	0xA18A: 0xFFFD,
	0xA18B: 0xFFFD,
	0xA18C: 0xFFFD,
	0xA18D: 0xFFFD,
	0xA18E: 0xFFFD,
	0xA18F: 0xFFFD,
	0xA190: 0xFFFD,
	0xA191: 0xFFFD,
	0xA192: 0xFFFD,
	0xA193: 0xFFFD,
	0xA194: 0xFFFD,
	0xA195: 0xFFFD,
	0xA196: 0xFFFD,
	0xA197: 0xFFFD,
	0xA198: 0xFFFD,
	0xA199: 0xFFFD,
	0xA19A: 0xFFFD,
	0xA19B: 0xFFFD,
	0xA19C: 0xFFFD,
	0xA19D: 0xFFFD,
	0xA19E: 0xFFFD,
	0xA19F: 0xFFFD,
	0xA1A0: 0xFFFD,
	0xA1A1: 0xFFFD,
	0xA1A2: 0xFFFD,
	0xA1A3: 0xFFFD,
	0xA1A4: 0xFFFD,
	0xA1A5: 0xFFFD,
	0xA1A6: 0xFFFD,
	0xA1A7: 0xFFFD,
	0xA1A8: 0xFFFD,
	0xA1A9: 0xFFFD,
	0xA1AA: 0xFFFD,
	0xA1AB: 0xFFFD,
	0xA1AC: 0xFFFD,
	0xA1AD: 0xFFFD,
	0xA1AE: 0xFFFD,
	0xA1AF: 0xFFFD,
	0xA1B0: 0xFFFD,
	0xA1B1: 0xFFFD,
	0xA1B2: 0xFFFD,
	0xA1B3: 0xFFFD,
	0xA1B4: 0xFFFD,
	0xA1B5: 0xFFFD,
	0xA1B6: 0xFFFD,
	0xA1B7: 0xFFFD,
	0xA1B8: 0xFFFD,
	0xA1B9: 0xFFFD,
	0xA1BA: 0xFFFD,
	0xA1BB: 0xFFFD,
	0xA1BC: 0xFFFD,
	0xA1BD: 0xFFFD,
	0xA1BE: 0xFFFD,
	0xA1BF: 0xFFFD,
	0xA1C0: 0xFFFD,
	0xA1C1: 0xFFFD,
	0xA1C2: 0xFFFD,
	0xA1C3: 0xFFFD,
	0xA1C4: 0xFFFD,
	0xA1C5: 0xFFFD,
	0xA1C6: 0xFFFD,
	0xA1C7: 0xFFFD,
	0xA1C8: 0xFFFD,
	0xA1C9: 0xFFFD,
	0xA1CA: 0xFFFD,
	0xA1CB: 0xFFFD,
	0xA1CC: 0xFFFD,
	0xA1CD: 0xFFFD,
	0xA1CE: 0xFFFD,
	0xA1CF: 0xFFFD,
	0xA1D0: 0xFFFD,
	0xA1D1: 0xFFFD,
	0xA1D2: 0xFFFD,
	0xA1D3: 0xFFFD,
	0xA1D4: 0xFFFD,
	0xA1D5: 0xFFFD,
	0xA1D6: 0xFFFD,
	0xA1D7: 0xFFFD,
	0xA1D8: 0xFFFD,
	0xA1D9: 0xFFFD,
	0xA1DA: 0xFFFD,
	0xA1DB: 0xFFFD,
	0xA1DC: 0xFFFD,
	0xA1DD: 0xFFFD,
	0xA1DE: 0xFFFD,
	0xA1DF: 0xFFFD,
	0xA1E0: 0xFFFD,
	0xA1E1: 0xFFFD,
	0xA1E2: 0xFFFD,
	0xA1E3: 0xFFFD,
	0xA1E4: 0xFFFD,
	0xA1E5: 0xFFFD,
	0xA1E6: 0xFFFD,
	0xA1E7: 0xFFFD,
	0xA1E8: 0xFFFD,
	0xA1E9: 0xFFFD,
	0xA1EA: 0xFFFD,
	0xA1EB: 0xFFFD,
	0xA1EC: 0xFFFD,
	0xA1ED: 0xFFFD,
	0xA1EE: 0xFFFD,
	0xA1EF: 0xFFFD,
	0xA1F0: 0xFFFD,
	0xA1F1: 0xFFFD,
	0xA1F2: 0xFFFD,
	0xA1F3: 0xFFFD,
	0xA1F4: 0xFFFD,
	0xA1F5: 0xFFFD,
	0xA1F6: 0xFFFD,
	0xA1F7: 0xFFFD,
	0xA1F8: 0xFFFD,
	0xA1F9: 0xFFFD,
	0xA1FA: 0xFFFD,
	0xA1FB: 0xFFFD,
	0xA1FC: 0xFFFD,
	0xA1FD: 0xFFFD,
	0xA1FE: 0xFFFD,
	0xA1FF: 0xFFFD,
	0xA200: 0xFFFD,
	0xA201: 0xFFFD,
	0xA202: 0xFFFD,
	0xA203: 0xFFFD,
	0xA204: 0xFFFD,
	0xA205: 0xFFFD,
	0xA206: 0xFFFD,
	0xA207: 0xFFFD,
	0xA208: 0xFFFD,
	0xA209: 0xFFFD,
	0xA20A: 0xFFFD,
	0xA20B: 0xFFFD,
	0xA20C: 0xFFFD,
	0xA20D: 0xFFFD,
	0xA20E: 0xFFFD,
	0xA20F: 0xFFFD,
	0xA210: 0xFFFD,
	0xA211: 0xFFFD,
	0xA212: 0xFFFD,
	0xA213: 0xFFFD,
	0xA214: 0xFFFD,
	0xA215: 0xFFFD,
	0xA216: 0xFFFD,
	0xA217: 0xFFFD,
	0xA218: 0xFFFD,
	0xA219: 0xFFFD,
	0xA21A: 0xFFFD,
	0xA21B: 0xFFFD,
	0xA21C: 0xFFFD,
	0xA21D: 0xFFFD,
	0xA21E: 0xFFFD,
	0xA21F: 0xFFFD,
	0xA220: 0xFFFD,
	0xA221: 0xFFFD,
	0xA222: 0xFFFD,
	0xA223: 0xFFFD,
	0xA224: 0xFFFD,
	0xA225: 0xFFFD,
	0xA226: 0xFFFD,
	0xA227: 0xFFFD,
	0xA228: 0xFFFD,
	0xA229: 0xFFFD,
	0xA22A: 0xFFFD,
	0xA22B: 0xFFFD,
	0xA22C: 0xFFFD,
	0xA22D: 0xFFFD,
	0xA22E: 0xFFFD,
	0xA22F: 0xFFFD,
	0xA230: 0xFFFD,
	0xA231: 0xFFFD,
	0xA232: 0xFFFD,
	0xA233: 0xFFFD,
	0xA234: 0xFFFD,
	0xA235: 0xFFFD,
	0xA236: 0xFFFD,
	0xA237: 0xFFFD,
	0xA238: 0xFFFD,
	0xA239: 0xFFFD,
	0xA23A: 0xFFFD,
	0xA23B: 0xFFFD,
	0xA23C: 0xFFFD,
	0xA23D: 0xFFFD,
	0xA23E: 0xFFFD,
	0xA23F: 0xFFFD,
	0xA240: 0xFFFD,
	0xA241: 0xFFFD,
	0xA242: 0xFFFD,
	0xA243: 0xFFFD,
	0xA244: 0xFFFD,
	0xA245: 0xFFFD,
	0xA246: 0xFFFD,
	0xA247: 0xFFFD,
	0xA248: 0xFFFD,
	0xA249: 0xFFFD,
	0xA24A: 0xFFFD,
	0xA24B: 0xFFFD,
	0xA24C: 0xFFFD,
	0xA24D: 0xFFFD,
	0xA24E: 0xFFFD,
	0xA24F: 0xFFFD,
	0xA250: 0xFFFD,
	0xA251: 0xFFFD,
	0xA252: 0xFFFD,
	0xA253: 0xFFFD,
	0xA254: 0xFFFD,
	0xA255: 0xFFFD,
	0xA256: 0xFFFD,
	0xA257: 0xFFFD,
	0xA258: 0xFFFD,
	0xA259: 0xFFFD,
	0xA25A: 0xFFFD,
	0xA25B: 0xFFFD,
	0xA25C: 0xFFFD,
	0xA25D: 0xFFFD,
	0xA25E: 0xFFFD,
	0xA25F: 0xFFFD,
	0xA260: 0xFFFD,
	0xA261: 0xFFFD,
	0xA262: 0xFFFD,
	0xA263: 0xFFFD,
	0xA264: 0xFFFD,
	0xA265: 0xFFFD,
	0xA266: 0xFFFD,
	0xA267: 0xFFFD,
	0xA268: 0xFFFD,
	0xA269: 0xFFFD,
	0xA26A: 0xFFFD,
	0xA26B: 0xFFFD,
	0xA26C: 0xFFFD,
	0xA26D: 0xFFFD,
	0xA26E: 0xFFFD,
	0xA26F: 0xFFFD,
	0xA270: 0xFFFD,
	0xA271: 0xFFFD,
	0xA272: 0xFFFD,
	0xA273: 0xFFFD,
	0xA274: 0xFFFD,
	0xA275: 0xFFFD,
	0xA276: 0xFFFD,
	0xA277: 0xFFFD,
	0xA278: 0xFFFD,
	0xA279: 0xFFFD,
	0xA27A: 0xFFFD,
	0xA27B: 0xFFFD,
	0xA27C: 0xFFFD,
	0xA27D: 0xFFFD,
	0xA27E: 0xFFFD,
	0xA27F: 0xFFFD,
	0xA280: 0xFFFD,
	0xA281: 0xFFFD,
	0xA282: 0xFFFD,
	0xA283: 0xFFFD,
	0xA284: 0xFFFD,
	0xA285: 0xFFFD,
	0xA286: 0xFFFD,
	0xA287: 0xFFFD,
	0xA288: 0xFFFD,
	0xA289: 0xFFFD,
	0xA28A: 0xFFFD,
	0xA28B: 0xFFFD,
	0xA28C: 0xFFFD,
	0xA28D: 0xFFFD,
	0xA28E: 0xFFFD,
	0xA28F: 0xFFFD,
	0xA290: 0xFFFD,
	0xA291: 0xFFFD,
	0xA292: 0xFFFD,
	0xA293: 0xFFFD,
	0xA294: 0xFFFD,
	0xA295: 0xFFFD,
	0xA296: 0xFFFD,
	0xA297: 0xFFFD,
	0xA298: 0xFFFD,
	0xA299: 0xFFFD,
	0xA29A: 0xFFFD,
	0xA29B: 0xFFFD,
	0xA29C: 0xFFFD,
	0xA29D: 0xFFFD,
	0xA29E: 0xFFFD,
	0xA29F: 0xFFFD,
	0xA2A0: 0xFFFD,
	0xA2A1: 0xFFFD,
	0xA2A2: 0xFFFD,
	0xA2A3: 0xFFFD,
	0xA2A4: 0xFFFD,
	0xA2A5: 0xFFFD,
	0xA2A6: 0xFFFD,
	0xA2A7: 0xFFFD,
	0xA2A8: 0xFFFD,
	0xA2A9: 0xFFFD,
	0xA2AA: 0xFFFD,
	0xA2AB: 0xFFFD,
	0xA2AC: 0xFFFD,
	0xA2AD: 0xFFFD,
	0xA2AE: 0xFFFD,
	0xA2AF: 0xFFFD,
	0xA2B0: 0xFFFD,
	0xA2B1: 0xFFFD,
	0xA2B2: 0xFFFD,
	0xA2B3: 0xFFFD,
	0xA2B4: 0xFFFD,
	0xA2B5: 0xFFFD,
	0xA2B6: 0xFFFD,
	0xA2B7: 0xFFFD,
	0xA2B8: 0xFFFD,
	0xA2B9: 0xFFFD,
	0xA2BA: 0xFFFD,
	0xA2BB: 0xFFFD,
	0xA2BC: 0xFFFD,
	0xA2BD: 0xFFFD,
	0xA2BE: 0xFFFD,
	0xA2BF: 0xFFFD,
	0xA2C0: 0xFFFD,
	0xA2C1: 0xFFFD,
	0xA2C2: 0xFFFD,
	0xA2C3: 0xFFFD,
	0xA2C4: 0xFFFD,
	0xA2C5: 0xFFFD,
	0xA2C6: 0xFFFD,
	0xA2C7: 0xFFFD,
	0xA2C8: 0xFFFD,
	0xA2C9: 0xFFFD,
	0xA2CA: 0xFFFD,
	0xA2CB: 0xFFFD,
	0xA2CC: 0xFFFD,
	0xA2CD: 0xFFFD,
	0xA2CE: 0xFFFD,
	0xA2CF: 0xFFFD,
	0xA2D0: 0xFFFD,
	0xA2D1: 0xFFFD,
	0xA2D2: 0xFFFD,
	0xA2D3: 0xFFFD,
	0xA2D4: 0xFFFD,
	0xA2D5: 0xFFFD,
	0xA2D6: 0xFFFD,
	0xA2D7: 0xFFFD,
	0xA2D8: 0xFFFD,
	0xA2D9: 0xFFFD,
	0xA2DA: 0xFFFD,
	0xA2DB: 0xFFFD,
	0xA2DC: 0xFFFD,
	0xA2DD: 0xFFFD,
	0xA2DE: 0xFFFD,
	0xA2DF: 0xFFFD,
	0xA2E0: 0xFFFD,
	0xA2E1: 0xFFFD,
	0xA2E2: 0xFFFD,
	0xA2E3: 0xFFFD,
	0xA2E4: 0xFFFD,
	0xA2E5: 0xFFFD,
	0xA2E6: 0xFFFD,
	0xA2E7: 0xFFFD,
	0xA2E8: 0xFFFD,
	0xA2E9: 0xFFFD,
	0xA2EA: 0xFFFD,
	0xA2EB: 0xFFFD,
	0xA2EC: 0xFFFD,
	0xA2ED: 0xFFFD,
	0xA2EE: 0xFFFD,
	0xA2EF: 0xFFFD,
	0xA2F0: 0xFFFD,
	0xA2F1: 0xFFFD,
	0xA2F2: 0xFFFD,
	0xA2F3: 0xFFFD,
	0xA2F4: 0xFFFD,
	0xA2F5: 0xFFFD,
	0xA2F6: 0xFFFD,
	0xA2F7: 0xFFFD,
	0xA2F8: 0xFFFD,
	0xA2F9: 0xFFFD,
	0xA2FA: 0xFFFD,
	0xA2FB: 0xFFFD,
	0xA2FC: 0xFFFD,
	0xA2FD: 0xFFFD,
	0xA2FE: 0xFFFD,
	0xA2FF: 0xFFFD,
	0xA300: 0xFFFD,
	0xA301: 0xFFFD,
	0xA302: 0xFFFD,
	0xA303: 0xFFFD,
	0xA304: 0xFFFD,
	0xA305: 0xFFFD,
	0xA306: 0xFFFD,
	0xA307: 0xFFFD,
	0xA308: 0xFFFD,
	0xA309: 0xFFFD,
	0xA30A: 0xFFFD,
	0xA30B: 0xFFFD,
	0xA30C: 0xFFFD,
	0xA30D: 0xFFFD,
	0xA30E: 0xFFFD,
	0xA30F: 0xFFFD,
	0xA310: 0xFFFD,
	0xA311: 0xFFFD,
	0xA312: 0xFFFD,
	0xA313: 0xFFFD,
	0xA314: 0xFFFD,
	0xA315: 0xFFFD,
	0xA316: 0xFFFD,
	0xA317: 0xFFFD,
	0xA318: 0xFFFD,
	0xA319: 0xFFFD,
	0xA31A: 0xFFFD,
	0xA31B: 0xFFFD,
	0xA31C: 0xFFFD,
	0xA31D: 0xFFFD,
	0xA31E: 0xFFFD,
	0xA31F: 0xFFFD,
	0xA320: 0xFFFD,
	0xA321: 0xFFFD,
	0xA322: 0xFFFD,
	0xA323: 0xFFFD,
	0xA324: 0xFFFD,
	0xA325: 0xFFFD,
	0xA326: 0xFFFD,
	0xA327: 0xFFFD,
	0xA328: 0xFFFD,
	0xA329: 0xFFFD,
	0xA32A: 0xFFFD,
	0xA32B: 0xFFFD,
	0xA32C: 0xFFFD,
	0xA32D: 0xFFFD,
	0xA32E: 0xFFFD,
	0xA32F: 0xFFFD,
	0xA330: 0xFFFD,
	0xA331: 0xFFFD,
	0xA332: 0xFFFD,
	0xA333: 0xFFFD,
	0xA334: 0xFFFD,
	0xA335: 0xFFFD,
	0xA336: 0xFFFD,
	0xA337: 0xFFFD,
	0xA338: 0xFFFD,
	0xA339: 0xFFFD,
	0xA33A: 0xFFFD,
	0xA33B: 0xFFFD,
	0xA33C: 0xFFFD,
	0xA33D: 0xFFFD,
	0xA33E: 0xFFFD,
	0xA33F: 0xFFFD,
	0xA340: 0xFFFD,
	0xA341: 0xFFFD,
	0xA342: 0xFFFD,
	0xA343: 0xFFFD,
	0xA344: 0xFFFD,
	0xA345: 0xFFFD,
	0xA346: 0xFFFD,
	0xA347: 0xFFFD,
	0xA348: 0xFFFD,
	0xA349: 0xFFFD,
	0xA34A: 0xFFFD,
	0xA34B: 0xFFFD,
	0xA34C: 0xFFFD,
	0xA34D: 0xFFFD,
	0xA34E: 0xFFFD,
	0xA34F: 0xFFFD,
	0xA350: 0xFFFD,
	0xA351: 0xFFFD,
	0xA352: 0xFFFD,
	0xA353: 0xFFFD,
	0xA354: 0xFFFD,
	0xA355: 0xFFFD,
	0xA356: 0xFFFD,
	0xA357: 0xFFFD,
	0xA358: 0xFFFD,
	0xA359: 0xFFFD,
	0xA35A: 0xFFFD,
	0xA35B: 0xFFFD,
	0xA35C: 0xFFFD,
	0xA35D: 0xFFFD,
	0xA35E: 0xFFFD,
	0xA35F: 0xFFFD,
	0xA360: 0xFFFD,
	0xA361: 0xFFFD,
	0xA362: 0xFFFD,
	0xA363: 0xFFFD,
	0xA364: 0xFFFD,
	0xA365: 0xFFFD,
	0xA366: 0xFFFD,
	0xA367: 0xFFFD,
	0xA368: 0xFFFD,
	0xA369: 0xFFFD,
	0xA36A: 0xFFFD,
	0xA36B: 0xFFFD,
	0xA36C: 0xFFFD,
	0xA36D: 0xFFFD,
	0xA36E: 0xFFFD,
	0xA36F: 0xFFFD,
	0xA370: 0xFFFD,
	0xA371: 0xFFFD,
	0xA372: 0xFFFD,
	0xA373: 0xFFFD,
	0xA374: 0xFFFD,
	0xA375: 0xFFFD,
	0xA376: 0xFFFD,
	0xA377: 0xFFFD,
	0xA378: 0xFFFD,
	0xA379: 0xFFFD,
	0xA37A: 0xFFFD,
	0xA37B: 0xFFFD,
	0xA37C: 0xFFFD,
	0xA37D: 0xFFFD,
	0xA37E: 0xFFFD,
	0xA37F: 0xFFFD,
	0xA380: 0xFFFD,
	0xA381: 0xFFFD,
	0xA382: 0xFFFD,
	0xA383: 0xFFFD,
	0xA384: 0xFFFD,
	0xA385: 0xFFFD,
	0xA386: 0xFFFD,
	0xA387: 0xFFFD,
	0xA388: 0xFFFD,
	0xA389: 0xFFFD,
	0xA38A: 0xFFFD,
	0xA38B: 0xFFFD,
	0xA38C: 0xFFFD,
	0xA38D: 0xFFFD,
	0xA38E: 0xFFFD,
	0xA38F: 0xFFFD,
	0xA390: 0xFFFD,
	0xA391: 0xFFFD,
	0xA392: 0xFFFD,
	0xA393: 0xFFFD,
	0xA394: 0xFFFD,
	0xA395: 0xFFFD,
	0xA396: 0xFFFD,
	0xA397: 0xFFFD,
	0xA398: 0xFFFD,
	0xA399: 0xFFFD,
	0xA39A: 0xFFFD,
	0xA39B: 0xFFFD,
	0xA39C: 0xFFFD,
	0xA39D: 0xFFFD,
	0xA39E: 0xFFFD,
	0xA39F: 0xFFFD,
	0xA3A0: 0xFFFD,
	0xA3A1: 0xFFFD,
	0xA3A2: 0xFFFD,
	0xA3A3: 0xFFFD,
	0xA3A4: 0xFFFD,
	0xA3A5: 0xFFFD,
	0xA3A6: 0xFFFD,
	0xA3A7: 0xFFFD,
	0xA3A8: 0xFFFD,
	0xA3A9: 0xFFFD,
	0xA3AA: 0xFFFD,
	0xA3AB: 0xFFFD,
	0xA3AC: 0xFFFD,
	0xA3AD: 0xFFFD,
	0xA3AE: 0xFFFD,
	0xA3AF: 0xFFFD,
	0xA3B0: 0xFFFD,
	0xA3B1: 0xFFFD,
	0xA3B2: 0xFFFD,
	0xA3B3: 0xFFFD,
	0xA3B4: 0xFFFD,
	0xA3B5: 0xFFFD,
	0xA3B6: 0xFFFD,
	0xA3B7: 0xFFFD,
	0xA3B8: 0xFFFD,
	0xA3B9: 0xFFFD,
	0xA3BA: 0xFFFD,
	0xA3BB: 0xFFFD,
	0xA3BC: 0xFFFD,
	0xA3BD: 0xFFFD,
	0xA3BE: 0xFFFD,
	0xA3BF: 0xFFFD,
	0xA3C0: 0xFFFD,
	0xA3C1: 0xFFFD,
	0xA3C2: 0xFFFD,
	0xA3C3: 0xFFFD,
	0xA3C4: 0xFFFD,
	0xA3C5: 0xFFFD,
	0xA3C6: 0xFFFD,
	0xA3C7: 0xFFFD,
	0xA3C8: 0xFFFD,
	0xA3C9: 0xFFFD,
	0xA3CA: 0xFFFD,
	0xA3CB: 0xFFFD,
	0xA3CC: 0xFFFD,
	0xA3CD: 0xFFFD,
	0xA3CE: 0xFFFD,
	0xA3CF: 0xFFFD,
	0xA3D0: 0xFFFD,
	0xA3D1: 0xFFFD,
	0xA3D2: 0xFFFD,
	0xA3D3: 0xFFFD,
	0xA3D4: 0xFFFD,
	0xA3D5: 0xFFFD,
	0xA3D6: 0xFFFD,
	0xA3D7: 0xFFFD,
	0xA3D8: 0xFFFD,
	0xA3D9: 0xFFFD,
	0xA3DA: 0xFFFD,
	0xA3DB: 0xFFFD,
	0xA3DC: 0xFFFD,
	0xA3DD: 0xFFFD,
	0xA3DE: 0xFFFD,
	0xA3DF: 0xFFFD,
	0xA3E0: 0xFFFD,
	0xA3E1: 0xFFFD,
	0xA3E2: 0xFFFD,
	0xA3E3: 0xFFFD,
	0xA3E4: 0xFFFD,
	0xA3E5: 0xFFFD,
	0xA3E6: 0xFFFD,
	0xA3E7: 0xFFFD,
	0xA3E8: 0xFFFD,
	0xA3E9: 0xFFFD,
	0xA3EA: 0xFFFD,
	0xA3EB: 0xFFFD,
	0xA3EC: 0xFFFD,
	0xA3ED: 0xFFFD,
	0xA3EE: 0xFFFD,
	0xA3EF: 0xFFFD,
	0xA3F0: 0xFFFD,
	0xA3F1: 0xFFFD,
	0xA3F2: 0xFFFD,
	0xA3F3: 0xFFFD,
	0xA3F4: 0xFFFD,
	0xA3F5: 0xFFFD,
	0xA3F6: 0xFFFD,
	0xA3F7: 0xFFFD,
	0xA3F8: 0xFFFD,
	0xA3F9: 0xFFFD,
	0xA3FA: 0xFFFD,
	0xA3FB: 0xFFFD,
	0xA3FC: 0xFFFD,
	0xA3FD: 0xFFFD,
	0xA3FE: 0xFFFD,
	0xA3FF: 0xFFFD,
	0xA400: 0xFFFD,
	0xA401: 0xFFFD,
	0xA402: 0xFFFD,
	0xA403: 0xFFFD,
	0xA404: 0xFFFD,
	0xA405: 0xFFFD,
	0xA406: 0xFFFD,
	0xA407: 0xFFFD,
	0xA408: 0xFFFD,
	0xA409: 0xFFFD,
	0xA40A: 0xFFFD,
	0xA40B: 0xFFFD,
	0xA40C: 0xFFFD,
	0xA40D: 0xFFFD,
	0xA40E: 0xFFFD,
	0xA40F: 0xFFFD,
	0xA410: 0xFFFD,
	0xA411: 0xFFFD,
	0xA412: 0xFFFD,
	0xA413: 0xFFFD,
	0xA414: 0xFFFD,
	0xA415: 0xFFFD,
	0xA416: 0xFFFD,
	0xA417: 0xFFFD,
	0xA418: 0xFFFD,
	0xA419: 0xFFFD,
	0xA41A: 0xFFFD,
	0xA41B: 0xFFFD,
	0xA41C: 0xFFFD,
	0xA41D: 0xFFFD,
	0xA41E: 0xFFFD,
	0xA41F: 0xFFFD,
	0xA420: 0xFFFD,
	0xA421: 0xFFFD,
	0xA422: 0xFFFD,
	0xA423: 0xFFFD,
	0xA424: 0xFFFD,
	0xA425: 0xFFFD,
	0xA426: 0xFFFD,
	0xA427: 0xFFFD,
	0xA428: 0xFFFD,
	0xA429: 0xFFFD,
	0xA42A: 0xFFFD,
	0xA42B: 0xFFFD,
	0xA42C: 0xFFFD,
	0xA42D: 0xFFFD,
	0xA42E: 0xFFFD,
	0xA42F: 0xFFFD,
	0xA430: 0xFFFD,
	0xA431: 0xFFFD,
	0xA432: 0xFFFD,
	0xA433: 0xFFFD,
	0xA434: 0xFFFD,
	0xA435: 0xFFFD,
	0xA436: 0xFFFD,
	0xA437: 0xFFFD,
	0xA438: 0xFFFD,
	0xA439: 0xFFFD,
	0xA43A: 0xFFFD,
	0xA43B: 0xFFFD,
	0xA43C: 0xFFFD,
	0xA43D: 0xFFFD,
	0xA43E: 0xFFFD,
	0xA43F: 0xFFFD,
	0xA440: 0xFFFD,
	0xA441: 0xFFFD,
	0xA442: 0xFFFD,
	0xA443: 0xFFFD,
	0xA444: 0xFFFD,
	0xA445: 0xFFFD,
	0xA446: 0xFFFD,
	0xA447: 0xFFFD,
	0xA448: 0xFFFD,
	0xA449: 0xFFFD,
	0xA44A: 0xFFFD,
	0xA44B: 0xFFFD,
	0xA44C: 0xFFFD,
	0xA44D: 0xFFFD,
	0xA44E: 0xFFFD,
	0xA44F: 0xFFFD,
	0xA450: 0xFFFD,
	0xA451: 0xFFFD,
	0xA452: 0xFFFD,
	0xA453: 0xFFFD,
	0xA454: 0xFFFD,
	0xA455: 0xFFFD,
	0xA456: 0xFFFD,
	0xA457: 0xFFFD,
	0xA458: 0xFFFD,
	0xA459: 0xFFFD,
	0xA45A: 0xFFFD,
	0xA45B: 0xFFFD,
	0xA45C: 0xFFFD,
	0xA45D: 0xFFFD,
	0xA45E: 0xFFFD,
	0xA45F: 0xFFFD,
	0xA460: 0xFFFD,
	0xA461: 0xFFFD,
	0xA462: 0xFFFD,
	0xA463: 0xFFFD,
	0xA464: 0xFFFD,
	0xA465: 0xFFFD,
	0xA466: 0xFFFD,
	0xA467: 0xFFFD,
	0xA468: 0xFFFD,
	0xA469: 0xFFFD,
	0xA46A: 0xFFFD,
	0xA46B: 0xFFFD,
	0xA46C: 0xFFFD,
	0xA46D: 0xFFFD,
	0xA46E: 0xFFFD,
	0xA46F: 0xFFFD,
	0xA470: 0xFFFD,
	0xA471: 0xFFFD,
	0xA472: 0xFFFD,
	0xA473: 0xFFFD,
	0xA474: 0xFFFD,
	0xA475: 0xFFFD,
	0xA476: 0xFFFD,
	0xA477: 0xFFFD,
	0xA478: 0xFFFD,
	0xA479: 0xFFFD,
	0xA47A: 0xFFFD,
	0xA47B: 0xFFFD,
	0xA47C: 0xFFFD,
	0xA47D: 0xFFFD,
	0xA47E: 0xFFFD,
	0xA47F: 0xFFFD,
	0xA480: 0xFFFD,
	0xA481: 0xFFFD,
	0xA482: 0xFFFD,
	0xA483: 0xFFFD,
	0xA484: 0xFFFD,
	0xA485: 0xFFFD,
	0xA486: 0xFFFD,
	0xA487: 0xFFFD,
	0xA488: 0xFFFD,
	0xA489: 0xFFFD,
	0xA48A: 0xFFFD,
	0xA48B: 0xFFFD,
	0xA48C: 0xFFFD,
	0xA48D: 0xFFFD,
	0xA48E: 0xFFFD,
	0xA48F: 0xFFFD,
	0xA490: 0xFFFD,
	0xA491: 0xFFFD,
	0xA492: 0xFFFD,
	0xA493: 0xFFFD,
	0xA494: 0xFFFD,
	0xA495: 0xFFFD,
	0xA496: 0xFFFD,
	0xA497: 0xFFFD,
	0xA498: 0xFFFD,
	0xA499: 0xFFFD,
	0xA49A: 0xFFFD,
	0xA49B: 0xFFFD,
	0xA49C: 0xFFFD,
	0xA49D: 0xFFFD,
	0xA49E: 0xFFFD,
	0xA49F: 0xFFFD,
	0xA4A0: 0xFFFD,
	0xA4A1: 0xFFFD,
	0xA4A2: 0xFFFD,
	0xA4A3: 0xFFFD,
	0xA4A4: 0xFFFD,
	0xA4A5: 0xFFFD,
	0xA4A6: 0xFFFD,
	0xA4A7: 0xFFFD,
	0xA4A8: 0xFFFD,
	0xA4A9: 0xFFFD,
	0xA4AA: 0xFFFD,
	0xA4AB: 0xFFFD,
	0xA4AC: 0xFFFD,
	0xA4AD: 0xFFFD,
	0xA4AE: 0xFFFD,
	0xA4AF: 0xFFFD,
	0xA4B0: 0xFFFD,
	0xA4B1: 0xFFFD,
	0xA4B2: 0xFFFD,
	0xA4B3: 0xFFFD,
	0xA4B4: 0xFFFD,
	0xA4B5: 0xFFFD,
	0xA4B6: 0xFFFD,
	0xA4B7: 0xFFFD,
	0xA4B8: 0xFFFD,
	0xA4B9: 0xFFFD,
	0xA4BA: 0xFFFD,
	0xA4BB: 0xFFFD,
	0xA4BC: 0xFFFD,
	0xA4BD: 0xFFFD,
	0xA4BE: 0xFFFD,
	0xA4BF: 0xFFFD,
	0xA4C0: 0xFFFD,
	0xA4C1: 0xFFFD,
	0xA4C2: 0xFFFD,
	0xA4C3: 0xFFFD,
	0xA4C4: 0xFFFD,
	0xA4C5: 0xFFFD,
	0xA4C6: 0xFFFD,
	0xA4C7: 0xFFFD,
	0xA4C8: 0xFFFD,
	0xA4C9: 0xFFFD,
	0xA4CA: 0xFFFD,
	0xA4CB: 0xFFFD,
	0xA4CC: 0xFFFD,
	0xA4CD: 0xFFFD,
	0xA4CE: 0xFFFD,
	0xA4CF: 0xFFFD,
	0xA4D0: 0xFFFD,
	0xA4D1: 0xFFFD,
	0xA4D2: 0xFFFD,
	0xA4D3: 0xFFFD,
	0xA4D4: 0xFFFD,
	0xA4D5: 0xFFFD,
	0xA4D6: 0xFFFD,
	0xA4D7: 0xFFFD,
	0xA4D8: 0xFFFD,
	0xA4D9: 0xFFFD,
	0xA4DA: 0xFFFD,
	0xA4DB: 0xFFFD,
	0xA4DC: 0xFFFD,
	0xA4DD: 0xFFFD,
	0xA4DE: 0xFFFD,
	0xA4DF: 0xFFFD,
	0xA4E0: 0xFFFD,
	0xA4E1: 0xFFFD,
	0xA4E2: 0xFFFD,
	0xA4E3: 0xFFFD,
	0xA4E4: 0xFFFD,
	0xA4E5: 0xFFFD,
	0xA4E6: 0xFFFD,
	0xA4E7: 0xFFFD,
	0xA4E8: 0xFFFD,
	0xA4E9: 0xFFFD,
	0xA4EA: 0xFFFD,
	0xA4EB: 0xFFFD,
	0xA4EC: 0xFFFD,
	0xA4ED: 0xFFFD,
	0xA4EE: 0xFFFD,
	0xA4EF: 0xFFFD,
	0xA4F0: 0xFFFD,
	0xA4F1: 0xFFFD,
	0xA4F2: 0xFFFD,
	0xA4F3: 0xFFFD,
	0xA4F4: 0xFFFD,
	0xA4F5: 0xFFFD,
	0xA4F6: 0xFFFD,
	0xA4F7: 0xFFFD,
	0xA4F8: 0xFFFD,
	0xA4F9: 0xFFFD,
	0xA4FA: 0xFFFD,
	0xA4FB: 0xFFFD,
	0xA4FC: 0xFFFD,
	0xA4FD: 0xFFFD,
	0xA4FE: 0xFFFD,
	0xA4FF: 0xFFFD,
	0xA500: 0xFFFD,
	0xA501: 0xFFFD,
	0xA502: 0xFFFD,
	0xA503: 0xFFFD,
	0xA504: 0xFFFD,
	0xA505: 0xFFFD,
	0xA506: 0xFFFD,
	0xA507: 0xFFFD,
	0xA508: 0xFFFD,
	0xA509: 0xFFFD,
	0xA50A: 0xFFFD,
	0xA50B: 0xFFFD,
	0xA50C: 0xFFFD,
	0xA50D: 0xFFFD,
	0xA50E: 0xFFFD,
	0xA50F: 0xFFFD,
	0xA510: 0xFFFD,
	0xA511: 0xFFFD,
	0xA512: 0xFFFD,
	0xA513: 0xFFFD,
	0xA514: 0xFFFD,
	0xA515: 0xFFFD,
	0xA516: 0xFFFD,
	0xA517: 0xFFFD,
	0xA518: 0xFFFD,
	0xA519: 0xFFFD,
	0xA51A: 0xFFFD,
	0xA51B: 0xFFFD,
	0xA51C: 0xFFFD,
	0xA51D: 0xFFFD,
	0xA51E: 0xFFFD,
	0xA51F: 0xFFFD,
	0xA520: 0xFFFD,
	0xA521: 0xFFFD,
	0xA522: 0xFFFD,
	0xA523: 0xFFFD,
	0xA524: 0xFFFD,
	0xA525: 0xFFFD,
	0xA526: 0xFFFD,
	0xA527: 0xFFFD,
	0xA528: 0xFFFD,
	0xA529: 0xFFFD,
	0xA52A: 0xFFFD,
	0xA52B: 0xFFFD,
	0xA52C: 0xFFFD,
	0xA52D: 0xFFFD,
	0xA52E: 0xFFFD,
	0xA52F: 0xFFFD,
	0xA530: 0xFFFD,
	0xA531: 0xFFFD,
	0xA532: 0xFFFD,
	0xA533: 0xFFFD,
	0xA534: 0xFFFD,
	0xA535: 0xFFFD,
	0xA536: 0xFFFD,
	0xA537: 0xFFFD,
	0xA538: 0xFFFD,
	0xA539: 0xFFFD,
	0xA53A: 0xFFFD,
	0xA53B: 0xFFFD,
	0xA53C: 0xFFFD,
	0xA53D: 0xFFFD,
	0xA53E: 0xFFFD,
	0xA53F: 0xFFFD,
	0xA540: 0xFFFD,
	0xA541: 0xFFFD,
	0xA542: 0xFFFD,
	0xA543: 0xFFFD,
	0xA544: 0xFFFD,
	0xA545: 0xFFFD,
	0xA546: 0xFFFD,
	0xA547: 0xFFFD,
	0xA548: 0xFFFD,
	0xA549: 0xFFFD,
	0xA54A: 0xFFFD,
	0xA54B: 0xFFFD,
	0xA54C: 0xFFFD,
	0xA54D: 0xFFFD,
	0xA54E: 0xFFFD,
	0xA54F: 0xFFFD,
	0xA550: 0xFFFD,
	0xA551: 0xFFFD,
	0xA552: 0xFFFD,
	0xA553: 0xFFFD,
	0xA554: 0xFFFD,
	0xA555: 0xFFFD,
	0xA556: 0xFFFD,
	0xA557: 0xFFFD,
	0xA558: 0xFFFD,
	0xA559: 0xFFFD,
	0xA55A: 0xFFFD,
	0xA55B: 0xFFFD,
	0xA55C: 0xFFFD,
	0xA55D: 0xFFFD,
	0xA55E: 0xFFFD,
	0xA55F: 0xFFFD,
	0xA560: 0xFFFD,
	0xA561: 0xFFFD,
	0xA562: 0xFFFD,
	0xA563: 0xFFFD,
	0xA564: 0xFFFD,
	0xA565: 0xFFFD,
	0xA566: 0xFFFD,
	0xA567: 0xFFFD,
	0xA568: 0xFFFD,
	0xA569: 0xFFFD,
	0xA56A: 0xFFFD,
	0xA56B: 0xFFFD,
	0xA56C: 0xFFFD,
	0xA56D: 0xFFFD,
	0xA56E: 0xFFFD,
	0xA56F: 0xFFFD,
	0xA570: 0xFFFD,
	0xA571: 0xFFFD,
	0xA572: 0xFFFD,
	0xA573: 0xFFFD,
	0xA574: 0xFFFD,
	0xA575: 0xFFFD,
	0xA576: 0xFFFD,
	0xA577: 0xFFFD,
	0xA578: 0xFFFD,
	0xA579: 0xFFFD,
	0xA57A: 0xFFFD,
	0xA57B: 0xFFFD,
	0xA57C: 0xFFFD,
	0xA57D: 0xFFFD,
	0xA57E: 0xFFFD,
	0xA57F: 0xFFFD,
	0xA580: 0xFFFD,
	0xA581: 0xFFFD,
	0xA582: 0xFFFD,
	0xA583: 0xFFFD,
	0xA584: 0xFFFD,
	0xA585: 0xFFFD,
	0xA586: 0xFFFD,
	0xA587: 0xFFFD,
	0xA588: 0xFFFD,
	0xA589: 0xFFFD,
	0xA58A: 0xFFFD,
	0xA58B: 0xFFFD,
	0xA58C: 0xFFFD,
	0xA58D: 0xFFFD,
	0xA58E: 0xFFFD,
	0xA58F: 0xFFFD,
	0xA590: 0xFFFD,
	0xA591: 0xFFFD,
	0xA592: 0xFFFD,
	0xA593: 0xFFFD,
	0xA594: 0xFFFD,
	0xA595: 0xFFFD,
	0xA596: 0xFFFD,
	0xA597: 0xFFFD,
	0xA598: 0xFFFD,
	0xA599: 0xFFFD,
	0xA59A: 0xFFFD,
	0xA59B: 0xFFFD,
	0xA59C: 0xFFFD,
	0xA59D: 0xFFFD,
	0xA59E: 0xFFFD,
	0xA59F: 0xFFFD,
	0xA5A0: 0xFFFD,
	0xA5A1: 0xFFFD,
	0xA5A2: 0xFFFD,
	0xA5A3: 0xFFFD,
	0xA5A4: 0xFFFD,
	0xA5A5: 0xFFFD,
	0xA5A6: 0xFFFD,
	0xA5A7: 0xFFFD,
	0xA5A8: 0xFFFD,
	0xA5A9: 0xFFFD,
	0xA5AA: 0xFFFD,
	0xA5AB: 0xFFFD,
	0xA5AC: 0xFFFD,
	0xA5AD: 0xFFFD,
	0xA5AE: 0xFFFD,
	0xA5AF: 0xFFFD,
	0xA5B0: 0xFFFD,
	0xA5B1: 0xFFFD,
	0xA5B2: 0xFFFD,
	0xA5B3: 0xFFFD,
	0xA5B4: 0xFFFD,
	0xA5B5: 0xFFFD,
	0xA5B6: 0xFFFD,
	0xA5B7: 0xFFFD,
	0xA5B8: 0xFFFD,
	0xA5B9: 0xFFFD,
	0xA5BA: 0xFFFD,
	0xA5BB: 0xFFFD,
	0xA5BC: 0xFFFD,
	0xA5BD: 0xFFFD,
	0xA5BE: 0xFFFD,
	0xA5BF: 0xFFFD,
	0xA5C0: 0xFFFD,
	0xA5C1: 0xFFFD,
	0xA5C2: 0xFFFD,
	0xA5C3: 0xFFFD,
	0xA5C4: 0xFFFD,
	0xA5C5: 0xFFFD,
	0xA5C6: 0xFFFD,
	0xA5C7: 0xFFFD,
	0xA5C8: 0xFFFD,
	0xA5C9: 0xFFFD,
	0xA5CA: 0xFFFD,
	0xA5CB: 0xFFFD,
	0xA5CC: 0xFFFD,
	0xA5CD: 0xFFFD,
	0xA5CE: 0xFFFD,
	0xA5CF: 0xFFFD,
	0xA5D0: 0xFFFD,
	0xA5D1: 0xFFFD,
	0xA5D2: 0xFFFD,
	0xA5D3: 0xFFFD,
	0xA5D4: 0xFFFD,
	0xA5D5: 0xFFFD,
	0xA5D6: 0xFFFD,
	0xA5D7: 0xFFFD,
	0xA5D8: 0xFFFD,
	0xA5D9: 0xFFFD,
	0xA5DA: 0xFFFD,
	0xA5DB: 0xFFFD,
	0xA5DC: 0xFFFD,
	0xA5DD: 0xFFFD,
	0xA5DE: 0xFFFD,
	0xA5DF: 0xFFFD,
	0xA5E0: 0xFFFD,
	0xA5E1: 0xFFFD,
	0xA5E2: 0xFFFD,
	0xA5E3: 0xFFFD,
	0xA5E4: 0xFFFD,
	0xA5E5: 0xFFFD,
	0xA5E6: 0xFFFD,
	0xA5E7: 0xFFFD,
	0xA5E8: 0xFFFD,
	0xA5E9: 0xFFFD,
	0xA5EA: 0xFFFD,
	0xA5EB: 0xFFFD,
	0xA5EC: 0xFFFD,
	0xA5ED: 0xFFFD,
	0xA5EE: 0xFFFD,
	0xA5EF: 0xFFFD,
	0xA5F0: 0xFFFD,
	0xA5F1: 0xFFFD,
	0xA5F2: 0xFFFD,
	0xA5F3: 0xFFFD,
	0xA5F4: 0xFFFD,
	0xA5F5: 0xFFFD,
	0xA5F6: 0xFFFD,
	0xA5F7: 0xFFFD,
	0xA5F8: 0xFFFD,
	0xA5F9: 0xFFFD,
	0xA5FA: 0xFFFD,
	0xA5FB: 0xFFFD,
	0xA5FC: 0xFFFD,
	0xA5FD: 0xFFFD,
	0xA5FE: 0xFFFD,
	0xA5FF: 0xFFFD,
	0xA600: 0xFFFD,
	0xA601: 0xFFFD,
	0xA602: 0xFFFD,
	0xA603: 0xFFFD,
	0xA604: 0xFFFD,
	0xA605: 0xFFFD,
	0xA606: 0xFFFD,
	0xA607: 0xFFFD,
	0xA608: 0xFFFD,
	0xA609: 0xFFFD,
	0xA60A: 0xFFFD,
	0xA60B: 0xFFFD,
	0xA60C: 0xFFFD,
	0xA60D: 0xFFFD,
	0xA60E: 0xFFFD,
	0xA60F: 0xFFFD,
	0xA610: 0xFFFD,
	0xA611: 0xFFFD,
	0xA612: 0xFFFD,
	0xA613: 0xFFFD,
	0xA614: 0xFFFD,
	0xA615: 0xFFFD,
	0xA616: 0xFFFD,
	0xA617: 0xFFFD,
	0xA618: 0xFFFD,
	0xA619: 0xFFFD,
	0xA61A: 0xFFFD,
	0xA61B: 0xFFFD,
	0xA61C: 0xFFFD,
	0xA61D: 0xFFFD,
	0xA61E: 0xFFFD,
	0xA61F: 0xFFFD,
	0xA620: 0xFFFD,
	0xA621: 0xFFFD,
	0xA622: 0xFFFD,
	0xA623: 0xFFFD,
	0xA624: 0xFFFD,
	0xA625: 0xFFFD,
	0xA626: 0xFFFD,
	0xA627: 0xFFFD,
	0xA628: 0xFFFD,
	0xA629: 0xFFFD,
	0xA62A: 0xFFFD,
	0xA62B: 0xFFFD,
	0xA62C: 0xFFFD,
	0xA62D: 0xFFFD,
	0xA62E: 0xFFFD,
	0xA62F: 0xFFFD,
	0xA630: 0xFFFD,
	0xA631: 0xFFFD,
	0xA632: 0xFFFD,
	0xA633: 0xFFFD,
	0xA634: 0xFFFD,
	0xA635: 0xFFFD,
	0xA636: 0xFFFD,
	0xA637: 0xFFFD,
	0xA638: 0xFFFD,
	0xA639: 0xFFFD,
	0xA63A: 0xFFFD,
	0xA63B: 0xFFFD,
	0xA63C: 0xFFFD,
	0xA63D: 0xFFFD,
	0xA63E: 0xFFFD,
	0xA63F: 0xFFFD,
	0xA640: 0xFFFD,
	0xA641: 0xFFFD,
	0xA642: 0xFFFD,
	0xA643: 0xFFFD,
	0xA644: 0xFFFD,
	0xA645: 0xFFFD,
	0xA646: 0xFFFD,
	0xA647: 0xFFFD,
	0xA648: 0xFFFD,
	0xA649: 0xFFFD,
	0xA64A: 0xFFFD,
	0xA64B: 0xFFFD,
	0xA64C: 0xFFFD,
	0xA64D: 0xFFFD,
	0xA64E: 0xFFFD,
	0xA64F: 0xFFFD,
	0xA650: 0xFFFD,
	0xA651: 0xFFFD,
	0xA652: 0xFFFD,
	0xA653: 0xFFFD,
	0xA654: 0xFFFD,
	0xA655: 0xFFFD,
	0xA656: 0xFFFD,
	0xA657: 0xFFFD,
	0xA658: 0xFFFD,
	0xA659: 0xFFFD,
	0xA65A: 0xFFFD,
	0xA65B: 0xFFFD,
	0xA65C: 0xFFFD,
	0xA65D: 0xFFFD,
	0xA65E: 0xFFFD,
	0xA65F: 0xFFFD,
	0xA660: 0xFFFD,
	0xA661: 0xFFFD,
	0xA662: 0xFFFD,
	0xA663: 0xFFFD,
	0xA664: 0xFFFD,
	0xA665: 0xFFFD,
	0xA666: 0xFFFD,
	0xA667: 0xFFFD,
	0xA668: 0xFFFD,
	0xA669: 0xFFFD,
	0xA66A: 0xFFFD,
	0xA66B: 0xFFFD,
	0xA66C: 0xFFFD,
	0xA66D: 0xFFFD,
	0xA66E: 0xFFFD,
	0xA66F: 0xFFFD,
	0xA670: 0xFFFD,
	0xA671: 0xFFFD,
	0xA672: 0xFFFD,
	0xA673: 0xFFFD,
	0xA674: 0xFFFD,
	0xA675: 0xFFFD,
	0xA676: 0xFFFD,
	0xA677: 0xFFFD,
	0xA678: 0xFFFD,
	0xA679: 0xFFFD,
	0xA67A: 0xFFFD,
	0xA67B: 0xFFFD,
	0xA67C: 0xFFFD,
	0xA67D: 0xFFFD,
	0xA67E: 0xFFFD,
	0xA67F: 0xFFFD,
	0xA680: 0xFFFD,
	0xA681: 0xFFFD,
	0xA682: 0xFFFD,
	0xA683: 0xFFFD,
	0xA684: 0xFFFD,
	0xA685: 0xFFFD,
	0xA686: 0xFFFD,
	0xA687: 0xFFFD,
	0xA688: 0xFFFD,
	0xA689: 0xFFFD,
	0xA68A: 0xFFFD,
	0xA68B: 0xFFFD,
	0xA68C: 0xFFFD,
	0xA68D: 0xFFFD,
	0xA68E: 0xFFFD,
	0xA68F: 0xFFFD,
	0xA690: 0xFFFD,
	0xA691: 0xFFFD,
	0xA692: 0xFFFD,
	0xA693: 0xFFFD,
	0xA694: 0xFFFD,
	0xA695: 0xFFFD,
	0xA696: 0xFFFD,
	0xA697: 0xFFFD,
	0xA698: 0xFFFD,
	0xA699: 0xFFFD,
	0xA69A: 0xFFFD,
	0xA69B: 0xFFFD,
	0xA69C: 0xFFFD,
	0xA69D: 0xFFFD,
	0xA69E: 0xFFFD,
	0xA69F: 0xFFFD,
	0xA6A0: 0xFFFD,
	0xA6A1: 0xFFFD,
	0xA6A2: 0xFFFD,
	0xA6A3: 0xFFFD,
	0xA6A4: 0xFFFD,
	0xA6A5: 0xFFFD,
	0xA6A6: 0xFFFD,
	0xA6A7: 0xFFFD,
	0xA6A8: 0xFFFD,
	0xA6A9: 0xFFFD,
	0xA6AA: 0xFFFD,
	0xA6AB: 0xFFFD,
	0xA6AC: 0xFFFD,
	0xA6AD: 0xFFFD,
	0xA6AE: 0xFFFD,
	0xA6AF: 0xFFFD,
	0xA6B0: 0xFFFD,
	0xA6B1: 0xFFFD,
	0xA6B2: 0xFFFD,
	0xA6B3: 0xFFFD,
	0xA6B4: 0xFFFD,
	0xA6B5: 0xFFFD,
	0xA6B6: 0xFFFD,
	0xA6B7: 0xFFFD,
	0xA6B8: 0xFFFD,
	0xA6B9: 0xFFFD,
	0xA6BA: 0xFFFD,
	0xA6BB: 0xFFFD,
	0xA6BC: 0xFFFD,
	0xA6BD: 0xFFFD,
	0xA6BE: 0xFFFD,
	0xA6BF: 0xFFFD,
	0xA6C0: 0xFFFD,
	0xA6C1: 0xFFFD,
	0xA6C2: 0xFFFD,
	0xA6C3: 0xFFFD,
	0xA6C4: 0xFFFD,
	0xA6C5: 0xFFFD,
	0xA6C6: 0xFFFD,
	0xA6C7: 0xFFFD,
	0xA6C8: 0xFFFD,
	0xA6C9: 0xFFFD,
	0xA6CA: 0xFFFD,
	0xA6CB: 0xFFFD,
	0xA6CC: 0xFFFD,
	0xA6CD: 0xFFFD,
	0xA6CE: 0xFFFD,
	0xA6CF: 0xFFFD,
	0xA6D0: 0xFFFD,
	0xA6D1: 0xFFFD,
	0xA6D2: 0xFFFD,
	0xA6D3: 0xFFFD,
	0xA6D4: 0xFFFD,
	0xA6D5: 0xFFFD,
	0xA6D6: 0xFFFD,
	0xA6D7: 0xFFFD,
	0xA6D8: 0xFFFD,
	0xA6D9: 0xFFFD,
	0xA6DA: 0xFFFD,
	0xA6DB: 0xFFFD,
	0xA6DC: 0xFFFD,
	0xA6DD: 0xFFFD,
	0xA6DE: 0xFFFD,
	0xA6DF: 0xFFFD,
	0xA6E0: 0xFFFD,
	0xA6E1: 0xFFFD,
	0xA6E2: 0xFFFD,
	0xA6E3: 0xFFFD,
	0xA6E4: 0xFFFD,
	0xA6E5: 0xFFFD,
	0xA6E6: 0xFFFD,
	0xA6E7: 0xFFFD,
	0xA6E8: 0xFFFD,
	0xA6E9: 0xFFFD,
	0xA6EA: 0xFFFD,
	0xA6EB: 0xFFFD,
	0xA6EC: 0xFFFD,
	0xA6ED: 0xFFFD,
	0xA6EE: 0xFFFD,
	0xA6EF: 0xFFFD,
	0xA6F0: 0xFFFD,
	0xA6F1: 0xFFFD,
	0xA6F2: 0xFFFD,
	0xA6F3: 0xFFFD,
	0xA6F4: 0xFFFD,
	0xA6F5: 0xFFFD,
	0xA6F6: 0xFFFD,
	0xA6F7: 0xFFFD,
	0xA6F8: 0xFFFD,
	0xA6F9: 0xFFFD,
	0xA6FA: 0xFFFD,
	0xA6FB: 0xFFFD,
	0xA6FC: 0xFFFD,
	0xA6FD: 0xFFFD,
	0xA6FE: 0xFFFD,
	0xA6FF: 0xFFFD,
	0xA700: 0xFFFD,
	0xA701: 0xFFFD,
	0xA702: 0xFFFD,
	0xA703: 0xFFFD,
	0xA704: 0xFFFD,
	0xA705: 0xFFFD,
	0xA706: 0xFFFD,
	0xA707: 0xFFFD,
	0xA708: 0xFFFD,
	0xA709: 0xFFFD,
	0xA70A: 0xFFFD,
	0xA70B: 0xFFFD,
	0xA70C: 0xFFFD,
	0xA70D: 0xFFFD,
	0xA70E: 0xFFFD,
	0xA70F: 0xFFFD,
	0xA710: 0xFFFD,
	0xA711: 0xFFFD,
	0xA712: 0xFFFD,
	0xA713: 0xFFFD,
	0xA714: 0xFFFD,
	0xA715: 0xFFFD,
	0xA716: 0xFFFD,
	0xA717: 0xFFFD,
	0xA718: 0xFFFD,
	0xA719: 0xFFFD,
	0xA71A: 0xFFFD,
	0xA71B: 0xFFFD,
	0xA71C: 0xFFFD,
	0xA71D: 0xFFFD,
	0xA71E: 0xFFFD,
	0xA71F: 0xFFFD,
	0xA720: 0xFFFD,
	0xA721: 0xFFFD,
	0xA722: 0xFFFD,
	0xA723: 0xFFFD,
	0xA724: 0xFFFD,
	0xA725: 0xFFFD,
	0xA726: 0xFFFD,
	0xA727: 0xFFFD,
	0xA728: 0xFFFD,
	0xA729: 0xFFFD,
	0xA72A: 0xFFFD,
	0xA72B: 0xFFFD,
	0xA72C: 0xFFFD,
	0xA72D: 0xFFFD,
	0xA72E: 0xFFFD,
	0xA72F: 0xFFFD,
	0xA730: 0xFFFD,
	0xA731: 0xFFFD,
	0xA732: 0xFFFD,
	0xA733: 0xFFFD,
	0xA734: 0xFFFD,
	0xA735: 0xFFFD,
	0xA736: 0xFFFD,
	0xA737: 0xFFFD,
	0xA738: 0xFFFD,
	0xA739: 0xFFFD,
	0xA73A: 0xFFFD,
	0xA73B: 0xFFFD,
	0xA73C: 0xFFFD,
	0xA73D: 0xFFFD,
	0xA73E: 0xFFFD,
	0xA73F: 0xFFFD,
	0xA740: 0xFFFD,
	0xA741: 0xFFFD,
	0xA742: 0xFFFD,
	0xA743: 0xFFFD,
	0xA744: 0xFFFD,
	0xA745: 0xFFFD,
	0xA746: 0xFFFD,
	0xA747: 0xFFFD,
	0xA748: 0xFFFD,
	0xA749: 0xFFFD,
	0xA74A: 0xFFFD,
	0xA74B: 0xFFFD,
	0xA74C: 0xFFFD,
	0xA74D: 0xFFFD,
	0xA74E: 0xFFFD,
	0xA74F: 0xFFFD,
	0xA750: 0xFFFD,
	0xA751: 0xFFFD,
	0xA752: 0xFFFD,
	0xA753: 0xFFFD,
	0xA754: 0xFFFD,
	0xA755: 0xFFFD,
	0xA756: 0xFFFD,
	0xA757: 0xFFFD,
	0xA758: 0xFFFD,
	0xA759: 0xFFFD,
	0xA75A: 0xFFFD,
	0xA75B: 0xFFFD,
	0xA75C: 0xFFFD,
	0xA75D: 0xFFFD,
	0xA75E: 0xFFFD,
	0xA75F: 0xFFFD,
	0xA760: 0xFFFD,
	0xA761: 0xFFFD,
	0xA762: 0xFFFD,
	0xA763: 0xFFFD,
	0xA764: 0xFFFD,
	0xA765: 0xFFFD,
	0xA766: 0xFFFD,
	0xA767: 0xFFFD,
	0xA768: 0xFFFD,
	0xA769: 0xFFFD,
	0xA76A: 0xFFFD,
	0xA76B: 0xFFFD,
	0xA76C: 0xFFFD,
	0xA76D: 0xFFFD,
	0xA76E: 0xFFFD,
	0xA76F: 0xFFFD,
	0xA770: 0xFFFD,
	0xA771: 0xFFFD,
	0xA772: 0xFFFD,
	0xA773: 0xFFFD,
	0xA774: 0xFFFD,
	0xA775: 0xFFFD,
	0xA776: 0xFFFD,
	0xA777: 0xFFFD,
	0xA778: 0xFFFD,
	0xA779: 0xFFFD,
	0xA77A: 0xFFFD,
	0xA77B: 0xFFFD,
	0xA77C: 0xFFFD,
	0xA77D: 0xFFFD,
	0xA77E: 0xFFFD,
	0xA77F: 0xFFFD,
	0xA780: 0xFFFD,
	0xA781: 0xFFFD,
	0xA782: 0xFFFD,
	0xA783: 0xFFFD,
	0xA784: 0xFFFD,
	0xA785: 0xFFFD,
	0xA786: 0xFFFD,
	0xA787: 0xFFFD,
	0xA788: 0xFFFD,
	0xA789: 0xFFFD,
	0xA78A: 0xFFFD,
	0xA78B: 0xFFFD,
	0xA78C: 0xFFFD,
	0xA78D: 0xFFFD,
	0xA78E: 0xFFFD,
	0xA78F: 0xFFFD,
	0xA790: 0xFFFD,
	0xA791: 0xFFFD,
	0xA792: 0xFFFD,
	0xA793: 0xFFFD,
	0xA794: 0xFFFD,
	0xA795: 0xFFFD,
	0xA796: 0xFFFD,
	0xA797: 0xFFFD,
	0xA798: 0xFFFD,
	0xA799: 0xFFFD,
	0xA79A: 0xFFFD,
	0xA79B: 0xFFFD,
	0xA79C: 0xFFFD,
	0xA79D: 0xFFFD,
	0xA79E: 0xFFFD,
	0xA79F: 0xFFFD,
	0xA7A0: 0xFFFD,
	0xA7A1: 0xFFFD,
	0xA7A2: 0xFFFD,
	0xA7A3: 0xFFFD,
	0xA7A4: 0xFFFD,
	0xA7A5: 0xFFFD,
	0xA7A6: 0xFFFD,
	0xA7A7: 0xFFFD,
	0xA7A8: 0xFFFD,
	0xA7A9: 0xFFFD,
	0xA7AA: 0xFFFD,
	0xA7AB: 0xFFFD,
	0xA7AC: 0xFFFD,
	0xA7AD: 0xFFFD,
	0xA7AE: 0xFFFD,
	0xA7AF: 0xFFFD,
	0xA7B0: 0xFFFD,
	0xA7B1: 0xFFFD,
	0xA7B2: 0xFFFD,
	0xA7B3: 0xFFFD,
	0xA7B4: 0xFFFD,
	0xA7B5: 0xFFFD,
	0xA7B6: 0xFFFD,
	0xA7B7: 0xFFFD,
	0xA7B8: 0xFFFD,
	0xA7B9: 0xFFFD,
	0xA7BA: 0xFFFD,
	0xA7BB: 0xFFFD,
	0xA7BC: 0xFFFD,
	0xA7BD: 0xFFFD,
	0xA7BE: 0xFFFD,
	0xA7BF: 0xFFFD,
	0xA7C0: 0xFFFD,
	0xA7C1: 0xFFFD,
	0xA7C2: 0xFFFD,
	0xA7C3: 0xFFFD,
	0xA7C4: 0xFFFD,
	0xA7C5: 0xFFFD,
	0xA7C6: 0xFFFD,
	0xA7C7: 0xFFFD,
	0xA7C8: 0xFFFD,
	0xA7C9: 0xFFFD,
	0xA7CA: 0xFFFD,
	0xA7CB: 0xFFFD,
	0xA7CC: 0xFFFD,
	0xA7CD: 0xFFFD,
	0xA7CE: 0xFFFD,
	0xA7CF: 0xFFFD,
	0xA7D0: 0xFFFD,
	0xA7D1: 0xFFFD,
	0xA7D2: 0xFFFD,
	0xA7D3: 0xFFFD,
	0xA7D4: 0xFFFD,
	0xA7D5: 0xFFFD,
	0xA7D6: 0xFFFD,
	0xA7D7: 0xFFFD,
	0xA7D8: 0xFFFD,
	0xA7D9: 0xFFFD,
	0xA7DA: 0xFFFD,
	0xA7DB: 0xFFFD,
	0xA7DC: 0xFFFD,
	0xA7DD: 0xFFFD,
	0xA7DE: 0xFFFD,
	0xA7DF: 0xFFFD,
	0xA7E0: 0xFFFD,
	0xA7E1: 0xFFFD,
	0xA7E2: 0xFFFD,
	0xA7E3: 0xFFFD,
	0xA7E4: 0xFFFD,
	0xA7E5: 0xFFFD,
	0xA7E6: 0xFFFD,
	0xA7E7: 0xFFFD,
	0xA7E8: 0xFFFD,
	0xA7E9: 0xFFFD,
	0xA7EA: 0xFFFD,
	0xA7EB: 0xFFFD,
	0xA7EC: 0xFFFD,
	0xA7ED: 0xFFFD,
	0xA7EE: 0xFFFD,
	0xA7EF: 0xFFFD,
	0xA7F0: 0xFFFD,
	0xA7F1: 0xFFFD,
	0xA7F2: 0xFFFD,
	0xA7F3: 0xFFFD,
	0xA7F4: 0xFFFD,
	0xA7F5: 0xFFFD,
	0xA7F6: 0xFFFD,
	0xA7F7: 0xFFFD,
	0xA7F8: 0xFFFD,
	0xA7F9: 0xFFFD,
	0xA7FA: 0xFFFD,
	0xA7FB: 0xFFFD,
	0xA7FC: 0xFFFD,
	0xA7FD: 0xFFFD,
	0xA7FE: 0xFFFD,
	0xA7FF: 0xFFFD,
	0xA800: 0xFFFD,
	0xA801: 0xFFFD,
	0xA802: 0xFFFD,
	0xA803: 0xFFFD,
	0xA804: 0xFFFD,
	0xA805: 0xFFFD,
	0xA806: 0xFFFD,
	0xA807: 0xFFFD,
	0xA808: 0xFFFD,
	0xA809: 0xFFFD,
	0xA80A: 0xFFFD,
	0xA80B: 0xFFFD,
	0xA80C: 0xFFFD,
	0xA80D: 0xFFFD,
	0xA80E: 0xFFFD,
	0xA80F: 0xFFFD,
	0xA810: 0xFFFD,
	0xA811: 0xFFFD,
	0xA812: 0xFFFD,
	0xA813: 0xFFFD,
	0xA814: 0xFFFD,
	0xA815: 0xFFFD,
	0xA816: 0xFFFD,
	0xA817: 0xFFFD,
	0xA818: 0xFFFD,
	0xA819: 0xFFFD,
	0xA81A: 0xFFFD,
	0xA81B: 0xFFFD,
	0xA81C: 0xFFFD,
	0xA81D: 0xFFFD,
	0xA81E: 0xFFFD,
	0xA81F: 0xFFFD,
	0xA820: 0xFFFD,
	0xA821: 0xFFFD,
	0xA822: 0xFFFD,
	0xA823: 0xFFFD,
	0xA824: 0xFFFD,
	0xA825: 0xFFFD,
	0xA826: 0xFFFD,
	0xA827: 0xFFFD,
	0xA828: 0xFFFD,
	0xA829: 0xFFFD,
	0xA82A: 0xFFFD,
	0xA82B: 0xFFFD,
	0xA82C: 0xFFFD,
	0xA82D: 0xFFFD,
	0xA82E: 0xFFFD,
	0xA82F: 0xFFFD,
	0xA830: 0xFFFD,
	0xA831: 0xFFFD,
	0xA832: 0xFFFD,
	0xA833: 0xFFFD,
	0xA834: 0xFFFD,
	0xA835: 0xFFFD,
	0xA836: 0xFFFD,
	0xA837: 0xFFFD,
	0xA838: 0xFFFD,
	0xA839: 0xFFFD,
	0xA83A: 0xFFFD,
	0xA83B: 0xFFFD,
	0xA83C: 0xFFFD,
	0xA83D: 0xFFFD,
	0xA83E: 0xFFFD,
	0xA83F: 0xFFFD,
	0xA840: 0xFFFD,
	0xA841: 0xFFFD,
	0xA842: 0xFFFD,
	0xA843: 0xFFFD,
	0xA844: 0xFFFD,
	0xA845: 0xFFFD,
	0xA846: 0xFFFD,
	0xA847: 0xFFFD,
	0xA848: 0xFFFD,
	0xA849: 0xFFFD,
	0xA84A: 0xFFFD,
	0xA84B: 0xFFFD,
	0xA84C: 0xFFFD,
	0xA84D: 0xFFFD,
	0xA84E: 0xFFFD,
	0xA84F: 0xFFFD,
	0xA850: 0xFFFD,
	0xA851: 0xFFFD,
	0xA852: 0xFFFD,
	0xA853: 0xFFFD,
	0xA854: 0xFFFD,
	0xA855: 0xFFFD,
	0xA856: 0xFFFD,
	0xA857: 0xFFFD,
	0xA858: 0xFFFD,
	0xA859: 0xFFFD,
	0xA85A: 0xFFFD,
	0xA85B: 0xFFFD,
	0xA85C: 0xFFFD,
	0xA85D: 0xFFFD,
	0xA85E: 0xFFFD,
	0xA85F: 0xFFFD,
	0xA860: 0xFFFD,
	0xA861: 0xFFFD,
	0xA862: 0xFFFD,
	0xA863: 0xFFFD,
	0xA864: 0xFFFD,
	0xA865: 0xFFFD,
	0xA866: 0xFFFD,
	0xA867: 0xFFFD,
	0xA868: 0xFFFD,
	0xA869: 0xFFFD,
	0xA86A: 0xFFFD,
	0xA86B: 0xFFFD,
	0xA86C: 0xFFFD,
	0xA86D: 0xFFFD,
	0xA86E: 0xFFFD,
	0xA86F: 0xFFFD,
	0xA870: 0xFFFD,
	0xA871: 0xFFFD,
	0xA872: 0xFFFD,
	0xA873: 0xFFFD,
	0xA874: 0xFFFD,
	0xA875: 0xFFFD,
	0xA876: 0xFFFD,
	0xA877: 0xFFFD,
	0xA878: 0xFFFD,
	0xA879: 0xFFFD,
	0xA87A: 0xFFFD,
	0xA87B: 0xFFFD,
	0xA87C: 0xFFFD,
	0xA87D: 0xFFFD,
	0xA87E: 0xFFFD,
	0xA87F: 0xFFFD,
	0xA880: 0xFFFD,
	0xA881: 0xFFFD,
	0xA882: 0xFFFD,
	0xA883: 0xFFFD,
	0xA884: 0xFFFD,
	0xA885: 0xFFFD,
	0xA886: 0xFFFD,
	0xA887: 0xFFFD,
	0xA888: 0xFFFD,
	0xA889: 0xFFFD,
	0xA88A: 0xFFFD,
	0xA88B: 0xFFFD,
	0xA88C: 0xFFFD,
	0xA88D: 0xFFFD,
	0xA88E: 0xFFFD,
	0xA88F: 0xFFFD,
	0xA890: 0xFFFD,
	0xA891: 0xFFFD,
	0xA892: 0xFFFD,
	0xA893: 0xFFFD,
	0xA894: 0xFFFD,
	0xA895: 0xFFFD,
	0xA896: 0xFFFD,
	0xA897: 0xFFFD,
	0xA898: 0xFFFD,
	0xA899: 0xFFFD,
	0xA89A: 0xFFFD,
	0xA89B: 0xFFFD,
	0xA89C: 0xFFFD,
	0xA89D: 0xFFFD,
	0xA89E: 0xFFFD,
	0xA89F: 0xFFFD,
	0xA8A0: 0xFFFD,
	0xA8A1: 0xFFFD,
	0xA8A2: 0xFFFD,
	0xA8A3: 0xFFFD,
	0xA8A4: 0xFFFD,
	0xA8A5: 0xFFFD,
	0xA8A6: 0xFFFD,
	0xA8A7: 0xFFFD,
	0xA8A8: 0xFFFD,
	0xA8A9: 0xFFFD,
	0xA8AA: 0xFFFD,
	0xA8AB: 0xFFFD,
	0xA8AC: 0xFFFD,
	0xA8AD: 0xFFFD,
	0xA8AE: 0xFFFD,
	0xA8AF: 0xFFFD,
	0xA8B0: 0xFFFD,
	0xA8B1: 0xFFFD,
	0xA8B2: 0xFFFD,
	0xA8B3: 0xFFFD,
	0xA8B4: 0xFFFD,
	0xA8B5: 0xFFFD,
	0xA8B6: 0xFFFD,
	0xA8B7: 0xFFFD,
	0xA8B8: 0xFFFD,
	0xA8B9: 0xFFFD,
	0xA8BA: 0xFFFD,
	0xA8BB: 0xFFFD,
	0xA8BC: 0xFFFD,
	0xA8BD: 0xFFFD,
	0xA8BE: 0xFFFD,
	0xA8BF: 0xFFFD,
	0xA8C0: 0xFFFD,
	0xA8C1: 0xFFFD,
	0xA8C2: 0xFFFD,
	0xA8C3: 0xFFFD,
	0xA8C4: 0xFFFD,
	0xA8C5: 0xFFFD,
	0xA8C6: 0xFFFD,
	0xA8C7: 0xFFFD,
	0xA8C8: 0xFFFD,
	0xA8C9: 0xFFFD,
	0xA8CA: 0xFFFD,
	0xA8CB: 0xFFFD,
	0xA8CC: 0xFFFD,
	0xA8CD: 0xFFFD,
	0xA8CE: 0xFFFD,
	0xA8CF: 0xFFFD,
	0xA8D0: 0xFFFD,
	0xA8D1: 0xFFFD,
	0xA8D2: 0xFFFD,
	0xA8D3: 0xFFFD,
	0xA8D4: 0xFFFD,
	0xA8D5: 0xFFFD,
	0xA8D6: 0xFFFD,
	0xA8D7: 0xFFFD,
	0xA8D8: 0xFFFD,
	0xA8D9: 0xFFFD,
	0xA8DA: 0xFFFD,
	0xA8DB: 0xFFFD,
	0xA8DC: 0xFFFD,
	0xA8DD: 0xFFFD,
	0xA8DE: 0xFFFD,
	0xA8DF: 0xFFFD,
	0xA8E0: 0xFFFD,
	0xA8E1: 0xFFFD,
	0xA8E2: 0xFFFD,
	0xA8E3: 0xFFFD,
	0xA8E4: 0xFFFD,
	0xA8E5: 0xFFFD,
	0xA8E6: 0xFFFD,
	0xA8E7: 0xFFFD,
	0xA8E8: 0xFFFD,
	0xA8E9: 0xFFFD,
	0xA8EA: 0xFFFD,
	0xA8EB: 0xFFFD,
	0xA8EC: 0xFFFD,
	0xA8ED: 0xFFFD,
	0xA8EE: 0xFFFD,
	0xA8EF: 0xFFFD,
	0xA8F0: 0xFFFD,
	0xA8F1: 0xFFFD,
	0xA8F2: 0xFFFD,
	0xA8F3: 0xFFFD,
	0xA8F4: 0xFFFD,
	0xA8F5: 0xFFFD,
	0xA8F6: 0xFFFD,
	0xA8F7: 0xFFFD,
	0xA8F8: 0xFFFD,
	0xA8F9: 0xFFFD,
	0xA8FA: 0xFFFD,
	0xA8FB: 0xFFFD,
	0xA8FC: 0xFFFD,
	0xA8FD: 0xFFFD,
	0xA8FE: 0xFFFD,
	0xA8FF: 0xFFFD,
	0xA900: 0xFFFD,
	0xA901: 0xFFFD,
	0xA902: 0xFFFD,
	0xA903: 0xFFFD,
	0xA904: 0xFFFD,
	0xA905: 0xFFFD,
	0xA906: 0xFFFD,
	0xA907: 0xFFFD,
	0xA908: 0xFFFD,
	0xA909: 0xFFFD,
	0xA90A: 0xFFFD,
	0xA90B: 0xFFFD,
	0xA90C: 0xFFFD,
	0xA90D: 0xFFFD,
	0xA90E: 0xFFFD,
	0xA90F: 0xFFFD,
	0xA910: 0xFFFD,
	0xA911: 0xFFFD,
	0xA912: 0xFFFD,
	0xA913: 0xFFFD,
	0xA914: 0xFFFD,
	0xA915: 0xFFFD,
	0xA916: 0xFFFD,
	0xA917: 0xFFFD,
	0xA918: 0xFFFD,
	0xA919: 0xFFFD,
	0xA91A: 0xFFFD,
	0xA91B: 0xFFFD,
	0xA91C: 0xFFFD,
	0xA91D: 0xFFFD,
	0xA91E: 0xFFFD,
	0xA91F: 0xFFFD,
	0xA920: 0xFFFD,
	0xA921: 0xFFFD,
	0xA922: 0xFFFD,
	0xA923: 0xFFFD,
	0xA924: 0xFFFD,
	0xA925: 0xFFFD,
	0xA926: 0xFFFD,
	0xA927: 0xFFFD,
	0xA928: 0xFFFD,
	0xA929: 0xFFFD,
	0xA92A: 0xFFFD,
	0xA92B: 0xFFFD,
	0xA92C: 0xFFFD,
	0xA92D: 0xFFFD,
	0xA92E: 0xFFFD,
	0xA92F: 0xFFFD,
	0xA930: 0xFFFD,
	0xA931: 0xFFFD,
	0xA932: 0xFFFD,
	0xA933: 0xFFFD,
	0xA934: 0xFFFD,
	0xA935: 0xFFFD,
	0xA936: 0xFFFD,
	0xA937: 0xFFFD,
	0xA938: 0xFFFD,
	0xA939: 0xFFFD,
	0xA93A: 0xFFFD,
	0xA93B: 0xFFFD,
	0xA93C: 0xFFFD,
	0xA93D: 0xFFFD,
	0xA93E: 0xFFFD,
	0xA93F: 0xFFFD,
	0xA940: 0xFFFD,
	0xA941: 0xFFFD,
	0xA942: 0xFFFD,
	0xA943: 0xFFFD,
	0xA944: 0xFFFD,
	0xA945: 0xFFFD,
	0xA946: 0xFFFD,
	0xA947: 0xFFFD,
	0xA948: 0xFFFD,
	0xA949: 0xFFFD,
	0xA94A: 0xFFFD,
	0xA94B: 0xFFFD,
	0xA94C: 0xFFFD,
	0xA94D: 0xFFFD,
	0xA94E: 0xFFFD,
	0xA94F: 0xFFFD,
	0xA950: 0xFFFD,
	0xA951: 0xFFFD,
	0xA952: 0xFFFD,
	0xA953: 0xFFFD,
	0xA954: 0xFFFD,
	0xA955: 0xFFFD,
	0xA956: 0xFFFD,
	0xA957: 0xFFFD,
	0xA958: 0xFFFD,
	0xA959: 0xFFFD,
	0xA95A: 0xFFFD,
	0xA95B: 0xFFFD,
	0xA95C: 0xFFFD,
	0xA95D: 0xFFFD,
	0xA95E: 0xFFFD,
	0xA95F: 0xFFFD,
	0xA960: 0xFFFD,
	0xA961: 0xFFFD,
	0xA962: 0xFFFD,
	0xA963: 0xFFFD,
	0xA964: 0xFFFD,
	0xA965: 0xFFFD,
	0xA966: 0xFFFD,
	0xA967: 0xFFFD,
	0xA968: 0xFFFD,
	0xA969: 0xFFFD,
	0xA96A: 0xFFFD,
	0xA96B: 0xFFFD,
	0xA96C: 0xFFFD,
	0xA96D: 0xFFFD,
	0xA96E: 0xFFFD,
	0xA96F: 0xFFFD,
	0xA970: 0xFFFD,
	0xA971: 0xFFFD,
	0xA972: 0xFFFD,
	0xA973: 0xFFFD,
	0xA974: 0xFFFD,
	0xA975: 0xFFFD,
	0xA976: 0xFFFD,
	0xA977: 0xFFFD,
	0xA978: 0xFFFD,
	0xA979: 0xFFFD,
	0xA97A: 0xFFFD,
	0xA97B: 0xFFFD,
	0xA97C: 0xFFFD,
	0xA97D: 0xFFFD,
	0xA97E: 0xFFFD,
	0xA97F: 0xFFFD,
	0xA980: 0xFFFD,
	0xA981: 0xFFFD,
	0xA982: 0xFFFD,
	0xA983: 0xFFFD,
	0xA984: 0xFFFD,
	0xA985: 0xFFFD,
	0xA986: 0xFFFD,
	0xA987: 0xFFFD,
	0xA988: 0xFFFD,
	0xA989: 0xFFFD,
	0xA98A: 0xFFFD,
	0xA98B: 0xFFFD,
	0xA98C: 0xFFFD,
	0xA98D: 0xFFFD,
	0xA98E: 0xFFFD,
	0xA98F: 0xFFFD,
	0xA990: 0xFFFD,
	0xA991: 0xFFFD,
	0xA992: 0xFFFD,
	0xA993: 0xFFFD,
	0xA994: 0xFFFD,
	0xA995: 0xFFFD,
	0xA996: 0xFFFD,
	0xA997: 0xFFFD,
	0xA998: 0xFFFD,
	0xA999: 0xFFFD,
	0xA99A: 0xFFFD,
	0xA99B: 0xFFFD,
	0xA99C: 0xFFFD,
	0xA99D: 0xFFFD,
	0xA99E: 0xFFFD,
	0xA99F: 0xFFFD,
	0xA9A0: 0xFFFD,
	0xA9A1: 0xFFFD,
	0xA9A2: 0xFFFD,
	0xA9A3: 0xFFFD,
	0xA9A4: 0xFFFD,
	0xA9A5: 0xFFFD,
	0xA9A6: 0xFFFD,
	0xA9A7: 0xFFFD,
	0xA9A8: 0xFFFD,
	0xA9A9: 0xFFFD,
	0xA9AA: 0xFFFD,
	0xA9AB: 0xFFFD,
	0xA9AC: 0xFFFD,
	0xA9AD: 0xFFFD,
	0xA9AE: 0xFFFD,
	0xA9AF: 0xFFFD,
	0xA9B0: 0xFFFD,
	0xA9B1: 0xFFFD,
	0xA9B2: 0xFFFD,
	0xA9B3: 0xFFFD,
	0xA9B4: 0xFFFD,
	0xA9B5: 0xFFFD,
	0xA9B6: 0xFFFD,
	0xA9B7: 0xFFFD,
	0xA9B8: 0xFFFD,
	0xA9B9: 0xFFFD,
	0xA9BA: 0xFFFD,
	0xA9BB: 0xFFFD,
	0xA9BC: 0xFFFD,
	0xA9BD: 0xFFFD,
	0xA9BE: 0xFFFD,
	0xA9BF: 0xFFFD,
	0xA9C0: 0xFFFD,
	0xA9C1: 0xFFFD,
	0xA9C2: 0xFFFD,
	0xA9C3: 0xFFFD,
	0xA9C4: 0xFFFD,
	0xA9C5: 0xFFFD,
	0xA9C6: 0xFFFD,
	0xA9C7: 0xFFFD,
	0xA9C8: 0xFFFD,
	0xA9C9: 0xFFFD,
	0xA9CA: 0xFFFD,
	0xA9CB: 0xFFFD,
	0xA9CC: 0xFFFD,
	0xA9CD: 0xFFFD,
	0xA9CE: 0xFFFD,
	0xA9CF: 0xFFFD,
	0xA9D0: 0xFFFD,
	0xA9D1: 0xFFFD,
	0xA9D2: 0xFFFD,
	0xA9D3: 0xFFFD,
	0xA9D4: 0xFFFD,
	0xA9D5: 0xFFFD,
	0xA9D6: 0xFFFD,
	0xA9D7: 0xFFFD,
	0xA9D8: 0xFFFD,
	0xA9D9: 0xFFFD,
	0xA9DA: 0xFFFD,
	0xA9DB: 0xFFFD,
	0xA9DC: 0xFFFD,
	0xA9DD: 0xFFFD,
	0xA9DE: 0xFFFD,
	0xA9DF: 0xFFFD,
	0xA9E0: 0xFFFD,
	0xA9E1: 0xFFFD,
	0xA9E2: 0xFFFD,
	0xA9E3: 0xFFFD,
	0xA9E4: 0xFFFD,
	0xA9E5: 0xFFFD,
	0xA9E6: 0xFFFD,
	0xA9E7: 0xFFFD,
	0xA9E8: 0xFFFD,
	0xA9E9: 0xFFFD,
	0xA9EA: 0xFFFD,
	0xA9EB: 0xFFFD,
	0xA9EC: 0xFFFD,
	0xA9ED: 0xFFFD,
	0xA9EE: 0xFFFD,
	0xA9EF: 0xFFFD,
	0xA9F0: 0xFFFD,
	0xA9F1: 0xFFFD,
	0xA9F2: 0xFFFD,
	0xA9F3: 0xFFFD,
	0xA9F4: 0xFFFD,
	0xA9F5: 0xFFFD,
	0xA9F6: 0xFFFD,
	0xA9F7: 0xFFFD,
	0xA9F8: 0xFFFD,
	0xA9F9: 0xFFFD,
	0xA9FA: 0xFFFD,
	0xA9FB: 0xFFFD,
	0xA9FC: 0xFFFD,
	0xA9FD: 0xFFFD,
	0xA9FE: 0xFFFD,
	0xA9FF: 0xFFFD,
	0xAA00: 0xFFFD,
	0xAA01: 0xFFFD,
	0xAA02: 0xFFFD,
	0xAA03: 0xFFFD,
	0xAA04: 0xFFFD,
	0xAA05: 0xFFFD,
	0xAA06: 0xFFFD,
	0xAA07: 0xFFFD,
	0xAA08: 0xFFFD,
	0xAA09: 0xFFFD,
	0xAA0A: 0xFFFD,
	0xAA0B: 0xFFFD,
	0xAA0C: 0xFFFD,
	0xAA0D: 0xFFFD,
	0xAA0E: 0xFFFD,
	0xAA0F: 0xFFFD,
	0xAA10: 0xFFFD,
	0xAA11: 0xFFFD,
	0xAA12: 0xFFFD,
	0xAA13: 0xFFFD,
	0xAA14: 0xFFFD,
	0xAA15: 0xFFFD,
	0xAA16: 0xFFFD,
	0xAA17: 0xFFFD,
	0xAA18: 0xFFFD,
	0xAA19: 0xFFFD,
	0xAA1A: 0xFFFD,
	0xAA1B: 0xFFFD,
	0xAA1C: 0xFFFD,
	0xAA1D: 0xFFFD,
	0xAA1E: 0xFFFD,
	0xAA1F: 0xFFFD,
	0xAA20: 0xFFFD,
	0xAA21: 0xFFFD,
	0xAA22: 0xFFFD,
	0xAA23: 0xFFFD,
	0xAA24: 0xFFFD,
	0xAA25: 0xFFFD,
	0xAA26: 0xFFFD,
	0xAA27: 0xFFFD,
	0xAA28: 0xFFFD,
	0xAA29: 0xFFFD,
	0xAA2A: 0xFFFD,
	0xAA2B: 0xFFFD,
	0xAA2C: 0xFFFD,
	0xAA2D: 0xFFFD,
	0xAA2E: 0xFFFD,
	0xAA2F: 0xFFFD,
	0xAA30: 0xFFFD,
	0xAA31: 0xFFFD,
	0xAA32: 0xFFFD,
	0xAA33: 0xFFFD,
	0xAA34: 0xFFFD,
	0xAA35: 0xFFFD,
	0xAA36: 0xFFFD,
	0xAA37: 0xFFFD,
	0xAA38: 0xFFFD,
	0xAA39: 0xFFFD,
	0xAA3A: 0xFFFD,
	0xAA3B: 0xFFFD,
	0xAA3C: 0xFFFD,
	0xAA3D: 0xFFFD,
	0xAA3E: 0xFFFD,
	0xAA3F: 0xFFFD,
	0xAA40: 0xFFFD,
	0xAA41: 0xFFFD,
	0xAA42: 0xFFFD,
	0xAA43: 0xFFFD,
	0xAA44: 0xFFFD,
	0xAA45: 0xFFFD,
	0xAA46: 0xFFFD,
	0xAA47: 0xFFFD,
	0xAA48: 0xFFFD,
	0xAA49: 0xFFFD,
	0xAA4A: 0xFFFD,
	0xAA4B: 0xFFFD,
	0xAA4C: 0xFFFD,
	0xAA4D: 0xFFFD,
	0xAA4E: 0xFFFD,
	0xAA4F: 0xFFFD,
	0xAA50: 0xFFFD,
	0xAA51: 0xFFFD,
	0xAA52: 0xFFFD,
	0xAA53: 0xFFFD,
	0xAA54: 0xFFFD,
	0xAA55: 0xFFFD,
	0xAA56: 0xFFFD,
	0xAA57: 0xFFFD,
	0xAA58: 0xFFFD,
	0xAA59: 0xFFFD,
	0xAA5A: 0xFFFD,
	0xAA5B: 0xFFFD,
	0xAA5C: 0xFFFD,
	0xAA5D: 0xFFFD,
	0xAA5E: 0xFFFD,
	0xAA5F: 0xFFFD,
	0xAA60: 0xFFFD,
	0xAA61: 0xFFFD,
	0xAA62: 0xFFFD,
	0xAA63: 0xFFFD,
	0xAA64: 0xFFFD,
	0xAA65: 0xFFFD,
	0xAA66: 0xFFFD,
	0xAA67: 0xFFFD,
	0xAA68: 0xFFFD,
	0xAA69: 0xFFFD,
	0xAA6A: 0xFFFD,
	0xAA6B: 0xFFFD,
	0xAA6C: 0xFFFD,
	0xAA6D: 0xFFFD,
	0xAA6E: 0xFFFD,
	0xAA6F: 0xFFFD,
	0xAA70: 0xFFFD,
	0xAA71: 0xFFFD,
	0xAA72: 0xFFFD,
	0xAA73: 0xFFFD,
	0xAA74: 0xFFFD,
	0xAA75: 0xFFFD,
	0xAA76: 0xFFFD,
	0xAA77: 0xFFFD,
	0xAA78: 0xFFFD,
	0xAA79: 0xFFFD,
	0xAA7A: 0xFFFD,
	0xAA7B: 0xFFFD,
	0xAA7C: 0xFFFD,
	0xAA7D: 0xFFFD,
	0xAA7E: 0xFFFD,
	0xAA7F: 0xFFFD,
	0xAA80: 0xFFFD,
	0xAA81: 0xFFFD,
	0xAA82: 0xFFFD,
	0xAA83: 0xFFFD,
	0xAA84: 0xFFFD,
	0xAA85: 0xFFFD,
	0xAA86: 0xFFFD,
	0xAA87: 0xFFFD,
	0xAA88: 0xFFFD,
	0xAA89: 0xFFFD,
	0xAA8A: 0xFFFD,
	0xAA8B: 0xFFFD,
	0xAA8C: 0xFFFD,
	0xAA8D: 0xFFFD,
	0xAA8E: 0xFFFD,
	0xAA8F: 0xFFFD,
	0xAA90: 0xFFFD,
	0xAA91: 0xFFFD,
	0xAA92: 0xFFFD,
	0xAA93: 0xFFFD,
	0xAA94: 0xFFFD,
	0xAA95: 0xFFFD,
	0xAA96: 0xFFFD,
	0xAA97: 0xFFFD,
	0xAA98: 0xFFFD,
	0xAA99: 0xFFFD,
	0xAA9A: 0xFFFD,
	0xAA9B: 0xFFFD,
	0xAA9C: 0xFFFD,
	0xAA9D: 0xFFFD,
	0xAA9E: 0xFFFD,
	0xAA9F: 0xFFFD,
	0xAAA0: 0xFFFD,
	0xAAA1: 0xFFFD,
	0xAAA2: 0xFFFD,
	0xAAA3: 0xFFFD,
	0xAAA4: 0xFFFD,
	0xAAA5: 0xFFFD,
	0xAAA6: 0xFFFD,
	0xAAA7: 0xFFFD,
	0xAAA8: 0xFFFD,
	0xAAA9: 0xFFFD,
	0xAAAA: 0xFFFD,
	0xAAAB: 0xFFFD,
	0xAAAC: 0xFFFD,
	0xAAAD: 0xFFFD,
	0xAAAE: 0xFFFD,
	0xAAAF: 0xFFFD,
	0xAAB0: 0xFFFD,
	0xAAB1: 0xFFFD,
	0xAAB2: 0xFFFD,
	0xAAB3: 0xFFFD,
	0xAAB4: 0xFFFD,
	0xAAB5: 0xFFFD,
	0xAAB6: 0xFFFD,
	0xAAB7: 0xFFFD,
	0xAAB8: 0xFFFD,
	0xAAB9: 0xFFFD,
	0xAABA: 0xFFFD,
	0xAABB: 0xFFFD,
	0xAABC: 0xFFFD,
	0xAABD: 0xFFFD,
	0xAABE: 0xFFFD,
	0xAABF: 0xFFFD,
	0xAAC0: 0xFFFD,
	0xAAC1: 0xFFFD,
	0xAAC2: 0xFFFD,
	0xAAC3: 0xFFFD,
	0xAAC4: 0xFFFD,
	0xAAC5: 0xFFFD,
	0xAAC6: 0xFFFD,
	0xAAC7: 0xFFFD,
	0xAAC8: 0xFFFD,
	0xAAC9: 0xFFFD,
	0xAACA: 0xFFFD,
	0xAACB: 0xFFFD,
	0xAACC: 0xFFFD,
	0xAACD: 0xFFFD,
	0xAACE: 0xFFFD,
	0xAACF: 0xFFFD,
	0xAAD0: 0xFFFD,
	0xAAD1: 0xFFFD,
	0xAAD2: 0xFFFD,
	0xAAD3: 0xFFFD,
	0xAAD4: 0xFFFD,
	0xAAD5: 0xFFFD,
	0xAAD6: 0xFFFD,
	0xAAD7: 0xFFFD,
	0xAAD8: 0xFFFD,
	0xAAD9: 0xFFFD,
	0xAADA: 0xFFFD,
	0xAADB: 0xFFFD,
	0xAADC: 0xFFFD,
	0xAADD: 0xFFFD,
	0xAADE: 0xFFFD,
	0xAADF: 0xFFFD,
	0xAAE0: 0xFFFD,
	0xAAE1: 0xFFFD,
	0xAAE2: 0xFFFD,
	0xAAE3: 0xFFFD,
	0xAAE4: 0xFFFD,
	0xAAE5: 0xFFFD,
	0xAAE6: 0xFFFD,
	0xAAE7: 0xFFFD,
	0xAAE8: 0xFFFD,
	0xAAE9: 0xFFFD,
	0xAAEA: 0xFFFD,
	0xAAEB: 0xFFFD,
	0xAAEC: 0xFFFD,
	0xAAED: 0xFFFD,
	0xAAEE: 0xFFFD,
	0xAAEF: 0xFFFD,
	0xAAF0: 0xFFFD,
	0xAAF1: 0xFFFD,
	0xAAF2: 0xFFFD,
	0xAAF3: 0xFFFD,
	0xAAF4: 0xFFFD,
	0xAAF5: 0xFFFD,
	0xAAF6: 0xFFFD,
	0xAAF7: 0xFFFD,
	0xAAF8: 0xFFFD,
	0xAAF9: 0xFFFD,
	0xAAFA: 0xFFFD,
	0xAAFB: 0xFFFD,
	0xAAFC: 0xFFFD,
	0xAAFD: 0xFFFD,
	0xAAFE: 0xFFFD,
	0xAAFF: 0xFFFD,
	0xAB00: 0xFFFD,
	0xAB01: 0xFFFD,
	0xAB02: 0xFFFD,
	0xAB03: 0xFFFD,
	0xAB04: 0xFFFD,
	0xAB05: 0xFFFD,
	0xAB06: 0xFFFD,
	0xAB07: 0xFFFD,
	0xAB08: 0xFFFD,
	0xAB09: 0xFFFD,
	0xAB0A: 0xFFFD,
	0xAB0B: 0xFFFD,
	0xAB0C: 0xFFFD,
	0xAB0D: 0xFFFD,
	0xAB0E: 0xFFFD,
	0xAB0F: 0xFFFD,
	0xAB10: 0xFFFD,
	0xAB11: 0xFFFD,
	0xAB12: 0xFFFD,
	0xAB13: 0xFFFD,
	0xAB14: 0xFFFD,
	0xAB15: 0xFFFD,
	0xAB16: 0xFFFD,
	0xAB17: 0xFFFD,
	0xAB18: 0xFFFD,
	0xAB19: 0xFFFD,
	0xAB1A: 0xFFFD,
	0xAB1B: 0xFFFD,
	0xAB1C: 0xFFFD,
	0xAB1D: 0xFFFD,
	0xAB1E: 0xFFFD,
	0xAB1F: 0xFFFD,
	0xAB20: 0xFFFD,
	0xAB21: 0xFFFD,
	0xAB22: 0xFFFD,
	0xAB23: 0xFFFD,
	0xAB24: 0xFFFD,
	0xAB25: 0xFFFD,
	0xAB26: 0xFFFD,
	0xAB27: 0xFFFD,
	0xAB28: 0xFFFD,
	0xAB29: 0xFFFD,
	0xAB2A: 0xFFFD,
	0xAB2B: 0xFFFD,
	0xAB2C: 0xFFFD,
	0xAB2D: 0xFFFD,
	0xAB2E: 0xFFFD,
	0xAB2F: 0xFFFD,
	0xAB30: 0xFFFD,
	0xAB31: 0xFFFD,
	0xAB32: 0xFFFD,
	0xAB33: 0xFFFD,
	0xAB34: 0xFFFD,
	0xAB35: 0xFFFD,
	0xAB36: 0xFFFD,
	0xAB37: 0xFFFD,
	0xAB38: 0xFFFD,
	0xAB39: 0xFFFD,
	0xAB3A: 0xFFFD,
	0xAB3B: 0xFFFD,
	0xAB3C: 0xFFFD,
	0xAB3D: 0xFFFD,
	0xAB3E: 0xFFFD,
	0xAB3F: 0xFFFD,
	0xAB40: 0xFFFD,
	0xAB41: 0xFFFD,
	0xAB42: 0xFFFD,
	0xAB43: 0xFFFD,
	0xAB44: 0xFFFD,
	0xAB45: 0xFFFD,
	0xAB46: 0xFFFD,
	0xAB47: 0xFFFD,
	0xAB48: 0xFFFD,
	0xAB49: 0xFFFD,
	0xAB4A: 0xFFFD,
	0xAB4B: 0xFFFD,
	0xAB4C: 0xFFFD,
	0xAB4D: 0xFFFD,
	0xAB4E: 0xFFFD,
	0xAB4F: 0xFFFD,
	0xAB50: 0xFFFD,
	0xAB51: 0xFFFD,
	0xAB52: 0xFFFD,
	0xAB53: 0xFFFD,
	0xAB54: 0xFFFD,
	0xAB55: 0xFFFD,
	0xAB56: 0xFFFD,
	0xAB57: 0xFFFD,
	0xAB58: 0xFFFD,
	0xAB59: 0xFFFD,
	0xAB5A: 0xFFFD,
	0xAB5B: 0xFFFD,
	0xAB5C: 0xFFFD,
	0xAB5D: 0xFFFD,
	0xAB5E: 0xFFFD,
	0xAB5F: 0xFFFD,
	0xAB60: 0xFFFD,
	0xAB61: 0xFFFD,
	0xAB62: 0xFFFD,
	0xAB63: 0xFFFD,
	0xAB64: 0xFFFD,
	0xAB65: 0xFFFD,
	0xAB66: 0xFFFD,
	0xAB67: 0xFFFD,
	0xAB68: 0xFFFD,
	0xAB69: 0xFFFD,
	0xAB6A: 0xFFFD,
	0xAB6B: 0xFFFD,
	0xAB6C: 0xFFFD,
	0xAB6D: 0xFFFD,
	0xAB6E: 0xFFFD,
	0xAB6F: 0xFFFD,
	0xAB70: 0xFFFD,
	0xAB71: 0xFFFD,
	0xAB72: 0xFFFD,
	0xAB73: 0xFFFD,
	0xAB74: 0xFFFD,
	0xAB75: 0xFFFD,
	0xAB76: 0xFFFD,
	0xAB77: 0xFFFD,
	0xAB78: 0xFFFD,
	0xAB79: 0xFFFD,
	0xAB7A: 0xFFFD,
	0xAB7B: 0xFFFD,
	0xAB7C: 0xFFFD,
	0xAB7D: 0xFFFD,
	0xAB7E: 0xFFFD,
	0xAB7F: 0xFFFD,
	0xAB80: 0xFFFD,
	0xAB81: 0xFFFD,
	0xAB82: 0xFFFD,
	0xAB83: 0xFFFD,
	0xAB84: 0xFFFD,
	0xAB85: 0xFFFD,
	0xAB86: 0xFFFD,
	0xAB87: 0xFFFD,
	0xAB88: 0xFFFD,
	0xAB89: 0xFFFD,
	0xAB8A: 0xFFFD,
	0xAB8B: 0xFFFD,
	0xAB8C: 0xFFFD,
	0xAB8D: 0xFFFD,
	0xAB8E: 0xFFFD,
	0xAB8F: 0xFFFD,
	0xAB90: 0xFFFD,
	0xAB91: 0xFFFD,
	0xAB92: 0xFFFD,
	0xAB93: 0xFFFD,
	0xAB94: 0xFFFD,
	0xAB95: 0xFFFD,
	0xAB96: 0xFFFD,
	0xAB97: 0xFFFD,
	0xAB98: 0xFFFD,
	0xAB99: 0xFFFD,
	0xAB9A: 0xFFFD,
	0xAB9B: 0xFFFD,
	0xAB9C: 0xFFFD,
	0xAB9D: 0xFFFD,
	0xAB9E: 0xFFFD,
	0xAB9F: 0xFFFD,
	0xABA0: 0xFFFD,
	0xABA1: 0xFFFD,
	0xABA2: 0xFFFD,
	0xABA3: 0xFFFD,
	0xABA4: 0xFFFD,
	0xABA5: 0xFFFD,
	0xABA6: 0xFFFD,
	0xABA7: 0xFFFD,
	0xABA8: 0xFFFD,
	0xABA9: 0xFFFD,
	0xABAA: 0xFFFD,
	0xABAB: 0xFFFD,
	0xABAC: 0xFFFD,
	0xABAD: 0xFFFD,
	0xABAE: 0xFFFD,
	0xABAF: 0xFFFD,
	0xABB0: 0xFFFD,
	0xABB1: 0xFFFD,
	0xABB2: 0xFFFD,
	0xABB3: 0xFFFD,
	0xABB4: 0xFFFD,
	0xABB5: 0xFFFD,
	0xABB6: 0xFFFD,
	0xABB7: 0xFFFD,
	0xABB8: 0xFFFD,
	0xABB9: 0xFFFD,
	0xABBA: 0xFFFD,
	0xABBB: 0xFFFD,
	0xABBC: 0xFFFD,
	0xABBD: 0xFFFD,
	0xABBE: 0xFFFD,
	0xABBF: 0xFFFD,
	0xABC0: 0xFFFD,
	0xABC1: 0xFFFD,
	0xABC2: 0xFFFD,
	0xABC3: 0xFFFD,
	0xABC4: 0xFFFD,
	0xABC5: 0xFFFD,
	0xABC6: 0xFFFD,
	0xABC7: 0xFFFD,
	0xABC8: 0xFFFD,
	0xABC9: 0xFFFD,
	0xABCA: 0xFFFD,
	0xABCB: 0xFFFD,
	0xABCC: 0xFFFD,
	0xABCD: 0xFFFD,
	0xABCE: 0xFFFD,
	0xABCF: 0xFFFD,
	0xABD0: 0xFFFD,
	0xABD1: 0xFFFD,
	0xABD2: 0xFFFD,
	0xABD3: 0xFFFD,
	0xABD4: 0xFFFD,
	0xABD5: 0xFFFD,
	0xABD6: 0xFFFD,
	0xABD7: 0xFFFD,
	0xABD8: 0xFFFD,
	0xABD9: 0xFFFD,
	0xABDA: 0xFFFD,
	0xABDB: 0xFFFD,
	0xABDC: 0xFFFD,
	0xABDD: 0xFFFD,
	0xABDE: 0xFFFD,
	0xABDF: 0xFFFD,
	0xABE0: 0xFFFD,
	0xABE1: 0xFFFD,
	0xABE2: 0xFFFD,
	0xABE3: 0xFFFD,
	0xABE4: 0xFFFD,
	0xABE5: 0xFFFD,
	0xABE6: 0xFFFD,
	0xABE7: 0xFFFD,
	0xABE8: 0xFFFD,
	0xABE9: 0xFFFD,
	0xABEA: 0xFFFD,
	0xABEB: 0xFFFD,
	0xABEC: 0xFFFD,
	0xABED: 0xFFFD,
	0xABEE: 0xFFFD,
	0xABEF: 0xFFFD,
	0xABF0: 0xFFFD,
	0xABF1: 0xFFFD,
	0xABF2: 0xFFFD,
	0xABF3: 0xFFFD,
	0xABF4: 0xFFFD,
	0xABF5: 0xFFFD,
	0xABF6: 0xFFFD,
	0xABF7: 0xFFFD,
	0xABF8: 0xFFFD,
	0xABF9: 0xFFFD,
	0xABFA: 0xFFFD,
	0xABFB: 0xFFFD,
	0xABFC: 0xFFFD,
	0xABFD: 0xFFFD,
	0xABFE: 0xFFFD,
	0xABFF: 0xFFFD,
	0xAC00: 0xFFFD,
	0xAC01: 0xFFFD,
	0xAC02: 0xFFFD,
	0xAC03: 0xFFFD,
	0xAC04: 0xFFFD,
	0xAC05: 0xFFFD,
	0xAC06: 0xFFFD,
	0xAC07: 0xFFFD,
	0xAC08: 0xFFFD,
	0xAC09: 0xFFFD,
	0xAC0A: 0xFFFD,
	0xAC0B: 0xFFFD,
	0xAC0C: 0xFFFD,
	0xAC0D: 0xFFFD,
	0xAC0E: 0xFFFD,
	0xAC0F: 0xFFFD,
	0xAC10: 0xFFFD,
	0xAC11: 0xFFFD,
	0xAC12: 0xFFFD,
	0xAC13: 0xFFFD,
	0xAC14: 0xFFFD,
	0xAC15: 0xFFFD,
	0xAC16: 0xFFFD,
	0xAC17: 0xFFFD,
	0xAC18: 0xFFFD,
	0xAC19: 0xFFFD,
	0xAC1A: 0xFFFD,
	0xAC1B: 0xFFFD,
	0xAC1C: 0xFFFD,
	0xAC1D: 0xFFFD,
	0xAC1E: 0xFFFD,
	0xAC1F: 0xFFFD,
	0xAC20: 0xFFFD,
	0xAC21: 0xFFFD,
	0xAC22: 0xFFFD,
	0xAC23: 0xFFFD,
	0xAC24: 0xFFFD,
	0xAC25: 0xFFFD,
	0xAC26: 0xFFFD,
	0xAC27: 0xFFFD,
	0xAC28: 0xFFFD,
	0xAC29: 0xFFFD,
	0xAC2A: 0xFFFD,
	0xAC2B: 0xFFFD,
	0xAC2C: 0xFFFD,
	0xAC2D: 0xFFFD,
	0xAC2E: 0xFFFD,
	0xAC2F: 0xFFFD,
	0xAC30: 0xFFFD,
	0xAC31: 0xFFFD,
	0xAC32: 0xFFFD,
	0xAC33: 0xFFFD,
	0xAC34: 0xFFFD,
	0xAC35: 0xFFFD,
	0xAC36: 0xFFFD,
	0xAC37: 0xFFFD,
	0xAC38: 0xFFFD,
	0xAC39: 0xFFFD,
	0xAC3A: 0xFFFD,
	0xAC3B: 0xFFFD,
	0xAC3C: 0xFFFD,
	0xAC3D: 0xFFFD,
	0xAC3E: 0xFFFD,
	0xAC3F: 0xFFFD,
	0xAC40: 0xFFFD,
	0xAC41: 0xFFFD,
	0xAC42: 0xFFFD,
	0xAC43: 0xFFFD,
	0xAC44: 0xFFFD,
	0xAC45: 0xFFFD,
	0xAC46: 0xFFFD,
	0xAC47: 0xFFFD,
	0xAC48: 0xFFFD,
	0xAC49: 0xFFFD,
	0xAC4A: 0xFFFD,
	0xAC4B: 0xFFFD,
	0xAC4C: 0xFFFD,
	0xAC4D: 0xFFFD,
	0xAC4E: 0xFFFD,
	0xAC4F: 0xFFFD,
	0xAC50: 0xFFFD,
	0xAC51: 0xFFFD,
	0xAC52: 0xFFFD,
	0xAC53: 0xFFFD,
	0xAC54: 0xFFFD,
	0xAC55: 0xFFFD,
	0xAC56: 0xFFFD,
	0xAC57: 0xFFFD,
	0xAC58: 0xFFFD,
	0xAC59: 0xFFFD,
	0xAC5A: 0xFFFD,
	0xAC5B: 0xFFFD,
	0xAC5C: 0xFFFD,
	0xAC5D: 0xFFFD,
	0xAC5E: 0xFFFD,
	0xAC5F: 0xFFFD,
	0xAC60: 0xFFFD,
	0xAC61: 0xFFFD,
	0xAC62: 0xFFFD,
	0xAC63: 0xFFFD,
	0xAC64: 0xFFFD,
	0xAC65: 0xFFFD,
	0xAC66: 0xFFFD,
	0xAC67: 0xFFFD,
	0xAC68: 0xFFFD,
	0xAC69: 0xFFFD,
	0xAC6A: 0xFFFD,
	0xAC6B: 0xFFFD,
	0xAC6C: 0xFFFD,
	0xAC6D: 0xFFFD,
	0xAC6E: 0xFFFD,
	0xAC6F: 0xFFFD,
	0xAC70: 0xFFFD,
	0xAC71: 0xFFFD,
	0xAC72: 0xFFFD,
	0xAC73: 0xFFFD,
	0xAC74: 0xFFFD,
	0xAC75: 0xFFFD,
	0xAC76: 0xFFFD,
	0xAC77: 0xFFFD,
	0xAC78: 0xFFFD,
	0xAC79: 0xFFFD,
	0xAC7A: 0xFFFD,
	0xAC7B: 0xFFFD,
	0xAC7C: 0xFFFD,
	0xAC7D: 0xFFFD,
	0xAC7E: 0xFFFD,
	0xAC7F: 0xFFFD,
	0xAC80: 0xFFFD,
	0xAC81: 0xFFFD,
	0xAC82: 0xFFFD,
	0xAC83: 0xFFFD,
	0xAC84: 0xFFFD,
	0xAC85: 0xFFFD,
	0xAC86: 0xFFFD,
	0xAC87: 0xFFFD,
	0xAC88: 0xFFFD,
	0xAC89: 0xFFFD,
	0xAC8A: 0xFFFD,
	0xAC8B: 0xFFFD,
	0xAC8C: 0xFFFD,
	0xAC8D: 0xFFFD,
	0xAC8E: 0xFFFD,
	0xAC8F: 0xFFFD,
	0xAC90: 0xFFFD,
	0xAC91: 0xFFFD,
	0xAC92: 0xFFFD,
	0xAC93: 0xFFFD,
	0xAC94: 0xFFFD,
	0xAC95: 0xFFFD,
	0xAC96: 0xFFFD,
	0xAC97: 0xFFFD,
	0xAC98: 0xFFFD,
	0xAC99: 0xFFFD,
	0xAC9A: 0xFFFD,
	0xAC9B: 0xFFFD,
	0xAC9C: 0xFFFD,
	0xAC9D: 0xFFFD,
	0xAC9E: 0xFFFD,
	0xAC9F: 0xFFFD,
	0xACA0: 0xFFFD,
	0xACA1: 0xFFFD,
	0xACA2: 0xFFFD,
	0xACA3: 0xFFFD,
	0xACA4: 0xFFFD,
	0xACA5: 0xFFFD,
	0xACA6: 0xFFFD,
	0xACA7: 0xFFFD,
	0xACA8: 0xFFFD,
	0xACA9: 0xFFFD,
	0xACAA: 0xFFFD,
	0xACAB: 0xFFFD,
	0xACAC: 0xFFFD,
	0xACAD: 0xFFFD,
	0xACAE: 0xFFFD,
	0xACAF: 0xFFFD,
	0xACB0: 0xFFFD,
	0xACB1: 0xFFFD,
	0xACB2: 0xFFFD,
	0xACB3: 0xFFFD,
	0xACB4: 0xFFFD,
	0xACB5: 0xFFFD,
	0xACB6: 0xFFFD,
	0xACB7: 0xFFFD,
	0xACB8: 0xFFFD,
	0xACB9: 0xFFFD,
	0xACBA: 0xFFFD,
	0xACBB: 0xFFFD,
	0xACBC: 0xFFFD,
	0xACBD: 0xFFFD,
	0xACBE: 0xFFFD,
	0xACBF: 0xFFFD,
	0xACC0: 0xFFFD,
	0xACC1: 0xFFFD,
	0xACC2: 0xFFFD,
	0xACC3: 0xFFFD,
	0xACC4: 0xFFFD,
	0xACC5: 0xFFFD,
	0xACC6: 0xFFFD,
	0xACC7: 0xFFFD,
	0xACC8: 0xFFFD,
	0xACC9: 0xFFFD,
	0xACCA: 0xFFFD,
	0xACCB: 0xFFFD,
	0xACCC: 0xFFFD,
	0xACCD: 0xFFFD,
	0xACCE: 0xFFFD,
	0xACCF: 0xFFFD,
	0xACD0: 0xFFFD,
	0xACD1: 0xFFFD,
	0xACD2: 0xFFFD,
	0xACD3: 0xFFFD,
	0xACD4: 0xFFFD,
	0xACD5: 0xFFFD,
	0xACD6: 0xFFFD,
	0xACD7: 0xFFFD,
	0xACD8: 0xFFFD,
	0xACD9: 0xFFFD,
	0xACDA: 0xFFFD,
	0xACDB: 0xFFFD,
	0xACDC: 0xFFFD,
	0xACDD: 0xFFFD,
	0xACDE: 0xFFFD,
	0xACDF: 0xFFFD,
	0xACE0: 0xFFFD,
	0xACE1: 0xFFFD,
	0xACE2: 0xFFFD,
	0xACE3: 0xFFFD,
	0xACE4: 0xFFFD,
	0xACE5: 0xFFFD,
	0xACE6: 0xFFFD,
	0xACE7: 0xFFFD,
	0xACE8: 0xFFFD,
	0xACE9: 0xFFFD,
	0xACEA: 0xFFFD,
	0xACEB: 0xFFFD,
	0xACEC: 0xFFFD,
	0xACED: 0xFFFD,
	0xACEE: 0xFFFD,
	0xACEF: 0xFFFD,
	0xACF0: 0xFFFD,
	0xACF1: 0xFFFD,
	0xACF2: 0xFFFD,
	0xACF3: 0xFFFD,
	0xACF4: 0xFFFD,
	0xACF5: 0xFFFD,
	0xACF6: 0xFFFD,
	0xACF7: 0xFFFD,
	0xACF8: 0xFFFD,
	0xACF9: 0xFFFD,
	0xACFA: 0xFFFD,
	0xACFB: 0xFFFD,
	0xACFC: 0xFFFD,
	0xACFD: 0xFFFD,
	0xACFE: 0xFFFD,
	0xACFF: 0xFFFD,
	0xAD00: 0xFFFD,
	0xAD01: 0xFFFD,
	0xAD02: 0xFFFD,
	0xAD03: 0xFFFD,
	0xAD04: 0xFFFD,
	0xAD05: 0xFFFD,
	0xAD06: 0xFFFD,
	0xAD07: 0xFFFD,
	0xAD08: 0xFFFD,
	0xAD09: 0xFFFD,
	0xAD0A: 0xFFFD,
	0xAD0B: 0xFFFD,
	0xAD0C: 0xFFFD,
	0xAD0D: 0xFFFD,
	0xAD0E: 0xFFFD,
	0xAD0F: 0xFFFD,
	0xAD10: 0xFFFD,
	0xAD11: 0xFFFD,
	0xAD12: 0xFFFD,
	0xAD13: 0xFFFD,
	0xAD14: 0xFFFD,
	0xAD15: 0xFFFD,
	0xAD16: 0xFFFD,
	0xAD17: 0xFFFD,
	0xAD18: 0xFFFD,
	0xAD19: 0xFFFD,
	0xAD1A: 0xFFFD,
	0xAD1B: 0xFFFD,
	0xAD1C: 0xFFFD,
	0xAD1D: 0xFFFD,
	0xAD1E: 0xFFFD,
	0xAD1F: 0xFFFD,
	0xAD20: 0xFFFD,
	0xAD21: 0xFFFD,
	0xAD22: 0xFFFD,
	0xAD23: 0xFFFD,
	0xAD24: 0xFFFD,
	0xAD25: 0xFFFD,
	0xAD26: 0xFFFD,
	0xAD27: 0xFFFD,
	0xAD28: 0xFFFD,
	0xAD29: 0xFFFD,
	0xAD2A: 0xFFFD,
	0xAD2B: 0xFFFD,
	0xAD2C: 0xFFFD,
	0xAD2D: 0xFFFD,
	0xAD2E: 0xFFFD,
	0xAD2F: 0xFFFD,
	0xAD30: 0xFFFD,
	0xAD31: 0xFFFD,
	0xAD32: 0xFFFD,
	0xAD33: 0xFFFD,
	0xAD34: 0xFFFD,
	0xAD35: 0xFFFD,
	0xAD36: 0xFFFD,
	0xAD37: 0xFFFD,
	0xAD38: 0xFFFD,
	0xAD39: 0xFFFD,
	0xAD3A: 0xFFFD,
	0xAD3B: 0xFFFD,
	0xAD3C: 0xFFFD,
	0xAD3D: 0xFFFD,
	0xAD3E: 0xFFFD,
	0xAD3F: 0xFFFD,
	0xAD40: 0xFFFD,
	0xAD41: 0xFFFD,
	0xAD42: 0xFFFD,
	0xAD43: 0xFFFD,
	0xAD44: 0xFFFD,
	0xAD45: 0xFFFD,
	0xAD46: 0xFFFD,
	0xAD47: 0xFFFD,
	0xAD48: 0xFFFD,
	0xAD49: 0xFFFD,
	0xAD4A: 0xFFFD,
	0xAD4B: 0xFFFD,
	0xAD4C: 0xFFFD,
	0xAD4D: 0xFFFD,
	0xAD4E: 0xFFFD,
	0xAD4F: 0xFFFD,
	0xAD50: 0xFFFD,
	0xAD51: 0xFFFD,
	0xAD52: 0xFFFD,
	0xAD53: 0xFFFD,
	0xAD54: 0xFFFD,
	0xAD55: 0xFFFD,
	0xAD56: 0xFFFD,
	0xAD57: 0xFFFD,
	0xAD58: 0xFFFD,
	0xAD59: 0xFFFD,
	0xAD5A: 0xFFFD,
	0xAD5B: 0xFFFD,
	0xAD5C: 0xFFFD,
	0xAD5D: 0xFFFD,
	0xAD5E: 0xFFFD,
	0xAD5F: 0xFFFD,
	0xAD60: 0xFFFD,
	0xAD61: 0xFFFD,
	0xAD62: 0xFFFD,
	0xAD63: 0xFFFD,
	0xAD64: 0xFFFD,
	0xAD65: 0xFFFD,
	0xAD66: 0xFFFD,
	0xAD67: 0xFFFD,
	0xAD68: 0xFFFD,
	0xAD69: 0xFFFD,
	0xAD6A: 0xFFFD,
	0xAD6B: 0xFFFD,
	0xAD6C: 0xFFFD,
	0xAD6D: 0xFFFD,
	0xAD6E: 0xFFFD,
	0xAD6F: 0xFFFD,
	0xAD70: 0xFFFD,
	0xAD71: 0xFFFD,
	0xAD72: 0xFFFD,
	0xAD73: 0xFFFD,
	0xAD74: 0xFFFD,
	0xAD75: 0xFFFD,
	0xAD76: 0xFFFD,
	0xAD77: 0xFFFD,
	0xAD78: 0xFFFD,
	0xAD79: 0xFFFD,
	0xAD7A: 0xFFFD,
	0xAD7B: 0xFFFD,
	0xAD7C: 0xFFFD,
	0xAD7D: 0xFFFD,
	0xAD7E: 0xFFFD,
	0xAD7F: 0xFFFD,
	0xAD80: 0xFFFD,
	0xAD81: 0xFFFD,
	0xAD82: 0xFFFD,
	0xAD83: 0xFFFD,
	0xAD84: 0xFFFD,
	0xAD85: 0xFFFD,
	0xAD86: 0xFFFD,
	0xAD87: 0xFFFD,
	0xAD88: 0xFFFD,
	0xAD89: 0xFFFD,
	0xAD8A: 0xFFFD,
	0xAD8B: 0xFFFD,
	0xAD8C: 0xFFFD,
	0xAD8D: 0xFFFD,
	0xAD8E: 0xFFFD,
	0xAD8F: 0xFFFD,
	0xAD90: 0xFFFD,
	0xAD91: 0xFFFD,
	0xAD92: 0xFFFD,
	0xAD93: 0xFFFD,
	0xAD94: 0xFFFD,
	0xAD95: 0xFFFD,
	0xAD96: 0xFFFD,
	0xAD97: 0xFFFD,
	0xAD98: 0xFFFD,
	0xAD99: 0xFFFD,
	0xAD9A: 0xFFFD,
	0xAD9B: 0xFFFD,
	0xAD9C: 0xFFFD,
	0xAD9D: 0xFFFD,
	0xAD9E: 0xFFFD,
	0xAD9F: 0xFFFD,
	0xADA0: 0xFFFD,
	0xADA1: 0xFFFD,
	0xADA2: 0xFFFD,
	0xADA3: 0xFFFD,
	0xADA4: 0xFFFD,
	0xADA5: 0xFFFD,
	0xADA6: 0xFFFD,
	0xADA7: 0xFFFD,
	0xADA8: 0xFFFD,
	0xADA9: 0xFFFD,
	0xADAA: 0xFFFD,
	0xADAB: 0xFFFD,
	0xADAC: 0xFFFD,
	0xADAD: 0xFFFD,
	0xADAE: 0xFFFD,
	0xADAF: 0xFFFD,
	0xADB0: 0xFFFD,
	0xADB1: 0xFFFD,
	0xADB2: 0xFFFD,
	0xADB3: 0xFFFD,
	0xADB4: 0xFFFD,
	0xADB5: 0xFFFD,
	0xADB6: 0xFFFD,
	0xADB7: 0xFFFD,
	0xADB8: 0xFFFD,
	0xADB9: 0xFFFD,
	0xADBA: 0xFFFD,
	0xADBB: 0xFFFD,
	0xADBC: 0xFFFD,
	0xADBD: 0xFFFD,
	0xADBE: 0xFFFD,
	0xADBF: 0xFFFD,
	0xADC0: 0xFFFD,
	0xADC1: 0xFFFD,
	0xADC2: 0xFFFD,
	0xADC3: 0xFFFD,
	0xADC4: 0xFFFD,
	0xADC5: 0xFFFD,
	0xADC6: 0xFFFD,
	0xADC7: 0xFFFD,
	0xADC8: 0xFFFD,
	0xADC9: 0xFFFD,
	0xADCA: 0xFFFD,
	0xADCB: 0xFFFD,
	0xADCC: 0xFFFD,
	0xADCD: 0xFFFD,
	0xADCE: 0xFFFD,
	0xADCF: 0xFFFD,
	0xADD0: 0xFFFD,
	0xADD1: 0xFFFD,
	0xADD2: 0xFFFD,
	0xADD3: 0xFFFD,
	0xADD4: 0xFFFD,
	0xADD5: 0xFFFD,
	0xADD6: 0xFFFD,
	0xADD7: 0xFFFD,
	0xADD8: 0xFFFD,
	0xADD9: 0xFFFD,
	0xADDA: 0xFFFD,
	0xADDB: 0xFFFD,
	0xADDC: 0xFFFD,
	0xADDD: 0xFFFD,
	0xADDE: 0xFFFD,
	0xADDF: 0xFFFD,
	0xADE0: 0xFFFD,
	0xADE1: 0xFFFD,
	0xADE2: 0xFFFD,
	0xADE3: 0xFFFD,
	0xADE4: 0xFFFD,
	0xADE5: 0xFFFD,
	0xADE6: 0xFFFD,
	0xADE7: 0xFFFD,
	0xADE8: 0xFFFD,
	0xADE9: 0xFFFD,
	0xADEA: 0xFFFD,
	0xADEB: 0xFFFD,
	0xADEC: 0xFFFD,
	0xADED: 0xFFFD,
	0xADEE: 0xFFFD,
	0xADEF: 0xFFFD,
	0xADF0: 0xFFFD,
	0xADF1: 0xFFFD,
	0xADF2: 0xFFFD,
	0xADF3: 0xFFFD,
	0xADF4: 0xFFFD,
	0xADF5: 0xFFFD,
	0xADF6: 0xFFFD,
	0xADF7: 0xFFFD,
	0xADF8: 0xFFFD,
	0xADF9: 0xFFFD,
	0xADFA: 0xFFFD,
	0xADFB: 0xFFFD,
	0xADFC: 0xFFFD,
	0xADFD: 0xFFFD,
	0xADFE: 0xFFFD,
	0xADFF: 0xFFFD,
	0xAE00: 0xFFFD,
	0xAE01: 0xFFFD,
	0xAE02: 0xFFFD,
	0xAE03: 0xFFFD,
	0xAE04: 0xFFFD,
	0xAE05: 0xFFFD,
	0xAE06: 0xFFFD,
	0xAE07: 0xFFFD,
	0xAE08: 0xFFFD,
	0xAE09: 0xFFFD,
	0xAE0A: 0xFFFD,
	0xAE0B: 0xFFFD,
	0xAE0C: 0xFFFD,
	0xAE0D: 0xFFFD,
	0xAE0E: 0xFFFD,
	0xAE0F: 0xFFFD,
	0xAE10: 0xFFFD,
	0xAE11: 0xFFFD,
	0xAE12: 0xFFFD,
	0xAE13: 0xFFFD,
	0xAE14: 0xFFFD,
	0xAE15: 0xFFFD,
	0xAE16: 0xFFFD,
	0xAE17: 0xFFFD,
	0xAE18: 0xFFFD,
	0xAE19: 0xFFFD,
	0xAE1A: 0xFFFD,
	0xAE1B: 0xFFFD,
	0xAE1C: 0xFFFD,
	0xAE1D: 0xFFFD,
	0xAE1E: 0xFFFD,
	0xAE1F: 0xFFFD,
	0xAE20: 0xFFFD,
	0xAE21: 0xFFFD,
	0xAE22: 0xFFFD,
	0xAE23: 0xFFFD,
	0xAE24: 0xFFFD,
	0xAE25: 0xFFFD,
	0xAE26: 0xFFFD,
	0xAE27: 0xFFFD,
	0xAE28: 0xFFFD,
	0xAE29: 0xFFFD,
	0xAE2A: 0xFFFD,
	0xAE2B: 0xFFFD,
	0xAE2C: 0xFFFD,
	0xAE2D: 0xFFFD,
	0xAE2E: 0xFFFD,
	0xAE2F: 0xFFFD,
	0xAE30: 0xFFFD,
	0xAE31: 0xFFFD,
	0xAE32: 0xFFFD,
	0xAE33: 0xFFFD,
	0xAE34: 0xFFFD,
	0xAE35: 0xFFFD,
	0xAE36: 0xFFFD,
	0xAE37: 0xFFFD,
	0xAE38: 0xFFFD,
	0xAE39: 0xFFFD,
	0xAE3A: 0xFFFD,
	0xAE3B: 0xFFFD,
	0xAE3C: 0xFFFD,
	0xAE3D: 0xFFFD,
	0xAE3E: 0xFFFD,
	0xAE3F: 0xFFFD,
	0xAE40: 0xFFFD,
	0xAE41: 0xFFFD,
	0xAE42: 0xFFFD,
	0xAE43: 0xFFFD,
	0xAE44: 0xFFFD,
	0xAE45: 0xFFFD,
	0xAE46: 0xFFFD,
	0xAE47: 0xFFFD,
	0xAE48: 0xFFFD,
	0xAE49: 0xFFFD,
	0xAE4A: 0xFFFD,
	0xAE4B: 0xFFFD,
	0xAE4C: 0xFFFD,
	0xAE4D: 0xFFFD,
	0xAE4E: 0xFFFD,
	0xAE4F: 0xFFFD,
	0xAE50: 0xFFFD,
	0xAE51: 0xFFFD,
	0xAE52: 0xFFFD,
	0xAE53: 0xFFFD,
	0xAE54: 0xFFFD,
	0xAE55: 0xFFFD,
	0xAE56: 0xFFFD,
	0xAE57: 0xFFFD,
	0xAE58: 0xFFFD,
	0xAE59: 0xFFFD,
	0xAE5A: 0xFFFD,
	0xAE5B: 0xFFFD,
	0xAE5C: 0xFFFD,
	0xAE5D: 0xFFFD,
	0xAE5E: 0xFFFD,
	0xAE5F: 0xFFFD,
	0xAE60: 0xFFFD,
	0xAE61: 0xFFFD,
	0xAE62: 0xFFFD,
	0xAE63: 0xFFFD,
	0xAE64: 0xFFFD,
	0xAE65: 0xFFFD,
	0xAE66: 0xFFFD,
	0xAE67: 0xFFFD,
	0xAE68: 0xFFFD,
	0xAE69: 0xFFFD,
	0xAE6A: 0xFFFD,
	0xAE6B: 0xFFFD,
	0xAE6C: 0xFFFD,
	0xAE6D: 0xFFFD,
	0xAE6E: 0xFFFD,
	0xAE6F: 0xFFFD,
	0xAE70: 0xFFFD,
	0xAE71: 0xFFFD,
	0xAE72: 0xFFFD,
	0xAE73: 0xFFFD,
	0xAE74: 0xFFFD,
	0xAE75: 0xFFFD,
	0xAE76: 0xFFFD,
	0xAE77: 0xFFFD,
	0xAE78: 0xFFFD,
	0xAE79: 0xFFFD,
	0xAE7A: 0xFFFD,
	0xAE7B: 0xFFFD,
	0xAE7C: 0xFFFD,
	0xAE7D: 0xFFFD,
	0xAE7E: 0xFFFD,
	0xAE7F: 0xFFFD,
	0xAE80: 0xFFFD,
	0xAE81: 0xFFFD,
	0xAE82: 0xFFFD,
	0xAE83: 0xFFFD,
	0xAE84: 0xFFFD,
	0xAE85: 0xFFFD,
	0xAE86: 0xFFFD,
	0xAE87: 0xFFFD,
	0xAE88: 0xFFFD,
	0xAE89: 0xFFFD,
	0xAE8A: 0xFFFD,
	0xAE8B: 0xFFFD,
	0xAE8C: 0xFFFD,
	0xAE8D: 0xFFFD,
	0xAE8E: 0xFFFD,
	0xAE8F: 0xFFFD,
	0xAE90: 0xFFFD,
	0xAE91: 0xFFFD,
	0xAE92: 0xFFFD,
	0xAE93: 0xFFFD,
	0xAE94: 0xFFFD,
	0xAE95: 0xFFFD,
	0xAE96: 0xFFFD,
	0xAE97: 0xFFFD,
	0xAE98: 0xFFFD,
	0xAE99: 0xFFFD,
	0xAE9A: 0xFFFD,
	0xAE9B: 0xFFFD,
	0xAE9C: 0xFFFD,
	0xAE9D: 0xFFFD,
	0xAE9E: 0xFFFD,
	0xAE9F: 0xFFFD,
	0xAEA0: 0xFFFD,
	0xAEA1: 0xFFFD,
	0xAEA2: 0xFFFD,
	0xAEA3: 0xFFFD,
	0xAEA4: 0xFFFD,
	0xAEA5: 0xFFFD,
	0xAEA6: 0xFFFD,
	0xAEA7: 0xFFFD,
	0xAEA8: 0xFFFD,
	0xAEA9: 0xFFFD,
	0xAEAA: 0xFFFD,
	0xAEAB: 0xFFFD,
	0xAEAC: 0xFFFD,
	0xAEAD: 0xFFFD,
	0xAEAE: 0xFFFD,
	0xAEAF: 0xFFFD,
	0xAEB0: 0xFFFD,
	0xAEB1: 0xFFFD,
	0xAEB2: 0xFFFD,
	0xAEB3: 0xFFFD,
	0xAEB4: 0xFFFD,
	0xAEB5: 0xFFFD,
	0xAEB6: 0xFFFD,
	0xAEB7: 0xFFFD,
	0xAEB8: 0xFFFD,
	0xAEB9: 0xFFFD,
	0xAEBA: 0xFFFD,
	0xAEBB: 0xFFFD,
	0xAEBC: 0xFFFD,
	0xAEBD: 0xFFFD,
	0xAEBE: 0xFFFD,
	0xAEBF: 0xFFFD,
	0xAEC0: 0xFFFD,
	0xAEC1: 0xFFFD,
	0xAEC2: 0xFFFD,
	0xAEC3: 0xFFFD,
	0xAEC4: 0xFFFD,
	0xAEC5: 0xFFFD,
	0xAEC6: 0xFFFD,
	0xAEC7: 0xFFFD,
	0xAEC8: 0xFFFD,
	0xAEC9: 0xFFFD,
	0xAECA: 0xFFFD,
	0xAECB: 0xFFFD,
	0xAECC: 0xFFFD,
	0xAECD: 0xFFFD,
	0xAECE: 0xFFFD,
	0xAECF: 0xFFFD,
	0xAED0: 0xFFFD,
	0xAED1: 0xFFFD,
	0xAED2: 0xFFFD,
	0xAED3: 0xFFFD,
	0xAED4: 0xFFFD,
	0xAED5: 0xFFFD,
	0xAED6: 0xFFFD,
	0xAED7: 0xFFFD,
	0xAED8: 0xFFFD,
	0xAED9: 0xFFFD,
	0xAEDA: 0xFFFD,
	0xAEDB: 0xFFFD,
	0xAEDC: 0xFFFD,
	0xAEDD: 0xFFFD,
	0xAEDE: 0xFFFD,
	0xAEDF: 0xFFFD,
	0xAEE0: 0xFFFD,
	0xAEE1: 0xFFFD,
	0xAEE2: 0xFFFD,
	0xAEE3: 0xFFFD,
	0xAEE4: 0xFFFD,
	0xAEE5: 0xFFFD,
	0xAEE6: 0xFFFD,
	0xAEE7: 0xFFFD,
	0xAEE8: 0xFFFD,
	0xAEE9: 0xFFFD,
	0xAEEA: 0xFFFD,
	0xAEEB: 0xFFFD,
	0xAEEC: 0xFFFD,
	0xAEED: 0xFFFD,
	0xAEEE: 0xFFFD,
	0xAEEF: 0xFFFD,
	0xAEF0: 0xFFFD,
	0xAEF1: 0xFFFD,
	0xAEF2: 0xFFFD,
	0xAEF3: 0xFFFD,
	0xAEF4: 0xFFFD,
	0xAEF5: 0xFFFD,
	0xAEF6: 0xFFFD,
	0xAEF7: 0xFFFD,
	0xAEF8: 0xFFFD,
	0xAEF9: 0xFFFD,
	0xAEFA: 0xFFFD,
	0xAEFB: 0xFFFD,
	0xAEFC: 0xFFFD,
	0xAEFD: 0xFFFD,
	0xAEFE: 0xFFFD,
	0xAEFF: 0xFFFD,
	0xAF00: 0xFFFD,
	0xAF01: 0xFFFD,
	0xAF02: 0xFFFD,
	0xAF03: 0xFFFD,
	0xAF04: 0xFFFD,
	0xAF05: 0xFFFD,
	0xAF06: 0xFFFD,
	0xAF07: 0xFFFD,
	0xAF08: 0xFFFD,
	0xAF09: 0xFFFD,
	0xAF0A: 0xFFFD,
	0xAF0B: 0xFFFD,
	0xAF0C: 0xFFFD,
	0xAF0D: 0xFFFD,
	0xAF0E: 0xFFFD,
	0xAF0F: 0xFFFD,
	0xAF10: 0xFFFD,
	0xAF11: 0xFFFD,
	0xAF12: 0xFFFD,
	0xAF13: 0xFFFD,
	0xAF14: 0xFFFD,
	0xAF15: 0xFFFD,
	0xAF16: 0xFFFD,
	0xAF17: 0xFFFD,
	0xAF18: 0xFFFD,
	0xAF19: 0xFFFD,
	0xAF1A: 0xFFFD,
	0xAF1B: 0xFFFD,
	0xAF1C: 0xFFFD,
	0xAF1D: 0xFFFD,
	0xAF1E: 0xFFFD,
	0xAF1F: 0xFFFD,
	0xAF20: 0xFFFD,
	0xAF21: 0xFFFD,
	0xAF22: 0xFFFD,
	0xAF23: 0xFFFD,
	0xAF24: 0xFFFD,
	0xAF25: 0xFFFD,
	0xAF26: 0xFFFD,
	0xAF27: 0xFFFD,
	0xAF28: 0xFFFD,
	0xAF29: 0xFFFD,
	0xAF2A: 0xFFFD,
	0xAF2B: 0xFFFD,
	0xAF2C: 0xFFFD,
	0xAF2D: 0xFFFD,
	0xAF2E: 0xFFFD,
	0xAF2F: 0xFFFD,
	0xAF30: 0xFFFD,
	0xAF31: 0xFFFD,
	0xAF32: 0xFFFD,
	0xAF33: 0xFFFD,
	0xAF34: 0xFFFD,
	0xAF35: 0xFFFD,
	0xAF36: 0xFFFD,
	0xAF37: 0xFFFD,
	0xAF38: 0xFFFD,
	0xAF39: 0xFFFD,
	0xAF3A: 0xFFFD,
	0xAF3B: 0xFFFD,
	0xAF3C: 0xFFFD,
	0xAF3D: 0xFFFD,
	0xAF3E: 0xFFFD,
	0xAF3F: 0xFFFD,
	0xAF40: 0xFFFD,
	0xAF41: 0xFFFD,
	0xAF42: 0xFFFD,
	0xAF43: 0xFFFD,
	0xAF44: 0xFFFD,
	0xAF45: 0xFFFD,
	0xAF46: 0xFFFD,
	0xAF47: 0xFFFD,
	0xAF48: 0xFFFD,
	0xAF49: 0xFFFD,
	0xAF4A: 0xFFFD,
	0xAF4B: 0xFFFD,
	0xAF4C: 0xFFFD,
	0xAF4D: 0xFFFD,
	0xAF4E: 0xFFFD,
	0xAF4F: 0xFFFD,
	0xAF50: 0xFFFD,
	0xAF51: 0xFFFD,
	0xAF52: 0xFFFD,
	0xAF53: 0xFFFD,
	0xAF54: 0xFFFD,
	0xAF55: 0xFFFD,
	0xAF56: 0xFFFD,
	0xAF57: 0xFFFD,
	0xAF58: 0xFFFD,
	0xAF59: 0xFFFD,
	0xAF5A: 0xFFFD,
	0xAF5B: 0xFFFD,
	0xAF5C: 0xFFFD,
	0xAF5D: 0xFFFD,
	0xAF5E: 0xFFFD,
	0xAF5F: 0xFFFD,
	0xAF60: 0xFFFD,
	0xAF61: 0xFFFD,
	0xAF62: 0xFFFD,
	0xAF63: 0xFFFD,
	0xAF64: 0xFFFD,
	0xAF65: 0xFFFD,
	0xAF66: 0xFFFD,
	0xAF67: 0xFFFD,
	0xAF68: 0xFFFD,
	0xAF69: 0xFFFD,
	0xAF6A: 0xFFFD,
	0xAF6B: 0xFFFD,
	0xAF6C: 0xFFFD,
	0xAF6D: 0xFFFD,
	0xAF6E: 0xFFFD,
	0xAF6F: 0xFFFD,
	0xAF70: 0xFFFD,
	0xAF71: 0xFFFD,
	0xAF72: 0xFFFD,
	0xAF73: 0xFFFD,
	0xAF74: 0xFFFD,
	0xAF75: 0xFFFD,
	0xAF76: 0xFFFD,
	0xAF77: 0xFFFD,
	0xAF78: 0xFFFD,
	0xAF79: 0xFFFD,
	0xAF7A: 0xFFFD,
	0xAF7B: 0xFFFD,
	0xAF7C: 0xFFFD,
	0xAF7D: 0xFFFD,
	0xAF7E: 0xFFFD,
	0xAF7F: 0xFFFD,
	0xAF80: 0xFFFD,
	0xAF81: 0xFFFD,
	0xAF82: 0xFFFD,
	0xAF83: 0xFFFD,
	0xAF84: 0xFFFD,
	0xAF85: 0xFFFD,
	0xAF86: 0xFFFD,
	0xAF87: 0xFFFD,
	0xAF88: 0xFFFD,
	0xAF89: 0xFFFD,
	0xAF8A: 0xFFFD,
	0xAF8B: 0xFFFD,
	0xAF8C: 0xFFFD,
	0xAF8D: 0xFFFD,
	0xAF8E: 0xFFFD,
	0xAF8F: 0xFFFD,
	0xAF90: 0xFFFD,
	0xAF91: 0xFFFD,
	0xAF92: 0xFFFD,
	0xAF93: 0xFFFD,
	0xAF94: 0xFFFD,
	0xAF95: 0xFFFD,
	0xAF96: 0xFFFD,
	0xAF97: 0xFFFD,
	0xAF98: 0xFFFD,
	0xAF99: 0xFFFD,
	0xAF9A: 0xFFFD,
	0xAF9B: 0xFFFD,
	0xAF9C: 0xFFFD,
	0xAF9D: 0xFFFD,
	0xAF9E: 0xFFFD,
	0xAF9F: 0xFFFD,
	0xAFA0: 0xFFFD,
	0xAFA1: 0xFFFD,
	0xAFA2: 0xFFFD,
	0xAFA3: 0xFFFD,
	0xAFA4: 0xFFFD,
	0xAFA5: 0xFFFD,
	0xAFA6: 0xFFFD,
	0xAFA7: 0xFFFD,
	0xAFA8: 0xFFFD,
	0xAFA9: 0xFFFD,
	0xAFAA: 0xFFFD,
	0xAFAB: 0xFFFD,
	0xAFAC: 0xFFFD,
	0xAFAD: 0xFFFD,
	0xAFAE: 0xFFFD,
	0xAFAF: 0xFFFD,
	0xAFB0: 0xFFFD,
	0xAFB1: 0xFFFD,
	0xAFB2: 0xFFFD,
	0xAFB3: 0xFFFD,
	0xAFB4: 0xFFFD,
	0xAFB5: 0xFFFD,
	0xAFB6: 0xFFFD,
	0xAFB7: 0xFFFD,
	0xAFB8: 0xFFFD,
	0xAFB9: 0xFFFD,
	0xAFBA: 0xFFFD,
	0xAFBB: 0xFFFD,
	0xAFBC: 0xFFFD,
	0xAFBD: 0xFFFD,
	0xAFBE: 0xFFFD,
	0xAFBF: 0xFFFD,
	0xAFC0: 0xFFFD,
	0xAFC1: 0xFFFD,
	0xAFC2: 0xFFFD,
	0xAFC3: 0xFFFD,
	0xAFC4: 0xFFFD,
	0xAFC5: 0xFFFD,
	0xAFC6: 0xFFFD,
	0xAFC7: 0xFFFD,
	0xAFC8: 0xFFFD,
	0xAFC9: 0xFFFD,
	0xAFCA: 0xFFFD,
	0xAFCB: 0xFFFD,
	0xAFCC: 0xFFFD,
	0xAFCD: 0xFFFD,
	0xAFCE: 0xFFFD,
	0xAFCF: 0xFFFD,
	0xAFD0: 0xFFFD,
	0xAFD1: 0xFFFD,
	0xAFD2: 0xFFFD,
	0xAFD3: 0xFFFD,
	0xAFD4: 0xFFFD,
	0xAFD5: 0xFFFD,
	0xAFD6: 0xFFFD,
	0xAFD7: 0xFFFD,
	0xAFD8: 0xFFFD,
	0xAFD9: 0xFFFD,
	0xAFDA: 0xFFFD,
	0xAFDB: 0xFFFD,
	0xAFDC: 0xFFFD,
	0xAFDD: 0xFFFD,
	0xAFDE: 0xFFFD,
	0xAFDF: 0xFFFD,
	0xAFE0: 0xFFFD,
	0xAFE1: 0xFFFD,
	0xAFE2: 0xFFFD,
	0xAFE3: 0xFFFD,
	0xAFE4: 0xFFFD,
	0xAFE5: 0xFFFD,
	0xAFE6: 0xFFFD,
	0xAFE7: 0xFFFD,
	0xAFE8: 0xFFFD,
	0xAFE9: 0xFFFD,
	0xAFEA: 0xFFFD,
	0xAFEB: 0xFFFD,
	0xAFEC: 0xFFFD,
	0xAFED: 0xFFFD,
	0xAFEE: 0xFFFD,
	0xAFEF: 0xFFFD,
	0xAFF0: 0xFFFD,
	0xAFF1: 0xFFFD,
	0xAFF2: 0xFFFD,
	0xAFF3: 0xFFFD,
	0xAFF4: 0xFFFD,
	0xAFF5: 0xFFFD,
	0xAFF6: 0xFFFD,
	0xAFF7: 0xFFFD,
	0xAFF8: 0xFFFD,
	0xAFF9: 0xFFFD,
	0xAFFA: 0xFFFD,
	0xAFFB: 0xFFFD,
	0xAFFC: 0xFFFD,
	0xAFFD: 0xFFFD,
	0xAFFE: 0xFFFD,
	0xAFFF: 0xFFFD,
	0xB000: 0xFFFD,
	0xB001: 0xFFFD,
	0xB002: 0xFFFD,
	0xB003: 0xFFFD,
	0xB004: 0xFFFD,
	0xB005: 0xFFFD,
	0xB006: 0xFFFD,
	0xB007: 0xFFFD,
	0xB008: 0xFFFD,
	0xB009: 0xFFFD,
	0xB00A: 0xFFFD,
	0xB00B: 0xFFFD,
	0xB00C: 0xFFFD,
	0xB00D: 0xFFFD,
	0xB00E: 0xFFFD,
	0xB00F: 0xFFFD,
	0xB010: 0xFFFD,
	0xB011: 0xFFFD,
	0xB012: 0xFFFD,
	0xB013: 0xFFFD,
	0xB014: 0xFFFD,
	0xB015: 0xFFFD,
	0xB016: 0xFFFD,
	0xB017: 0xFFFD,
	0xB018: 0xFFFD,
	0xB019: 0xFFFD,
	0xB01A: 0xFFFD,
	0xB01B: 0xFFFD,
	0xB01C: 0xFFFD,
	0xB01D: 0xFFFD,
	0xB01E: 0xFFFD,
	0xB01F: 0xFFFD,
	0xB020: 0xFFFD,
	0xB021: 0xFFFD,
	0xB022: 0xFFFD,
	0xB023: 0xFFFD,
	0xB024: 0xFFFD,
	0xB025: 0xFFFD,
	0xB026: 0xFFFD,
	0xB027: 0xFFFD,
	0xB028: 0xFFFD,
	0xB029: 0xFFFD,
	0xB02A: 0xFFFD,
	0xB02B: 0xFFFD,
	0xB02C: 0xFFFD,
	0xB02D: 0xFFFD,
	0xB02E: 0xFFFD,
	0xB02F: 0xFFFD,
	0xB030: 0xFFFD,
	0xB031: 0xFFFD,
	0xB032: 0xFFFD,
	0xB033: 0xFFFD,
	0xB034: 0xFFFD,
	0xB035: 0xFFFD,
	0xB036: 0xFFFD,
	0xB037: 0xFFFD,
	0xB038: 0xFFFD,
	0xB039: 0xFFFD,
	0xB03A: 0xFFFD,
	0xB03B: 0xFFFD,
	0xB03C: 0xFFFD,
	0xB03D: 0xFFFD,
	0xB03E: 0xFFFD,
	0xB03F: 0xFFFD,
	0xB040: 0xFFFD,
	0xB041: 0xFFFD,
	0xB042: 0xFFFD,
	0xB043: 0xFFFD,
	0xB044: 0xFFFD,
	0xB045: 0xFFFD,
	0xB046: 0xFFFD,
	0xB047: 0xFFFD,
	0xB048: 0xFFFD,
	0xB049: 0xFFFD,
	0xB04A: 0xFFFD,
	0xB04B: 0xFFFD,
	0xB04C: 0xFFFD,
	0xB04D: 0xFFFD,
	0xB04E: 0xFFFD,
	0xB04F: 0xFFFD,
	0xB050: 0xFFFD,
	0xB051: 0xFFFD,
	0xB052: 0xFFFD,
	0xB053: 0xFFFD,
	0xB054: 0xFFFD,
	0xB055: 0xFFFD,
	0xB056: 0xFFFD,
	0xB057: 0xFFFD,
	0xB058: 0xFFFD,
	0xB059: 0xFFFD,
	0xB05A: 0xFFFD,
	0xB05B: 0xFFFD,
	0xB05C: 0xFFFD,
	0xB05D: 0xFFFD,
	0xB05E: 0xFFFD,
	0xB05F: 0xFFFD,
	0xB060: 0xFFFD,
	0xB061: 0xFFFD,
	0xB062: 0xFFFD,
	0xB063: 0xFFFD,
	0xB064: 0xFFFD,
	0xB065: 0xFFFD,
	0xB066: 0xFFFD,
	0xB067: 0xFFFD,
	0xB068: 0xFFFD,
	0xB069: 0xFFFD,
	0xB06A: 0xFFFD,
	0xB06B: 0xFFFD,
	0xB06C: 0xFFFD,
	0xB06D: 0xFFFD,
	0xB06E: 0xFFFD,
	0xB06F: 0xFFFD,
	0xB070: 0xFFFD,
	0xB071: 0xFFFD,
	0xB072: 0xFFFD,
	0xB073: 0xFFFD,
	0xB074: 0xFFFD,
	0xB075: 0xFFFD,
	0xB076: 0xFFFD,
	0xB077: 0xFFFD,
	0xB078: 0xFFFD,
	0xB079: 0xFFFD,
	0xB07A: 0xFFFD,
	0xB07B: 0xFFFD,
	0xB07C: 0xFFFD,
	0xB07D: 0xFFFD,
	0xB07E: 0xFFFD,
	0xB07F: 0xFFFD,
	0xB080: 0xFFFD,
	0xB081: 0xFFFD,
	0xB082: 0xFFFD,
	0xB083: 0xFFFD,
	0xB084: 0xFFFD,
	0xB085: 0xFFFD,
	0xB086: 0xFFFD,
	0xB087: 0xFFFD,
	0xB088: 0xFFFD,
	0xB089: 0xFFFD,
	0xB08A: 0xFFFD,
	0xB08B: 0xFFFD,
	0xB08C: 0xFFFD,
	0xB08D: 0xFFFD,
	0xB08E: 0xFFFD,
	0xB08F: 0xFFFD,
	0xB090: 0xFFFD,
	0xB091: 0xFFFD,
	0xB092: 0xFFFD,
	0xB093: 0xFFFD,
	0xB094: 0xFFFD,
	0xB095: 0xFFFD,
	0xB096: 0xFFFD,
	0xB097: 0xFFFD,
	0xB098: 0xFFFD,
	0xB099: 0xFFFD,
	0xB09A: 0xFFFD,
	0xB09B: 0xFFFD,
	0xB09C: 0xFFFD,
	0xB09D: 0xFFFD,
	0xB09E: 0xFFFD,
	0xB09F: 0xFFFD,
	0xB0A0: 0xFFFD,
	0xB0A1: 0xFFFD,
	0xB0A2: 0xFFFD,
	0xB0A3: 0xFFFD,
	0xB0A4: 0xFFFD,
	0xB0A5: 0xFFFD,
	0xB0A6: 0xFFFD,
	0xB0A7: 0xFFFD,
	0xB0A8: 0xFFFD,
	0xB0A9: 0xFFFD,
	0xB0AA: 0xFFFD,
	0xB0AB: 0xFFFD,
	0xB0AC: 0xFFFD,
	0xB0AD: 0xFFFD,
	0xB0AE: 0xFFFD,
	0xB0AF: 0xFFFD,
	0xB0B0: 0xFFFD,
	0xB0B1: 0xFFFD,
	0xB0B2: 0xFFFD,
	0xB0B3: 0xFFFD,
	0xB0B4: 0xFFFD,
	0xB0B5: 0xFFFD,
	0xB0B6: 0xFFFD,
	0xB0B7: 0xFFFD,
	0xB0B8: 0xFFFD,
	0xB0B9: 0xFFFD,
	0xB0BA: 0xFFFD,
	0xB0BB: 0xFFFD,
	0xB0BC: 0xFFFD,
	0xB0BD: 0xFFFD,
	0xB0BE: 0xFFFD,
	0xB0BF: 0xFFFD,
	0xB0C0: 0xFFFD,
	0xB0C1: 0xFFFD,
	0xB0C2: 0xFFFD,
	0xB0C3: 0xFFFD,
	0xB0C4: 0xFFFD,
	0xB0C5: 0xFFFD,
	0xB0C6: 0xFFFD,
	0xB0C7: 0xFFFD,
	0xB0C8: 0xFFFD,
	0xB0C9: 0xFFFD,
	0xB0CA: 0xFFFD,
	0xB0CB: 0xFFFD,
	0xB0CC: 0xFFFD,
	0xB0CD: 0xFFFD,
	0xB0CE: 0xFFFD,
	0xB0CF: 0xFFFD,
	0xB0D0: 0xFFFD,
	0xB0D1: 0xFFFD,
	0xB0D2: 0xFFFD,
	0xB0D3: 0xFFFD,
	0xB0D4: 0xFFFD,
	0xB0D5: 0xFFFD,
	0xB0D6: 0xFFFD,
	0xB0D7: 0xFFFD,
	0xB0D8: 0xFFFD,
	0xB0D9: 0xFFFD,
	0xB0DA: 0xFFFD,
	0xB0DB: 0xFFFD,
	0xB0DC: 0xFFFD,
	0xB0DD: 0xFFFD,
	0xB0DE: 0xFFFD,
	0xB0DF: 0xFFFD,
	0xB0E0: 0xFFFD,
	0xB0E1: 0xFFFD,
	0xB0E2: 0xFFFD,
	0xB0E3: 0xFFFD,
	0xB0E4: 0xFFFD,
	0xB0E5: 0xFFFD,
	0xB0E6: 0xFFFD,
	0xB0E7: 0xFFFD,
	0xB0E8: 0xFFFD,
	0xB0E9: 0xFFFD,
	0xB0EA: 0xFFFD,
	0xB0EB: 0xFFFD,
	0xB0EC: 0xFFFD,
	0xB0ED: 0xFFFD,
	0xB0EE: 0xFFFD,
	0xB0EF: 0xFFFD,
	0xB0F0: 0xFFFD,
	0xB0F1: 0xFFFD,
	0xB0F2: 0xFFFD,
	0xB0F3: 0xFFFD,
	0xB0F4: 0xFFFD,
	0xB0F5: 0xFFFD,
	0xB0F6: 0xFFFD,
	0xB0F7: 0xFFFD,
	0xB0F8: 0xFFFD,
	0xB0F9: 0xFFFD,
	0xB0FA: 0xFFFD,
	0xB0FB: 0xFFFD,
	0xB0FC: 0xFFFD,
	0xB0FD: 0xFFFD,
	0xB0FE: 0xFFFD,
	0xB0FF: 0xFFFD,
	0xB100: 0xFFFD,
	0xB101: 0xFFFD,
	0xB102: 0xFFFD,
	0xB103: 0xFFFD,
	0xB104: 0xFFFD,
	0xB105: 0xFFFD,
	0xB106: 0xFFFD,
	0xB107: 0xFFFD,
	0xB108: 0xFFFD,
	0xB109: 0xFFFD,
	0xB10A: 0xFFFD,
	0xB10B: 0xFFFD,
	0xB10C: 0xFFFD,
	0xB10D: 0xFFFD,
	0xB10E: 0xFFFD,
	0xB10F: 0xFFFD,
	0xB110: 0xFFFD,
	0xB111: 0xFFFD,
	0xB112: 0xFFFD,
	0xB113: 0xFFFD,
	0xB114: 0xFFFD,
	0xB115: 0xFFFD,
	0xB116: 0xFFFD,
	0xB117: 0xFFFD,
	0xB118: 0xFFFD,
	0xB119: 0xFFFD,
	0xB11A: 0xFFFD,
	0xB11B: 0xFFFD,
	0xB11C: 0xFFFD,
	0xB11D: 0xFFFD,
	0xB11E: 0xFFFD,
	0xB11F: 0xFFFD,
	0xB120: 0xFFFD,
	0xB121: 0xFFFD,
	0xB122: 0xFFFD,
	0xB123: 0xFFFD,
	0xB124: 0xFFFD,
	0xB125: 0xFFFD,
	0xB126: 0xFFFD,
	0xB127: 0xFFFD,
	0xB128: 0xFFFD,
	0xB129: 0xFFFD,
	0xB12A: 0xFFFD,
	0xB12B: 0xFFFD,
	0xB12C: 0xFFFD,
	0xB12D: 0xFFFD,
	0xB12E: 0xFFFD,
	0xB12F: 0xFFFD,
	0xB130: 0xFFFD,
	0xB131: 0xFFFD,
	0xB132: 0xFFFD,
	0xB133: 0xFFFD,
	0xB134: 0xFFFD,
	0xB135: 0xFFFD,
	0xB136: 0xFFFD,
	0xB137: 0xFFFD,
	0xB138: 0xFFFD,
	0xB139: 0xFFFD,
	0xB13A: 0xFFFD,
	0xB13B: 0xFFFD,
	0xB13C: 0xFFFD,
	0xB13D: 0xFFFD,
	0xB13E: 0xFFFD,
	0xB13F: 0xFFFD,
	0xB140: 0xFFFD,
	0xB141: 0xFFFD,
	0xB142: 0xFFFD,
	0xB143: 0xFFFD,
	0xB144: 0xFFFD,
	0xB145: 0xFFFD,
	0xB146: 0xFFFD,
	0xB147: 0xFFFD,
	0xB148: 0xFFFD,
	0xB149: 0xFFFD,
	0xB14A: 0xFFFD,
	0xB14B: 0xFFFD,
	0xB14C: 0xFFFD,
	0xB14D: 0xFFFD,
	0xB14E: 0xFFFD,
	0xB14F: 0xFFFD,
	0xB150: 0xFFFD,
	0xB151: 0xFFFD,
	0xB152: 0xFFFD,
	0xB153: 0xFFFD,
	0xB154: 0xFFFD,
	0xB155: 0xFFFD,
	0xB156: 0xFFFD,
	0xB157: 0xFFFD,
	0xB158: 0xFFFD,
	0xB159: 0xFFFD,
	0xB15A: 0xFFFD,
	0xB15B: 0xFFFD,
	0xB15C: 0xFFFD,
	0xB15D: 0xFFFD,
	0xB15E: 0xFFFD,
	0xB15F: 0xFFFD,
	0xB160: 0xFFFD,
	0xB161: 0xFFFD,
	0xB162: 0xFFFD,
	0xB163: 0xFFFD,
	0xB164: 0xFFFD,
	0xB165: 0xFFFD,
	0xB166: 0xFFFD,
	0xB167: 0xFFFD,
	0xB168: 0xFFFD,
	0xB169: 0xFFFD,
	0xB16A: 0xFFFD,
	0xB16B: 0xFFFD,
	0xB16C: 0xFFFD,
	0xB16D: 0xFFFD,
	0xB16E: 0xFFFD,
	0xB16F: 0xFFFD,
	0xB170: 0xFFFD,
	0xB171: 0xFFFD,
	0xB172: 0xFFFD,
	0xB173: 0xFFFD,
	0xB174: 0xFFFD,
	0xB175: 0xFFFD,
	0xB176: 0xFFFD,
	0xB177: 0xFFFD,
	0xB178: 0xFFFD,
	0xB179: 0xFFFD,
	0xB17A: 0xFFFD,
	0xB17B: 0xFFFD,
	0xB17C: 0xFFFD,
	0xB17D: 0xFFFD,
	0xB17E: 0xFFFD,
	0xB17F: 0xFFFD,
	0xB180: 0xFFFD,
	0xB181: 0xFFFD,
	0xB182: 0xFFFD,
	0xB183: 0xFFFD,
	0xB184: 0xFFFD,
	0xB185: 0xFFFD,
	0xB186: 0xFFFD,
	0xB187: 0xFFFD,
	0xB188: 0xFFFD,
	0xB189: 0xFFFD,
	0xB18A: 0xFFFD,
	0xB18B: 0xFFFD,
	0xB18C: 0xFFFD,
	0xB18D: 0xFFFD,
	0xB18E: 0xFFFD,
	0xB18F: 0xFFFD,
	0xB190: 0xFFFD,
	0xB191: 0xFFFD,
	0xB192: 0xFFFD,
	0xB193: 0xFFFD,
	0xB194: 0xFFFD,
	0xB195: 0xFFFD,
	0xB196: 0xFFFD,
	0xB197: 0xFFFD,
	0xB198: 0xFFFD,
	0xB199: 0xFFFD,
	0xB19A: 0xFFFD,
	0xB19B: 0xFFFD,
	0xB19C: 0xFFFD,
	0xB19D: 0xFFFD,
	0xB19E: 0xFFFD,
	0xB19F: 0xFFFD,
	0xB1A0: 0xFFFD,
	0xB1A1: 0xFFFD,
	0xB1A2: 0xFFFD,
	0xB1A3: 0xFFFD,
	0xB1A4: 0xFFFD,
	0xB1A5: 0xFFFD,
	0xB1A6: 0xFFFD,
	0xB1A7: 0xFFFD,
	0xB1A8: 0xFFFD,
	0xB1A9: 0xFFFD,
	0xB1AA: 0xFFFD,
	0xB1AB: 0xFFFD,
	0xB1AC: 0xFFFD,
	0xB1AD: 0xFFFD,
	0xB1AE: 0xFFFD,
	0xB1AF: 0xFFFD,
	0xB1B0: 0xFFFD,
	0xB1B1: 0xFFFD,
	0xB1B2: 0xFFFD,
	0xB1B3: 0xFFFD,
	0xB1B4: 0xFFFD,
	0xB1B5: 0xFFFD,
	0xB1B6: 0xFFFD,
	0xB1B7: 0xFFFD,
	0xB1B8: 0xFFFD,
	0xB1B9: 0xFFFD,
	0xB1BA: 0xFFFD,
	0xB1BB: 0xFFFD,
	0xB1BC: 0xFFFD,
	0xB1BD: 0xFFFD,
	0xB1BE: 0xFFFD,
	0xB1BF: 0xFFFD,
	0xB1C0: 0xFFFD,
	0xB1C1: 0xFFFD,
	0xB1C2: 0xFFFD,
	0xB1C3: 0xFFFD,
	0xB1C4: 0xFFFD,
	0xB1C5: 0xFFFD,
	0xB1C6: 0xFFFD,
	0xB1C7: 0xFFFD,
	0xB1C8: 0xFFFD,
	0xB1C9: 0xFFFD,
	0xB1CA: 0xFFFD,
	0xB1CB: 0xFFFD,
	0xB1CC: 0xFFFD,
	0xB1CD: 0xFFFD,
	0xB1CE: 0xFFFD,
	0xB1CF: 0xFFFD,
	0xB1D0: 0xFFFD,
	0xB1D1: 0xFFFD,
	0xB1D2: 0xFFFD,
	0xB1D3: 0xFFFD,
	0xB1D4: 0xFFFD,
	0xB1D5: 0xFFFD,
	0xB1D6: 0xFFFD,
	0xB1D7: 0xFFFD,
	0xB1D8: 0xFFFD,
	0xB1D9: 0xFFFD,
	0xB1DA: 0xFFFD,
	0xB1DB: 0xFFFD,
	0xB1DC: 0xFFFD,
	0xB1DD: 0xFFFD,
	0xB1DE: 0xFFFD,
	0xB1DF: 0xFFFD,
	0xB1E0: 0xFFFD,
	0xB1E1: 0xFFFD,
	0xB1E2: 0xFFFD,
	0xB1E3: 0xFFFD,
	0xB1E4: 0xFFFD,
	0xB1E5: 0xFFFD,
	0xB1E6: 0xFFFD,
	0xB1E7: 0xFFFD,
	0xB1E8: 0xFFFD,
	0xB1E9: 0xFFFD,
	0xB1EA: 0xFFFD,
	0xB1EB: 0xFFFD,
	0xB1EC: 0xFFFD,
	0xB1ED: 0xFFFD,
	0xB1EE: 0xFFFD,
	0xB1EF: 0xFFFD,
	0xB1F0: 0xFFFD,
	0xB1F1: 0xFFFD,
	0xB1F2: 0xFFFD,
	0xB1F3: 0xFFFD,
	0xB1F4: 0xFFFD,
	0xB1F5: 0xFFFD,
	0xB1F6: 0xFFFD,
	0xB1F7: 0xFFFD,
	0xB1F8: 0xFFFD,
	0xB1F9: 0xFFFD,
	0xB1FA: 0xFFFD,
	0xB1FB: 0xFFFD,
	0xB1FC: 0xFFFD,
	0xB1FD: 0xFFFD,
	0xB1FE: 0xFFFD,
	0xB1FF: 0xFFFD,
	0xB200: 0xFFFD,
	0xB201: 0xFFFD,
	0xB202: 0xFFFD,
	0xB203: 0xFFFD,
	0xB204: 0xFFFD,
	0xB205: 0xFFFD,
	0xB206: 0xFFFD,
	0xB207: 0xFFFD,
	0xB208: 0xFFFD,
	0xB209: 0xFFFD,
	0xB20A: 0xFFFD,
	0xB20B: 0xFFFD,
	0xB20C: 0xFFFD,
	0xB20D: 0xFFFD,
	0xB20E: 0xFFFD,
	0xB20F: 0xFFFD,
	0xB210: 0xFFFD,
	0xB211: 0xFFFD,
	0xB212: 0xFFFD,
	0xB213: 0xFFFD,
	0xB214: 0xFFFD,
	0xB215: 0xFFFD,
	0xB216: 0xFFFD,
	0xB217: 0xFFFD,
	0xB218: 0xFFFD,
	0xB219: 0xFFFD,
	0xB21A: 0xFFFD,
	0xB21B: 0xFFFD,
	0xB21C: 0xFFFD,
	0xB21D: 0xFFFD,
	0xB21E: 0xFFFD,
	0xB21F: 0xFFFD,
	0xB220: 0xFFFD,
	0xB221: 0xFFFD,
	0xB222: 0xFFFD,
	0xB223: 0xFFFD,
	0xB224: 0xFFFD,
	0xB225: 0xFFFD,
	0xB226: 0xFFFD,
	0xB227: 0xFFFD,
	0xB228: 0xFFFD,
	0xB229: 0xFFFD,
	0xB22A: 0xFFFD,
	0xB22B: 0xFFFD,
	0xB22C: 0xFFFD,
	0xB22D: 0xFFFD,
	0xB22E: 0xFFFD,
	0xB22F: 0xFFFD,
	0xB230: 0xFFFD,
	0xB231: 0xFFFD,
	0xB232: 0xFFFD,
	0xB233: 0xFFFD,
	0xB234: 0xFFFD,
	0xB235: 0xFFFD,
	0xB236: 0xFFFD,
	0xB237: 0xFFFD,
	0xB238: 0xFFFD,
	0xB239: 0xFFFD,
	0xB23A: 0xFFFD,
	0xB23B: 0xFFFD,
	0xB23C: 0xFFFD,
	0xB23D: 0xFFFD,
	0xB23E: 0xFFFD,
	0xB23F: 0xFFFD,
	0xB240: 0xFFFD,
	0xB241: 0xFFFD,
	0xB242: 0xFFFD,
	0xB243: 0xFFFD,
	0xB244: 0xFFFD,
	0xB245: 0xFFFD,
	0xB246: 0xFFFD,
	0xB247: 0xFFFD,
	0xB248: 0xFFFD,
	0xB249: 0xFFFD,
	0xB24A: 0xFFFD,
	0xB24B: 0xFFFD,
	0xB24C: 0xFFFD,
	0xB24D: 0xFFFD,
	0xB24E: 0xFFFD,
	0xB24F: 0xFFFD,
	0xB250: 0xFFFD,
	0xB251: 0xFFFD,
	0xB252: 0xFFFD,
	0xB253: 0xFFFD,
	0xB254: 0xFFFD,
	0xB255: 0xFFFD,
	0xB256: 0xFFFD,
	0xB257: 0xFFFD,
	0xB258: 0xFFFD,
	0xB259: 0xFFFD,
	0xB25A: 0xFFFD,
	0xB25B: 0xFFFD,
	0xB25C: 0xFFFD,
	0xB25D: 0xFFFD,
	0xB25E: 0xFFFD,
	0xB25F: 0xFFFD,
	0xB260: 0xFFFD,
	0xB261: 0xFFFD,
	0xB262: 0xFFFD,
	0xB263: 0xFFFD,
	0xB264: 0xFFFD,
	0xB265: 0xFFFD,
	0xB266: 0xFFFD,
	0xB267: 0xFFFD,
	0xB268: 0xFFFD,
	0xB269: 0xFFFD,
	0xB26A: 0xFFFD,
	0xB26B: 0xFFFD,
	0xB26C: 0xFFFD,
	0xB26D: 0xFFFD,
	0xB26E: 0xFFFD,
	0xB26F: 0xFFFD,
	0xB270: 0xFFFD,
	0xB271: 0xFFFD,
	0xB272: 0xFFFD,
	0xB273: 0xFFFD,
	0xB274: 0xFFFD,
	0xB275: 0xFFFD,
	0xB276: 0xFFFD,
	0xB277: 0xFFFD,
	0xB278: 0xFFFD,
	0xB279: 0xFFFD,
	0xB27A: 0xFFFD,
	0xB27B: 0xFFFD,
	0xB27C: 0xFFFD,
	0xB27D: 0xFFFD,
	0xB27E: 0xFFFD,
	0xB27F: 0xFFFD,
	0xB280: 0xFFFD,
	0xB281: 0xFFFD,
	0xB282: 0xFFFD,
	0xB283: 0xFFFD,
	0xB284: 0xFFFD,
	0xB285: 0xFFFD,
	0xB286: 0xFFFD,
	0xB287: 0xFFFD,
	0xB288: 0xFFFD,
	0xB289: 0xFFFD,
	0xB28A: 0xFFFD,
	0xB28B: 0xFFFD,
	0xB28C: 0xFFFD,
	0xB28D: 0xFFFD,
	0xB28E: 0xFFFD,
	0xB28F: 0xFFFD,
	0xB290: 0xFFFD,
	0xB291: 0xFFFD,
	0xB292: 0xFFFD,
	0xB293: 0xFFFD,
	0xB294: 0xFFFD,
	0xB295: 0xFFFD,
	0xB296: 0xFFFD,
	0xB297: 0xFFFD,
	0xB298: 0xFFFD,
	0xB299: 0xFFFD,
	0xB29A: 0xFFFD,
	0xB29B: 0xFFFD,
	0xB29C: 0xFFFD,
	0xB29D: 0xFFFD,
	0xB29E: 0xFFFD,
	0xB29F: 0xFFFD,
	0xB2A0: 0xFFFD,
	0xB2A1: 0xFFFD,
	0xB2A2: 0xFFFD,
	0xB2A3: 0xFFFD,
	0xB2A4: 0xFFFD,
	0xB2A5: 0xFFFD,
	0xB2A6: 0xFFFD,
	0xB2A7: 0xFFFD,
	0xB2A8: 0xFFFD,
	0xB2A9: 0xFFFD,
	0xB2AA: 0xFFFD,
	0xB2AB: 0xFFFD,
	0xB2AC: 0xFFFD,
	0xB2AD: 0xFFFD,
	0xB2AE: 0xFFFD,
	0xB2AF: 0xFFFD,
	0xB2B0: 0xFFFD,
	0xB2B1: 0xFFFD,
	0xB2B2: 0xFFFD,
	0xB2B3: 0xFFFD,
	0xB2B4: 0xFFFD,
	0xB2B5: 0xFFFD,
	0xB2B6: 0xFFFD,
	0xB2B7: 0xFFFD,
	0xB2B8: 0xFFFD,
	0xB2B9: 0xFFFD,
	0xB2BA: 0xFFFD,
	0xB2BB: 0xFFFD,
	0xB2BC: 0xFFFD,
	0xB2BD: 0xFFFD,
	0xB2BE: 0xFFFD,
	0xB2BF: 0xFFFD,
	0xB2C0: 0xFFFD,
	0xB2C1: 0xFFFD,
	0xB2C2: 0xFFFD,
	0xB2C3: 0xFFFD,
	0xB2C4: 0xFFFD,
	0xB2C5: 0xFFFD,
	0xB2C6: 0xFFFD,
	0xB2C7: 0xFFFD,
	0xB2C8: 0xFFFD,
	0xB2C9: 0xFFFD,
	0xB2CA: 0xFFFD,
	0xB2CB: 0xFFFD,
	0xB2CC: 0xFFFD,
	0xB2CD: 0xFFFD,
	0xB2CE: 0xFFFD,
	0xB2CF: 0xFFFD,
	0xB2D0: 0xFFFD,
	0xB2D1: 0xFFFD,
	0xB2D2: 0xFFFD,
	0xB2D3: 0xFFFD,
	0xB2D4: 0xFFFD,
	0xB2D5: 0xFFFD,
	0xB2D6: 0xFFFD,
	0xB2D7: 0xFFFD,
	0xB2D8: 0xFFFD,
	0xB2D9: 0xFFFD,
	0xB2DA: 0xFFFD,
	0xB2DB: 0xFFFD,
	0xB2DC: 0xFFFD,
	0xB2DD: 0xFFFD,
	0xB2DE: 0xFFFD,
	0xB2DF: 0xFFFD,
	0xB2E0: 0xFFFD,
	0xB2E1: 0xFFFD,
	0xB2E2: 0xFFFD,
	0xB2E3: 0xFFFD,
	0xB2E4: 0xFFFD,
	0xB2E5: 0xFFFD,
	0xB2E6: 0xFFFD,
	0xB2E7: 0xFFFD,
	0xB2E8: 0xFFFD,
	0xB2E9: 0xFFFD,
	0xB2EA: 0xFFFD,
	0xB2EB: 0xFFFD,
	0xB2EC: 0xFFFD,
	0xB2ED: 0xFFFD,
	0xB2EE: 0xFFFD,
	0xB2EF: 0xFFFD,
	0xB2F0: 0xFFFD,
	0xB2F1: 0xFFFD,
	0xB2F2: 0xFFFD,
	0xB2F3: 0xFFFD,
	0xB2F4: 0xFFFD,
	0xB2F5: 0xFFFD,
	0xB2F6: 0xFFFD,
	0xB2F7: 0xFFFD,
	0xB2F8: 0xFFFD,
	0xB2F9: 0xFFFD,
	0xB2FA: 0xFFFD,
	0xB2FB: 0xFFFD,
	0xB2FC: 0xFFFD,
	0xB2FD: 0xFFFD,
	0xB2FE: 0xFFFD,
	0xB2FF: 0xFFFD,
	0xB300: 0xFFFD,
	0xB301: 0xFFFD,
	0xB302: 0xFFFD,
	0xB303: 0xFFFD,
	0xB304: 0xFFFD,
	0xB305: 0xFFFD,
	0xB306: 0xFFFD,
	0xB307: 0xFFFD,
	0xB308: 0xFFFD,
	0xB309: 0xFFFD,
	0xB30A: 0xFFFD,
	0xB30B: 0xFFFD,
	0xB30C: 0xFFFD,
	0xB30D: 0xFFFD,
	0xB30E: 0xFFFD,
	0xB30F: 0xFFFD,
	0xB310: 0xFFFD,
	0xB311: 0xFFFD,
	0xB312: 0xFFFD,
	0xB313: 0xFFFD,
	0xB314: 0xFFFD,
	0xB315: 0xFFFD,
	0xB316: 0xFFFD,
	0xB317: 0xFFFD,
	0xB318: 0xFFFD,
	0xB319: 0xFFFD,
	0xB31A: 0xFFFD,
	0xB31B: 0xFFFD,
	0xB31C: 0xFFFD,
	0xB31D: 0xFFFD,
	0xB31E: 0xFFFD,
	0xB31F: 0xFFFD,
	0xB320: 0xFFFD,
	0xB321: 0xFFFD,
	0xB322: 0xFFFD,
	0xB323: 0xFFFD,
	0xB324: 0xFFFD,
	0xB325: 0xFFFD,
	0xB326: 0xFFFD,
	0xB327: 0xFFFD,
	0xB328: 0xFFFD,
	0xB329: 0xFFFD,
	0xB32A: 0xFFFD,
	0xB32B: 0xFFFD,
	0xB32C: 0xFFFD,
	0xB32D: 0xFFFD,
	0xB32E: 0xFFFD,
	0xB32F: 0xFFFD,
	0xB330: 0xFFFD,
	0xB331: 0xFFFD,
	0xB332: 0xFFFD,
	0xB333: 0xFFFD,
	0xB334: 0xFFFD,
	0xB335: 0xFFFD,
	0xB336: 0xFFFD,
	0xB337: 0xFFFD,
	0xB338: 0xFFFD,
	0xB339: 0xFFFD,
	0xB33A: 0xFFFD,
	0xB33B: 0xFFFD,
	0xB33C: 0xFFFD,
	0xB33D: 0xFFFD,
	0xB33E: 0xFFFD,
	0xB33F: 0xFFFD,
	0xB340: 0xFFFD,
	0xB341: 0xFFFD,
	0xB342: 0xFFFD,
	0xB343: 0xFFFD,
	0xB344: 0xFFFD,
	0xB345: 0xFFFD,
	0xB346: 0xFFFD,
	0xB347: 0xFFFD,
	0xB348: 0xFFFD,
	0xB349: 0xFFFD,
	0xB34A: 0xFFFD,
	0xB34B: 0xFFFD,
	0xB34C: 0xFFFD,
	0xB34D: 0xFFFD,
	0xB34E: 0xFFFD,
	0xB34F: 0xFFFD,
	0xB350: 0xFFFD,
	0xB351: 0xFFFD,
	0xB352: 0xFFFD,
	0xB353: 0xFFFD,
	0xB354: 0xFFFD,
	0xB355: 0xFFFD,
	0xB356: 0xFFFD,
	0xB357: 0xFFFD,
	0xB358: 0xFFFD,
	0xB359: 0xFFFD,
	0xB35A: 0xFFFD,
	0xB35B: 0xFFFD,
	0xB35C: 0xFFFD,
	0xB35D: 0xFFFD,
	0xB35E: 0xFFFD,
	0xB35F: 0xFFFD,
	0xB360: 0xFFFD,
	0xB361: 0xFFFD,
	0xB362: 0xFFFD,
	0xB363: 0xFFFD,
	0xB364: 0xFFFD,
	0xB365: 0xFFFD,
	0xB366: 0xFFFD,
	0xB367: 0xFFFD,
	0xB368: 0xFFFD,
	0xB369: 0xFFFD,
	0xB36A: 0xFFFD,
	0xB36B: 0xFFFD,
	0xB36C: 0xFFFD,
	0xB36D: 0xFFFD,
	0xB36E: 0xFFFD,
	0xB36F: 0xFFFD,
	0xB370: 0xFFFD,
	0xB371: 0xFFFD,
	0xB372: 0xFFFD,
	0xB373: 0xFFFD,
	0xB374: 0xFFFD,
	0xB375: 0xFFFD,
	0xB376: 0xFFFD,
	0xB377: 0xFFFD,
	0xB378: 0xFFFD,
	0xB379: 0xFFFD,
	0xB37A: 0xFFFD,
	0xB37B: 0xFFFD,
	0xB37C: 0xFFFD,
	0xB37D: 0xFFFD,
	0xB37E: 0xFFFD,
	0xB37F: 0xFFFD,
	0xB380: 0xFFFD,
	0xB381: 0xFFFD,
	0xB382: 0xFFFD,
	0xB383: 0xFFFD,
	0xB384: 0xFFFD,
	0xB385: 0xFFFD,
	0xB386: 0xFFFD,
	0xB387: 0xFFFD,
	0xB388: 0xFFFD,
	0xB389: 0xFFFD,
	0xB38A: 0xFFFD,
	0xB38B: 0xFFFD,
	0xB38C: 0xFFFD,
	0xB38D: 0xFFFD,
	0xB38E: 0xFFFD,
	0xB38F: 0xFFFD,
	0xB390: 0xFFFD,
	0xB391: 0xFFFD,
	0xB392: 0xFFFD,
	0xB393: 0xFFFD,
	0xB394: 0xFFFD,
	0xB395: 0xFFFD,
	0xB396: 0xFFFD,
	0xB397: 0xFFFD,
	0xB398: 0xFFFD,
	0xB399: 0xFFFD,
	0xB39A: 0xFFFD,
	0xB39B: 0xFFFD,
	0xB39C: 0xFFFD,
	0xB39D: 0xFFFD,
	0xB39E: 0xFFFD,
	0xB39F: 0xFFFD,
	0xB3A0: 0xFFFD,
	0xB3A1: 0xFFFD,
	0xB3A2: 0xFFFD,
	0xB3A3: 0xFFFD,
	0xB3A4: 0xFFFD,
	0xB3A5: 0xFFFD,
	0xB3A6: 0xFFFD,
	0xB3A7: 0xFFFD,
	0xB3A8: 0xFFFD,
	0xB3A9: 0xFFFD,
	0xB3AA: 0xFFFD,
	0xB3AB: 0xFFFD,
	0xB3AC: 0xFFFD,
	0xB3AD: 0xFFFD,
	0xB3AE: 0xFFFD,
	0xB3AF: 0xFFFD,
	0xB3B0: 0xFFFD,
	0xB3B1: 0xFFFD,
	0xB3B2: 0xFFFD,
	0xB3B3: 0xFFFD,
	0xB3B4: 0xFFFD,
	0xB3B5: 0xFFFD,
	0xB3B6: 0xFFFD,
	0xB3B7: 0xFFFD,
	0xB3B8: 0xFFFD,
	0xB3B9: 0xFFFD,
	0xB3BA: 0xFFFD,
	0xB3BB: 0xFFFD,
	0xB3BC: 0xFFFD,
	0xB3BD: 0xFFFD,
	0xB3BE: 0xFFFD,
	0xB3BF: 0xFFFD,
	0xB3C0: 0xFFFD,
	0xB3C1: 0xFFFD,
	0xB3C2: 0xFFFD,
	0xB3C3: 0xFFFD,
	0xB3C4: 0xFFFD,
	0xB3C5: 0xFFFD,
	0xB3C6: 0xFFFD,
	0xB3C7: 0xFFFD,
	0xB3C8: 0xFFFD,
	0xB3C9: 0xFFFD,
	0xB3CA: 0xFFFD,
	0xB3CB: 0xFFFD,
	0xB3CC: 0xFFFD,
	0xB3CD: 0xFFFD,
	0xB3CE: 0xFFFD,
	0xB3CF: 0xFFFD,
	0xB3D0: 0xFFFD,
	0xB3D1: 0xFFFD,
	0xB3D2: 0xFFFD,
	0xB3D3: 0xFFFD,
	0xB3D4: 0xFFFD,
	0xB3D5: 0xFFFD,
	0xB3D6: 0xFFFD,
	0xB3D7: 0xFFFD,
	0xB3D8: 0xFFFD,
	0xB3D9: 0xFFFD,
	0xB3DA: 0xFFFD,
	0xB3DB: 0xFFFD,
	0xB3DC: 0xFFFD,
	0xB3DD: 0xFFFD,
	0xB3DE: 0xFFFD,
	0xB3DF: 0xFFFD,
	0xB3E0: 0xFFFD,
	0xB3E1: 0xFFFD,
	0xB3E2: 0xFFFD,
	0xB3E3: 0xFFFD,
	0xB3E4: 0xFFFD,
	0xB3E5: 0xFFFD,
	0xB3E6: 0xFFFD,
	0xB3E7: 0xFFFD,
	0xB3E8: 0xFFFD,
	0xB3E9: 0xFFFD,
	0xB3EA: 0xFFFD,
	0xB3EB: 0xFFFD,
	0xB3EC: 0xFFFD,
	0xB3ED: 0xFFFD,
	0xB3EE: 0xFFFD,
	0xB3EF: 0xFFFD,
	0xB3F0: 0xFFFD,
	0xB3F1: 0xFFFD,
	0xB3F2: 0xFFFD,
	0xB3F3: 0xFFFD,
	0xB3F4: 0xFFFD,
	0xB3F5: 0xFFFD,
	0xB3F6: 0xFFFD,
	0xB3F7: 0xFFFD,
	0xB3F8: 0xFFFD,
	0xB3F9: 0xFFFD,
	0xB3FA: 0xFFFD,
	0xB3FB: 0xFFFD,
	0xB3FC: 0xFFFD,
	0xB3FD: 0xFFFD,
	0xB3FE: 0xFFFD,
	0xB3FF: 0xFFFD,
	0xB400: 0xFFFD,
	0xB401: 0xFFFD,
	0xB402: 0xFFFD,
	0xB403: 0xFFFD,
	0xB404: 0xFFFD,
	0xB405: 0xFFFD,
	0xB406: 0xFFFD,
	0xB407: 0xFFFD,
	0xB408: 0xFFFD,
	0xB409: 0xFFFD,
	0xB40A: 0xFFFD,
	0xB40B: 0xFFFD,
	0xB40C: 0xFFFD,
	0xB40D: 0xFFFD,
	0xB40E: 0xFFFD,
	0xB40F: 0xFFFD,
	0xB410: 0xFFFD,
	0xB411: 0xFFFD,
	0xB412: 0xFFFD,
	0xB413: 0xFFFD,
	0xB414: 0xFFFD,
	0xB415: 0xFFFD,
	0xB416: 0xFFFD,
	0xB417: 0xFFFD,
	0xB418: 0xFFFD,
	0xB419: 0xFFFD,
	0xB41A: 0xFFFD,
	0xB41B: 0xFFFD,
	0xB41C: 0xFFFD,
	0xB41D: 0xFFFD,
	0xB41E: 0xFFFD,
	0xB41F: 0xFFFD,
	0xB420: 0xFFFD,
	0xB421: 0xFFFD,
	0xB422: 0xFFFD,
	0xB423: 0xFFFD,
	0xB424: 0xFFFD,
	0xB425: 0xFFFD,
	0xB426: 0xFFFD,
	0xB427: 0xFFFD,
	0xB428: 0xFFFD,
	0xB429: 0xFFFD,
	0xB42A: 0xFFFD,
	0xB42B: 0xFFFD,
	0xB42C: 0xFFFD,
	0xB42D: 0xFFFD,
	0xB42E: 0xFFFD,
	0xB42F: 0xFFFD,
	0xB430: 0xFFFD,
	0xB431: 0xFFFD,
	0xB432: 0xFFFD,
	0xB433: 0xFFFD,
	0xB434: 0xFFFD,
	0xB435: 0xFFFD,
	0xB436: 0xFFFD,
	0xB437: 0xFFFD,
	0xB438: 0xFFFD,
	0xB439: 0xFFFD,
	0xB43A: 0xFFFD,
	0xB43B: 0xFFFD,
	0xB43C: 0xFFFD,
	0xB43D: 0xFFFD,
	0xB43E: 0xFFFD,
	0xB43F: 0xFFFD,
	0xB440: 0xFFFD,
	0xB441: 0xFFFD,
	0xB442: 0xFFFD,
	0xB443: 0xFFFD,
	0xB444: 0xFFFD,
	0xB445: 0xFFFD,
	0xB446: 0xFFFD,
	0xB447: 0xFFFD,
	0xB448: 0xFFFD,
	0xB449: 0xFFFD,
	0xB44A: 0xFFFD,
	0xB44B: 0xFFFD,
	0xB44C: 0xFFFD,
	0xB44D: 0xFFFD,
	0xB44E: 0xFFFD,
	0xB44F: 0xFFFD,
	0xB450: 0xFFFD,
	0xB451: 0xFFFD,
	0xB452: 0xFFFD,
	0xB453: 0xFFFD,
	0xB454: 0xFFFD,
	0xB455: 0xFFFD,
	0xB456: 0xFFFD,
	0xB457: 0xFFFD,
	0xB458: 0xFFFD,
	0xB459: 0xFFFD,
	0xB45A: 0xFFFD,
	0xB45B: 0xFFFD,
	0xB45C: 0xFFFD,
	0xB45D: 0xFFFD,
	0xB45E: 0xFFFD,
	0xB45F: 0xFFFD,
	0xB460: 0xFFFD,
	0xB461: 0xFFFD,
	0xB462: 0xFFFD,
	0xB463: 0xFFFD,
	0xB464: 0xFFFD,
	0xB465: 0xFFFD,
	0xB466: 0xFFFD,
	0xB467: 0xFFFD,
	0xB468: 0xFFFD,
	0xB469: 0xFFFD,
	0xB46A: 0xFFFD,
	0xB46B: 0xFFFD,
	0xB46C: 0xFFFD,
	0xB46D: 0xFFFD,
	0xB46E: 0xFFFD,
	0xB46F: 0xFFFD,
	0xB470: 0xFFFD,
	0xB471: 0xFFFD,
	0xB472: 0xFFFD,
	0xB473: 0xFFFD,
	0xB474: 0xFFFD,
	0xB475: 0xFFFD,
	0xB476: 0xFFFD,
	0xB477: 0xFFFD,
	0xB478: 0xFFFD,
	0xB479: 0xFFFD,
	0xB47A: 0xFFFD,
	0xB47B: 0xFFFD,
	0xB47C: 0xFFFD,
	0xB47D: 0xFFFD,
	0xB47E: 0xFFFD,
	0xB47F: 0xFFFD,
	0xB480: 0xFFFD,
	0xB481: 0xFFFD,
	0xB482: 0xFFFD,
	0xB483: 0xFFFD,
	0xB484: 0xFFFD,
	0xB485: 0xFFFD,
	0xB486: 0xFFFD,
	0xB487: 0xFFFD,
	0xB488: 0xFFFD,
	0xB489: 0xFFFD,
	0xB48A: 0xFFFD,
	0xB48B: 0xFFFD,
	0xB48C: 0xFFFD,
	0xB48D: 0xFFFD,
	0xB48E: 0xFFFD,
	0xB48F: 0xFFFD,
	0xB490: 0xFFFD,
	0xB491: 0xFFFD,
	0xB492: 0xFFFD,
	0xB493: 0xFFFD,
	0xB494: 0xFFFD,
	0xB495: 0xFFFD,
	0xB496: 0xFFFD,
	0xB497: 0xFFFD,
	0xB498: 0xFFFD,
	0xB499: 0xFFFD,
	0xB49A: 0xFFFD,
	0xB49B: 0xFFFD,
	0xB49C: 0xFFFD,
	0xB49D: 0xFFFD,
	0xB49E: 0xFFFD,
	0xB49F: 0xFFFD,
	0xB4A0: 0xFFFD,
	0xB4A1: 0xFFFD,
	0xB4A2: 0xFFFD,
	0xB4A3: 0xFFFD,
	0xB4A4: 0xFFFD,
	0xB4A5: 0xFFFD,
	0xB4A6: 0xFFFD,
	0xB4A7: 0xFFFD,
	0xB4A8: 0xFFFD,
	0xB4A9: 0xFFFD,
	0xB4AA: 0xFFFD,
	0xB4AB: 0xFFFD,
	0xB4AC: 0xFFFD,
	0xB4AD: 0xFFFD,
	0xB4AE: 0xFFFD,
	0xB4AF: 0xFFFD,
	0xB4B0: 0xFFFD,
	0xB4B1: 0xFFFD,
	0xB4B2: 0xFFFD,
	0xB4B3: 0xFFFD,
	0xB4B4: 0xFFFD,
	0xB4B5: 0xFFFD,
	0xB4B6: 0xFFFD,
	0xB4B7: 0xFFFD,
	0xB4B8: 0xFFFD,
	0xB4B9: 0xFFFD,
	0xB4BA: 0xFFFD,
	0xB4BB: 0xFFFD,
	0xB4BC: 0xFFFD,
	0xB4BD: 0xFFFD,
	0xB4BE: 0xFFFD,
	0xB4BF: 0xFFFD,
	0xB4C0: 0xFFFD,
	0xB4C1: 0xFFFD,
	0xB4C2: 0xFFFD,
	0xB4C3: 0xFFFD,
	0xB4C4: 0xFFFD,
	0xB4C5: 0xFFFD,
	0xB4C6: 0xFFFD,
	0xB4C7: 0xFFFD,
	0xB4C8: 0xFFFD,
	0xB4C9: 0xFFFD,
	0xB4CA: 0xFFFD,
	0xB4CB: 0xFFFD,
	0xB4CC: 0xFFFD,
	0xB4CD: 0xFFFD,
	0xB4CE: 0xFFFD,
	0xB4CF: 0xFFFD,
	0xB4D0: 0xFFFD,
	0xB4D1: 0xFFFD,
	0xB4D2: 0xFFFD,
	0xB4D3: 0xFFFD,
	0xB4D4: 0xFFFD,
	0xB4D5: 0xFFFD,
	0xB4D6: 0xFFFD,
	0xB4D7: 0xFFFD,
	0xB4D8: 0xFFFD,
	0xB4D9: 0xFFFD,
	0xB4DA: 0xFFFD,
	0xB4DB: 0xFFFD,
	0xB4DC: 0xFFFD,
	0xB4DD: 0xFFFD,
	0xB4DE: 0xFFFD,
	0xB4DF: 0xFFFD,
	0xB4E0: 0xFFFD,
	0xB4E1: 0xFFFD,
	0xB4E2: 0xFFFD,
	0xB4E3: 0xFFFD,
	0xB4E4: 0xFFFD,
	0xB4E5: 0xFFFD,
	0xB4E6: 0xFFFD,
	0xB4E7: 0xFFFD,
	0xB4E8: 0xFFFD,
	0xB4E9: 0xFFFD,
	0xB4EA: 0xFFFD,
	0xB4EB: 0xFFFD,
	0xB4EC: 0xFFFD,
	0xB4ED: 0xFFFD,
	0xB4EE: 0xFFFD,
	0xB4EF: 0xFFFD,
	0xB4F0: 0xFFFD,
	0xB4F1: 0xFFFD,
	0xB4F2: 0xFFFD,
	0xB4F3: 0xFFFD,
	0xB4F4: 0xFFFD,
	0xB4F5: 0xFFFD,
	0xB4F6: 0xFFFD,
	0xB4F7: 0xFFFD,
	0xB4F8: 0xFFFD,
	0xB4F9: 0xFFFD,
	0xB4FA: 0xFFFD,
	0xB4FB: 0xFFFD,
	0xB4FC: 0xFFFD,
	0xB4FD: 0xFFFD,
	0xB4FE: 0xFFFD,
	0xB4FF: 0xFFFD,
	0xB500: 0xFFFD,
	0xB501: 0xFFFD,
	0xB502: 0xFFFD,
	0xB503: 0xFFFD,
	0xB504: 0xFFFD,
	0xB505: 0xFFFD,
	0xB506: 0xFFFD,
	0xB507: 0xFFFD,
	0xB508: 0xFFFD,
	0xB509: 0xFFFD,
	0xB50A: 0xFFFD,
	0xB50B: 0xFFFD,
	0xB50C: 0xFFFD,
	0xB50D: 0xFFFD,
	0xB50E: 0xFFFD,
	0xB50F: 0xFFFD,
	0xB510: 0xFFFD,
	0xB511: 0xFFFD,
	0xB512: 0xFFFD,
	0xB513: 0xFFFD,
	0xB514: 0xFFFD,
	0xB515: 0xFFFD,
	0xB516: 0xFFFD,
	0xB517: 0xFFFD,
	0xB518: 0xFFFD,
	0xB519: 0xFFFD,
	0xB51A: 0xFFFD,
	0xB51B: 0xFFFD,
	0xB51C: 0xFFFD,
	0xB51D: 0xFFFD,
	0xB51E: 0xFFFD,
	0xB51F: 0xFFFD,
	0xB520: 0xFFFD,
	0xB521: 0xFFFD,
	0xB522: 0xFFFD,
	0xB523: 0xFFFD,
	0xB524: 0xFFFD,
	0xB525: 0xFFFD,
	0xB526: 0xFFFD,
	0xB527: 0xFFFD,
	0xB528: 0xFFFD,
	0xB529: 0xFFFD,
	0xB52A: 0xFFFD,
	0xB52B: 0xFFFD,
	0xB52C: 0xFFFD,
	0xB52D: 0xFFFD,
	0xB52E: 0xFFFD,
	0xB52F: 0xFFFD,
	0xB530: 0xFFFD,
	0xB531: 0xFFFD,
	0xB532: 0xFFFD,
	0xB533: 0xFFFD,
	0xB534: 0xFFFD,
	0xB535: 0xFFFD,
	0xB536: 0xFFFD,
	0xB537: 0xFFFD,
	0xB538: 0xFFFD,
	0xB539: 0xFFFD,
	0xB53A: 0xFFFD,
	0xB53B: 0xFFFD,
	0xB53C: 0xFFFD,
	0xB53D: 0xFFFD,
	0xB53E: 0xFFFD,
	0xB53F: 0xFFFD,
	0xB540: 0xFFFD,
	0xB541: 0xFFFD,
	0xB542: 0xFFFD,
	0xB543: 0xFFFD,
	0xB544: 0xFFFD,
	0xB545: 0xFFFD,
	0xB546: 0xFFFD,
	0xB547: 0xFFFD,
	0xB548: 0xFFFD,
	0xB549: 0xFFFD,
	0xB54A: 0xFFFD,
	0xB54B: 0xFFFD,
	0xB54C: 0xFFFD,
	0xB54D: 0xFFFD,
	0xB54E: 0xFFFD,
	0xB54F: 0xFFFD,
	0xB550: 0xFFFD,
	0xB551: 0xFFFD,
	0xB552: 0xFFFD,
	0xB553: 0xFFFD,
	0xB554: 0xFFFD,
	0xB555: 0xFFFD,
	0xB556: 0xFFFD,
	0xB557: 0xFFFD,
	0xB558: 0xFFFD,
	0xB559: 0xFFFD,
	0xB55A: 0xFFFD,
	0xB55B: 0xFFFD,
	0xB55C: 0xFFFD,
	0xB55D: 0xFFFD,
	0xB55E: 0xFFFD,
	0xB55F: 0xFFFD,
	0xB560: 0xFFFD,
	0xB561: 0xFFFD,
	0xB562: 0xFFFD,
	0xB563: 0xFFFD,
	0xB564: 0xFFFD,
	0xB565: 0xFFFD,
	0xB566: 0xFFFD,
	0xB567: 0xFFFD,
	0xB568: 0xFFFD,
	0xB569: 0xFFFD,
	0xB56A: 0xFFFD,
	0xB56B: 0xFFFD,
	0xB56C: 0xFFFD,
	0xB56D: 0xFFFD,
	0xB56E: 0xFFFD,
	0xB56F: 0xFFFD,
	0xB570: 0xFFFD,
	0xB571: 0xFFFD,
	0xB572: 0xFFFD,
	0xB573: 0xFFFD,
	0xB574: 0xFFFD,
	0xB575: 0xFFFD,
	0xB576: 0xFFFD,
	0xB577: 0xFFFD,
	0xB578: 0xFFFD,
	0xB579: 0xFFFD,
	0xB57A: 0xFFFD,
	0xB57B: 0xFFFD,
	0xB57C: 0xFFFD,
	0xB57D: 0xFFFD,
	0xB57E: 0xFFFD,
	0xB57F: 0xFFFD,
	0xB580: 0xFFFD,
	0xB581: 0xFFFD,
	0xB582: 0xFFFD,
	0xB583: 0xFFFD,
	0xB584: 0xFFFD,
	0xB585: 0xFFFD,
	0xB586: 0xFFFD,
	0xB587: 0xFFFD,
	0xB588: 0xFFFD,
	0xB589: 0xFFFD,
	0xB58A: 0xFFFD,
	0xB58B: 0xFFFD,
	0xB58C: 0xFFFD,
	0xB58D: 0xFFFD,
	0xB58E: 0xFFFD,
	0xB58F: 0xFFFD,
	0xB590: 0xFFFD,
	0xB591: 0xFFFD,
	0xB592: 0xFFFD,
	0xB593: 0xFFFD,
	0xB594: 0xFFFD,
	0xB595: 0xFFFD,
	0xB596: 0xFFFD,
	0xB597: 0xFFFD,
	0xB598: 0xFFFD,
	0xB599: 0xFFFD,
	0xB59A: 0xFFFD,
	0xB59B: 0xFFFD,
	0xB59C: 0xFFFD,
	0xB59D: 0xFFFD,
	0xB59E: 0xFFFD,
	0xB59F: 0xFFFD,
	0xB5A0: 0xFFFD,
	0xB5A1: 0xFFFD,
	0xB5A2: 0xFFFD,
	0xB5A3: 0xFFFD,
	0xB5A4: 0xFFFD,
	0xB5A5: 0xFFFD,
	0xB5A6: 0xFFFD,
	0xB5A7: 0xFFFD,
	0xB5A8: 0xFFFD,
	0xB5A9: 0xFFFD,
	0xB5AA: 0xFFFD,
	0xB5AB: 0xFFFD,
	0xB5AC: 0xFFFD,
	0xB5AD: 0xFFFD,
	0xB5AE: 0xFFFD,
	0xB5AF: 0xFFFD,
	0xB5B0: 0xFFFD,
	0xB5B1: 0xFFFD,
	0xB5B2: 0xFFFD,
	0xB5B3: 0xFFFD,
	0xB5B4: 0xFFFD,
	0xB5B5: 0xFFFD,
	0xB5B6: 0xFFFD,
	0xB5B7: 0xFFFD,
	0xB5B8: 0xFFFD,
	0xB5B9: 0xFFFD,
	0xB5BA: 0xFFFD,
	0xB5BB: 0xFFFD,
	0xB5BC: 0xFFFD,
	0xB5BD: 0xFFFD,
	0xB5BE: 0xFFFD,
	0xB5BF: 0xFFFD,
	0xB5C0: 0xFFFD,
	0xB5C1: 0xFFFD,
	0xB5C2: 0xFFFD,
	0xB5C3: 0xFFFD,
	0xB5C4: 0xFFFD,
	0xB5C5: 0xFFFD,
	0xB5C6: 0xFFFD,
	0xB5C7: 0xFFFD,
	0xB5C8: 0xFFFD,
	0xB5C9: 0xFFFD,
	0xB5CA: 0xFFFD,
	0xB5CB: 0xFFFD,
	0xB5CC: 0xFFFD,
	0xB5CD: 0xFFFD,
	0xB5CE: 0xFFFD,
	0xB5CF: 0xFFFD,
	0xB5D0: 0xFFFD,
	0xB5D1: 0xFFFD,
	0xB5D2: 0xFFFD,
	0xB5D3: 0xFFFD,
	0xB5D4: 0xFFFD,
	0xB5D5: 0xFFFD,
	0xB5D6: 0xFFFD,
	0xB5D7: 0xFFFD,
	0xB5D8: 0xFFFD,
	0xB5D9: 0xFFFD,
	0xB5DA: 0xFFFD,
	0xB5DB: 0xFFFD,
	0xB5DC: 0xFFFD,
	0xB5DD: 0xFFFD,
	0xB5DE: 0xFFFD,
	0xB5DF: 0xFFFD,
	0xB5E0: 0xFFFD,
	0xB5E1: 0xFFFD,
	0xB5E2: 0xFFFD,
	0xB5E3: 0xFFFD,
	0xB5E4: 0xFFFD,
	0xB5E5: 0xFFFD,
	0xB5E6: 0xFFFD,
	0xB5E7: 0xFFFD,
	0xB5E8: 0xFFFD,
	0xB5E9: 0xFFFD,
	0xB5EA: 0xFFFD,
	0xB5EB: 0xFFFD,
	0xB5EC: 0xFFFD,
	0xB5ED: 0xFFFD,
	0xB5EE: 0xFFFD,
	0xB5EF: 0xFFFD,
	0xB5F0: 0xFFFD,
	0xB5F1: 0xFFFD,
	0xB5F2: 0xFFFD,
	0xB5F3: 0xFFFD,
	0xB5F4: 0xFFFD,
	0xB5F5: 0xFFFD,
	0xB5F6: 0xFFFD,
	0xB5F7: 0xFFFD,
	0xB5F8: 0xFFFD,
	0xB5F9: 0xFFFD,
	0xB5FA: 0xFFFD,
	0xB5FB: 0xFFFD,
	0xB5FC: 0xFFFD,
	0xB5FD: 0xFFFD,
	0xB5FE: 0xFFFD,
	0xB5FF: 0xFFFD,
	0xB600: 0xFFFD,
	0xB601: 0xFFFD,
	0xB602: 0xFFFD,
	0xB603: 0xFFFD,
	0xB604: 0xFFFD,
	0xB605: 0xFFFD,
	0xB606: 0xFFFD,
	0xB607: 0xFFFD,
	0xB608: 0xFFFD,
	0xB609: 0xFFFD,
	0xB60A: 0xFFFD,
	0xB60B: 0xFFFD,
	0xB60C: 0xFFFD,
	0xB60D: 0xFFFD,
	0xB60E: 0xFFFD,
	0xB60F: 0xFFFD,
	0xB610: 0xFFFD,
	0xB611: 0xFFFD,
	0xB612: 0xFFFD,
	0xB613: 0xFFFD,
	0xB614: 0xFFFD,
	0xB615: 0xFFFD,
	0xB616: 0xFFFD,
	0xB617: 0xFFFD,
	0xB618: 0xFFFD,
	0xB619: 0xFFFD,
	0xB61A: 0xFFFD,
	0xB61B: 0xFFFD,
	0xB61C: 0xFFFD,
	0xB61D: 0xFFFD,
	0xB61E: 0xFFFD,
	0xB61F: 0xFFFD,
	0xB620: 0xFFFD,
	0xB621: 0xFFFD,
	0xB622: 0xFFFD,
	0xB623: 0xFFFD,
	0xB624: 0xFFFD,
	0xB625: 0xFFFD,
	0xB626: 0xFFFD,
	0xB627: 0xFFFD,
	0xB628: 0xFFFD,
	0xB629: 0xFFFD,
	0xB62A: 0xFFFD,
	0xB62B: 0xFFFD,
	0xB62C: 0xFFFD,
	0xB62D: 0xFFFD,
	0xB62E: 0xFFFD,
	0xB62F: 0xFFFD,
	0xB630: 0xFFFD,
	0xB631: 0xFFFD,
	0xB632: 0xFFFD,
	0xB633: 0xFFFD,
	0xB634: 0xFFFD,
	0xB635: 0xFFFD,
	0xB636: 0xFFFD,
	0xB637: 0xFFFD,
	0xB638: 0xFFFD,
	0xB639: 0xFFFD,
	0xB63A: 0xFFFD,
	0xB63B: 0xFFFD,
	0xB63C: 0xFFFD,
	0xB63D: 0xFFFD,
	0xB63E: 0xFFFD,
	0xB63F: 0xFFFD,
	0xB640: 0xFFFD,
	0xB641: 0xFFFD,
	0xB642: 0xFFFD,
	0xB643: 0xFFFD,
	0xB644: 0xFFFD,
	0xB645: 0xFFFD,
	0xB646: 0xFFFD,
	0xB647: 0xFFFD,
	0xB648: 0xFFFD,
	0xB649: 0xFFFD,
	0xB64A: 0xFFFD,
	0xB64B: 0xFFFD,
	0xB64C: 0xFFFD,
	0xB64D: 0xFFFD,
	0xB64E: 0xFFFD,
	0xB64F: 0xFFFD,
	0xB650: 0xFFFD,
	0xB651: 0xFFFD,
	0xB652: 0xFFFD,
	0xB653: 0xFFFD,
	0xB654: 0xFFFD,
	0xB655: 0xFFFD,
	0xB656: 0xFFFD,
	0xB657: 0xFFFD,
	0xB658: 0xFFFD,
	0xB659: 0xFFFD,
	0xB65A: 0xFFFD,
	0xB65B: 0xFFFD,
	0xB65C: 0xFFFD,
	0xB65D: 0xFFFD,
	0xB65E: 0xFFFD,
	0xB65F: 0xFFFD,
	0xB660: 0xFFFD,
	0xB661: 0xFFFD,
	0xB662: 0xFFFD,
	0xB663: 0xFFFD,
	0xB664: 0xFFFD,
	0xB665: 0xFFFD,
	0xB666: 0xFFFD,
	0xB667: 0xFFFD,
	0xB668: 0xFFFD,
	0xB669: 0xFFFD,
	0xB66A: 0xFFFD,
	0xB66B: 0xFFFD,
	0xB66C: 0xFFFD,
	0xB66D: 0xFFFD,
	0xB66E: 0xFFFD,
	0xB66F: 0xFFFD,
	0xB670: 0xFFFD,
	0xB671: 0xFFFD,
	0xB672: 0xFFFD,
	0xB673: 0xFFFD,
	0xB674: 0xFFFD,
	0xB675: 0xFFFD,
	0xB676: 0xFFFD,
	0xB677: 0xFFFD,
	0xB678: 0xFFFD,
	0xB679: 0xFFFD,
	0xB67A: 0xFFFD,
	0xB67B: 0xFFFD,
	0xB67C: 0xFFFD,
	0xB67D: 0xFFFD,
	0xB67E: 0xFFFD,
	0xB67F: 0xFFFD,
	0xB680: 0xFFFD,
	0xB681: 0xFFFD,
	0xB682: 0xFFFD,
	0xB683: 0xFFFD,
	0xB684: 0xFFFD,
	0xB685: 0xFFFD,
	0xB686: 0xFFFD,
	0xB687: 0xFFFD,
	0xB688: 0xFFFD,
	0xB689: 0xFFFD,
	0xB68A: 0xFFFD,
	0xB68B: 0xFFFD,
	0xB68C: 0xFFFD,
	0xB68D: 0xFFFD,
	0xB68E: 0xFFFD,
	0xB68F: 0xFFFD,
	0xB690: 0xFFFD,
	0xB691: 0xFFFD,
	0xB692: 0xFFFD,
	0xB693: 0xFFFD,
	0xB694: 0xFFFD,
	0xB695: 0xFFFD,
	0xB696: 0xFFFD,
	0xB697: 0xFFFD,
	0xB698: 0xFFFD,
	0xB699: 0xFFFD,
	0xB69A: 0xFFFD,
	0xB69B: 0xFFFD,
	0xB69C: 0xFFFD,
	0xB69D: 0xFFFD,
	0xB69E: 0xFFFD,
	0xB69F: 0xFFFD,
	0xB6A0: 0xFFFD,
	0xB6A1: 0xFFFD,
	0xB6A2: 0xFFFD,
	0xB6A3: 0xFFFD,
	0xB6A4: 0xFFFD,
	0xB6A5: 0xFFFD,
	0xB6A6: 0xFFFD,
	0xB6A7: 0xFFFD,
	0xB6A8: 0xFFFD,
	0xB6A9: 0xFFFD,
	0xB6AA: 0xFFFD,
	0xB6AB: 0xFFFD,
	0xB6AC: 0xFFFD,
	0xB6AD: 0xFFFD,
	0xB6AE: 0xFFFD,
	0xB6AF: 0xFFFD,
	0xB6B0: 0xFFFD,
	0xB6B1: 0xFFFD,
	0xB6B2: 0xFFFD,
	0xB6B3: 0xFFFD,
	0xB6B4: 0xFFFD,
	0xB6B5: 0xFFFD,
	0xB6B6: 0xFFFD,
	0xB6B7: 0xFFFD,
	0xB6B8: 0xFFFD,
	0xB6B9: 0xFFFD,
	0xB6BA: 0xFFFD,
	0xB6BB: 0xFFFD,
	0xB6BC: 0xFFFD,
	0xB6BD: 0xFFFD,
	0xB6BE: 0xFFFD,
	0xB6BF: 0xFFFD,
	0xB6C0: 0xFFFD,
	0xB6C1: 0xFFFD,
	0xB6C2: 0xFFFD,
	0xB6C3: 0xFFFD,
	0xB6C4: 0xFFFD,
	0xB6C5: 0xFFFD,
	0xB6C6: 0xFFFD,
	0xB6C7: 0xFFFD,
	0xB6C8: 0xFFFD,
	0xB6C9: 0xFFFD,
	0xB6CA: 0xFFFD,
	0xB6CB: 0xFFFD,
	0xB6CC: 0xFFFD,
	0xB6CD: 0xFFFD,
	0xB6CE: 0xFFFD,
	0xB6CF: 0xFFFD,
	0xB6D0: 0xFFFD,
	0xB6D1: 0xFFFD,
	0xB6D2: 0xFFFD,
	0xB6D3: 0xFFFD,
	0xB6D4: 0xFFFD,
	0xB6D5: 0xFFFD,
	0xB6D6: 0xFFFD,
	0xB6D7: 0xFFFD,
	0xB6D8: 0xFFFD,
	0xB6D9: 0xFFFD,
	0xB6DA: 0xFFFD,
	0xB6DB: 0xFFFD,
	0xB6DC: 0xFFFD,
	0xB6DD: 0xFFFD,
	0xB6DE: 0xFFFD,
	0xB6DF: 0xFFFD,
	0xB6E0: 0xFFFD,
	0xB6E1: 0xFFFD,
	0xB6E2: 0xFFFD,
	0xB6E3: 0xFFFD,
	0xB6E4: 0xFFFD,
	0xB6E5: 0xFFFD,
	0xB6E6: 0xFFFD,
	0xB6E7: 0xFFFD,
	0xB6E8: 0xFFFD,
	0xB6E9: 0xFFFD,
	0xB6EA: 0xFFFD,
	0xB6EB: 0xFFFD,
	0xB6EC: 0xFFFD,
	0xB6ED: 0xFFFD,
	0xB6EE: 0xFFFD,
	0xB6EF: 0xFFFD,
	0xB6F0: 0xFFFD,
	0xB6F1: 0xFFFD,
	0xB6F2: 0xFFFD,
	0xB6F3: 0xFFFD,
	0xB6F4: 0xFFFD,
	0xB6F5: 0xFFFD,
	0xB6F6: 0xFFFD,
	0xB6F7: 0xFFFD,
	0xB6F8: 0xFFFD,
	0xB6F9: 0xFFFD,
	0xB6FA: 0xFFFD,
	0xB6FB: 0xFFFD,
	0xB6FC: 0xFFFD,
	0xB6FD: 0xFFFD,
	0xB6FE: 0xFFFD,
	0xB6FF: 0xFFFD,
	0xB700: 0xFFFD,
	0xB701: 0xFFFD,
	0xB702: 0xFFFD,
	0xB703: 0xFFFD,
	0xB704: 0xFFFD,
	0xB705: 0xFFFD,
	0xB706: 0xFFFD,
	0xB707: 0xFFFD,
	0xB708: 0xFFFD,
	0xB709: 0xFFFD,
	0xB70A: 0xFFFD,
	0xB70B: 0xFFFD,
	0xB70C: 0xFFFD,
	0xB70D: 0xFFFD,
	0xB70E: 0xFFFD,
	0xB70F: 0xFFFD,
	0xB710: 0xFFFD,
	0xB711: 0xFFFD,
	0xB712: 0xFFFD,
	0xB713: 0xFFFD,
	0xB714: 0xFFFD,
	0xB715: 0xFFFD,
	0xB716: 0xFFFD,
	0xB717: 0xFFFD,
	0xB718: 0xFFFD,
	0xB719: 0xFFFD,
	0xB71A: 0xFFFD,
	0xB71B: 0xFFFD,
	0xB71C: 0xFFFD,
	0xB71D: 0xFFFD,
	0xB71E: 0xFFFD,
	0xB71F: 0xFFFD,
	0xB720: 0xFFFD,
	0xB721: 0xFFFD,
	0xB722: 0xFFFD,
	0xB723: 0xFFFD,
	0xB724: 0xFFFD,
	0xB725: 0xFFFD,
	0xB726: 0xFFFD,
	0xB727: 0xFFFD,
	0xB728: 0xFFFD,
	0xB729: 0xFFFD,
	0xB72A: 0xFFFD,
	0xB72B: 0xFFFD,
	0xB72C: 0xFFFD,
	0xB72D: 0xFFFD,
	0xB72E: 0xFFFD,
	0xB72F: 0xFFFD,
	0xB730: 0xFFFD,
	0xB731: 0xFFFD,
	0xB732: 0xFFFD,
	0xB733: 0xFFFD,
	0xB734: 0xFFFD,
	0xB735: 0xFFFD,
	0xB736: 0xFFFD,
	0xB737: 0xFFFD,
	0xB738: 0xFFFD,
	0xB739: 0xFFFD,
	0xB73A: 0xFFFD,
	0xB73B: 0xFFFD,
	0xB73C: 0xFFFD,
	0xB73D: 0xFFFD,
	0xB73E: 0xFFFD,
	0xB73F: 0xFFFD,
	0xB740: 0xFFFD,
	0xB741: 0xFFFD,
	0xB742: 0xFFFD,
	0xB743: 0xFFFD,
	0xB744: 0xFFFD,
	0xB745: 0xFFFD,
	0xB746: 0xFFFD,
	0xB747: 0xFFFD,
	0xB748: 0xFFFD,
	0xB749: 0xFFFD,
	0xB74A: 0xFFFD,
	0xB74B: 0xFFFD,
	0xB74C: 0xFFFD,
	0xB74D: 0xFFFD,
	0xB74E: 0xFFFD,
	0xB74F: 0xFFFD,
	0xB750: 0xFFFD,
	0xB751: 0xFFFD,
	0xB752: 0xFFFD,
	0xB753: 0xFFFD,
	0xB754: 0xFFFD,
	0xB755: 0xFFFD,
	0xB756: 0xFFFD,
	0xB757: 0xFFFD,
	0xB758: 0xFFFD,
	0xB759: 0xFFFD,
	0xB75A: 0xFFFD,
	0xB75B: 0xFFFD,
	0xB75C: 0xFFFD,
	0xB75D: 0xFFFD,
	0xB75E: 0xFFFD,
	0xB75F: 0xFFFD,
	0xB760: 0xFFFD,
	0xB761: 0xFFFD,
	0xB762: 0xFFFD,
	0xB763: 0xFFFD,
	0xB764: 0xFFFD,
	0xB765: 0xFFFD,
	0xB766: 0xFFFD,
	0xB767: 0xFFFD,
	0xB768: 0xFFFD,
	0xB769: 0xFFFD,
	0xB76A: 0xFFFD,
	0xB76B: 0xFFFD,
	0xB76C: 0xFFFD,
	0xB76D: 0xFFFD,
	0xB76E: 0xFFFD,
	0xB76F: 0xFFFD,
	0xB770: 0xFFFD,
	0xB771: 0xFFFD,
	0xB772: 0xFFFD,
	0xB773: 0xFFFD,
	0xB774: 0xFFFD,
	0xB775: 0xFFFD,
	0xB776: 0xFFFD,
	0xB777: 0xFFFD,
	0xB778: 0xFFFD,
	0xB779: 0xFFFD,
	0xB77A: 0xFFFD,
	0xB77B: 0xFFFD,
	0xB77C: 0xFFFD,
	0xB77D: 0xFFFD,
	0xB77E: 0xFFFD,
	0xB77F: 0xFFFD,
	0xB780: 0xFFFD,
	0xB781: 0xFFFD,
	0xB782: 0xFFFD,
	0xB783: 0xFFFD,
	0xB784: 0xFFFD,
	0xB785: 0xFFFD,
	0xB786: 0xFFFD,
	0xB787: 0xFFFD,
	0xB788: 0xFFFD,
	0xB789: 0xFFFD,
	0xB78A: 0xFFFD,
	0xB78B: 0xFFFD,
	0xB78C: 0xFFFD,
	0xB78D: 0xFFFD,
	0xB78E: 0xFFFD,
	0xB78F: 0xFFFD,
	0xB790: 0xFFFD,
	0xB791: 0xFFFD,
	0xB792: 0xFFFD,
	0xB793: 0xFFFD,
	0xB794: 0xFFFD,
	0xB795: 0xFFFD,
	0xB796: 0xFFFD,
	0xB797: 0xFFFD,
	0xB798: 0xFFFD,
	0xB799: 0xFFFD,
	0xB79A: 0xFFFD,
	0xB79B: 0xFFFD,
	0xB79C: 0xFFFD,
	0xB79D: 0xFFFD,
	0xB79E: 0xFFFD,
	0xB79F: 0xFFFD,
	0xB7A0: 0xFFFD,
	0xB7A1: 0xFFFD,
	0xB7A2: 0xFFFD,
	0xB7A3: 0xFFFD,
	0xB7A4: 0xFFFD,
	0xB7A5: 0xFFFD,
	0xB7A6: 0xFFFD,
	0xB7A7: 0xFFFD,
	0xB7A8: 0xFFFD,
	0xB7A9: 0xFFFD,
	0xB7AA: 0xFFFD,
	0xB7AB: 0xFFFD,
	0xB7AC: 0xFFFD,
	0xB7AD: 0xFFFD,
	0xB7AE: 0xFFFD,
	0xB7AF: 0xFFFD,
	0xB7B0: 0xFFFD,
	0xB7B1: 0xFFFD,
	0xB7B2: 0xFFFD,
	0xB7B3: 0xFFFD,
	0xB7B4: 0xFFFD,
	0xB7B5: 0xFFFD,
	0xB7B6: 0xFFFD,
	0xB7B7: 0xFFFD,
	0xB7B8: 0xFFFD,
	0xB7B9: 0xFFFD,
	0xB7BA: 0xFFFD,
	0xB7BB: 0xFFFD,
	0xB7BC: 0xFFFD,
	0xB7BD: 0xFFFD,
	0xB7BE: 0xFFFD,
	0xB7BF: 0xFFFD,
	0xB7C0: 0xFFFD,
	0xB7C1: 0xFFFD,
	0xB7C2: 0xFFFD,
	0xB7C3: 0xFFFD,
	0xB7C4: 0xFFFD,
	0xB7C5: 0xFFFD,
	0xB7C6: 0xFFFD,
	0xB7C7: 0xFFFD,
	0xB7C8: 0xFFFD,
	0xB7C9: 0xFFFD,
	0xB7CA: 0xFFFD,
	0xB7CB: 0xFFFD,
	0xB7CC: 0xFFFD,
	0xB7CD: 0xFFFD,
	0xB7CE: 0xFFFD,
	0xB7CF: 0xFFFD,
	0xB7D0: 0xFFFD,
	0xB7D1: 0xFFFD,
	0xB7D2: 0xFFFD,
	0xB7D3: 0xFFFD,
	0xB7D4: 0xFFFD,
	0xB7D5: 0xFFFD,
	0xB7D6: 0xFFFD,
	0xB7D7: 0xFFFD,
	0xB7D8: 0xFFFD,
	0xB7D9: 0xFFFD,
	0xB7DA: 0xFFFD,
	0xB7DB: 0xFFFD,
	0xB7DC: 0xFFFD,
	0xB7DD: 0xFFFD,
	0xB7DE: 0xFFFD,
	0xB7DF: 0xFFFD,
	0xB7E0: 0xFFFD,
	0xB7E1: 0xFFFD,
	0xB7E2: 0xFFFD,
	0xB7E3: 0xFFFD,
	0xB7E4: 0xFFFD,
	0xB7E5: 0xFFFD,
	0xB7E6: 0xFFFD,
	0xB7E7: 0xFFFD,
	0xB7E8: 0xFFFD,
	0xB7E9: 0xFFFD,
	0xB7EA: 0xFFFD,
	0xB7EB: 0xFFFD,
	0xB7EC: 0xFFFD,
	0xB7ED: 0xFFFD,
	0xB7EE: 0xFFFD,
	0xB7EF: 0xFFFD,
	0xB7F0: 0xFFFD,
	0xB7F1: 0xFFFD,
	0xB7F2: 0xFFFD,
	0xB7F3: 0xFFFD,
	0xB7F4: 0xFFFD,
	0xB7F5: 0xFFFD,
	0xB7F6: 0xFFFD,
	0xB7F7: 0xFFFD,
	0xB7F8: 0xFFFD,
	0xB7F9: 0xFFFD,
	0xB7FA: 0xFFFD,
	0xB7FB: 0xFFFD,
	0xB7FC: 0xFFFD,
	0xB7FD: 0xFFFD,
	0xB7FE: 0xFFFD,
	0xB7FF: 0xFFFD,
	0xB800: 0xFFFD,
	0xB801: 0xFFFD,
	0xB802: 0xFFFD,
	0xB803: 0xFFFD,
	0xB804: 0xFFFD,
	0xB805: 0xFFFD,
	0xB806: 0xFFFD,
	0xB807: 0xFFFD,
	0xB808: 0xFFFD,
	0xB809: 0xFFFD,
	0xB80A: 0xFFFD,
	0xB80B: 0xFFFD,
	0xB80C: 0xFFFD,
	0xB80D: 0xFFFD,
	0xB80E: 0xFFFD,
	0xB80F: 0xFFFD,
	0xB810: 0xFFFD,
	0xB811: 0xFFFD,
	0xB812: 0xFFFD,
	0xB813: 0xFFFD,
	0xB814: 0xFFFD,
	0xB815: 0xFFFD,
	0xB816: 0xFFFD,
	0xB817: 0xFFFD,
	0xB818: 0xFFFD,
	0xB819: 0xFFFD,
	0xB81A: 0xFFFD,
	0xB81B: 0xFFFD,
	0xB81C: 0xFFFD,
	0xB81D: 0xFFFD,
	0xB81E: 0xFFFD,
	0xB81F: 0xFFFD,
	0xB820: 0xFFFD,
	0xB821: 0xFFFD,
	0xB822: 0xFFFD,
	0xB823: 0xFFFD,
	0xB824: 0xFFFD,
	0xB825: 0xFFFD,
	0xB826: 0xFFFD,
	0xB827: 0xFFFD,
	0xB828: 0xFFFD,
	0xB829: 0xFFFD,
	0xB82A: 0xFFFD,
	0xB82B: 0xFFFD,
	0xB82C: 0xFFFD,
	0xB82D: 0xFFFD,
	0xB82E: 0xFFFD,
	0xB82F: 0xFFFD,
	0xB830: 0xFFFD,
	0xB831: 0xFFFD,
	0xB832: 0xFFFD,
	0xB833: 0xFFFD,
	0xB834: 0xFFFD,
	0xB835: 0xFFFD,
	0xB836: 0xFFFD,
	0xB837: 0xFFFD,
	0xB838: 0xFFFD,
	0xB839: 0xFFFD,
	0xB83A: 0xFFFD,
	0xB83B: 0xFFFD,
	0xB83C: 0xFFFD,
	0xB83D: 0xFFFD,
	0xB83E: 0xFFFD,
	0xB83F: 0xFFFD,
	0xB840: 0xFFFD,
	0xB841: 0xFFFD,
	0xB842: 0xFFFD,
	0xB843: 0xFFFD,
	0xB844: 0xFFFD,
	0xB845: 0xFFFD,
	0xB846: 0xFFFD,
	0xB847: 0xFFFD,
	0xB848: 0xFFFD,
	0xB849: 0xFFFD,
	0xB84A: 0xFFFD,
	0xB84B: 0xFFFD,
	0xB84C: 0xFFFD,
	0xB84D: 0xFFFD,
	0xB84E: 0xFFFD,
	0xB84F: 0xFFFD,
	0xB850: 0xFFFD,
	0xB851: 0xFFFD,
	0xB852: 0xFFFD,
	0xB853: 0xFFFD,
	0xB854: 0xFFFD,
	0xB855: 0xFFFD,
	0xB856: 0xFFFD,
	0xB857: 0xFFFD,
	0xB858: 0xFFFD,
	0xB859: 0xFFFD,
	0xB85A: 0xFFFD,
	0xB85B: 0xFFFD,
	0xB85C: 0xFFFD,
	0xB85D: 0xFFFD,
	0xB85E: 0xFFFD,
	0xB85F: 0xFFFD,
	0xB860: 0xFFFD,
	0xB861: 0xFFFD,
	0xB862: 0xFFFD,
	0xB863: 0xFFFD,
	0xB864: 0xFFFD,
	0xB865: 0xFFFD,
	0xB866: 0xFFFD,
	0xB867: 0xFFFD,
	0xB868: 0xFFFD,
	0xB869: 0xFFFD,
	0xB86A: 0xFFFD,
	0xB86B: 0xFFFD,
	0xB86C: 0xFFFD,
	0xB86D: 0xFFFD,
	0xB86E: 0xFFFD,
	0xB86F: 0xFFFD,
	0xB870: 0xFFFD,
	0xB871: 0xFFFD,
	0xB872: 0xFFFD,
	0xB873: 0xFFFD,
	0xB874: 0xFFFD,
	0xB875: 0xFFFD,
	0xB876: 0xFFFD,
	0xB877: 0xFFFD,
	0xB878: 0xFFFD,
	0xB879: 0xFFFD,
	0xB87A: 0xFFFD,
	0xB87B: 0xFFFD,
	0xB87C: 0xFFFD,
	0xB87D: 0xFFFD,
	0xB87E: 0xFFFD,
	0xB87F: 0xFFFD,
	0xB880: 0xFFFD,
	0xB881: 0xFFFD,
	0xB882: 0xFFFD,
	0xB883: 0xFFFD,
	0xB884: 0xFFFD,
	0xB885: 0xFFFD,
	0xB886: 0xFFFD,
	0xB887: 0xFFFD,
	0xB888: 0xFFFD,
	0xB889: 0xFFFD,
	0xB88A: 0xFFFD,
	0xB88B: 0xFFFD,
	0xB88C: 0xFFFD,
	0xB88D: 0xFFFD,
	0xB88E: 0xFFFD,
	0xB88F: 0xFFFD,
	0xB890: 0xFFFD,
	0xB891: 0xFFFD,
	0xB892: 0xFFFD,
	0xB893: 0xFFFD,
	0xB894: 0xFFFD,
	0xB895: 0xFFFD,
	0xB896: 0xFFFD,
	0xB897: 0xFFFD,
	0xB898: 0xFFFD,
	0xB899: 0xFFFD,
	0xB89A: 0xFFFD,
	0xB89B: 0xFFFD,
	0xB89C: 0xFFFD,
	0xB89D: 0xFFFD,
	0xB89E: 0xFFFD,
	0xB89F: 0xFFFD,
	0xB8A0: 0xFFFD,
	0xB8A1: 0xFFFD,
	0xB8A2: 0xFFFD,
	0xB8A3: 0xFFFD,
	0xB8A4: 0xFFFD,
	0xB8A5: 0xFFFD,
	0xB8A6: 0xFFFD,
	0xB8A7: 0xFFFD,
	0xB8A8: 0xFFFD,
	0xB8A9: 0xFFFD,
	0xB8AA: 0xFFFD,
	0xB8AB: 0xFFFD,
	0xB8AC: 0xFFFD,
	0xB8AD: 0xFFFD,
	0xB8AE: 0xFFFD,
	0xB8AF: 0xFFFD,
	0xB8B0: 0xFFFD,
	0xB8B1: 0xFFFD,
	0xB8B2: 0xFFFD,
	0xB8B3: 0xFFFD,
	0xB8B4: 0xFFFD,
	0xB8B5: 0xFFFD,
	0xB8B6: 0xFFFD,
	0xB8B7: 0xFFFD,
	0xB8B8: 0xFFFD,
	0xB8B9: 0xFFFD,
	0xB8BA: 0xFFFD,
	0xB8BB: 0xFFFD,
	0xB8BC: 0xFFFD,
	0xB8BD: 0xFFFD,
	0xB8BE: 0xFFFD,
	0xB8BF: 0xFFFD,
	0xB8C0: 0xFFFD,
	0xB8C1: 0xFFFD,
	0xB8C2: 0xFFFD,
	0xB8C3: 0xFFFD,
	0xB8C4: 0xFFFD,
	0xB8C5: 0xFFFD,
	0xB8C6: 0xFFFD,
	0xB8C7: 0xFFFD,
	0xB8C8: 0xFFFD,
	0xB8C9: 0xFFFD,
	0xB8CA: 0xFFFD,
	0xB8CB: 0xFFFD,
	0xB8CC: 0xFFFD,
	0xB8CD: 0xFFFD,
	0xB8CE: 0xFFFD,
	0xB8CF: 0xFFFD,
	0xB8D0: 0xFFFD,
	0xB8D1: 0xFFFD,
	0xB8D2: 0xFFFD,
	0xB8D3: 0xFFFD,
	0xB8D4: 0xFFFD,
	0xB8D5: 0xFFFD,
	0xB8D6: 0xFFFD,
	0xB8D7: 0xFFFD,
	0xB8D8: 0xFFFD,
	0xB8D9: 0xFFFD,
	0xB8DA: 0xFFFD,
	0xB8DB: 0xFFFD,
	0xB8DC: 0xFFFD,
	0xB8DD: 0xFFFD,
	0xB8DE: 0xFFFD,
	0xB8DF: 0xFFFD,
	0xB8E0: 0xFFFD,
	0xB8E1: 0xFFFD,
	0xB8E2: 0xFFFD,
	0xB8E3: 0xFFFD,
	0xB8E4: 0xFFFD,
	0xB8E5: 0xFFFD,
	0xB8E6: 0xFFFD,
	0xB8E7: 0xFFFD,
	0xB8E8: 0xFFFD,
	0xB8E9: 0xFFFD,
	0xB8EA: 0xFFFD,
	0xB8EB: 0xFFFD,
	0xB8EC: 0xFFFD,
	0xB8ED: 0xFFFD,
	0xB8EE: 0xFFFD,
	0xB8EF: 0xFFFD,
	0xB8F0: 0xFFFD,
	0xB8F1: 0xFFFD,
	0xB8F2: 0xFFFD,
	0xB8F3: 0xFFFD,
	0xB8F4: 0xFFFD,
	0xB8F5: 0xFFFD,
	0xB8F6: 0xFFFD,
	0xB8F7: 0xFFFD,
	0xB8F8: 0xFFFD,
	0xB8F9: 0xFFFD,
	0xB8FA: 0xFFFD,
	0xB8FB: 0xFFFD,
	0xB8FC: 0xFFFD,
	0xB8FD: 0xFFFD,
	0xB8FE: 0xFFFD,
	0xB8FF: 0xFFFD,
	0xB900: 0xFFFD,
	0xB901: 0xFFFD,
	0xB902: 0xFFFD,
	0xB903: 0xFFFD,
	0xB904: 0xFFFD,
	0xB905: 0xFFFD,
	0xB906: 0xFFFD,
	0xB907: 0xFFFD,
	0xB908: 0xFFFD,
	0xB909: 0xFFFD,
	0xB90A: 0xFFFD,
	0xB90B: 0xFFFD,
	0xB90C: 0xFFFD,
	0xB90D: 0xFFFD,
	0xB90E: 0xFFFD,
	0xB90F: 0xFFFD,
	0xB910: 0xFFFD,
	0xB911: 0xFFFD,
	0xB912: 0xFFFD,
	0xB913: 0xFFFD,
	0xB914: 0xFFFD,
	0xB915: 0xFFFD,
	0xB916: 0xFFFD,
	0xB917: 0xFFFD,
	0xB918: 0xFFFD,
	0xB919: 0xFFFD,
	0xB91A: 0xFFFD,
	0xB91B: 0xFFFD,
	0xB91C: 0xFFFD,
	0xB91D: 0xFFFD,
	0xB91E: 0xFFFD,
	0xB91F: 0xFFFD,
	0xB920: 0xFFFD,
	0xB921: 0xFFFD,
	0xB922: 0xFFFD,
	0xB923: 0xFFFD,
	0xB924: 0xFFFD,
	0xB925: 0xFFFD,
	0xB926: 0xFFFD,
	0xB927: 0xFFFD,
	0xB928: 0xFFFD,
	0xB929: 0xFFFD,
	0xB92A: 0xFFFD,
	0xB92B: 0xFFFD,
	0xB92C: 0xFFFD,
	0xB92D: 0xFFFD,
	0xB92E: 0xFFFD,
	0xB92F: 0xFFFD,
	0xB930: 0xFFFD,
	0xB931: 0xFFFD,
	0xB932: 0xFFFD,
	0xB933: 0xFFFD,
	0xB934: 0xFFFD,
	0xB935: 0xFFFD,
	0xB936: 0xFFFD,
	0xB937: 0xFFFD,
	0xB938: 0xFFFD,
	0xB939: 0xFFFD,
	0xB93A: 0xFFFD,
	0xB93B: 0xFFFD,
	0xB93C: 0xFFFD,
	0xB93D: 0xFFFD,
	0xB93E: 0xFFFD,
	0xB93F: 0xFFFD,
	0xB940: 0xFFFD,
	0xB941: 0xFFFD,
	0xB942: 0xFFFD,
	0xB943: 0xFFFD,
	0xB944: 0xFFFD,
	0xB945: 0xFFFD,
	0xB946: 0xFFFD,
	0xB947: 0xFFFD,
	0xB948: 0xFFFD,
	0xB949: 0xFFFD,
	0xB94A: 0xFFFD,
	0xB94B: 0xFFFD,
	0xB94C: 0xFFFD,
	0xB94D: 0xFFFD,
	0xB94E: 0xFFFD,
	0xB94F: 0xFFFD,
	0xB950: 0xFFFD,
	0xB951: 0xFFFD,
	0xB952: 0xFFFD,
	0xB953: 0xFFFD,
	0xB954: 0xFFFD,
	0xB955: 0xFFFD,
	0xB956: 0xFFFD,
	0xB957: 0xFFFD,
	0xB958: 0xFFFD,
	0xB959: 0xFFFD,
	0xB95A: 0xFFFD,
	0xB95B: 0xFFFD,
	0xB95C: 0xFFFD,
	0xB95D: 0xFFFD,
	0xB95E: 0xFFFD,
	0xB95F: 0xFFFD,
	0xB960: 0xFFFD,
	0xB961: 0xFFFD,
	0xB962: 0xFFFD,
	0xB963: 0xFFFD,
	0xB964: 0xFFFD,
	0xB965: 0xFFFD,
	0xB966: 0xFFFD,
	0xB967: 0xFFFD,
	0xB968: 0xFFFD,
	0xB969: 0xFFFD,
	0xB96A: 0xFFFD,
	0xB96B: 0xFFFD,
	0xB96C: 0xFFFD,
	0xB96D: 0xFFFD,
	0xB96E: 0xFFFD,
	0xB96F: 0xFFFD,
	0xB970: 0xFFFD,
	0xB971: 0xFFFD,
	0xB972: 0xFFFD,
	0xB973: 0xFFFD,
	0xB974: 0xFFFD,
	0xB975: 0xFFFD,
	0xB976: 0xFFFD,
	0xB977: 0xFFFD,
	0xB978: 0xFFFD,
	0xB979: 0xFFFD,
	0xB97A: 0xFFFD,
	0xB97B: 0xFFFD,
	0xB97C: 0xFFFD,
	0xB97D: 0xFFFD,
	0xB97E: 0xFFFD,
	0xB97F: 0xFFFD,
	0xB980: 0xFFFD,
	0xB981: 0xFFFD,
	0xB982: 0xFFFD,
	0xB983: 0xFFFD,
	0xB984: 0xFFFD,
	0xB985: 0xFFFD,
	0xB986: 0xFFFD,
	0xB987: 0xFFFD,
	0xB988: 0xFFFD,
	0xB989: 0xFFFD,
	0xB98A: 0xFFFD,
	0xB98B: 0xFFFD,
	0xB98C: 0xFFFD,
	0xB98D: 0xFFFD,
	0xB98E: 0xFFFD,
	0xB98F: 0xFFFD,
	0xB990: 0xFFFD,
	0xB991: 0xFFFD,
	0xB992: 0xFFFD,
	0xB993: 0xFFFD,
	0xB994: 0xFFFD,
	0xB995: 0xFFFD,
	0xB996: 0xFFFD,
	0xB997: 0xFFFD,
	0xB998: 0xFFFD,
	0xB999: 0xFFFD,
	0xB99A: 0xFFFD,
	0xB99B: 0xFFFD,
	0xB99C: 0xFFFD,
	0xB99D: 0xFFFD,
	0xB99E: 0xFFFD,
	0xB99F: 0xFFFD,
	0xB9A0: 0xFFFD,
	0xB9A1: 0xFFFD,
	0xB9A2: 0xFFFD,
	0xB9A3: 0xFFFD,
	0xB9A4: 0xFFFD,
	0xB9A5: 0xFFFD,
	0xB9A6: 0xFFFD,
	0xB9A7: 0xFFFD,
	0xB9A8: 0xFFFD,
	0xB9A9: 0xFFFD,
	0xB9AA: 0xFFFD,
	0xB9AB: 0xFFFD,
	0xB9AC: 0xFFFD,
	0xB9AD: 0xFFFD,
	0xB9AE: 0xFFFD,
	0xB9AF: 0xFFFD,
	0xB9B0: 0xFFFD,
	0xB9B1: 0xFFFD,
	0xB9B2: 0xFFFD,
	0xB9B3: 0xFFFD,
	0xB9B4: 0xFFFD,
	0xB9B5: 0xFFFD,
	0xB9B6: 0xFFFD,
	0xB9B7: 0xFFFD,
	0xB9B8: 0xFFFD,
	0xB9B9: 0xFFFD,
	0xB9BA: 0xFFFD,
	0xB9BB: 0xFFFD,
	0xB9BC: 0xFFFD,
	0xB9BD: 0xFFFD,
	0xB9BE: 0xFFFD,
	0xB9BF: 0xFFFD,
	0xB9C0: 0xFFFD,
	0xB9C1: 0xFFFD,
	0xB9C2: 0xFFFD,
	0xB9C3: 0xFFFD,
	0xB9C4: 0xFFFD,
	0xB9C5: 0xFFFD,
	0xB9C6: 0xFFFD,
	0xB9C7: 0xFFFD,
	0xB9C8: 0xFFFD,
	0xB9C9: 0xFFFD,
	0xB9CA: 0xFFFD,
	0xB9CB: 0xFFFD,
	0xB9CC: 0xFFFD,
	0xB9CD: 0xFFFD,
	0xB9CE: 0xFFFD,
	0xB9CF: 0xFFFD,
	0xB9D0: 0xFFFD,
	0xB9D1: 0xFFFD,
	0xB9D2: 0xFFFD,
	0xB9D3: 0xFFFD,
	0xB9D4: 0xFFFD,
	0xB9D5: 0xFFFD,
	0xB9D6: 0xFFFD,
	0xB9D7: 0xFFFD,
	0xB9D8: 0xFFFD,
	0xB9D9: 0xFFFD,
	0xB9DA: 0xFFFD,
	0xB9DB: 0xFFFD,
	0xB9DC: 0xFFFD,
	0xB9DD: 0xFFFD,
	0xB9DE: 0xFFFD,
	0xB9DF: 0xFFFD,
	0xB9E0: 0xFFFD,
	0xB9E1: 0xFFFD,
	0xB9E2: 0xFFFD,
	0xB9E3: 0xFFFD,
	0xB9E4: 0xFFFD,
	0xB9E5: 0xFFFD,
	0xB9E6: 0xFFFD,
	0xB9E7: 0xFFFD,
	0xB9E8: 0xFFFD,
	0xB9E9: 0xFFFD,
	0xB9EA: 0xFFFD,
	0xB9EB: 0xFFFD,
	0xB9EC: 0xFFFD,
	0xB9ED: 0xFFFD,
	0xB9EE: 0xFFFD,
	0xB9EF: 0xFFFD,
	0xB9F0: 0xFFFD,
	0xB9F1: 0xFFFD,
	0xB9F2: 0xFFFD,
	0xB9F3: 0xFFFD,
	0xB9F4: 0xFFFD,
	0xB9F5: 0xFFFD,
	0xB9F6: 0xFFFD,
	0xB9F7: 0xFFFD,
	0xB9F8: 0xFFFD,
	0xB9F9: 0xFFFD,
	0xB9FA: 0xFFFD,
	0xB9FB: 0xFFFD,
	0xB9FC: 0xFFFD,
	0xB9FD: 0xFFFD,
	0xB9FE: 0xFFFD,
	0xB9FF: 0xFFFD,
	0xBA00: 0xFFFD,
	0xBA01: 0xFFFD,
	0xBA02: 0xFFFD,
	0xBA03: 0xFFFD,
	0xBA04: 0xFFFD,
	0xBA05: 0xFFFD,
	0xBA06: 0xFFFD,
	0xBA07: 0xFFFD,
	0xBA08: 0xFFFD,
	0xBA09: 0xFFFD,
	0xBA0A: 0xFFFD,
	0xBA0B: 0xFFFD,
	0xBA0C: 0xFFFD,
	0xBA0D: 0xFFFD,
	0xBA0E: 0xFFFD,
	0xBA0F: 0xFFFD,
	0xBA10: 0xFFFD,
	0xBA11: 0xFFFD,
	0xBA12: 0xFFFD,
	0xBA13: 0xFFFD,
	0xBA14: 0xFFFD,
	0xBA15: 0xFFFD,
	0xBA16: 0xFFFD,
	0xBA17: 0xFFFD,
	0xBA18: 0xFFFD,
	0xBA19: 0xFFFD,
	0xBA1A: 0xFFFD,
	0xBA1B: 0xFFFD,
	0xBA1C: 0xFFFD,
	0xBA1D: 0xFFFD,
	0xBA1E: 0xFFFD,
	0xBA1F: 0xFFFD,
	0xBA20: 0xFFFD,
	0xBA21: 0xFFFD,
	0xBA22: 0xFFFD,
	0xBA23: 0xFFFD,
	0xBA24: 0xFFFD,
	0xBA25: 0xFFFD,
	0xBA26: 0xFFFD,
	0xBA27: 0xFFFD,
	0xBA28: 0xFFFD,
	0xBA29: 0xFFFD,
	0xBA2A: 0xFFFD,
	0xBA2B: 0xFFFD,
	0xBA2C: 0xFFFD,
	0xBA2D: 0xFFFD,
	0xBA2E: 0xFFFD,
	0xBA2F: 0xFFFD,
	0xBA30: 0xFFFD,
	0xBA31: 0xFFFD,
	0xBA32: 0xFFFD,
	0xBA33: 0xFFFD,
	0xBA34: 0xFFFD,
	0xBA35: 0xFFFD,
	0xBA36: 0xFFFD,
	0xBA37: 0xFFFD,
	0xBA38: 0xFFFD,
	0xBA39: 0xFFFD,
	0xBA3A: 0xFFFD,
	0xBA3B: 0xFFFD,
	0xBA3C: 0xFFFD,
	0xBA3D: 0xFFFD,
	0xBA3E: 0xFFFD,
	0xBA3F: 0xFFFD,
	0xBA40: 0xFFFD,
	0xBA41: 0xFFFD,
	0xBA42: 0xFFFD,
	0xBA43: 0xFFFD,
	0xBA44: 0xFFFD,
	0xBA45: 0xFFFD,
	0xBA46: 0xFFFD,
	0xBA47: 0xFFFD,
	0xBA48: 0xFFFD,
	0xBA49: 0xFFFD,
	0xBA4A: 0xFFFD,
	0xBA4B: 0xFFFD,
	0xBA4C: 0xFFFD,
	0xBA4D: 0xFFFD,
	0xBA4E: 0xFFFD,
	0xBA4F: 0xFFFD,
	0xBA50: 0xFFFD,
	0xBA51: 0xFFFD,
	0xBA52: 0xFFFD,
	0xBA53: 0xFFFD,
	0xBA54: 0xFFFD,
	0xBA55: 0xFFFD,
	0xBA56: 0xFFFD,
	0xBA57: 0xFFFD,
	0xBA58: 0xFFFD,
	0xBA59: 0xFFFD,
	0xBA5A: 0xFFFD,
	0xBA5B: 0xFFFD,
	0xBA5C: 0xFFFD,
	0xBA5D: 0xFFFD,
	0xBA5E: 0xFFFD,
	0xBA5F: 0xFFFD,
	0xBA60: 0xFFFD,
	0xBA61: 0xFFFD,
	0xBA62: 0xFFFD,
	0xBA63: 0xFFFD,
	0xBA64: 0xFFFD,
	0xBA65: 0xFFFD,
	0xBA66: 0xFFFD,
	0xBA67: 0xFFFD,
	0xBA68: 0xFFFD,
	0xBA69: 0xFFFD,
	0xBA6A: 0xFFFD,
	0xBA6B: 0xFFFD,
	0xBA6C: 0xFFFD,
	0xBA6D: 0xFFFD,
	0xBA6E: 0xFFFD,
	0xBA6F: 0xFFFD,
	0xBA70: 0xFFFD,
	0xBA71: 0xFFFD,
	0xBA72: 0xFFFD,
	0xBA73: 0xFFFD,
	0xBA74: 0xFFFD,
	0xBA75: 0xFFFD,
	0xBA76: 0xFFFD,
	0xBA77: 0xFFFD,
	0xBA78: 0xFFFD,
	0xBA79: 0xFFFD,
	0xBA7A: 0xFFFD,
	0xBA7B: 0xFFFD,
	0xBA7C: 0xFFFD,
	0xBA7D: 0xFFFD,
	0xBA7E: 0xFFFD,
	0xBA7F: 0xFFFD,
	0xBA80: 0xFFFD,
	0xBA81: 0xFFFD,
	0xBA82: 0xFFFD,
	0xBA83: 0xFFFD,
	0xBA84: 0xFFFD,
	0xBA85: 0xFFFD,
	0xBA86: 0xFFFD,
	0xBA87: 0xFFFD,
	0xBA88: 0xFFFD,
	0xBA89: 0xFFFD,
	0xBA8A: 0xFFFD,
	0xBA8B: 0xFFFD,
	0xBA8C: 0xFFFD,
	0xBA8D: 0xFFFD,
	0xBA8E: 0xFFFD,
	0xBA8F: 0xFFFD,
	0xBA90: 0xFFFD,
	0xBA91: 0xFFFD,
	0xBA92: 0xFFFD,
	0xBA93: 0xFFFD,
	0xBA94: 0xFFFD,
	0xBA95: 0xFFFD,
	0xBA96: 0xFFFD,
	0xBA97: 0xFFFD,
	0xBA98: 0xFFFD,
	0xBA99: 0xFFFD,
	0xBA9A: 0xFFFD,
	0xBA9B: 0xFFFD,
	0xBA9C: 0xFFFD,
	0xBA9D: 0xFFFD,
	0xBA9E: 0xFFFD,
	0xBA9F: 0xFFFD,
	0xBAA0: 0xFFFD,
	0xBAA1: 0xFFFD,
	0xBAA2: 0xFFFD,
	0xBAA3: 0xFFFD,
	0xBAA4: 0xFFFD,
	0xBAA5: 0xFFFD,
	0xBAA6: 0xFFFD,
	0xBAA7: 0xFFFD,
	0xBAA8: 0xFFFD,
	0xBAA9: 0xFFFD,
	0xBAAA: 0xFFFD,
	0xBAAB: 0xFFFD,
	0xBAAC: 0xFFFD,
	0xBAAD: 0xFFFD,
	0xBAAE: 0xFFFD,
	0xBAAF: 0xFFFD,
	0xBAB0: 0xFFFD,
	0xBAB1: 0xFFFD,
	0xBAB2: 0xFFFD,
	0xBAB3: 0xFFFD,
	0xBAB4: 0xFFFD,
	0xBAB5: 0xFFFD,
	0xBAB6: 0xFFFD,
	0xBAB7: 0xFFFD,
	0xBAB8: 0xFFFD,
	0xBAB9: 0xFFFD,
	0xBABA: 0xFFFD,
	0xBABB: 0xFFFD,
	0xBABC: 0xFFFD,
	0xBABD: 0xFFFD,
	0xBABE: 0xFFFD,
	0xBABF: 0xFFFD,
	0xBAC0: 0xFFFD,
	0xBAC1: 0xFFFD,
	0xBAC2: 0xFFFD,
	0xBAC3: 0xFFFD,
	0xBAC4: 0xFFFD,
	0xBAC5: 0xFFFD,
	0xBAC6: 0xFFFD,
	0xBAC7: 0xFFFD,
	0xBAC8: 0xFFFD,
	0xBAC9: 0xFFFD,
	0xBACA: 0xFFFD,
	0xBACB: 0xFFFD,
	0xBACC: 0xFFFD,
	0xBACD: 0xFFFD,
	0xBACE: 0xFFFD,
	0xBACF: 0xFFFD,
	0xBAD0: 0xFFFD,
	0xBAD1: 0xFFFD,
	0xBAD2: 0xFFFD,
	0xBAD3: 0xFFFD,
	0xBAD4: 0xFFFD,
	0xBAD5: 0xFFFD,
	0xBAD6: 0xFFFD,
	0xBAD7: 0xFFFD,
	0xBAD8: 0xFFFD,
	0xBAD9: 0xFFFD,
	0xBADA: 0xFFFD,
	0xBADB: 0xFFFD,
	0xBADC: 0xFFFD,
	0xBADD: 0xFFFD,
	0xBADE: 0xFFFD,
	0xBADF: 0xFFFD,
	0xBAE0: 0xFFFD,
	0xBAE1: 0xFFFD,
	0xBAE2: 0xFFFD,
	0xBAE3: 0xFFFD,
	0xBAE4: 0xFFFD,
	0xBAE5: 0xFFFD,
	0xBAE6: 0xFFFD,
	0xBAE7: 0xFFFD,
	0xBAE8: 0xFFFD,
	0xBAE9: 0xFFFD,
	0xBAEA: 0xFFFD,
	0xBAEB: 0xFFFD,
	0xBAEC: 0xFFFD,
	0xBAED: 0xFFFD,
	0xBAEE: 0xFFFD,
	0xBAEF: 0xFFFD,
	0xBAF0: 0xFFFD,
	0xBAF1: 0xFFFD,
	0xBAF2: 0xFFFD,
	0xBAF3: 0xFFFD,
	0xBAF4: 0xFFFD,
	0xBAF5: 0xFFFD,
	0xBAF6: 0xFFFD,
	0xBAF7: 0xFFFD,
	0xBAF8: 0xFFFD,
	0xBAF9: 0xFFFD,
	0xBAFA: 0xFFFD,
	0xBAFB: 0xFFFD,
	0xBAFC: 0xFFFD,
	0xBAFD: 0xFFFD,
	0xBAFE: 0xFFFD,
	0xBAFF: 0xFFFD,
	0xBB00: 0xFFFD,
	0xBB01: 0xFFFD,
	0xBB02: 0xFFFD,
	0xBB03: 0xFFFD,
	0xBB04: 0xFFFD,
	0xBB05: 0xFFFD,
	0xBB06: 0xFFFD,
	0xBB07: 0xFFFD,
	0xBB08: 0xFFFD,
	0xBB09: 0xFFFD,
	0xBB0A: 0xFFFD,
	0xBB0B: 0xFFFD,
	0xBB0C: 0xFFFD,
	0xBB0D: 0xFFFD,
	0xBB0E: 0xFFFD,
	0xBB0F: 0xFFFD,
	0xBB10: 0xFFFD,
	0xBB11: 0xFFFD,
	0xBB12: 0xFFFD,
	0xBB13: 0xFFFD,
	0xBB14: 0xFFFD,
	0xBB15: 0xFFFD,
	0xBB16: 0xFFFD,
	0xBB17: 0xFFFD,
	0xBB18: 0xFFFD,
	0xBB19: 0xFFFD,
	0xBB1A: 0xFFFD,
	0xBB1B: 0xFFFD,
	0xBB1C: 0xFFFD,
	0xBB1D: 0xFFFD,
	0xBB1E: 0xFFFD,
	0xBB1F: 0xFFFD,
	0xBB20: 0xFFFD,
	0xBB21: 0xFFFD,
	0xBB22: 0xFFFD,
	0xBB23: 0xFFFD,
	0xBB24: 0xFFFD,
	0xBB25: 0xFFFD,
	0xBB26: 0xFFFD,
	0xBB27: 0xFFFD,
	0xBB28: 0xFFFD,
	0xBB29: 0xFFFD,
	0xBB2A: 0xFFFD,
	0xBB2B: 0xFFFD,
	0xBB2C: 0xFFFD,
	0xBB2D: 0xFFFD,
	0xBB2E: 0xFFFD,
	0xBB2F: 0xFFFD,
	0xBB30: 0xFFFD,
	0xBB31: 0xFFFD,
	0xBB32: 0xFFFD,
	0xBB33: 0xFFFD,
	0xBB34: 0xFFFD,
	0xBB35: 0xFFFD,
	0xBB36: 0xFFFD,
	0xBB37: 0xFFFD,
	0xBB38: 0xFFFD,
	0xBB39: 0xFFFD,
	0xBB3A: 0xFFFD,
	0xBB3B: 0xFFFD,
	0xBB3C: 0xFFFD,
	0xBB3D: 0xFFFD,
	0xBB3E: 0xFFFD,
	0xBB3F: 0xFFFD,
	0xBB40: 0xFFFD,
	0xBB41: 0xFFFD,
	0xBB42: 0xFFFD,
	0xBB43: 0xFFFD,
	0xBB44: 0xFFFD,
	0xBB45: 0xFFFD,
	0xBB46: 0xFFFD,
	0xBB47: 0xFFFD,
	0xBB48: 0xFFFD,
	0xBB49: 0xFFFD,
	0xBB4A: 0xFFFD,
	0xBB4B: 0xFFFD,
	0xBB4C: 0xFFFD,
	0xBB4D: 0xFFFD,
	0xBB4E: 0xFFFD,
	0xBB4F: 0xFFFD,
	0xBB50: 0xFFFD,
	0xBB51: 0xFFFD,
	0xBB52: 0xFFFD,
	0xBB53: 0xFFFD,
	0xBB54: 0xFFFD,
	0xBB55: 0xFFFD,
	0xBB56: 0xFFFD,
	0xBB57: 0xFFFD,
	0xBB58: 0xFFFD,
	0xBB59: 0xFFFD,
	0xBB5A: 0xFFFD,
	0xBB5B: 0xFFFD,
	0xBB5C: 0xFFFD,
	0xBB5D: 0xFFFD,
	0xBB5E: 0xFFFD,
	0xBB5F: 0xFFFD,
	0xBB60: 0xFFFD,
	0xBB61: 0xFFFD,
	0xBB62: 0xFFFD,
	0xBB63: 0xFFFD,
	0xBB64: 0xFFFD,
	0xBB65: 0xFFFD,
	0xBB66: 0xFFFD,
	0xBB67: 0xFFFD,
	0xBB68: 0xFFFD,
	0xBB69: 0xFFFD,
	0xBB6A: 0xFFFD,
	0xBB6B: 0xFFFD,
	0xBB6C: 0xFFFD,
	0xBB6D: 0xFFFD,
	0xBB6E: 0xFFFD,
	0xBB6F: 0xFFFD,
	0xBB70: 0xFFFD,
	0xBB71: 0xFFFD,
	0xBB72: 0xFFFD,
	0xBB73: 0xFFFD,
	0xBB74: 0xFFFD,
	0xBB75: 0xFFFD,
	0xBB76: 0xFFFD,
	0xBB77: 0xFFFD,
	0xBB78: 0xFFFD,
	0xBB79: 0xFFFD,
	0xBB7A: 0xFFFD,
	0xBB7B: 0xFFFD,
	0xBB7C: 0xFFFD,
	0xBB7D: 0xFFFD,
	0xBB7E: 0xFFFD,
	0xBB7F: 0xFFFD,
	0xBB80: 0xFFFD,
	0xBB81: 0xFFFD,
	0xBB82: 0xFFFD,
	0xBB83: 0xFFFD,
	0xBB84: 0xFFFD,
	0xBB85: 0xFFFD,
	0xBB86: 0xFFFD,
	0xBB87: 0xFFFD,
	0xBB88: 0xFFFD,
	0xBB89: 0xFFFD,
	0xBB8A: 0xFFFD,
	0xBB8B: 0xFFFD,
	0xBB8C: 0xFFFD,
	0xBB8D: 0xFFFD,
	0xBB8E: 0xFFFD,
	0xBB8F: 0xFFFD,
	0xBB90: 0xFFFD,
	0xBB91: 0xFFFD,
	0xBB92: 0xFFFD,
	0xBB93: 0xFFFD,
	0xBB94: 0xFFFD,
	0xBB95: 0xFFFD,
	0xBB96: 0xFFFD,
	0xBB97: 0xFFFD,
	0xBB98: 0xFFFD,
	0xBB99: 0xFFFD,
	0xBB9A: 0xFFFD,
	0xBB9B: 0xFFFD,
	0xBB9C: 0xFFFD,
	0xBB9D: 0xFFFD,
	0xBB9E: 0xFFFD,
	0xBB9F: 0xFFFD,
	0xBBA0: 0xFFFD,
	0xBBA1: 0xFFFD,
	0xBBA2: 0xFFFD,
	0xBBA3: 0xFFFD,
	0xBBA4: 0xFFFD,
	0xBBA5: 0xFFFD,
	0xBBA6: 0xFFFD,
	0xBBA7: 0xFFFD,
	0xBBA8: 0xFFFD,
	0xBBA9: 0xFFFD,
	0xBBAA: 0xFFFD,
	0xBBAB: 0xFFFD,
	0xBBAC: 0xFFFD,
	0xBBAD: 0xFFFD,
	0xBBAE: 0xFFFD,
	0xBBAF: 0xFFFD,
	0xBBB0: 0xFFFD,
	0xBBB1: 0xFFFD,
	0xBBB2: 0xFFFD,
	0xBBB3: 0xFFFD,
	0xBBB4: 0xFFFD,
	0xBBB5: 0xFFFD,
	0xBBB6: 0xFFFD,
	0xBBB7: 0xFFFD,
	0xBBB8: 0xFFFD,
	0xBBB9: 0xFFFD,
	0xBBBA: 0xFFFD,
	0xBBBB: 0xFFFD,
	0xBBBC: 0xFFFD,
	0xBBBD: 0xFFFD,
	0xBBBE: 0xFFFD,
	0xBBBF: 0xFFFD,
	0xBBC0: 0xFFFD,
	0xBBC1: 0xFFFD,
	0xBBC2: 0xFFFD,
	0xBBC3: 0xFFFD,
	0xBBC4: 0xFFFD,
	0xBBC5: 0xFFFD,
	0xBBC6: 0xFFFD,
	0xBBC7: 0xFFFD,
	0xBBC8: 0xFFFD,
	0xBBC9: 0xFFFD,
	0xBBCA: 0xFFFD,
	0xBBCB: 0xFFFD,
	0xBBCC: 0xFFFD,
	0xBBCD: 0xFFFD,
	0xBBCE: 0xFFFD,
	0xBBCF: 0xFFFD,
	0xBBD0: 0xFFFD,
	0xBBD1: 0xFFFD,
	0xBBD2: 0xFFFD,
	0xBBD3: 0xFFFD,
	0xBBD4: 0xFFFD,
	0xBBD5: 0xFFFD,
	0xBBD6: 0xFFFD,
	0xBBD7: 0xFFFD,
	0xBBD8: 0xFFFD,
	0xBBD9: 0xFFFD,
	0xBBDA: 0xFFFD,
	0xBBDB: 0xFFFD,
	0xBBDC: 0xFFFD,
	0xBBDD: 0xFFFD,
	0xBBDE: 0xFFFD,
	0xBBDF: 0xFFFD,
	0xBBE0: 0xFFFD,
	0xBBE1: 0xFFFD,
	0xBBE2: 0xFFFD,
	0xBBE3: 0xFFFD,
	0xBBE4: 0xFFFD,
	0xBBE5: 0xFFFD,
	0xBBE6: 0xFFFD,
	0xBBE7: 0xFFFD,
	0xBBE8: 0xFFFD,
	0xBBE9: 0xFFFD,
	0xBBEA: 0xFFFD,
	0xBBEB: 0xFFFD,
	0xBBEC: 0xFFFD,
	0xBBED: 0xFFFD,
	0xBBEE: 0xFFFD,
	0xBBEF: 0xFFFD,
	0xBBF0: 0xFFFD,
	0xBBF1: 0xFFFD,
	0xBBF2: 0xFFFD,
	0xBBF3: 0xFFFD,
	0xBBF4: 0xFFFD,
	0xBBF5: 0xFFFD,
	0xBBF6: 0xFFFD,
	0xBBF7: 0xFFFD,
	0xBBF8: 0xFFFD,
	0xBBF9: 0xFFFD,
	0xBBFA: 0xFFFD,
	0xBBFB: 0xFFFD,
	0xBBFC: 0xFFFD,
	0xBBFD: 0xFFFD,
	0xBBFE: 0xFFFD,
	0xBBFF: 0xFFFD,
	0xBC00: 0xFFFD,
	0xBC01: 0xFFFD,
	0xBC02: 0xFFFD,
	0xBC03: 0xFFFD,
	0xBC04: 0xFFFD,
	0xBC05: 0xFFFD,
	0xBC06: 0xFFFD,
	0xBC07: 0xFFFD,
	0xBC08: 0xFFFD,
	0xBC09: 0xFFFD,
	0xBC0A: 0xFFFD,
	0xBC0B: 0xFFFD,
	0xBC0C: 0xFFFD,
	0xBC0D: 0xFFFD,
	0xBC0E: 0xFFFD,
	0xBC0F: 0xFFFD,
	0xBC10: 0xFFFD,
	0xBC11: 0xFFFD,
	0xBC12: 0xFFFD,
	0xBC13: 0xFFFD,
	0xBC14: 0xFFFD,
	0xBC15: 0xFFFD,
	0xBC16: 0xFFFD,
	0xBC17: 0xFFFD,
	0xBC18: 0xFFFD,
	0xBC19: 0xFFFD,
	0xBC1A: 0xFFFD,
	0xBC1B: 0xFFFD,
	0xBC1C: 0xFFFD,
	0xBC1D: 0xFFFD,
	0xBC1E: 0xFFFD,
	0xBC1F: 0xFFFD,
	0xBC20: 0xFFFD,
	0xBC21: 0xFFFD,
	0xBC22: 0xFFFD,
	0xBC23: 0xFFFD,
	0xBC24: 0xFFFD,
	0xBC25: 0xFFFD,
	0xBC26: 0xFFFD,
	0xBC27: 0xFFFD,
	0xBC28: 0xFFFD,
	0xBC29: 0xFFFD,
	0xBC2A: 0xFFFD,
	0xBC2B: 0xFFFD,
	0xBC2C: 0xFFFD,
	0xBC2D: 0xFFFD,
	0xBC2E: 0xFFFD,
	0xBC2F: 0xFFFD,
	0xBC30: 0xFFFD,
	0xBC31: 0xFFFD,
	0xBC32: 0xFFFD,
	0xBC33: 0xFFFD,
	0xBC34: 0xFFFD,
	0xBC35: 0xFFFD,
	0xBC36: 0xFFFD,
	0xBC37: 0xFFFD,
	0xBC38: 0xFFFD,
	0xBC39: 0xFFFD,
	0xBC3A: 0xFFFD,
	0xBC3B: 0xFFFD,
	0xBC3C: 0xFFFD,
	0xBC3D: 0xFFFD,
	0xBC3E: 0xFFFD,
	0xBC3F: 0xFFFD,
	0xBC40: 0xFFFD,
	0xBC41: 0xFFFD,
	0xBC42: 0xFFFD,
	0xBC43: 0xFFFD,
	0xBC44: 0xFFFD,
	0xBC45: 0xFFFD,
	0xBC46: 0xFFFD,
	0xBC47: 0xFFFD,
	0xBC48: 0xFFFD,
	0xBC49: 0xFFFD,
	0xBC4A: 0xFFFD,
	0xBC4B: 0xFFFD,
	0xBC4C: 0xFFFD,
	0xBC4D: 0xFFFD,
	0xBC4E: 0xFFFD,
	0xBC4F: 0xFFFD,
	0xBC50: 0xFFFD,
	0xBC51: 0xFFFD,
	0xBC52: 0xFFFD,
	0xBC53: 0xFFFD,
	0xBC54: 0xFFFD,
	0xBC55: 0xFFFD,
	0xBC56: 0xFFFD,
	0xBC57: 0xFFFD,
	0xBC58: 0xFFFD,
	0xBC59: 0xFFFD,
	0xBC5A: 0xFFFD,
	0xBC5B: 0xFFFD,
	0xBC5C: 0xFFFD,
	0xBC5D: 0xFFFD,
	0xBC5E: 0xFFFD,
	0xBC5F: 0xFFFD,
	0xBC60: 0xFFFD,
	0xBC61: 0xFFFD,
	0xBC62: 0xFFFD,
	0xBC63: 0xFFFD,
	0xBC64: 0xFFFD,
	0xBC65: 0xFFFD,
	0xBC66: 0xFFFD,
	0xBC67: 0xFFFD,
	0xBC68: 0xFFFD,
	0xBC69: 0xFFFD,
	0xBC6A: 0xFFFD,
	0xBC6B: 0xFFFD,
	0xBC6C: 0xFFFD,
	0xBC6D: 0xFFFD,
	0xBC6E: 0xFFFD,
	0xBC6F: 0xFFFD,
	0xBC70: 0xFFFD,
	0xBC71: 0xFFFD,
	0xBC72: 0xFFFD,
	0xBC73: 0xFFFD,
	0xBC74: 0xFFFD,
	0xBC75: 0xFFFD,
	0xBC76: 0xFFFD,
	0xBC77: 0xFFFD,
	0xBC78: 0xFFFD,
	0xBC79: 0xFFFD,
	0xBC7A: 0xFFFD,
	0xBC7B: 0xFFFD,
	0xBC7C: 0xFFFD,
	0xBC7D: 0xFFFD,
	0xBC7E: 0xFFFD,
	0xBC7F: 0xFFFD,
	0xBC80: 0xFFFD,
	0xBC81: 0xFFFD,
	0xBC82: 0xFFFD,
	0xBC83: 0xFFFD,
	0xBC84: 0xFFFD,
	0xBC85: 0xFFFD,
	0xBC86: 0xFFFD,
	0xBC87: 0xFFFD,
	0xBC88: 0xFFFD,
	0xBC89: 0xFFFD,
	0xBC8A: 0xFFFD,
	0xBC8B: 0xFFFD,
	0xBC8C: 0xFFFD,
	0xBC8D: 0xFFFD,
	0xBC8E: 0xFFFD,
	0xBC8F: 0xFFFD,
	0xBC90: 0xFFFD,
	0xBC91: 0xFFFD,
	0xBC92: 0xFFFD,
	0xBC93: 0xFFFD,
	0xBC94: 0xFFFD,
	0xBC95: 0xFFFD,
	0xBC96: 0xFFFD,
	0xBC97: 0xFFFD,
	0xBC98: 0xFFFD,
	0xBC99: 0xFFFD,
	0xBC9A: 0xFFFD,
	0xBC9B: 0xFFFD,
	0xBC9C: 0xFFFD,
	0xBC9D: 0xFFFD,
	0xBC9E: 0xFFFD,
	0xBC9F: 0xFFFD,
	0xBCA0: 0xFFFD,
	0xBCA1: 0xFFFD,
	0xBCA2: 0xFFFD,
	0xBCA3: 0xFFFD,
	0xBCA4: 0xFFFD,
	0xBCA5: 0xFFFD,
	0xBCA6: 0xFFFD,
	0xBCA7: 0xFFFD,
	0xBCA8: 0xFFFD,
	0xBCA9: 0xFFFD,
	0xBCAA: 0xFFFD,
	0xBCAB: 0xFFFD,
	0xBCAC: 0xFFFD,
	0xBCAD: 0xFFFD,
	0xBCAE: 0xFFFD,
	0xBCAF: 0xFFFD,
	0xBCB0: 0xFFFD,
	0xBCB1: 0xFFFD,
	0xBCB2: 0xFFFD,
	0xBCB3: 0xFFFD,
	0xBCB4: 0xFFFD,
	0xBCB5: 0xFFFD,
	0xBCB6: 0xFFFD,
	0xBCB7: 0xFFFD,
	0xBCB8: 0xFFFD,
	0xBCB9: 0xFFFD,
	0xBCBA: 0xFFFD,
	0xBCBB: 0xFFFD,
	0xBCBC: 0xFFFD,
	0xBCBD: 0xFFFD,
	0xBCBE: 0xFFFD,
	0xBCBF: 0xFFFD,
	0xBCC0: 0xFFFD,
	0xBCC1: 0xFFFD,
	0xBCC2: 0xFFFD,
	0xBCC3: 0xFFFD,
	0xBCC4: 0xFFFD,
	0xBCC5: 0xFFFD,
	0xBCC6: 0xFFFD,
	0xBCC7: 0xFFFD,
	0xBCC8: 0xFFFD,
	0xBCC9: 0xFFFD,
	0xBCCA: 0xFFFD,
	0xBCCB: 0xFFFD,
	0xBCCC: 0xFFFD,
	0xBCCD: 0xFFFD,
	0xBCCE: 0xFFFD,
	0xBCCF: 0xFFFD,
	0xBCD0: 0xFFFD,
	0xBCD1: 0xFFFD,
	0xBCD2: 0xFFFD,
	0xBCD3: 0xFFFD,
	0xBCD4: 0xFFFD,
	0xBCD5: 0xFFFD,
	0xBCD6: 0xFFFD,
	0xBCD7: 0xFFFD,
	0xBCD8: 0xFFFD,
	0xBCD9: 0xFFFD,
	0xBCDA: 0xFFFD,
	0xBCDB: 0xFFFD,
	0xBCDC: 0xFFFD,
	0xBCDD: 0xFFFD,
	0xBCDE: 0xFFFD,
	0xBCDF: 0xFFFD,
	0xBCE0: 0xFFFD,
	0xBCE1: 0xFFFD,
	0xBCE2: 0xFFFD,
	0xBCE3: 0xFFFD,
	0xBCE4: 0xFFFD,
	0xBCE5: 0xFFFD,
	0xBCE6: 0xFFFD,
	0xBCE7: 0xFFFD,
	0xBCE8: 0xFFFD,
	0xBCE9: 0xFFFD,
	0xBCEA: 0xFFFD,
	0xBCEB: 0xFFFD,
	0xBCEC: 0xFFFD,
	0xBCED: 0xFFFD,
	0xBCEE: 0xFFFD,
	0xBCEF: 0xFFFD,
	0xBCF0: 0xFFFD,
	0xBCF1: 0xFFFD,
	0xBCF2: 0xFFFD,
	0xBCF3: 0xFFFD,
	0xBCF4: 0xFFFD,
	0xBCF5: 0xFFFD,
	0xBCF6: 0xFFFD,
	0xBCF7: 0xFFFD,
	0xBCF8: 0xFFFD,
	0xBCF9: 0xFFFD,
	0xBCFA: 0xFFFD,
	0xBCFB: 0xFFFD,
	0xBCFC: 0xFFFD,
	0xBCFD: 0xFFFD,
	0xBCFE: 0xFFFD,
	0xBCFF: 0xFFFD,
	0xBD00: 0xFFFD,
	0xBD01: 0xFFFD,
	0xBD02: 0xFFFD,
	0xBD03: 0xFFFD,
	0xBD04: 0xFFFD,
	0xBD05: 0xFFFD,
	0xBD06: 0xFFFD,
	0xBD07: 0xFFFD,
	0xBD08: 0xFFFD,
	0xBD09: 0xFFFD,
	0xBD0A: 0xFFFD,
	0xBD0B: 0xFFFD,
	0xBD0C: 0xFFFD,
	0xBD0D: 0xFFFD,
	0xBD0E: 0xFFFD,
	0xBD0F: 0xFFFD,
	0xBD10: 0xFFFD,
	0xBD11: 0xFFFD,
	0xBD12: 0xFFFD,
	0xBD13: 0xFFFD,
	0xBD14: 0xFFFD,
	0xBD15: 0xFFFD,
	0xBD16: 0xFFFD,
	0xBD17: 0xFFFD,
	0xBD18: 0xFFFD,
	0xBD19: 0xFFFD,
	0xBD1A: 0xFFFD,
	0xBD1B: 0xFFFD,
	0xBD1C: 0xFFFD,
	0xBD1D: 0xFFFD,
	0xBD1E: 0xFFFD,
	0xBD1F: 0xFFFD,
	0xBD20: 0xFFFD,
	0xBD21: 0xFFFD,
	0xBD22: 0xFFFD,
	0xBD23: 0xFFFD,
	0xBD24: 0xFFFD,
	0xBD25: 0xFFFD,
	0xBD26: 0xFFFD,
	0xBD27: 0xFFFD,
	0xBD28: 0xFFFD,
	0xBD29: 0xFFFD,
	0xBD2A: 0xFFFD,
	0xBD2B: 0xFFFD,
	0xBD2C: 0xFFFD,
	0xBD2D: 0xFFFD,
	0xBD2E: 0xFFFD,
	0xBD2F: 0xFFFD,
	0xBD30: 0xFFFD,
	0xBD31: 0xFFFD,
	0xBD32: 0xFFFD,
	0xBD33: 0xFFFD,
	0xBD34: 0xFFFD,
	0xBD35: 0xFFFD,
	0xBD36: 0xFFFD,
	0xBD37: 0xFFFD,
	0xBD38: 0xFFFD,
	0xBD39: 0xFFFD,
	0xBD3A: 0xFFFD,
	0xBD3B: 0xFFFD,
	0xBD3C: 0xFFFD,
	0xBD3D: 0xFFFD,
	0xBD3E: 0xFFFD,
	0xBD3F: 0xFFFD,
	0xBD40: 0xFFFD,
	0xBD41: 0xFFFD,
	0xBD42: 0xFFFD,
	0xBD43: 0xFFFD,
	0xBD44: 0xFFFD,
	0xBD45: 0xFFFD,
	0xBD46: 0xFFFD,
	0xBD47: 0xFFFD,
	0xBD48: 0xFFFD,
	0xBD49: 0xFFFD,
	0xBD4A: 0xFFFD,
	0xBD4B: 0xFFFD,
	0xBD4C: 0xFFFD,
	0xBD4D: 0xFFFD,
	0xBD4E: 0xFFFD,
	0xBD4F: 0xFFFD,
	0xBD50: 0xFFFD,
	0xBD51: 0xFFFD,
	0xBD52: 0xFFFD,
	0xBD53: 0xFFFD,
	0xBD54: 0xFFFD,
	0xBD55: 0xFFFD,
	0xBD56: 0xFFFD,
	0xBD57: 0xFFFD,
	0xBD58: 0xFFFD,
	0xBD59: 0xFFFD,
	0xBD5A: 0xFFFD,
	0xBD5B: 0xFFFD,
	0xBD5C: 0xFFFD,
	0xBD5D: 0xFFFD,
	0xBD5E: 0xFFFD,
	0xBD5F: 0xFFFD,
	0xBD60: 0xFFFD,
	0xBD61: 0xFFFD,
	0xBD62: 0xFFFD,
	0xBD63: 0xFFFD,
	0xBD64: 0xFFFD,
	0xBD65: 0xFFFD,
	0xBD66: 0xFFFD,
	0xBD67: 0xFFFD,
	0xBD68: 0xFFFD,
	0xBD69: 0xFFFD,
	0xBD6A: 0xFFFD,
	0xBD6B: 0xFFFD,
	0xBD6C: 0xFFFD,
	0xBD6D: 0xFFFD,
	0xBD6E: 0xFFFD,
	0xBD6F: 0xFFFD,
	0xBD70: 0xFFFD,
	0xBD71: 0xFFFD,
	0xBD72: 0xFFFD,
	0xBD73: 0xFFFD,
	0xBD74: 0xFFFD,
	0xBD75: 0xFFFD,
	0xBD76: 0xFFFD,
	0xBD77: 0xFFFD,
	0xBD78: 0xFFFD,
	0xBD79: 0xFFFD,
	0xBD7A: 0xFFFD,
	0xBD7B: 0xFFFD,
	0xBD7C: 0xFFFD,
	0xBD7D: 0xFFFD,
	0xBD7E: 0xFFFD,
	0xBD7F: 0xFFFD,
	0xBD80: 0xFFFD,
	0xBD81: 0xFFFD,
	0xBD82: 0xFFFD,
	0xBD83: 0xFFFD,
	0xBD84: 0xFFFD,
	0xBD85: 0xFFFD,
	0xBD86: 0xFFFD,
	0xBD87: 0xFFFD,
	0xBD88: 0xFFFD,
	0xBD89: 0xFFFD,
	0xBD8A: 0xFFFD,
	0xBD8B: 0xFFFD,
	0xBD8C: 0xFFFD,
	0xBD8D: 0xFFFD,
	0xBD8E: 0xFFFD,
	0xBD8F: 0xFFFD,
	0xBD90: 0xFFFD,
	0xBD91: 0xFFFD,
	0xBD92: 0xFFFD,
	0xBD93: 0xFFFD,
	0xBD94: 0xFFFD,
	0xBD95: 0xFFFD,
	0xBD96: 0xFFFD,
	0xBD97: 0xFFFD,
	0xBD98: 0xFFFD,
	0xBD99: 0xFFFD,
	0xBD9A: 0xFFFD,
	0xBD9B: 0xFFFD,
	0xBD9C: 0xFFFD,
	0xBD9D: 0xFFFD,
	0xBD9E: 0xFFFD,
	0xBD9F: 0xFFFD,
	0xBDA0: 0xFFFD,
	0xBDA1: 0xFFFD,
	0xBDA2: 0xFFFD,
	0xBDA3: 0xFFFD,
	0xBDA4: 0xFFFD,
	0xBDA5: 0xFFFD,
	0xBDA6: 0xFFFD,
	0xBDA7: 0xFFFD,
	0xBDA8: 0xFFFD,
	0xBDA9: 0xFFFD,
	0xBDAA: 0xFFFD,
	0xBDAB: 0xFFFD,
	0xBDAC: 0xFFFD,
	0xBDAD: 0xFFFD,
	0xBDAE: 0xFFFD,
	0xBDAF: 0xFFFD,
	0xBDB0: 0xFFFD,
	0xBDB1: 0xFFFD,
	0xBDB2: 0xFFFD,
	0xBDB3: 0xFFFD,
	0xBDB4: 0xFFFD,
	0xBDB5: 0xFFFD,
	0xBDB6: 0xFFFD,
	0xBDB7: 0xFFFD,
	0xBDB8: 0xFFFD,
	0xBDB9: 0xFFFD,
	0xBDBA: 0xFFFD,
	0xBDBB: 0xFFFD,
	0xBDBC: 0xFFFD,
	0xBDBD: 0xFFFD,
	0xBDBE: 0xFFFD,
	0xBDBF: 0xFFFD,
	0xBDC0: 0xFFFD,
	0xBDC1: 0xFFFD,
	0xBDC2: 0xFFFD,
	0xBDC3: 0xFFFD,
	0xBDC4: 0xFFFD,
	0xBDC5: 0xFFFD,
	0xBDC6: 0xFFFD,
	0xBDC7: 0xFFFD,
	0xBDC8: 0xFFFD,
	0xBDC9: 0xFFFD,
	0xBDCA: 0xFFFD,
	0xBDCB: 0xFFFD,
	0xBDCC: 0xFFFD,
	0xBDCD: 0xFFFD,
	0xBDCE: 0xFFFD,
	0xBDCF: 0xFFFD,
	0xBDD0: 0xFFFD,
	0xBDD1: 0xFFFD,
	0xBDD2: 0xFFFD,
	0xBDD3: 0xFFFD,
	0xBDD4: 0xFFFD,
	0xBDD5: 0xFFFD,
	0xBDD6: 0xFFFD,
	0xBDD7: 0xFFFD,
	0xBDD8: 0xFFFD,
	0xBDD9: 0xFFFD,
	0xBDDA: 0xFFFD,
	0xBDDB: 0xFFFD,
	0xBDDC: 0xFFFD,
	0xBDDD: 0xFFFD,
	0xBDDE: 0xFFFD,
	0xBDDF: 0xFFFD,
	0xBDE0: 0xFFFD,
	0xBDE1: 0xFFFD,
	0xBDE2: 0xFFFD,
	0xBDE3: 0xFFFD,
	0xBDE4: 0xFFFD,
	0xBDE5: 0xFFFD,
	0xBDE6: 0xFFFD,
	0xBDE7: 0xFFFD,
	0xBDE8: 0xFFFD,
	0xBDE9: 0xFFFD,
	0xBDEA: 0xFFFD,
	0xBDEB: 0xFFFD,
	0xBDEC: 0xFFFD,
	0xBDED: 0xFFFD,
	0xBDEE: 0xFFFD,
	0xBDEF: 0xFFFD,
	0xBDF0: 0xFFFD,
	0xBDF1: 0xFFFD,
	0xBDF2: 0xFFFD,
	0xBDF3: 0xFFFD,
	0xBDF4: 0xFFFD,
	0xBDF5: 0xFFFD,
	0xBDF6: 0xFFFD,
	0xBDF7: 0xFFFD,
	0xBDF8: 0xFFFD,
	0xBDF9: 0xFFFD,
	0xBDFA: 0xFFFD,
	0xBDFB: 0xFFFD,
	0xBDFC: 0xFFFD,
	0xBDFD: 0xFFFD,
	0xBDFE: 0xFFFD,
	0xBDFF: 0xFFFD,
	0xBE00: 0xFFFD,
	0xBE01: 0xFFFD,
	0xBE02: 0xFFFD,
	0xBE03: 0xFFFD,
	0xBE04: 0xFFFD,
	0xBE05: 0xFFFD,
	0xBE06: 0xFFFD,
	0xBE07: 0xFFFD,
	0xBE08: 0xFFFD,
	0xBE09: 0xFFFD,
	0xBE0A: 0xFFFD,
	0xBE0B: 0xFFFD,
	0xBE0C: 0xFFFD,
	0xBE0D: 0xFFFD,
	0xBE0E: 0xFFFD,
	0xBE0F: 0xFFFD,
	0xBE10: 0xFFFD,
	0xBE11: 0xFFFD,
	0xBE12: 0xFFFD,
	0xBE13: 0xFFFD,
	0xBE14: 0xFFFD,
	0xBE15: 0xFFFD,
	0xBE16: 0xFFFD,
	0xBE17: 0xFFFD,
	0xBE18: 0xFFFD,
	0xBE19: 0xFFFD,
	0xBE1A: 0xFFFD,
	0xBE1B: 0xFFFD,
	0xBE1C: 0xFFFD,
	0xBE1D: 0xFFFD,
	0xBE1E: 0xFFFD,
	0xBE1F: 0xFFFD,
	0xBE20: 0xFFFD,
	0xBE21: 0xFFFD,
	0xBE22: 0xFFFD,
	0xBE23: 0xFFFD,
	0xBE24: 0xFFFD,
	0xBE25: 0xFFFD,
	0xBE26: 0xFFFD,
	0xBE27: 0xFFFD,
	0xBE28: 0xFFFD,
	0xBE29: 0xFFFD,
	0xBE2A: 0xFFFD,
	0xBE2B: 0xFFFD,
	0xBE2C: 0xFFFD,
	0xBE2D: 0xFFFD,
	0xBE2E: 0xFFFD,
	0xBE2F: 0xFFFD,
	0xBE30: 0xFFFD,
	0xBE31: 0xFFFD,
	0xBE32: 0xFFFD,
	0xBE33: 0xFFFD,
	0xBE34: 0xFFFD,
	0xBE35: 0xFFFD,
	0xBE36: 0xFFFD,
	0xBE37: 0xFFFD,
	0xBE38: 0xFFFD,
	0xBE39: 0xFFFD,
	0xBE3A: 0xFFFD,
	0xBE3B: 0xFFFD,
	0xBE3C: 0xFFFD,
	0xBE3D: 0xFFFD,
	0xBE3E: 0xFFFD,
	0xBE3F: 0xFFFD,
	0xBE40: 0xFFFD,
	0xBE41: 0xFFFD,
	0xBE42: 0xFFFD,
	0xBE43: 0xFFFD,
	0xBE44: 0xFFFD,
	0xBE45: 0xFFFD,
	0xBE46: 0xFFFD,
	0xBE47: 0xFFFD,
	0xBE48: 0xFFFD,
	0xBE49: 0xFFFD,
	0xBE4A: 0xFFFD,
	0xBE4B: 0xFFFD,
	0xBE4C: 0xFFFD,
	0xBE4D: 0xFFFD,
	0xBE4E: 0xFFFD,
	0xBE4F: 0xFFFD,
	0xBE50: 0xFFFD,
	0xBE51: 0xFFFD,
	0xBE52: 0xFFFD,
	0xBE53: 0xFFFD,
	0xBE54: 0xFFFD,
	0xBE55: 0xFFFD,
	0xBE56: 0xFFFD,
	0xBE57: 0xFFFD,
	0xBE58: 0xFFFD,
	0xBE59: 0xFFFD,
	0xBE5A: 0xFFFD,
	0xBE5B: 0xFFFD,
	0xBE5C: 0xFFFD,
	0xBE5D: 0xFFFD,
	0xBE5E: 0xFFFD,
	0xBE5F: 0xFFFD,
	0xBE60: 0xFFFD,
	0xBE61: 0xFFFD,
	0xBE62: 0xFFFD,
	0xBE63: 0xFFFD,
	0xBE64: 0xFFFD,
	0xBE65: 0xFFFD,
	0xBE66: 0xFFFD,
	0xBE67: 0xFFFD,
	0xBE68: 0xFFFD,
	0xBE69: 0xFFFD,
	0xBE6A: 0xFFFD,
	0xBE6B: 0xFFFD,
	0xBE6C: 0xFFFD,
	0xBE6D: 0xFFFD,
	0xBE6E: 0xFFFD,
	0xBE6F: 0xFFFD,
	0xBE70: 0xFFFD,
	0xBE71: 0xFFFD,
	0xBE72: 0xFFFD,
	0xBE73: 0xFFFD,
	0xBE74: 0xFFFD,
	0xBE75: 0xFFFD,
	0xBE76: 0xFFFD,
	0xBE77: 0xFFFD,
	0xBE78: 0xFFFD,
	0xBE79: 0xFFFD,
	0xBE7A: 0xFFFD,
	0xBE7B: 0xFFFD,
	0xBE7C: 0xFFFD,
	0xBE7D: 0xFFFD,
	0xBE7E: 0xFFFD,
	0xBE7F: 0xFFFD,
	0xBE80: 0xFFFD,
	0xBE81: 0xFFFD,
	0xBE82: 0xFFFD,
	0xBE83: 0xFFFD,
	0xBE84: 0xFFFD,
	0xBE85: 0xFFFD,
	0xBE86: 0xFFFD,
	0xBE87: 0xFFFD,
	0xBE88: 0xFFFD,
	0xBE89: 0xFFFD,
	0xBE8A: 0xFFFD,
	0xBE8B: 0xFFFD,
	0xBE8C: 0xFFFD,
	0xBE8D: 0xFFFD,
	0xBE8E: 0xFFFD,
	0xBE8F: 0xFFFD,
	0xBE90: 0xFFFD,
	0xBE91: 0xFFFD,
	0xBE92: 0xFFFD,
	0xBE93: 0xFFFD,
	0xBE94: 0xFFFD,
	0xBE95: 0xFFFD,
	0xBE96: 0xFFFD,
	0xBE97: 0xFFFD,
	0xBE98: 0xFFFD,
	0xBE99: 0xFFFD,
	0xBE9A: 0xFFFD,
	0xBE9B: 0xFFFD,
	0xBE9C: 0xFFFD,
	0xBE9D: 0xFFFD,
	0xBE9E: 0xFFFD,
	0xBE9F: 0xFFFD,
	0xBEA0: 0xFFFD,
	0xBEA1: 0xFFFD,
	0xBEA2: 0xFFFD,
	0xBEA3: 0xFFFD,
	0xBEA4: 0xFFFD,
	0xBEA5: 0xFFFD,
	0xBEA6: 0xFFFD,
	0xBEA7: 0xFFFD,
	0xBEA8: 0xFFFD,
	0xBEA9: 0xFFFD,
	0xBEAA: 0xFFFD,
	0xBEAB: 0xFFFD,
	0xBEAC: 0xFFFD,
	0xBEAD: 0xFFFD,
	0xBEAE: 0xFFFD,
	0xBEAF: 0xFFFD,
	0xBEB0: 0xFFFD,
	0xBEB1: 0xFFFD,
	0xBEB2: 0xFFFD,
	0xBEB3: 0xFFFD,
	0xBEB4: 0xFFFD,
	0xBEB5: 0xFFFD,
	0xBEB6: 0xFFFD,
	0xBEB7: 0xFFFD,
	0xBEB8: 0xFFFD,
	0xBEB9: 0xFFFD,
	0xBEBA: 0xFFFD,
	0xBEBB: 0xFFFD,
	0xBEBC: 0xFFFD,
	0xBEBD: 0xFFFD,
	0xBEBE: 0xFFFD,
	0xBEBF: 0xFFFD,
	0xBEC0: 0xFFFD,
	0xBEC1: 0xFFFD,
	0xBEC2: 0xFFFD,
	0xBEC3: 0xFFFD,
	0xBEC4: 0xFFFD,
	0xBEC5: 0xFFFD,
	0xBEC6: 0xFFFD,
	0xBEC7: 0xFFFD,
	0xBEC8: 0xFFFD,
	0xBEC9: 0xFFFD,
	0xBECA: 0xFFFD,
	0xBECB: 0xFFFD,
	0xBECC: 0xFFFD,
	0xBECD: 0xFFFD,
	0xBECE: 0xFFFD,
	0xBECF: 0xFFFD,
	0xBED0: 0xFFFD,
	0xBED1: 0xFFFD,
	0xBED2: 0xFFFD,
	0xBED3: 0xFFFD,
	0xBED4: 0xFFFD,
	0xBED5: 0xFFFD,
	0xBED6: 0xFFFD,
	0xBED7: 0xFFFD,
	0xBED8: 0xFFFD,
	0xBED9: 0xFFFD,
	0xBEDA: 0xFFFD,
	0xBEDB: 0xFFFD,
	0xBEDC: 0xFFFD,
	0xBEDD: 0xFFFD,
	0xBEDE: 0xFFFD,
	0xBEDF: 0xFFFD,
	0xBEE0: 0xFFFD,
	0xBEE1: 0xFFFD,
	0xBEE2: 0xFFFD,
	0xBEE3: 0xFFFD,
	0xBEE4: 0xFFFD,
	0xBEE5: 0xFFFD,
	0xBEE6: 0xFFFD,
	0xBEE7: 0xFFFD,
	0xBEE8: 0xFFFD,
	0xBEE9: 0xFFFD,
	0xBEEA: 0xFFFD,
	0xBEEB: 0xFFFD,
	0xBEEC: 0xFFFD,
	0xBEED: 0xFFFD,
	0xBEEE: 0xFFFD,
	0xBEEF: 0xFFFD,
	0xBEF0: 0xFFFD,
	0xBEF1: 0xFFFD,
	0xBEF2: 0xFFFD,
	0xBEF3: 0xFFFD,
	0xBEF4: 0xFFFD,
	0xBEF5: 0xFFFD,
	0xBEF6: 0xFFFD,
	0xBEF7: 0xFFFD,
	0xBEF8: 0xFFFD,
	0xBEF9: 0xFFFD,
	0xBEFA: 0xFFFD,
	0xBEFB: 0xFFFD,
	0xBEFC: 0xFFFD,
	0xBEFD: 0xFFFD,
	0xBEFE: 0xFFFD,
	0xBEFF: 0xFFFD,
	0xBF00: 0xFFFD,
	0xBF01: 0xFFFD,
	0xBF02: 0xFFFD,
	0xBF03: 0xFFFD,
	0xBF04: 0xFFFD,
	0xBF05: 0xFFFD,
	0xBF06: 0xFFFD,
	0xBF07: 0xFFFD,
	0xBF08: 0xFFFD,
	0xBF09: 0xFFFD,
	0xBF0A: 0xFFFD,
	0xBF0B: 0xFFFD,
	0xBF0C: 0xFFFD,
	0xBF0D: 0xFFFD,
	0xBF0E: 0xFFFD,
	0xBF0F: 0xFFFD,
	0xBF10: 0xFFFD,
	0xBF11: 0xFFFD,
	0xBF12: 0xFFFD,
	0xBF13: 0xFFFD,
	0xBF14: 0xFFFD,
	0xBF15: 0xFFFD,
	0xBF16: 0xFFFD,
	0xBF17: 0xFFFD,
	0xBF18: 0xFFFD,
	0xBF19: 0xFFFD,
	0xBF1A: 0xFFFD,
	0xBF1B: 0xFFFD,
	0xBF1C: 0xFFFD,
	0xBF1D: 0xFFFD,
	0xBF1E: 0xFFFD,
	0xBF1F: 0xFFFD,
	0xBF20: 0xFFFD,
	0xBF21: 0xFFFD,
	0xBF22: 0xFFFD,
	0xBF23: 0xFFFD,
	0xBF24: 0xFFFD,
	0xBF25: 0xFFFD,
	0xBF26: 0xFFFD,
	0xBF27: 0xFFFD,
	0xBF28: 0xFFFD,
	0xBF29: 0xFFFD,
	0xBF2A: 0xFFFD,
	0xBF2B: 0xFFFD,
	0xBF2C: 0xFFFD,
	0xBF2D: 0xFFFD,
	0xBF2E: 0xFFFD,
	0xBF2F: 0xFFFD,
	0xBF30: 0xFFFD,
	0xBF31: 0xFFFD,
	0xBF32: 0xFFFD,
	0xBF33: 0xFFFD,
	0xBF34: 0xFFFD,
	0xBF35: 0xFFFD,
	0xBF36: 0xFFFD,
	0xBF37: 0xFFFD,
	0xBF38: 0xFFFD,
	0xBF39: 0xFFFD,
	0xBF3A: 0xFFFD,
	0xBF3B: 0xFFFD,
	0xBF3C: 0xFFFD,
	0xBF3D: 0xFFFD,
	0xBF3E: 0xFFFD,
	0xBF3F: 0xFFFD,
	0xBF40: 0xFFFD,
	0xBF41: 0xFFFD,
	0xBF42: 0xFFFD,
	0xBF43: 0xFFFD,
	0xBF44: 0xFFFD,
	0xBF45: 0xFFFD,
	0xBF46: 0xFFFD,
	0xBF47: 0xFFFD,
	0xBF48: 0xFFFD,
	0xBF49: 0xFFFD,
	0xBF4A: 0xFFFD,
	0xBF4B: 0xFFFD,
	0xBF4C: 0xFFFD,
	0xBF4D: 0xFFFD,
	0xBF4E: 0xFFFD,
	0xBF4F: 0xFFFD,
	0xBF50: 0xFFFD,
	0xBF51: 0xFFFD,
	0xBF52: 0xFFFD,
	0xBF53: 0xFFFD,
	0xBF54: 0xFFFD,
	0xBF55: 0xFFFD,
	0xBF56: 0xFFFD,
	0xBF57: 0xFFFD,
	0xBF58: 0xFFFD,
	0xBF59: 0xFFFD,
	0xBF5A: 0xFFFD,
	0xBF5B: 0xFFFD,
	0xBF5C: 0xFFFD,
	0xBF5D: 0xFFFD,
	0xBF5E: 0xFFFD,
	0xBF5F: 0xFFFD,
	0xBF60: 0xFFFD,
	0xBF61: 0xFFFD,
	0xBF62: 0xFFFD,
	0xBF63: 0xFFFD,
	0xBF64: 0xFFFD,
	0xBF65: 0xFFFD,
	0xBF66: 0xFFFD,
	0xBF67: 0xFFFD,
	0xBF68: 0xFFFD,
	0xBF69: 0xFFFD,
	0xBF6A: 0xFFFD,
	0xBF6B: 0xFFFD,
	0xBF6C: 0xFFFD,
	0xBF6D: 0xFFFD,
	0xBF6E: 0xFFFD,
	0xBF6F: 0xFFFD,
	0xBF70: 0xFFFD,
	0xBF71: 0xFFFD,
	0xBF72: 0xFFFD,
	0xBF73: 0xFFFD,
	0xBF74: 0xFFFD,
	0xBF75: 0xFFFD,
	0xBF76: 0xFFFD,
	0xBF77: 0xFFFD,
	0xBF78: 0xFFFD,
	0xBF79: 0xFFFD,
	0xBF7A: 0xFFFD,
	0xBF7B: 0xFFFD,
	0xBF7C: 0xFFFD,
	0xBF7D: 0xFFFD,
	0xBF7E: 0xFFFD,
	0xBF7F: 0xFFFD,
	0xBF80: 0xFFFD,
	0xBF81: 0xFFFD,
	0xBF82: 0xFFFD,
	0xBF83: 0xFFFD,
	0xBF84: 0xFFFD,
	0xBF85: 0xFFFD,
	0xBF86: 0xFFFD,
	0xBF87: 0xFFFD,
	0xBF88: 0xFFFD,
	0xBF89: 0xFFFD,
	0xBF8A: 0xFFFD,
	0xBF8B: 0xFFFD,
	0xBF8C: 0xFFFD,
	0xBF8D: 0xFFFD,
	0xBF8E: 0xFFFD,
	0xBF8F: 0xFFFD,
	0xBF90: 0xFFFD,
	0xBF91: 0xFFFD,
	0xBF92: 0xFFFD,
	0xBF93: 0xFFFD,
	0xBF94: 0xFFFD,
	0xBF95: 0xFFFD,
	0xBF96: 0xFFFD,
	0xBF97: 0xFFFD,
	0xBF98: 0xFFFD,
	0xBF99: 0xFFFD,
	0xBF9A: 0xFFFD,
	0xBF9B: 0xFFFD,
	0xBF9C: 0xFFFD,
	0xBF9D: 0xFFFD,
	0xBF9E: 0xFFFD,
	0xBF9F: 0xFFFD,
	0xBFA0: 0xFFFD,
	0xBFA1: 0xFFFD,
	0xBFA2: 0xFFFD,
	0xBFA3: 0xFFFD,
	0xBFA4: 0xFFFD,
	0xBFA5: 0xFFFD,
	0xBFA6: 0xFFFD,
	0xBFA7: 0xFFFD,
	0xBFA8: 0xFFFD,
	0xBFA9: 0xFFFD,
	0xBFAA: 0xFFFD,
	0xBFAB: 0xFFFD,
	0xBFAC: 0xFFFD,
	0xBFAD: 0xFFFD,
	0xBFAE: 0xFFFD,
	0xBFAF: 0xFFFD,
	0xBFB0: 0xFFFD,
	0xBFB1: 0xFFFD,
	0xBFB2: 0xFFFD,
	0xBFB3: 0xFFFD,
	0xBFB4: 0xFFFD,
	0xBFB5: 0xFFFD,
	0xBFB6: 0xFFFD,
	0xBFB7: 0xFFFD,
	0xBFB8: 0xFFFD,
	0xBFB9: 0xFFFD,
	0xBFBA: 0xFFFD,
	0xBFBB: 0xFFFD,
	0xBFBC: 0xFFFD,
	0xBFBD: 0xFFFD,
	0xBFBE: 0xFFFD,
	0xBFBF: 0xFFFD,
	0xBFC0: 0xFFFD,
	0xBFC1: 0xFFFD,
	0xBFC2: 0xFFFD,
	0xBFC3: 0xFFFD,
	0xBFC4: 0xFFFD,
	0xBFC5: 0xFFFD,
	0xBFC6: 0xFFFD,
	0xBFC7: 0xFFFD,
	0xBFC8: 0xFFFD,
	0xBFC9: 0xFFFD,
	0xBFCA: 0xFFFD,
	0xBFCB: 0xFFFD,
	0xBFCC: 0xFFFD,
	0xBFCD: 0xFFFD,
	0xBFCE: 0xFFFD,
	0xBFCF: 0xFFFD,
	0xBFD0: 0xFFFD,
	0xBFD1: 0xFFFD,
	0xBFD2: 0xFFFD,
	0xBFD3: 0xFFFD,
	0xBFD4: 0xFFFD,
	0xBFD5: 0xFFFD,
	0xBFD6: 0xFFFD,
	0xBFD7: 0xFFFD,
	0xBFD8: 0xFFFD,
	0xBFD9: 0xFFFD,
	0xBFDA: 0xFFFD,
	0xBFDB: 0xFFFD,
	0xBFDC: 0xFFFD,
	0xBFDD: 0xFFFD,
	0xBFDE: 0xFFFD,
	0xBFDF: 0xFFFD,
	0xBFE0: 0xFFFD,
	0xBFE1: 0xFFFD,
	0xBFE2: 0xFFFD,
	0xBFE3: 0xFFFD,
	0xBFE4: 0xFFFD,
	0xBFE5: 0xFFFD,
	0xBFE6: 0xFFFD,
	0xBFE7: 0xFFFD,
	0xBFE8: 0xFFFD,
	0xBFE9: 0xFFFD,
	0xBFEA: 0xFFFD,
	0xBFEB: 0xFFFD,
	0xBFEC: 0xFFFD,
	0xBFED: 0xFFFD,
	0xBFEE: 0xFFFD,
	0xBFEF: 0xFFFD,
	0xBFF0: 0xFFFD,
	0xBFF1: 0xFFFD,
	0xBFF2: 0xFFFD,
	0xBFF3: 0xFFFD,
	0xBFF4: 0xFFFD,
	0xBFF5: 0xFFFD,
	0xBFF6: 0xFFFD,
	0xBFF7: 0xFFFD,
	0xBFF8: 0xFFFD,
	0xBFF9: 0xFFFD,
	0xBFFA: 0xFFFD,
	0xBFFB: 0xFFFD,
	0xBFFC: 0xFFFD,
	0xBFFD: 0xFFFD,
	0xBFFE: 0xFFFD,
	0xBFFF: 0xFFFD,
	0xC000: 0xFFFD,
	0xC001: 0xFFFD,
	0xC002: 0xFFFD,
	0xC003: 0xFFFD,
	0xC004: 0xFFFD,
	0xC005: 0xFFFD,
	0xC006: 0xFFFD,
	0xC007: 0xFFFD,
	0xC008: 0xFFFD,
	0xC009: 0xFFFD,
	0xC00A: 0xFFFD,
	0xC00B: 0xFFFD,
	0xC00C: 0xFFFD,
	0xC00D: 0xFFFD,
	0xC00E: 0xFFFD,
	0xC00F: 0xFFFD,
	0xC010: 0xFFFD,
	0xC011: 0xFFFD,
	0xC012: 0xFFFD,
	0xC013: 0xFFFD,
	0xC014: 0xFFFD,
	0xC015: 0xFFFD,
	0xC016: 0xFFFD,
	0xC017: 0xFFFD,
	0xC018: 0xFFFD,
	0xC019: 0xFFFD,
	0xC01A: 0xFFFD,
	0xC01B: 0xFFFD,
	0xC01C: 0xFFFD,
	0xC01D: 0xFFFD,
	0xC01E: 0xFFFD,
	0xC01F: 0xFFFD,
	0xC020: 0xFFFD,
	0xC021: 0xFFFD,
	0xC022: 0xFFFD,
	0xC023: 0xFFFD,
	0xC024: 0xFFFD,
	0xC025: 0xFFFD,
	0xC026: 0xFFFD,
	0xC027: 0xFFFD,
	0xC028: 0xFFFD,
	0xC029: 0xFFFD,
	0xC02A: 0xFFFD,
	0xC02B: 0xFFFD,
	0xC02C: 0xFFFD,
	0xC02D: 0xFFFD,
	0xC02E: 0xFFFD,
	0xC02F: 0xFFFD,
	0xC030: 0xFFFD,
	0xC031: 0xFFFD,
	0xC032: 0xFFFD,
	0xC033: 0xFFFD,
	0xC034: 0xFFFD,
	0xC035: 0xFFFD,
	0xC036: 0xFFFD,
	0xC037: 0xFFFD,
	0xC038: 0xFFFD,
	0xC039: 0xFFFD,
	0xC03A: 0xFFFD,
	0xC03B: 0xFFFD,
	0xC03C: 0xFFFD,
	0xC03D: 0xFFFD,
	0xC03E: 0xFFFD,
	0xC03F: 0xFFFD,
	0xC040: 0xFFFD,
	0xC041: 0xFFFD,
	0xC042: 0xFFFD,
	0xC043: 0xFFFD,
	0xC044: 0xFFFD,
	0xC045: 0xFFFD,
	0xC046: 0xFFFD,
	0xC047: 0xFFFD,
	0xC048: 0xFFFD,
	0xC049: 0xFFFD,
	0xC04A: 0xFFFD,
	0xC04B: 0xFFFD,
	0xC04C: 0xFFFD,
	0xC04D: 0xFFFD,
	0xC04E: 0xFFFD,
	0xC04F: 0xFFFD,
	0xC050: 0xFFFD,
	0xC051: 0xFFFD,
	0xC052: 0xFFFD,
	0xC053: 0xFFFD,
	0xC054: 0xFFFD,
	0xC055: 0xFFFD,
	0xC056: 0xFFFD,
	0xC057: 0xFFFD,
	0xC058: 0xFFFD,
	0xC059: 0xFFFD,
	0xC05A: 0xFFFD,
	0xC05B: 0xFFFD,
	0xC05C: 0xFFFD,
	0xC05D: 0xFFFD,
	0xC05E: 0xFFFD,
	0xC05F: 0xFFFD,
	0xC060: 0xFFFD,
	0xC061: 0xFFFD,
	0xC062: 0xFFFD,
	0xC063: 0xFFFD,
	0xC064: 0xFFFD,
	0xC065: 0xFFFD,
	0xC066: 0xFFFD,
	0xC067: 0xFFFD,
	0xC068: 0xFFFD,
	0xC069: 0xFFFD,
	0xC06A: 0xFFFD,
	0xC06B: 0xFFFD,
	0xC06C: 0xFFFD,
	0xC06D: 0xFFFD,
	0xC06E: 0xFFFD,
	0xC06F: 0xFFFD,
	0xC070: 0xFFFD,
	0xC071: 0xFFFD,
	0xC072: 0xFFFD,
	0xC073: 0xFFFD,
	0xC074: 0xFFFD,
	0xC075: 0xFFFD,
	0xC076: 0xFFFD,
	0xC077: 0xFFFD,
	0xC078: 0xFFFD,
	0xC079: 0xFFFD,
	0xC07A: 0xFFFD,
	0xC07B: 0xFFFD,
	0xC07C: 0xFFFD,
	0xC07D: 0xFFFD,
	0xC07E: 0xFFFD,
	0xC07F: 0xFFFD,
	0xC080: 0xFFFD,
	0xC081: 0xFFFD,
	0xC082: 0xFFFD,
	0xC083: 0xFFFD,
	0xC084: 0xFFFD,
	0xC085: 0xFFFD,
	0xC086: 0xFFFD,
	0xC087: 0xFFFD,
	0xC088: 0xFFFD,
	0xC089: 0xFFFD,
	0xC08A: 0xFFFD,
	0xC08B: 0xFFFD,
	0xC08C: 0xFFFD,
	0xC08D: 0xFFFD,
	0xC08E: 0xFFFD,
	0xC08F: 0xFFFD,
	0xC090: 0xFFFD,
	0xC091: 0xFFFD,
	0xC092: 0xFFFD,
	0xC093: 0xFFFD,
	0xC094: 0xFFFD,
	0xC095: 0xFFFD,
	0xC096: 0xFFFD,
	0xC097: 0xFFFD,
	0xC098: 0xFFFD,
	0xC099: 0xFFFD,
	0xC09A: 0xFFFD,
	0xC09B: 0xFFFD,
	0xC09C: 0xFFFD,
	0xC09D: 0xFFFD,
	0xC09E: 0xFFFD,
	0xC09F: 0xFFFD,
	0xC0A0: 0xFFFD,
	0xC0A1: 0xFFFD,
	0xC0A2: 0xFFFD,
	0xC0A3: 0xFFFD,
	0xC0A4: 0xFFFD,
	0xC0A5: 0xFFFD,
	0xC0A6: 0xFFFD,
	0xC0A7: 0xFFFD,
	0xC0A8: 0xFFFD,
	0xC0A9: 0xFFFD,
	0xC0AA: 0xFFFD,
	0xC0AB: 0xFFFD,
	0xC0AC: 0xFFFD,
	0xC0AD: 0xFFFD,
	0xC0AE: 0xFFFD,
	0xC0AF: 0xFFFD,
	0xC0B0: 0xFFFD,
	0xC0B1: 0xFFFD,
	0xC0B2: 0xFFFD,
	0xC0B3: 0xFFFD,
	0xC0B4: 0xFFFD,
	0xC0B5: 0xFFFD,
	0xC0B6: 0xFFFD,
	0xC0B7: 0xFFFD,
	0xC0B8: 0xFFFD,
	0xC0B9: 0xFFFD,
	0xC0BA: 0xFFFD,
	0xC0BB: 0xFFFD,
	0xC0BC: 0xFFFD,
	0xC0BD: 0xFFFD,
	0xC0BE: 0xFFFD,
	0xC0BF: 0xFFFD,
	0xC0C0: 0xFFFD,
	0xC0C1: 0xFFFD,
	0xC0C2: 0xFFFD,
	0xC0C3: 0xFFFD,
	0xC0C4: 0xFFFD,
	0xC0C5: 0xFFFD,
	0xC0C6: 0xFFFD,
	0xC0C7: 0xFFFD,
	0xC0C8: 0xFFFD,
	0xC0C9: 0xFFFD,
	0xC0CA: 0xFFFD,
	0xC0CB: 0xFFFD,
	0xC0CC: 0xFFFD,
	0xC0CD: 0xFFFD,
	0xC0CE: 0xFFFD,
	0xC0CF: 0xFFFD,
	0xC0D0: 0xFFFD,
	0xC0D1: 0xFFFD,
	0xC0D2: 0xFFFD,
	0xC0D3: 0xFFFD,
	0xC0D4: 0xFFFD,
	0xC0D5: 0xFFFD,
	0xC0D6: 0xFFFD,
	0xC0D7: 0xFFFD,
	0xC0D8: 0xFFFD,
	0xC0D9: 0xFFFD,
	0xC0DA: 0xFFFD,
	0xC0DB: 0xFFFD,
	0xC0DC: 0xFFFD,
	0xC0DD: 0xFFFD,
	0xC0DE: 0xFFFD,
	0xC0DF: 0xFFFD,
	0xC0E0: 0xFFFD,
	0xC0E1: 0xFFFD,
	0xC0E2: 0xFFFD,
	0xC0E3: 0xFFFD,
	0xC0E4: 0xFFFD,
	0xC0E5: 0xFFFD,
	0xC0E6: 0xFFFD,
	0xC0E7: 0xFFFD,
	0xC0E8: 0xFFFD,
	0xC0E9: 0xFFFD,
	0xC0EA: 0xFFFD,
	0xC0EB: 0xFFFD,
	0xC0EC: 0xFFFD,
	0xC0ED: 0xFFFD,
	0xC0EE: 0xFFFD,
	0xC0EF: 0xFFFD,
	0xC0F0: 0xFFFD,
	0xC0F1: 0xFFFD,
	0xC0F2: 0xFFFD,
	0xC0F3: 0xFFFD,
	0xC0F4: 0xFFFD,
	0xC0F5: 0xFFFD,
	0xC0F6: 0xFFFD,
	0xC0F7: 0xFFFD,
	0xC0F8: 0xFFFD,
	0xC0F9: 0xFFFD,
	0xC0FA: 0xFFFD,
	0xC0FB: 0xFFFD,
	0xC0FC: 0xFFFD,
	0xC0FD: 0xFFFD,
	0xC0FE: 0xFFFD,
	0xC0FF: 0xFFFD,
	0xC100: 0xFFFD,
	0xC101: 0xFFFD,
	0xC102: 0xFFFD,
	0xC103: 0xFFFD,
	0xC104: 0xFFFD,
	0xC105: 0xFFFD,
	0xC106: 0xFFFD,
	0xC107: 0xFFFD,
	0xC108: 0xFFFD,
	0xC109: 0xFFFD,
	0xC10A: 0xFFFD,
	0xC10B: 0xFFFD,
	0xC10C: 0xFFFD,
	0xC10D: 0xFFFD,
	0xC10E: 0xFFFD,
	0xC10F: 0xFFFD,
	0xC110: 0xFFFD,
	0xC111: 0xFFFD,
	0xC112: 0xFFFD,
	0xC113: 0xFFFD,
	0xC114: 0xFFFD,
	0xC115: 0xFFFD,
	0xC116: 0xFFFD,
	0xC117: 0xFFFD,
	0xC118: 0xFFFD,
	0xC119: 0xFFFD,
	0xC11A: 0xFFFD,
	0xC11B: 0xFFFD,
	0xC11C: 0xFFFD,
	0xC11D: 0xFFFD,
	0xC11E: 0xFFFD,
	0xC11F: 0xFFFD,
	0xC120: 0xFFFD,
	0xC121: 0xFFFD,
	0xC122: 0xFFFD,
	0xC123: 0xFFFD,
	0xC124: 0xFFFD,
	0xC125: 0xFFFD,
	0xC126: 0xFFFD,
	0xC127: 0xFFFD,
	0xC128: 0xFFFD,
	0xC129: 0xFFFD,
	0xC12A: 0xFFFD,
	0xC12B: 0xFFFD,
	0xC12C: 0xFFFD,
	0xC12D: 0xFFFD,
	0xC12E: 0xFFFD,
	0xC12F: 0xFFFD,
	0xC130: 0xFFFD,
	0xC131: 0xFFFD,
	0xC132: 0xFFFD,
	0xC133: 0xFFFD,
	0xC134: 0xFFFD,
	0xC135: 0xFFFD,
	0xC136: 0xFFFD,
	0xC137: 0xFFFD,
	0xC138: 0xFFFD,
	0xC139: 0xFFFD,
	0xC13A: 0xFFFD,
	0xC13B: 0xFFFD,
	0xC13C: 0xFFFD,
	0xC13D: 0xFFFD,
	0xC13E: 0xFFFD,
	0xC13F: 0xFFFD,
	0xC140: 0xFFFD,
	0xC141: 0xFFFD,
	0xC142: 0xFFFD,
	0xC143: 0xFFFD,
	0xC144: 0xFFFD,
	0xC145: 0xFFFD,
	0xC146: 0xFFFD,
	0xC147: 0xFFFD,
	0xC148: 0xFFFD,
	0xC149: 0xFFFD,
	0xC14A: 0xFFFD,
	0xC14B: 0xFFFD,
	0xC14C: 0xFFFD,
	0xC14D: 0xFFFD,
	0xC14E: 0xFFFD,
	0xC14F: 0xFFFD,
	0xC150: 0xFFFD,
	0xC151: 0xFFFD,
	0xC152: 0xFFFD,
	0xC153: 0xFFFD,
	0xC154: 0xFFFD,
	0xC155: 0xFFFD,
	0xC156: 0xFFFD,
	0xC157: 0xFFFD,
	0xC158: 0xFFFD,
	0xC159: 0xFFFD,
	0xC15A: 0xFFFD,
	0xC15B: 0xFFFD,
	0xC15C: 0xFFFD,
	0xC15D: 0xFFFD,
	0xC15E: 0xFFFD,
	0xC15F: 0xFFFD,
	0xC160: 0xFFFD,
	0xC161: 0xFFFD,
	0xC162: 0xFFFD,
	0xC163: 0xFFFD,
	0xC164: 0xFFFD,
	0xC165: 0xFFFD,
	0xC166: 0xFFFD,
	0xC167: 0xFFFD,
	0xC168: 0xFFFD,
	0xC169: 0xFFFD,
	0xC16A: 0xFFFD,
	0xC16B: 0xFFFD,
	0xC16C: 0xFFFD,
	0xC16D: 0xFFFD,
	0xC16E: 0xFFFD,
	0xC16F: 0xFFFD,
	0xC170: 0xFFFD,
	0xC171: 0xFFFD,
	0xC172: 0xFFFD,
	0xC173: 0xFFFD,
	0xC174: 0xFFFD,
	0xC175: 0xFFFD,
	0xC176: 0xFFFD,
	0xC177: 0xFFFD,
	0xC178: 0xFFFD,
	0xC179: 0xFFFD,
	0xC17A: 0xFFFD,
	0xC17B: 0xFFFD,
	0xC17C: 0xFFFD,
	0xC17D: 0xFFFD,
	0xC17E: 0xFFFD,
	0xC17F: 0xFFFD,
	0xC180: 0xFFFD,
	0xC181: 0xFFFD,
	0xC182: 0xFFFD,
	0xC183: 0xFFFD,
	0xC184: 0xFFFD,
	0xC185: 0xFFFD,
	0xC186: 0xFFFD,
	0xC187: 0xFFFD,
	0xC188: 0xFFFD,
	0xC189: 0xFFFD,
	0xC18A: 0xFFFD,
	0xC18B: 0xFFFD,
	0xC18C: 0xFFFD,
	0xC18D: 0xFFFD,
	0xC18E: 0xFFFD,
	0xC18F: 0xFFFD,
	0xC190: 0xFFFD,
	0xC191: 0xFFFD,
	0xC192: 0xFFFD,
	0xC193: 0xFFFD,
	0xC194: 0xFFFD,
	0xC195: 0xFFFD,
	0xC196: 0xFFFD,
	0xC197: 0xFFFD,
	0xC198: 0xFFFD,
	0xC199: 0xFFFD,
	0xC19A: 0xFFFD,
	0xC19B: 0xFFFD,
	0xC19C: 0xFFFD,
	0xC19D: 0xFFFD,
	0xC19E: 0xFFFD,
	0xC19F: 0xFFFD,
	0xC1A0: 0xFFFD,
	0xC1A1: 0xFFFD,
	0xC1A2: 0xFFFD,
	0xC1A3: 0xFFFD,
	0xC1A4: 0xFFFD,
	0xC1A5: 0xFFFD,
	0xC1A6: 0xFFFD,
	0xC1A7: 0xFFFD,
	0xC1A8: 0xFFFD,
	0xC1A9: 0xFFFD,
	0xC1AA: 0xFFFD,
	0xC1AB: 0xFFFD,
	0xC1AC: 0xFFFD,
	0xC1AD: 0xFFFD,
	0xC1AE: 0xFFFD,
	0xC1AF: 0xFFFD,
	0xC1B0: 0xFFFD,
	0xC1B1: 0xFFFD,
	0xC1B2: 0xFFFD,
	0xC1B3: 0xFFFD,
	0xC1B4: 0xFFFD,
	0xC1B5: 0xFFFD,
	0xC1B6: 0xFFFD,
	0xC1B7: 0xFFFD,
	0xC1B8: 0xFFFD,
	0xC1B9: 0xFFFD,
	0xC1BA: 0xFFFD,
	0xC1BB: 0xFFFD,
	0xC1BC: 0xFFFD,
	0xC1BD: 0xFFFD,
	0xC1BE: 0xFFFD,
	0xC1BF: 0xFFFD,
	0xC1C0: 0xFFFD,
	0xC1C1: 0xFFFD,
	0xC1C2: 0xFFFD,
	0xC1C3: 0xFFFD,
	0xC1C4: 0xFFFD,
	0xC1C5: 0xFFFD,
	0xC1C6: 0xFFFD,
	0xC1C7: 0xFFFD,
	0xC1C8: 0xFFFD,
	0xC1C9: 0xFFFD,
	0xC1CA: 0xFFFD,
	0xC1CB: 0xFFFD,
	0xC1CC: 0xFFFD,
	0xC1CD: 0xFFFD,
	0xC1CE: 0xFFFD,
	0xC1CF: 0xFFFD,
	0xC1D0: 0xFFFD,
	0xC1D1: 0xFFFD,
	0xC1D2: 0xFFFD,
	0xC1D3: 0xFFFD,
	0xC1D4: 0xFFFD,
	0xC1D5: 0xFFFD,
	0xC1D6: 0xFFFD,
	0xC1D7: 0xFFFD,
	0xC1D8: 0xFFFD,
	0xC1D9: 0xFFFD,
	0xC1DA: 0xFFFD,
	0xC1DB: 0xFFFD,
	0xC1DC: 0xFFFD,
	0xC1DD: 0xFFFD,
	0xC1DE: 0xFFFD,
	0xC1DF: 0xFFFD,
	0xC1E0: 0xFFFD,
	0xC1E1: 0xFFFD,
	0xC1E2: 0xFFFD,
	0xC1E3: 0xFFFD,
	0xC1E4: 0xFFFD,
	0xC1E5: 0xFFFD,
	0xC1E6: 0xFFFD,
	0xC1E7: 0xFFFD,
	0xC1E8: 0xFFFD,
	0xC1E9: 0xFFFD,
	0xC1EA: 0xFFFD,
	0xC1EB: 0xFFFD,
	0xC1EC: 0xFFFD,
	0xC1ED: 0xFFFD,
	0xC1EE: 0xFFFD,
	0xC1EF: 0xFFFD,
	0xC1F0: 0xFFFD,
	0xC1F1: 0xFFFD,
	0xC1F2: 0xFFFD,
	0xC1F3: 0xFFFD,
	0xC1F4: 0xFFFD,
	0xC1F5: 0xFFFD,
	0xC1F6: 0xFFFD,
	0xC1F7: 0xFFFD,
	0xC1F8: 0xFFFD,
	0xC1F9: 0xFFFD,
	0xC1FA: 0xFFFD,
	0xC1FB: 0xFFFD,
	0xC1FC: 0xFFFD,
	0xC1FD: 0xFFFD,
	0xC1FE: 0xFFFD,
	0xC1FF: 0xFFFD,
	0xC200: 0xFFFD,
	0xC201: 0xFFFD,
	0xC202: 0xFFFD,
	0xC203: 0xFFFD,
	0xC204: 0xFFFD,
	0xC205: 0xFFFD,
	0xC206: 0xFFFD,
	0xC207: 0xFFFD,
	0xC208: 0xFFFD,
	0xC209: 0xFFFD,
	0xC20A: 0xFFFD,
	0xC20B: 0xFFFD,
	0xC20C: 0xFFFD,
	0xC20D: 0xFFFD,
	0xC20E: 0xFFFD,
	0xC20F: 0xFFFD,
	0xC210: 0xFFFD,
	0xC211: 0xFFFD,
	0xC212: 0xFFFD,
	0xC213: 0xFFFD,
	0xC214: 0xFFFD,
	0xC215: 0xFFFD,
	0xC216: 0xFFFD,
	0xC217: 0xFFFD,
	0xC218: 0xFFFD,
	0xC219: 0xFFFD,
	0xC21A: 0xFFFD,
	0xC21B: 0xFFFD,
	0xC21C: 0xFFFD,
	0xC21D: 0xFFFD,
	0xC21E: 0xFFFD,
	0xC21F: 0xFFFD,
	0xC220: 0xFFFD,
	0xC221: 0xFFFD,
	0xC222: 0xFFFD,
	0xC223: 0xFFFD,
	0xC224: 0xFFFD,
	0xC225: 0xFFFD,
	0xC226: 0xFFFD,
	0xC227: 0xFFFD,
	0xC228: 0xFFFD,
	0xC229: 0xFFFD,
	0xC22A: 0xFFFD,
	0xC22B: 0xFFFD,
	0xC22C: 0xFFFD,
	0xC22D: 0xFFFD,
	0xC22E: 0xFFFD,
	0xC22F: 0xFFFD,
	0xC230: 0xFFFD,
	0xC231: 0xFFFD,
	0xC232: 0xFFFD,
	0xC233: 0xFFFD,
	0xC234: 0xFFFD,
	0xC235: 0xFFFD,
	0xC236: 0xFFFD,
	0xC237: 0xFFFD,
	0xC238: 0xFFFD,
	0xC239: 0xFFFD,
	0xC23A: 0xFFFD,
	0xC23B: 0xFFFD,
	0xC23C: 0xFFFD,
	0xC23D: 0xFFFD,
	0xC23E: 0xFFFD,
	0xC23F: 0xFFFD,
	0xC240: 0xFFFD,
	0xC241: 0xFFFD,
	0xC242: 0xFFFD,
	0xC243: 0xFFFD,
	0xC244: 0xFFFD,
	0xC245: 0xFFFD,
	0xC246: 0xFFFD,
	0xC247: 0xFFFD,
	0xC248: 0xFFFD,
	0xC249: 0xFFFD,
	0xC24A: 0xFFFD,
	0xC24B: 0xFFFD,
	0xC24C: 0xFFFD,
	0xC24D: 0xFFFD,
	0xC24E: 0xFFFD,
	0xC24F: 0xFFFD,
	0xC250: 0xFFFD,
	0xC251: 0xFFFD,
	0xC252: 0xFFFD,
	0xC253: 0xFFFD,
	0xC254: 0xFFFD,
	0xC255: 0xFFFD,
	0xC256: 0xFFFD,
	0xC257: 0xFFFD,
	0xC258: 0xFFFD,
	0xC259: 0xFFFD,
	0xC25A: 0xFFFD,
	0xC25B: 0xFFFD,
	0xC25C: 0xFFFD,
	0xC25D: 0xFFFD,
	0xC25E: 0xFFFD,
	0xC25F: 0xFFFD,
	0xC260: 0xFFFD,
	0xC261: 0xFFFD,
	0xC262: 0xFFFD,
	0xC263: 0xFFFD,
	0xC264: 0xFFFD,
	0xC265: 0xFFFD,
	0xC266: 0xFFFD,
	0xC267: 0xFFFD,
	0xC268: 0xFFFD,
	0xC269: 0xFFFD,
	0xC26A: 0xFFFD,
	0xC26B: 0xFFFD,
	0xC26C: 0xFFFD,
	0xC26D: 0xFFFD,
	0xC26E: 0xFFFD,
	0xC26F: 0xFFFD,
	0xC270: 0xFFFD,
	0xC271: 0xFFFD,
	0xC272: 0xFFFD,
	0xC273: 0xFFFD,
	0xC274: 0xFFFD,
	0xC275: 0xFFFD,
	0xC276: 0xFFFD,
	0xC277: 0xFFFD,
	0xC278: 0xFFFD,
	0xC279: 0xFFFD,
	0xC27A: 0xFFFD,
	0xC27B: 0xFFFD,
	0xC27C: 0xFFFD,
	0xC27D: 0xFFFD,
	0xC27E: 0xFFFD,
	0xC27F: 0xFFFD,
	0xC280: 0xFFFD,
	0xC281: 0xFFFD,
	0xC282: 0xFFFD,
	0xC283: 0xFFFD,
	0xC284: 0xFFFD,
	0xC285: 0xFFFD,
	0xC286: 0xFFFD,
	0xC287: 0xFFFD,
	0xC288: 0xFFFD,
	0xC289: 0xFFFD,
	0xC28A: 0xFFFD,
	0xC28B: 0xFFFD,
	0xC28C: 0xFFFD,
	0xC28D: 0xFFFD,
	0xC28E: 0xFFFD,
	0xC28F: 0xFFFD,
	0xC290: 0xFFFD,
	0xC291: 0xFFFD,
	0xC292: 0xFFFD,
	0xC293: 0xFFFD,
	0xC294: 0xFFFD,
	0xC295: 0xFFFD,
	0xC296: 0xFFFD,
	0xC297: 0xFFFD,
	0xC298: 0xFFFD,
	0xC299: 0xFFFD,
	0xC29A: 0xFFFD,
	0xC29B: 0xFFFD,
	0xC29C: 0xFFFD,
	0xC29D: 0xFFFD,
	0xC29E: 0xFFFD,
	0xC29F: 0xFFFD,
	0xC2A0: 0xFFFD,
	0xC2A1: 0xFFFD,
	0xC2A2: 0xFFFD,
	0xC2A3: 0xFFFD,
	0xC2A4: 0xFFFD,
	0xC2A5: 0xFFFD,
	0xC2A6: 0xFFFD,
	0xC2A7: 0xFFFD,
	0xC2A8: 0xFFFD,
	0xC2A9: 0xFFFD,
	0xC2AA: 0xFFFD,
	0xC2AB: 0xFFFD,
	0xC2AC: 0xFFFD,
	0xC2AD: 0xFFFD,
	0xC2AE: 0xFFFD,
	0xC2AF: 0xFFFD,
	0xC2B0: 0xFFFD,
	0xC2B1: 0xFFFD,
	0xC2B2: 0xFFFD,
	0xC2B3: 0xFFFD,
	0xC2B4: 0xFFFD,
	0xC2B5: 0xFFFD,
	0xC2B6: 0xFFFD,
	0xC2B7: 0xFFFD,
	0xC2B8: 0xFFFD,
	0xC2B9: 0xFFFD,
	0xC2BA: 0xFFFD,
	0xC2BB: 0xFFFD,
	0xC2BC: 0xFFFD,
	0xC2BD: 0xFFFD,
	0xC2BE: 0xFFFD,
	0xC2BF: 0xFFFD,
	0xC2C0: 0xFFFD,
	0xC2C1: 0xFFFD,
	0xC2C2: 0xFFFD,
	0xC2C3: 0xFFFD,
	0xC2C4: 0xFFFD,
	0xC2C5: 0xFFFD,
	0xC2C6: 0xFFFD,
	0xC2C7: 0xFFFD,
	0xC2C8: 0xFFFD,
	0xC2C9: 0xFFFD,
	0xC2CA: 0xFFFD,
	0xC2CB: 0xFFFD,
	0xC2CC: 0xFFFD,
	0xC2CD: 0xFFFD,
	0xC2CE: 0xFFFD,
	0xC2CF: 0xFFFD,
	0xC2D0: 0xFFFD,
	0xC2D1: 0xFFFD,
	0xC2D2: 0xFFFD,
	0xC2D3: 0xFFFD,
	0xC2D4: 0xFFFD,
	0xC2D5: 0xFFFD,
	0xC2D6: 0xFFFD,
	0xC2D7: 0xFFFD,
	0xC2D8: 0xFFFD,
	0xC2D9: 0xFFFD,
	0xC2DA: 0xFFFD,
	0xC2DB: 0xFFFD,
	0xC2DC: 0xFFFD,
	0xC2DD: 0xFFFD,
	0xC2DE: 0xFFFD,
	0xC2DF: 0xFFFD,
	0xC2E0: 0xFFFD,
	0xC2E1: 0xFFFD,
	0xC2E2: 0xFFFD,
	0xC2E3: 0xFFFD,
	0xC2E4: 0xFFFD,
	0xC2E5: 0xFFFD,
	0xC2E6: 0xFFFD,
	0xC2E7: 0xFFFD,
	0xC2E8: 0xFFFD,
	0xC2E9: 0xFFFD,
	0xC2EA: 0xFFFD,
	0xC2EB: 0xFFFD,
	0xC2EC: 0xFFFD,
	0xC2ED: 0xFFFD,
	0xC2EE: 0xFFFD,
	0xC2EF: 0xFFFD,
	0xC2F0: 0xFFFD,
	0xC2F1: 0xFFFD,
	0xC2F2: 0xFFFD,
	0xC2F3: 0xFFFD,
	0xC2F4: 0xFFFD,
	0xC2F5: 0xFFFD,
	0xC2F6: 0xFFFD,
	0xC2F7: 0xFFFD,
	0xC2F8: 0xFFFD,
	0xC2F9: 0xFFFD,
	0xC2FA: 0xFFFD,
	0xC2FB: 0xFFFD,
	0xC2FC: 0xFFFD,
	0xC2FD: 0xFFFD,
	0xC2FE: 0xFFFD,
	0xC2FF: 0xFFFD,
	0xC300: 0xFFFD,
	0xC301: 0xFFFD,
	0xC302: 0xFFFD,
	0xC303: 0xFFFD,
	0xC304: 0xFFFD,
	0xC305: 0xFFFD,
	0xC306: 0xFFFD,
	0xC307: 0xFFFD,
	0xC308: 0xFFFD,
	0xC309: 0xFFFD,
	0xC30A: 0xFFFD,
	0xC30B: 0xFFFD,
	0xC30C: 0xFFFD,
	0xC30D: 0xFFFD,
	0xC30E: 0xFFFD,
	0xC30F: 0xFFFD,
	0xC310: 0xFFFD,
	0xC311: 0xFFFD,
	0xC312: 0xFFFD,
	0xC313: 0xFFFD,
	0xC314: 0xFFFD,
	0xC315: 0xFFFD,
	0xC316: 0xFFFD,
	0xC317: 0xFFFD,
	0xC318: 0xFFFD,
	0xC319: 0xFFFD,
	0xC31A: 0xFFFD,
	0xC31B: 0xFFFD,
	0xC31C: 0xFFFD,
	0xC31D: 0xFFFD,
	0xC31E: 0xFFFD,
	0xC31F: 0xFFFD,
	0xC320: 0xFFFD,
	0xC321: 0xFFFD,
	0xC322: 0xFFFD,
	0xC323: 0xFFFD,
	0xC324: 0xFFFD,
	0xC325: 0xFFFD,
	0xC326: 0xFFFD,
	0xC327: 0xFFFD,
	0xC328: 0xFFFD,
	0xC329: 0xFFFD,
	0xC32A: 0xFFFD,
	0xC32B: 0xFFFD,
	0xC32C: 0xFFFD,
	0xC32D: 0xFFFD,
	0xC32E: 0xFFFD,
	0xC32F: 0xFFFD,
	0xC330: 0xFFFD,
	0xC331: 0xFFFD,
	0xC332: 0xFFFD,
	0xC333: 0xFFFD,
	0xC334: 0xFFFD,
	0xC335: 0xFFFD,
	0xC336: 0xFFFD,
	0xC337: 0xFFFD,
	0xC338: 0xFFFD,
	0xC339: 0xFFFD,
	0xC33A: 0xFFFD,
	0xC33B: 0xFFFD,
	0xC33C: 0xFFFD,
	0xC33D: 0xFFFD,
	0xC33E: 0xFFFD,
	0xC33F: 0xFFFD,
	0xC340: 0xFFFD,
	0xC341: 0xFFFD,
	0xC342: 0xFFFD,
	0xC343: 0xFFFD,
	0xC344: 0xFFFD,
	0xC345: 0xFFFD,
	0xC346: 0xFFFD,
	0xC347: 0xFFFD,
	0xC348: 0xFFFD,
	0xC349: 0xFFFD,
	0xC34A: 0xFFFD,
	0xC34B: 0xFFFD,
	0xC34C: 0xFFFD,
	0xC34D: 0xFFFD,
	0xC34E: 0xFFFD,
	0xC34F: 0xFFFD,
	0xC350: 0xFFFD,
	0xC351: 0xFFFD,
	0xC352: 0xFFFD,
	0xC353: 0xFFFD,
	0xC354: 0xFFFD,
	0xC355: 0xFFFD,
	0xC356: 0xFFFD,
	0xC357: 0xFFFD,
	0xC358: 0xFFFD,
	0xC359: 0xFFFD,
	0xC35A: 0xFFFD,
	0xC35B: 0xFFFD,
	0xC35C: 0xFFFD,
	0xC35D: 0xFFFD,
	0xC35E: 0xFFFD,
	0xC35F: 0xFFFD,
	0xC360: 0xFFFD,
	0xC361: 0xFFFD,
	0xC362: 0xFFFD,
	0xC363: 0xFFFD,
	0xC364: 0xFFFD,
	0xC365: 0xFFFD,
	0xC366: 0xFFFD,
	0xC367: 0xFFFD,
	0xC368: 0xFFFD,
	0xC369: 0xFFFD,
	0xC36A: 0xFFFD,
	0xC36B: 0xFFFD,
	0xC36C: 0xFFFD,
	0xC36D: 0xFFFD,
	0xC36E: 0xFFFD,
	0xC36F: 0xFFFD,
	0xC370: 0xFFFD,
	0xC371: 0xFFFD,
	0xC372: 0xFFFD,
	0xC373: 0xFFFD,
	0xC374: 0xFFFD,
	0xC375: 0xFFFD,
	0xC376: 0xFFFD,
	0xC377: 0xFFFD,
	0xC378: 0xFFFD,
	0xC379: 0xFFFD,
	0xC37A: 0xFFFD,
	0xC37B: 0xFFFD,
	0xC37C: 0xFFFD,
	0xC37D: 0xFFFD,
	0xC37E: 0xFFFD,
	0xC37F: 0xFFFD,
	0xC380: 0xFFFD,
	0xC381: 0xFFFD,
	0xC382: 0xFFFD,
	0xC383: 0xFFFD,
	0xC384: 0xFFFD,
	0xC385: 0xFFFD,
	0xC386: 0xFFFD,
	0xC387: 0xFFFD,
	0xC388: 0xFFFD,
	0xC389: 0xFFFD,
	0xC38A: 0xFFFD,
	0xC38B: 0xFFFD,
	0xC38C: 0xFFFD,
	0xC38D: 0xFFFD,
	0xC38E: 0xFFFD,
	0xC38F: 0xFFFD,
	0xC390: 0xFFFD,
	0xC391: 0xFFFD,
	0xC392: 0xFFFD,
	0xC393: 0xFFFD,
	0xC394: 0xFFFD,
	0xC395: 0xFFFD,
	0xC396: 0xFFFD,
	0xC397: 0xFFFD,
	0xC398: 0xFFFD,
	0xC399: 0xFFFD,
	0xC39A: 0xFFFD,
	0xC39B: 0xFFFD,
	0xC39C: 0xFFFD,
	0xC39D: 0xFFFD,
	0xC39E: 0xFFFD,
	0xC39F: 0xFFFD,
	0xC3A0: 0xFFFD,
	0xC3A1: 0xFFFD,
	0xC3A2: 0xFFFD,
	0xC3A3: 0xFFFD,
	0xC3A4: 0xFFFD,
	0xC3A5: 0xFFFD,
	0xC3A6: 0xFFFD,
	0xC3A7: 0xFFFD,
	0xC3A8: 0xFFFD,
	0xC3A9: 0xFFFD,
	0xC3AA: 0xFFFD,
	0xC3AB: 0xFFFD,
	0xC3AC: 0xFFFD,
	0xC3AD: 0xFFFD,
	0xC3AE: 0xFFFD,
	0xC3AF: 0xFFFD,
	0xC3B0: 0xFFFD,
	0xC3B1: 0xFFFD,
	0xC3B2: 0xFFFD,
	0xC3B3: 0xFFFD,
	0xC3B4: 0xFFFD,
	0xC3B5: 0xFFFD,
	0xC3B6: 0xFFFD,
	0xC3B7: 0xFFFD,
	0xC3B8: 0xFFFD,
	0xC3B9: 0xFFFD,
	0xC3BA: 0xFFFD,
	0xC3BB: 0xFFFD,
	0xC3BC: 0xFFFD,
	0xC3BD: 0xFFFD,
	0xC3BE: 0xFFFD,
	0xC3BF: 0xFFFD,
	0xC3C0: 0xFFFD,
	0xC3C1: 0xFFFD,
	0xC3C2: 0xFFFD,
	0xC3C3: 0xFFFD,
	0xC3C4: 0xFFFD,
	0xC3C5: 0xFFFD,
	0xC3C6: 0xFFFD,
	0xC3C7: 0xFFFD,
	0xC3C8: 0xFFFD,
	0xC3C9: 0xFFFD,
	0xC3CA: 0xFFFD,
	0xC3CB: 0xFFFD,
	0xC3CC: 0xFFFD,
	0xC3CD: 0xFFFD,
	0xC3CE: 0xFFFD,
	0xC3CF: 0xFFFD,
	0xC3D0: 0xFFFD,
	0xC3D1: 0xFFFD,
	0xC3D2: 0xFFFD,
	0xC3D3: 0xFFFD,
	0xC3D4: 0xFFFD,
	0xC3D5: 0xFFFD,
	0xC3D6: 0xFFFD,
	0xC3D7: 0xFFFD,
	0xC3D8: 0xFFFD,
	0xC3D9: 0xFFFD,
	0xC3DA: 0xFFFD,
	0xC3DB: 0xFFFD,
	0xC3DC: 0xFFFD,
	0xC3DD: 0xFFFD,
	0xC3DE: 0xFFFD,
	0xC3DF: 0xFFFD,
	0xC3E0: 0xFFFD,
	0xC3E1: 0xFFFD,
	0xC3E2: 0xFFFD,
	0xC3E3: 0xFFFD,
	0xC3E4: 0xFFFD,
	0xC3E5: 0xFFFD,
	0xC3E6: 0xFFFD,
	0xC3E7: 0xFFFD,
	0xC3E8: 0xFFFD,
	0xC3E9: 0xFFFD,
	0xC3EA: 0xFFFD,
	0xC3EB: 0xFFFD,
	0xC3EC: 0xFFFD,
	0xC3ED: 0xFFFD,
	0xC3EE: 0xFFFD,
	0xC3EF: 0xFFFD,
	0xC3F0: 0xFFFD,
	0xC3F1: 0xFFFD,
	0xC3F2: 0xFFFD,
	0xC3F3: 0xFFFD,
	0xC3F4: 0xFFFD,
	0xC3F5: 0xFFFD,
	0xC3F6: 0xFFFD,
	0xC3F7: 0xFFFD,
	0xC3F8: 0xFFFD,
	0xC3F9: 0xFFFD,
	0xC3FA: 0xFFFD,
	0xC3FB: 0xFFFD,
	0xC3FC: 0xFFFD,
	0xC3FD: 0xFFFD,
	0xC3FE: 0xFFFD,
	0xC3FF: 0xFFFD,
	0xC400: 0xFFFD,
	0xC401: 0xFFFD,
	0xC402: 0xFFFD,
	0xC403: 0xFFFD,
	0xC404: 0xFFFD,
	0xC405: 0xFFFD,
	0xC406: 0xFFFD,
	0xC407: 0xFFFD,
	0xC408: 0xFFFD,
	0xC409: 0xFFFD,
	0xC40A: 0xFFFD,
	0xC40B: 0xFFFD,
	0xC40C: 0xFFFD,
	0xC40D: 0xFFFD,
	0xC40E: 0xFFFD,
	0xC40F: 0xFFFD,
	0xC410: 0xFFFD,
	0xC411: 0xFFFD,
	0xC412: 0xFFFD,
	0xC413: 0xFFFD,
	0xC414: 0xFFFD,
	0xC415: 0xFFFD,
	0xC416: 0xFFFD,
	0xC417: 0xFFFD,
	0xC418: 0xFFFD,
	0xC419: 0xFFFD,
	0xC41A: 0xFFFD,
	0xC41B: 0xFFFD,
	0xC41C: 0xFFFD,
	0xC41D: 0xFFFD,
	0xC41E: 0xFFFD,
	0xC41F: 0xFFFD,
	0xC420: 0xFFFD,
	0xC421: 0xFFFD,
	0xC422: 0xFFFD,
	0xC423: 0xFFFD,
	0xC424: 0xFFFD,
	0xC425: 0xFFFD,
	0xC426: 0xFFFD,
	0xC427: 0xFFFD,
	0xC428: 0xFFFD,
	0xC429: 0xFFFD,
	0xC42A: 0xFFFD,
	0xC42B: 0xFFFD,
	0xC42C: 0xFFFD,
	0xC42D: 0xFFFD,
	0xC42E: 0xFFFD,
	0xC42F: 0xFFFD,
	0xC430: 0xFFFD,
	0xC431: 0xFFFD,
	0xC432: 0xFFFD,
	0xC433: 0xFFFD,
	0xC434: 0xFFFD,
	0xC435: 0xFFFD,
	0xC436: 0xFFFD,
	0xC437: 0xFFFD,
	0xC438: 0xFFFD,
	0xC439: 0xFFFD,
	0xC43A: 0xFFFD,
	0xC43B: 0xFFFD,
	0xC43C: 0xFFFD,
	0xC43D: 0xFFFD,
	0xC43E: 0xFFFD,
	0xC43F: 0xFFFD,
	0xC440: 0xFFFD,
	0xC441: 0xFFFD,
	0xC442: 0xFFFD,
	0xC443: 0xFFFD,
	0xC444: 0xFFFD,
	0xC445: 0xFFFD,
	0xC446: 0xFFFD,
	0xC447: 0xFFFD,
	0xC448: 0xFFFD,
	0xC449: 0xFFFD,
	0xC44A: 0xFFFD,
	0xC44B: 0xFFFD,
	0xC44C: 0xFFFD,
	0xC44D: 0xFFFD,
	0xC44E: 0xFFFD,
	0xC44F: 0xFFFD,
	0xC450: 0xFFFD,
	0xC451: 0xFFFD,
	0xC452: 0xFFFD,
	0xC453: 0xFFFD,
	0xC454: 0xFFFD,
	0xC455: 0xFFFD,
	0xC456: 0xFFFD,
	0xC457: 0xFFFD,
	0xC458: 0xFFFD,
	0xC459: 0xFFFD,
	0xC45A: 0xFFFD,
	0xC45B: 0xFFFD,
	0xC45C: 0xFFFD,
	0xC45D: 0xFFFD,
	0xC45E: 0xFFFD,
	0xC45F: 0xFFFD,
	0xC460: 0xFFFD,
	0xC461: 0xFFFD,
	0xC462: 0xFFFD,
	0xC463: 0xFFFD,
	0xC464: 0xFFFD,
	0xC465: 0xFFFD,
	0xC466: 0xFFFD,
	0xC467: 0xFFFD,
	0xC468: 0xFFFD,
	0xC469: 0xFFFD,
	0xC46A: 0xFFFD,
	0xC46B: 0xFFFD,
	0xC46C: 0xFFFD,
	0xC46D: 0xFFFD,
	0xC46E: 0xFFFD,
	0xC46F: 0xFFFD,
	0xC470: 0xFFFD,
	0xC471: 0xFFFD,
	0xC472: 0xFFFD,
	0xC473: 0xFFFD,
	0xC474: 0xFFFD,
	0xC475: 0xFFFD,
	0xC476: 0xFFFD,
	0xC477: 0xFFFD,
	0xC478: 0xFFFD,
	0xC479: 0xFFFD,
	0xC47A: 0xFFFD,
	0xC47B: 0xFFFD,
	0xC47C: 0xFFFD,
	0xC47D: 0xFFFD,
	0xC47E: 0xFFFD,
	0xC47F: 0xFFFD,
	0xC480: 0xFFFD,
	0xC481: 0xFFFD,
	0xC482: 0xFFFD,
	0xC483: 0xFFFD,
	0xC484: 0xFFFD,
	0xC485: 0xFFFD,
	0xC486: 0xFFFD,
	0xC487: 0xFFFD,
	0xC488: 0xFFFD,
	0xC489: 0xFFFD,
	0xC48A: 0xFFFD,
	0xC48B: 0xFFFD,
	0xC48C: 0xFFFD,
	0xC48D: 0xFFFD,
	0xC48E: 0xFFFD,
	0xC48F: 0xFFFD,
	0xC490: 0xFFFD,
	0xC491: 0xFFFD,
	0xC492: 0xFFFD,
	0xC493: 0xFFFD,
	0xC494: 0xFFFD,
	0xC495: 0xFFFD,
	0xC496: 0xFFFD,
	0xC497: 0xFFFD,
	0xC498: 0xFFFD,
	0xC499: 0xFFFD,
	0xC49A: 0xFFFD,
	0xC49B: 0xFFFD,
	0xC49C: 0xFFFD,
	0xC49D: 0xFFFD,
	0xC49E: 0xFFFD,
	0xC49F: 0xFFFD,
	0xC4A0: 0xFFFD,
	0xC4A1: 0xFFFD,
	0xC4A2: 0xFFFD,
	0xC4A3: 0xFFFD,
	0xC4A4: 0xFFFD,
	0xC4A5: 0xFFFD,
	0xC4A6: 0xFFFD,
	0xC4A7: 0xFFFD,
	0xC4A8: 0xFFFD,
	0xC4A9: 0xFFFD,
	0xC4AA: 0xFFFD,
	0xC4AB: 0xFFFD,
	0xC4AC: 0xFFFD,
	0xC4AD: 0xFFFD,
	0xC4AE: 0xFFFD,
	0xC4AF: 0xFFFD,
	0xC4B0: 0xFFFD,
	0xC4B1: 0xFFFD,
	0xC4B2: 0xFFFD,
	0xC4B3: 0xFFFD,
	0xC4B4: 0xFFFD,
	0xC4B5: 0xFFFD,
	0xC4B6: 0xFFFD,
	0xC4B7: 0xFFFD,
	0xC4B8: 0xFFFD,
	0xC4B9: 0xFFFD,
	0xC4BA: 0xFFFD,
	0xC4BB: 0xFFFD,
	0xC4BC: 0xFFFD,
	0xC4BD: 0xFFFD,
	0xC4BE: 0xFFFD,
	0xC4BF: 0xFFFD,
	0xC4C0: 0xFFFD,
	0xC4C1: 0xFFFD,
	0xC4C2: 0xFFFD,
	0xC4C3: 0xFFFD,
	0xC4C4: 0xFFFD,
	0xC4C5: 0xFFFD,
	0xC4C6: 0xFFFD,
	0xC4C7: 0xFFFD,
	0xC4C8: 0xFFFD,
	0xC4C9: 0xFFFD,
	0xC4CA: 0xFFFD,
	0xC4CB: 0xFFFD,
	0xC4CC: 0xFFFD,
	0xC4CD: 0xFFFD,
	0xC4CE: 0xFFFD,
	0xC4CF: 0xFFFD,
	0xC4D0: 0xFFFD,
	0xC4D1: 0xFFFD,
	0xC4D2: 0xFFFD,
	0xC4D3: 0xFFFD,
	0xC4D4: 0xFFFD,
	0xC4D5: 0xFFFD,
	0xC4D6: 0xFFFD,
	0xC4D7: 0xFFFD,
	0xC4D8: 0xFFFD,
	0xC4D9: 0xFFFD,
	0xC4DA: 0xFFFD,
	0xC4DB: 0xFFFD,
	0xC4DC: 0xFFFD,
	0xC4DD: 0xFFFD,
	0xC4DE: 0xFFFD,
	0xC4DF: 0xFFFD,
	0xC4E0: 0xFFFD,
	0xC4E1: 0xFFFD,
	0xC4E2: 0xFFFD,
	0xC4E3: 0xFFFD,
	0xC4E4: 0xFFFD,
	0xC4E5: 0xFFFD,
	0xC4E6: 0xFFFD,
	0xC4E7: 0xFFFD,
	0xC4E8: 0xFFFD,
	0xC4E9: 0xFFFD,
	0xC4EA: 0xFFFD,
	0xC4EB: 0xFFFD,
	0xC4EC: 0xFFFD,
	0xC4ED: 0xFFFD,
	0xC4EE: 0xFFFD,
	0xC4EF: 0xFFFD,
	0xC4F0: 0xFFFD,
	0xC4F1: 0xFFFD,
	0xC4F2: 0xFFFD,
	0xC4F3: 0xFFFD,
	0xC4F4: 0xFFFD,
	0xC4F5: 0xFFFD,
	0xC4F6: 0xFFFD,
	0xC4F7: 0xFFFD,
	0xC4F8: 0xFFFD,
	0xC4F9: 0xFFFD,
	0xC4FA: 0xFFFD,
	0xC4FB: 0xFFFD,
	0xC4FC: 0xFFFD,
	0xC4FD: 0xFFFD,
	0xC4FE: 0xFFFD,
	0xC4FF: 0xFFFD,
	0xC500: 0xFFFD,
	0xC501: 0xFFFD,
	0xC502: 0xFFFD,
	0xC503: 0xFFFD,
	0xC504: 0xFFFD,
	0xC505: 0xFFFD,
	0xC506: 0xFFFD,
	0xC507: 0xFFFD,
	0xC508: 0xFFFD,
	0xC509: 0xFFFD,
	0xC50A: 0xFFFD,
	0xC50B: 0xFFFD,
	0xC50C: 0xFFFD,
	0xC50D: 0xFFFD,
	0xC50E: 0xFFFD,
	0xC50F: 0xFFFD,
	0xC510: 0xFFFD,
	0xC511: 0xFFFD,
	0xC512: 0xFFFD,
	0xC513: 0xFFFD,
	0xC514: 0xFFFD,
	0xC515: 0xFFFD,
	0xC516: 0xFFFD,
	0xC517: 0xFFFD,
	0xC518: 0xFFFD,
	0xC519: 0xFFFD,
	0xC51A: 0xFFFD,
	0xC51B: 0xFFFD,
	0xC51C: 0xFFFD,
	0xC51D: 0xFFFD,
	0xC51E: 0xFFFD,
	0xC51F: 0xFFFD,
	0xC520: 0xFFFD,
	0xC521: 0xFFFD,
	0xC522: 0xFFFD,
	0xC523: 0xFFFD,
	0xC524: 0xFFFD,
	0xC525: 0xFFFD,
	0xC526: 0xFFFD,
	0xC527: 0xFFFD,
	0xC528: 0xFFFD,
	0xC529: 0xFFFD,
	0xC52A: 0xFFFD,
	0xC52B: 0xFFFD,
	0xC52C: 0xFFFD,
	0xC52D: 0xFFFD,
	0xC52E: 0xFFFD,
	0xC52F: 0xFFFD,
	0xC530: 0xFFFD,
	0xC531: 0xFFFD,
	0xC532: 0xFFFD,
	0xC533: 0xFFFD,
	0xC534: 0xFFFD,
	0xC535: 0xFFFD,
	0xC536: 0xFFFD,
	0xC537: 0xFFFD,
	0xC538: 0xFFFD,
	0xC539: 0xFFFD,
	0xC53A: 0xFFFD,
	0xC53B: 0xFFFD,
	0xC53C: 0xFFFD,
	0xC53D: 0xFFFD,
	0xC53E: 0xFFFD,
	0xC53F: 0xFFFD,
	0xC540: 0xFFFD,
	0xC541: 0xFFFD,
	0xC542: 0xFFFD,
	0xC543: 0xFFFD,
	0xC544: 0xFFFD,
	0xC545: 0xFFFD,
	0xC546: 0xFFFD,
	0xC547: 0xFFFD,
	0xC548: 0xFFFD,
	0xC549: 0xFFFD,
	0xC54A: 0xFFFD,
	0xC54B: 0xFFFD,
	0xC54C: 0xFFFD,
	0xC54D: 0xFFFD,
	0xC54E: 0xFFFD,
	0xC54F: 0xFFFD,
	0xC550: 0xFFFD,
	0xC551: 0xFFFD,
	0xC552: 0xFFFD,
	0xC553: 0xFFFD,
	0xC554: 0xFFFD,
	0xC555: 0xFFFD,
	0xC556: 0xFFFD,
	0xC557: 0xFFFD,
	0xC558: 0xFFFD,
	0xC559: 0xFFFD,
	0xC55A: 0xFFFD,
	0xC55B: 0xFFFD,
	0xC55C: 0xFFFD,
	0xC55D: 0xFFFD,
	0xC55E: 0xFFFD,
	0xC55F: 0xFFFD,
	0xC560: 0xFFFD,
	0xC561: 0xFFFD,
	0xC562: 0xFFFD,
	0xC563: 0xFFFD,
	0xC564: 0xFFFD,
	0xC565: 0xFFFD,
	0xC566: 0xFFFD,
	0xC567: 0xFFFD,
	0xC568: 0xFFFD,
	0xC569: 0xFFFD,
	0xC56A: 0xFFFD,
	0xC56B: 0xFFFD,
	0xC56C: 0xFFFD,
	0xC56D: 0xFFFD,
	0xC56E: 0xFFFD,
	0xC56F: 0xFFFD,
	0xC570: 0xFFFD,
	0xC571: 0xFFFD,
	0xC572: 0xFFFD,
	0xC573: 0xFFFD,
	0xC574: 0xFFFD,
	0xC575: 0xFFFD,
	0xC576: 0xFFFD,
	0xC577: 0xFFFD,
	0xC578: 0xFFFD,
	0xC579: 0xFFFD,
	0xC57A: 0xFFFD,
	0xC57B: 0xFFFD,
	0xC57C: 0xFFFD,
	0xC57D: 0xFFFD,
	0xC57E: 0xFFFD,
	0xC57F: 0xFFFD,
	0xC580: 0xFFFD,
	0xC581: 0xFFFD,
	0xC582: 0xFFFD,
	0xC583: 0xFFFD,
	0xC584: 0xFFFD,
	0xC585: 0xFFFD,
	0xC586: 0xFFFD,
	0xC587: 0xFFFD,
	0xC588: 0xFFFD,
	0xC589: 0xFFFD,
	0xC58A: 0xFFFD,
	0xC58B: 0xFFFD,
	0xC58C: 0xFFFD,
	0xC58D: 0xFFFD,
	0xC58E: 0xFFFD,
	0xC58F: 0xFFFD,
	0xC590: 0xFFFD,
	0xC591: 0xFFFD,
	0xC592: 0xFFFD,
	0xC593: 0xFFFD,
	0xC594: 0xFFFD,
	0xC595: 0xFFFD,
	0xC596: 0xFFFD,
	0xC597: 0xFFFD,
	0xC598: 0xFFFD,
	0xC599: 0xFFFD,
	0xC59A: 0xFFFD,
	0xC59B: 0xFFFD,
	0xC59C: 0xFFFD,
	0xC59D: 0xFFFD,
	0xC59E: 0xFFFD,
	0xC59F: 0xFFFD,
	0xC5A0: 0xFFFD,
	0xC5A1: 0xFFFD,
	0xC5A2: 0xFFFD,
	0xC5A3: 0xFFFD,
	0xC5A4: 0xFFFD,
	0xC5A5: 0xFFFD,
	0xC5A6: 0xFFFD,
	0xC5A7: 0xFFFD,
	0xC5A8: 0xFFFD,
	0xC5A9: 0xFFFD,
	0xC5AA: 0xFFFD,
	0xC5AB: 0xFFFD,
	0xC5AC: 0xFFFD,
	0xC5AD: 0xFFFD,
	0xC5AE: 0xFFFD,
	0xC5AF: 0xFFFD,
	0xC5B0: 0xFFFD,
	0xC5B1: 0xFFFD,
	0xC5B2: 0xFFFD,
	0xC5B3: 0xFFFD,
	0xC5B4: 0xFFFD,
	0xC5B5: 0xFFFD,
	0xC5B6: 0xFFFD,
	0xC5B7: 0xFFFD,
	0xC5B8: 0xFFFD,
	0xC5B9: 0xFFFD,
	0xC5BA: 0xFFFD,
	0xC5BB: 0xFFFD,
	0xC5BC: 0xFFFD,
	0xC5BD: 0xFFFD,
	0xC5BE: 0xFFFD,
	0xC5BF: 0xFFFD,
	0xC5C0: 0xFFFD,
	0xC5C1: 0xFFFD,
	0xC5C2: 0xFFFD,
	0xC5C3: 0xFFFD,
	0xC5C4: 0xFFFD,
	0xC5C5: 0xFFFD,
	0xC5C6: 0xFFFD,
	0xC5C7: 0xFFFD,
	0xC5C8: 0xFFFD,
	0xC5C9: 0xFFFD,
	0xC5CA: 0xFFFD,
	0xC5CB: 0xFFFD,
	0xC5CC: 0xFFFD,
	0xC5CD: 0xFFFD,
	0xC5CE: 0xFFFD,
	0xC5CF: 0xFFFD,
	0xC5D0: 0xFFFD,
	0xC5D1: 0xFFFD,
	0xC5D2: 0xFFFD,
	0xC5D3: 0xFFFD,
	0xC5D4: 0xFFFD,
	0xC5D5: 0xFFFD,
	0xC5D6: 0xFFFD,
	0xC5D7: 0xFFFD,
	0xC5D8: 0xFFFD,
	0xC5D9: 0xFFFD,
	0xC5DA: 0xFFFD,
	0xC5DB: 0xFFFD,
	0xC5DC: 0xFFFD,
	0xC5DD: 0xFFFD,
	0xC5DE: 0xFFFD,
	0xC5DF: 0xFFFD,
	0xC5E0: 0xFFFD,
	0xC5E1: 0xFFFD,
	0xC5E2: 0xFFFD,
	0xC5E3: 0xFFFD,
	0xC5E4: 0xFFFD,
	0xC5E5: 0xFFFD,
	0xC5E6: 0xFFFD,
	0xC5E7: 0xFFFD,
	0xC5E8: 0xFFFD,
	0xC5E9: 0xFFFD,
	0xC5EA: 0xFFFD,
	0xC5EB: 0xFFFD,
	0xC5EC: 0xFFFD,
	0xC5ED: 0xFFFD,
	0xC5EE: 0xFFFD,
	0xC5EF: 0xFFFD,
	0xC5F0: 0xFFFD,
	0xC5F1: 0xFFFD,
	0xC5F2: 0xFFFD,
	0xC5F3: 0xFFFD,
	0xC5F4: 0xFFFD,
	0xC5F5: 0xFFFD,
	0xC5F6: 0xFFFD,
	0xC5F7: 0xFFFD,
	0xC5F8: 0xFFFD,
	0xC5F9: 0xFFFD,
	0xC5FA: 0xFFFD,
	0xC5FB: 0xFFFD,
	0xC5FC: 0xFFFD,
	0xC5FD: 0xFFFD,
	0xC5FE: 0xFFFD,
	0xC5FF: 0xFFFD,
	0xC600: 0xFFFD,
	0xC601: 0xFFFD,
	0xC602: 0xFFFD,
	0xC603: 0xFFFD,
	0xC604: 0xFFFD,
	0xC605: 0xFFFD,
	0xC606: 0xFFFD,
	0xC607: 0xFFFD,
	0xC608: 0xFFFD,
	0xC609: 0xFFFD,
	0xC60A: 0xFFFD,
	0xC60B: 0xFFFD,
	0xC60C: 0xFFFD,
	0xC60D: 0xFFFD,
	0xC60E: 0xFFFD,
	0xC60F: 0xFFFD,
	0xC610: 0xFFFD,
	0xC611: 0xFFFD,
	0xC612: 0xFFFD,
	0xC613: 0xFFFD,
	0xC614: 0xFFFD,
	0xC615: 0xFFFD,
	0xC616: 0xFFFD,
	0xC617: 0xFFFD,
	0xC618: 0xFFFD,
	0xC619: 0xFFFD,
	0xC61A: 0xFFFD,
	0xC61B: 0xFFFD,
	0xC61C: 0xFFFD,
	0xC61D: 0xFFFD,
	0xC61E: 0xFFFD,
	0xC61F: 0xFFFD,
	0xC620: 0xFFFD,
	0xC621: 0xFFFD,
	0xC622: 0xFFFD,
	0xC623: 0xFFFD,
	0xC624: 0xFFFD,
	0xC625: 0xFFFD,
	0xC626: 0xFFFD,
	0xC627: 0xFFFD,
	0xC628: 0xFFFD,
	0xC629: 0xFFFD,
	0xC62A: 0xFFFD,
	0xC62B: 0xFFFD,
	0xC62C: 0xFFFD,
	0xC62D: 0xFFFD,
	0xC62E: 0xFFFD,
	0xC62F: 0xFFFD,
	0xC630: 0xFFFD,
	0xC631: 0xFFFD,
	0xC632: 0xFFFD,
	0xC633: 0xFFFD,
	0xC634: 0xFFFD,
	0xC635: 0xFFFD,
	0xC636: 0xFFFD,
	0xC637: 0xFFFD,
	0xC638: 0xFFFD,
	0xC639: 0xFFFD,
	0xC63A: 0xFFFD,
	0xC63B: 0xFFFD,
	0xC63C: 0xFFFD,
	0xC63D: 0xFFFD,
	0xC63E: 0xFFFD,
	0xC63F: 0xFFFD,
	0xC640: 0xFFFD,
	0xC641: 0xFFFD,
	0xC642: 0xFFFD,
	0xC643: 0xFFFD,
	0xC644: 0xFFFD,
	0xC645: 0xFFFD,
	0xC646: 0xFFFD,
	0xC647: 0xFFFD,
	0xC648: 0xFFFD,
	0xC649: 0xFFFD,
	0xC64A: 0xFFFD,
	0xC64B: 0xFFFD,
	0xC64C: 0xFFFD,
	0xC64D: 0xFFFD,
	0xC64E: 0xFFFD,
	0xC64F: 0xFFFD,
	0xC650: 0xFFFD,
	0xC651: 0xFFFD,
	0xC652: 0xFFFD,
	0xC653: 0xFFFD,
	0xC654: 0xFFFD,
	0xC655: 0xFFFD,
	0xC656: 0xFFFD,
	0xC657: 0xFFFD,
	0xC658: 0xFFFD,
	0xC659: 0xFFFD,
	0xC65A: 0xFFFD,
	0xC65B: 0xFFFD,
	0xC65C: 0xFFFD,
	0xC65D: 0xFFFD,
	0xC65E: 0xFFFD,
	0xC65F: 0xFFFD,
	0xC660: 0xFFFD,
	0xC661: 0xFFFD,
	0xC662: 0xFFFD,
	0xC663: 0xFFFD,
	0xC664: 0xFFFD,
	0xC665: 0xFFFD,
	0xC666: 0xFFFD,
	0xC667: 0xFFFD,
	0xC668: 0xFFFD,
	0xC669: 0xFFFD,
	0xC66A: 0xFFFD,
	0xC66B: 0xFFFD,
	0xC66C: 0xFFFD,
	0xC66D: 0xFFFD,
	0xC66E: 0xFFFD,
	0xC66F: 0xFFFD,
	0xC670: 0xFFFD,
	0xC671: 0xFFFD,
	0xC672: 0xFFFD,
	0xC673: 0xFFFD,
	0xC674: 0xFFFD,
	0xC675: 0xFFFD,
	0xC676: 0xFFFD,
	0xC677: 0xFFFD,
	0xC678: 0xFFFD,
	0xC679: 0xFFFD,
	0xC67A: 0xFFFD,
	0xC67B: 0xFFFD,
	0xC67C: 0xFFFD,
	0xC67D: 0xFFFD,
	0xC67E: 0xFFFD,
	0xC67F: 0xFFFD,
	0xC680: 0xFFFD,
	0xC681: 0xFFFD,
	0xC682: 0xFFFD,
	0xC683: 0xFFFD,
	0xC684: 0xFFFD,
	0xC685: 0xFFFD,
	0xC686: 0xFFFD,
	0xC687: 0xFFFD,
	0xC688: 0xFFFD,
	0xC689: 0xFFFD,
	0xC68A: 0xFFFD,
	0xC68B: 0xFFFD,
	0xC68C: 0xFFFD,
	0xC68D: 0xFFFD,
	0xC68E: 0xFFFD,
	0xC68F: 0xFFFD,
	0xC690: 0xFFFD,
	0xC691: 0xFFFD,
	0xC692: 0xFFFD,
	0xC693: 0xFFFD,
	0xC694: 0xFFFD,
	0xC695: 0xFFFD,
	0xC696: 0xFFFD,
	0xC697: 0xFFFD,
	0xC698: 0xFFFD,
	0xC699: 0xFFFD,
	0xC69A: 0xFFFD,
	0xC69B: 0xFFFD,
	0xC69C: 0xFFFD,
	0xC69D: 0xFFFD,
	0xC69E: 0xFFFD,
	0xC69F: 0xFFFD,
	0xC6A0: 0xFFFD,
	0xC6A1: 0xFFFD,
	0xC6A2: 0xFFFD,
	0xC6A3: 0xFFFD,
	0xC6A4: 0xFFFD,
	0xC6A5: 0xFFFD,
	0xC6A6: 0xFFFD,
	0xC6A7: 0xFFFD,
	0xC6A8: 0xFFFD,
	0xC6A9: 0xFFFD,
	0xC6AA: 0xFFFD,
	0xC6AB: 0xFFFD,
	0xC6AC: 0xFFFD,
	0xC6AD: 0xFFFD,
	0xC6AE: 0xFFFD,
	0xC6AF: 0xFFFD,
	0xC6B0: 0xFFFD,
	0xC6B1: 0xFFFD,
	0xC6B2: 0xFFFD,
	0xC6B3: 0xFFFD,
	0xC6B4: 0xFFFD,
	0xC6B5: 0xFFFD,
	0xC6B6: 0xFFFD,
	0xC6B7: 0xFFFD,
	0xC6B8: 0xFFFD,
	0xC6B9: 0xFFFD,
	0xC6BA: 0xFFFD,
	0xC6BB: 0xFFFD,
	0xC6BC: 0xFFFD,
	0xC6BD: 0xFFFD,
	0xC6BE: 0xFFFD,
	0xC6BF: 0xFFFD,
	0xC6C0: 0xFFFD,
	0xC6C1: 0xFFFD,
	0xC6C2: 0xFFFD,
	0xC6C3: 0xFFFD,
	0xC6C4: 0xFFFD,
	0xC6C5: 0xFFFD,
	0xC6C6: 0xFFFD,
	0xC6C7: 0xFFFD,
	0xC6C8: 0xFFFD,
	0xC6C9: 0xFFFD,
	0xC6CA: 0xFFFD,
	0xC6CB: 0xFFFD,
	0xC6CC: 0xFFFD,
	0xC6CD: 0xFFFD,
	0xC6CE: 0xFFFD,
	0xC6CF: 0xFFFD,
	0xC6D0: 0xFFFD,
	0xC6D1: 0xFFFD,
	0xC6D2: 0xFFFD,
	0xC6D3: 0xFFFD,
	0xC6D4: 0xFFFD,
	0xC6D5: 0xFFFD,
	0xC6D6: 0xFFFD,
	0xC6D7: 0xFFFD,
	0xC6D8: 0xFFFD,
	0xC6D9: 0xFFFD,
	0xC6DA: 0xFFFD,
	0xC6DB: 0xFFFD,
	0xC6DC: 0xFFFD,
	0xC6DD: 0xFFFD,
	0xC6DE: 0xFFFD,
	0xC6DF: 0xFFFD,
	0xC6E0: 0xFFFD,
	0xC6E1: 0xFFFD,
	0xC6E2: 0xFFFD,
	0xC6E3: 0xFFFD,
	0xC6E4: 0xFFFD,
	0xC6E5: 0xFFFD,
	0xC6E6: 0xFFFD,
	0xC6E7: 0xFFFD,
	0xC6E8: 0xFFFD,
	0xC6E9: 0xFFFD,
	0xC6EA: 0xFFFD,
	0xC6EB: 0xFFFD,
	0xC6EC: 0xFFFD,
	0xC6ED: 0xFFFD,
	0xC6EE: 0xFFFD,
	0xC6EF: 0xFFFD,
	0xC6F0: 0xFFFD,
	0xC6F1: 0xFFFD,
	0xC6F2: 0xFFFD,
	0xC6F3: 0xFFFD,
	0xC6F4: 0xFFFD,
	0xC6F5: 0xFFFD,
	0xC6F6: 0xFFFD,
	0xC6F7: 0xFFFD,
	0xC6F8: 0xFFFD,
	0xC6F9: 0xFFFD,
	0xC6FA: 0xFFFD,
	0xC6FB: 0xFFFD,
	0xC6FC: 0xFFFD,
	0xC6FD: 0xFFFD,
	0xC6FE: 0xFFFD,
	0xC6FF: 0xFFFD,
	0xC700: 0xFFFD,
	0xC701: 0xFFFD,
	0xC702: 0xFFFD,
	0xC703: 0xFFFD,
	0xC704: 0xFFFD,
	0xC705: 0xFFFD,
	0xC706: 0xFFFD,
	0xC707: 0xFFFD,
	0xC708: 0xFFFD,
	0xC709: 0xFFFD,
	0xC70A: 0xFFFD,
	0xC70B: 0xFFFD,
	0xC70C: 0xFFFD,
	0xC70D: 0xFFFD,
	0xC70E: 0xFFFD,
	0xC70F: 0xFFFD,
	0xC710: 0xFFFD,
	0xC711: 0xFFFD,
	0xC712: 0xFFFD,
	0xC713: 0xFFFD,
	0xC714: 0xFFFD,
	0xC715: 0xFFFD,
	0xC716: 0xFFFD,
	0xC717: 0xFFFD,
	0xC718: 0xFFFD,
	0xC719: 0xFFFD,
	0xC71A: 0xFFFD,
	0xC71B: 0xFFFD,
	0xC71C: 0xFFFD,
	0xC71D: 0xFFFD,
	0xC71E: 0xFFFD,
	0xC71F: 0xFFFD,
	0xC720: 0xFFFD,
	0xC721: 0xFFFD,
	0xC722: 0xFFFD,
	0xC723: 0xFFFD,
	0xC724: 0xFFFD,
	0xC725: 0xFFFD,
	0xC726: 0xFFFD,
	0xC727: 0xFFFD,
	0xC728: 0xFFFD,
	0xC729: 0xFFFD,
	0xC72A: 0xFFFD,
	0xC72B: 0xFFFD,
	0xC72C: 0xFFFD,
	0xC72D: 0xFFFD,
	0xC72E: 0xFFFD,
	0xC72F: 0xFFFD,
	0xC730: 0xFFFD,
	0xC731: 0xFFFD,
	0xC732: 0xFFFD,
	0xC733: 0xFFFD,
	0xC734: 0xFFFD,
	0xC735: 0xFFFD,
	0xC736: 0xFFFD,
	0xC737: 0xFFFD,
	0xC738: 0xFFFD,
	0xC739: 0xFFFD,
	0xC73A: 0xFFFD,
	0xC73B: 0xFFFD,
	0xC73C: 0xFFFD,
	0xC73D: 0xFFFD,
	0xC73E: 0xFFFD,
	0xC73F: 0xFFFD,
	0xC740: 0xFFFD,
	0xC741: 0xFFFD,
	0xC742: 0xFFFD,
	0xC743: 0xFFFD,
	0xC744: 0xFFFD,
	0xC745: 0xFFFD,
	0xC746: 0xFFFD,
	0xC747: 0xFFFD,
	0xC748: 0xFFFD,
	0xC749: 0xFFFD,
	0xC74A: 0xFFFD,
	0xC74B: 0xFFFD,
	0xC74C: 0xFFFD,
	0xC74D: 0xFFFD,
	0xC74E: 0xFFFD,
	0xC74F: 0xFFFD,
	0xC750: 0xFFFD,
	0xC751: 0xFFFD,
	0xC752: 0xFFFD,
	0xC753: 0xFFFD,
	0xC754: 0xFFFD,
	0xC755: 0xFFFD,
	0xC756: 0xFFFD,
	0xC757: 0xFFFD,
	0xC758: 0xFFFD,
	0xC759: 0xFFFD,
	0xC75A: 0xFFFD,
	0xC75B: 0xFFFD,
	0xC75C: 0xFFFD,
	0xC75D: 0xFFFD,
	0xC75E: 0xFFFD,
	0xC75F: 0xFFFD,
	0xC760: 0xFFFD,
	0xC761: 0xFFFD,
	0xC762: 0xFFFD,
	0xC763: 0xFFFD,
	0xC764: 0xFFFD,
	0xC765: 0xFFFD,
	0xC766: 0xFFFD,
	0xC767: 0xFFFD,
	0xC768: 0xFFFD,
	0xC769: 0xFFFD,
	0xC76A: 0xFFFD,
	0xC76B: 0xFFFD,
	0xC76C: 0xFFFD,
	0xC76D: 0xFFFD,
	0xC76E: 0xFFFD,
	0xC76F: 0xFFFD,
	0xC770: 0xFFFD,
	0xC771: 0xFFFD,
	0xC772: 0xFFFD,
	0xC773: 0xFFFD,
	0xC774: 0xFFFD,
	0xC775: 0xFFFD,
	0xC776: 0xFFFD,
	0xC777: 0xFFFD,
	0xC778: 0xFFFD,
	0xC779: 0xFFFD,
	0xC77A: 0xFFFD,
	0xC77B: 0xFFFD,
	0xC77C: 0xFFFD,
	0xC77D: 0xFFFD,
	0xC77E: 0xFFFD,
	0xC77F: 0xFFFD,
	0xC780: 0xFFFD,
	0xC781: 0xFFFD,
	0xC782: 0xFFFD,
	0xC783: 0xFFFD,
	0xC784: 0xFFFD,
	0xC785: 0xFFFD,
	0xC786: 0xFFFD,
	0xC787: 0xFFFD,
	0xC788: 0xFFFD,
	0xC789: 0xFFFD,
	0xC78A: 0xFFFD,
	0xC78B: 0xFFFD,
	0xC78C: 0xFFFD,
	0xC78D: 0xFFFD,
	0xC78E: 0xFFFD,
	0xC78F: 0xFFFD,
	0xC790: 0xFFFD,
	0xC791: 0xFFFD,
	0xC792: 0xFFFD,
	0xC793: 0xFFFD,
	0xC794: 0xFFFD,
	0xC795: 0xFFFD,
	0xC796: 0xFFFD,
	0xC797: 0xFFFD,
	0xC798: 0xFFFD,
	0xC799: 0xFFFD,
	0xC79A: 0xFFFD,
	0xC79B: 0xFFFD,
	0xC79C: 0xFFFD,
	0xC79D: 0xFFFD,
	0xC79E: 0xFFFD,
	0xC79F: 0xFFFD,
	0xC7A0: 0xFFFD,
	0xC7A1: 0xFFFD,
	0xC7A2: 0xFFFD,
	0xC7A3: 0xFFFD,
	0xC7A4: 0xFFFD,
	0xC7A5: 0xFFFD,
	0xC7A6: 0xFFFD,
	0xC7A7: 0xFFFD,
	0xC7A8: 0xFFFD,
	0xC7A9: 0xFFFD,
	0xC7AA: 0xFFFD,
	0xC7AB: 0xFFFD,
	0xC7AC: 0xFFFD,
	0xC7AD: 0xFFFD,
	0xC7AE: 0xFFFD,
	0xC7AF: 0xFFFD,
	0xC7B0: 0xFFFD,
	0xC7B1: 0xFFFD,
	0xC7B2: 0xFFFD,
	0xC7B3: 0xFFFD,
	0xC7B4: 0xFFFD,
	0xC7B5: 0xFFFD,
	0xC7B6: 0xFFFD,
	0xC7B7: 0xFFFD,
	0xC7B8: 0xFFFD,
	0xC7B9: 0xFFFD,
	0xC7BA: 0xFFFD,
	0xC7BB: 0xFFFD,
	0xC7BC: 0xFFFD,
	0xC7BD: 0xFFFD,
	0xC7BE: 0xFFFD,
	0xC7BF: 0xFFFD,
	0xC7C0: 0xFFFD,
	0xC7C1: 0xFFFD,
	0xC7C2: 0xFFFD,
	0xC7C3: 0xFFFD,
	0xC7C4: 0xFFFD,
	0xC7C5: 0xFFFD,
	0xC7C6: 0xFFFD,
	0xC7C7: 0xFFFD,
	0xC7C8: 0xFFFD,
	0xC7C9: 0xFFFD,
	0xC7CA: 0xFFFD,
	0xC7CB: 0xFFFD,
	0xC7CC: 0xFFFD,
	0xC7CD: 0xFFFD,
	0xC7CE: 0xFFFD,
	0xC7CF: 0xFFFD,
	0xC7D0: 0xFFFD,
	0xC7D1: 0xFFFD,
	0xC7D2: 0xFFFD,
	0xC7D3: 0xFFFD,
	0xC7D4: 0xFFFD,
	0xC7D5: 0xFFFD,
	0xC7D6: 0xFFFD,
	0xC7D7: 0xFFFD,
	0xC7D8: 0xFFFD,
	0xC7D9: 0xFFFD,
	0xC7DA: 0xFFFD,
	0xC7DB: 0xFFFD,
	0xC7DC: 0xFFFD,
	0xC7DD: 0xFFFD,
	0xC7DE: 0xFFFD,
	0xC7DF: 0xFFFD,
	0xC7E0: 0xFFFD,
	0xC7E1: 0xFFFD,
	0xC7E2: 0xFFFD,
	0xC7E3: 0xFFFD,
	0xC7E4: 0xFFFD,
	0xC7E5: 0xFFFD,
	0xC7E6: 0xFFFD,
	0xC7E7: 0xFFFD,
	0xC7E8: 0xFFFD,
	0xC7E9: 0xFFFD,
	0xC7EA: 0xFFFD,
	0xC7EB: 0xFFFD,
	0xC7EC: 0xFFFD,
	0xC7ED: 0xFFFD,
	0xC7EE: 0xFFFD,
	0xC7EF: 0xFFFD,
	0xC7F0: 0xFFFD,
	0xC7F1: 0xFFFD,
	0xC7F2: 0xFFFD,
	0xC7F3: 0xFFFD,
	0xC7F4: 0xFFFD,
	0xC7F5: 0xFFFD,
	0xC7F6: 0xFFFD,
	0xC7F7: 0xFFFD,
	0xC7F8: 0xFFFD,
	0xC7F9: 0xFFFD,
	0xC7FA: 0xFFFD,
	0xC7FB: 0xFFFD,
	0xC7FC: 0xFFFD,
	0xC7FD: 0xFFFD,
	0xC7FE: 0xFFFD,
	0xC7FF: 0xFFFD,
	0xC800: 0xFFFD,
	0xC801: 0xFFFD,
	0xC802: 0xFFFD,
	0xC803: 0xFFFD,
	0xC804: 0xFFFD,
	0xC805: 0xFFFD,
	0xC806: 0xFFFD,
	0xC807: 0xFFFD,
	0xC808: 0xFFFD,
	0xC809: 0xFFFD,
	0xC80A: 0xFFFD,
	0xC80B: 0xFFFD,
	0xC80C: 0xFFFD,
	0xC80D: 0xFFFD,
	0xC80E: 0xFFFD,
	0xC80F: 0xFFFD,
	0xC810: 0xFFFD,
	0xC811: 0xFFFD,
	0xC812: 0xFFFD,
	0xC813: 0xFFFD,
	0xC814: 0xFFFD,
	0xC815: 0xFFFD,
	0xC816: 0xFFFD,
	0xC817: 0xFFFD,
	0xC818: 0xFFFD,
	0xC819: 0xFFFD,
	0xC81A: 0xFFFD,
	0xC81B: 0xFFFD,
	0xC81C: 0xFFFD,
	0xC81D: 0xFFFD,
	0xC81E: 0xFFFD,
	0xC81F: 0xFFFD,
	0xC820: 0xFFFD,
	0xC821: 0xFFFD,
	0xC822: 0xFFFD,
	0xC823: 0xFFFD,
	0xC824: 0xFFFD,
	0xC825: 0xFFFD,
	0xC826: 0xFFFD,
	0xC827: 0xFFFD,
	0xC828: 0xFFFD,
	0xC829: 0xFFFD,
	0xC82A: 0xFFFD,
	0xC82B: 0xFFFD,
	0xC82C: 0xFFFD,
	0xC82D: 0xFFFD,
	0xC82E: 0xFFFD,
	0xC82F: 0xFFFD,
	0xC830: 0xFFFD,
	0xC831: 0xFFFD,
	0xC832: 0xFFFD,
	0xC833: 0xFFFD,
	0xC834: 0xFFFD,
	0xC835: 0xFFFD,
	0xC836: 0xFFFD,
	0xC837: 0xFFFD,
	0xC838: 0xFFFD,
	0xC839: 0xFFFD,
	0xC83A: 0xFFFD,
	0xC83B: 0xFFFD,
	0xC83C: 0xFFFD,
	0xC83D: 0xFFFD,
	0xC83E: 0xFFFD,
	0xC83F: 0xFFFD,
	0xC840: 0xFFFD,
	0xC841: 0xFFFD,
	0xC842: 0xFFFD,
	0xC843: 0xFFFD,
	0xC844: 0xFFFD,
	0xC845: 0xFFFD,
	0xC846: 0xFFFD,
	0xC847: 0xFFFD,
	0xC848: 0xFFFD,
	0xC849: 0xFFFD,
	0xC84A: 0xFFFD,
	0xC84B: 0xFFFD,
	0xC84C: 0xFFFD,
	0xC84D: 0xFFFD,
	0xC84E: 0xFFFD,
	0xC84F: 0xFFFD,
	0xC850: 0xFFFD,
	0xC851: 0xFFFD,
	0xC852: 0xFFFD,
	0xC853: 0xFFFD,
	0xC854: 0xFFFD,
	0xC855: 0xFFFD,
	0xC856: 0xFFFD,
	0xC857: 0xFFFD,
	0xC858: 0xFFFD,
	0xC859: 0xFFFD,
	0xC85A: 0xFFFD,
	0xC85B: 0xFFFD,
	0xC85C: 0xFFFD,
	0xC85D: 0xFFFD,
	0xC85E: 0xFFFD,
	0xC85F: 0xFFFD,
	0xC860: 0xFFFD,
	0xC861: 0xFFFD,
	0xC862: 0xFFFD,
	0xC863: 0xFFFD,
	0xC864: 0xFFFD,
	0xC865: 0xFFFD,
	0xC866: 0xFFFD,
	0xC867: 0xFFFD,
	0xC868: 0xFFFD,
	0xC869: 0xFFFD,
	0xC86A: 0xFFFD,
	0xC86B: 0xFFFD,
	0xC86C: 0xFFFD,
	0xC86D: 0xFFFD,
	0xC86E: 0xFFFD,
	0xC86F: 0xFFFD,
	0xC870: 0xFFFD,
	0xC871: 0xFFFD,
	0xC872: 0xFFFD,
	0xC873: 0xFFFD,
	0xC874: 0xFFFD,
	0xC875: 0xFFFD,
	0xC876: 0xFFFD,
	0xC877: 0xFFFD,
	0xC878: 0xFFFD,
	0xC879: 0xFFFD,
	0xC87A: 0xFFFD,
	0xC87B: 0xFFFD,
	0xC87C: 0xFFFD,
	0xC87D: 0xFFFD,
	0xC87E: 0xFFFD,
	0xC87F: 0xFFFD,
	0xC880: 0xFFFD,
	0xC881: 0xFFFD,
	0xC882: 0xFFFD,
	0xC883: 0xFFFD,
	0xC884: 0xFFFD,
	0xC885: 0xFFFD,
	0xC886: 0xFFFD,
	0xC887: 0xFFFD,
	0xC888: 0xFFFD,
	0xC889: 0xFFFD,
	0xC88A: 0xFFFD,
	0xC88B: 0xFFFD,
	0xC88C: 0xFFFD,
	0xC88D: 0xFFFD,
	0xC88E: 0xFFFD,
	0xC88F: 0xFFFD,
	0xC890: 0xFFFD,
	0xC891: 0xFFFD,
	0xC892: 0xFFFD,
	0xC893: 0xFFFD,
	0xC894: 0xFFFD,
	0xC895: 0xFFFD,
	0xC896: 0xFFFD,
	0xC897: 0xFFFD,
	0xC898: 0xFFFD,
	0xC899: 0xFFFD,
	0xC89A: 0xFFFD,
	0xC89B: 0xFFFD,
	0xC89C: 0xFFFD,
	0xC89D: 0xFFFD,
	0xC89E: 0xFFFD,
	0xC89F: 0xFFFD,
	0xC8A0: 0xFFFD,
	0xC8A1: 0xFFFD,
	0xC8A2: 0xFFFD,
	0xC8A3: 0xFFFD,
	0xC8A4: 0xFFFD,
	0xC8A5: 0xFFFD,
	0xC8A6: 0xFFFD,
	0xC8A7: 0xFFFD,
	0xC8A8: 0xFFFD,
	0xC8A9: 0xFFFD,
	0xC8AA: 0xFFFD,
	0xC8AB: 0xFFFD,
	0xC8AC: 0xFFFD,
	0xC8AD: 0xFFFD,
	0xC8AE: 0xFFFD,
	0xC8AF: 0xFFFD,
	0xC8B0: 0xFFFD,
	0xC8B1: 0xFFFD,
	0xC8B2: 0xFFFD,
	0xC8B3: 0xFFFD,
	0xC8B4: 0xFFFD,
	0xC8B5: 0xFFFD,
	0xC8B6: 0xFFFD,
	0xC8B7: 0xFFFD,
	0xC8B8: 0xFFFD,
	0xC8B9: 0xFFFD,
	0xC8BA: 0xFFFD,
	0xC8BB: 0xFFFD,
	0xC8BC: 0xFFFD,
	0xC8BD: 0xFFFD,
	0xC8BE: 0xFFFD,
	0xC8BF: 0xFFFD,
	0xC8C0: 0xFFFD,
	0xC8C1: 0xFFFD,
	0xC8C2: 0xFFFD,
	0xC8C3: 0xFFFD,
	0xC8C4: 0xFFFD,
	0xC8C5: 0xFFFD,
	0xC8C6: 0xFFFD,
	0xC8C7: 0xFFFD,
	0xC8C8: 0xFFFD,
	0xC8C9: 0xFFFD,
	0xC8CA: 0xFFFD,
	0xC8CB: 0xFFFD,
	0xC8CC: 0xFFFD,
	0xC8CD: 0xFFFD,
	0xC8CE: 0xFFFD,
	0xC8CF: 0xFFFD,
	0xC8D0: 0xFFFD,
	0xC8D1: 0xFFFD,
	0xC8D2: 0xFFFD,
	0xC8D3: 0xFFFD,
	0xC8D4: 0xFFFD,
	0xC8D5: 0xFFFD,
	0xC8D6: 0xFFFD,
	0xC8D7: 0xFFFD,
	0xC8D8: 0xFFFD,
	0xC8D9: 0xFFFD,
	0xC8DA: 0xFFFD,
	0xC8DB: 0xFFFD,
	0xC8DC: 0xFFFD,
	0xC8DD: 0xFFFD,
	0xC8DE: 0xFFFD,
	0xC8DF: 0xFFFD,
	0xC8E0: 0xFFFD,
	0xC8E1: 0xFFFD,
	0xC8E2: 0xFFFD,
	0xC8E3: 0xFFFD,
	0xC8E4: 0xFFFD,
	0xC8E5: 0xFFFD,
	0xC8E6: 0xFFFD,
	0xC8E7: 0xFFFD,
	0xC8E8: 0xFFFD,
	0xC8E9: 0xFFFD,
	0xC8EA: 0xFFFD,
	0xC8EB: 0xFFFD,
	0xC8EC: 0xFFFD,
	0xC8ED: 0xFFFD,
	0xC8EE: 0xFFFD,
	0xC8EF: 0xFFFD,
	0xC8F0: 0xFFFD,
	0xC8F1: 0xFFFD,
	0xC8F2: 0xFFFD,
	0xC8F3: 0xFFFD,
	0xC8F4: 0xFFFD,
	0xC8F5: 0xFFFD,
	0xC8F6: 0xFFFD,
	0xC8F7: 0xFFFD,
	0xC8F8: 0xFFFD,
	0xC8F9: 0xFFFD,
	0xC8FA: 0xFFFD,
	0xC8FB: 0xFFFD,
	0xC8FC: 0xFFFD,
	0xC8FD: 0xFFFD,
	0xC8FE: 0xFFFD,
	0xC8FF: 0xFFFD,
	0xC900: 0xFFFD,
	0xC901: 0xFFFD,
	0xC902: 0xFFFD,
	0xC903: 0xFFFD,
	0xC904: 0xFFFD,
	0xC905: 0xFFFD,
	0xC906: 0xFFFD,
	0xC907: 0xFFFD,
	0xC908: 0xFFFD,
	0xC909: 0xFFFD,
	0xC90A: 0xFFFD,
	0xC90B: 0xFFFD,
	0xC90C: 0xFFFD,
	0xC90D: 0xFFFD,
	0xC90E: 0xFFFD,
	0xC90F: 0xFFFD,
	0xC910: 0xFFFD,
	0xC911: 0xFFFD,
	0xC912: 0xFFFD,
	0xC913: 0xFFFD,
	0xC914: 0xFFFD,
	0xC915: 0xFFFD,
	0xC916: 0xFFFD,
	0xC917: 0xFFFD,
	0xC918: 0xFFFD,
	0xC919: 0xFFFD,
	0xC91A: 0xFFFD,
	0xC91B: 0xFFFD,
	0xC91C: 0xFFFD,
	0xC91D: 0xFFFD,
	0xC91E: 0xFFFD,
	0xC91F: 0xFFFD,
	0xC920: 0xFFFD,
	0xC921: 0xFFFD,
	0xC922: 0xFFFD,
	0xC923: 0xFFFD,
	0xC924: 0xFFFD,
	0xC925: 0xFFFD,
	0xC926: 0xFFFD,
	0xC927: 0xFFFD,
	0xC928: 0xFFFD,
	0xC929: 0xFFFD,
	0xC92A: 0xFFFD,
	0xC92B: 0xFFFD,
	0xC92C: 0xFFFD,
	0xC92D: 0xFFFD,
	0xC92E: 0xFFFD,
	0xC92F: 0xFFFD,
	0xC930: 0xFFFD,
	0xC931: 0xFFFD,
	0xC932: 0xFFFD,
	0xC933: 0xFFFD,
	0xC934: 0xFFFD,
	0xC935: 0xFFFD,
	0xC936: 0xFFFD,
	0xC937: 0xFFFD,
	0xC938: 0xFFFD,
	0xC939: 0xFFFD,
	0xC93A: 0xFFFD,
	0xC93B: 0xFFFD,
	0xC93C: 0xFFFD,
	0xC93D: 0xFFFD,
	0xC93E: 0xFFFD,
	0xC93F: 0xFFFD,
	0xC940: 0xFFFD,
	0xC941: 0xFFFD,
	0xC942: 0xFFFD,
	0xC943: 0xFFFD,
	0xC944: 0xFFFD,
	0xC945: 0xFFFD,
	0xC946: 0xFFFD,
	0xC947: 0xFFFD,
	0xC948: 0xFFFD,
	0xC949: 0xFFFD,
	0xC94A: 0xFFFD,
	0xC94B: 0xFFFD,
	0xC94C: 0xFFFD,
	0xC94D: 0xFFFD,
	0xC94E: 0xFFFD,
	0xC94F: 0xFFFD,
	0xC950: 0xFFFD,
	0xC951: 0xFFFD,
	0xC952: 0xFFFD,
	0xC953: 0xFFFD,
	0xC954: 0xFFFD,
	0xC955: 0xFFFD,
	0xC956: 0xFFFD,
	0xC957: 0xFFFD,
	0xC958: 0xFFFD,
	0xC959: 0xFFFD,
	0xC95A: 0xFFFD,
	0xC95B: 0xFFFD,
	0xC95C: 0xFFFD,
	0xC95D: 0xFFFD,
	0xC95E: 0xFFFD,
	0xC95F: 0xFFFD,
	0xC960: 0xFFFD,
	0xC961: 0xFFFD,
	0xC962: 0xFFFD,
	0xC963: 0xFFFD,
	0xC964: 0xFFFD,
	0xC965: 0xFFFD,
	0xC966: 0xFFFD,
	0xC967: 0xFFFD,
	0xC968: 0xFFFD,
	0xC969: 0xFFFD,
	0xC96A: 0xFFFD,
	0xC96B: 0xFFFD,
	0xC96C: 0xFFFD,
	0xC96D: 0xFFFD,
	0xC96E: 0xFFFD,
	0xC96F: 0xFFFD,
	0xC970: 0xFFFD,
	0xC971: 0xFFFD,
	0xC972: 0xFFFD,
	0xC973: 0xFFFD,
	0xC974: 0xFFFD,
	0xC975: 0xFFFD,
	0xC976: 0xFFFD,
	0xC977: 0xFFFD,
	0xC978: 0xFFFD,
	0xC979: 0xFFFD,
	0xC97A: 0xFFFD,
	0xC97B: 0xFFFD,
	0xC97C: 0xFFFD,
	0xC97D: 0xFFFD,
	0xC97E: 0xFFFD,
	0xC97F: 0xFFFD,
	0xC980: 0xFFFD,
	0xC981: 0xFFFD,
	0xC982: 0xFFFD,
	0xC983: 0xFFFD,
	0xC984: 0xFFFD,
	0xC985: 0xFFFD,
	0xC986: 0xFFFD,
	0xC987: 0xFFFD,
	0xC988: 0xFFFD,
	0xC989: 0xFFFD,
	0xC98A: 0xFFFD,
	0xC98B: 0xFFFD,
	0xC98C: 0xFFFD,
	0xC98D: 0xFFFD,
	0xC98E: 0xFFFD,
	0xC98F: 0xFFFD,
	0xC990: 0xFFFD,
	0xC991: 0xFFFD,
	0xC992: 0xFFFD,
	0xC993: 0xFFFD,
	0xC994: 0xFFFD,
	0xC995: 0xFFFD,
	0xC996: 0xFFFD,
	0xC997: 0xFFFD,
	0xC998: 0xFFFD,
	0xC999: 0xFFFD,
	0xC99A: 0xFFFD,
	0xC99B: 0xFFFD,
	0xC99C: 0xFFFD,
	0xC99D: 0xFFFD,
	0xC99E: 0xFFFD,
	0xC99F: 0xFFFD,
	0xC9A0: 0xFFFD,
	0xC9A1: 0xFFFD,
	0xC9A2: 0xFFFD,
	0xC9A3: 0xFFFD,
	0xC9A4: 0xFFFD,
	0xC9A5: 0xFFFD,
	0xC9A6: 0xFFFD,
	0xC9A7: 0xFFFD,
	0xC9A8: 0xFFFD,
	0xC9A9: 0xFFFD,
	0xC9AA: 0xFFFD,
	0xC9AB: 0xFFFD,
	0xC9AC: 0xFFFD,
	0xC9AD: 0xFFFD,
	0xC9AE: 0xFFFD,
	0xC9AF: 0xFFFD,
	0xC9B0: 0xFFFD,
	0xC9B1: 0xFFFD,
	0xC9B2: 0xFFFD,
	0xC9B3: 0xFFFD,
	0xC9B4: 0xFFFD,
	0xC9B5: 0xFFFD,
	0xC9B6: 0xFFFD,
	0xC9B7: 0xFFFD,
	0xC9B8: 0xFFFD,
	0xC9B9: 0xFFFD,
	0xC9BA: 0xFFFD,
	0xC9BB: 0xFFFD,
	0xC9BC: 0xFFFD,
	0xC9BD: 0xFFFD,
	0xC9BE: 0xFFFD,
	0xC9BF: 0xFFFD,
	0xC9C0: 0xFFFD,
	0xC9C1: 0xFFFD,
	0xC9C2: 0xFFFD,
	0xC9C3: 0xFFFD,
	0xC9C4: 0xFFFD,
	0xC9C5: 0xFFFD,
	0xC9C6: 0xFFFD,
	0xC9C7: 0xFFFD,
	0xC9C8: 0xFFFD,
	0xC9C9: 0xFFFD,
	0xC9CA: 0xFFFD,
	0xC9CB: 0xFFFD,
	0xC9CC: 0xFFFD,
	0xC9CD: 0xFFFD,
	0xC9CE: 0xFFFD,
	0xC9CF: 0xFFFD,
	0xC9D0: 0xFFFD,
	0xC9D1: 0xFFFD,
	0xC9D2: 0xFFFD,
	0xC9D3: 0xFFFD,
	0xC9D4: 0xFFFD,
	0xC9D5: 0xFFFD,
	0xC9D6: 0xFFFD,
	0xC9D7: 0xFFFD,
	0xC9D8: 0xFFFD,
	0xC9D9: 0xFFFD,
	0xC9DA: 0xFFFD,
	0xC9DB: 0xFFFD,
	0xC9DC: 0xFFFD,
	0xC9DD: 0xFFFD,
	0xC9DE: 0xFFFD,
	0xC9DF: 0xFFFD,
	0xC9E0: 0xFFFD,
	0xC9E1: 0xFFFD,
	0xC9E2: 0xFFFD,
	0xC9E3: 0xFFFD,
	0xC9E4: 0xFFFD,
	0xC9E5: 0xFFFD,
	0xC9E6: 0xFFFD,
	0xC9E7: 0xFFFD,
	0xC9E8: 0xFFFD,
	0xC9E9: 0xFFFD,
	0xC9EA: 0xFFFD,
	0xC9EB: 0xFFFD,
	0xC9EC: 0xFFFD,
	0xC9ED: 0xFFFD,
	0xC9EE: 0xFFFD,
	0xC9EF: 0xFFFD,
	0xC9F0: 0xFFFD,
	0xC9F1: 0xFFFD,
	0xC9F2: 0xFFFD,
	0xC9F3: 0xFFFD,
	0xC9F4: 0xFFFD,
	0xC9F5: 0xFFFD,
	0xC9F6: 0xFFFD,
	0xC9F7: 0xFFFD,
	0xC9F8: 0xFFFD,
	0xC9F9: 0xFFFD,
	0xC9FA: 0xFFFD,
	0xC9FB: 0xFFFD,
	0xC9FC: 0xFFFD,
	0xC9FD: 0xFFFD,
	0xC9FE: 0xFFFD,
	0xC9FF: 0xFFFD,
	0xCA00: 0xFFFD,
	0xCA01: 0xFFFD,
	0xCA02: 0xFFFD,
	0xCA03: 0xFFFD,
	0xCA04: 0xFFFD,
	0xCA05: 0xFFFD,
	0xCA06: 0xFFFD,
	0xCA07: 0xFFFD,
	0xCA08: 0xFFFD,
	0xCA09: 0xFFFD,
	0xCA0A: 0xFFFD,
	0xCA0B: 0xFFFD,
	0xCA0C: 0xFFFD,
	0xCA0D: 0xFFFD,
	0xCA0E: 0xFFFD,
	0xCA0F: 0xFFFD,
	0xCA10: 0xFFFD,
	0xCA11: 0xFFFD,
	0xCA12: 0xFFFD,
	0xCA13: 0xFFFD,
	0xCA14: 0xFFFD,
	0xCA15: 0xFFFD,
	0xCA16: 0xFFFD,
	0xCA17: 0xFFFD,
	0xCA18: 0xFFFD,
	0xCA19: 0xFFFD,
	0xCA1A: 0xFFFD,
	0xCA1B: 0xFFFD,
	0xCA1C: 0xFFFD,
	0xCA1D: 0xFFFD,
	0xCA1E: 0xFFFD,
	0xCA1F: 0xFFFD,
	0xCA20: 0xFFFD,
	0xCA21: 0xFFFD,
	0xCA22: 0xFFFD,
	0xCA23: 0xFFFD,
	0xCA24: 0xFFFD,
	0xCA25: 0xFFFD,
	0xCA26: 0xFFFD,
	0xCA27: 0xFFFD,
	0xCA28: 0xFFFD,
	0xCA29: 0xFFFD,
	0xCA2A: 0xFFFD,
	0xCA2B: 0xFFFD,
	0xCA2C: 0xFFFD,
	0xCA2D: 0xFFFD,
	0xCA2E: 0xFFFD,
	0xCA2F: 0xFFFD,
	0xCA30: 0xFFFD,
	0xCA31: 0xFFFD,
	0xCA32: 0xFFFD,
	0xCA33: 0xFFFD,
	0xCA34: 0xFFFD,
	0xCA35: 0xFFFD,
	0xCA36: 0xFFFD,
	0xCA37: 0xFFFD,
	0xCA38: 0xFFFD,
	0xCA39: 0xFFFD,
	0xCA3A: 0xFFFD,
	0xCA3B: 0xFFFD,
	0xCA3C: 0xFFFD,
	0xCA3D: 0xFFFD,
	0xCA3E: 0xFFFD,
	0xCA3F: 0xFFFD,
	0xCA40: 0xFFFD,
	0xCA41: 0xFFFD,
	0xCA42: 0xFFFD,
	0xCA43: 0xFFFD,
	0xCA44: 0xFFFD,
	0xCA45: 0xFFFD,
	0xCA46: 0xFFFD,
	0xCA47: 0xFFFD,
	0xCA48: 0xFFFD,
	0xCA49: 0xFFFD,
	0xCA4A: 0xFFFD,
	0xCA4B: 0xFFFD,
	0xCA4C: 0xFFFD,
	0xCA4D: 0xFFFD,
	0xCA4E: 0xFFFD,
	0xCA4F: 0xFFFD,
	0xCA50: 0xFFFD,
	0xCA51: 0xFFFD,
	0xCA52: 0xFFFD,
	0xCA53: 0xFFFD,
	0xCA54: 0xFFFD,
	0xCA55: 0xFFFD,
	0xCA56: 0xFFFD,
	0xCA57: 0xFFFD,
	0xCA58: 0xFFFD,
	0xCA59: 0xFFFD,
	0xCA5A: 0xFFFD,
	0xCA5B: 0xFFFD,
	0xCA5C: 0xFFFD,
	0xCA5D: 0xFFFD,
	0xCA5E: 0xFFFD,
	0xCA5F: 0xFFFD,
	0xCA60: 0xFFFD,
	0xCA61: 0xFFFD,
	0xCA62: 0xFFFD,
	0xCA63: 0xFFFD,
	0xCA64: 0xFFFD,
	0xCA65: 0xFFFD,
	0xCA66: 0xFFFD,
	0xCA67: 0xFFFD,
	0xCA68: 0xFFFD,
	0xCA69: 0xFFFD,
	0xCA6A: 0xFFFD,
	0xCA6B: 0xFFFD,
	0xCA6C: 0xFFFD,
	0xCA6D: 0xFFFD,
	0xCA6E: 0xFFFD,
	0xCA6F: 0xFFFD,
	0xCA70: 0xFFFD,
	0xCA71: 0xFFFD,
	0xCA72: 0xFFFD,
	0xCA73: 0xFFFD,
	0xCA74: 0xFFFD,
	0xCA75: 0xFFFD,
	0xCA76: 0xFFFD,
	0xCA77: 0xFFFD,
	0xCA78: 0xFFFD,
	0xCA79: 0xFFFD,
	0xCA7A: 0xFFFD,
	0xCA7B: 0xFFFD,
	0xCA7C: 0xFFFD,
	0xCA7D: 0xFFFD,
	0xCA7E: 0xFFFD,
	0xCA7F: 0xFFFD,
	0xCA80: 0xFFFD,
	0xCA81: 0xFFFD,
	0xCA82: 0xFFFD,
	0xCA83: 0xFFFD,
	0xCA84: 0xFFFD,
	0xCA85: 0xFFFD,
	0xCA86: 0xFFFD,
	0xCA87: 0xFFFD,
	0xCA88: 0xFFFD,
	0xCA89: 0xFFFD,
	0xCA8A: 0xFFFD,
	0xCA8B: 0xFFFD,
	0xCA8C: 0xFFFD,
	0xCA8D: 0xFFFD,
	0xCA8E: 0xFFFD,
	0xCA8F: 0xFFFD,
	0xCA90: 0xFFFD,
	0xCA91: 0xFFFD,
	0xCA92: 0xFFFD,
	0xCA93: 0xFFFD,
	0xCA94: 0xFFFD,
	0xCA95: 0xFFFD,
	0xCA96: 0xFFFD,
	0xCA97: 0xFFFD,
	0xCA98: 0xFFFD,
	0xCA99: 0xFFFD,
	0xCA9A: 0xFFFD,
	0xCA9B: 0xFFFD,
	0xCA9C: 0xFFFD,
	0xCA9D: 0xFFFD,
	0xCA9E: 0xFFFD,
	0xCA9F: 0xFFFD,
	0xCAA0: 0xFFFD,
	0xCAA1: 0xFFFD,
	0xCAA2: 0xFFFD,
	0xCAA3: 0xFFFD,
	0xCAA4: 0xFFFD,
	0xCAA5: 0xFFFD,
	0xCAA6: 0xFFFD,
	0xCAA7: 0xFFFD,
	0xCAA8: 0xFFFD,
	0xCAA9: 0xFFFD,
	0xCAAA: 0xFFFD,
	0xCAAB: 0xFFFD,
	0xCAAC: 0xFFFD,
	0xCAAD: 0xFFFD,
	0xCAAE: 0xFFFD,
	0xCAAF: 0xFFFD,
	0xCAB0: 0xFFFD,
	0xCAB1: 0xFFFD,
	0xCAB2: 0xFFFD,
	0xCAB3: 0xFFFD,
	0xCAB4: 0xFFFD,
	0xCAB5: 0xFFFD,
	0xCAB6: 0xFFFD,
	0xCAB7: 0xFFFD,
	0xCAB8: 0xFFFD,
	0xCAB9: 0xFFFD,
	0xCABA: 0xFFFD,
	0xCABB: 0xFFFD,
	0xCABC: 0xFFFD,
	0xCABD: 0xFFFD,
	0xCABE: 0xFFFD,
	0xCABF: 0xFFFD,
	0xCAC0: 0xFFFD,
	0xCAC1: 0xFFFD,
	0xCAC2: 0xFFFD,
	0xCAC3: 0xFFFD,
	0xCAC4: 0xFFFD,
	0xCAC5: 0xFFFD,
	0xCAC6: 0xFFFD,
	0xCAC7: 0xFFFD,
	0xCAC8: 0xFFFD,
	0xCAC9: 0xFFFD,
	0xCACA: 0xFFFD,
	0xCACB: 0xFFFD,
	0xCACC: 0xFFFD,
	0xCACD: 0xFFFD,
	0xCACE: 0xFFFD,
	0xCACF: 0xFFFD,
	0xCAD0: 0xFFFD,
	0xCAD1: 0xFFFD,
	0xCAD2: 0xFFFD,
	0xCAD3: 0xFFFD,
	0xCAD4: 0xFFFD,
	0xCAD5: 0xFFFD,
	0xCAD6: 0xFFFD,
	0xCAD7: 0xFFFD,
	0xCAD8: 0xFFFD,
	0xCAD9: 0xFFFD,
	0xCADA: 0xFFFD,
	0xCADB: 0xFFFD,
	0xCADC: 0xFFFD,
	0xCADD: 0xFFFD,
	0xCADE: 0xFFFD,
	0xCADF: 0xFFFD,
	0xCAE0: 0xFFFD,
	0xCAE1: 0xFFFD,
	0xCAE2: 0xFFFD,
	0xCAE3: 0xFFFD,
	0xCAE4: 0xFFFD,
	0xCAE5: 0xFFFD,
	0xCAE6: 0xFFFD,
	0xCAE7: 0xFFFD,
	0xCAE8: 0xFFFD,
	0xCAE9: 0xFFFD,
	0xCAEA: 0xFFFD,
	0xCAEB: 0xFFFD,
	0xCAEC: 0xFFFD,
	0xCAED: 0xFFFD,
	0xCAEE: 0xFFFD,
	0xCAEF: 0xFFFD,
	0xCAF0: 0xFFFD,
	0xCAF1: 0xFFFD,
	0xCAF2: 0xFFFD,
	0xCAF3: 0xFFFD,
	0xCAF4: 0xFFFD,
	0xCAF5: 0xFFFD,
	0xCAF6: 0xFFFD,
	0xCAF7: 0xFFFD,
	0xCAF8: 0xFFFD,
	0xCAF9: 0xFFFD,
	0xCAFA: 0xFFFD,
	0xCAFB: 0xFFFD,
	0xCAFC: 0xFFFD,
	0xCAFD: 0xFFFD,
	0xCAFE: 0xFFFD,
	0xCAFF: 0xFFFD,
	0xCB00: 0xFFFD,
	0xCB01: 0xFFFD,
	0xCB02: 0xFFFD,
	0xCB03: 0xFFFD,
	0xCB04: 0xFFFD,
	0xCB05: 0xFFFD,
	0xCB06: 0xFFFD,
	0xCB07: 0xFFFD,
	0xCB08: 0xFFFD,
	0xCB09: 0xFFFD,
	0xCB0A: 0xFFFD,
	0xCB0B: 0xFFFD,
	0xCB0C: 0xFFFD,
	0xCB0D: 0xFFFD,
	0xCB0E: 0xFFFD,
	0xCB0F: 0xFFFD,
	0xCB10: 0xFFFD,
	0xCB11: 0xFFFD,
	0xCB12: 0xFFFD,
	0xCB13: 0xFFFD,
	0xCB14: 0xFFFD,
	0xCB15: 0xFFFD,
	0xCB16: 0xFFFD,
	0xCB17: 0xFFFD,
	0xCB18: 0xFFFD,
	0xCB19: 0xFFFD,
	0xCB1A: 0xFFFD,
	0xCB1B: 0xFFFD,
	0xCB1C: 0xFFFD,
	0xCB1D: 0xFFFD,
	0xCB1E: 0xFFFD,
	0xCB1F: 0xFFFD,
	0xCB20: 0xFFFD,
	0xCB21: 0xFFFD,
	0xCB22: 0xFFFD,
	0xCB23: 0xFFFD,
	0xCB24: 0xFFFD,
	0xCB25: 0xFFFD,
	0xCB26: 0xFFFD,
	0xCB27: 0xFFFD,
	0xCB28: 0xFFFD,
	0xCB29: 0xFFFD,
	0xCB2A: 0xFFFD,
	0xCB2B: 0xFFFD,
	0xCB2C: 0xFFFD,
	0xCB2D: 0xFFFD,
	0xCB2E: 0xFFFD,
	0xCB2F: 0xFFFD,
	0xCB30: 0xFFFD,
	0xCB31: 0xFFFD,
	0xCB32: 0xFFFD,
	0xCB33: 0xFFFD,
	0xCB34: 0xFFFD,
	0xCB35: 0xFFFD,
	0xCB36: 0xFFFD,
	0xCB37: 0xFFFD,
	0xCB38: 0xFFFD,
	0xCB39: 0xFFFD,
	0xCB3A: 0xFFFD,
	0xCB3B: 0xFFFD,
	0xCB3C: 0xFFFD,
	0xCB3D: 0xFFFD,
	0xCB3E: 0xFFFD,
	0xCB3F: 0xFFFD,
	0xCB40: 0xFFFD,
	0xCB41: 0xFFFD,
	0xCB42: 0xFFFD,
	0xCB43: 0xFFFD,
	0xCB44: 0xFFFD,
	0xCB45: 0xFFFD,
	0xCB46: 0xFFFD,
	0xCB47: 0xFFFD,
	0xCB48: 0xFFFD,
	0xCB49: 0xFFFD,
	0xCB4A: 0xFFFD,
	0xCB4B: 0xFFFD,
	0xCB4C: 0xFFFD,
	0xCB4D: 0xFFFD,
	0xCB4E: 0xFFFD,
	0xCB4F: 0xFFFD,
	0xCB50: 0xFFFD,
	0xCB51: 0xFFFD,
	0xCB52: 0xFFFD,
	0xCB53: 0xFFFD,
	0xCB54: 0xFFFD,
	0xCB55: 0xFFFD,
	0xCB56: 0xFFFD,
	0xCB57: 0xFFFD,
	0xCB58: 0xFFFD,
	0xCB59: 0xFFFD,
	0xCB5A: 0xFFFD,
	0xCB5B: 0xFFFD,
	0xCB5C: 0xFFFD,
	0xCB5D: 0xFFFD,
	0xCB5E: 0xFFFD,
	0xCB5F: 0xFFFD,
	0xCB60: 0xFFFD,
	0xCB61: 0xFFFD,
	0xCB62: 0xFFFD,
	0xCB63: 0xFFFD,
	0xCB64: 0xFFFD,
	0xCB65: 0xFFFD,
	0xCB66: 0xFFFD,
	0xCB67: 0xFFFD,
	0xCB68: 0xFFFD,
	0xCB69: 0xFFFD,
	0xCB6A: 0xFFFD,
	0xCB6B: 0xFFFD,
	0xCB6C: 0xFFFD,
	0xCB6D: 0xFFFD,
	0xCB6E: 0xFFFD,
	0xCB6F: 0xFFFD,
	0xCB70: 0xFFFD,
	0xCB71: 0xFFFD,
	0xCB72: 0xFFFD,
	0xCB73: 0xFFFD,
	0xCB74: 0xFFFD,
	0xCB75: 0xFFFD,
	0xCB76: 0xFFFD,
	0xCB77: 0xFFFD,
	0xCB78: 0xFFFD,
	0xCB79: 0xFFFD,
	0xCB7A: 0xFFFD,
	0xCB7B: 0xFFFD,
	0xCB7C: 0xFFFD,
	0xCB7D: 0xFFFD,
	0xCB7E: 0xFFFD,
	0xCB7F: 0xFFFD,
	0xCB80: 0xFFFD,
	0xCB81: 0xFFFD,
	0xCB82: 0xFFFD,
	0xCB83: 0xFFFD,
	0xCB84: 0xFFFD,
	0xCB85: 0xFFFD,
	0xCB86: 0xFFFD,
	0xCB87: 0xFFFD,
	0xCB88: 0xFFFD,
	0xCB89: 0xFFFD,
	0xCB8A: 0xFFFD,
	0xCB8B: 0xFFFD,
	0xCB8C: 0xFFFD,
	0xCB8D: 0xFFFD,
	0xCB8E: 0xFFFD,
	0xCB8F: 0xFFFD,
	0xCB90: 0xFFFD,
	0xCB91: 0xFFFD,
	0xCB92: 0xFFFD,
	0xCB93: 0xFFFD,
	0xCB94: 0xFFFD,
	0xCB95: 0xFFFD,
	0xCB96: 0xFFFD,
	0xCB97: 0xFFFD,
	0xCB98: 0xFFFD,
	0xCB99: 0xFFFD,
	0xCB9A: 0xFFFD,
	0xCB9B: 0xFFFD,
	0xCB9C: 0xFFFD,
	0xCB9D: 0xFFFD,
	0xCB9E: 0xFFFD,
	0xCB9F: 0xFFFD,
	0xCBA0: 0xFFFD,
	0xCBA1: 0xFFFD,
	0xCBA2: 0xFFFD,
	0xCBA3: 0xFFFD,
	0xCBA4: 0xFFFD,
	0xCBA5: 0xFFFD,
	0xCBA6: 0xFFFD,
	0xCBA7: 0xFFFD,
	0xCBA8: 0xFFFD,
	0xCBA9: 0xFFFD,
	0xCBAA: 0xFFFD,
	0xCBAB: 0xFFFD,
	0xCBAC: 0xFFFD,
	0xCBAD: 0xFFFD,
	0xCBAE: 0xFFFD,
	0xCBAF: 0xFFFD,
	0xCBB0: 0xFFFD,
	0xCBB1: 0xFFFD,
	0xCBB2: 0xFFFD,
	0xCBB3: 0xFFFD,
	0xCBB4: 0xFFFD,
	0xCBB5: 0xFFFD,
	0xCBB6: 0xFFFD,
	0xCBB7: 0xFFFD,
	0xCBB8: 0xFFFD,
	0xCBB9: 0xFFFD,
	0xCBBA: 0xFFFD,
	0xCBBB: 0xFFFD,
	0xCBBC: 0xFFFD,
	0xCBBD: 0xFFFD,
	0xCBBE: 0xFFFD,
	0xCBBF: 0xFFFD,
	0xCBC0: 0xFFFD,
	0xCBC1: 0xFFFD,
	0xCBC2: 0xFFFD,
	0xCBC3: 0xFFFD,
	0xCBC4: 0xFFFD,
	0xCBC5: 0xFFFD,
	0xCBC6: 0xFFFD,
	0xCBC7: 0xFFFD,
	0xCBC8: 0xFFFD,
	0xCBC9: 0xFFFD,
	0xCBCA: 0xFFFD,
	0xCBCB: 0xFFFD,
	0xCBCC: 0xFFFD,
	0xCBCD: 0xFFFD,
	0xCBCE: 0xFFFD,
	0xCBCF: 0xFFFD,
	0xCBD0: 0xFFFD,
	0xCBD1: 0xFFFD,
	0xCBD2: 0xFFFD,
	0xCBD3: 0xFFFD,
	0xCBD4: 0xFFFD,
	0xCBD5: 0xFFFD,
	0xCBD6: 0xFFFD,
	0xCBD7: 0xFFFD,
	0xCBD8: 0xFFFD,
	0xCBD9: 0xFFFD,
	0xCBDA: 0xFFFD,
	0xCBDB: 0xFFFD,
	0xCBDC: 0xFFFD,
	0xCBDD: 0xFFFD,
	0xCBDE: 0xFFFD,
	0xCBDF: 0xFFFD,
	0xCBE0: 0xFFFD,
	0xCBE1: 0xFFFD,
	0xCBE2: 0xFFFD,
	0xCBE3: 0xFFFD,
	0xCBE4: 0xFFFD,
	0xCBE5: 0xFFFD,
	0xCBE6: 0xFFFD,
	0xCBE7: 0xFFFD,
	0xCBE8: 0xFFFD,
	0xCBE9: 0xFFFD,
	0xCBEA: 0xFFFD,
	0xCBEB: 0xFFFD,
	0xCBEC: 0xFFFD,
	0xCBED: 0xFFFD,
	0xCBEE: 0xFFFD,
	0xCBEF: 0xFFFD,
	0xCBF0: 0xFFFD,
	0xCBF1: 0xFFFD,
	0xCBF2: 0xFFFD,
	0xCBF3: 0xFFFD,
	0xCBF4: 0xFFFD,
	0xCBF5: 0xFFFD,
	0xCBF6: 0xFFFD,
	0xCBF7: 0xFFFD,
	0xCBF8: 0xFFFD,
	0xCBF9: 0xFFFD,
	0xCBFA: 0xFFFD,
	0xCBFB: 0xFFFD,
	0xCBFC: 0xFFFD,
	0xCBFD: 0xFFFD,
	0xCBFE: 0xFFFD,
	0xCBFF: 0xFFFD,
	0xCC00: 0xFFFD,
	0xCC01: 0xFFFD,
	0xCC02: 0xFFFD,
	0xCC03: 0xFFFD,
	0xCC04: 0xFFFD,
	0xCC05: 0xFFFD,
	0xCC06: 0xFFFD,
	0xCC07: 0xFFFD,
	0xCC08: 0xFFFD,
	0xCC09: 0xFFFD,
	0xCC0A: 0xFFFD,
	0xCC0B: 0xFFFD,
	0xCC0C: 0xFFFD,
	0xCC0D: 0xFFFD,
	0xCC0E: 0xFFFD,
	0xCC0F: 0xFFFD,
	0xCC10: 0xFFFD,
	0xCC11: 0xFFFD,
	0xCC12: 0xFFFD,
	0xCC13: 0xFFFD,
	0xCC14: 0xFFFD,
	0xCC15: 0xFFFD,
	0xCC16: 0xFFFD,
	0xCC17: 0xFFFD,
	0xCC18: 0xFFFD,
	0xCC19: 0xFFFD,
	0xCC1A: 0xFFFD,
	0xCC1B: 0xFFFD,
	0xCC1C: 0xFFFD,
	0xCC1D: 0xFFFD,
	0xCC1E: 0xFFFD,
	0xCC1F: 0xFFFD,
	0xCC20: 0xFFFD,
	0xCC21: 0xFFFD,
	0xCC22: 0xFFFD,
	0xCC23: 0xFFFD,
	0xCC24: 0xFFFD,
	0xCC25: 0xFFFD,
	0xCC26: 0xFFFD,
	0xCC27: 0xFFFD,
	0xCC28: 0xFFFD,
	0xCC29: 0xFFFD,
	0xCC2A: 0xFFFD,
	0xCC2B: 0xFFFD,
	0xCC2C: 0xFFFD,
	0xCC2D: 0xFFFD,
	0xCC2E: 0xFFFD,
	0xCC2F: 0xFFFD,
	0xCC30: 0xFFFD,
	0xCC31: 0xFFFD,
	0xCC32: 0xFFFD,
	0xCC33: 0xFFFD,
	0xCC34: 0xFFFD,
	0xCC35: 0xFFFD,
	0xCC36: 0xFFFD,
	0xCC37: 0xFFFD,
	0xCC38: 0xFFFD,
	0xCC39: 0xFFFD,
	0xCC3A: 0xFFFD,
	0xCC3B: 0xFFFD,
	0xCC3C: 0xFFFD,
	0xCC3D: 0xFFFD,
	0xCC3E: 0xFFFD,
	0xCC3F: 0xFFFD,
	0xCC40: 0xFFFD,
	0xCC41: 0xFFFD,
	0xCC42: 0xFFFD,
	0xCC43: 0xFFFD,
	0xCC44: 0xFFFD,
	0xCC45: 0xFFFD,
	0xCC46: 0xFFFD,
	0xCC47: 0xFFFD,
	0xCC48: 0xFFFD,
	0xCC49: 0xFFFD,
	0xCC4A: 0xFFFD,
	0xCC4B: 0xFFFD,
	0xCC4C: 0xFFFD,
	0xCC4D: 0xFFFD,
	0xCC4E: 0xFFFD,
	0xCC4F: 0xFFFD,
	0xCC50: 0xFFFD,
	0xCC51: 0xFFFD,
	0xCC52: 0xFFFD,
	0xCC53: 0xFFFD,
	0xCC54: 0xFFFD,
	0xCC55: 0xFFFD,
	0xCC56: 0xFFFD,
	0xCC57: 0xFFFD,
	0xCC58: 0xFFFD,
	0xCC59: 0xFFFD,
	0xCC5A: 0xFFFD,
	0xCC5B: 0xFFFD,
	0xCC5C: 0xFFFD,
	0xCC5D: 0xFFFD,
	0xCC5E: 0xFFFD,
	0xCC5F: 0xFFFD,
	0xCC60: 0xFFFD,
	0xCC61: 0xFFFD,
	0xCC62: 0xFFFD,
	0xCC63: 0xFFFD,
	0xCC64: 0xFFFD,
	0xCC65: 0xFFFD,
	0xCC66: 0xFFFD,
	0xCC67: 0xFFFD,
	0xCC68: 0xFFFD,
	0xCC69: 0xFFFD,
	0xCC6A: 0xFFFD,
	0xCC6B: 0xFFFD,
	0xCC6C: 0xFFFD,
	0xCC6D: 0xFFFD,
	0xCC6E: 0xFFFD,
	0xCC6F: 0xFFFD,
	0xCC70: 0xFFFD,
	0xCC71: 0xFFFD,
	0xCC72: 0xFFFD,
	0xCC73: 0xFFFD,
	0xCC74: 0xFFFD,
	0xCC75: 0xFFFD,
	0xCC76: 0xFFFD,
	0xCC77: 0xFFFD,
	0xCC78: 0xFFFD,
	0xCC79: 0xFFFD,
	0xCC7A: 0xFFFD,
	0xCC7B: 0xFFFD,
	0xCC7C: 0xFFFD,
	0xCC7D: 0xFFFD,
	0xCC7E: 0xFFFD,
	0xCC7F: 0xFFFD,
	0xCC80: 0xFFFD,
	0xCC81: 0xFFFD,
	0xCC82: 0xFFFD,
	0xCC83: 0xFFFD,
	0xCC84: 0xFFFD,
	0xCC85: 0xFFFD,
	0xCC86: 0xFFFD,
	0xCC87: 0xFFFD,
	0xCC88: 0xFFFD,
	0xCC89: 0xFFFD,
	0xCC8A: 0xFFFD,
	0xCC8B: 0xFFFD,
	0xCC8C: 0xFFFD,
	0xCC8D: 0xFFFD,
	0xCC8E: 0xFFFD,
	0xCC8F: 0xFFFD,
	0xCC90: 0xFFFD,
	0xCC91: 0xFFFD,
	0xCC92: 0xFFFD,
	0xCC93: 0xFFFD,
	0xCC94: 0xFFFD,
	0xCC95: 0xFFFD,
	0xCC96: 0xFFFD,
	0xCC97: 0xFFFD,
	0xCC98: 0xFFFD,
	0xCC99: 0xFFFD,
	0xCC9A: 0xFFFD,
	0xCC9B: 0xFFFD,
	0xCC9C: 0xFFFD,
	0xCC9D: 0xFFFD,
	0xCC9E: 0xFFFD,
	0xCC9F: 0xFFFD,
	0xCCA0: 0xFFFD,
	0xCCA1: 0xFFFD,
	0xCCA2: 0xFFFD,
	0xCCA3: 0xFFFD,
	0xCCA4: 0xFFFD,
	0xCCA5: 0xFFFD,
	0xCCA6: 0xFFFD,
	0xCCA7: 0xFFFD,
	0xCCA8: 0xFFFD,
	0xCCA9: 0xFFFD,
	0xCCAA: 0xFFFD,
	0xCCAB: 0xFFFD,
	0xCCAC: 0xFFFD,
	0xCCAD: 0xFFFD,
	0xCCAE: 0xFFFD,
	0xCCAF: 0xFFFD,
	0xCCB0: 0xFFFD,
	0xCCB1: 0xFFFD,
	0xCCB2: 0xFFFD,
	0xCCB3: 0xFFFD,
	0xCCB4: 0xFFFD,
	0xCCB5: 0xFFFD,
	0xCCB6: 0xFFFD,
	0xCCB7: 0xFFFD,
	0xCCB8: 0xFFFD,
	0xCCB9: 0xFFFD,
	0xCCBA: 0xFFFD,
	0xCCBB: 0xFFFD,
	0xCCBC: 0xFFFD,
	0xCCBD: 0xFFFD,
	0xCCBE: 0xFFFD,
	0xCCBF: 0xFFFD,
	0xCCC0: 0xFFFD,
	0xCCC1: 0xFFFD,
	0xCCC2: 0xFFFD,
	0xCCC3: 0xFFFD,
	0xCCC4: 0xFFFD,
	0xCCC5: 0xFFFD,
	0xCCC6: 0xFFFD,
	0xCCC7: 0xFFFD,
	0xCCC8: 0xFFFD,
	0xCCC9: 0xFFFD,
	0xCCCA: 0xFFFD,
	0xCCCB: 0xFFFD,
	0xCCCC: 0xFFFD,
	0xCCCD: 0xFFFD,
	0xCCCE: 0xFFFD,
	0xCCCF: 0xFFFD,
	0xCCD0: 0xFFFD,
	0xCCD1: 0xFFFD,
	0xCCD2: 0xFFFD,
	0xCCD3: 0xFFFD,
	0xCCD4: 0xFFFD,
	0xCCD5: 0xFFFD,
	0xCCD6: 0xFFFD,
	0xCCD7: 0xFFFD,
	0xCCD8: 0xFFFD,
	0xCCD9: 0xFFFD,
	0xCCDA: 0xFFFD,
	0xCCDB: 0xFFFD,
	0xCCDC: 0xFFFD,
	0xCCDD: 0xFFFD,
	0xCCDE: 0xFFFD,
	0xCCDF: 0xFFFD,
	0xCCE0: 0xFFFD,
	0xCCE1: 0xFFFD,
	0xCCE2: 0xFFFD,
	0xCCE3: 0xFFFD,
	0xCCE4: 0xFFFD,
	0xCCE5: 0xFFFD,
	0xCCE6: 0xFFFD,
	0xCCE7: 0xFFFD,
	0xCCE8: 0xFFFD,
	0xCCE9: 0xFFFD,
	0xCCEA: 0xFFFD,
	0xCCEB: 0xFFFD,
	0xCCEC: 0xFFFD,
	0xCCED: 0xFFFD,
	0xCCEE: 0xFFFD,
	0xCCEF: 0xFFFD,
	0xCCF0: 0xFFFD,
	0xCCF1: 0xFFFD,
	0xCCF2: 0xFFFD,
	0xCCF3: 0xFFFD,
	0xCCF4: 0xFFFD,
	0xCCF5: 0xFFFD,
	0xCCF6: 0xFFFD,
	0xCCF7: 0xFFFD,
	0xCCF8: 0xFFFD,
	0xCCF9: 0xFFFD,
	0xCCFA: 0xFFFD,
	0xCCFB: 0xFFFD,
	0xCCFC: 0xFFFD,
	0xCCFD: 0xFFFD,
	0xCCFE: 0xFFFD,
	0xCCFF: 0xFFFD,
	0xCD00: 0xFFFD,
	0xCD01: 0xFFFD,
	0xCD02: 0xFFFD,
	0xCD03: 0xFFFD,
	0xCD04: 0xFFFD,
	0xCD05: 0xFFFD,
	0xCD06: 0xFFFD,
	0xCD07: 0xFFFD,
	0xCD08: 0xFFFD,
	0xCD09: 0xFFFD,
	0xCD0A: 0xFFFD,
	0xCD0B: 0xFFFD,
	0xCD0C: 0xFFFD,
	0xCD0D: 0xFFFD,
	0xCD0E: 0xFFFD,
	0xCD0F: 0xFFFD,
	0xCD10: 0xFFFD,
	0xCD11: 0xFFFD,
	0xCD12: 0xFFFD,
	0xCD13: 0xFFFD,
	0xCD14: 0xFFFD,
	0xCD15: 0xFFFD,
	0xCD16: 0xFFFD,
	0xCD17: 0xFFFD,
	0xCD18: 0xFFFD,
	0xCD19: 0xFFFD,
	0xCD1A: 0xFFFD,
	0xCD1B: 0xFFFD,
	0xCD1C: 0xFFFD,
	0xCD1D: 0xFFFD,
	0xCD1E: 0xFFFD,
	0xCD1F: 0xFFFD,
	0xCD20: 0xFFFD,
	0xCD21: 0xFFFD,
	0xCD22: 0xFFFD,
	0xCD23: 0xFFFD,
	0xCD24: 0xFFFD,
	0xCD25: 0xFFFD,
	0xCD26: 0xFFFD,
	0xCD27: 0xFFFD,
	0xCD28: 0xFFFD,
	0xCD29: 0xFFFD,
	0xCD2A: 0xFFFD,
	0xCD2B: 0xFFFD,
	0xCD2C: 0xFFFD,
	0xCD2D: 0xFFFD,
	0xCD2E: 0xFFFD,
	0xCD2F: 0xFFFD,
	0xCD30: 0xFFFD,
	0xCD31: 0xFFFD,
	0xCD32: 0xFFFD,
	0xCD33: 0xFFFD,
	0xCD34: 0xFFFD,
	0xCD35: 0xFFFD,
	0xCD36: 0xFFFD,
	0xCD37: 0xFFFD,
	0xCD38: 0xFFFD,
	0xCD39: 0xFFFD,
	0xCD3A: 0xFFFD,
	0xCD3B: 0xFFFD,
	0xCD3C: 0xFFFD,
	0xCD3D: 0xFFFD,
	0xCD3E: 0xFFFD,
	0xCD3F: 0xFFFD,
	0xCD40: 0xFFFD,
	0xCD41: 0xFFFD,
	0xCD42: 0xFFFD,
	0xCD43: 0xFFFD,
	0xCD44: 0xFFFD,
	0xCD45: 0xFFFD,
	0xCD46: 0xFFFD,
	0xCD47: 0xFFFD,
	0xCD48: 0xFFFD,
	0xCD49: 0xFFFD,
	0xCD4A: 0xFFFD,
	0xCD4B: 0xFFFD,
	0xCD4C: 0xFFFD,
	0xCD4D: 0xFFFD,
	0xCD4E: 0xFFFD,
	0xCD4F: 0xFFFD,
	0xCD50: 0xFFFD,
	0xCD51: 0xFFFD,
	0xCD52: 0xFFFD,
	0xCD53: 0xFFFD,
	0xCD54: 0xFFFD,
	0xCD55: 0xFFFD,
	0xCD56: 0xFFFD,
	0xCD57: 0xFFFD,
	0xCD58: 0xFFFD,
	0xCD59: 0xFFFD,
	0xCD5A: 0xFFFD,
	0xCD5B: 0xFFFD,
	0xCD5C: 0xFFFD,
	0xCD5D: 0xFFFD,
	0xCD5E: 0xFFFD,
	0xCD5F: 0xFFFD,
	0xCD60: 0xFFFD,
	0xCD61: 0xFFFD,
	0xCD62: 0xFFFD,
	0xCD63: 0xFFFD,
	0xCD64: 0xFFFD,
	0xCD65: 0xFFFD,
	0xCD66: 0xFFFD,
	0xCD67: 0xFFFD,
	0xCD68: 0xFFFD,
	0xCD69: 0xFFFD,
	0xCD6A: 0xFFFD,
	0xCD6B: 0xFFFD,
	0xCD6C: 0xFFFD,
	0xCD6D: 0xFFFD,
	0xCD6E: 0xFFFD,
	0xCD6F: 0xFFFD,
	0xCD70: 0xFFFD,
	0xCD71: 0xFFFD,
	0xCD72: 0xFFFD,
	0xCD73: 0xFFFD,
	0xCD74: 0xFFFD,
	0xCD75: 0xFFFD,
	0xCD76: 0xFFFD,
	0xCD77: 0xFFFD,
	0xCD78: 0xFFFD,
	0xCD79: 0xFFFD,
	0xCD7A: 0xFFFD,
	0xCD7B: 0xFFFD,
	0xCD7C: 0xFFFD,
	0xCD7D: 0xFFFD,
	0xCD7E: 0xFFFD,
	0xCD7F: 0xFFFD,
	0xCD80: 0xFFFD,
	0xCD81: 0xFFFD,
	0xCD82: 0xFFFD,
	0xCD83: 0xFFFD,
	0xCD84: 0xFFFD,
	0xCD85: 0xFFFD,
	0xCD86: 0xFFFD,
	0xCD87: 0xFFFD,
	0xCD88: 0xFFFD,
	0xCD89: 0xFFFD,
	0xCD8A: 0xFFFD,
	0xCD8B: 0xFFFD,
	0xCD8C: 0xFFFD,
	0xCD8D: 0xFFFD,
	0xCD8E: 0xFFFD,
	0xCD8F: 0xFFFD,
	0xCD90: 0xFFFD,
	0xCD91: 0xFFFD,
	0xCD92: 0xFFFD,
	0xCD93: 0xFFFD,
	0xCD94: 0xFFFD,
	0xCD95: 0xFFFD,
	0xCD96: 0xFFFD,
	0xCD97: 0xFFFD,
	0xCD98: 0xFFFD,
	0xCD99: 0xFFFD,
	0xCD9A: 0xFFFD,
	0xCD9B: 0xFFFD,
	0xCD9C: 0xFFFD,
	0xCD9D: 0xFFFD,
	0xCD9E: 0xFFFD,
	0xCD9F: 0xFFFD,
	0xCDA0: 0xFFFD,
	0xCDA1: 0xFFFD,
	0xCDA2: 0xFFFD,
	0xCDA3: 0xFFFD,
	0xCDA4: 0xFFFD,
	0xCDA5: 0xFFFD,
	0xCDA6: 0xFFFD,
	0xCDA7: 0xFFFD,
	0xCDA8: 0xFFFD,
	0xCDA9: 0xFFFD,
	0xCDAA: 0xFFFD,
	0xCDAB: 0xFFFD,
	0xCDAC: 0xFFFD,
	0xCDAD: 0xFFFD,
	0xCDAE: 0xFFFD,
	0xCDAF: 0xFFFD,
	0xCDB0: 0xFFFD,
	0xCDB1: 0xFFFD,
	0xCDB2: 0xFFFD,
	0xCDB3: 0xFFFD,
	0xCDB4: 0xFFFD,
	0xCDB5: 0xFFFD,
	0xCDB6: 0xFFFD,
	0xCDB7: 0xFFFD,
	0xCDB8: 0xFFFD,
	0xCDB9: 0xFFFD,
	0xCDBA: 0xFFFD,
	0xCDBB: 0xFFFD,
	0xCDBC: 0xFFFD,
	0xCDBD: 0xFFFD,
	0xCDBE: 0xFFFD,
	0xCDBF: 0xFFFD,
	0xCDC0: 0xFFFD,
	0xCDC1: 0xFFFD,
	0xCDC2: 0xFFFD,
	0xCDC3: 0xFFFD,
	0xCDC4: 0xFFFD,
	0xCDC5: 0xFFFD,
	0xCDC6: 0xFFFD,
	0xCDC7: 0xFFFD,
	0xCDC8: 0xFFFD,
	0xCDC9: 0xFFFD,
	0xCDCA: 0xFFFD,
	0xCDCB: 0xFFFD,
	0xCDCC: 0xFFFD,
	0xCDCD: 0xFFFD,
	0xCDCE: 0xFFFD,
	0xCDCF: 0xFFFD,
	0xCDD0: 0xFFFD,
	0xCDD1: 0xFFFD,
	0xCDD2: 0xFFFD,
	0xCDD3: 0xFFFD,
	0xCDD4: 0xFFFD,
	0xCDD5: 0xFFFD,
	0xCDD6: 0xFFFD,
	0xCDD7: 0xFFFD,
	0xCDD8: 0xFFFD,
	0xCDD9: 0xFFFD,
	0xCDDA: 0xFFFD,
	0xCDDB: 0xFFFD,
	0xCDDC: 0xFFFD,
	0xCDDD: 0xFFFD,
	0xCDDE: 0xFFFD,
	0xCDDF: 0xFFFD,
	0xCDE0: 0xFFFD,
	0xCDE1: 0xFFFD,
	0xCDE2: 0xFFFD,
	0xCDE3: 0xFFFD,
	0xCDE4: 0xFFFD,
	0xCDE5: 0xFFFD,
	0xCDE6: 0xFFFD,
	0xCDE7: 0xFFFD,
	0xCDE8: 0xFFFD,
	0xCDE9: 0xFFFD,
	0xCDEA: 0xFFFD,
	0xCDEB: 0xFFFD,
	0xCDEC: 0xFFFD,
	0xCDED: 0xFFFD,
	0xCDEE: 0xFFFD,
	0xCDEF: 0xFFFD,
	0xCDF0: 0xFFFD,
	0xCDF1: 0xFFFD,
	0xCDF2: 0xFFFD,
	0xCDF3: 0xFFFD,
	0xCDF4: 0xFFFD,
	0xCDF5: 0xFFFD,
	0xCDF6: 0xFFFD,
	0xCDF7: 0xFFFD,
	0xCDF8: 0xFFFD,
	0xCDF9: 0xFFFD,
	0xCDFA: 0xFFFD,
	0xCDFB: 0xFFFD,
	0xCDFC: 0xFFFD,
	0xCDFD: 0xFFFD,
	0xCDFE: 0xFFFD,
	0xCDFF: 0xFFFD,
	0xCE00: 0xFFFD,
	0xCE01: 0xFFFD,
	0xCE02: 0xFFFD,
	0xCE03: 0xFFFD,
	0xCE04: 0xFFFD,
	0xCE05: 0xFFFD,
	0xCE06: 0xFFFD,
	0xCE07: 0xFFFD,
	0xCE08: 0xFFFD,
	0xCE09: 0xFFFD,
	0xCE0A: 0xFFFD,
	0xCE0B: 0xFFFD,
	0xCE0C: 0xFFFD,
	0xCE0D: 0xFFFD,
	0xCE0E: 0xFFFD,
	0xCE0F: 0xFFFD,
	0xCE10: 0xFFFD,
	0xCE11: 0xFFFD,
	0xCE12: 0xFFFD,
	0xCE13: 0xFFFD,
	0xCE14: 0xFFFD,
	0xCE15: 0xFFFD,
	0xCE16: 0xFFFD,
	0xCE17: 0xFFFD,
	0xCE18: 0xFFFD,
	0xCE19: 0xFFFD,
	0xCE1A: 0xFFFD,
	0xCE1B: 0xFFFD,
	0xCE1C: 0xFFFD,
	0xCE1D: 0xFFFD,
	0xCE1E: 0xFFFD,
	0xCE1F: 0xFFFD,
	0xCE20: 0xFFFD,
	0xCE21: 0xFFFD,
	0xCE22: 0xFFFD,
	0xCE23: 0xFFFD,
	0xCE24: 0xFFFD,
	0xCE25: 0xFFFD,
	0xCE26: 0xFFFD,
	0xCE27: 0xFFFD,
	0xCE28: 0xFFFD,
	0xCE29: 0xFFFD,
	0xCE2A: 0xFFFD,
	0xCE2B: 0xFFFD,
	0xCE2C: 0xFFFD,
	0xCE2D: 0xFFFD,
	0xCE2E: 0xFFFD,
	0xCE2F: 0xFFFD,
	0xCE30: 0xFFFD,
	0xCE31: 0xFFFD,
	0xCE32: 0xFFFD,
	0xCE33: 0xFFFD,
	0xCE34: 0xFFFD,
	0xCE35: 0xFFFD,
	0xCE36: 0xFFFD,
	0xCE37: 0xFFFD,
	0xCE38: 0xFFFD,
	0xCE39: 0xFFFD,
	0xCE3A: 0xFFFD,
	0xCE3B: 0xFFFD,
	0xCE3C: 0xFFFD,
	0xCE3D: 0xFFFD,
	0xCE3E: 0xFFFD,
	0xCE3F: 0xFFFD,
	0xCE40: 0xFFFD,
	0xCE41: 0xFFFD,
	0xCE42: 0xFFFD,
	0xCE43: 0xFFFD,
	0xCE44: 0xFFFD,
	0xCE45: 0xFFFD,
	0xCE46: 0xFFFD,
	0xCE47: 0xFFFD,
	0xCE48: 0xFFFD,
	0xCE49: 0xFFFD,
	0xCE4A: 0xFFFD,
	0xCE4B: 0xFFFD,
	0xCE4C: 0xFFFD,
	0xCE4D: 0xFFFD,
	0xCE4E: 0xFFFD,
	0xCE4F: 0xFFFD,
	0xCE50: 0xFFFD,
	0xCE51: 0xFFFD,
	0xCE52: 0xFFFD,
	0xCE53: 0xFFFD,
	0xCE54: 0xFFFD,
	0xCE55: 0xFFFD,
	0xCE56: 0xFFFD,
	0xCE57: 0xFFFD,
	0xCE58: 0xFFFD,
	0xCE59: 0xFFFD,
	0xCE5A: 0xFFFD,
	0xCE5B: 0xFFFD,
	0xCE5C: 0xFFFD,
	0xCE5D: 0xFFFD,
	0xCE5E: 0xFFFD,
	0xCE5F: 0xFFFD,
	0xCE60: 0xFFFD,
	0xCE61: 0xFFFD,
	0xCE62: 0xFFFD,
	0xCE63: 0xFFFD,
	0xCE64: 0xFFFD,
	0xCE65: 0xFFFD,
	0xCE66: 0xFFFD,
	0xCE67: 0xFFFD,
	0xCE68: 0xFFFD,
	0xCE69: 0xFFFD,
	0xCE6A: 0xFFFD,
	0xCE6B: 0xFFFD,
	0xCE6C: 0xFFFD,
	0xCE6D: 0xFFFD,
	0xCE6E: 0xFFFD,
	0xCE6F: 0xFFFD,
	0xCE70: 0xFFFD,
	0xCE71: 0xFFFD,
	0xCE72: 0xFFFD,
	0xCE73: 0xFFFD,
	0xCE74: 0xFFFD,
	0xCE75: 0xFFFD,
	0xCE76: 0xFFFD,
	0xCE77: 0xFFFD,
	0xCE78: 0xFFFD,
	0xCE79: 0xFFFD,
	0xCE7A: 0xFFFD,
	0xCE7B: 0xFFFD,
	0xCE7C: 0xFFFD,
	0xCE7D: 0xFFFD,
	0xCE7E: 0xFFFD,
	0xCE7F: 0xFFFD,
	0xCE80: 0xFFFD,
	0xCE81: 0xFFFD,
	0xCE82: 0xFFFD,
	0xCE83: 0xFFFD,
	0xCE84: 0xFFFD,
	0xCE85: 0xFFFD,
	0xCE86: 0xFFFD,
	0xCE87: 0xFFFD,
	0xCE88: 0xFFFD,
	0xCE89: 0xFFFD,
	0xCE8A: 0xFFFD,
	0xCE8B: 0xFFFD,
	0xCE8C: 0xFFFD,
	0xCE8D: 0xFFFD,
	0xCE8E: 0xFFFD,
	0xCE8F: 0xFFFD,
	0xCE90: 0xFFFD,
	0xCE91: 0xFFFD,
	0xCE92: 0xFFFD,
	0xCE93: 0xFFFD,
	0xCE94: 0xFFFD,
	0xCE95: 0xFFFD,
	0xCE96: 0xFFFD,
	0xCE97: 0xFFFD,
	0xCE98: 0xFFFD,
	0xCE99: 0xFFFD,
	0xCE9A: 0xFFFD,
	0xCE9B: 0xFFFD,
	0xCE9C: 0xFFFD,
	0xCE9D: 0xFFFD,
	0xCE9E: 0xFFFD,
	0xCE9F: 0xFFFD,
	0xCEA0: 0xFFFD,
	0xCEA1: 0xFFFD,
	0xCEA2: 0xFFFD,
	0xCEA3: 0xFFFD,
	0xCEA4: 0xFFFD,
	0xCEA5: 0xFFFD,
	0xCEA6: 0xFFFD,
	0xCEA7: 0xFFFD,
	0xCEA8: 0xFFFD,
	0xCEA9: 0xFFFD,
	0xCEAA: 0xFFFD,
	0xCEAB: 0xFFFD,
	0xCEAC: 0xFFFD,
	0xCEAD: 0xFFFD,
	0xCEAE: 0xFFFD,
	0xCEAF: 0xFFFD,
	0xCEB0: 0xFFFD,
	0xCEB1: 0xFFFD,
	0xCEB2: 0xFFFD,
	0xCEB3: 0xFFFD,
	0xCEB4: 0xFFFD,
	0xCEB5: 0xFFFD,
	0xCEB6: 0xFFFD,
	0xCEB7: 0xFFFD,
	0xCEB8: 0xFFFD,
	0xCEB9: 0xFFFD,
	0xCEBA: 0xFFFD,
	0xCEBB: 0xFFFD,
	0xCEBC: 0xFFFD,
	0xCEBD: 0xFFFD,
	0xCEBE: 0xFFFD,
	0xCEBF: 0xFFFD,
	0xCEC0: 0xFFFD,
	0xCEC1: 0xFFFD,
	0xCEC2: 0xFFFD,
	0xCEC3: 0xFFFD,
	0xCEC4: 0xFFFD,
	0xCEC5: 0xFFFD,
	0xCEC6: 0xFFFD,
	0xCEC7: 0xFFFD,
	0xCEC8: 0xFFFD,
	0xCEC9: 0xFFFD,
	0xCECA: 0xFFFD,
	0xCECB: 0xFFFD,
	0xCECC: 0xFFFD,
	0xCECD: 0xFFFD,
	0xCECE: 0xFFFD,
	0xCECF: 0xFFFD,
	0xCED0: 0xFFFD,
	0xCED1: 0xFFFD,
	0xCED2: 0xFFFD,
	0xCED3: 0xFFFD,
	0xCED4: 0xFFFD,
	0xCED5: 0xFFFD,
	0xCED6: 0xFFFD,
	0xCED7: 0xFFFD,
	0xCED8: 0xFFFD,
	0xCED9: 0xFFFD,
	0xCEDA: 0xFFFD,
	0xCEDB: 0xFFFD,
	0xCEDC: 0xFFFD,
	0xCEDD: 0xFFFD,
	0xCEDE: 0xFFFD,
	0xCEDF: 0xFFFD,
	0xCEE0: 0xFFFD,
	0xCEE1: 0xFFFD,
	0xCEE2: 0xFFFD,
	0xCEE3: 0xFFFD,
	0xCEE4: 0xFFFD,
	0xCEE5: 0xFFFD,
	0xCEE6: 0xFFFD,
	0xCEE7: 0xFFFD,
	0xCEE8: 0xFFFD,
	0xCEE9: 0xFFFD,
	0xCEEA: 0xFFFD,
	0xCEEB: 0xFFFD,
	0xCEEC: 0xFFFD,
	0xCEED: 0xFFFD,
	0xCEEE: 0xFFFD,
	0xCEEF: 0xFFFD,
	0xCEF0: 0xFFFD,
	0xCEF1: 0xFFFD,
	0xCEF2: 0xFFFD,
	0xCEF3: 0xFFFD,
	0xCEF4: 0xFFFD,
	0xCEF5: 0xFFFD,
	0xCEF6: 0xFFFD,
	0xCEF7: 0xFFFD,
	0xCEF8: 0xFFFD,
	0xCEF9: 0xFFFD,
	0xCEFA: 0xFFFD,
	0xCEFB: 0xFFFD,
	0xCEFC: 0xFFFD,
	0xCEFD: 0xFFFD,
	0xCEFE: 0xFFFD,
	0xCEFF: 0xFFFD,
	0xCF00: 0xFFFD,
	0xCF01: 0xFFFD,
	0xCF02: 0xFFFD,
	0xCF03: 0xFFFD,
	0xCF04: 0xFFFD,
	0xCF05: 0xFFFD,
	0xCF06: 0xFFFD,
	0xCF07: 0xFFFD,
	0xCF08: 0xFFFD,
	0xCF09: 0xFFFD,
	0xCF0A: 0xFFFD,
	0xCF0B: 0xFFFD,
	0xCF0C: 0xFFFD,
	0xCF0D: 0xFFFD,
	0xCF0E: 0xFFFD,
	0xCF0F: 0xFFFD,
	0xCF10: 0xFFFD,
	0xCF11: 0xFFFD,
	0xCF12: 0xFFFD,
	0xCF13: 0xFFFD,
	0xCF14: 0xFFFD,
	0xCF15: 0xFFFD,
	0xCF16: 0xFFFD,
	0xCF17: 0xFFFD,
	0xCF18: 0xFFFD,
	0xCF19: 0xFFFD,
	0xCF1A: 0xFFFD,
	0xCF1B: 0xFFFD,
	0xCF1C: 0xFFFD,
	0xCF1D: 0xFFFD,
	0xCF1E: 0xFFFD,
	0xCF1F: 0xFFFD,
	0xCF20: 0xFFFD,
	0xCF21: 0xFFFD,
	0xCF22: 0xFFFD,
	0xCF23: 0xFFFD,
	0xCF24: 0xFFFD,
	0xCF25: 0xFFFD,
	0xCF26: 0xFFFD,
	0xCF27: 0xFFFD,
	0xCF28: 0xFFFD,
	0xCF29: 0xFFFD,
	0xCF2A: 0xFFFD,
	0xCF2B: 0xFFFD,
	0xCF2C: 0xFFFD,
	0xCF2D: 0xFFFD,
	0xCF2E: 0xFFFD,
	0xCF2F: 0xFFFD,
	0xCF30: 0xFFFD,
	0xCF31: 0xFFFD,
	0xCF32: 0xFFFD,
	0xCF33: 0xFFFD,
	0xCF34: 0xFFFD,
	0xCF35: 0xFFFD,
	0xCF36: 0xFFFD,
	0xCF37: 0xFFFD,
	0xCF38: 0xFFFD,
	0xCF39: 0xFFFD,
	0xCF3A: 0xFFFD,
	0xCF3B: 0xFFFD,
	0xCF3C: 0xFFFD,
	0xCF3D: 0xFFFD,
	0xCF3E: 0xFFFD,
	0xCF3F: 0xFFFD,
	0xCF40: 0xFFFD,
	0xCF41: 0xFFFD,
	0xCF42: 0xFFFD,
	0xCF43: 0xFFFD,
	0xCF44: 0xFFFD,
	0xCF45: 0xFFFD,
	0xCF46: 0xFFFD,
	0xCF47: 0xFFFD,
	0xCF48: 0xFFFD,
	0xCF49: 0xFFFD,
	0xCF4A: 0xFFFD,
	0xCF4B: 0xFFFD,
	0xCF4C: 0xFFFD,
	0xCF4D: 0xFFFD,
	0xCF4E: 0xFFFD,
	0xCF4F: 0xFFFD,
	0xCF50: 0xFFFD,
	0xCF51: 0xFFFD,
	0xCF52: 0xFFFD,
	0xCF53: 0xFFFD,
	0xCF54: 0xFFFD,
	0xCF55: 0xFFFD,
	0xCF56: 0xFFFD,
	0xCF57: 0xFFFD,
	0xCF58: 0xFFFD,
	0xCF59: 0xFFFD,
	0xCF5A: 0xFFFD,
	0xCF5B: 0xFFFD,
	0xCF5C: 0xFFFD,
	0xCF5D: 0xFFFD,
	0xCF5E: 0xFFFD,
	0xCF5F: 0xFFFD,
	0xCF60: 0xFFFD,
	0xCF61: 0xFFFD,
	0xCF62: 0xFFFD,
	0xCF63: 0xFFFD,
	0xCF64: 0xFFFD,
	0xCF65: 0xFFFD,
	0xCF66: 0xFFFD,
	0xCF67: 0xFFFD,
	0xCF68: 0xFFFD,
	0xCF69: 0xFFFD,
	0xCF6A: 0xFFFD,
	0xCF6B: 0xFFFD,
	0xCF6C: 0xFFFD,
	0xCF6D: 0xFFFD,
	0xCF6E: 0xFFFD,
	0xCF6F: 0xFFFD,
	0xCF70: 0xFFFD,
	0xCF71: 0xFFFD,
	0xCF72: 0xFFFD,
	0xCF73: 0xFFFD,
	0xCF74: 0xFFFD,
	0xCF75: 0xFFFD,
	0xCF76: 0xFFFD,
	0xCF77: 0xFFFD,
	0xCF78: 0xFFFD,
	0xCF79: 0xFFFD,
	0xCF7A: 0xFFFD,
	0xCF7B: 0xFFFD,
	0xCF7C: 0xFFFD,
	0xCF7D: 0xFFFD,
	0xCF7E: 0xFFFD,
	0xCF7F: 0xFFFD,
	0xCF80: 0xFFFD,
	0xCF81: 0xFFFD,
	0xCF82: 0xFFFD,
	0xCF83: 0xFFFD,
	0xCF84: 0xFFFD,
	0xCF85: 0xFFFD,
	0xCF86: 0xFFFD,
	0xCF87: 0xFFFD,
	0xCF88: 0xFFFD,
	0xCF89: 0xFFFD,
	0xCF8A: 0xFFFD,
	0xCF8B: 0xFFFD,
	0xCF8C: 0xFFFD,
	0xCF8D: 0xFFFD,
	0xCF8E: 0xFFFD,
	0xCF8F: 0xFFFD,
	0xCF90: 0xFFFD,
	0xCF91: 0xFFFD,
	0xCF92: 0xFFFD,
	0xCF93: 0xFFFD,
	0xCF94: 0xFFFD,
	0xCF95: 0xFFFD,
	0xCF96: 0xFFFD,
	0xCF97: 0xFFFD,
	0xCF98: 0xFFFD,
	0xCF99: 0xFFFD,
	0xCF9A: 0xFFFD,
	0xCF9B: 0xFFFD,
	0xCF9C: 0xFFFD,
	0xCF9D: 0xFFFD,
	0xCF9E: 0xFFFD,
	0xCF9F: 0xFFFD,
	0xCFA0: 0xFFFD,
	0xCFA1: 0xFFFD,
	0xCFA2: 0xFFFD,
	0xCFA3: 0xFFFD,
	0xCFA4: 0xFFFD,
	0xCFA5: 0xFFFD,
	0xCFA6: 0xFFFD,
	0xCFA7: 0xFFFD,
	0xCFA8: 0xFFFD,
	0xCFA9: 0xFFFD,
	0xCFAA: 0xFFFD,
	0xCFAB: 0xFFFD,
	0xCFAC: 0xFFFD,
	0xCFAD: 0xFFFD,
	0xCFAE: 0xFFFD,
	0xCFAF: 0xFFFD,
	0xCFB0: 0xFFFD,
	0xCFB1: 0xFFFD,
	0xCFB2: 0xFFFD,
	0xCFB3: 0xFFFD,
	0xCFB4: 0xFFFD,
	0xCFB5: 0xFFFD,
	0xCFB6: 0xFFFD,
	0xCFB7: 0xFFFD,
	0xCFB8: 0xFFFD,
	0xCFB9: 0xFFFD,
	0xCFBA: 0xFFFD,
	0xCFBB: 0xFFFD,
	0xCFBC: 0xFFFD,
	0xCFBD: 0xFFFD,
	0xCFBE: 0xFFFD,
	0xCFBF: 0xFFFD,
	0xCFC0: 0xFFFD,
	0xCFC1: 0xFFFD,
	0xCFC2: 0xFFFD,
	0xCFC3: 0xFFFD,
	0xCFC4: 0xFFFD,
	0xCFC5: 0xFFFD,
	0xCFC6: 0xFFFD,
	0xCFC7: 0xFFFD,
	0xCFC8: 0xFFFD,
	0xCFC9: 0xFFFD,
	0xCFCA: 0xFFFD,
	0xCFCB: 0xFFFD,
	0xCFCC: 0xFFFD,
	0xCFCD: 0xFFFD,
	0xCFCE: 0xFFFD,
	0xCFCF: 0xFFFD,
	0xCFD0: 0xFFFD,
	0xCFD1: 0xFFFD,
	0xCFD2: 0xFFFD,
	0xCFD3: 0xFFFD,
	0xCFD4: 0xFFFD,
	0xCFD5: 0xFFFD,
	0xCFD6: 0xFFFD,
	0xCFD7: 0xFFFD,
	0xCFD8: 0xFFFD,
	0xCFD9: 0xFFFD,
	0xCFDA: 0xFFFD,
	0xCFDB: 0xFFFD,
	0xCFDC: 0xFFFD,
	0xCFDD: 0xFFFD,
	0xCFDE: 0xFFFD,
	0xCFDF: 0xFFFD,
	0xCFE0: 0xFFFD,
	0xCFE1: 0xFFFD,
	0xCFE2: 0xFFFD,
	0xCFE3: 0xFFFD,
	0xCFE4: 0xFFFD,
	0xCFE5: 0xFFFD,
	0xCFE6: 0xFFFD,
	0xCFE7: 0xFFFD,
	0xCFE8: 0xFFFD,
	0xCFE9: 0xFFFD,
	0xCFEA: 0xFFFD,
	0xCFEB: 0xFFFD,
	0xCFEC: 0xFFFD,
	0xCFED: 0xFFFD,
	0xCFEE: 0xFFFD,
	0xCFEF: 0xFFFD,
	0xCFF0: 0xFFFD,
	0xCFF1: 0xFFFD,
	0xCFF2: 0xFFFD,
	0xCFF3: 0xFFFD,
	0xCFF4: 0xFFFD,
	0xCFF5: 0xFFFD,
	0xCFF6: 0xFFFD,
	0xCFF7: 0xFFFD,
	0xCFF8: 0xFFFD,
	0xCFF9: 0xFFFD,
	0xCFFA: 0xFFFD,
	0xCFFB: 0xFFFD,
	0xCFFC: 0xFFFD,
	0xCFFD: 0xFFFD,
	0xCFFE: 0xFFFD,
	0xCFFF: 0xFFFD,
	0xD000: 0xFFFD,
	0xD001: 0xFFFD,
	0xD002: 0xFFFD,
	0xD003: 0xFFFD,
	0xD004: 0xFFFD,
	0xD005: 0xFFFD,
	0xD006: 0xFFFD,
	0xD007: 0xFFFD,
	0xD008: 0xFFFD,
	0xD009: 0xFFFD,
	0xD00A: 0xFFFD,
	0xD00B: 0xFFFD,
	0xD00C: 0xFFFD,
	0xD00D: 0xFFFD,
	0xD00E: 0xFFFD,
	0xD00F: 0xFFFD,
	0xD010: 0xFFFD,
	0xD011: 0xFFFD,
	0xD012: 0xFFFD,
	0xD013: 0xFFFD,
	0xD014: 0xFFFD,
	0xD015: 0xFFFD,
	0xD016: 0xFFFD,
	0xD017: 0xFFFD,
	0xD018: 0xFFFD,
	0xD019: 0xFFFD,
	0xD01A: 0xFFFD,
	0xD01B: 0xFFFD,
	0xD01C: 0xFFFD,
	0xD01D: 0xFFFD,
	0xD01E: 0xFFFD,
	0xD01F: 0xFFFD,
	0xD020: 0xFFFD,
	0xD021: 0xFFFD,
	0xD022: 0xFFFD,
	0xD023: 0xFFFD,
	0xD024: 0xFFFD,
	0xD025: 0xFFFD,
	0xD026: 0xFFFD,
	0xD027: 0xFFFD,
	0xD028: 0xFFFD,
	0xD029: 0xFFFD,
	0xD02A: 0xFFFD,
	0xD02B: 0xFFFD,
	0xD02C: 0xFFFD,
	0xD02D: 0xFFFD,
	0xD02E: 0xFFFD,
	0xD02F: 0xFFFD,
	0xD030: 0xFFFD,
	0xD031: 0xFFFD,
	0xD032: 0xFFFD,
	0xD033: 0xFFFD,
	0xD034: 0xFFFD,
	0xD035: 0xFFFD,
	0xD036: 0xFFFD,
	0xD037: 0xFFFD,
	0xD038: 0xFFFD,
	0xD039: 0xFFFD,
	0xD03A: 0xFFFD,
	0xD03B: 0xFFFD,
	0xD03C: 0xFFFD,
	0xD03D: 0xFFFD,
	0xD03E: 0xFFFD,
	0xD03F: 0xFFFD,
	0xD040: 0xFFFD,
	0xD041: 0xFFFD,
	0xD042: 0xFFFD,
	0xD043: 0xFFFD,
	0xD044: 0xFFFD,
	0xD045: 0xFFFD,
	0xD046: 0xFFFD,
	0xD047: 0xFFFD,
	0xD048: 0xFFFD,
	0xD049: 0xFFFD,
	0xD04A: 0xFFFD,
	0xD04B: 0xFFFD,
	0xD04C: 0xFFFD,
	0xD04D: 0xFFFD,
	0xD04E: 0xFFFD,
	0xD04F: 0xFFFD,
	0xD050: 0xFFFD,
	0xD051: 0xFFFD,
	0xD052: 0xFFFD,
	0xD053: 0xFFFD,
	0xD054: 0xFFFD,
	0xD055: 0xFFFD,
	0xD056: 0xFFFD,
	0xD057: 0xFFFD,
	0xD058: 0xFFFD,
	0xD059: 0xFFFD,
	0xD05A: 0xFFFD,
	0xD05B: 0xFFFD,
	0xD05C: 0xFFFD,
	0xD05D: 0xFFFD,
	0xD05E: 0xFFFD,
	0xD05F: 0xFFFD,
	0xD060: 0xFFFD,
	0xD061: 0xFFFD,
	0xD062: 0xFFFD,
	0xD063: 0xFFFD,
	0xD064: 0xFFFD,
	0xD065: 0xFFFD,
	0xD066: 0xFFFD,
	0xD067: 0xFFFD,
	0xD068: 0xFFFD,
	0xD069: 0xFFFD,
	0xD06A: 0xFFFD,
	0xD06B: 0xFFFD,
	0xD06C: 0xFFFD,
	0xD06D: 0xFFFD,
	0xD06E: 0xFFFD,
	0xD06F: 0xFFFD,
	0xD070: 0xFFFD,
	0xD071: 0xFFFD,
	0xD072: 0xFFFD,
	0xD073: 0xFFFD,
	0xD074: 0xFFFD,
	0xD075: 0xFFFD,
	0xD076: 0xFFFD,
	0xD077: 0xFFFD,
	0xD078: 0xFFFD,
	0xD079: 0xFFFD,
	0xD07A: 0xFFFD,
	0xD07B: 0xFFFD,
	0xD07C: 0xFFFD,
	0xD07D: 0xFFFD,
	0xD07E: 0xFFFD,
	0xD07F: 0xFFFD,
	0xD080: 0xFFFD,
	0xD081: 0xFFFD,
	0xD082: 0xFFFD,
	0xD083: 0xFFFD,
	0xD084: 0xFFFD,
	0xD085: 0xFFFD,
	0xD086: 0xFFFD,
	0xD087: 0xFFFD,
	0xD088: 0xFFFD,
	0xD089: 0xFFFD,
	0xD08A: 0xFFFD,
	0xD08B: 0xFFFD,
	0xD08C: 0xFFFD,
	0xD08D: 0xFFFD,
	0xD08E: 0xFFFD,
	0xD08F: 0xFFFD,
	0xD090: 0xFFFD,
	0xD091: 0xFFFD,
	0xD092: 0xFFFD,
	0xD093: 0xFFFD,
	0xD094: 0xFFFD,
	0xD095: 0xFFFD,
	0xD096: 0xFFFD,
	0xD097: 0xFFFD,
	0xD098: 0xFFFD,
	0xD099: 0xFFFD,
	0xD09A: 0xFFFD,
	0xD09B: 0xFFFD,
	0xD09C: 0xFFFD,
	0xD09D: 0xFFFD,
	0xD09E: 0xFFFD,
	0xD09F: 0xFFFD,
	0xD0A0: 0xFFFD,
	0xD0A1: 0xFFFD,
	0xD0A2: 0xFFFD,
	0xD0A3: 0xFFFD,
	0xD0A4: 0xFFFD,
	0xD0A5: 0xFFFD,
	0xD0A6: 0xFFFD,
	0xD0A7: 0xFFFD,
	0xD0A8: 0xFFFD,
	0xD0A9: 0xFFFD,
	0xD0AA: 0xFFFD,
	0xD0AB: 0xFFFD,
	0xD0AC: 0xFFFD,
	0xD0AD: 0xFFFD,
	0xD0AE: 0xFFFD,
	0xD0AF: 0xFFFD,
	0xD0B0: 0xFFFD,
	0xD0B1: 0xFFFD,
	0xD0B2: 0xFFFD,
	0xD0B3: 0xFFFD,
	0xD0B4: 0xFFFD,
	0xD0B5: 0xFFFD,
	0xD0B6: 0xFFFD,
	0xD0B7: 0xFFFD,
	0xD0B8: 0xFFFD,
	0xD0B9: 0xFFFD,
	0xD0BA: 0xFFFD,
	0xD0BB: 0xFFFD,
	0xD0BC: 0xFFFD,
	0xD0BD: 0xFFFD,
	0xD0BE: 0xFFFD,
	0xD0BF: 0xFFFD,
	0xD0C0: 0xFFFD,
	0xD0C1: 0xFFFD,
	0xD0C2: 0xFFFD,
	0xD0C3: 0xFFFD,
	0xD0C4: 0xFFFD,
	0xD0C5: 0xFFFD,
	0xD0C6: 0xFFFD,
	0xD0C7: 0xFFFD,
	0xD0C8: 0xFFFD,
	0xD0C9: 0xFFFD,
	0xD0CA: 0xFFFD,
	0xD0CB: 0xFFFD,
	0xD0CC: 0xFFFD,
	0xD0CD: 0xFFFD,
	0xD0CE: 0xFFFD,
	0xD0CF: 0xFFFD,
	0xD0D0: 0xFFFD,
	0xD0D1: 0xFFFD,
	0xD0D2: 0xFFFD,
	0xD0D3: 0xFFFD,
	0xD0D4: 0xFFFD,
	0xD0D5: 0xFFFD,
	0xD0D6: 0xFFFD,
	0xD0D7: 0xFFFD,
	0xD0D8: 0xFFFD,
	0xD0D9: 0xFFFD,
	0xD0DA: 0xFFFD,
	0xD0DB: 0xFFFD,
	0xD0DC: 0xFFFD,
	0xD0DD: 0xFFFD,
	0xD0DE: 0xFFFD,
	0xD0DF: 0xFFFD,
	0xD0E0: 0xFFFD,
	0xD0E1: 0xFFFD,
	0xD0E2: 0xFFFD,
	0xD0E3: 0xFFFD,
	0xD0E4: 0xFFFD,
	0xD0E5: 0xFFFD,
	0xD0E6: 0xFFFD,
	0xD0E7: 0xFFFD,
	0xD0E8: 0xFFFD,
	0xD0E9: 0xFFFD,
	0xD0EA: 0xFFFD,
	0xD0EB: 0xFFFD,
	0xD0EC: 0xFFFD,
	0xD0ED: 0xFFFD,
	0xD0EE: 0xFFFD,
	0xD0EF: 0xFFFD,
	0xD0F0: 0xFFFD,
	0xD0F1: 0xFFFD,
	0xD0F2: 0xFFFD,
	0xD0F3: 0xFFFD,
	0xD0F4: 0xFFFD,
	0xD0F5: 0xFFFD,
	0xD0F6: 0xFFFD,
	0xD0F7: 0xFFFD,
	0xD0F8: 0xFFFD,
	0xD0F9: 0xFFFD,
	0xD0FA: 0xFFFD,
	0xD0FB: 0xFFFD,
	0xD0FC: 0xFFFD,
	0xD0FD: 0xFFFD,
	0xD0FE: 0xFFFD,
	0xD0FF: 0xFFFD,
	0xD100: 0xFFFD,
	0xD101: 0xFFFD,
	0xD102: 0xFFFD,
	0xD103: 0xFFFD,
	0xD104: 0xFFFD,
	0xD105: 0xFFFD,
	0xD106: 0xFFFD,
	0xD107: 0xFFFD,
	0xD108: 0xFFFD,
	0xD109: 0xFFFD,
	0xD10A: 0xFFFD,
	0xD10B: 0xFFFD,
	0xD10C: 0xFFFD,
	0xD10D: 0xFFFD,
	0xD10E: 0xFFFD,
	0xD10F: 0xFFFD,
	0xD110: 0xFFFD,
	0xD111: 0xFFFD,
	0xD112: 0xFFFD,
	0xD113: 0xFFFD,
	0xD114: 0xFFFD,
	0xD115: 0xFFFD,
	0xD116: 0xFFFD,
	0xD117: 0xFFFD,
	0xD118: 0xFFFD,
	0xD119: 0xFFFD,
	0xD11A: 0xFFFD,
	0xD11B: 0xFFFD,
	0xD11C: 0xFFFD,
	0xD11D: 0xFFFD,
	0xD11E: 0xFFFD,
	0xD11F: 0xFFFD,
	0xD120: 0xFFFD,
	0xD121: 0xFFFD,
	0xD122: 0xFFFD,
	0xD123: 0xFFFD,
	0xD124: 0xFFFD,
	0xD125: 0xFFFD,
	0xD126: 0xFFFD,
	0xD127: 0xFFFD,
	0xD128: 0xFFFD,
	0xD129: 0xFFFD,
	0xD12A: 0xFFFD,
	0xD12B: 0xFFFD,
	0xD12C: 0xFFFD,
	0xD12D: 0xFFFD,
	0xD12E: 0xFFFD,
	0xD12F: 0xFFFD,
	0xD130: 0xFFFD,
	0xD131: 0xFFFD,
	0xD132: 0xFFFD,
	0xD133: 0xFFFD,
	0xD134: 0xFFFD,
	0xD135: 0xFFFD,
	0xD136: 0xFFFD,
	0xD137: 0xFFFD,
	0xD138: 0xFFFD,
	0xD139: 0xFFFD,
	0xD13A: 0xFFFD,
	0xD13B: 0xFFFD,
	0xD13C: 0xFFFD,
	0xD13D: 0xFFFD,
	0xD13E: 0xFFFD,
	0xD13F: 0xFFFD,
	0xD140: 0xFFFD,
	0xD141: 0xFFFD,
	0xD142: 0xFFFD,
	0xD143: 0xFFFD,
	0xD144: 0xFFFD,
	0xD145: 0xFFFD,
	0xD146: 0xFFFD,
	0xD147: 0xFFFD,
	0xD148: 0xFFFD,
	0xD149: 0xFFFD,
	0xD14A: 0xFFFD,
	0xD14B: 0xFFFD,
	0xD14C: 0xFFFD,
	0xD14D: 0xFFFD,
	0xD14E: 0xFFFD,
	0xD14F: 0xFFFD,
	0xD150: 0xFFFD,
	0xD151: 0xFFFD,
	0xD152: 0xFFFD,
	0xD153: 0xFFFD,
	0xD154: 0xFFFD,
	0xD155: 0xFFFD,
	0xD156: 0xFFFD,
	0xD157: 0xFFFD,
	0xD158: 0xFFFD,
	0xD159: 0xFFFD,
	0xD15A: 0xFFFD,
	0xD15B: 0xFFFD,
	0xD15C: 0xFFFD,
	0xD15D: 0xFFFD,
	0xD15E: 0xFFFD,
	0xD15F: 0xFFFD,
	0xD160: 0xFFFD,
	0xD161: 0xFFFD,
	0xD162: 0xFFFD,
	0xD163: 0xFFFD,
	0xD164: 0xFFFD,
	0xD165: 0xFFFD,
	0xD166: 0xFFFD,
	0xD167: 0xFFFD,
	0xD168: 0xFFFD,
	0xD169: 0xFFFD,
	0xD16A: 0xFFFD,
	0xD16B: 0xFFFD,
	0xD16C: 0xFFFD,
	0xD16D: 0xFFFD,
	0xD16E: 0xFFFD,
	0xD16F: 0xFFFD,
	0xD170: 0xFFFD,
	0xD171: 0xFFFD,
	0xD172: 0xFFFD,
	0xD173: 0xFFFD,
	0xD174: 0xFFFD,
	0xD175: 0xFFFD,
	0xD176: 0xFFFD,
	0xD177: 0xFFFD,
	0xD178: 0xFFFD,
	0xD179: 0xFFFD,
	0xD17A: 0xFFFD,
	0xD17B: 0xFFFD,
	0xD17C: 0xFFFD,
	0xD17D: 0xFFFD,
	0xD17E: 0xFFFD,
	0xD17F: 0xFFFD,
	0xD180: 0xFFFD,
	0xD181: 0xFFFD,
	0xD182: 0xFFFD,
	0xD183: 0xFFFD,
	0xD184: 0xFFFD,
	0xD185: 0xFFFD,
	0xD186: 0xFFFD,
	0xD187: 0xFFFD,
	0xD188: 0xFFFD,
	0xD189: 0xFFFD,
	0xD18A: 0xFFFD,
	0xD18B: 0xFFFD,
	0xD18C: 0xFFFD,
	0xD18D: 0xFFFD,
	0xD18E: 0xFFFD,
	0xD18F: 0xFFFD,
	0xD190: 0xFFFD,
	0xD191: 0xFFFD,
	0xD192: 0xFFFD,
	0xD193: 0xFFFD,
	0xD194: 0xFFFD,
	0xD195: 0xFFFD,
	0xD196: 0xFFFD,
	0xD197: 0xFFFD,
	0xD198: 0xFFFD,
	0xD199: 0xFFFD,
	0xD19A: 0xFFFD,
	0xD19B: 0xFFFD,
	0xD19C: 0xFFFD,
	0xD19D: 0xFFFD,
	0xD19E: 0xFFFD,
	0xD19F: 0xFFFD,
	0xD1A0: 0xFFFD,
	0xD1A1: 0xFFFD,
	0xD1A2: 0xFFFD,
	0xD1A3: 0xFFFD,
	0xD1A4: 0xFFFD,
	0xD1A5: 0xFFFD,
	0xD1A6: 0xFFFD,
	0xD1A7: 0xFFFD,
	0xD1A8: 0xFFFD,
	0xD1A9: 0xFFFD,
	0xD1AA: 0xFFFD,
	0xD1AB: 0xFFFD,
	0xD1AC: 0xFFFD,
	0xD1AD: 0xFFFD,
	0xD1AE: 0xFFFD,
	0xD1AF: 0xFFFD,
	0xD1B0: 0xFFFD,
	0xD1B1: 0xFFFD,
	0xD1B2: 0xFFFD,
	0xD1B3: 0xFFFD,
	0xD1B4: 0xFFFD,
	0xD1B5: 0xFFFD,
	0xD1B6: 0xFFFD,
	0xD1B7: 0xFFFD,
	0xD1B8: 0xFFFD,
	0xD1B9: 0xFFFD,
	0xD1BA: 0xFFFD,
	0xD1BB: 0xFFFD,
	0xD1BC: 0xFFFD,
	0xD1BD: 0xFFFD,
	0xD1BE: 0xFFFD,
	0xD1BF: 0xFFFD,
	0xD1C0: 0xFFFD,
	0xD1C1: 0xFFFD,
	0xD1C2: 0xFFFD,
	0xD1C3: 0xFFFD,
	0xD1C4: 0xFFFD,
	0xD1C5: 0xFFFD,
	0xD1C6: 0xFFFD,
	0xD1C7: 0xFFFD,
	0xD1C8: 0xFFFD,
	0xD1C9: 0xFFFD,
	0xD1CA: 0xFFFD,
	0xD1CB: 0xFFFD,
	0xD1CC: 0xFFFD,
	0xD1CD: 0xFFFD,
	0xD1CE: 0xFFFD,
	0xD1CF: 0xFFFD,
	0xD1D0: 0xFFFD,
	0xD1D1: 0xFFFD,
	0xD1D2: 0xFFFD,
	0xD1D3: 0xFFFD,
	0xD1D4: 0xFFFD,
	0xD1D5: 0xFFFD,
	0xD1D6: 0xFFFD,
	0xD1D7: 0xFFFD,
	0xD1D8: 0xFFFD,
	0xD1D9: 0xFFFD,
	0xD1DA: 0xFFFD,
	0xD1DB: 0xFFFD,
	0xD1DC: 0xFFFD,
	0xD1DD: 0xFFFD,
	0xD1DE: 0xFFFD,
	0xD1DF: 0xFFFD,
	0xD1E0: 0xFFFD,
	0xD1E1: 0xFFFD,
	0xD1E2: 0xFFFD,
	0xD1E3: 0xFFFD,
	0xD1E4: 0xFFFD,
	0xD1E5: 0xFFFD,
	0xD1E6: 0xFFFD,
	0xD1E7: 0xFFFD,
	0xD1E8: 0xFFFD,
	0xD1E9: 0xFFFD,
	0xD1EA: 0xFFFD,
	0xD1EB: 0xFFFD,
	0xD1EC: 0xFFFD,
	0xD1ED: 0xFFFD,
	0xD1EE: 0xFFFD,
	0xD1EF: 0xFFFD,
	0xD1F0: 0xFFFD,
	0xD1F1: 0xFFFD,
	0xD1F2: 0xFFFD,
	0xD1F3: 0xFFFD,
	0xD1F4: 0xFFFD,
	0xD1F5: 0xFFFD,
	0xD1F6: 0xFFFD,
	0xD1F7: 0xFFFD,
	0xD1F8: 0xFFFD,
	0xD1F9: 0xFFFD,
	0xD1FA: 0xFFFD,
	0xD1FB: 0xFFFD,
	0xD1FC: 0xFFFD,
	0xD1FD: 0xFFFD,
	0xD1FE: 0xFFFD,
	0xD1FF: 0xFFFD,
	0xD200: 0xFFFD,
	0xD201: 0xFFFD,
	0xD202: 0xFFFD,
	0xD203: 0xFFFD,
	0xD204: 0xFFFD,
	0xD205: 0xFFFD,
	0xD206: 0xFFFD,
	0xD207: 0xFFFD,
	0xD208: 0xFFFD,
	0xD209: 0xFFFD,
	0xD20A: 0xFFFD,
	0xD20B: 0xFFFD,
	0xD20C: 0xFFFD,
	0xD20D: 0xFFFD,
	0xD20E: 0xFFFD,
	0xD20F: 0xFFFD,
	0xD210: 0xFFFD,
	0xD211: 0xFFFD,
	0xD212: 0xFFFD,
	0xD213: 0xFFFD,
	0xD214: 0xFFFD,
	0xD215: 0xFFFD,
	0xD216: 0xFFFD,
	0xD217: 0xFFFD,
	0xD218: 0xFFFD,
	0xD219: 0xFFFD,
	0xD21A: 0xFFFD,
	0xD21B: 0xFFFD,
	0xD21C: 0xFFFD,
	0xD21D: 0xFFFD,
	0xD21E: 0xFFFD,
	0xD21F: 0xFFFD,
	0xD220: 0xFFFD,
	0xD221: 0xFFFD,
	0xD222: 0xFFFD,
	0xD223: 0xFFFD,
	0xD224: 0xFFFD,
	0xD225: 0xFFFD,
	0xD226: 0xFFFD,
	0xD227: 0xFFFD,
	0xD228: 0xFFFD,
	0xD229: 0xFFFD,
	0xD22A: 0xFFFD,
	0xD22B: 0xFFFD,
	0xD22C: 0xFFFD,
	0xD22D: 0xFFFD,
	0xD22E: 0xFFFD,
	0xD22F: 0xFFFD,
	0xD230: 0xFFFD,
	0xD231: 0xFFFD,
	0xD232: 0xFFFD,
	0xD233: 0xFFFD,
	0xD234: 0xFFFD,
	0xD235: 0xFFFD,
	0xD236: 0xFFFD,
	0xD237: 0xFFFD,
	0xD238: 0xFFFD,
	0xD239: 0xFFFD,
	0xD23A: 0xFFFD,
	0xD23B: 0xFFFD,
	0xD23C: 0xFFFD,
	0xD23D: 0xFFFD,
	0xD23E: 0xFFFD,
	0xD23F: 0xFFFD,
	0xD240: 0xFFFD,
	0xD241: 0xFFFD,
	0xD242: 0xFFFD,
	0xD243: 0xFFFD,
	0xD244: 0xFFFD,
	0xD245: 0xFFFD,
	0xD246: 0xFFFD,
	0xD247: 0xFFFD,
	0xD248: 0xFFFD,
	0xD249: 0xFFFD,
	0xD24A: 0xFFFD,
	0xD24B: 0xFFFD,
	0xD24C: 0xFFFD,
	0xD24D: 0xFFFD,
	0xD24E: 0xFFFD,
	0xD24F: 0xFFFD,
	0xD250: 0xFFFD,
	0xD251: 0xFFFD,
	0xD252: 0xFFFD,
	0xD253: 0xFFFD,
	0xD254: 0xFFFD,
	0xD255: 0xFFFD,
	0xD256: 0xFFFD,
	0xD257: 0xFFFD,
	0xD258: 0xFFFD,
	0xD259: 0xFFFD,
	0xD25A: 0xFFFD,
	0xD25B: 0xFFFD,
	0xD25C: 0xFFFD,
	0xD25D: 0xFFFD,
	0xD25E: 0xFFFD,
	0xD25F: 0xFFFD,
	0xD260: 0xFFFD,
	0xD261: 0xFFFD,
	0xD262: 0xFFFD,
	0xD263: 0xFFFD,
	0xD264: 0xFFFD,
	0xD265: 0xFFFD,
	0xD266: 0xFFFD,
	0xD267: 0xFFFD,
	0xD268: 0xFFFD,
	0xD269: 0xFFFD,
	0xD26A: 0xFFFD,
	0xD26B: 0xFFFD,
	0xD26C: 0xFFFD,
	0xD26D: 0xFFFD,
	0xD26E: 0xFFFD,
	0xD26F: 0xFFFD,
	0xD270: 0xFFFD,
	0xD271: 0xFFFD,
	0xD272: 0xFFFD,
	0xD273: 0xFFFD,
	0xD274: 0xFFFD,
	0xD275: 0xFFFD,
	0xD276: 0xFFFD,
	0xD277: 0xFFFD,
	0xD278: 0xFFFD,
	0xD279: 0xFFFD,
	0xD27A: 0xFFFD,
	0xD27B: 0xFFFD,
	0xD27C: 0xFFFD,
	0xD27D: 0xFFFD,
	0xD27E: 0xFFFD,
	0xD27F: 0xFFFD,
	0xD280: 0xFFFD,
	0xD281: 0xFFFD,
	0xD282: 0xFFFD,
	0xD283: 0xFFFD,
	0xD284: 0xFFFD,
	0xD285: 0xFFFD,
	0xD286: 0xFFFD,
	0xD287: 0xFFFD,
	0xD288: 0xFFFD,
	0xD289: 0xFFFD,
	0xD28A: 0xFFFD,
	0xD28B: 0xFFFD,
	0xD28C: 0xFFFD,
	0xD28D: 0xFFFD,
	0xD28E: 0xFFFD,
	0xD28F: 0xFFFD,
	0xD290: 0xFFFD,
	0xD291: 0xFFFD,
	0xD292: 0xFFFD,
	0xD293: 0xFFFD,
	0xD294: 0xFFFD,
	0xD295: 0xFFFD,
	0xD296: 0xFFFD,
	0xD297: 0xFFFD,
	0xD298: 0xFFFD,
	0xD299: 0xFFFD,
	0xD29A: 0xFFFD,
	0xD29B: 0xFFFD,
	0xD29C: 0xFFFD,
	0xD29D: 0xFFFD,
	0xD29E: 0xFFFD,
	0xD29F: 0xFFFD,
	0xD2A0: 0xFFFD,
	0xD2A1: 0xFFFD,
	0xD2A2: 0xFFFD,
	0xD2A3: 0xFFFD,
	0xD2A4: 0xFFFD,
	0xD2A5: 0xFFFD,
	0xD2A6: 0xFFFD,
	0xD2A7: 0xFFFD,
	0xD2A8: 0xFFFD,
	0xD2A9: 0xFFFD,
	0xD2AA: 0xFFFD,
	0xD2AB: 0xFFFD,
	0xD2AC: 0xFFFD,
	0xD2AD: 0xFFFD,
	0xD2AE: 0xFFFD,
	0xD2AF: 0xFFFD,
	0xD2B0: 0xFFFD,
	0xD2B1: 0xFFFD,
	0xD2B2: 0xFFFD,
	0xD2B3: 0xFFFD,
	0xD2B4: 0xFFFD,
	0xD2B5: 0xFFFD,
	0xD2B6: 0xFFFD,
	0xD2B7: 0xFFFD,
	0xD2B8: 0xFFFD,
	0xD2B9: 0xFFFD,
	0xD2BA: 0xFFFD,
	0xD2BB: 0xFFFD,
	0xD2BC: 0xFFFD,
	0xD2BD: 0xFFFD,
	0xD2BE: 0xFFFD,
	0xD2BF: 0xFFFD,
	0xD2C0: 0xFFFD,
	0xD2C1: 0xFFFD,
	0xD2C2: 0xFFFD,
	0xD2C3: 0xFFFD,
	0xD2C4: 0xFFFD,
	0xD2C5: 0xFFFD,
	0xD2C6: 0xFFFD,
	0xD2C7: 0xFFFD,
	0xD2C8: 0xFFFD,
	0xD2C9: 0xFFFD,
	0xD2CA: 0xFFFD,
	0xD2CB: 0xFFFD,
	0xD2CC: 0xFFFD,
	0xD2CD: 0xFFFD,
	0xD2CE: 0xFFFD,
	0xD2CF: 0xFFFD,
	0xD2D0: 0xFFFD,
	0xD2D1: 0xFFFD,
	0xD2D2: 0xFFFD,
	0xD2D3: 0xFFFD,
	0xD2D4: 0xFFFD,
	0xD2D5: 0xFFFD,
	0xD2D6: 0xFFFD,
	0xD2D7: 0xFFFD,
	0xD2D8: 0xFFFD,
	0xD2D9: 0xFFFD,
	0xD2DA: 0xFFFD,
	0xD2DB: 0xFFFD,
	0xD2DC: 0xFFFD,
	0xD2DD: 0xFFFD,
	0xD2DE: 0xFFFD,
	0xD2DF: 0xFFFD,
	0xD2E0: 0xFFFD,
	0xD2E1: 0xFFFD,
	0xD2E2: 0xFFFD,
	0xD2E3: 0xFFFD,
	0xD2E4: 0xFFFD,
	0xD2E5: 0xFFFD,
	0xD2E6: 0xFFFD,
	0xD2E7: 0xFFFD,
	0xD2E8: 0xFFFD,
	0xD2E9: 0xFFFD,
	0xD2EA: 0xFFFD,
	0xD2EB: 0xFFFD,
	0xD2EC: 0xFFFD,
	0xD2ED: 0xFFFD,
	0xD2EE: 0xFFFD,
	0xD2EF: 0xFFFD,
	0xD2F0: 0xFFFD,
	0xD2F1: 0xFFFD,
	0xD2F2: 0xFFFD,
	0xD2F3: 0xFFFD,
	0xD2F4: 0xFFFD,
	0xD2F5: 0xFFFD,
	0xD2F6: 0xFFFD,
	0xD2F7: 0xFFFD,
	0xD2F8: 0xFFFD,
	0xD2F9: 0xFFFD,
	0xD2FA: 0xFFFD,
	0xD2FB: 0xFFFD,
	0xD2FC: 0xFFFD,
	0xD2FD: 0xFFFD,
	0xD2FE: 0xFFFD,
	0xD2FF: 0xFFFD,
	0xD300: 0xFFFD,
	0xD301: 0xFFFD,
	0xD302: 0xFFFD,
	0xD303: 0xFFFD,
	0xD304: 0xFFFD,
	0xD305: 0xFFFD,
	0xD306: 0xFFFD,
	0xD307: 0xFFFD,
	0xD308: 0xFFFD,
	0xD309: 0xFFFD,
	0xD30A: 0xFFFD,
	0xD30B: 0xFFFD,
	0xD30C: 0xFFFD,
	0xD30D: 0xFFFD,
	0xD30E: 0xFFFD,
	0xD30F: 0xFFFD,
	0xD310: 0xFFFD,
	0xD311: 0xFFFD,
	0xD312: 0xFFFD,
	0xD313: 0xFFFD,
	0xD314: 0xFFFD,
	0xD315: 0xFFFD,
	0xD316: 0xFFFD,
	0xD317: 0xFFFD,
	0xD318: 0xFFFD,
	0xD319: 0xFFFD,
	0xD31A: 0xFFFD,
	0xD31B: 0xFFFD,
	0xD31C: 0xFFFD,
	0xD31D: 0xFFFD,
	0xD31E: 0xFFFD,
	0xD31F: 0xFFFD,
	0xD320: 0xFFFD,
	0xD321: 0xFFFD,
	0xD322: 0xFFFD,
	0xD323: 0xFFFD,
	0xD324: 0xFFFD,
	0xD325: 0xFFFD,
	0xD326: 0xFFFD,
	0xD327: 0xFFFD,
	0xD328: 0xFFFD,
	0xD329: 0xFFFD,
	0xD32A: 0xFFFD,
	0xD32B: 0xFFFD,
	0xD32C: 0xFFFD,
	0xD32D: 0xFFFD,
	0xD32E: 0xFFFD,
	0xD32F: 0xFFFD,
	0xD330: 0xFFFD,
	0xD331: 0xFFFD,
	0xD332: 0xFFFD,
	0xD333: 0xFFFD,
	0xD334: 0xFFFD,
	0xD335: 0xFFFD,
	0xD336: 0xFFFD,
	0xD337: 0xFFFD,
	0xD338: 0xFFFD,
	0xD339: 0xFFFD,
	0xD33A: 0xFFFD,
	0xD33B: 0xFFFD,
	0xD33C: 0xFFFD,
	0xD33D: 0xFFFD,
	0xD33E: 0xFFFD,
	0xD33F: 0xFFFD,
	0xD340: 0xFFFD,
	0xD341: 0xFFFD,
	0xD342: 0xFFFD,
	0xD343: 0xFFFD,
	0xD344: 0xFFFD,
	0xD345: 0xFFFD,
	0xD346: 0xFFFD,
	0xD347: 0xFFFD,
	0xD348: 0xFFFD,
	0xD349: 0xFFFD,
	0xD34A: 0xFFFD,
	0xD34B: 0xFFFD,
	0xD34C: 0xFFFD,
	0xD34D: 0xFFFD,
	0xD34E: 0xFFFD,
	0xD34F: 0xFFFD,
	0xD350: 0xFFFD,
	0xD351: 0xFFFD,
	0xD352: 0xFFFD,
	0xD353: 0xFFFD,
	0xD354: 0xFFFD,
	0xD355: 0xFFFD,
	0xD356: 0xFFFD,
	0xD357: 0xFFFD,
	0xD358: 0xFFFD,
	0xD359: 0xFFFD,
	0xD35A: 0xFFFD,
	0xD35B: 0xFFFD,
	0xD35C: 0xFFFD,
	0xD35D: 0xFFFD,
	0xD35E: 0xFFFD,
	0xD35F: 0xFFFD,
	0xD360: 0xFFFD,
	0xD361: 0xFFFD,
	0xD362: 0xFFFD,
	0xD363: 0xFFFD,
	0xD364: 0xFFFD,
	0xD365: 0xFFFD,
	0xD366: 0xFFFD,
	0xD367: 0xFFFD,
	0xD368: 0xFFFD,
	0xD369: 0xFFFD,
	0xD36A: 0xFFFD,
	0xD36B: 0xFFFD,
	0xD36C: 0xFFFD,
	0xD36D: 0xFFFD,
	0xD36E: 0xFFFD,
	0xD36F: 0xFFFD,
	0xD370: 0xFFFD,
	0xD371: 0xFFFD,
	0xD372: 0xFFFD,
	0xD373: 0xFFFD,
	0xD374: 0xFFFD,
	0xD375: 0xFFFD,
	0xD376: 0xFFFD,
	0xD377: 0xFFFD,
	0xD378: 0xFFFD,
	0xD379: 0xFFFD,
	0xD37A: 0xFFFD,
	0xD37B: 0xFFFD,
	0xD37C: 0xFFFD,
	0xD37D: 0xFFFD,
	0xD37E: 0xFFFD,
	0xD37F: 0xFFFD,
	0xD380: 0xFFFD,
	0xD381: 0xFFFD,
	0xD382: 0xFFFD,
	0xD383: 0xFFFD,
	0xD384: 0xFFFD,
	0xD385: 0xFFFD,
	0xD386: 0xFFFD,
	0xD387: 0xFFFD,
	0xD388: 0xFFFD,
	0xD389: 0xFFFD,
	0xD38A: 0xFFFD,
	0xD38B: 0xFFFD,
	0xD38C: 0xFFFD,
	0xD38D: 0xFFFD,
	0xD38E: 0xFFFD,
	0xD38F: 0xFFFD,
	0xD390: 0xFFFD,
	0xD391: 0xFFFD,
	0xD392: 0xFFFD,
	0xD393: 0xFFFD,
	0xD394: 0xFFFD,
	0xD395: 0xFFFD,
	0xD396: 0xFFFD,
	0xD397: 0xFFFD,
	0xD398: 0xFFFD,
	0xD399: 0xFFFD,
	0xD39A: 0xFFFD,
	0xD39B: 0xFFFD,
	0xD39C: 0xFFFD,
	0xD39D: 0xFFFD,
	0xD39E: 0xFFFD,
	0xD39F: 0xFFFD,
	0xD3A0: 0xFFFD,
	0xD3A1: 0xFFFD,
	0xD3A2: 0xFFFD,
	0xD3A3: 0xFFFD,
	0xD3A4: 0xFFFD,
	0xD3A5: 0xFFFD,
	0xD3A6: 0xFFFD,
	0xD3A7: 0xFFFD,
	0xD3A8: 0xFFFD,
	0xD3A9: 0xFFFD,
	0xD3AA: 0xFFFD,
	0xD3AB: 0xFFFD,
	0xD3AC: 0xFFFD,
	0xD3AD: 0xFFFD,
	0xD3AE: 0xFFFD,
	0xD3AF: 0xFFFD,
	0xD3B0: 0xFFFD,
	0xD3B1: 0xFFFD,
	0xD3B2: 0xFFFD,
	0xD3B3: 0xFFFD,
	0xD3B4: 0xFFFD,
	0xD3B5: 0xFFFD,
	0xD3B6: 0xFFFD,
	0xD3B7: 0xFFFD,
	0xD3B8: 0xFFFD,
	0xD3B9: 0xFFFD,
	0xD3BA: 0xFFFD,
	0xD3BB: 0xFFFD,
	0xD3BC: 0xFFFD,
	0xD3BD: 0xFFFD,
	0xD3BE: 0xFFFD,
	0xD3BF: 0xFFFD,
	0xD3C0: 0xFFFD,
	0xD3C1: 0xFFFD,
	0xD3C2: 0xFFFD,
	0xD3C3: 0xFFFD,
	0xD3C4: 0xFFFD,
	0xD3C5: 0xFFFD,
	0xD3C6: 0xFFFD,
	0xD3C7: 0xFFFD,
	0xD3C8: 0xFFFD,
	0xD3C9: 0xFFFD,
	0xD3CA: 0xFFFD,
	0xD3CB: 0xFFFD,
	0xD3CC: 0xFFFD,
	0xD3CD: 0xFFFD,
	0xD3CE: 0xFFFD,
	0xD3CF: 0xFFFD,
	0xD3D0: 0xFFFD,
	0xD3D1: 0xFFFD,
	0xD3D2: 0xFFFD,
	0xD3D3: 0xFFFD,
	0xD3D4: 0xFFFD,
	0xD3D5: 0xFFFD,
	0xD3D6: 0xFFFD,
	0xD3D7: 0xFFFD,
	0xD3D8: 0xFFFD,
	0xD3D9: 0xFFFD,
	0xD3DA: 0xFFFD,
	0xD3DB: 0xFFFD,
	0xD3DC: 0xFFFD,
	0xD3DD: 0xFFFD,
	0xD3DE: 0xFFFD,
	0xD3DF: 0xFFFD,
	0xD3E0: 0xFFFD,
	0xD3E1: 0xFFFD,
	0xD3E2: 0xFFFD,
	0xD3E3: 0xFFFD,
	0xD3E4: 0xFFFD,
	0xD3E5: 0xFFFD,
	0xD3E6: 0xFFFD,
	0xD3E7: 0xFFFD,
	0xD3E8: 0xFFFD,
	0xD3E9: 0xFFFD,
	0xD3EA: 0xFFFD,
	0xD3EB: 0xFFFD,
	0xD3EC: 0xFFFD,
	0xD3ED: 0xFFFD,
	0xD3EE: 0xFFFD,
	0xD3EF: 0xFFFD,
	0xD3F0: 0xFFFD,
	0xD3F1: 0xFFFD,
	0xD3F2: 0xFFFD,
	0xD3F3: 0xFFFD,
	0xD3F4: 0xFFFD,
	0xD3F5: 0xFFFD,
	0xD3F6: 0xFFFD,
	0xD3F7: 0xFFFD,
	0xD3F8: 0xFFFD,
	0xD3F9: 0xFFFD,
	0xD3FA: 0xFFFD,
	0xD3FB: 0xFFFD,
	0xD3FC: 0xFFFD,
	0xD3FD: 0xFFFD,
	0xD3FE: 0xFFFD,
	0xD3FF: 0xFFFD,
	0xD400: 0xFFFD,
	0xD401: 0xFFFD,
	0xD402: 0xFFFD,
	0xD403: 0xFFFD,
	0xD404: 0xFFFD,
	0xD405: 0xFFFD,
	0xD406: 0xFFFD,
	0xD407: 0xFFFD,
	0xD408: 0xFFFD,
	0xD409: 0xFFFD,
	0xD40A: 0xFFFD,
	0xD40B: 0xFFFD,
	0xD40C: 0xFFFD,
	0xD40D: 0xFFFD,
	0xD40E: 0xFFFD,
	0xD40F: 0xFFFD,
	0xD410: 0xFFFD,
	0xD411: 0xFFFD,
	0xD412: 0xFFFD,
	0xD413: 0xFFFD,
	0xD414: 0xFFFD,
	0xD415: 0xFFFD,
	0xD416: 0xFFFD,
	0xD417: 0xFFFD,
	0xD418: 0xFFFD,
	0xD419: 0xFFFD,
	0xD41A: 0xFFFD,
	0xD41B: 0xFFFD,
	0xD41C: 0xFFFD,
	0xD41D: 0xFFFD,
	0xD41E: 0xFFFD,
	0xD41F: 0xFFFD,
	0xD420: 0xFFFD,
	0xD421: 0xFFFD,
	0xD422: 0xFFFD,
	0xD423: 0xFFFD,
	0xD424: 0xFFFD,
	0xD425: 0xFFFD,
	0xD426: 0xFFFD,
	0xD427: 0xFFFD,
	0xD428: 0xFFFD,
	0xD429: 0xFFFD,
	0xD42A: 0xFFFD,
	0xD42B: 0xFFFD,
	0xD42C: 0xFFFD,
	0xD42D: 0xFFFD,
	0xD42E: 0xFFFD,
	0xD42F: 0xFFFD,
	0xD430: 0xFFFD,
	0xD431: 0xFFFD,
	0xD432: 0xFFFD,
	0xD433: 0xFFFD,
	0xD434: 0xFFFD,
	0xD435: 0xFFFD,
	0xD436: 0xFFFD,
	0xD437: 0xFFFD,
	0xD438: 0xFFFD,
	0xD439: 0xFFFD,
	0xD43A: 0xFFFD,
	0xD43B: 0xFFFD,
	0xD43C: 0xFFFD,
	0xD43D: 0xFFFD,
	0xD43E: 0xFFFD,
	0xD43F: 0xFFFD,
	0xD440: 0xFFFD,
	0xD441: 0xFFFD,
	0xD442: 0xFFFD,
	0xD443: 0xFFFD,
	0xD444: 0xFFFD,
	0xD445: 0xFFFD,
	0xD446: 0xFFFD,
	0xD447: 0xFFFD,
	0xD448: 0xFFFD,
	0xD449: 0xFFFD,
	0xD44A: 0xFFFD,
	0xD44B: 0xFFFD,
	0xD44C: 0xFFFD,
	0xD44D: 0xFFFD,
	0xD44E: 0xFFFD,
	0xD44F: 0xFFFD,
	0xD450: 0xFFFD,
	0xD451: 0xFFFD,
	0xD452: 0xFFFD,
	0xD453: 0xFFFD,
	0xD454: 0xFFFD,
	0xD455: 0xFFFD,
	0xD456: 0xFFFD,
	0xD457: 0xFFFD,
	0xD458: 0xFFFD,
	0xD459: 0xFFFD,
	0xD45A: 0xFFFD,
	0xD45B: 0xFFFD,
	0xD45C: 0xFFFD,
	0xD45D: 0xFFFD,
	0xD45E: 0xFFFD,
	0xD45F: 0xFFFD,
	0xD460: 0xFFFD,
	0xD461: 0xFFFD,
	0xD462: 0xFFFD,
	0xD463: 0xFFFD,
	0xD464: 0xFFFD,
	0xD465: 0xFFFD,
	0xD466: 0xFFFD,
	0xD467: 0xFFFD,
	0xD468: 0xFFFD,
	0xD469: 0xFFFD,
	0xD46A: 0xFFFD,
	0xD46B: 0xFFFD,
	0xD46C: 0xFFFD,
	0xD46D: 0xFFFD,
	0xD46E: 0xFFFD,
	0xD46F: 0xFFFD,
	0xD470: 0xFFFD,
	0xD471: 0xFFFD,
	0xD472: 0xFFFD,
	0xD473: 0xFFFD,
	0xD474: 0xFFFD,
	0xD475: 0xFFFD,
	0xD476: 0xFFFD,
	0xD477: 0xFFFD,
	0xD478: 0xFFFD,
	0xD479: 0xFFFD,
	0xD47A: 0xFFFD,
	0xD47B: 0xFFFD,
	0xD47C: 0xFFFD,
	0xD47D: 0xFFFD,
	0xD47E: 0xFFFD,
	0xD47F: 0xFFFD,
	0xD480: 0xFFFD,
	0xD481: 0xFFFD,
	0xD482: 0xFFFD,
	0xD483: 0xFFFD,
	0xD484: 0xFFFD,
	0xD485: 0xFFFD,
	0xD486: 0xFFFD,
	0xD487: 0xFFFD,
	0xD488: 0xFFFD,
	0xD489: 0xFFFD,
	0xD48A: 0xFFFD,
	0xD48B: 0xFFFD,
	0xD48C: 0xFFFD,
	0xD48D: 0xFFFD,
	0xD48E: 0xFFFD,
	0xD48F: 0xFFFD,
	0xD490: 0xFFFD,
	0xD491: 0xFFFD,
	0xD492: 0xFFFD,
	0xD493: 0xFFFD,
	0xD494: 0xFFFD,
	0xD495: 0xFFFD,
	0xD496: 0xFFFD,
	0xD497: 0xFFFD,
	0xD498: 0xFFFD,
	0xD499: 0xFFFD,
	0xD49A: 0xFFFD,
	0xD49B: 0xFFFD,
	0xD49C: 0xFFFD,
	0xD49D: 0xFFFD,
	0xD49E: 0xFFFD,
	0xD49F: 0xFFFD,
	0xD4A0: 0xFFFD,
	0xD4A1: 0xFFFD,
	0xD4A2: 0xFFFD,
	0xD4A3: 0xFFFD,
	0xD4A4: 0xFFFD,
	0xD4A5: 0xFFFD,
	0xD4A6: 0xFFFD,
	0xD4A7: 0xFFFD,
	0xD4A8: 0xFFFD,
	0xD4A9: 0xFFFD,
	0xD4AA: 0xFFFD,
	0xD4AB: 0xFFFD,
	0xD4AC: 0xFFFD,
	0xD4AD: 0xFFFD,
	0xD4AE: 0xFFFD,
	0xD4AF: 0xFFFD,
	0xD4B0: 0xFFFD,
	0xD4B1: 0xFFFD,
	0xD4B2: 0xFFFD,
	0xD4B3: 0xFFFD,
	0xD4B4: 0xFFFD,
	0xD4B5: 0xFFFD,
	0xD4B6: 0xFFFD,
	0xD4B7: 0xFFFD,
	0xD4B8: 0xFFFD,
	0xD4B9: 0xFFFD,
	0xD4BA: 0xFFFD,
	0xD4BB: 0xFFFD,
	0xD4BC: 0xFFFD,
	0xD4BD: 0xFFFD,
	0xD4BE: 0xFFFD,
	0xD4BF: 0xFFFD,
	0xD4C0: 0xFFFD,
	0xD4C1: 0xFFFD,
	0xD4C2: 0xFFFD,
	0xD4C3: 0xFFFD,
	0xD4C4: 0xFFFD,
	0xD4C5: 0xFFFD,
	0xD4C6: 0xFFFD,
	0xD4C7: 0xFFFD,
	0xD4C8: 0xFFFD,
	0xD4C9: 0xFFFD,
	0xD4CA: 0xFFFD,
	0xD4CB: 0xFFFD,
	0xD4CC: 0xFFFD,
	0xD4CD: 0xFFFD,
	0xD4CE: 0xFFFD,
	0xD4CF: 0xFFFD,
	0xD4D0: 0xFFFD,
	0xD4D1: 0xFFFD,
	0xD4D2: 0xFFFD,
	0xD4D3: 0xFFFD,
	0xD4D4: 0xFFFD,
	0xD4D5: 0xFFFD,
	0xD4D6: 0xFFFD,
	0xD4D7: 0xFFFD,
	0xD4D8: 0xFFFD,
	0xD4D9: 0xFFFD,
	0xD4DA: 0xFFFD,
	0xD4DB: 0xFFFD,
	0xD4DC: 0xFFFD,
	0xD4DD: 0xFFFD,
	0xD4DE: 0xFFFD,
	0xD4DF: 0xFFFD,
	0xD4E0: 0xFFFD,
	0xD4E1: 0xFFFD,
	0xD4E2: 0xFFFD,
	0xD4E3: 0xFFFD,
	0xD4E4: 0xFFFD,
	0xD4E5: 0xFFFD,
	0xD4E6: 0xFFFD,
	0xD4E7: 0xFFFD,
	0xD4E8: 0xFFFD,
	0xD4E9: 0xFFFD,
	0xD4EA: 0xFFFD,
	0xD4EB: 0xFFFD,
	0xD4EC: 0xFFFD,
	0xD4ED: 0xFFFD,
	0xD4EE: 0xFFFD,
	0xD4EF: 0xFFFD,
	0xD4F0: 0xFFFD,
	0xD4F1: 0xFFFD,
	0xD4F2: 0xFFFD,
	0xD4F3: 0xFFFD,
	0xD4F4: 0xFFFD,
	0xD4F5: 0xFFFD,
	0xD4F6: 0xFFFD,
	0xD4F7: 0xFFFD,
	0xD4F8: 0xFFFD,
	0xD4F9: 0xFFFD,
	0xD4FA: 0xFFFD,
	0xD4FB: 0xFFFD,
	0xD4FC: 0xFFFD,
	0xD4FD: 0xFFFD,
	0xD4FE: 0xFFFD,
	0xD4FF: 0xFFFD,
	0xD500: 0xFFFD,
	0xD501: 0xFFFD,
	0xD502: 0xFFFD,
	0xD503: 0xFFFD,
	0xD504: 0xFFFD,
	0xD505: 0xFFFD,
	0xD506: 0xFFFD,
	0xD507: 0xFFFD,
	0xD508: 0xFFFD,
	0xD509: 0xFFFD,
	0xD50A: 0xFFFD,
	0xD50B: 0xFFFD,
	0xD50C: 0xFFFD,
	0xD50D: 0xFFFD,
	0xD50E: 0xFFFD,
	0xD50F: 0xFFFD,
	0xD510: 0xFFFD,
	0xD511: 0xFFFD,
	0xD512: 0xFFFD,
	0xD513: 0xFFFD,
	0xD514: 0xFFFD,
	0xD515: 0xFFFD,
	0xD516: 0xFFFD,
	0xD517: 0xFFFD,
	0xD518: 0xFFFD,
	0xD519: 0xFFFD,
	0xD51A: 0xFFFD,
	0xD51B: 0xFFFD,
	0xD51C: 0xFFFD,
	0xD51D: 0xFFFD,
	0xD51E: 0xFFFD,
	0xD51F: 0xFFFD,
	0xD520: 0xFFFD,
	0xD521: 0xFFFD,
	0xD522: 0xFFFD,
	0xD523: 0xFFFD,
	0xD524: 0xFFFD,
	0xD525: 0xFFFD,
	0xD526: 0xFFFD,
	0xD527: 0xFFFD,
	0xD528: 0xFFFD,
	0xD529: 0xFFFD,
	0xD52A: 0xFFFD,
	0xD52B: 0xFFFD,
	0xD52C: 0xFFFD,
	0xD52D: 0xFFFD,
	0xD52E: 0xFFFD,
	0xD52F: 0xFFFD,
	0xD530: 0xFFFD,
	0xD531: 0xFFFD,
	0xD532: 0xFFFD,
	0xD533: 0xFFFD,
	0xD534: 0xFFFD,
	0xD535: 0xFFFD,
	0xD536: 0xFFFD,
	0xD537: 0xFFFD,
	0xD538: 0xFFFD,
	0xD539: 0xFFFD,
	0xD53A: 0xFFFD,
	0xD53B: 0xFFFD,
	0xD53C: 0xFFFD,
	0xD53D: 0xFFFD,
	0xD53E: 0xFFFD,
	0xD53F: 0xFFFD,
	0xD540: 0xFFFD,
	0xD541: 0xFFFD,
	0xD542: 0xFFFD,
	0xD543: 0xFFFD,
	0xD544: 0xFFFD,
	0xD545: 0xFFFD,
	0xD546: 0xFFFD,
	0xD547: 0xFFFD,
	0xD548: 0xFFFD,
	0xD549: 0xFFFD,
	0xD54A: 0xFFFD,
	0xD54B: 0xFFFD,
	0xD54C: 0xFFFD,
	0xD54D: 0xFFFD,
	0xD54E: 0xFFFD,
	0xD54F: 0xFFFD,
	0xD550: 0xFFFD,
	0xD551: 0xFFFD,
	0xD552: 0xFFFD,
	0xD553: 0xFFFD,
	0xD554: 0xFFFD,
	0xD555: 0xFFFD,
	0xD556: 0xFFFD,
	0xD557: 0xFFFD,
	0xD558: 0xFFFD,
	0xD559: 0xFFFD,
	0xD55A: 0xFFFD,
	0xD55B: 0xFFFD,
	0xD55C: 0xFFFD,
	0xD55D: 0xFFFD,
	0xD55E: 0xFFFD,
	0xD55F: 0xFFFD,
	0xD560: 0xFFFD,
	0xD561: 0xFFFD,
	0xD562: 0xFFFD,
	0xD563: 0xFFFD,
	0xD564: 0xFFFD,
	0xD565: 0xFFFD,
	0xD566: 0xFFFD,
	0xD567: 0xFFFD,
	0xD568: 0xFFFD,
	0xD569: 0xFFFD,
	0xD56A: 0xFFFD,
	0xD56B: 0xFFFD,
	0xD56C: 0xFFFD,
	0xD56D: 0xFFFD,
	0xD56E: 0xFFFD,
	0xD56F: 0xFFFD,
	0xD570: 0xFFFD,
	0xD571: 0xFFFD,
	0xD572: 0xFFFD,
	0xD573: 0xFFFD,
	0xD574: 0xFFFD,
	0xD575: 0xFFFD,
	0xD576: 0xFFFD,
	0xD577: 0xFFFD,
	0xD578: 0xFFFD,
	0xD579: 0xFFFD,
	0xD57A: 0xFFFD,
	0xD57B: 0xFFFD,
	0xD57C: 0xFFFD,
	0xD57D: 0xFFFD,
	0xD57E: 0xFFFD,
	0xD57F: 0xFFFD,
	0xD580: 0xFFFD,
	0xD581: 0xFFFD,
	0xD582: 0xFFFD,
	0xD583: 0xFFFD,
	0xD584: 0xFFFD,
	0xD585: 0xFFFD,
	0xD586: 0xFFFD,
	0xD587: 0xFFFD,
	0xD588: 0xFFFD,
	0xD589: 0xFFFD,
	0xD58A: 0xFFFD,
	0xD58B: 0xFFFD,
	0xD58C: 0xFFFD,
	0xD58D: 0xFFFD,
	0xD58E: 0xFFFD,
	0xD58F: 0xFFFD,
	0xD590: 0xFFFD,
	0xD591: 0xFFFD,
	0xD592: 0xFFFD,
	0xD593: 0xFFFD,
	0xD594: 0xFFFD,
	0xD595: 0xFFFD,
	0xD596: 0xFFFD,
	0xD597: 0xFFFD,
	0xD598: 0xFFFD,
	0xD599: 0xFFFD,
	0xD59A: 0xFFFD,
	0xD59B: 0xFFFD,
	0xD59C: 0xFFFD,
	0xD59D: 0xFFFD,
	0xD59E: 0xFFFD,
	0xD59F: 0xFFFD,
	0xD5A0: 0xFFFD,
	0xD5A1: 0xFFFD,
	0xD5A2: 0xFFFD,
	0xD5A3: 0xFFFD,
	0xD5A4: 0xFFFD,
	0xD5A5: 0xFFFD,
	0xD5A6: 0xFFFD,
	0xD5A7: 0xFFFD,
	0xD5A8: 0xFFFD,
	0xD5A9: 0xFFFD,
	0xD5AA: 0xFFFD,
	0xD5AB: 0xFFFD,
	0xD5AC: 0xFFFD,
	0xD5AD: 0xFFFD,
	0xD5AE: 0xFFFD,
	0xD5AF: 0xFFFD,
	0xD5B0: 0xFFFD,
	0xD5B1: 0xFFFD,
	0xD5B2: 0xFFFD,
	0xD5B3: 0xFFFD,
	0xD5B4: 0xFFFD,
	0xD5B5: 0xFFFD,
	0xD5B6: 0xFFFD,
	0xD5B7: 0xFFFD,
	0xD5B8: 0xFFFD,
	0xD5B9: 0xFFFD,
	0xD5BA: 0xFFFD,
	0xD5BB: 0xFFFD,
	0xD5BC: 0xFFFD,
	0xD5BD: 0xFFFD,
	0xD5BE: 0xFFFD,
	0xD5BF: 0xFFFD,
	0xD5C0: 0xFFFD,
	0xD5C1: 0xFFFD,
	0xD5C2: 0xFFFD,
	0xD5C3: 0xFFFD,
	0xD5C4: 0xFFFD,
	0xD5C5: 0xFFFD,
	0xD5C6: 0xFFFD,
	0xD5C7: 0xFFFD,
	0xD5C8: 0xFFFD,
	0xD5C9: 0xFFFD,
	0xD5CA: 0xFFFD,
	0xD5CB: 0xFFFD,
	0xD5CC: 0xFFFD,
	0xD5CD: 0xFFFD,
	0xD5CE: 0xFFFD,
	0xD5CF: 0xFFFD,
	0xD5D0: 0xFFFD,
	0xD5D1: 0xFFFD,
	0xD5D2: 0xFFFD,
	0xD5D3: 0xFFFD,
	0xD5D4: 0xFFFD,
	0xD5D5: 0xFFFD,
	0xD5D6: 0xFFFD,
	0xD5D7: 0xFFFD,
	0xD5D8: 0xFFFD,
	0xD5D9: 0xFFFD,
	0xD5DA: 0xFFFD,
	0xD5DB: 0xFFFD,
	0xD5DC: 0xFFFD,
	0xD5DD: 0xFFFD,
	0xD5DE: 0xFFFD,
	0xD5DF: 0xFFFD,
	0xD5E0: 0xFFFD,
	0xD5E1: 0xFFFD,
	0xD5E2: 0xFFFD,
	0xD5E3: 0xFFFD,
	0xD5E4: 0xFFFD,
	0xD5E5: 0xFFFD,
	0xD5E6: 0xFFFD,
	0xD5E7: 0xFFFD,
	0xD5E8: 0xFFFD,
	0xD5E9: 0xFFFD,
	0xD5EA: 0xFFFD,
	0xD5EB: 0xFFFD,
	0xD5EC: 0xFFFD,
	0xD5ED: 0xFFFD,
	0xD5EE: 0xFFFD,
	0xD5EF: 0xFFFD,
	0xD5F0: 0xFFFD,
	0xD5F1: 0xFFFD,
	0xD5F2: 0xFFFD,
	0xD5F3: 0xFFFD,
	0xD5F4: 0xFFFD,
	0xD5F5: 0xFFFD,
	0xD5F6: 0xFFFD,
	0xD5F7: 0xFFFD,
	0xD5F8: 0xFFFD,
	0xD5F9: 0xFFFD,
	0xD5FA: 0xFFFD,
	0xD5FB: 0xFFFD,
	0xD5FC: 0xFFFD,
	0xD5FD: 0xFFFD,
	0xD5FE: 0xFFFD,
	0xD5FF: 0xFFFD,
	0xD600: 0xFFFD,
	0xD601: 0xFFFD,
	0xD602: 0xFFFD,
	0xD603: 0xFFFD,
	0xD604: 0xFFFD,
	0xD605: 0xFFFD,
	0xD606: 0xFFFD,
	0xD607: 0xFFFD,
	0xD608: 0xFFFD,
	0xD609: 0xFFFD,
	0xD60A: 0xFFFD,
	0xD60B: 0xFFFD,
	0xD60C: 0xFFFD,
	0xD60D: 0xFFFD,
	0xD60E: 0xFFFD,
	0xD60F: 0xFFFD,
	0xD610: 0xFFFD,
	0xD611: 0xFFFD,
	0xD612: 0xFFFD,
	0xD613: 0xFFFD,
	0xD614: 0xFFFD,
	0xD615: 0xFFFD,
	0xD616: 0xFFFD,
	0xD617: 0xFFFD,
	0xD618: 0xFFFD,
	0xD619: 0xFFFD,
	0xD61A: 0xFFFD,
	0xD61B: 0xFFFD,
	0xD61C: 0xFFFD,
	0xD61D: 0xFFFD,
	0xD61E: 0xFFFD,
	0xD61F: 0xFFFD,
	0xD620: 0xFFFD,
	0xD621: 0xFFFD,
	0xD622: 0xFFFD,
	0xD623: 0xFFFD,
	0xD624: 0xFFFD,
	0xD625: 0xFFFD,
	0xD626: 0xFFFD,
	0xD627: 0xFFFD,
	0xD628: 0xFFFD,
	0xD629: 0xFFFD,
	0xD62A: 0xFFFD,
	0xD62B: 0xFFFD,
	0xD62C: 0xFFFD,
	0xD62D: 0xFFFD,
	0xD62E: 0xFFFD,
	0xD62F: 0xFFFD,
	0xD630: 0xFFFD,
	0xD631: 0xFFFD,
	0xD632: 0xFFFD,
	0xD633: 0xFFFD,
	0xD634: 0xFFFD,
	0xD635: 0xFFFD,
	0xD636: 0xFFFD,
	0xD637: 0xFFFD,
	0xD638: 0xFFFD,
	0xD639: 0xFFFD,
	0xD63A: 0xFFFD,
	0xD63B: 0xFFFD,
	0xD63C: 0xFFFD,
	0xD63D: 0xFFFD,
	0xD63E: 0xFFFD,
	0xD63F: 0xFFFD,
	0xD640: 0xFFFD,
	0xD641: 0xFFFD,
	0xD642: 0xFFFD,
	0xD643: 0xFFFD,
	0xD644: 0xFFFD,
	0xD645: 0xFFFD,
	0xD646: 0xFFFD,
	0xD647: 0xFFFD,
	0xD648: 0xFFFD,
	0xD649: 0xFFFD,
	0xD64A: 0xFFFD,
	0xD64B: 0xFFFD,
	0xD64C: 0xFFFD,
	0xD64D: 0xFFFD,
	0xD64E: 0xFFFD,
	0xD64F: 0xFFFD,
	0xD650: 0xFFFD,
	0xD651: 0xFFFD,
	0xD652: 0xFFFD,
	0xD653: 0xFFFD,
	0xD654: 0xFFFD,
	0xD655: 0xFFFD,
	0xD656: 0xFFFD,
	0xD657: 0xFFFD,
	0xD658: 0xFFFD,
	0xD659: 0xFFFD,
	0xD65A: 0xFFFD,
	0xD65B: 0xFFFD,
	0xD65C: 0xFFFD,
	0xD65D: 0xFFFD,
	0xD65E: 0xFFFD,
	0xD65F: 0xFFFD,
	0xD660: 0xFFFD,
	0xD661: 0xFFFD,
	0xD662: 0xFFFD,
	0xD663: 0xFFFD,
	0xD664: 0xFFFD,
	0xD665: 0xFFFD,
	0xD666: 0xFFFD,
	0xD667: 0xFFFD,
	0xD668: 0xFFFD,
	0xD669: 0xFFFD,
	0xD66A: 0xFFFD,
	0xD66B: 0xFFFD,
	0xD66C: 0xFFFD,
	0xD66D: 0xFFFD,
	0xD66E: 0xFFFD,
	0xD66F: 0xFFFD,
	0xD670: 0xFFFD,
	0xD671: 0xFFFD,
	0xD672: 0xFFFD,
	0xD673: 0xFFFD,
	0xD674: 0xFFFD,
	0xD675: 0xFFFD,
	0xD676: 0xFFFD,
	0xD677: 0xFFFD,
	0xD678: 0xFFFD,
	0xD679: 0xFFFD,
	0xD67A: 0xFFFD,
	0xD67B: 0xFFFD,
	0xD67C: 0xFFFD,
	0xD67D: 0xFFFD,
	0xD67E: 0xFFFD,
	0xD67F: 0xFFFD,
	0xD680: 0xFFFD,
	0xD681: 0xFFFD,
	0xD682: 0xFFFD,
	0xD683: 0xFFFD,
	0xD684: 0xFFFD,
	0xD685: 0xFFFD,
	0xD686: 0xFFFD,
	0xD687: 0xFFFD,
	0xD688: 0xFFFD,
	0xD689: 0xFFFD,
	0xD68A: 0xFFFD,
	0xD68B: 0xFFFD,
	0xD68C: 0xFFFD,
	0xD68D: 0xFFFD,
	0xD68E: 0xFFFD,
	0xD68F: 0xFFFD,
	0xD690: 0xFFFD,
	0xD691: 0xFFFD,
	0xD692: 0xFFFD,
	0xD693: 0xFFFD,
	0xD694: 0xFFFD,
	0xD695: 0xFFFD,
	0xD696: 0xFFFD,
	0xD697: 0xFFFD,
	0xD698: 0xFFFD,
	0xD699: 0xFFFD,
	0xD69A: 0xFFFD,
	0xD69B: 0xFFFD,
	0xD69C: 0xFFFD,
	0xD69D: 0xFFFD,
	0xD69E: 0xFFFD,
	0xD69F: 0xFFFD,
	0xD6A0: 0xFFFD,
	0xD6A1: 0xFFFD,
	0xD6A2: 0xFFFD,
	0xD6A3: 0xFFFD,
	0xD6A4: 0xFFFD,
	0xD6A5: 0xFFFD,
	0xD6A6: 0xFFFD,
	0xD6A7: 0xFFFD,
	0xD6A8: 0xFFFD,
	0xD6A9: 0xFFFD,
	0xD6AA: 0xFFFD,
	0xD6AB: 0xFFFD,
	0xD6AC: 0xFFFD,
	0xD6AD: 0xFFFD,
	0xD6AE: 0xFFFD,
	0xD6AF: 0xFFFD,
	0xD6B0: 0xFFFD,
	0xD6B1: 0xFFFD,
	0xD6B2: 0xFFFD,
	0xD6B3: 0xFFFD,
	0xD6B4: 0xFFFD,
	0xD6B5: 0xFFFD,
	0xD6B6: 0xFFFD,
	0xD6B7: 0xFFFD,
	0xD6B8: 0xFFFD,
	0xD6B9: 0xFFFD,
	0xD6BA: 0xFFFD,
	0xD6BB: 0xFFFD,
	0xD6BC: 0xFFFD,
	0xD6BD: 0xFFFD,
	0xD6BE: 0xFFFD,
	0xD6BF: 0xFFFD,
	0xD6C0: 0xFFFD,
	0xD6C1: 0xFFFD,
	0xD6C2: 0xFFFD,
	0xD6C3: 0xFFFD,
	0xD6C4: 0xFFFD,
	0xD6C5: 0xFFFD,
	0xD6C6: 0xFFFD,
	0xD6C7: 0xFFFD,
	0xD6C8: 0xFFFD,
	0xD6C9: 0xFFFD,
	0xD6CA: 0xFFFD,
	0xD6CB: 0xFFFD,
	0xD6CC: 0xFFFD,
	0xD6CD: 0xFFFD,
	0xD6CE: 0xFFFD,
	0xD6CF: 0xFFFD,
	0xD6D0: 0xFFFD,
	0xD6D1: 0xFFFD,
	0xD6D2: 0xFFFD,
	0xD6D3: 0xFFFD,
	0xD6D4: 0xFFFD,
	0xD6D5: 0xFFFD,
	0xD6D6: 0xFFFD,
	0xD6D7: 0xFFFD,
	0xD6D8: 0xFFFD,
	0xD6D9: 0xFFFD,
	0xD6DA: 0xFFFD,
	0xD6DB: 0xFFFD,
	0xD6DC: 0xFFFD,
	0xD6DD: 0xFFFD,
	0xD6DE: 0xFFFD,
	0xD6DF: 0xFFFD,
	0xD6E0: 0xFFFD,
	0xD6E1: 0xFFFD,
	0xD6E2: 0xFFFD,
	0xD6E3: 0xFFFD,
	0xD6E4: 0xFFFD,
	0xD6E5: 0xFFFD,
	0xD6E6: 0xFFFD,
	0xD6E7: 0xFFFD,
	0xD6E8: 0xFFFD,
	0xD6E9: 0xFFFD,
	0xD6EA: 0xFFFD,
	0xD6EB: 0xFFFD,
	0xD6EC: 0xFFFD,
	0xD6ED: 0xFFFD,
	0xD6EE: 0xFFFD,
	0xD6EF: 0xFFFD,
	0xD6F0: 0xFFFD,
	0xD6F1: 0xFFFD,
	0xD6F2: 0xFFFD,
	0xD6F3: 0xFFFD,
	0xD6F4: 0xFFFD,
	0xD6F5: 0xFFFD,
	0xD6F6: 0xFFFD,
	0xD6F7: 0xFFFD,
	0xD6F8: 0xFFFD,
	0xD6F9: 0xFFFD,
	0xD6FA: 0xFFFD,
	0xD6FB: 0xFFFD,
	0xD6FC: 0xFFFD,
	0xD6FD: 0xFFFD,
	0xD6FE: 0xFFFD,
	0xD6FF: 0xFFFD,
	0xD700: 0xFFFD,
	0xD701: 0xFFFD,
	0xD702: 0xFFFD,
	0xD703: 0xFFFD,
	0xD704: 0xFFFD,
	0xD705: 0xFFFD,
	0xD706: 0xFFFD,
	0xD707: 0xFFFD,
	0xD708: 0xFFFD,
	0xD709: 0xFFFD,
	0xD70A: 0xFFFD,
	0xD70B: 0xFFFD,
	0xD70C: 0xFFFD,
	0xD70D: 0xFFFD,
	0xD70E: 0xFFFD,
	0xD70F: 0xFFFD,
	0xD710: 0xFFFD,
	0xD711: 0xFFFD,
	0xD712: 0xFFFD,
	0xD713: 0xFFFD,
	0xD714: 0xFFFD,
	0xD715: 0xFFFD,
	0xD716: 0xFFFD,
	0xD717: 0xFFFD,
	0xD718: 0xFFFD,
	0xD719: 0xFFFD,
	0xD71A: 0xFFFD,
	0xD71B: 0xFFFD,
	0xD71C: 0xFFFD,
	0xD71D: 0xFFFD,
	0xD71E: 0xFFFD,
	0xD71F: 0xFFFD,
	0xD720: 0xFFFD,
	0xD721: 0xFFFD,
	0xD722: 0xFFFD,
	0xD723: 0xFFFD,
	0xD724: 0xFFFD,
	0xD725: 0xFFFD,
	0xD726: 0xFFFD,
	0xD727: 0xFFFD,
	0xD728: 0xFFFD,
	0xD729: 0xFFFD,
	0xD72A: 0xFFFD,
	0xD72B: 0xFFFD,
	0xD72C: 0xFFFD,
	0xD72D: 0xFFFD,
	0xD72E: 0xFFFD,
	0xD72F: 0xFFFD,
	0xD730: 0xFFFD,
	0xD731: 0xFFFD,
	0xD732: 0xFFFD,
	0xD733: 0xFFFD,
	0xD734: 0xFFFD,
	0xD735: 0xFFFD,
	0xD736: 0xFFFD,
	0xD737: 0xFFFD,
	0xD738: 0xFFFD,
	0xD739: 0xFFFD,
	0xD73A: 0xFFFD,
	0xD73B: 0xFFFD,
	0xD73C: 0xFFFD,
	0xD73D: 0xFFFD,
	0xD73E: 0xFFFD,
	0xD73F: 0xFFFD,
	0xD740: 0xFFFD,
	0xD741: 0xFFFD,
	0xD742: 0xFFFD,
	0xD743: 0xFFFD,
	0xD744: 0xFFFD,
	0xD745: 0xFFFD,
	0xD746: 0xFFFD,
	0xD747: 0xFFFD,
	0xD748: 0xFFFD,
	0xD749: 0xFFFD,
	0xD74A: 0xFFFD,
	0xD74B: 0xFFFD,
	0xD74C: 0xFFFD,
	0xD74D: 0xFFFD,
	0xD74E: 0xFFFD,
	0xD74F: 0xFFFD,
	0xD750: 0xFFFD,
	0xD751: 0xFFFD,
	0xD752: 0xFFFD,
	0xD753: 0xFFFD,
	0xD754: 0xFFFD,
	0xD755: 0xFFFD,
	0xD756: 0xFFFD,
	0xD757: 0xFFFD,
	0xD758: 0xFFFD,
	0xD759: 0xFFFD,
	0xD75A: 0xFFFD,
	0xD75B: 0xFFFD,
	0xD75C: 0xFFFD,
	0xD75D: 0xFFFD,
	0xD75E: 0xFFFD,
	0xD75F: 0xFFFD,
	0xD760: 0xFFFD,
	0xD761: 0xFFFD,
	0xD762: 0xFFFD,
	0xD763: 0xFFFD,
	0xD764: 0xFFFD,
	0xD765: 0xFFFD,
	0xD766: 0xFFFD,
	0xD767: 0xFFFD,
	0xD768: 0xFFFD,
	0xD769: 0xFFFD,
	0xD76A: 0xFFFD,
	0xD76B: 0xFFFD,
	0xD76C: 0xFFFD,
	0xD76D: 0xFFFD,
	0xD76E: 0xFFFD,
	0xD76F: 0xFFFD,
	0xD770: 0xFFFD,
	0xD771: 0xFFFD,
	0xD772: 0xFFFD,
	0xD773: 0xFFFD,
	0xD774: 0xFFFD,
	0xD775: 0xFFFD,
	0xD776: 0xFFFD,
	0xD777: 0xFFFD,
	0xD778: 0xFFFD,
	0xD779: 0xFFFD,
	0xD77A: 0xFFFD,
	0xD77B: 0xFFFD,
	0xD77C: 0xFFFD,
	0xD77D: 0xFFFD,
	0xD77E: 0xFFFD,
	0xD77F: 0xFFFD,
	0xD780: 0xFFFD,
	0xD781: 0xFFFD,
	0xD782: 0xFFFD,
	0xD783: 0xFFFD,
	0xD784: 0xFFFD,
	0xD785: 0xFFFD,
	0xD786: 0xFFFD,
	0xD787: 0xFFFD,
	0xD788: 0xFFFD,
	0xD789: 0xFFFD,
	0xD78A: 0xFFFD,
	0xD78B: 0xFFFD,
	0xD78C: 0xFFFD,
	0xD78D: 0xFFFD,
	0xD78E: 0xFFFD,
	0xD78F: 0xFFFD,
	0xD790: 0xFFFD,
	0xD791: 0xFFFD,
	0xD792: 0xFFFD,
	0xD793: 0xFFFD,
	0xD794: 0xFFFD,
	0xD795: 0xFFFD,
	0xD796: 0xFFFD,
	0xD797: 0xFFFD,
	0xD798: 0xFFFD,
	0xD799: 0xFFFD,
	0xD79A: 0xFFFD,
	0xD79B: 0xFFFD,
	0xD79C: 0xFFFD,
	0xD79D: 0xFFFD,
	0xD79E: 0xFFFD,
	0xD79F: 0xFFFD,
	0xD7A0: 0xFFFD,
	0xD7A1: 0xFFFD,
	0xD7A2: 0xFFFD,
	0xD7A3: 0xFFFD,
	0xD7A4: 0xFFFD,
	0xD7A5: 0xFFFD,
	0xD7A6: 0xFFFD,
	0xD7A7: 0xFFFD,
	0xD7A8: 0xFFFD,
	0xD7A9: 0xFFFD,
	0xD7AA: 0xFFFD,
	0xD7AB: 0xFFFD,
	0xD7AC: 0xFFFD,
	0xD7AD: 0xFFFD,
	0xD7AE: 0xFFFD,
	0xD7AF: 0xFFFD,
	0xD7B0: 0xFFFD,
	0xD7B1: 0xFFFD,
	0xD7B2: 0xFFFD,
	0xD7B3: 0xFFFD,
	0xD7B4: 0xFFFD,
	0xD7B5: 0xFFFD,
	0xD7B6: 0xFFFD,
	0xD7B7: 0xFFFD,
	0xD7B8: 0xFFFD,
	0xD7B9: 0xFFFD,
	0xD7BA: 0xFFFD,
	0xD7BB: 0xFFFD,
	0xD7BC: 0xFFFD,
	0xD7BD: 0xFFFD,
	0xD7BE: 0xFFFD,
	0xD7BF: 0xFFFD,
	0xD7C0: 0xFFFD,
	0xD7C1: 0xFFFD,
	0xD7C2: 0xFFFD,
	0xD7C3: 0xFFFD,
	0xD7C4: 0xFFFD,
	0xD7C5: 0xFFFD,
	0xD7C6: 0xFFFD,
	0xD7C7: 0xFFFD,
	0xD7C8: 0xFFFD,
	0xD7C9: 0xFFFD,
	0xD7CA: 0xFFFD,
	0xD7CB: 0xFFFD,
	0xD7CC: 0xFFFD,
	0xD7CD: 0xFFFD,
	0xD7CE: 0xFFFD,
	0xD7CF: 0xFFFD,
	0xD7D0: 0xFFFD,
	0xD7D1: 0xFFFD,
	0xD7D2: 0xFFFD,
	0xD7D3: 0xFFFD,
	0xD7D4: 0xFFFD,
	0xD7D5: 0xFFFD,
	0xD7D6: 0xFFFD,
	0xD7D7: 0xFFFD,
	0xD7D8: 0xFFFD,
	0xD7D9: 0xFFFD,
	0xD7DA: 0xFFFD,
	0xD7DB: 0xFFFD,
	0xD7DC: 0xFFFD,
	0xD7DD: 0xFFFD,
	0xD7DE: 0xFFFD,
	0xD7DF: 0xFFFD,
	0xD7E0: 0xFFFD,
	0xD7E1: 0xFFFD,
	0xD7E2: 0xFFFD,
	0xD7E3: 0xFFFD,
	0xD7E4: 0xFFFD,
	0xD7E5: 0xFFFD,
	0xD7E6: 0xFFFD,
	0xD7E7: 0xFFFD,
	0xD7E8: 0xFFFD,
	0xD7E9: 0xFFFD,
	0xD7EA: 0xFFFD,
	0xD7EB: 0xFFFD,
	0xD7EC: 0xFFFD,
	0xD7ED: 0xFFFD,
	0xD7EE: 0xFFFD,
	0xD7EF: 0xFFFD,
	0xD7F0: 0xFFFD,
	0xD7F1: 0xFFFD,
	0xD7F2: 0xFFFD,
	0xD7F3: 0xFFFD,
	0xD7F4: 0xFFFD,
	0xD7F5: 0xFFFD,
	0xD7F6: 0xFFFD,
	0xD7F7: 0xFFFD,
	0xD7F8: 0xFFFD,
	0xD7F9: 0xFFFD,
	0xD7FA: 0xFFFD,
	0xD7FB: 0xFFFD,
	0xD7FC: 0xFFFD,
	0xD7FD: 0xFFFD,
	0xD7FE: 0xFFFD,
	0xD7FF: 0xFFFD,
	0xD800: 0xFFFD,
	0xD801: 0xFFFD,
	0xD802: 0xFFFD,
	0xD803: 0xFFFD,
	0xD804: 0xFFFD,
	0xD805: 0xFFFD,
	0xD806: 0xFFFD,
	0xD807: 0xFFFD,
	0xD808: 0xFFFD,
	0xD809: 0xFFFD,
	0xD80A: 0xFFFD,
	0xD80B: 0xFFFD,
	0xD80C: 0xFFFD,
	0xD80D: 0xFFFD,
	0xD80E: 0xFFFD,
	0xD80F: 0xFFFD,
	0xD810: 0xFFFD,
	0xD811: 0xFFFD,
	0xD812: 0xFFFD,
	0xD813: 0xFFFD,
	0xD814: 0xFFFD,
	0xD815: 0xFFFD,
	0xD816: 0xFFFD,
	0xD817: 0xFFFD,
	0xD818: 0xFFFD,
	0xD819: 0xFFFD,
	0xD81A: 0xFFFD,
	0xD81B: 0xFFFD,
	0xD81C: 0xFFFD,
	0xD81D: 0xFFFD,
	0xD81E: 0xFFFD,
	0xD81F: 0xFFFD,
	0xD820: 0xFFFD,
	0xD821: 0xFFFD,
	0xD822: 0xFFFD,
	0xD823: 0xFFFD,
	0xD824: 0xFFFD,
	0xD825: 0xFFFD,
	0xD826: 0xFFFD,
	0xD827: 0xFFFD,
	0xD828: 0xFFFD,
	0xD829: 0xFFFD,
	0xD82A: 0xFFFD,
	0xD82B: 0xFFFD,
	0xD82C: 0xFFFD,
	0xD82D: 0xFFFD,
	0xD82E: 0xFFFD,
	0xD82F: 0xFFFD,
	0xD830: 0xFFFD,
	0xD831: 0xFFFD,
	0xD832: 0xFFFD,
	0xD833: 0xFFFD,
	0xD834: 0xFFFD,
	0xD835: 0xFFFD,
	0xD836: 0xFFFD,
	0xD837: 0xFFFD,
	0xD838: 0xFFFD,
	0xD839: 0xFFFD,
	0xD83A: 0xFFFD,
	0xD83B: 0xFFFD,
	0xD83C: 0xFFFD,
	0xD83D: 0xFFFD,
	0xD83E: 0xFFFD,
	0xD83F: 0xFFFD,
	0xD840: 0xFFFD,
	0xD841: 0xFFFD,
	0xD842: 0xFFFD,
	0xD843: 0xFFFD,
	0xD844: 0xFFFD,
	0xD845: 0xFFFD,
	0xD846: 0xFFFD,
	0xD847: 0xFFFD,
	0xD848: 0xFFFD,
	0xD849: 0xFFFD,
	0xD84A: 0xFFFD,
	0xD84B: 0xFFFD,
	0xD84C: 0xFFFD,
	0xD84D: 0xFFFD,
	0xD84E: 0xFFFD,
	0xD84F: 0xFFFD,
	0xD850: 0xFFFD,
	0xD851: 0xFFFD,
	0xD852: 0xFFFD,
	0xD853: 0xFFFD,
	0xD854: 0xFFFD,
	0xD855: 0xFFFD,
	0xD856: 0xFFFD,
	0xD857: 0xFFFD,
	0xD858: 0xFFFD,
	0xD859: 0xFFFD,
	0xD85A: 0xFFFD,
	0xD85B: 0xFFFD,
	0xD85C: 0xFFFD,
	0xD85D: 0xFFFD,
	0xD85E: 0xFFFD,
	0xD85F: 0xFFFD,
	0xD860: 0xFFFD,
	0xD861: 0xFFFD,
	0xD862: 0xFFFD,
	0xD863: 0xFFFD,
	0xD864: 0xFFFD,
	0xD865: 0xFFFD,
	0xD866: 0xFFFD,
	0xD867: 0xFFFD,
	0xD868: 0xFFFD,
	0xD869: 0xFFFD,
	0xD86A: 0xFFFD,
	0xD86B: 0xFFFD,
	0xD86C: 0xFFFD,
	0xD86D: 0xFFFD,
	0xD86E: 0xFFFD,
	0xD86F: 0xFFFD,
	0xD870: 0xFFFD,
	0xD871: 0xFFFD,
	0xD872: 0xFFFD,
	0xD873: 0xFFFD,
	0xD874: 0xFFFD,
	0xD875: 0xFFFD,
	0xD876: 0xFFFD,
	0xD877: 0xFFFD,
	0xD878: 0xFFFD,
	0xD879: 0xFFFD,
	0xD87A: 0xFFFD,
	0xD87B: 0xFFFD,
	0xD87C: 0xFFFD,
	0xD87D: 0xFFFD,
	0xD87E: 0xFFFD,
	0xD87F: 0xFFFD,
	0xD880: 0xFFFD,
	0xD881: 0xFFFD,
	0xD882: 0xFFFD,
	0xD883: 0xFFFD,
	0xD884: 0xFFFD,
	0xD885: 0xFFFD,
	0xD886: 0xFFFD,
	0xD887: 0xFFFD,
	0xD888: 0xFFFD,
	0xD889: 0xFFFD,
	0xD88A: 0xFFFD,
	0xD88B: 0xFFFD,
	0xD88C: 0xFFFD,
	0xD88D: 0xFFFD,
	0xD88E: 0xFFFD,
	0xD88F: 0xFFFD,
	0xD890: 0xFFFD,
	0xD891: 0xFFFD,
	0xD892: 0xFFFD,
	0xD893: 0xFFFD,
	0xD894: 0xFFFD,
	0xD895: 0xFFFD,
	0xD896: 0xFFFD,
	0xD897: 0xFFFD,
	0xD898: 0xFFFD,
	0xD899: 0xFFFD,
	0xD89A: 0xFFFD,
	0xD89B: 0xFFFD,
	0xD89C: 0xFFFD,
	0xD89D: 0xFFFD,
	0xD89E: 0xFFFD,
	0xD89F: 0xFFFD,
	0xD8A0: 0xFFFD,
	0xD8A1: 0xFFFD,
	0xD8A2: 0xFFFD,
	0xD8A3: 0xFFFD,
	0xD8A4: 0xFFFD,
	0xD8A5: 0xFFFD,
	0xD8A6: 0xFFFD,
	0xD8A7: 0xFFFD,
	0xD8A8: 0xFFFD,
	0xD8A9: 0xFFFD,
	0xD8AA: 0xFFFD,
	0xD8AB: 0xFFFD,
	0xD8AC: 0xFFFD,
	0xD8AD: 0xFFFD,
	0xD8AE: 0xFFFD,
	0xD8AF: 0xFFFD,
	0xD8B0: 0xFFFD,
	0xD8B1: 0xFFFD,
	0xD8B2: 0xFFFD,
	0xD8B3: 0xFFFD,
	0xD8B4: 0xFFFD,
	0xD8B5: 0xFFFD,
	0xD8B6: 0xFFFD,
	0xD8B7: 0xFFFD,
	0xD8B8: 0xFFFD,
	0xD8B9: 0xFFFD,
	0xD8BA: 0xFFFD,
	0xD8BB: 0xFFFD,
	0xD8BC: 0xFFFD,
	0xD8BD: 0xFFFD,
	0xD8BE: 0xFFFD,
	0xD8BF: 0xFFFD,
	0xD8C0: 0xFFFD,
	0xD8C1: 0xFFFD,
	0xD8C2: 0xFFFD,
	0xD8C3: 0xFFFD,
	0xD8C4: 0xFFFD,
	0xD8C5: 0xFFFD,
	0xD8C6: 0xFFFD,
	0xD8C7: 0xFFFD,
	0xD8C8: 0xFFFD,
	0xD8C9: 0xFFFD,
	0xD8CA: 0xFFFD,
	0xD8CB: 0xFFFD,
	0xD8CC: 0xFFFD,
	0xD8CD: 0xFFFD,
	0xD8CE: 0xFFFD,
	0xD8CF: 0xFFFD,
	0xD8D0: 0xFFFD,
	0xD8D1: 0xFFFD,
	0xD8D2: 0xFFFD,
	0xD8D3: 0xFFFD,
	0xD8D4: 0xFFFD,
	0xD8D5: 0xFFFD,
	0xD8D6: 0xFFFD,
	0xD8D7: 0xFFFD,
	0xD8D8: 0xFFFD,
	0xD8D9: 0xFFFD,
	0xD8DA: 0xFFFD,
	0xD8DB: 0xFFFD,
	0xD8DC: 0xFFFD,
	0xD8DD: 0xFFFD,
	0xD8DE: 0xFFFD,
	0xD8DF: 0xFFFD,
	0xD8E0: 0xFFFD,
	0xD8E1: 0xFFFD,
	0xD8E2: 0xFFFD,
	0xD8E3: 0xFFFD,
	0xD8E4: 0xFFFD,
	0xD8E5: 0xFFFD,
	0xD8E6: 0xFFFD,
	0xD8E7: 0xFFFD,
	0xD8E8: 0xFFFD,
	0xD8E9: 0xFFFD,
	0xD8EA: 0xFFFD,
	0xD8EB: 0xFFFD,
	0xD8EC: 0xFFFD,
	0xD8ED: 0xFFFD,
	0xD8EE: 0xFFFD,
	0xD8EF: 0xFFFD,
	0xD8F0: 0xFFFD,
	0xD8F1: 0xFFFD,
	0xD8F2: 0xFFFD,
	0xD8F3: 0xFFFD,
	0xD8F4: 0xFFFD,
	0xD8F5: 0xFFFD,
	0xD8F6: 0xFFFD,
	0xD8F7: 0xFFFD,
	0xD8F8: 0xFFFD,
	0xD8F9: 0xFFFD,
	0xD8FA: 0xFFFD,
	0xD8FB: 0xFFFD,
	0xD8FC: 0xFFFD,
	0xD8FD: 0xFFFD,
	0xD8FE: 0xFFFD,
	0xD8FF: 0xFFFD,
	0xD900: 0xFFFD,
	0xD901: 0xFFFD,
	0xD902: 0xFFFD,
	0xD903: 0xFFFD,
	0xD904: 0xFFFD,
	0xD905: 0xFFFD,
	0xD906: 0xFFFD,
	0xD907: 0xFFFD,
	0xD908: 0xFFFD,
	0xD909: 0xFFFD,
	0xD90A: 0xFFFD,
	0xD90B: 0xFFFD,
	0xD90C: 0xFFFD,
	0xD90D: 0xFFFD,
	0xD90E: 0xFFFD,
	0xD90F: 0xFFFD,
	0xD910: 0xFFFD,
	0xD911: 0xFFFD,
	0xD912: 0xFFFD,
	0xD913: 0xFFFD,
	0xD914: 0xFFFD,
	0xD915: 0xFFFD,
	0xD916: 0xFFFD,
	0xD917: 0xFFFD,
	0xD918: 0xFFFD,
	0xD919: 0xFFFD,
	0xD91A: 0xFFFD,
	0xD91B: 0xFFFD,
	0xD91C: 0xFFFD,
	0xD91D: 0xFFFD,
	0xD91E: 0xFFFD,
	0xD91F: 0xFFFD,
	0xD920: 0xFFFD,
	0xD921: 0xFFFD,
	0xD922: 0xFFFD,
	0xD923: 0xFFFD,
	0xD924: 0xFFFD,
	0xD925: 0xFFFD,
	0xD926: 0xFFFD,
	0xD927: 0xFFFD,
	0xD928: 0xFFFD,
	0xD929: 0xFFFD,
	0xD92A: 0xFFFD,
	0xD92B: 0xFFFD,
	0xD92C: 0xFFFD,
	0xD92D: 0xFFFD,
	0xD92E: 0xFFFD,
	0xD92F: 0xFFFD,
	0xD930: 0xFFFD,
	0xD931: 0xFFFD,
	0xD932: 0xFFFD,
	0xD933: 0xFFFD,
	0xD934: 0xFFFD,
	0xD935: 0xFFFD,
	0xD936: 0xFFFD,
	0xD937: 0xFFFD,
	0xD938: 0xFFFD,
	0xD939: 0xFFFD,
	0xD93A: 0xFFFD,
	0xD93B: 0xFFFD,
	0xD93C: 0xFFFD,
	0xD93D: 0xFFFD,
	0xD93E: 0xFFFD,
	0xD93F: 0xFFFD,
	0xD940: 0xFFFD,
	0xD941: 0xFFFD,
	0xD942: 0xFFFD,
	0xD943: 0xFFFD,
	0xD944: 0xFFFD,
	0xD945: 0xFFFD,
	0xD946: 0xFFFD,
	0xD947: 0xFFFD,
	0xD948: 0xFFFD,
	0xD949: 0xFFFD,
	0xD94A: 0xFFFD,
	0xD94B: 0xFFFD,
	0xD94C: 0xFFFD,
	0xD94D: 0xFFFD,
	0xD94E: 0xFFFD,
	0xD94F: 0xFFFD,
	0xD950: 0xFFFD,
	0xD951: 0xFFFD,
	0xD952: 0xFFFD,
	0xD953: 0xFFFD,
	0xD954: 0xFFFD,
	0xD955: 0xFFFD,
	0xD956: 0xFFFD,
	0xD957: 0xFFFD,
	0xD958: 0xFFFD,
	0xD959: 0xFFFD,
	0xD95A: 0xFFFD,
	0xD95B: 0xFFFD,
	0xD95C: 0xFFFD,
	0xD95D: 0xFFFD,
	0xD95E: 0xFFFD,
	0xD95F: 0xFFFD,
	0xD960: 0xFFFD,
	0xD961: 0xFFFD,
	0xD962: 0xFFFD,
	0xD963: 0xFFFD,
	0xD964: 0xFFFD,
	0xD965: 0xFFFD,
	0xD966: 0xFFFD,
	0xD967: 0xFFFD,
	0xD968: 0xFFFD,
	0xD969: 0xFFFD,
	0xD96A: 0xFFFD,
	0xD96B: 0xFFFD,
	0xD96C: 0xFFFD,
	0xD96D: 0xFFFD,
	0xD96E: 0xFFFD,
	0xD96F: 0xFFFD,
	0xD970: 0xFFFD,
	0xD971: 0xFFFD,
	0xD972: 0xFFFD,
	0xD973: 0xFFFD,
	0xD974: 0xFFFD,
	0xD975: 0xFFFD,
	0xD976: 0xFFFD,
	0xD977: 0xFFFD,
	0xD978: 0xFFFD,
	0xD979: 0xFFFD,
	0xD97A: 0xFFFD,
	0xD97B: 0xFFFD,
	0xD97C: 0xFFFD,
	0xD97D: 0xFFFD,
	0xD97E: 0xFFFD,
	0xD97F: 0xFFFD,
	0xD980: 0xFFFD,
	0xD981: 0xFFFD,
	0xD982: 0xFFFD,
	0xD983: 0xFFFD,
	0xD984: 0xFFFD,
	0xD985: 0xFFFD,
	0xD986: 0xFFFD,
	0xD987: 0xFFFD,
	0xD988: 0xFFFD,
	0xD989: 0xFFFD,
	0xD98A: 0xFFFD,
	0xD98B: 0xFFFD,
	0xD98C: 0xFFFD,
	0xD98D: 0xFFFD,
	0xD98E: 0xFFFD,
	0xD98F: 0xFFFD,
	0xD990: 0xFFFD,
	0xD991: 0xFFFD,
	0xD992: 0xFFFD,
	0xD993: 0xFFFD,
	0xD994: 0xFFFD,
	0xD995: 0xFFFD,
	0xD996: 0xFFFD,
	0xD997: 0xFFFD,
	0xD998: 0xFFFD,
	0xD999: 0xFFFD,
	0xD99A: 0xFFFD,
	0xD99B: 0xFFFD,
	0xD99C: 0xFFFD,
	0xD99D: 0xFFFD,
	0xD99E: 0xFFFD,
	0xD99F: 0xFFFD,
	0xD9A0: 0xFFFD,
	0xD9A1: 0xFFFD,
	0xD9A2: 0xFFFD,
	0xD9A3: 0xFFFD,
	0xD9A4: 0xFFFD,
	0xD9A5: 0xFFFD,
	0xD9A6: 0xFFFD,
	0xD9A7: 0xFFFD,
	0xD9A8: 0xFFFD,
	0xD9A9: 0xFFFD,
	0xD9AA: 0xFFFD,
	0xD9AB: 0xFFFD,
	0xD9AC: 0xFFFD,
	0xD9AD: 0xFFFD,
	0xD9AE: 0xFFFD,
	0xD9AF: 0xFFFD,
	0xD9B0: 0xFFFD,
	0xD9B1: 0xFFFD,
	0xD9B2: 0xFFFD,
	0xD9B3: 0xFFFD,
	0xD9B4: 0xFFFD,
	0xD9B5: 0xFFFD,
	0xD9B6: 0xFFFD,
	0xD9B7: 0xFFFD,
	0xD9B8: 0xFFFD,
	0xD9B9: 0xFFFD,
	0xD9BA: 0xFFFD,
	0xD9BB: 0xFFFD,
	0xD9BC: 0xFFFD,
	0xD9BD: 0xFFFD,
	0xD9BE: 0xFFFD,
	0xD9BF: 0xFFFD,
	0xD9C0: 0xFFFD,
	0xD9C1: 0xFFFD,
	0xD9C2: 0xFFFD,
	0xD9C3: 0xFFFD,
	0xD9C4: 0xFFFD,
	0xD9C5: 0xFFFD,
	0xD9C6: 0xFFFD,
	0xD9C7: 0xFFFD,
	0xD9C8: 0xFFFD,
	0xD9C9: 0xFFFD,
	0xD9CA: 0xFFFD,
	0xD9CB: 0xFFFD,
	0xD9CC: 0xFFFD,
	0xD9CD: 0xFFFD,
	0xD9CE: 0xFFFD,
	0xD9CF: 0xFFFD,
	0xD9D0: 0xFFFD,
	0xD9D1: 0xFFFD,
	0xD9D2: 0xFFFD,
	0xD9D3: 0xFFFD,
	0xD9D4: 0xFFFD,
	0xD9D5: 0xFFFD,
	0xD9D6: 0xFFFD,
	0xD9D7: 0xFFFD,
	0xD9D8: 0xFFFD,
	0xD9D9: 0xFFFD,
	0xD9DA: 0xFFFD,
	0xD9DB: 0xFFFD,
	0xD9DC: 0xFFFD,
	0xD9DD: 0xFFFD,
	0xD9DE: 0xFFFD,
	0xD9DF: 0xFFFD,
	0xD9E0: 0xFFFD,
	0xD9E1: 0xFFFD,
	0xD9E2: 0xFFFD,
	0xD9E3: 0xFFFD,
	0xD9E4: 0xFFFD,
	0xD9E5: 0xFFFD,
	0xD9E6: 0xFFFD,
	0xD9E7: 0xFFFD,
	0xD9E8: 0xFFFD,
	0xD9E9: 0xFFFD,
	0xD9EA: 0xFFFD,
	0xD9EB: 0xFFFD,
	0xD9EC: 0xFFFD,
	0xD9ED: 0xFFFD,
	0xD9EE: 0xFFFD,
	0xD9EF: 0xFFFD,
	0xD9F0: 0xFFFD,
	0xD9F1: 0xFFFD,
	0xD9F2: 0xFFFD,
	0xD9F3: 0xFFFD,
	0xD9F4: 0xFFFD,
	0xD9F5: 0xFFFD,
	0xD9F6: 0xFFFD,
	0xD9F7: 0xFFFD,
	0xD9F8: 0xFFFD,
	0xD9F9: 0xFFFD,
	0xD9FA: 0xFFFD,
	0xD9FB: 0xFFFD,
	0xD9FC: 0xFFFD,
	0xD9FD: 0xFFFD,
	0xD9FE: 0xFFFD,
	0xD9FF: 0xFFFD,
	0xDA00: 0xFFFD,
	0xDA01: 0xFFFD,
	0xDA02: 0xFFFD,
	0xDA03: 0xFFFD,
	0xDA04: 0xFFFD,
	0xDA05: 0xFFFD,
	0xDA06: 0xFFFD,
	0xDA07: 0xFFFD,
	0xDA08: 0xFFFD,
	0xDA09: 0xFFFD,
	0xDA0A: 0xFFFD,
	0xDA0B: 0xFFFD,
	0xDA0C: 0xFFFD,
	0xDA0D: 0xFFFD,
	0xDA0E: 0xFFFD,
	0xDA0F: 0xFFFD,
	0xDA10: 0xFFFD,
	0xDA11: 0xFFFD,
	0xDA12: 0xFFFD,
	0xDA13: 0xFFFD,
	0xDA14: 0xFFFD,
	0xDA15: 0xFFFD,
	0xDA16: 0xFFFD,
	0xDA17: 0xFFFD,
	0xDA18: 0xFFFD,
	0xDA19: 0xFFFD,
	0xDA1A: 0xFFFD,
	0xDA1B: 0xFFFD,
	0xDA1C: 0xFFFD,
	0xDA1D: 0xFFFD,
	0xDA1E: 0xFFFD,
	0xDA1F: 0xFFFD,
	0xDA20: 0xFFFD,
	0xDA21: 0xFFFD,
	0xDA22: 0xFFFD,
	0xDA23: 0xFFFD,
	0xDA24: 0xFFFD,
	0xDA25: 0xFFFD,
	0xDA26: 0xFFFD,
	0xDA27: 0xFFFD,
	0xDA28: 0xFFFD,
	0xDA29: 0xFFFD,
	0xDA2A: 0xFFFD,
	0xDA2B: 0xFFFD,
	0xDA2C: 0xFFFD,
	0xDA2D: 0xFFFD,
	0xDA2E: 0xFFFD,
	0xDA2F: 0xFFFD,
	0xDA30: 0xFFFD,
	0xDA31: 0xFFFD,
	0xDA32: 0xFFFD,
	0xDA33: 0xFFFD,
	0xDA34: 0xFFFD,
	0xDA35: 0xFFFD,
	0xDA36: 0xFFFD,
	0xDA37: 0xFFFD,
	0xDA38: 0xFFFD,
	0xDA39: 0xFFFD,
	0xDA3A: 0xFFFD,
	0xDA3B: 0xFFFD,
	0xDA3C: 0xFFFD,
	0xDA3D: 0xFFFD,
	0xDA3E: 0xFFFD,
	0xDA3F: 0xFFFD,
	0xDA40: 0xFFFD,
	0xDA41: 0xFFFD,
	0xDA42: 0xFFFD,
	0xDA43: 0xFFFD,
	0xDA44: 0xFFFD,
	0xDA45: 0xFFFD,
	0xDA46: 0xFFFD,
	0xDA47: 0xFFFD,
	0xDA48: 0xFFFD,
	0xDA49: 0xFFFD,
	0xDA4A: 0xFFFD,
	0xDA4B: 0xFFFD,
	0xDA4C: 0xFFFD,
	0xDA4D: 0xFFFD,
	0xDA4E: 0xFFFD,
	0xDA4F: 0xFFFD,
	0xDA50: 0xFFFD,
	0xDA51: 0xFFFD,
	0xDA52: 0xFFFD,
	0xDA53: 0xFFFD,
	0xDA54: 0xFFFD,
	0xDA55: 0xFFFD,
	0xDA56: 0xFFFD,
	0xDA57: 0xFFFD,
	0xDA58: 0xFFFD,
	0xDA59: 0xFFFD,
	0xDA5A: 0xFFFD,
	0xDA5B: 0xFFFD,
	0xDA5C: 0xFFFD,
	0xDA5D: 0xFFFD,
	0xDA5E: 0xFFFD,
	0xDA5F: 0xFFFD,
	0xDA60: 0xFFFD,
	0xDA61: 0xFFFD,
	0xDA62: 0xFFFD,
	0xDA63: 0xFFFD,
	0xDA64: 0xFFFD,
	0xDA65: 0xFFFD,
	0xDA66: 0xFFFD,
	0xDA67: 0xFFFD,
	0xDA68: 0xFFFD,
	0xDA69: 0xFFFD,
	0xDA6A: 0xFFFD,
	0xDA6B: 0xFFFD,
	0xDA6C: 0xFFFD,
	0xDA6D: 0xFFFD,
	0xDA6E: 0xFFFD,
	0xDA6F: 0xFFFD,
	0xDA70: 0xFFFD,
	0xDA71: 0xFFFD,
	0xDA72: 0xFFFD,
	0xDA73: 0xFFFD,
	0xDA74: 0xFFFD,
	0xDA75: 0xFFFD,
	0xDA76: 0xFFFD,
	0xDA77: 0xFFFD,
	0xDA78: 0xFFFD,
	0xDA79: 0xFFFD,
	0xDA7A: 0xFFFD,
	0xDA7B: 0xFFFD,
	0xDA7C: 0xFFFD,
	0xDA7D: 0xFFFD,
	0xDA7E: 0xFFFD,
	0xDA7F: 0xFFFD,
	0xDA80: 0xFFFD,
	0xDA81: 0xFFFD,
	0xDA82: 0xFFFD,
	0xDA83: 0xFFFD,
	0xDA84: 0xFFFD,
	0xDA85: 0xFFFD,
	0xDA86: 0xFFFD,
	0xDA87: 0xFFFD,
	0xDA88: 0xFFFD,
	0xDA89: 0xFFFD,
	0xDA8A: 0xFFFD,
	0xDA8B: 0xFFFD,
	0xDA8C: 0xFFFD,
	0xDA8D: 0xFFFD,
	0xDA8E: 0xFFFD,
	0xDA8F: 0xFFFD,
	0xDA90: 0xFFFD,
	0xDA91: 0xFFFD,
	0xDA92: 0xFFFD,
	0xDA93: 0xFFFD,
	0xDA94: 0xFFFD,
	0xDA95: 0xFFFD,
	0xDA96: 0xFFFD,
	0xDA97: 0xFFFD,
	0xDA98: 0xFFFD,
	0xDA99: 0xFFFD,
	0xDA9A: 0xFFFD,
	0xDA9B: 0xFFFD,
	0xDA9C: 0xFFFD,
	0xDA9D: 0xFFFD,
	0xDA9E: 0xFFFD,
	0xDA9F: 0xFFFD,
	0xDAA0: 0xFFFD,
	0xDAA1: 0xFFFD,
	0xDAA2: 0xFFFD,
	0xDAA3: 0xFFFD,
	0xDAA4: 0xFFFD,
	0xDAA5: 0xFFFD,
	0xDAA6: 0xFFFD,
	0xDAA7: 0xFFFD,
	0xDAA8: 0xFFFD,
	0xDAA9: 0xFFFD,
	0xDAAA: 0xFFFD,
	0xDAAB: 0xFFFD,
	0xDAAC: 0xFFFD,
	0xDAAD: 0xFFFD,
	0xDAAE: 0xFFFD,
	0xDAAF: 0xFFFD,
	0xDAB0: 0xFFFD,
	0xDAB1: 0xFFFD,
	0xDAB2: 0xFFFD,
	0xDAB3: 0xFFFD,
	0xDAB4: 0xFFFD,
	0xDAB5: 0xFFFD,
	0xDAB6: 0xFFFD,
	0xDAB7: 0xFFFD,
	0xDAB8: 0xFFFD,
	0xDAB9: 0xFFFD,
	0xDABA: 0xFFFD,
	0xDABB: 0xFFFD,
	0xDABC: 0xFFFD,
	0xDABD: 0xFFFD,
	0xDABE: 0xFFFD,
	0xDABF: 0xFFFD,
	0xDAC0: 0xFFFD,
	0xDAC1: 0xFFFD,
	0xDAC2: 0xFFFD,
	0xDAC3: 0xFFFD,
	0xDAC4: 0xFFFD,
	0xDAC5: 0xFFFD,
	0xDAC6: 0xFFFD,
	0xDAC7: 0xFFFD,
	0xDAC8: 0xFFFD,
	0xDAC9: 0xFFFD,
	0xDACA: 0xFFFD,
	0xDACB: 0xFFFD,
	0xDACC: 0xFFFD,
	0xDACD: 0xFFFD,
	0xDACE: 0xFFFD,
	0xDACF: 0xFFFD,
	0xDAD0: 0xFFFD,
	0xDAD1: 0xFFFD,
	0xDAD2: 0xFFFD,
	0xDAD3: 0xFFFD,
	0xDAD4: 0xFFFD,
	0xDAD5: 0xFFFD,
	0xDAD6: 0xFFFD,
	0xDAD7: 0xFFFD,
	0xDAD8: 0xFFFD,
	0xDAD9: 0xFFFD,
	0xDADA: 0xFFFD,
	0xDADB: 0xFFFD,
	0xDADC: 0xFFFD,
	0xDADD: 0xFFFD,
	0xDADE: 0xFFFD,
	0xDADF: 0xFFFD,
	0xDAE0: 0xFFFD,
	0xDAE1: 0xFFFD,
	0xDAE2: 0xFFFD,
	0xDAE3: 0xFFFD,
	0xDAE4: 0xFFFD,
	0xDAE5: 0xFFFD,
	0xDAE6: 0xFFFD,
	0xDAE7: 0xFFFD,
	0xDAE8: 0xFFFD,
	0xDAE9: 0xFFFD,
	0xDAEA: 0xFFFD,
	0xDAEB: 0xFFFD,
	0xDAEC: 0xFFFD,
	0xDAED: 0xFFFD,
	0xDAEE: 0xFFFD,
	0xDAEF: 0xFFFD,
	0xDAF0: 0xFFFD,
	0xDAF1: 0xFFFD,
	0xDAF2: 0xFFFD,
	0xDAF3: 0xFFFD,
	0xDAF4: 0xFFFD,
	0xDAF5: 0xFFFD,
	0xDAF6: 0xFFFD,
	0xDAF7: 0xFFFD,
	0xDAF8: 0xFFFD,
	0xDAF9: 0xFFFD,
	0xDAFA: 0xFFFD,
	0xDAFB: 0xFFFD,
	0xDAFC: 0xFFFD,
	0xDAFD: 0xFFFD,
	0xDAFE: 0xFFFD,
	0xDAFF: 0xFFFD,
	0xDB00: 0xFFFD,
	0xDB01: 0xFFFD,
	0xDB02: 0xFFFD,
	0xDB03: 0xFFFD,
	0xDB04: 0xFFFD,
	0xDB05: 0xFFFD,
	0xDB06: 0xFFFD,
	0xDB07: 0xFFFD,
	0xDB08: 0xFFFD,
	0xDB09: 0xFFFD,
	0xDB0A: 0xFFFD,
	0xDB0B: 0xFFFD,
	0xDB0C: 0xFFFD,
	0xDB0D: 0xFFFD,
	0xDB0E: 0xFFFD,
	0xDB0F: 0xFFFD,
	0xDB10: 0xFFFD,
	0xDB11: 0xFFFD,
	0xDB12: 0xFFFD,
	0xDB13: 0xFFFD,
	0xDB14: 0xFFFD,
	0xDB15: 0xFFFD,
	0xDB16: 0xFFFD,
	0xDB17: 0xFFFD,
	0xDB18: 0xFFFD,
	0xDB19: 0xFFFD,
	0xDB1A: 0xFFFD,
	0xDB1B: 0xFFFD,
	0xDB1C: 0xFFFD,
	0xDB1D: 0xFFFD,
	0xDB1E: 0xFFFD,
	0xDB1F: 0xFFFD,
	0xDB20: 0xFFFD,
	0xDB21: 0xFFFD,
	0xDB22: 0xFFFD,
	0xDB23: 0xFFFD,
	0xDB24: 0xFFFD,
	0xDB25: 0xFFFD,
	0xDB26: 0xFFFD,
	0xDB27: 0xFFFD,
	0xDB28: 0xFFFD,
	0xDB29: 0xFFFD,
	0xDB2A: 0xFFFD,
	0xDB2B: 0xFFFD,
	0xDB2C: 0xFFFD,
	0xDB2D: 0xFFFD,
	0xDB2E: 0xFFFD,
	0xDB2F: 0xFFFD,
	0xDB30: 0xFFFD,
	0xDB31: 0xFFFD,
	0xDB32: 0xFFFD,
	0xDB33: 0xFFFD,
	0xDB34: 0xFFFD,
	0xDB35: 0xFFFD,
	0xDB36: 0xFFFD,
	0xDB37: 0xFFFD,
	0xDB38: 0xFFFD,
	0xDB39: 0xFFFD,
	0xDB3A: 0xFFFD,
	0xDB3B: 0xFFFD,
	0xDB3C: 0xFFFD,
	0xDB3D: 0xFFFD,
	0xDB3E: 0xFFFD,
	0xDB3F: 0xFFFD,
	0xDB40: 0xFFFD,
	0xDB41: 0xFFFD,
	0xDB42: 0xFFFD,
	0xDB43: 0xFFFD,
	0xDB44: 0xFFFD,
	0xDB45: 0xFFFD,
	0xDB46: 0xFFFD,
	0xDB47: 0xFFFD,
	0xDB48: 0xFFFD,
	0xDB49: 0xFFFD,
	0xDB4A: 0xFFFD,
	0xDB4B: 0xFFFD,
	0xDB4C: 0xFFFD,
	0xDB4D: 0xFFFD,
	0xDB4E: 0xFFFD,
	0xDB4F: 0xFFFD,
	0xDB50: 0xFFFD,
	0xDB51: 0xFFFD,
	0xDB52: 0xFFFD,
	0xDB53: 0xFFFD,
	0xDB54: 0xFFFD,
	0xDB55: 0xFFFD,
	0xDB56: 0xFFFD,
	0xDB57: 0xFFFD,
	0xDB58: 0xFFFD,
	0xDB59: 0xFFFD,
	0xDB5A: 0xFFFD,
	0xDB5B: 0xFFFD,
	0xDB5C: 0xFFFD,
	0xDB5D: 0xFFFD,
	0xDB5E: 0xFFFD,
	0xDB5F: 0xFFFD,
	0xDB60: 0xFFFD,
	0xDB61: 0xFFFD,
	0xDB62: 0xFFFD,
	0xDB63: 0xFFFD,
	0xDB64: 0xFFFD,
	0xDB65: 0xFFFD,
	0xDB66: 0xFFFD,
	0xDB67: 0xFFFD,
	0xDB68: 0xFFFD,
	0xDB69: 0xFFFD,
	0xDB6A: 0xFFFD,
	0xDB6B: 0xFFFD,
	0xDB6C: 0xFFFD,
	0xDB6D: 0xFFFD,
	0xDB6E: 0xFFFD,
	0xDB6F: 0xFFFD,
	0xDB70: 0xFFFD,
	0xDB71: 0xFFFD,
	0xDB72: 0xFFFD,
	0xDB73: 0xFFFD,
	0xDB74: 0xFFFD,
	0xDB75: 0xFFFD,
	0xDB76: 0xFFFD,
	0xDB77: 0xFFFD,
	0xDB78: 0xFFFD,
	0xDB79: 0xFFFD,
	0xDB7A: 0xFFFD,
	0xDB7B: 0xFFFD,
	0xDB7C: 0xFFFD,
	0xDB7D: 0xFFFD,
	0xDB7E: 0xFFFD,
	0xDB7F: 0xFFFD,
	0xDB80: 0xFFFD,
	0xDB81: 0xFFFD,
	0xDB82: 0xFFFD,
	0xDB83: 0xFFFD,
	0xDB84: 0xFFFD,
	0xDB85: 0xFFFD,
	0xDB86: 0xFFFD,
	0xDB87: 0xFFFD,
	0xDB88: 0xFFFD,
	0xDB89: 0xFFFD,
	0xDB8A: 0xFFFD,
	0xDB8B: 0xFFFD,
	0xDB8C: 0xFFFD,
	0xDB8D: 0xFFFD,
	0xDB8E: 0xFFFD,
	0xDB8F: 0xFFFD,
	0xDB90: 0xFFFD,
	0xDB91: 0xFFFD,
	0xDB92: 0xFFFD,
	0xDB93: 0xFFFD,
	0xDB94: 0xFFFD,
	0xDB95: 0xFFFD,
	0xDB96: 0xFFFD,
	0xDB97: 0xFFFD,
	0xDB98: 0xFFFD,
	0xDB99: 0xFFFD,
	0xDB9A: 0xFFFD,
	0xDB9B: 0xFFFD,
	0xDB9C: 0xFFFD,
	0xDB9D: 0xFFFD,
	0xDB9E: 0xFFFD,
	0xDB9F: 0xFFFD,
	0xDBA0: 0xFFFD,
	0xDBA1: 0xFFFD,
	0xDBA2: 0xFFFD,
	0xDBA3: 0xFFFD,
	0xDBA4: 0xFFFD,
	0xDBA5: 0xFFFD,
	0xDBA6: 0xFFFD,
	0xDBA7: 0xFFFD,
	0xDBA8: 0xFFFD,
	0xDBA9: 0xFFFD,
	0xDBAA: 0xFFFD,
	0xDBAB: 0xFFFD,
	0xDBAC: 0xFFFD,
	0xDBAD: 0xFFFD,
	0xDBAE: 0xFFFD,
	0xDBAF: 0xFFFD,
	0xDBB0: 0xFFFD,
	0xDBB1: 0xFFFD,
	0xDBB2: 0xFFFD,
	0xDBB3: 0xFFFD,
	0xDBB4: 0xFFFD,
	0xDBB5: 0xFFFD,
	0xDBB6: 0xFFFD,
	0xDBB7: 0xFFFD,
	0xDBB8: 0xFFFD,
	0xDBB9: 0xFFFD,
	0xDBBA: 0xFFFD,
	0xDBBB: 0xFFFD,
	0xDBBC: 0xFFFD,
	0xDBBD: 0xFFFD,
	0xDBBE: 0xFFFD,
	0xDBBF: 0xFFFD,
	0xDBC0: 0xFFFD,
	0xDBC1: 0xFFFD,
	0xDBC2: 0xFFFD,
	0xDBC3: 0xFFFD,
	0xDBC4: 0xFFFD,
	0xDBC5: 0xFFFD,
	0xDBC6: 0xFFFD,
	0xDBC7: 0xFFFD,
	0xDBC8: 0xFFFD,
	0xDBC9: 0xFFFD,
	0xDBCA: 0xFFFD,
	0xDBCB: 0xFFFD,
	0xDBCC: 0xFFFD,
	0xDBCD: 0xFFFD,
	0xDBCE: 0xFFFD,
	0xDBCF: 0xFFFD,
	0xDBD0: 0xFFFD,
	0xDBD1: 0xFFFD,
	0xDBD2: 0xFFFD,
	0xDBD3: 0xFFFD,
	0xDBD4: 0xFFFD,
	0xDBD5: 0xFFFD,
	0xDBD6: 0xFFFD,
	0xDBD7: 0xFFFD,
	0xDBD8: 0xFFFD,
	0xDBD9: 0xFFFD,
	0xDBDA: 0xFFFD,
	0xDBDB: 0xFFFD,
	0xDBDC: 0xFFFD,
	0xDBDD: 0xFFFD,
	0xDBDE: 0xFFFD,
	0xDBDF: 0xFFFD,
	0xDBE0: 0xFFFD,
	0xDBE1: 0xFFFD,
	0xDBE2: 0xFFFD,
	0xDBE3: 0xFFFD,
	0xDBE4: 0xFFFD,
	0xDBE5: 0xFFFD,
	0xDBE6: 0xFFFD,
	0xDBE7: 0xFFFD,
	0xDBE8: 0xFFFD,
	0xDBE9: 0xFFFD,
	0xDBEA: 0xFFFD,
	0xDBEB: 0xFFFD,
	0xDBEC: 0xFFFD,
	0xDBED: 0xFFFD,
	0xDBEE: 0xFFFD,
	0xDBEF: 0xFFFD,
	0xDBF0: 0xFFFD,
	0xDBF1: 0xFFFD,
	0xDBF2: 0xFFFD,
	0xDBF3: 0xFFFD,
	0xDBF4: 0xFFFD,
	0xDBF5: 0xFFFD,
	0xDBF6: 0xFFFD,
	0xDBF7: 0xFFFD,
	0xDBF8: 0xFFFD,
	0xDBF9: 0xFFFD,
	0xDBFA: 0xFFFD,
	0xDBFB: 0xFFFD,
	0xDBFC: 0xFFFD,
	0xDBFD: 0xFFFD,
	0xDBFE: 0xFFFD,
	0xDBFF: 0xFFFD,
	0xDC00: 0xFFFD,
	0xDC01: 0xFFFD,
	0xDC02: 0xFFFD,
	0xDC03: 0xFFFD,
	0xDC04: 0xFFFD,
	0xDC05: 0xFFFD,
	0xDC06: 0xFFFD,
	0xDC07: 0xFFFD,
	0xDC08: 0xFFFD,
	0xDC09: 0xFFFD,
	0xDC0A: 0xFFFD,
	0xDC0B: 0xFFFD,
	0xDC0C: 0xFFFD,
	0xDC0D: 0xFFFD,
	0xDC0E: 0xFFFD,
	0xDC0F: 0xFFFD,
	0xDC10: 0xFFFD,
	0xDC11: 0xFFFD,
	0xDC12: 0xFFFD,
	0xDC13: 0xFFFD,
	0xDC14: 0xFFFD,
	0xDC15: 0xFFFD,
	0xDC16: 0xFFFD,
	0xDC17: 0xFFFD,
	0xDC18: 0xFFFD,
	0xDC19: 0xFFFD,
	0xDC1A: 0xFFFD,
	0xDC1B: 0xFFFD,
	0xDC1C: 0xFFFD,
	0xDC1D: 0xFFFD,
	0xDC1E: 0xFFFD,
	0xDC1F: 0xFFFD,
	0xDC20: 0xFFFD,
	0xDC21: 0xFFFD,
	0xDC22: 0xFFFD,
	0xDC23: 0xFFFD,
	0xDC24: 0xFFFD,
	0xDC25: 0xFFFD,
	0xDC26: 0xFFFD,
	0xDC27: 0xFFFD,
	0xDC28: 0xFFFD,
	0xDC29: 0xFFFD,
	0xDC2A: 0xFFFD,
	0xDC2B: 0xFFFD,
	0xDC2C: 0xFFFD,
	0xDC2D: 0xFFFD,
	0xDC2E: 0xFFFD,
	0xDC2F: 0xFFFD,
	0xDC30: 0xFFFD,
	0xDC31: 0xFFFD,
	0xDC32: 0xFFFD,
	0xDC33: 0xFFFD,
	0xDC34: 0xFFFD,
	0xDC35: 0xFFFD,
	0xDC36: 0xFFFD,
	0xDC37: 0xFFFD,
	0xDC38: 0xFFFD,
	0xDC39: 0xFFFD,
	0xDC3A: 0xFFFD,
	0xDC3B: 0xFFFD,
	0xDC3C: 0xFFFD,
	0xDC3D: 0xFFFD,
	0xDC3E: 0xFFFD,
	0xDC3F: 0xFFFD,
	0xDC40: 0xFFFD,
	0xDC41: 0xFFFD,
	0xDC42: 0xFFFD,
	0xDC43: 0xFFFD,
	0xDC44: 0xFFFD,
	0xDC45: 0xFFFD,
	0xDC46: 0xFFFD,
	0xDC47: 0xFFFD,
	0xDC48: 0xFFFD,
	0xDC49: 0xFFFD,
	0xDC4A: 0xFFFD,
	0xDC4B: 0xFFFD,
	0xDC4C: 0xFFFD,
	0xDC4D: 0xFFFD,
	0xDC4E: 0xFFFD,
	0xDC4F: 0xFFFD,
	0xDC50: 0xFFFD,
	0xDC51: 0xFFFD,
	0xDC52: 0xFFFD,
	0xDC53: 0xFFFD,
	0xDC54: 0xFFFD,
	0xDC55: 0xFFFD,
	0xDC56: 0xFFFD,
	0xDC57: 0xFFFD,
	0xDC58: 0xFFFD,
	0xDC59: 0xFFFD,
	0xDC5A: 0xFFFD,
	0xDC5B: 0xFFFD,
	0xDC5C: 0xFFFD,
	0xDC5D: 0xFFFD,
	0xDC5E: 0xFFFD,
	0xDC5F: 0xFFFD,
	0xDC60: 0xFFFD,
	0xDC61: 0xFFFD,
	0xDC62: 0xFFFD,
	0xDC63: 0xFFFD,
	0xDC64: 0xFFFD,
	0xDC65: 0xFFFD,
	0xDC66: 0xFFFD,
	0xDC67: 0xFFFD,
	0xDC68: 0xFFFD,
	0xDC69: 0xFFFD,
	0xDC6A: 0xFFFD,
	0xDC6B: 0xFFFD,
	0xDC6C: 0xFFFD,
	0xDC6D: 0xFFFD,
	0xDC6E: 0xFFFD,
	0xDC6F: 0xFFFD,
	0xDC70: 0xFFFD,
	0xDC71: 0xFFFD,
	0xDC72: 0xFFFD,
	0xDC73: 0xFFFD,
	0xDC74: 0xFFFD,
	0xDC75: 0xFFFD,
	0xDC76: 0xFFFD,
	0xDC77: 0xFFFD,
	0xDC78: 0xFFFD,
	0xDC79: 0xFFFD,
	0xDC7A: 0xFFFD,
	0xDC7B: 0xFFFD,
	0xDC7C: 0xFFFD,
	0xDC7D: 0xFFFD,
	0xDC7E: 0xFFFD,
	0xDC7F: 0xFFFD,
	0xDC80: 0xFFFD,
	0xDC81: 0xFFFD,
	0xDC82: 0xFFFD,
	0xDC83: 0xFFFD,
	0xDC84: 0xFFFD,
	0xDC85: 0xFFFD,
	0xDC86: 0xFFFD,
	0xDC87: 0xFFFD,
	0xDC88: 0xFFFD,
	0xDC89: 0xFFFD,
	0xDC8A: 0xFFFD,
	0xDC8B: 0xFFFD,
	0xDC8C: 0xFFFD,
	0xDC8D: 0xFFFD,
	0xDC8E: 0xFFFD,
	0xDC8F: 0xFFFD,
	0xDC90: 0xFFFD,
	0xDC91: 0xFFFD,
	0xDC92: 0xFFFD,
	0xDC93: 0xFFFD,
	0xDC94: 0xFFFD,
	0xDC95: 0xFFFD,
	0xDC96: 0xFFFD,
	0xDC97: 0xFFFD,
	0xDC98: 0xFFFD,
	0xDC99: 0xFFFD,
	0xDC9A: 0xFFFD,
	0xDC9B: 0xFFFD,
	0xDC9C: 0xFFFD,
	0xDC9D: 0xFFFD,
	0xDC9E: 0xFFFD,
	0xDC9F: 0xFFFD,
	0xDCA0: 0xFFFD,
	0xDCA1: 0xFFFD,
	0xDCA2: 0xFFFD,
	0xDCA3: 0xFFFD,
	0xDCA4: 0xFFFD,
	0xDCA5: 0xFFFD,
	0xDCA6: 0xFFFD,
	0xDCA7: 0xFFFD,
	0xDCA8: 0xFFFD,
	0xDCA9: 0xFFFD,
	0xDCAA: 0xFFFD,
	0xDCAB: 0xFFFD,
	0xDCAC: 0xFFFD,
	0xDCAD: 0xFFFD,
	0xDCAE: 0xFFFD,
	0xDCAF: 0xFFFD,
	0xDCB0: 0xFFFD,
	0xDCB1: 0xFFFD,
	0xDCB2: 0xFFFD,
	0xDCB3: 0xFFFD,
	0xDCB4: 0xFFFD,
	0xDCB5: 0xFFFD,
	0xDCB6: 0xFFFD,
	0xDCB7: 0xFFFD,
	0xDCB8: 0xFFFD,
	0xDCB9: 0xFFFD,
	0xDCBA: 0xFFFD,
	0xDCBB: 0xFFFD,
	0xDCBC: 0xFFFD,
	0xDCBD: 0xFFFD,
	0xDCBE: 0xFFFD,
	0xDCBF: 0xFFFD,
	0xDCC0: 0xFFFD,
	0xDCC1: 0xFFFD,
	0xDCC2: 0xFFFD,
	0xDCC3: 0xFFFD,
	0xDCC4: 0xFFFD,
	0xDCC5: 0xFFFD,
	0xDCC6: 0xFFFD,
	0xDCC7: 0xFFFD,
	0xDCC8: 0xFFFD,
	0xDCC9: 0xFFFD,
	0xDCCA: 0xFFFD,
	0xDCCB: 0xFFFD,
	0xDCCC: 0xFFFD,
	0xDCCD: 0xFFFD,
	0xDCCE: 0xFFFD,
	0xDCCF: 0xFFFD,
	0xDCD0: 0xFFFD,
	0xDCD1: 0xFFFD,
	0xDCD2: 0xFFFD,
	0xDCD3: 0xFFFD,
	0xDCD4: 0xFFFD,
	0xDCD5: 0xFFFD,
	0xDCD6: 0xFFFD,
	0xDCD7: 0xFFFD,
	0xDCD8: 0xFFFD,
	0xDCD9: 0xFFFD,
	0xDCDA: 0xFFFD,
	0xDCDB: 0xFFFD,
	0xDCDC: 0xFFFD,
	0xDCDD: 0xFFFD,
	0xDCDE: 0xFFFD,
	0xDCDF: 0xFFFD,
	0xDCE0: 0xFFFD,
	0xDCE1: 0xFFFD,
	0xDCE2: 0xFFFD,
	0xDCE3: 0xFFFD,
	0xDCE4: 0xFFFD,
	0xDCE5: 0xFFFD,
	0xDCE6: 0xFFFD,
	0xDCE7: 0xFFFD,
	0xDCE8: 0xFFFD,
	0xDCE9: 0xFFFD,
	0xDCEA: 0xFFFD,
	0xDCEB: 0xFFFD,
	0xDCEC: 0xFFFD,
	0xDCED: 0xFFFD,
	0xDCEE: 0xFFFD,
	0xDCEF: 0xFFFD,
	0xDCF0: 0xFFFD,
	0xDCF1: 0xFFFD,
	0xDCF2: 0xFFFD,
	0xDCF3: 0xFFFD,
	0xDCF4: 0xFFFD,
	0xDCF5: 0xFFFD,
	0xDCF6: 0xFFFD,
	0xDCF7: 0xFFFD,
	0xDCF8: 0xFFFD,
	0xDCF9: 0xFFFD,
	0xDCFA: 0xFFFD,
	0xDCFB: 0xFFFD,
	0xDCFC: 0xFFFD,
	0xDCFD: 0xFFFD,
	0xDCFE: 0xFFFD,
	0xDCFF: 0xFFFD,
	0xDD00: 0xFFFD,
	0xDD01: 0xFFFD,
	0xDD02: 0xFFFD,
	0xDD03: 0xFFFD,
	0xDD04: 0xFFFD,
	0xDD05: 0xFFFD,
	0xDD06: 0xFFFD,
	0xDD07: 0xFFFD,
	0xDD08: 0xFFFD,
	0xDD09: 0xFFFD,
	0xDD0A: 0xFFFD,
	0xDD0B: 0xFFFD,
	0xDD0C: 0xFFFD,
	0xDD0D: 0xFFFD,
	0xDD0E: 0xFFFD,
	0xDD0F: 0xFFFD,
	0xDD10: 0xFFFD,
	0xDD11: 0xFFFD,
	0xDD12: 0xFFFD,
	0xDD13: 0xFFFD,
	0xDD14: 0xFFFD,
	0xDD15: 0xFFFD,
	0xDD16: 0xFFFD,
	0xDD17: 0xFFFD,
	0xDD18: 0xFFFD,
	0xDD19: 0xFFFD,
	0xDD1A: 0xFFFD,
	0xDD1B: 0xFFFD,
	0xDD1C: 0xFFFD,
	0xDD1D: 0xFFFD,
	0xDD1E: 0xFFFD,
	0xDD1F: 0xFFFD,
	0xDD20: 0xFFFD,
	0xDD21: 0xFFFD,
	0xDD22: 0xFFFD,
	0xDD23: 0xFFFD,
	0xDD24: 0xFFFD,
	0xDD25: 0xFFFD,
	0xDD26: 0xFFFD,
	0xDD27: 0xFFFD,
	0xDD28: 0xFFFD,
	0xDD29: 0xFFFD,
	0xDD2A: 0xFFFD,
	0xDD2B: 0xFFFD,
	0xDD2C: 0xFFFD,
	0xDD2D: 0xFFFD,
	0xDD2E: 0xFFFD,
	0xDD2F: 0xFFFD,
	0xDD30: 0xFFFD,
	0xDD31: 0xFFFD,
	0xDD32: 0xFFFD,
	0xDD33: 0xFFFD,
	0xDD34: 0xFFFD,
	0xDD35: 0xFFFD,
	0xDD36: 0xFFFD,
	0xDD37: 0xFFFD,
	0xDD38: 0xFFFD,
	0xDD39: 0xFFFD,
	0xDD3A: 0xFFFD,
	0xDD3B: 0xFFFD,
	0xDD3C: 0xFFFD,
	0xDD3D: 0xFFFD,
	0xDD3E: 0xFFFD,
	0xDD3F: 0xFFFD,
	0xDD40: 0xFFFD,
	0xDD41: 0xFFFD,
	0xDD42: 0xFFFD,
	0xDD43: 0xFFFD,
	0xDD44: 0xFFFD,
	0xDD45: 0xFFFD,
	0xDD46: 0xFFFD,
	0xDD47: 0xFFFD,
	0xDD48: 0xFFFD,
	0xDD49: 0xFFFD,
	0xDD4A: 0xFFFD,
	0xDD4B: 0xFFFD,
	0xDD4C: 0xFFFD,
	0xDD4D: 0xFFFD,
	0xDD4E: 0xFFFD,
	0xDD4F: 0xFFFD,
	0xDD50: 0xFFFD,
	0xDD51: 0xFFFD,
	0xDD52: 0xFFFD,
	0xDD53: 0xFFFD,
	0xDD54: 0xFFFD,
	0xDD55: 0xFFFD,
	0xDD56: 0xFFFD,
	0xDD57: 0xFFFD,
	0xDD58: 0xFFFD,
	0xDD59: 0xFFFD,
	0xDD5A: 0xFFFD,
	0xDD5B: 0xFFFD,
	0xDD5C: 0xFFFD,
	0xDD5D: 0xFFFD,
	0xDD5E: 0xFFFD,
	0xDD5F: 0xFFFD,
	0xDD60: 0xFFFD,
	0xDD61: 0xFFFD,
	0xDD62: 0xFFFD,
	0xDD63: 0xFFFD,
	0xDD64: 0xFFFD,
	0xDD65: 0xFFFD,
	0xDD66: 0xFFFD,
	0xDD67: 0xFFFD,
	0xDD68: 0xFFFD,
	0xDD69: 0xFFFD,
	0xDD6A: 0xFFFD,
	0xDD6B: 0xFFFD,
	0xDD6C: 0xFFFD,
	0xDD6D: 0xFFFD,
	0xDD6E: 0xFFFD,
	0xDD6F: 0xFFFD,
	0xDD70: 0xFFFD,
	0xDD71: 0xFFFD,
	0xDD72: 0xFFFD,
	0xDD73: 0xFFFD,
	0xDD74: 0xFFFD,
	0xDD75: 0xFFFD,
	0xDD76: 0xFFFD,
	0xDD77: 0xFFFD,
	0xDD78: 0xFFFD,
	0xDD79: 0xFFFD,
	0xDD7A: 0xFFFD,
	0xDD7B: 0xFFFD,
	0xDD7C: 0xFFFD,
	0xDD7D: 0xFFFD,
	0xDD7E: 0xFFFD,
	0xDD7F: 0xFFFD,
	0xDD80: 0xFFFD,
	0xDD81: 0xFFFD,
	0xDD82: 0xFFFD,
	0xDD83: 0xFFFD,
	0xDD84: 0xFFFD,
	0xDD85: 0xFFFD,
	0xDD86: 0xFFFD,
	0xDD87: 0xFFFD,
	0xDD88: 0xFFFD,
	0xDD89: 0xFFFD,
	0xDD8A: 0xFFFD,
	0xDD8B: 0xFFFD,
	0xDD8C: 0xFFFD,
	0xDD8D: 0xFFFD,
	0xDD8E: 0xFFFD,
	0xDD8F: 0xFFFD,
	0xDD90: 0xFFFD,
	0xDD91: 0xFFFD,
	0xDD92: 0xFFFD,
	0xDD93: 0xFFFD,
	0xDD94: 0xFFFD,
	0xDD95: 0xFFFD,
	0xDD96: 0xFFFD,
	0xDD97: 0xFFFD,
	0xDD98: 0xFFFD,
	0xDD99: 0xFFFD,
	0xDD9A: 0xFFFD,
	0xDD9B: 0xFFFD,
	0xDD9C: 0xFFFD,
	0xDD9D: 0xFFFD,
	0xDD9E: 0xFFFD,
	0xDD9F: 0xFFFD,
	0xDDA0: 0xFFFD,
	0xDDA1: 0xFFFD,
	0xDDA2: 0xFFFD,
	0xDDA3: 0xFFFD,
	0xDDA4: 0xFFFD,
	0xDDA5: 0xFFFD,
	0xDDA6: 0xFFFD,
	0xDDA7: 0xFFFD,
	0xDDA8: 0xFFFD,
	0xDDA9: 0xFFFD,
	0xDDAA: 0xFFFD,
	0xDDAB: 0xFFFD,
	0xDDAC: 0xFFFD,
	0xDDAD: 0xFFFD,
	0xDDAE: 0xFFFD,
	0xDDAF: 0xFFFD,
	0xDDB0: 0xFFFD,
	0xDDB1: 0xFFFD,
	0xDDB2: 0xFFFD,
	0xDDB3: 0xFFFD,
	0xDDB4: 0xFFFD,
	0xDDB5: 0xFFFD,
	0xDDB6: 0xFFFD,
	0xDDB7: 0xFFFD,
	0xDDB8: 0xFFFD,
	0xDDB9: 0xFFFD,
	0xDDBA: 0xFFFD,
	0xDDBB: 0xFFFD,
	0xDDBC: 0xFFFD,
	0xDDBD: 0xFFFD,
	0xDDBE: 0xFFFD,
	0xDDBF: 0xFFFD,
	0xDDC0: 0xFFFD,
	0xDDC1: 0xFFFD,
	0xDDC2: 0xFFFD,
	0xDDC3: 0xFFFD,
	0xDDC4: 0xFFFD,
	0xDDC5: 0xFFFD,
	0xDDC6: 0xFFFD,
	0xDDC7: 0xFFFD,
	0xDDC8: 0xFFFD,
	0xDDC9: 0xFFFD,
	0xDDCA: 0xFFFD,
	0xDDCB: 0xFFFD,
	0xDDCC: 0xFFFD,
	0xDDCD: 0xFFFD,
	0xDDCE: 0xFFFD,
	0xDDCF: 0xFFFD,
	0xDDD0: 0xFFFD,
	0xDDD1: 0xFFFD,
	0xDDD2: 0xFFFD,
	0xDDD3: 0xFFFD,
	0xDDD4: 0xFFFD,
	0xDDD5: 0xFFFD,
	0xDDD6: 0xFFFD,
	0xDDD7: 0xFFFD,
	0xDDD8: 0xFFFD,
	0xDDD9: 0xFFFD,
	0xDDDA: 0xFFFD,
	0xDDDB: 0xFFFD,
	0xDDDC: 0xFFFD,
	0xDDDD: 0xFFFD,
	0xDDDE: 0xFFFD,
	0xDDDF: 0xFFFD,
	0xDDE0: 0xFFFD,
	0xDDE1: 0xFFFD,
	0xDDE2: 0xFFFD,
	0xDDE3: 0xFFFD,
	0xDDE4: 0xFFFD,
	0xDDE5: 0xFFFD,
	0xDDE6: 0xFFFD,
	0xDDE7: 0xFFFD,
	0xDDE8: 0xFFFD,
	0xDDE9: 0xFFFD,
	0xDDEA: 0xFFFD,
	0xDDEB: 0xFFFD,
	0xDDEC: 0xFFFD,
	0xDDED: 0xFFFD,
	0xDDEE: 0xFFFD,
	0xDDEF: 0xFFFD,
	0xDDF0: 0xFFFD,
	0xDDF1: 0xFFFD,
	0xDDF2: 0xFFFD,
	0xDDF3: 0xFFFD,
	0xDDF4: 0xFFFD,
	0xDDF5: 0xFFFD,
	0xDDF6: 0xFFFD,
	0xDDF7: 0xFFFD,
	0xDDF8: 0xFFFD,
	0xDDF9: 0xFFFD,
	0xDDFA: 0xFFFD,
	0xDDFB: 0xFFFD,
	0xDDFC: 0xFFFD,
	0xDDFD: 0xFFFD,
	0xDDFE: 0xFFFD,
	0xDDFF: 0xFFFD,
	0xDE00: 0xFFFD,
	0xDE01: 0xFFFD,
	0xDE02: 0xFFFD,
	0xDE03: 0xFFFD,
	0xDE04: 0xFFFD,
	0xDE05: 0xFFFD,
	0xDE06: 0xFFFD,
	0xDE07: 0xFFFD,
	0xDE08: 0xFFFD,
	0xDE09: 0xFFFD,
	0xDE0A: 0xFFFD,
	0xDE0B: 0xFFFD,
	0xDE0C: 0xFFFD,
	0xDE0D: 0xFFFD,
	0xDE0E: 0xFFFD,
	0xDE0F: 0xFFFD,
	0xDE10: 0xFFFD,
	0xDE11: 0xFFFD,
	0xDE12: 0xFFFD,
	0xDE13: 0xFFFD,
	0xDE14: 0xFFFD,
	0xDE15: 0xFFFD,
	0xDE16: 0xFFFD,
	0xDE17: 0xFFFD,
	0xDE18: 0xFFFD,
	0xDE19: 0xFFFD,
	0xDE1A: 0xFFFD,
	0xDE1B: 0xFFFD,
	0xDE1C: 0xFFFD,
	0xDE1D: 0xFFFD,
	0xDE1E: 0xFFFD,
	0xDE1F: 0xFFFD,
	0xDE20: 0xFFFD,
	0xDE21: 0xFFFD,
	0xDE22: 0xFFFD,
	0xDE23: 0xFFFD,
	0xDE24: 0xFFFD,
	0xDE25: 0xFFFD,
	0xDE26: 0xFFFD,
	0xDE27: 0xFFFD,
	0xDE28: 0xFFFD,
	0xDE29: 0xFFFD,
	0xDE2A: 0xFFFD,
	0xDE2B: 0xFFFD,
	0xDE2C: 0xFFFD,
	0xDE2D: 0xFFFD,
	0xDE2E: 0xFFFD,
	0xDE2F: 0xFFFD,
	0xDE30: 0xFFFD,
	0xDE31: 0xFFFD,
	0xDE32: 0xFFFD,
	0xDE33: 0xFFFD,
	0xDE34: 0xFFFD,
	0xDE35: 0xFFFD,
	0xDE36: 0xFFFD,
	0xDE37: 0xFFFD,
	0xDE38: 0xFFFD,
	0xDE39: 0xFFFD,
	0xDE3A: 0xFFFD,
	0xDE3B: 0xFFFD,
	0xDE3C: 0xFFFD,
	0xDE3D: 0xFFFD,
	0xDE3E: 0xFFFD,
	0xDE3F: 0xFFFD,
	0xDE40: 0xFFFD,
	0xDE41: 0xFFFD,
	0xDE42: 0xFFFD,
	0xDE43: 0xFFFD,
	0xDE44: 0xFFFD,
	0xDE45: 0xFFFD,
	0xDE46: 0xFFFD,
	0xDE47: 0xFFFD,
	0xDE48: 0xFFFD,
	0xDE49: 0xFFFD,
	0xDE4A: 0xFFFD,
	0xDE4B: 0xFFFD,
	0xDE4C: 0xFFFD,
	0xDE4D: 0xFFFD,
	0xDE4E: 0xFFFD,
	0xDE4F: 0xFFFD,
	0xDE50: 0xFFFD,
	0xDE51: 0xFFFD,
	0xDE52: 0xFFFD,
	0xDE53: 0xFFFD,
	0xDE54: 0xFFFD,
	0xDE55: 0xFFFD,
	0xDE56: 0xFFFD,
	0xDE57: 0xFFFD,
	0xDE58: 0xFFFD,
	0xDE59: 0xFFFD,
	0xDE5A: 0xFFFD,
	0xDE5B: 0xFFFD,
	0xDE5C: 0xFFFD,
	0xDE5D: 0xFFFD,
	0xDE5E: 0xFFFD,
	0xDE5F: 0xFFFD,
	0xDE60: 0xFFFD,
	0xDE61: 0xFFFD,
	0xDE62: 0xFFFD,
	0xDE63: 0xFFFD,
	0xDE64: 0xFFFD,
	0xDE65: 0xFFFD,
	0xDE66: 0xFFFD,
	0xDE67: 0xFFFD,
	0xDE68: 0xFFFD,
	0xDE69: 0xFFFD,
	0xDE6A: 0xFFFD,
	0xDE6B: 0xFFFD,
	0xDE6C: 0xFFFD,
	0xDE6D: 0xFFFD,
	0xDE6E: 0xFFFD,
	0xDE6F: 0xFFFD,
	0xDE70: 0xFFFD,
	0xDE71: 0xFFFD,
	0xDE72: 0xFFFD,
	0xDE73: 0xFFFD,
	0xDE74: 0xFFFD,
	0xDE75: 0xFFFD,
	0xDE76: 0xFFFD,
	0xDE77: 0xFFFD,
	0xDE78: 0xFFFD,
	0xDE79: 0xFFFD,
	0xDE7A: 0xFFFD,
	0xDE7B: 0xFFFD,
	0xDE7C: 0xFFFD,
	0xDE7D: 0xFFFD,
	0xDE7E: 0xFFFD,
	0xDE7F: 0xFFFD,
	0xDE80: 0xFFFD,
	0xDE81: 0xFFFD,
	0xDE82: 0xFFFD,
	0xDE83: 0xFFFD,
	0xDE84: 0xFFFD,
	0xDE85: 0xFFFD,
	0xDE86: 0xFFFD,
	0xDE87: 0xFFFD,
	0xDE88: 0xFFFD,
	0xDE89: 0xFFFD,
	0xDE8A: 0xFFFD,
	0xDE8B: 0xFFFD,
	0xDE8C: 0xFFFD,
	0xDE8D: 0xFFFD,
	0xDE8E: 0xFFFD,
	0xDE8F: 0xFFFD,
	0xDE90: 0xFFFD,
	0xDE91: 0xFFFD,
	0xDE92: 0xFFFD,
	0xDE93: 0xFFFD,
	0xDE94: 0xFFFD,
	0xDE95: 0xFFFD,
	0xDE96: 0xFFFD,
	0xDE97: 0xFFFD,
	0xDE98: 0xFFFD,
	0xDE99: 0xFFFD,
	0xDE9A: 0xFFFD,
	0xDE9B: 0xFFFD,
	0xDE9C: 0xFFFD,
	0xDE9D: 0xFFFD,
	0xDE9E: 0xFFFD,
	0xDE9F: 0xFFFD,
	0xDEA0: 0xFFFD,
	0xDEA1: 0xFFFD,
	0xDEA2: 0xFFFD,
	0xDEA3: 0xFFFD,
	0xDEA4: 0xFFFD,
	0xDEA5: 0xFFFD,
	0xDEA6: 0xFFFD,
	0xDEA7: 0xFFFD,
	0xDEA8: 0xFFFD,
	0xDEA9: 0xFFFD,
	0xDEAA: 0xFFFD,
	0xDEAB: 0xFFFD,
	0xDEAC: 0xFFFD,
	0xDEAD: 0xFFFD,
	0xDEAE: 0xFFFD,
	0xDEAF: 0xFFFD,
	0xDEB0: 0xFFFD,
	0xDEB1: 0xFFFD,
	0xDEB2: 0xFFFD,
	0xDEB3: 0xFFFD,
	0xDEB4: 0xFFFD,
	0xDEB5: 0xFFFD,
	0xDEB6: 0xFFFD,
	0xDEB7: 0xFFFD,
	0xDEB8: 0xFFFD,
	0xDEB9: 0xFFFD,
	0xDEBA: 0xFFFD,
	0xDEBB: 0xFFFD,
	0xDEBC: 0xFFFD,
	0xDEBD: 0xFFFD,
	0xDEBE: 0xFFFD,
	0xDEBF: 0xFFFD,
	0xDEC0: 0xFFFD,
	0xDEC1: 0xFFFD,
	0xDEC2: 0xFFFD,
	0xDEC3: 0xFFFD,
	0xDEC4: 0xFFFD,
	0xDEC5: 0xFFFD,
	0xDEC6: 0xFFFD,
	0xDEC7: 0xFFFD,
	0xDEC8: 0xFFFD,
	0xDEC9: 0xFFFD,
	0xDECA: 0xFFFD,
	0xDECB: 0xFFFD,
	0xDECC: 0xFFFD,
	0xDECD: 0xFFFD,
	0xDECE: 0xFFFD,
	0xDECF: 0xFFFD,
	0xDED0: 0xFFFD,
	0xDED1: 0xFFFD,
	0xDED2: 0xFFFD,
	0xDED3: 0xFFFD,
	0xDED4: 0xFFFD,
	0xDED5: 0xFFFD,
	0xDED6: 0xFFFD,
	0xDED7: 0xFFFD,
	0xDED8: 0xFFFD,
	0xDED9: 0xFFFD,
	0xDEDA: 0xFFFD,
	0xDEDB: 0xFFFD,
	0xDEDC: 0xFFFD,
	0xDEDD: 0xFFFD,
	0xDEDE: 0xFFFD,
	0xDEDF: 0xFFFD,
	0xDEE0: 0xFFFD,
	0xDEE1: 0xFFFD,
	0xDEE2: 0xFFFD,
	0xDEE3: 0xFFFD,
	0xDEE4: 0xFFFD,
	0xDEE5: 0xFFFD,
	0xDEE6: 0xFFFD,
	0xDEE7: 0xFFFD,
	0xDEE8: 0xFFFD,
	0xDEE9: 0xFFFD,
	0xDEEA: 0xFFFD,
	0xDEEB: 0xFFFD,
	0xDEEC: 0xFFFD,
	0xDEED: 0xFFFD,
	0xDEEE: 0xFFFD,
	0xDEEF: 0xFFFD,
	0xDEF0: 0xFFFD,
	0xDEF1: 0xFFFD,
	0xDEF2: 0xFFFD,
	0xDEF3: 0xFFFD,
	0xDEF4: 0xFFFD,
	0xDEF5: 0xFFFD,
	0xDEF6: 0xFFFD,
	0xDEF7: 0xFFFD,
	0xDEF8: 0xFFFD,
	0xDEF9: 0xFFFD,
	0xDEFA: 0xFFFD,
	0xDEFB: 0xFFFD,
	0xDEFC: 0xFFFD,
	0xDEFD: 0xFFFD,
	0xDEFE: 0xFFFD,
	0xDEFF: 0xFFFD,
	0xDF00: 0xFFFD,
	0xDF01: 0xFFFD,
	0xDF02: 0xFFFD,
	0xDF03: 0xFFFD,
	0xDF04: 0xFFFD,
	0xDF05: 0xFFFD,
	0xDF06: 0xFFFD,
	0xDF07: 0xFFFD,
	0xDF08: 0xFFFD,
	0xDF09: 0xFFFD,
	0xDF0A: 0xFFFD,
	0xDF0B: 0xFFFD,
	0xDF0C: 0xFFFD,
	0xDF0D: 0xFFFD,
	0xDF0E: 0xFFFD,
	0xDF0F: 0xFFFD,
	0xDF10: 0xFFFD,
	0xDF11: 0xFFFD,
	0xDF12: 0xFFFD,
	0xDF13: 0xFFFD,
	0xDF14: 0xFFFD,
	0xDF15: 0xFFFD,
	0xDF16: 0xFFFD,
	0xDF17: 0xFFFD,
	0xDF18: 0xFFFD,
	0xDF19: 0xFFFD,
	0xDF1A: 0xFFFD,
	0xDF1B: 0xFFFD,
	0xDF1C: 0xFFFD,
	0xDF1D: 0xFFFD,
	0xDF1E: 0xFFFD,
	0xDF1F: 0xFFFD,
	0xDF20: 0xFFFD,
	0xDF21: 0xFFFD,
	0xDF22: 0xFFFD,
	0xDF23: 0xFFFD,
	0xDF24: 0xFFFD,
	0xDF25: 0xFFFD,
	0xDF26: 0xFFFD,
	0xDF27: 0xFFFD,
	0xDF28: 0xFFFD,
	0xDF29: 0xFFFD,
	0xDF2A: 0xFFFD,
	0xDF2B: 0xFFFD,
	0xDF2C: 0xFFFD,
	0xDF2D: 0xFFFD,
	0xDF2E: 0xFFFD,
	0xDF2F: 0xFFFD,
	0xDF30: 0xFFFD,
	0xDF31: 0xFFFD,
	0xDF32: 0xFFFD,
	0xDF33: 0xFFFD,
	0xDF34: 0xFFFD,
	0xDF35: 0xFFFD,
	0xDF36: 0xFFFD,
	0xDF37: 0xFFFD,
	0xDF38: 0xFFFD,
	0xDF39: 0xFFFD,
	0xDF3A: 0xFFFD,
	0xDF3B: 0xFFFD,
	0xDF3C: 0xFFFD,
	0xDF3D: 0xFFFD,
	0xDF3E: 0xFFFD,
	0xDF3F: 0xFFFD,
	0xDF40: 0xFFFD,
	0xDF41: 0xFFFD,
	0xDF42: 0xFFFD,
	0xDF43: 0xFFFD,
	0xDF44: 0xFFFD,
	0xDF45: 0xFFFD,
	0xDF46: 0xFFFD,
	0xDF47: 0xFFFD,
	0xDF48: 0xFFFD,
	0xDF49: 0xFFFD,
	0xDF4A: 0xFFFD,
	0xDF4B: 0xFFFD,
	0xDF4C: 0xFFFD,
	0xDF4D: 0xFFFD,
	0xDF4E: 0xFFFD,
	0xDF4F: 0xFFFD,
	0xDF50: 0xFFFD,
	0xDF51: 0xFFFD,
	0xDF52: 0xFFFD,
	0xDF53: 0xFFFD,
	0xDF54: 0xFFFD,
	0xDF55: 0xFFFD,
	0xDF56: 0xFFFD,
	0xDF57: 0xFFFD,
	0xDF58: 0xFFFD,
	0xDF59: 0xFFFD,
	0xDF5A: 0xFFFD,
	0xDF5B: 0xFFFD,
	0xDF5C: 0xFFFD,
	0xDF5D: 0xFFFD,
	0xDF5E: 0xFFFD,
	0xDF5F: 0xFFFD,
	0xDF60: 0xFFFD,
	0xDF61: 0xFFFD,
	0xDF62: 0xFFFD,
	0xDF63: 0xFFFD,
	0xDF64: 0xFFFD,
	0xDF65: 0xFFFD,
	0xDF66: 0xFFFD,
	0xDF67: 0xFFFD,
	0xDF68: 0xFFFD,
	0xDF69: 0xFFFD,
	0xDF6A: 0xFFFD,
	0xDF6B: 0xFFFD,
	0xDF6C: 0xFFFD,
	0xDF6D: 0xFFFD,
	0xDF6E: 0xFFFD,
	0xDF6F: 0xFFFD,
	0xDF70: 0xFFFD,
	0xDF71: 0xFFFD,
	0xDF72: 0xFFFD,
	0xDF73: 0xFFFD,
	0xDF74: 0xFFFD,
	0xDF75: 0xFFFD,
	0xDF76: 0xFFFD,
	0xDF77: 0xFFFD,
	0xDF78: 0xFFFD,
	0xDF79: 0xFFFD,
	0xDF7A: 0xFFFD,
	0xDF7B: 0xFFFD,
	0xDF7C: 0xFFFD,
	0xDF7D: 0xFFFD,
	0xDF7E: 0xFFFD,
	0xDF7F: 0xFFFD,
	0xDF80: 0xFFFD,
	0xDF81: 0xFFFD,
	0xDF82: 0xFFFD,
	0xDF83: 0xFFFD,
	0xDF84: 0xFFFD,
	0xDF85: 0xFFFD,
	0xDF86: 0xFFFD,
	0xDF87: 0xFFFD,
	0xDF88: 0xFFFD,
	0xDF89: 0xFFFD,
	0xDF8A: 0xFFFD,
	0xDF8B: 0xFFFD,
	0xDF8C: 0xFFFD,
	0xDF8D: 0xFFFD,
	0xDF8E: 0xFFFD,
	0xDF8F: 0xFFFD,
	0xDF90: 0xFFFD,
	0xDF91: 0xFFFD,
	0xDF92: 0xFFFD,
	0xDF93: 0xFFFD,
	0xDF94: 0xFFFD,
	0xDF95: 0xFFFD,
	0xDF96: 0xFFFD,
	0xDF97: 0xFFFD,
	0xDF98: 0xFFFD,
	0xDF99: 0xFFFD,
	0xDF9A: 0xFFFD,
	0xDF9B: 0xFFFD,
	0xDF9C: 0xFFFD,
	0xDF9D: 0xFFFD,
	0xDF9E: 0xFFFD,
	0xDF9F: 0xFFFD,
	0xDFA0: 0xFFFD,
	0xDFA1: 0xFFFD,
	0xDFA2: 0xFFFD,
	0xDFA3: 0xFFFD,
	0xDFA4: 0xFFFD,
	0xDFA5: 0xFFFD,
	0xDFA6: 0xFFFD,
	0xDFA7: 0xFFFD,
	0xDFA8: 0xFFFD,
	0xDFA9: 0xFFFD,
	0xDFAA: 0xFFFD,
	0xDFAB: 0xFFFD,
	0xDFAC: 0xFFFD,
	0xDFAD: 0xFFFD,
	0xDFAE: 0xFFFD,
	0xDFAF: 0xFFFD,
	0xDFB0: 0xFFFD,
	0xDFB1: 0xFFFD,
	0xDFB2: 0xFFFD,
	0xDFB3: 0xFFFD,
	0xDFB4: 0xFFFD,
	0xDFB5: 0xFFFD,
	0xDFB6: 0xFFFD,
	0xDFB7: 0xFFFD,
	0xDFB8: 0xFFFD,
	0xDFB9: 0xFFFD,
	0xDFBA: 0xFFFD,
	0xDFBB: 0xFFFD,
	0xDFBC: 0xFFFD,
	0xDFBD: 0xFFFD,
	0xDFBE: 0xFFFD,
	0xDFBF: 0xFFFD,
	0xDFC0: 0xFFFD,
	0xDFC1: 0xFFFD,
	0xDFC2: 0xFFFD,
	0xDFC3: 0xFFFD,
	0xDFC4: 0xFFFD,
	0xDFC5: 0xFFFD,
	0xDFC6: 0xFFFD,
	0xDFC7: 0xFFFD,
	0xDFC8: 0xFFFD,
	0xDFC9: 0xFFFD,
	0xDFCA: 0xFFFD,
	0xDFCB: 0xFFFD,
	0xDFCC: 0xFFFD,
	0xDFCD: 0xFFFD,
	0xDFCE: 0xFFFD,
	0xDFCF: 0xFFFD,
	0xDFD0: 0xFFFD,
	0xDFD1: 0xFFFD,
	0xDFD2: 0xFFFD,
	0xDFD3: 0xFFFD,
	0xDFD4: 0xFFFD,
	0xDFD5: 0xFFFD,
	0xDFD6: 0xFFFD,
	0xDFD7: 0xFFFD,
	0xDFD8: 0xFFFD,
	0xDFD9: 0xFFFD,
	0xDFDA: 0xFFFD,
	0xDFDB: 0xFFFD,
	0xDFDC: 0xFFFD,
	0xDFDD: 0xFFFD,
	0xDFDE: 0xFFFD,
	0xDFDF: 0xFFFD,
	0xDFE0: 0xFFFD,
	0xDFE1: 0xFFFD,
	0xDFE2: 0xFFFD,
	0xDFE3: 0xFFFD,
	0xDFE4: 0xFFFD,
	0xDFE5: 0xFFFD,
	0xDFE6: 0xFFFD,
	0xDFE7: 0xFFFD,
	0xDFE8: 0xFFFD,
	0xDFE9: 0xFFFD,
	0xDFEA: 0xFFFD,
	0xDFEB: 0xFFFD,
	0xDFEC: 0xFFFD,
	0xDFED: 0xFFFD,
	0xDFEE: 0xFFFD,
	0xDFEF: 0xFFFD,
	0xDFF0: 0xFFFD,
	0xDFF1: 0xFFFD,
	0xDFF2: 0xFFFD,
	0xDFF3: 0xFFFD,
	0xDFF4: 0xFFFD,
	0xDFF5: 0xFFFD,
	0xDFF6: 0xFFFD,
	0xDFF7: 0xFFFD,
	0xDFF8: 0xFFFD,
	0xDFF9: 0xFFFD,
	0xDFFA: 0xFFFD,
	0xDFFB: 0xFFFD,
	0xDFFC: 0xFFFD,
	0xDFFD: 0xFFFD,
	0xDFFE: 0xFFFD,
	0xDFFF: 0xFFFD,
	0xE000: 0xFA40,
	0xE001: 0xFA41,
	0xE002: 0xFA42,
	0xE003: 0xFA43,
	0xE004: 0xFA44,
	0xE005: 0xFA45,
	0xE006: 0xFA46,
	0xE007: 0xFA47,
	0xE008: 0xFA48,
	0xE009: 0xFA49,
	0xE00A: 0xFA4A,
	0xE00B: 0xFA4B,
	0xE00C: 0xFA4C,
	0xE00D: 0xFA4D,
	0xE00E: 0xFA4E,
	0xE00F: 0xFA4F,
	0xE010: 0xFA50,
	0xE011: 0xFA51,
	0xE012: 0xFA52,
	0xE013: 0xFA53,
	0xE014: 0xFA54,
	0xE015: 0xFA55,
	0xE016: 0xFA56,
	0xE017: 0xFA57,
	0xE018: 0xFA58,
	0xE019: 0xFA59,
	0xE01A: 0xFA5A,
	0xE01B: 0xFA5B,
	0xE01C: 0xFA5C,
	0xE01D: 0xFA5D,
	0xE01E: 0xFA5E,
	0xE01F: 0xFA5F,
	0xE020: 0xFA60,
	0xE021: 0xFA61,
	0xE022: 0xFA62,
	0xE023: 0xFA63,
	0xE024: 0xFA64,
	0xE025: 0xFA65,
	0xE026: 0xFA66,
	0xE027: 0xFA67,
	0xE028: 0xFA68,
	0xE029: 0xFA69,
	0xE02A: 0xFA6A,
	0xE02B: 0xFA6B,
	0xE02C: 0xFA6C,
	0xE02D: 0xFA6D,
	0xE02E: 0xFA6E,
	0xE02F: 0xFA6F,
	0xE030: 0xFA70,
	0xE031: 0xFA71,
	0xE032: 0xFA72,
	0xE033: 0xFA73,
	0xE034: 0xFA74,
	0xE035: 0xFA75,
	0xE036: 0xFA76,
	0xE037: 0xFA77,
	0xE038: 0xFA78,
	0xE039: 0xFA79,
	0xE03A: 0xFA7A,
	0xE03B: 0xFA7B,
	0xE03C: 0xFA7C,
	0xE03D: 0xFA7D,
	0xE03E: 0xFA7E,
	0xE03F: 0xFAA1,
	0xE040: 0xFAA2,
	0xE041: 0xFAA3,
	0xE042: 0xFAA4,
	0xE043: 0xFAA5,
	0xE044: 0xFAA6,
	0xE045: 0xFAA7,
	0xE046: 0xFAA8,
	0xE047: 0xFAA9,
	0xE048: 0xFAAA,
	0xE049: 0xFAAB,
	0xE04A: 0xFAAC,
	0xE04B: 0xFAAD,
	0xE04C: 0xFAAE,
	0xE04D: 0xFAAF,
	0xE04E: 0xFAB0,
	0xE04F: 0xFAB1,
	0xE050: 0xFAB2,
	0xE051: 0xFAB3,
	0xE052: 0xFAB4,
	0xE053: 0xFAB5,
	0xE054: 0xFAB6,
	0xE055: 0xFAB7,
	0xE056: 0xFAB8,
	0xE057: 0xFAB9,
	0xE058: 0xFABA,
	0xE059: 0xFABB,
	0xE05A: 0xFABC,
	0xE05B: 0xFABD,
	0xE05C: 0xFABE,
	0xE05D: 0xFABF,
	0xE05E: 0xFAC0,
	0xE05F: 0xFAC1,
	0xE060: 0xFAC2,
	0xE061: 0xFAC3,
	0xE062: 0xFAC4,
	0xE063: 0xFAC5,
	0xE064: 0xFAC6,
	0xE065: 0xFAC7,
	0xE066: 0xFAC8,
	0xE067: 0xFAC9,
	0xE068: 0xFACA,
	0xE069: 0xFACB,
	0xE06A: 0xFACC,
	0xE06B: 0xFACD,
	0xE06C: 0xFACE,
	0xE06D: 0xFACF,
	0xE06E: 0xFAD0,
	0xE06F: 0xFAD1,
	0xE070: 0xFAD2,
	0xE071: 0xFAD3,
	0xE072: 0xFAD4,
	0xE073: 0xFAD5,
	0xE074: 0xFAD6,
	0xE075: 0xFAD7,
	0xE076: 0xFAD8,
	0xE077: 0xFAD9,
	0xE078: 0xFADA,
	0xE079: 0xFADB,
	0xE07A: 0xFADC,
	0xE07B: 0xFADD,
	0xE07C: 0xFADE,
	0xE07D: 0xFADF,
	0xE07E: 0xFAE0,
	0xE07F: 0xFAE1,
	0xE080: 0xFAE2,
	0xE081: 0xFAE3,
	0xE082: 0xFAE4,
	0xE083: 0xFAE5,
	0xE084: 0xFAE6,
	0xE085: 0xFAE7,
	0xE086: 0xFAE8,
	0xE087: 0xFAE9,
	0xE088: 0xFAEA,
	0xE089: 0xFAEB,
	0xE08A: 0xFAEC,
	0xE08B: 0xFAED,
	0xE08C: 0xFAEE,
	0xE08D: 0xFAEF,
	0xE08E: 0xFAF0,
	0xE08F: 0xFAF1,
	0xE090: 0xFAF2,
	0xE091: 0xFAF3,
	0xE092: 0xFAF4,
	0xE093: 0xFAF5,
	0xE094: 0xFAF6,
	0xE095: 0xFAF7,
	0xE096: 0xFAF8,
	0xE097: 0xFAF9,
	0xE098: 0xFAFA,
	0xE099: 0xFAFB,
	0xE09A: 0xFAFC,
	0xE09B: 0xFAFD,
	0xE09C: 0xFAFE,
	0xE09D: 0xFB40,
	0xE09E: 0xFB41,
	0xE09F: 0xFB42,
	0xE0A0: 0xFB43,
	0xE0A1: 0xFB44,
	0xE0A2: 0xFB45,
	0xE0A3: 0xFB46,
	0xE0A4: 0xFB47,
	0xE0A5: 0xFB48,
	0xE0A6: 0xFB49,
	0xE0A7: 0xFB4A,
	0xE0A8: 0xFB4B,
	0xE0A9: 0xFB4C,
	0xE0AA: 0xFB4D,
	0xE0AB: 0xFB4E,
	0xE0AC: 0xFB4F,
	0xE0AD: 0xFB50,
	0xE0AE: 0xFB51,
	0xE0AF: 0xFB52,
	0xE0B0: 0xFB53,
	0xE0B1: 0xFB54,
	0xE0B2: 0xFB55,
	0xE0B3: 0xFB56,
	0xE0B4: 0xFB57,
	0xE0B5: 0xFB58,
	0xE0B6: 0xFB59,
	0xE0B7: 0xFB5A,
	0xE0B8: 0xFB5B,
	0xE0B9: 0xFB5C,
	0xE0BA: 0xFB5D,
	0xE0BB: 0xFB5E,
	0xE0BC: 0xFB5F,
	0xE0BD: 0xFB60,
	0xE0BE: 0xFB61,
	0xE0BF: 0xFB62,
	0xE0C0: 0xFB63,
	0xE0C1: 0xFB64,
	0xE0C2: 0xFB65,
	0xE0C3: 0xFB66,
	0xE0C4: 0xFB67,
	0xE0C5: 0xFB68,
	0xE0C6: 0xFB69,
	0xE0C7: 0xFB6A,
	0xE0C8: 0xFB6B,
	0xE0C9: 0xFB6C,
	0xE0CA: 0xFB6D,
	0xE0CB: 0xFB6E,
	0xE0CC: 0xFB6F,
	0xE0CD: 0xFB70,
	0xE0CE: 0xFB71,
	0xE0CF: 0xFB72,
	0xE0D0: 0xFB73,
	0xE0D1: 0xFB74,
	0xE0D2: 0xFB75,
	0xE0D3: 0xFB76,
	0xE0D4: 0xFB77,
	0xE0D5: 0xFB78,
	0xE0D6: 0xFB79,
	0xE0D7: 0xFB7A,
	0xE0D8: 0xFB7B,
	0xE0D9: 0xFB7C,
	0xE0DA: 0xFB7D,
	0xE0DB: 0xFB7E,
	0xE0DC: 0xFBA1,
	0xE0DD: 0xFBA2,
	0xE0DE: 0xFBA3,
	0xE0DF: 0xFBA4,
	0xE0E0: 0xFBA5,
	0xE0E1: 0xFBA6,
	0xE0E2: 0xFBA7,
	0xE0E3: 0xFBA8,
	0xE0E4: 0xFBA9,
	0xE0E5: 0xFBAA,
	0xE0E6: 0xFBAB,
	0xE0E7: 0xFBAC,
	0xE0E8: 0xFBAD,
	0xE0E9: 0xFBAE,
	0xE0EA: 0xFBAF,
	0xE0EB: 0xFBB0,
	0xE0EC: 0xFBB1,
	0xE0ED: 0xFBB2,
	0xE0EE: 0xFBB3,
	0xE0EF: 0xFBB4,
	0xE0F0: 0xFBB5,
	0xE0F1: 0xFBB6,
	0xE0F2: 0xFBB7,
	0xE0F3: 0xFBB8,
	0xE0F4: 0xFBB9,
	0xE0F5: 0xFBBA,
	0xE0F6: 0xFBBB,
	0xE0F7: 0xFBBC,
	0xE0F8: 0xFBBD,
	0xE0F9: 0xFBBE,
	0xE0FA: 0xFBBF,
	0xE0FB: 0xFBC0,
	0xE0FC: 0xFBC1,
	0xE0FD: 0xFBC2,
	0xE0FE: 0xFBC3,
	0xE0FF: 0xFBC4,
	0xE100: 0xFBC5,
	0xE101: 0xFBC6,
	0xE102: 0xFBC7,
	0xE103: 0xFBC8,
	0xE104: 0xFBC9,
	0xE105: 0xFBCA,
	0xE106: 0xFBCB,
	0xE107: 0xFBCC,
	0xE108: 0xFBCD,
	0xE109: 0xFBCE,
	0xE10A: 0xFBCF,
	0xE10B: 0xFBD0,
	0xE10C: 0xFBD1,
	0xE10D: 0xFBD2,
	0xE10E: 0xFBD3,
	0xE10F: 0xFBD4,
	0xE110: 0xFBD5,
	0xE111: 0xFBD6,
	0xE112: 0xFBD7,
	0xE113: 0xFBD8,
	0xE114: 0xFBD9,
	0xE115: 0xFBDA,
	0xE116: 0xFBDB,
	0xE117: 0xFBDC,
	0xE118: 0xFBDD,
	0xE119: 0xFBDE,
	0xE11A: 0xFBDF,
	0xE11B: 0xFBE0,
	0xE11C: 0xFBE1,
	0xE11D: 0xFBE2,
	0xE11E: 0xFBE3,
	0xE11F: 0xFBE4,
	0xE120: 0xFBE5,
	0xE121: 0xFBE6,
	0xE122: 0xFBE7,
	0xE123: 0xFBE8,
	0xE124: 0xFBE9,
	0xE125: 0xFBEA,
	0xE126: 0xFBEB,
	0xE127: 0xFBEC,
	0xE128: 0xFBED,
	0xE129: 0xFBEE,
	0xE12A: 0xFBEF,
	0xE12B: 0xFBF0,
	0xE12C: 0xFBF1,
	0xE12D: 0xFBF2,
	0xE12E: 0xFBF3,
	0xE12F: 0xFBF4,
	0xE130: 0xFBF5,
	0xE131: 0xFBF6,
	0xE132: 0xFBF7,
	0xE133: 0xFBF8,
	0xE134: 0xFBF9,
	0xE135: 0xFBFA,
	0xE136: 0xFBFB,
	0xE137: 0xFBFC,
	0xE138: 0xFBFD,
	0xE139: 0xFBFE,
	0xE13A: 0xFC40,
	0xE13B: 0xFC41,
	0xE13C: 0xFC42,
	0xE13D: 0xFC43,
	0xE13E: 0xFC44,
	0xE13F: 0xFC45,
	0xE140: 0xFC46,
	0xE141: 0xFC47,
	0xE142: 0xFC48,
	0xE143: 0xFC49,
	0xE144: 0xFC4A,
	0xE145: 0xFC4B,
	0xE146: 0xFC4C,
	0xE147: 0xFC4D,
	0xE148: 0xFC4E,
	0xE149: 0xFC4F,
	0xE14A: 0xFC50,
	0xE14B: 0xFC51,
	0xE14C: 0xFC52,
	0xE14D: 0xFC53,
	0xE14E: 0xFC54,
	0xE14F: 0xFC55,
	0xE150: 0xFC56,
	0xE151: 0xFC57,
	0xE152: 0xFC58,
	0xE153: 0xFC59,
	0xE154: 0xFC5A,
	0xE155: 0xFC5B,
	0xE156: 0xFC5C,
	0xE157: 0xFC5D,
	0xE158: 0xFC5E,
	0xE159: 0xFC5F,
	0xE15A: 0xFC60,
	0xE15B: 0xFC61,
	0xE15C: 0xFC62,
	0xE15D: 0xFC63,
	0xE15E: 0xFC64,
	0xE15F: 0xFC65,
	0xE160: 0xFC66,
	0xE161: 0xFC67,
	0xE162: 0xFC68,
	0xE163: 0xFC69,
	0xE164: 0xFC6A,
	0xE165: 0xFC6B,
	0xE166: 0xFC6C,
	0xE167: 0xFC6D,
	0xE168: 0xFC6E,
	0xE169: 0xFC6F,
	0xE16A: 0xFC70,
	0xE16B: 0xFC71,
	0xE16C: 0xFC72,
	0xE16D: 0xFC73,
	0xE16E: 0xFC74,
	0xE16F: 0xFC75,
	0xE170: 0xFC76,
	0xE171: 0xFC77,
	0xE172: 0xFC78,
	0xE173: 0xFC79,
	0xE174: 0xFC7A,
	0xE175: 0xFC7B,
	0xE176: 0xFC7C,
	0xE177: 0xFC7D,
	0xE178: 0xFC7E,
	0xE179: 0xFCA1,
	0xE17A: 0xFCA2,
	0xE17B: 0xFCA3,
	0xE17C: 0xFCA4,
	0xE17D: 0xFCA5,
	0xE17E: 0xFCA6,
	0xE17F: 0xFCA7,
	0xE180: 0xFCA8,
	0xE181: 0xFCA9,
	0xE182: 0xFCAA,
	0xE183: 0xFCAB,
	0xE184: 0xFCAC,
	0xE185: 0xFCAD,
	0xE186: 0xFCAE,
	0xE187: 0xFCAF,
	0xE188: 0xFCB0,
	0xE189: 0xFCB1,
	0xE18A: 0xFCB2,
	0xE18B: 0xFCB3,
	0xE18C: 0xFCB4,
	0xE18D: 0xFCB5,
	0xE18E: 0xFCB6,
	0xE18F: 0xFCB7,
	0xE190: 0xFCB8,
	0xE191: 0xFCB9,
	0xE192: 0xFCBA,
	0xE193: 0xFCBB,
	0xE194: 0xFCBC,
	0xE195: 0xFCBD,
	0xE196: 0xFCBE,
	0xE197: 0xFCBF,
	0xE198: 0xFCC0,
	0xE199: 0xFCC1,
	0xE19A: 0xFCC2,
	0xE19B: 0xFCC3,
	0xE19C: 0xFCC4,
	0xE19D: 0xFCC5,
	0xE19E: 0xFCC6,
	0xE19F: 0xFCC7,
	0xE1A0: 0xFCC8,
	0xE1A1: 0xFCC9,
	0xE1A2: 0xFCCA,
	0xE1A3: 0xFCCB,
	0xE1A4: 0xFCCC,
	0xE1A5: 0xFCCD,
	0xE1A6: 0xFCCE,
	0xE1A7: 0xFCCF,
	0xE1A8: 0xFCD0,
	0xE1A9: 0xFCD1,
	0xE1AA: 0xFCD2,
	0xE1AB: 0xFCD3,
	0xE1AC: 0xFCD4,
	0xE1AD: 0xFCD5,
	0xE1AE: 0xFCD6,
	0xE1AF: 0xFCD7,
	0xE1B0: 0xFCD8,
	0xE1B1: 0xFCD9,
	0xE1B2: 0xFCDA,
	0xE1B3: 0xFCDB,
	0xE1B4: 0xFCDC,
	0xE1B5: 0xFCDD,
	0xE1B6: 0xFCDE,
	0xE1B7: 0xFCDF,
	0xE1B8: 0xFCE0,
	0xE1B9: 0xFCE1,
	0xE1BA: 0xFCE2,
	0xE1BB: 0xFCE3,
	0xE1BC: 0xFCE4,
	0xE1BD: 0xFCE5,
	0xE1BE: 0xFCE6,
	0xE1BF: 0xFCE7,
	0xE1C0: 0xFCE8,
	0xE1C1: 0xFCE9,
	0xE1C2: 0xFCEA,
	0xE1C3: 0xFCEB,
	0xE1C4: 0xFCEC,
	0xE1C5: 0xFCED,
	0xE1C6: 0xFCEE,
	0xE1C7: 0xFCEF,
	0xE1C8: 0xFCF0,
	0xE1C9: 0xFCF1,
	0xE1CA: 0xFCF2,
	0xE1CB: 0xFCF3,
	0xE1CC: 0xFCF4,
	0xE1CD: 0xFCF5,
	0xE1CE: 0xFCF6,
	0xE1CF: 0xFCF7,
	0xE1D0: 0xFCF8,
	0xE1D1: 0xFCF9,
	0xE1D2: 0xFCFA,
	0xE1D3: 0xFCFB,
	0xE1D4: 0xFCFC,
	0xE1D5: 0xFCFD,
	0xE1D6: 0xFCFE,
	0xE1D7: 0xFD40,
	0xE1D8: 0xFD41,
	0xE1D9: 0xFD42,
	0xE1DA: 0xFD43,
	0xE1DB: 0xFD44,
	0xE1DC: 0xFD45,
	0xE1DD: 0xFD46,
	0xE1DE: 0xFD47,
	0xE1DF: 0xFD48,
	0xE1E0: 0xFD49,
	0xE1E1: 0xFD4A,
	0xE1E2: 0xFD4B,
	0xE1E3: 0xFD4C,
	0xE1E4: 0xFD4D,
	0xE1E5: 0xFD4E,
	0xE1E6: 0xFD4F,
	0xE1E7: 0xFD50,
	0xE1E8: 0xFD51,
	0xE1E9: 0xFD52,
	0xE1EA: 0xFD53,
	0xE1EB: 0xFD54,
	0xE1EC: 0xFD55,
	0xE1ED: 0xFD56,
	0xE1EE: 0xFD57,
	0xE1EF: 0xFD58,
	0xE1F0: 0xFD59,
	0xE1F1: 0xFD5A,
	0xE1F2: 0xFD5B,
	0xE1F3: 0xFD5C,
	0xE1F4: 0xFD5D,
	0xE1F5: 0xFD5E,
	0xE1F6: 0xFD5F,
	0xE1F7: 0xFD60,
	0xE1F8: 0xFD61,
	0xE1F9: 0xFD62,
	0xE1FA: 0xFD63,
	0xE1FB: 0xFD64,
	0xE1FC: 0xFD65,
	0xE1FD: 0xFD66,
	0xE1FE: 0xFD67,
	0xE1FF: 0xFD68,
	0xE200: 0xFD69,
	0xE201: 0xFD6A,
	0xE202: 0xFD6B,
	0xE203: 0xFD6C,
	0xE204: 0xFD6D,
	0xE205: 0xFD6E,
	0xE206: 0xFD6F,
	0xE207: 0xFD70,
	0xE208: 0xFD71,
	0xE209: 0xFD72,
	0xE20A: 0xFD73,
	0xE20B: 0xFD74,
	0xE20C: 0xFD75,
	0xE20D: 0xFD76,
	0xE20E: 0xFD77,
	0xE20F: 0xFD78,
	0xE210: 0xFD79,
	0xE211: 0xFD7A,
	0xE212: 0xFD7B,
	0xE213: 0xFD7C,
	0xE214: 0xFD7D,
	0xE215: 0xFD7E,
	0xE216: 0xFDA1,
	0xE217: 0xFDA2,
	0xE218: 0xFDA3,
	0xE219: 0xFDA4,
	0xE21A: 0xFDA5,
	0xE21B: 0xFDA6,
	0xE21C: 0xFDA7,
	0xE21D: 0xFDA8,
	0xE21E: 0xFDA9,
	0xE21F: 0xFDAA,
	0xE220: 0xFDAB,
	0xE221: 0xFDAC,
	0xE222: 0xFDAD,
	0xE223: 0xFDAE,
	0xE224: 0xFDAF,
	0xE225: 0xFDB0,
	0xE226: 0xFDB1,
	0xE227: 0xFDB2,
	0xE228: 0xFDB3,
	0xE229: 0xFDB4,
	0xE22A: 0xFDB5,
	0xE22B: 0xFDB6,
	0xE22C: 0xFDB7,
	0xE22D: 0xFDB8,
	0xE22E: 0xFDB9,
	0xE22F: 0xFDBA,
	0xE230: 0xFDBB,
	0xE231: 0xFDBC,
	0xE232: 0xFDBD,
	0xE233: 0xFDBE,
	0xE234: 0xFDBF,
	0xE235: 0xFDC0,
	0xE236: 0xFDC1,
	0xE237: 0xFDC2,
	0xE238: 0xFDC3,
	0xE239: 0xFDC4,
	0xE23A: 0xFDC5,
	0xE23B: 0xFDC6,
	0xE23C: 0xFDC7,
	0xE23D: 0xFDC8,
	0xE23E: 0xFDC9,
	0xE23F: 0xFDCA,
	0xE240: 0xFDCB,
	0xE241: 0xFDCC,
	0xE242: 0xFDCD,
	0xE243: 0xFDCE,
	0xE244: 0xFDCF,
	0xE245: 0xFDD0,
	0xE246: 0xFDD1,
	0xE247: 0xFDD2,
	0xE248: 0xFDD3,
	0xE249: 0xFDD4,
	0xE24A: 0xFDD5,
	0xE24B: 0xFDD6,
	0xE24C: 0xFDD7,
	0xE24D: 0xFDD8,
	0xE24E: 0xFDD9,
	0xE24F: 0xFDDA,
	0xE250: 0xFDDB,
	0xE251: 0xFDDC,
	0xE252: 0xFDDD,
	0xE253: 0xFDDE,
	0xE254: 0xFDDF,
	0xE255: 0xFDE0,
	0xE256: 0xFDE1,
	0xE257: 0xFDE2,
	0xE258: 0xFDE3,
	0xE259: 0xFDE4,
	0xE25A: 0xFDE5,
	0xE25B: 0xFDE6,
	0xE25C: 0xFDE7,
	0xE25D: 0xFDE8,
	0xE25E: 0xFDE9,
	0xE25F: 0xFDEA,
	0xE260: 0xFDEB,
	0xE261: 0xFDEC,
	0xE262: 0xFDED,
	0xE263: 0xFDEE,
	0xE264: 0xFDEF,
	0xE265: 0xFDF0,
	0xE266: 0xFDF1,
	0xE267: 0xFDF2,
	0xE268: 0xFDF3,
	0xE269: 0xFDF4,
	0xE26A: 0xFDF5,
	0xE26B: 0xFDF6,
	0xE26C: 0xFDF7,
	0xE26D: 0xFDF8,
	0xE26E: 0xFDF9,
	0xE26F: 0xFDFA,
	0xE270: 0xFDFB,
	0xE271: 0xFDFC,
	0xE272: 0xFDFD,
	0xE273: 0xFDFE,
	0xE274: 0xFE40,
	0xE275: 0xFE41,
	0xE276: 0xFE42,
	0xE277: 0xFE43,
	0xE278: 0xFE44,
	0xE279: 0xFE45,
	0xE27A: 0xFE46,
	0xE27B: 0xFE47,
	0xE27C: 0xFE48,
	0xE27D: 0xFE49,
	0xE27E: 0xFE4A,
	0xE27F: 0xFE4B,
	0xE280: 0xFE4C,
	0xE281: 0xFE4D,
	0xE282: 0xFE4E,
	0xE283: 0xFE4F,
	0xE284: 0xFE50,
	0xE285: 0xFE51,
	0xE286: 0xFE52,
	0xE287: 0xFE53,
	0xE288: 0xFE54,
	0xE289: 0xFE55,
	0xE28A: 0xFE56,
	0xE28B: 0xFE57,
	0xE28C: 0xFE58,
	0xE28D: 0xFE59,
	0xE28E: 0xFE5A,
	0xE28F: 0xFE5B,
	0xE290: 0xFE5C,
	0xE291: 0xFE5D,
	0xE292: 0xFE5E,
	0xE293: 0xFE5F,
	0xE294: 0xFE60,
	0xE295: 0xFE61,
	0xE296: 0xFE62,
	0xE297: 0xFE63,
	0xE298: 0xFE64,
	0xE299: 0xFE65,
	0xE29A: 0xFE66,
	0xE29B: 0xFE67,
	0xE29C: 0xFE68,
	0xE29D: 0xFE69,
	0xE29E: 0xFE6A,
	0xE29F: 0xFE6B,
	0xE2A0: 0xFE6C,
	0xE2A1: 0xFE6D,
	0xE2A2: 0xFE6E,
	0xE2A3: 0xFE6F,
	0xE2A4: 0xFE70,
	0xE2A5: 0xFE71,
	0xE2A6: 0xFE72,
	0xE2A7: 0xFE73,
	0xE2A8: 0xFE74,
	0xE2A9: 0xFE75,
	0xE2AA: 0xFE76,
	0xE2AB: 0xFE77,
	0xE2AC: 0xFE78,
	0xE2AD: 0xFE79,
	0xE2AE: 0xFE7A,
	0xE2AF: 0xFE7B,
	0xE2B0: 0xFE7C,
	0xE2B1: 0xFE7D,
	0xE2B2: 0xFE7E,
	0xE2B3: 0xFEA1,
	0xE2B4: 0xFEA2,
	0xE2B5: 0xFEA3,
	0xE2B6: 0xFEA4,
	0xE2B7: 0xFEA5,
	0xE2B8: 0xFEA6,
	0xE2B9: 0xFEA7,
	0xE2BA: 0xFEA8,
	0xE2BB: 0xFEA9,
	0xE2BC: 0xFEAA,
	0xE2BD: 0xFEAB,
	0xE2BE: 0xFEAC,
	0xE2BF: 0xFEAD,
	0xE2C0: 0xFEAE,
	0xE2C1: 0xFEAF,
	0xE2C2: 0xFEB0,
	0xE2C3: 0xFEB1,
	0xE2C4: 0xFEB2,
	0xE2C5: 0xFEB3,
	0xE2C6: 0xFEB4,
	0xE2C7: 0xFEB5,
	0xE2C8: 0xFEB6,
	0xE2C9: 0xFEB7,
	0xE2CA: 0xFEB8,
	0xE2CB: 0xFEB9,
	0xE2CC: 0xFEBA,
	0xE2CD: 0xFEBB,
	0xE2CE: 0xFEBC,
	0xE2CF: 0xFEBD,
	0xE2D0: 0xFEBE,
	0xE2D1: 0xFEBF,
	0xE2D2: 0xFEC0,
	0xE2D3: 0xFEC1,
	0xE2D4: 0xFEC2,
	0xE2D5: 0xFEC3,
	0xE2D6: 0xFEC4,
	0xE2D7: 0xFEC5,
	0xE2D8: 0xFEC6,
	0xE2D9: 0xFEC7,
	0xE2DA: 0xFEC8,
	0xE2DB: 0xFEC9,
	0xE2DC: 0xFECA,
	0xE2DD: 0xFECB,
	0xE2DE: 0xFECC,
	0xE2DF: 0xFECD,
	0xE2E0: 0xFECE,
	0xE2E1: 0xFECF,
	0xE2E2: 0xFED0,
	0xE2E3: 0xFED1,
	0xE2E4: 0xFED2,
	0xE2E5: 0xFED3,
	0xE2E6: 0xFED4,
	0xE2E7: 0xFED5,
	0xE2E8: 0xFED6,
	0xE2E9: 0xFED7,
	0xE2EA: 0xFED8,
	0xE2EB: 0xFED9,
	0xE2EC: 0xFEDA,
	0xE2ED: 0xFEDB,
	0xE2EE: 0xFEDC,
	0xE2EF: 0xFEDD,
	0xE2F0: 0xFEDE,
	0xE2F1: 0xFEDF,
	0xE2F2: 0xFEE0,
	0xE2F3: 0xFEE1,
	0xE2F4: 0xFEE2,
	0xE2F5: 0xFEE3,
	0xE2F6: 0xFEE4,
	0xE2F7: 0xFEE5,
	0xE2F8: 0xFEE6,
	0xE2F9: 0xFEE7,
	0xE2FA: 0xFEE8,
	0xE2FB: 0xFEE9,
	0xE2FC: 0xFEEA,
	0xE2FD: 0xFEEB,
	0xE2FE: 0xFEEC,
	0xE2FF: 0xFEED,
	0xE300: 0xFEEE,
	0xE301: 0xFEEF,
	0xE302: 0xFEF0,
	0xE303: 0xFEF1,
	0xE304: 0xFEF2,
	0xE305: 0xFEF3,
	0xE306: 0xFEF4,
	0xE307: 0xFEF5,
	0xE308: 0xFEF6,
	0xE309: 0xFEF7,
	0xE30A: 0xFEF8,
	0xE30B: 0xFEF9,
	0xE30C: 0xFEFA,
	0xE30D: 0xFEFB,
	0xE30E: 0xFEFC,
	0xE30F: 0xFEFD,
	0xE310: 0xFEFE,
	0xE311: 0x8E40,
	0xE312: 0x8E41,
	0xE313: 0x8E42,
	0xE314: 0x8E43,
	0xE315: 0x8E44,
	0xE316: 0x8E45,
	0xE317: 0x8E46,
	0xE318: 0x8E47,
	0xE319: 0x8E48,
	0xE31A: 0x8E49,
	0xE31B: 0x8E4A,
	0xE31C: 0x8E4B,
	0xE31D: 0x8E4C,
	0xE31E: 0x8E4D,
	0xE31F: 0x8E4E,
	0xE320: 0x8E4F,
	0xE321: 0x8E50,
	0xE322: 0x8E51,
	0xE323: 0x8E52,
	0xE324: 0x8E53,
	0xE325: 0x8E54,
	0xE326: 0x8E55,
	0xE327: 0x8E56,
	0xE328: 0x8E57,
	0xE329: 0x8E58,
	0xE32A: 0x8E59,
	0xE32B: 0x8E5A,
	0xE32C: 0x8E5B,
	0xE32D: 0x8E5C,
	0xE32E: 0x8E5D,
	0xE32F: 0x8E5E,
	0xE330: 0x8E5F,
	0xE331: 0x8E60,
	0xE332: 0x8E61,
	0xE333: 0x8E62,
	0xE334: 0x8E63,
	0xE335: 0x8E64,
	0xE336: 0x8E65,
	0xE337: 0x8E66,
	0xE338: 0x8E67,
	0xE339: 0x8E68,
	0xE33A: 0x8E69,
	0xE33B: 0x8E6A,
	0xE33C: 0x8E6B,
	0xE33D: 0x8E6C,
	0xE33E: 0x8E6D,
	0xE33F: 0x8E6E,
	0xE340: 0x8E6F,
	0xE341: 0x8E70,
	0xE342: 0x8E71,
	0xE343: 0x8E72,
	0xE344: 0x8E73,
	0xE345: 0x8E74,
	0xE346: 0x8E75,
	0xE347: 0x8E76,
	0xE348: 0x8E77,
	0xE349: 0x8E78,
	0xE34A: 0x8E79,
	0xE34B: 0x8E7A,
	0xE34C: 0x8E7B,
	0xE34D: 0x8E7C,
	0xE34E: 0x8E7D,
	0xE34F: 0x8E7E,
	0xE350: 0x8EA1,
	0xE351: 0x8EA2,
	0xE352: 0x8EA3,
	0xE353: 0x8EA4,
	0xE354: 0x8EA5,
	0xE355: 0x8EA6,
	0xE356: 0x8EA7,
	0xE357: 0x8EA8,
	0xE358: 0x8EA9,
	0xE359: 0x8EAA,
	0xE35A: 0x8EAB,
	0xE35B: 0x8EAC,
	0xE35C: 0x8EAD,
	0xE35D: 0x8EAE,
	0xE35E: 0x8EAF,
	0xE35F: 0x8EB0,
	0xE360: 0x8EB1,
	0xE361: 0x8EB2,
	0xE362: 0x8EB3,
	0xE363: 0x8EB4,
	0xE364: 0x8EB5,
	0xE365: 0x8EB6,
	0xE366: 0x8EB7,
	0xE367: 0x8EB8,
	0xE368: 0x8EB9,
	0xE369: 0x8EBA,
	0xE36A: 0x8EBB,
	0xE36B: 0x8EBC,
	0xE36C: 0x8EBD,
	0xE36D: 0x8EBE,
	0xE36E: 0x8EBF,
	0xE36F: 0x8EC0,
	0xE370: 0x8EC1,
	0xE371: 0x8EC2,
	0xE372: 0x8EC3,
	0xE373: 0x8EC4,
	0xE374: 0x8EC5,
	0xE375: 0x8EC6,
	0xE376: 0x8EC7,
	0xE377: 0x8EC8,
	0xE378: 0x8EC9,
	0xE379: 0x8ECA,
	0xE37A: 0x8ECB,
	0xE37B: 0x8ECC,
	0xE37C: 0x8ECD,
	0xE37D: 0x8ECE,
	0xE37E: 0x8ECF,
	0xE37F: 0x8ED0,
	0xE380: 0x8ED1,
	0xE381: 0x8ED2,
	0xE382: 0x8ED3,
	0xE383: 0x8ED4,
	0xE384: 0x8ED5,
	0xE385: 0x8ED6,
	0xE386: 0x8ED7,
	0xE387: 0x8ED8,
	0xE388: 0x8ED9,
	0xE389: 0x8EDA,
	0xE38A: 0x8EDB,
	0xE38B: 0x8EDC,
	0xE38C: 0x8EDD,
	0xE38D: 0x8EDE,
	0xE38E: 0x8EDF,
	0xE38F: 0x8EE0,
	0xE390: 0x8EE1,
	0xE391: 0x8EE2,
	0xE392: 0x8EE3,
	0xE393: 0x8EE4,
	0xE394: 0x8EE5,
	0xE395: 0x8EE6,
	0xE396: 0x8EE7,
	0xE397: 0x8EE8,
	0xE398: 0x8EE9,
	0xE399: 0x8EEA,
	0xE39A: 0x8EEB,
	0xE39B: 0x8EEC,
	0xE39C: 0x8EED,
	0xE39D: 0x8EEE,
	0xE39E: 0x8EEF,
	0xE39F: 0x8EF0,
	0xE3A0: 0x8EF1,
	0xE3A1: 0x8EF2,
	0xE3A2: 0x8EF3,
	0xE3A3: 0x8EF4,
	0xE3A4: 0x8EF5,
	0xE3A5: 0x8EF6,
	0xE3A6: 0x8EF7,
	0xE3A7: 0x8EF8,
	0xE3A8: 0x8EF9,
	0xE3A9: 0x8EFA,
	0xE3AA: 0x8EFB,
	0xE3AB: 0x8EFC,
	0xE3AC: 0x8EFD,
	0xE3AD: 0x8EFE,
	0xE3AE: 0x8F40,
	0xE3AF: 0x8F41,
	0xE3B0: 0x8F42,
	0xE3B1: 0x8F43,
	0xE3B2: 0x8F44,
	0xE3B3: 0x8F45,
	0xE3B4: 0x8F46,
	0xE3B5: 0x8F47,
	0xE3B6: 0x8F48,
	0xE3B7: 0x8F49,
	0xE3B8: 0x8F4A,
	0xE3B9: 0x8F4B,
	0xE3BA: 0x8F4C,
	0xE3BB: 0x8F4D,
	0xE3BC: 0x8F4E,
	0xE3BD: 0x8F4F,
	0xE3BE: 0x8F50,
	0xE3BF: 0x8F51,
	0xE3C0: 0x8F52,
	0xE3C1: 0x8F53,
	0xE3C2: 0x8F54,
	0xE3C3: 0x8F55,
	0xE3C4: 0x8F56,
	0xE3C5: 0x8F57,
	0xE3C6: 0x8F58,
	0xE3C7: 0x8F59,
	0xE3C8: 0x8F5A,
	0xE3C9: 0x8F5B,
	0xE3CA: 0x8F5C,
	0xE3CB: 0x8F5D,
	0xE3CC: 0x8F5E,
	0xE3CD: 0x8F5F,
	0xE3CE: 0x8F60,
	0xE3CF: 0x8F61,
	0xE3D0: 0x8F62,
	0xE3D1: 0x8F63,
	0xE3D2: 0x8F64,
	0xE3D3: 0x8F65,
	0xE3D4: 0x8F66,
	0xE3D5: 0x8F67,
	0xE3D6: 0x8F68,
	0xE3D7: 0x8F69,
	0xE3D8: 0x8F6A,
	0xE3D9: 0x8F6B,
	0xE3DA: 0x8F6C,
	0xE3DB: 0x8F6D,
	0xE3DC: 0x8F6E,
	0xE3DD: 0x8F6F,
	0xE3DE: 0x8F70,
	0xE3DF: 0x8F71,
	0xE3E0: 0x8F72,
	0xE3E1: 0x8F73,
	0xE3E2: 0x8F74,
	0xE3E3: 0x8F75,
	0xE3E4: 0x8F76,
	0xE3E5: 0x8F77,
	0xE3E6: 0x8F78,
	0xE3E7: 0x8F79,
	0xE3E8: 0x8F7A,
	0xE3E9: 0x8F7B,
	0xE3EA: 0x8F7C,
	0xE3EB: 0x8F7D,
	0xE3EC: 0x8F7E,
	0xE3ED: 0x8FA1,
	0xE3EE: 0x8FA2,
	0xE3EF: 0x8FA3,
	0xE3F0: 0x8FA4,
	0xE3F1: 0x8FA5,
	0xE3F2: 0x8FA6,
	0xE3F3: 0x8FA7,
	0xE3F4: 0x8FA8,
	0xE3F5: 0x8FA9,
	0xE3F6: 0x8FAA,
	0xE3F7: 0x8FAB,
	0xE3F8: 0x8FAC,
	0xE3F9: 0x8FAD,
	0xE3FA: 0x8FAE,
	0xE3FB: 0x8FAF,
	0xE3FC: 0x8FB0,
	0xE3FD: 0x8FB1,
	0xE3FE: 0x8FB2,
	0xE3FF: 0x8FB3,
	0xE400: 0x8FB4,
	0xE401: 0x8FB5,
	0xE402: 0x8FB6,
	0xE403: 0x8FB7,
	0xE404: 0x8FB8,
	0xE405: 0x8FB9,
	0xE406: 0x8FBA,
	0xE407: 0x8FBB,
	0xE408: 0x8FBC,
	0xE409: 0x8FBD,
	0xE40A: 0x8FBE,
	0xE40B: 0x8FBF,
	0xE40C: 0x8FC0,
	0xE40D: 0x8FC1,
	0xE40E: 0x8FC2,
	0xE40F: 0x8FC3,
	0xE410: 0x8FC4,
	0xE411: 0x8FC5,
	0xE412: 0x8FC6,
	0xE413: 0x8FC7,
	0xE414: 0x8FC8,
	0xE415: 0x8FC9,
	0xE416: 0x8FCA,
	0xE417: 0x8FCB,
	0xE418: 0x8FCC,
	0xE419: 0x8FCD,
	0xE41A: 0x8FCE,
	0xE41B: 0x8FCF,
	0xE41C: 0x8FD0,
	0xE41D: 0x8FD1,
	0xE41E: 0x8FD2,
	0xE41F: 0x8FD3,
	0xE420: 0x8FD4,
	0xE421: 0x8FD5,
	0xE422: 0x8FD6,
	0xE423: 0x8FD7,
	0xE424: 0x8FD8,
	0xE425: 0x8FD9,
	0xE426: 0x8FDA,
	0xE427: 0x8FDB,
	0xE428: 0x8FDC,
	0xE429: 0x8FDD,
	0xE42A: 0x8FDE,
	0xE42B: 0x8FDF,
	0xE42C: 0x8FE0,
	0xE42D: 0x8FE1,
	0xE42E: 0x8FE2,
	0xE42F: 0x8FE3,
	0xE430: 0x8FE4,
	0xE431: 0x8FE5,
	0xE432: 0x8FE6,
	0xE433: 0x8FE7,
	0xE434: 0x8FE8,
	0xE435: 0x8FE9,
	0xE436: 0x8FEA,
	0xE437: 0x8FEB,
	0xE438: 0x8FEC,
	0xE439: 0x8FED,
	0xE43A: 0x8FEE,
	0xE43B: 0x8FEF,
	0xE43C: 0x8FF0,
	0xE43D: 0x8FF1,
	0xE43E: 0x8FF2,
	0xE43F: 0x8FF3,
	0xE440: 0x8FF4,
	0xE441: 0x8FF5,
	0xE442: 0x8FF6,
	0xE443: 0x8FF7,
	0xE444: 0x8FF8,
	0xE445: 0x8FF9,
	0xE446: 0x8FFA,
	0xE447: 0x8FFB,
	0xE448: 0x8FFC,
	0xE449: 0x8FFD,
	0xE44A: 0x8FFE,
	0xE44B: 0x9040,
	0xE44C: 0x9041,
	0xE44D: 0x9042,
	0xE44E: 0x9043,
	0xE44F: 0x9044,
	0xE450: 0x9045,
	0xE451: 0x9046,
	0xE452: 0x9047,
	0xE453: 0x9048,
	0xE454: 0x9049,
	0xE455: 0x904A,
	0xE456: 0x904B,
	0xE457: 0x904C,
	0xE458: 0x904D,
	0xE459: 0x904E,
	0xE45A: 0x904F,
	0xE45B: 0x9050,
	0xE45C: 0x9051,
	0xE45D: 0x9052,
	0xE45E: 0x9053,
	0xE45F: 0x9054,
	0xE460: 0x9055,
	0xE461: 0x9056,
	0xE462: 0x9057,
	0xE463: 0x9058,
	0xE464: 0x9059,
	0xE465: 0x905A,
	0xE466: 0x905B,
	0xE467: 0x905C,
	0xE468: 0x905D,
	0xE469: 0x905E,
	0xE46A: 0x905F,
	0xE46B: 0x9060,
	0xE46C: 0x9061,
	0xE46D: 0x9062,
	0xE46E: 0x9063,
	0xE46F: 0x9064,
	0xE470: 0x9065,
	0xE471: 0x9066,
	0xE472: 0x9067,
	0xE473: 0x9068,
	0xE474: 0x9069,
	0xE475: 0x906A,
	0xE476: 0x906B,
	0xE477: 0x906C,
	0xE478: 0x906D,
	0xE479: 0x906E,
	0xE47A: 0x906F,
	0xE47B: 0x9070,
	0xE47C: 0x9071,
	0xE47D: 0x9072,
	0xE47E: 0x9073,
	0xE47F: 0x9074,
	0xE480: 0x9075,
	0xE481: 0x9076,
	0xE482: 0x9077,
	0xE483: 0x9078,
	0xE484: 0x9079,
	0xE485: 0x907A,
	0xE486: 0x907B,
	0xE487: 0x907C,
	0xE488: 0x907D,
	0xE489: 0x907E,
	0xE48A: 0x90A1,
	0xE48B: 0x90A2,
	0xE48C: 0x90A3,
	0xE48D: 0x90A4,
	0xE48E: 0x90A5,
	0xE48F: 0x90A6,
	0xE490: 0x90A7,
	0xE491: 0x90A8,
	0xE492: 0x90A9,
	0xE493: 0x90AA,
	0xE494: 0x90AB,
	0xE495: 0x90AC,
	0xE496: 0x90AD,
	0xE497: 0x90AE,
	0xE498: 0x90AF,
	0xE499: 0x90B0,
	0xE49A: 0x90B1,
	0xE49B: 0x90B2,
	0xE49C: 0x90B3,
	0xE49D: 0x90B4,
	0xE49E: 0x90B5,
	0xE49F: 0x90B6,
	0xE4A0: 0x90B7,
	0xE4A1: 0x90B8,
	0xE4A2: 0x90B9,
	0xE4A3: 0x90BA,
	0xE4A4: 0x90BB,
	0xE4A5: 0x90BC,
	0xE4A6: 0x90BD,
	0xE4A7: 0x90BE,
	0xE4A8: 0x90BF,
	0xE4A9: 0x90C0,
	0xE4AA: 0x90C1,
	0xE4AB: 0x90C2,
	0xE4AC: 0x90C3,
	0xE4AD: 0x90C4,
	0xE4AE: 0x90C5,
	0xE4AF: 0x90C6,
	0xE4B0: 0x90C7,
	0xE4B1: 0x90C8,
	0xE4B2: 0x90C9,
	0xE4B3: 0x90CA,
	0xE4B4: 0x90CB,
	0xE4B5: 0x90CC,
	0xE4B6: 0x90CD,
	0xE4B7: 0x90CE,
	0xE4B8: 0x90CF,
	0xE4B9: 0x90D0,
	0xE4BA: 0x90D1,
	0xE4BB: 0x90D2,
	0xE4BC: 0x90D3,
	0xE4BD: 0x90D4,
	0xE4BE: 0x90D5,
	0xE4BF: 0x90D6,
	0xE4C0: 0x90D7,
	0xE4C1: 0x90D8,
	0xE4C2: 0x90D9,
	0xE4C3: 0x90DA,
	0xE4C4: 0x90DB,
	0xE4C5: 0x90DC,
	0xE4C6: 0x90DD,
	0xE4C7: 0x90DE,
	0xE4C8: 0x90DF,
	0xE4C9: 0x90E0,
	0xE4CA: 0x90E1,
	0xE4CB: 0x90E2,
	0xE4CC: 0x90E3,
	0xE4CD: 0x90E4,
	0xE4CE: 0x90E5,
	0xE4CF: 0x90E6,
	0xE4D0: 0x90E7,
	0xE4D1: 0x90E8,
	0xE4D2: 0x90E9,
	0xE4D3: 0x90EA,
	0xE4D4: 0x90EB,
	0xE4D5: 0x90EC,
	0xE4D6: 0x90ED,
	0xE4D7: 0x90EE,
	0xE4D8: 0x90EF,
	0xE4D9: 0x90F0,
	0xE4DA: 0x90F1,
	0xE4DB: 0x90F2,
	0xE4DC: 0x90F3,
	0xE4DD: 0x90F4,
	0xE4DE: 0x90F5,
	0xE4DF: 0x90F6,
	0xE4E0: 0x90F7,
	0xE4E1: 0x90F8,
	0xE4E2: 0x90F9,
	0xE4E3: 0x90FA,
	0xE4E4: 0x90FB,
	0xE4E5: 0x90FC,
	0xE4E6: 0x90FD,
	0xE4E7: 0x90FE,
	0xE4E8: 0x9140,
	0xE4E9: 0x9141,
	0xE4EA: 0x9142,
	0xE4EB: 0x9143,
	0xE4EC: 0x9144,
	0xE4ED: 0x9145,
	0xE4EE: 0x9146,
	0xE4EF: 0x9147,
	0xE4F0: 0x9148,
	0xE4F1: 0x9149,
	0xE4F2: 0x914A,
	0xE4F3: 0x914B,
	0xE4F4: 0x914C,
	0xE4F5: 0x914D,
	0xE4F6: 0x914E,
	0xE4F7: 0x914F,
	0xE4F8: 0x9150,
	0xE4F9: 0x9151,
	0xE4FA: 0x9152,
	0xE4FB: 0x9153,
	0xE4FC: 0x9154,
	0xE4FD: 0x9155,
	0xE4FE: 0x9156,
	0xE4FF: 0x9157,
	0xE500: 0x9158,
	0xE501: 0x9159,
	0xE502: 0x915A,
	0xE503: 0x915B,
	0xE504: 0x915C,
	0xE505: 0x915D,
	0xE506: 0x915E,
	0xE507: 0x915F,
	0xE508: 0x9160,
	0xE509: 0x9161,
	0xE50A: 0x9162,
	0xE50B: 0x9163,
	0xE50C: 0x9164,
	0xE50D: 0x9165,
	0xE50E: 0x9166,
	0xE50F: 0x9167,
	0xE510: 0x9168,
	0xE511: 0x9169,
	0xE512: 0x916A,
	0xE513: 0x916B,
	0xE514: 0x916C,
	0xE515: 0x916D,
	0xE516: 0x916E,
	0xE517: 0x916F,
	0xE518: 0x9170,
	0xE519: 0x9171,
	0xE51A: 0x9172,
	0xE51B: 0x9173,
	0xE51C: 0x9174,
	0xE51D: 0x9175,
	0xE51E: 0x9176,
	0xE51F: 0x9177,
	0xE520: 0x9178,
	0xE521: 0x9179,
	0xE522: 0x917A,
	0xE523: 0x917B,
	0xE524: 0x917C,
	0xE525: 0x917D,
	0xE526: 0x917E,
	0xE527: 0x91A1,
	0xE528: 0x91A2,
	0xE529: 0x91A3,
	0xE52A: 0x91A4,
	0xE52B: 0x91A5,
	0xE52C: 0x91A6,
	0xE52D: 0x91A7,
	0xE52E: 0x91A8,
	0xE52F: 0x91A9,
	0xE530: 0x91AA,
	0xE531: 0x91AB,
	0xE532: 0x91AC,
	0xE533: 0x91AD,
	0xE534: 0x91AE,
	0xE535: 0x91AF,
	0xE536: 0x91B0,
	0xE537: 0x91B1,
	0xE538: 0x91B2,
	0xE539: 0x91B3,
	0xE53A: 0x91B4,
	0xE53B: 0x91B5,
	0xE53C: 0x91B6,
	0xE53D: 0x91B7,
	0xE53E: 0x91B8,
	0xE53F: 0x91B9,
	0xE540: 0x91BA,
	0xE541: 0x91BB,
	0xE542: 0x91BC,
	0xE543: 0x91BD,
	0xE544: 0x91BE,
	0xE545: 0x91BF,
	0xE546: 0x91C0,
	0xE547: 0x91C1,
	0xE548: 0x91C2,
	0xE549: 0x91C3,
	0xE54A: 0x91C4,
	0xE54B: 0x91C5,
	0xE54C: 0x91C6,
	0xE54D: 0x91C7,
	0xE54E: 0x91C8,
	0xE54F: 0x91C9,
	0xE550: 0x91CA,
	0xE551: 0x91CB,
	0xE552: 0x91CC,
	0xE553: 0x91CD,
	0xE554: 0x91CE,
	0xE555: 0x91CF,
	0xE556: 0x91D0,
	0xE557: 0x91D1,
	0xE558: 0x91D2,
	0xE559: 0x91D3,
	0xE55A: 0x91D4,
	0xE55B: 0x91D5,
	0xE55C: 0x91D6,
	0xE55D: 0x91D7,
	0xE55E: 0x91D8,
	0xE55F: 0x91D9,
	0xE560: 0x91DA,
	0xE561: 0x91DB,
	0xE562: 0x91DC,
	0xE563: 0x91DD,
	0xE564: 0x91DE,
	0xE565: 0x91DF,
	0xE566: 0x91E0,
	0xE567: 0x91E1,
	0xE568: 0x91E2,
	0xE569: 0x91E3,
	0xE56A: 0x91E4,
	0xE56B: 0x91E5,
	0xE56C: 0x91E6,
	0xE56D: 0x91E7,
	0xE56E: 0x91E8,
	0xE56F: 0x91E9,
	0xE570: 0x91EA,
	0xE571: 0x91EB,
	0xE572: 0x91EC,
	0xE573: 0x91ED,
	0xE574: 0x91EE,
	0xE575: 0x91EF,
	0xE576: 0x91F0,
	0xE577: 0x91F1,
	0xE578: 0x91F2,
	0xE579: 0x91F3,
	0xE57A: 0x91F4,
	0xE57B: 0x91F5,
	0xE57C: 0x91F6,
	0xE57D: 0x91F7,
	0xE57E: 0x91F8,
	0xE57F: 0x91F9,
	0xE580: 0x91FA,
	0xE581: 0x91FB,
	0xE582: 0x91FC,
	0xE583: 0x91FD,
	0xE584: 0x91FE,
	0xE585: 0x9240,
	0xE586: 0x9241,
	0xE587: 0x9242,
	0xE588: 0x9243,
	0xE589: 0x9244,
	0xE58A: 0x9245,
	0xE58B: 0x9246,
	0xE58C: 0x9247,
	0xE58D: 0x9248,
	0xE58E: 0x9249,
	0xE58F: 0x924A,
	0xE590: 0x924B,
	0xE591: 0x924C,
	0xE592: 0x924D,
	0xE593: 0x924E,
	0xE594: 0x924F,
	0xE595: 0x9250,
	0xE596: 0x9251,
	0xE597: 0x9252,
	0xE598: 0x9253,
	0xE599: 0x9254,
	0xE59A: 0x9255,
	0xE59B: 0x9256,
	0xE59C: 0x9257,
	0xE59D: 0x9258,
	0xE59E: 0x9259,
	0xE59F: 0x925A,
	0xE5A0: 0x925B,
	0xE5A1: 0x925C,
	0xE5A2: 0x925D,
	0xE5A3: 0x925E,
	0xE5A4: 0x925F,
	0xE5A5: 0x9260,
	0xE5A6: 0x9261,
	0xE5A7: 0x9262,
	0xE5A8: 0x9263,
	0xE5A9: 0x9264,
	0xE5AA: 0x9265,
	0xE5AB: 0x9266,
	0xE5AC: 0x9267,
	0xE5AD: 0x9268,
	0xE5AE: 0x9269,
	0xE5AF: 0x926A,
	0xE5B0: 0x926B,
	0xE5B1: 0x926C,
	0xE5B2: 0x926D,
	0xE5B3: 0x926E,
	0xE5B4: 0x926F,
	0xE5B5: 0x9270,
	0xE5B6: 0x9271,
	0xE5B7: 0x9272,
	0xE5B8: 0x9273,
	0xE5B9: 0x9274,
	0xE5BA: 0x9275,
	0xE5BB: 0x9276,
	0xE5BC: 0x9277,
	0xE5BD: 0x9278,
	0xE5BE: 0x9279,
	0xE5BF: 0x927A,
	0xE5C0: 0x927B,
	0xE5C1: 0x927C,
	0xE5C2: 0x927D,
	0xE5C3: 0x927E,
	0xE5C4: 0x92A1,
	0xE5C5: 0x92A2,
	0xE5C6: 0x92A3,
	0xE5C7: 0x92A4,
	0xE5C8: 0x92A5,
	0xE5C9: 0x92A6,
	0xE5CA: 0x92A7,
	0xE5CB: 0x92A8,
	0xE5CC: 0x92A9,
	0xE5CD: 0x92AA,
	0xE5CE: 0x92AB,
	0xE5CF: 0x92AC,
	0xE5D0: 0x92AD,
	0xE5D1: 0x92AE,
	0xE5D2: 0x92AF,
	0xE5D3: 0x92B0,
	0xE5D4: 0x92B1,
	0xE5D5: 0x92B2,
	0xE5D6: 0x92B3,
	0xE5D7: 0x92B4,
	0xE5D8: 0x92B5,
	0xE5D9: 0x92B6,
	0xE5DA: 0x92B7,
	0xE5DB: 0x92B8,
	0xE5DC: 0x92B9,
	0xE5DD: 0x92BA,
	0xE5DE: 0x92BB,
	0xE5DF: 0x92BC,
	0xE5E0: 0x92BD,
	0xE5E1: 0x92BE,
	0xE5E2: 0x92BF,
	0xE5E3: 0x92C0,
	0xE5E4: 0x92C1,
	0xE5E5: 0x92C2,
	0xE5E6: 0x92C3,
	0xE5E7: 0x92C4,
	0xE5E8: 0x92C5,
	0xE5E9: 0x92C6,
	0xE5EA: 0x92C7,
	0xE5EB: 0x92C8,
	0xE5EC: 0x92C9,
	0xE5ED: 0x92CA,
	0xE5EE: 0x92CB,
	0xE5EF: 0x92CC,
	0xE5F0: 0x92CD,
	0xE5F1: 0x92CE,
	0xE5F2: 0x92CF,
	0xE5F3: 0x92D0,
	0xE5F4: 0x92D1,
	0xE5F5: 0x92D2,
	0xE5F6: 0x92D3,
	0xE5F7: 0x92D4,
	0xE5F8: 0x92D5,
	0xE5F9: 0x92D6,
	0xE5FA: 0x92D7,
	0xE5FB: 0x92D8,
	0xE5FC: 0x92D9,
	0xE5FD: 0x92DA,
	0xE5FE: 0x92DB,
	0xE5FF: 0x92DC,
	0xE600: 0x92DD,
	0xE601: 0x92DE,
	0xE602: 0x92DF,
	0xE603: 0x92E0,
	0xE604: 0x92E1,
	0xE605: 0x92E2,
	0xE606: 0x92E3,
	0xE607: 0x92E4,
	0xE608: 0x92E5,
	0xE609: 0x92E6,
	0xE60A: 0x92E7,
	0xE60B: 0x92E8,
	0xE60C: 0x92E9,
	0xE60D: 0x92EA,
	0xE60E: 0x92EB,
	0xE60F: 0x92EC,
	0xE610: 0x92ED,
	0xE611: 0x92EE,
	0xE612: 0x92EF,
	0xE613: 0x92F0,
	0xE614: 0x92F1,
	0xE615: 0x92F2,
	0xE616: 0x92F3,
	0xE617: 0x92F4,
	0xE618: 0x92F5,
	0xE619: 0x92F6,
	0xE61A: 0x92F7,
	0xE61B: 0x92F8,
	0xE61C: 0x92F9,
	0xE61D: 0x92FA,
	0xE61E: 0x92FB,
	0xE61F: 0x92FC,
	0xE620: 0x92FD,
	0xE621: 0x92FE,
	0xE622: 0x9340,
	0xE623: 0x9341,
	0xE624: 0x9342,
	0xE625: 0x9343,
	0xE626: 0x9344,
	0xE627: 0x9345,
	0xE628: 0x9346,
	0xE629: 0x9347,
	0xE62A: 0x9348,
	0xE62B: 0x9349,
	0xE62C: 0x934A,
	0xE62D: 0x934B,
	0xE62E: 0x934C,
	0xE62F: 0x934D,
	0xE630: 0x934E,
	0xE631: 0x934F,
	0xE632: 0x9350,
	0xE633: 0x9351,
	0xE634: 0x9352,
	0xE635: 0x9353,
	0xE636: 0x9354,
	0xE637: 0x9355,
	0xE638: 0x9356,
	0xE639: 0x9357,
	0xE63A: 0x9358,
	0xE63B: 0x9359,
	0xE63C: 0x935A,
	0xE63D: 0x935B,
	0xE63E: 0x935C,
	0xE63F: 0x935D,
	0xE640: 0x935E,
	0xE641: 0x935F,
	0xE642: 0x9360,
	0xE643: 0x9361,
	0xE644: 0x9362,
	0xE645: 0x9363,
	0xE646: 0x9364,
	0xE647: 0x9365,
	0xE648: 0x9366,
	0xE649: 0x9367,
	0xE64A: 0x9368,
	0xE64B: 0x9369,
	0xE64C: 0x936A,
	0xE64D: 0x936B,
	0xE64E: 0x936C,
	0xE64F: 0x936D,
	0xE650: 0x936E,
	0xE651: 0x936F,
	0xE652: 0x9370,
	0xE653: 0x9371,
	0xE654: 0x9372,
	0xE655: 0x9373,
	0xE656: 0x9374,
	0xE657: 0x9375,
	0xE658: 0x9376,
	0xE659: 0x9377,
	0xE65A: 0x9378,
	0xE65B: 0x9379,
	0xE65C: 0x937A,
	0xE65D: 0x937B,
	0xE65E: 0x937C,
	0xE65F: 0x937D,
	0xE660: 0x937E,
	0xE661: 0x93A1,
	0xE662: 0x93A2,
	0xE663: 0x93A3,
	0xE664: 0x93A4,
	0xE665: 0x93A5,
	0xE666: 0x93A6,
	0xE667: 0x93A7,
	0xE668: 0x93A8,
	0xE669: 0x93A9,
	0xE66A: 0x93AA,
	0xE66B: 0x93AB,
	0xE66C: 0x93AC,
	0xE66D: 0x93AD,
	0xE66E: 0x93AE,
	0xE66F: 0x93AF,
	0xE670: 0x93B0,
	0xE671: 0x93B1,
	0xE672: 0x93B2,
	0xE673: 0x93B3,
	0xE674: 0x93B4,
	0xE675: 0x93B5,
	0xE676: 0x93B6,
	0xE677: 0x93B7,
	0xE678: 0x93B8,
	0xE679: 0x93B9,
	0xE67A: 0x93BA,
	0xE67B: 0x93BB,
	0xE67C: 0x93BC,
	0xE67D: 0x93BD,
	0xE67E: 0x93BE,
	0xE67F: 0x93BF,
	0xE680: 0x93C0,
	0xE681: 0x93C1,
	0xE682: 0x93C2,
	0xE683: 0x93C3,
	0xE684: 0x93C4,
	0xE685: 0x93C5,
	0xE686: 0x93C6,
	0xE687: 0x93C7,
	0xE688: 0x93C8,
	0xE689: 0x93C9,
	0xE68A: 0x93CA,
	0xE68B: 0x93CB,
	0xE68C: 0x93CC,
	0xE68D: 0x93CD,
	0xE68E: 0x93CE,
	0xE68F: 0x93CF,
	0xE690: 0x93D0,
	0xE691: 0x93D1,
	0xE692: 0x93D2,
	0xE693: 0x93D3,
	0xE694: 0x93D4,
	0xE695: 0x93D5,
	0xE696: 0x93D6,
	0xE697: 0x93D7,
	0xE698: 0x93D8,
	0xE699: 0x93D9,
	0xE69A: 0x93DA,
	0xE69B: 0x93DB,
	0xE69C: 0x93DC,
	0xE69D: 0x93DD,
	0xE69E: 0x93DE,
	0xE69F: 0x93DF,
	0xE6A0: 0x93E0,
	0xE6A1: 0x93E1,
	0xE6A2: 0x93E2,
	0xE6A3: 0x93E3,
	0xE6A4: 0x93E4,
	0xE6A5: 0x93E5,
	0xE6A6: 0x93E6,
	0xE6A7: 0x93E7,
	0xE6A8: 0x93E8,
	0xE6A9: 0x93E9,
	0xE6AA: 0x93EA,
	0xE6AB: 0x93EB,
	0xE6AC: 0x93EC,
	0xE6AD: 0x93ED,
	0xE6AE: 0x93EE,
	0xE6AF: 0x93EF,
	0xE6B0: 0x93F0,
	0xE6B1: 0x93F1,
	0xE6B2: 0x93F2,
	0xE6B3: 0x93F3,
	0xE6B4: 0x93F4,
	0xE6B5: 0x93F5,
	0xE6B6: 0x93F6,
	0xE6B7: 0x93F7,
	0xE6B8: 0x93F8,
	0xE6B9: 0x93F9,
	0xE6BA: 0x93FA,
	0xE6BB: 0x93FB,
	0xE6BC: 0x93FC,
	0xE6BD: 0x93FD,
	0xE6BE: 0x93FE,
	0xE6BF: 0x9440,
	0xE6C0: 0x9441,
	0xE6C1: 0x9442,
	0xE6C2: 0x9443,
	0xE6C3: 0x9444,
	0xE6C4: 0x9445,
	0xE6C5: 0x9446,
	0xE6C6: 0x9447,
	0xE6C7: 0x9448,
	0xE6C8: 0x9449,
	0xE6C9: 0x944A,
	0xE6CA: 0x944B,
	0xE6CB: 0x944C,
	0xE6CC: 0x944D,
	0xE6CD: 0x944E,
	0xE6CE: 0x944F,
	0xE6CF: 0x9450,
	0xE6D0: 0x9451,
	0xE6D1: 0x9452,
	0xE6D2: 0x9453,
	0xE6D3: 0x9454,
	0xE6D4: 0x9455,
	0xE6D5: 0x9456,
	0xE6D6: 0x9457,
	0xE6D7: 0x9458,
	0xE6D8: 0x9459,
	0xE6D9: 0x945A,
	0xE6DA: 0x945B,
	0xE6DB: 0x945C,
	0xE6DC: 0x945D,
	0xE6DD: 0x945E,
	0xE6DE: 0x945F,
	0xE6DF: 0x9460,
	0xE6E0: 0x9461,
	0xE6E1: 0x9462,
	0xE6E2: 0x9463,
	0xE6E3: 0x9464,
	0xE6E4: 0x9465,
	0xE6E5: 0x9466,
	0xE6E6: 0x9467,
	0xE6E7: 0x9468,
	0xE6E8: 0x9469,
	0xE6E9: 0x946A,
	0xE6EA: 0x946B,
	0xE6EB: 0x946C,
	0xE6EC: 0x946D,
	0xE6ED: 0x946E,
	0xE6EE: 0x946F,
	0xE6EF: 0x9470,
	0xE6F0: 0x9471,
	0xE6F1: 0x9472,
	0xE6F2: 0x9473,
	0xE6F3: 0x9474,
	0xE6F4: 0x9475,
	0xE6F5: 0x9476,
	0xE6F6: 0x9477,
	0xE6F7: 0x9478,
	0xE6F8: 0x9479,
	0xE6F9: 0x947A,
	0xE6FA: 0x947B,
	0xE6FB: 0x947C,
	0xE6FC: 0x947D,
	0xE6FD: 0x947E,
	0xE6FE: 0x94A1,
	0xE6FF: 0x94A2,
	0xE700: 0x94A3,
	0xE701: 0x94A4,
	0xE702: 0x94A5,
	0xE703: 0x94A6,
	0xE704: 0x94A7,
	0xE705: 0x94A8,
	0xE706: 0x94A9,
	0xE707: 0x94AA,
	0xE708: 0x94AB,
	0xE709: 0x94AC,
	0xE70A: 0x94AD,
	0xE70B: 0x94AE,
	0xE70C: 0x94AF,
	0xE70D: 0x94B0,
	0xE70E: 0x94B1,
	0xE70F: 0x94B2,
	0xE710: 0x94B3,
	0xE711: 0x94B4,
	0xE712: 0x94B5,
	0xE713: 0x94B6,
	0xE714: 0x94B7,
	0xE715: 0x94B8,
	0xE716: 0x94B9,
	0xE717: 0x94BA,
	0xE718: 0x94BB,
	0xE719: 0x94BC,
	0xE71A: 0x94BD,
	0xE71B: 0x94BE,
	0xE71C: 0x94BF,
	0xE71D: 0x94C0,
	0xE71E: 0x94C1,
	0xE71F: 0x94C2,
	0xE720: 0x94C3,
	0xE721: 0x94C4,
	0xE722: 0x94C5,
	0xE723: 0x94C6,
	0xE724: 0x94C7,
	0xE725: 0x94C8,
	0xE726: 0x94C9,
	0xE727: 0x94CA,
	0xE728: 0x94CB,
	0xE729: 0x94CC,
	0xE72A: 0x94CD,
	0xE72B: 0x94CE,
	0xE72C: 0x94CF,
	0xE72D: 0x94D0,
	0xE72E: 0x94D1,
	0xE72F: 0x94D2,
	0xE730: 0x94D3,
	0xE731: 0x94D4,
	0xE732: 0x94D5,
	0xE733: 0x94D6,
	0xE734: 0x94D7,
	0xE735: 0x94D8,
	0xE736: 0x94D9,
	0xE737: 0x94DA,
	0xE738: 0x94DB,
	0xE739: 0x94DC,
	0xE73A: 0x94DD,
	0xE73B: 0x94DE,
	0xE73C: 0x94DF,
	0xE73D: 0x94E0,
	0xE73E: 0x94E1,
	0xE73F: 0x94E2,
	0xE740: 0x94E3,
	0xE741: 0x94E4,
	0xE742: 0x94E5,
	0xE743: 0x94E6,
	0xE744: 0x94E7,
	0xE745: 0x94E8,
	0xE746: 0x94E9,
	0xE747: 0x94EA,
	0xE748: 0x94EB,
	0xE749: 0x94EC,
	0xE74A: 0x94ED,
	0xE74B: 0x94EE,
	0xE74C: 0x94EF,
	0xE74D: 0x94F0,
	0xE74E: 0x94F1,
	0xE74F: 0x94F2,
	0xE750: 0x94F3,
	0xE751: 0x94F4,
	0xE752: 0x94F5,
	0xE753: 0x94F6,
	0xE754: 0x94F7,
	0xE755: 0x94F8,
	0xE756: 0x94F9,
	0xE757: 0x94FA,
	0xE758: 0x94FB,
	0xE759: 0x94FC,
	0xE75A: 0x94FD,
	0xE75B: 0x94FE,
	0xE75C: 0x9540,
	0xE75D: 0x9541,
	0xE75E: 0x9542,
	0xE75F: 0x9543,
	0xE760: 0x9544,
	0xE761: 0x9545,
	0xE762: 0x9546,
	0xE763: 0x9547,
	0xE764: 0x9548,
	0xE765: 0x9549,
	0xE766: 0x954A,
	0xE767: 0x954B,
	0xE768: 0x954C,
	0xE769: 0x954D,
	0xE76A: 0x954E,
	0xE76B: 0x954F,
	0xE76C: 0x9550,
	0xE76D: 0x9551,
	0xE76E: 0x9552,
	0xE76F: 0x9553,
	0xE770: 0x9554,
	0xE771: 0x9555,
	0xE772: 0x9556,
	0xE773: 0x9557,
	0xE774: 0x9558,
	0xE775: 0x9559,
	0xE776: 0x955A,
	0xE777: 0x955B,
	0xE778: 0x955C,
	0xE779: 0x955D,
	0xE77A: 0x955E,
	0xE77B: 0x955F,
	0xE77C: 0x9560,
	0xE77D: 0x9561,
	0xE77E: 0x9562,
	0xE77F: 0x9563,
	0xE780: 0x9564,
	0xE781: 0x9565,
	0xE782: 0x9566,
	0xE783: 0x9567,
	0xE784: 0x9568,
	0xE785: 0x9569,
	0xE786: 0x956A,
	0xE787: 0x956B,
	0xE788: 0x956C,
	0xE789: 0x956D,
	0xE78A: 0x956E,
	0xE78B: 0x956F,
	0xE78C: 0x9570,
	0xE78D: 0x9571,
	0xE78E: 0x9572,
	0xE78F: 0x9573,
	0xE790: 0x9574,
	0xE791: 0x9575,
	0xE792: 0x9576,
	0xE793: 0x9577,
	0xE794: 0x9578,
	0xE795: 0x9579,
	0xE796: 0x957A,
	0xE797: 0x957B,
	0xE798: 0x957C,
	0xE799: 0x957D,
	0xE79A: 0x957E,
	0xE79B: 0x95A1,
	0xE79C: 0x95A2,
	0xE79D: 0x95A3,
	0xE79E: 0x95A4,
	0xE79F: 0x95A5,
	0xE7A0: 0x95A6,
	0xE7A1: 0x95A7,
	0xE7A2: 0x95A8,
	0xE7A3: 0x95A9,
	0xE7A4: 0x95AA,
	0xE7A5: 0x95AB,
	0xE7A6: 0x95AC,
	0xE7A7: 0x95AD,
	0xE7A8: 0x95AE,
	0xE7A9: 0x95AF,
	0xE7AA: 0x95B0,
	0xE7AB: 0x95B1,
	0xE7AC: 0x95B2,
	0xE7AD: 0x95B3,
	0xE7AE: 0x95B4,
	0xE7AF: 0x95B5,
	0xE7B0: 0x95B6,
	0xE7B1: 0x95B7,
	0xE7B2: 0x95B8,
	0xE7B3: 0x95B9,
	0xE7B4: 0x95BA,
	0xE7B5: 0x95BB,
	0xE7B6: 0x95BC,
	0xE7B7: 0x95BD,
	0xE7B8: 0x95BE,
	0xE7B9: 0x95BF,
	0xE7BA: 0x95C0,
	0xE7BB: 0x95C1,
	0xE7BC: 0x95C2,
	0xE7BD: 0x95C3,
	0xE7BE: 0x95C4,
	0xE7BF: 0x95C5,
	0xE7C0: 0x95C6,
	0xE7C1: 0x95C7,
	0xE7C2: 0x95C8,
	0xE7C3: 0x95C9,
	0xE7C4: 0x95CA,
	0xE7C5: 0x95CB,
	0xE7C6: 0x95CC,
	0xE7C7: 0x95CD,
	0xE7C8: 0x95CE,
	0xE7C9: 0x95CF,
	0xE7CA: 0x95D0,
	0xE7CB: 0x95D1,
	0xE7CC: 0x95D2,
	0xE7CD: 0x95D3,
	0xE7CE: 0x95D4,
	0xE7CF: 0x95D5,
	0xE7D0: 0x95D6,
	0xE7D1: 0x95D7,
	0xE7D2: 0x95D8,
	0xE7D3: 0x95D9,
	0xE7D4: 0x95DA,
	0xE7D5: 0x95DB,
	0xE7D6: 0x95DC,
	0xE7D7: 0x95DD,
	0xE7D8: 0x95DE,
	0xE7D9: 0x95DF,
	0xE7DA: 0x95E0,
	0xE7DB: 0x95E1,
	0xE7DC: 0x95E2,
	0xE7DD: 0x95E3,
	0xE7DE: 0x95E4,
	0xE7DF: 0x95E5,
	0xE7E0: 0x95E6,
	0xE7E1: 0x95E7,
	0xE7E2: 0x95E8,
	0xE7E3: 0x95E9,
	0xE7E4: 0x95EA,
	0xE7E5: 0x95EB,
	0xE7E6: 0x95EC,
	0xE7E7: 0x95ED,
	0xE7E8: 0x95EE,
	0xE7E9: 0x95EF,
	0xE7EA: 0x95F0,
	0xE7EB: 0x95F1,
	0xE7EC: 0x95F2,
	0xE7ED: 0x95F3,
	0xE7EE: 0x95F4,
	0xE7EF: 0x95F5,
	0xE7F0: 0x95F6,
	0xE7F1: 0x95F7,
	0xE7F2: 0x95F8,
	0xE7F3: 0x95F9,
	0xE7F4: 0x95FA,
	0xE7F5: 0x95FB,
	0xE7F6: 0x95FC,
	0xE7F7: 0x95FD,
	0xE7F8: 0x95FE,
	0xE7F9: 0x9640,
	0xE7FA: 0x9641,
	0xE7FB: 0x9642,
	0xE7FC: 0x9643,
	0xE7FD: 0x9644,
	0xE7FE: 0x9645,
	0xE7FF: 0x9646,
	0xE800: 0x9647,
	0xE801: 0x9648,
	0xE802: 0x9649,
	0xE803: 0x964A,
	0xE804: 0x964B,
	0xE805: 0x964C,
	0xE806: 0x964D,
	0xE807: 0x964E,
	0xE808: 0x964F,
	0xE809: 0x9650,
	0xE80A: 0x9651,
	0xE80B: 0x9652,
	0xE80C: 0x9653,
	0xE80D: 0x9654,
	0xE80E: 0x9655,
	0xE80F: 0x9656,
	0xE810: 0x9657,
	0xE811: 0x9658,
	0xE812: 0x9659,
	0xE813: 0x965A,
	0xE814: 0x965B,
	0xE815: 0x965C,
	0xE816: 0x965D,
	0xE817: 0x965E,
	0xE818: 0x965F,
	0xE819: 0x9660,
	0xE81A: 0x9661,
	0xE81B: 0x9662,
	0xE81C: 0x9663,
	0xE81D: 0x9664,
	0xE81E: 0x9665,
	0xE81F: 0x9666,
	0xE820: 0x9667,
	0xE821: 0x9668,
	0xE822: 0x9669,
	0xE823: 0x966A,
	0xE824: 0x966B,
	0xE825: 0x966C,
	0xE826: 0x966D,
	0xE827: 0x966E,
	0xE828: 0x966F,
	0xE829: 0x9670,
	0xE82A: 0x9671,
	0xE82B: 0x9672,
	0xE82C: 0x9673,
	0xE82D: 0x9674,
	0xE82E: 0x9675,
	0xE82F: 0x9676,
	0xE830: 0x9677,
	0xE831: 0x9678,
	0xE832: 0x9679,
	0xE833: 0x967A,
	0xE834: 0x967B,
	0xE835: 0x967C,
	0xE836: 0x967D,
	0xE837: 0x967E,
	0xE838: 0x96A1,
	0xE839: 0x96A2,
	0xE83A: 0x96A3,
	0xE83B: 0x96A4,
	0xE83C: 0x96A5,
	0xE83D: 0x96A6,
	0xE83E: 0x96A7,
	0xE83F: 0x96A8,
	0xE840: 0x96A9,
	0xE841: 0x96AA,
	0xE842: 0x96AB,
	0xE843: 0x96AC,
	0xE844: 0x96AD,
	0xE845: 0x96AE,
	0xE846: 0x96AF,
	0xE847: 0x96B0,
	0xE848: 0x96B1,
	0xE849: 0x96B2,
	0xE84A: 0x96B3,
	0xE84B: 0x96B4,
	0xE84C: 0x96B5,
	0xE84D: 0x96B6,
	0xE84E: 0x96B7,
	0xE84F: 0x96B8,
	0xE850: 0x96B9,
	0xE851: 0x96BA,
	0xE852: 0x96BB,
	0xE853: 0x96BC,
	0xE854: 0x96BD,
	0xE855: 0x96BE,
	0xE856: 0x96BF,
	0xE857: 0x96C0,
	0xE858: 0x96C1,
	0xE859: 0x96C2,
	0xE85A: 0x96C3,
	0xE85B: 0x96C4,
	0xE85C: 0x96C5,
	0xE85D: 0x96C6,
	0xE85E: 0x96C7,
	0xE85F: 0x96C8,
	0xE860: 0x96C9,
	0xE861: 0x96CA,
	0xE862: 0x96CB,
	0xE863: 0x96CC,
	0xE864: 0x96CD,
	0xE865: 0x96CE,
	0xE866: 0x96CF,
	0xE867: 0x96D0,
	0xE868: 0x96D1,
	0xE869: 0x96D2,
	0xE86A: 0x96D3,
	0xE86B: 0x96D4,
	0xE86C: 0x96D5,
	0xE86D: 0x96D6,
	0xE86E: 0x96D7,
	0xE86F: 0x96D8,
	0xE870: 0x96D9,
	0xE871: 0x96DA,
	0xE872: 0x96DB,
	0xE873: 0x96DC,
	0xE874: 0x96DD,
	0xE875: 0x96DE,
	0xE876: 0x96DF,
	0xE877: 0x96E0,
	0xE878: 0x96E1,
	0xE879: 0x96E2,
	0xE87A: 0x96E3,
	0xE87B: 0x96E4,
	0xE87C: 0x96E5,
	0xE87D: 0x96E6,
	0xE87E: 0x96E7,
	0xE87F: 0x96E8,
	0xE880: 0x96E9,
	0xE881: 0x96EA,
	0xE882: 0x96EB,
	0xE883: 0x96EC,
	0xE884: 0x96ED,
	0xE885: 0x96EE,
	0xE886: 0x96EF,
	0xE887: 0x96F0,
	0xE888: 0x96F1,
	0xE889: 0x96F2,
	0xE88A: 0x96F3,
	0xE88B: 0x96F4,
	0xE88C: 0x96F5,
	0xE88D: 0x96F6,
	0xE88E: 0x96F7,
	0xE88F: 0x96F8,
	0xE890: 0x96F9,
	0xE891: 0x96FA,
	0xE892: 0x96FB,
	0xE893: 0x96FC,
	0xE894: 0x96FD,
	0xE895: 0x96FE,
	0xE896: 0x9740,
	0xE897: 0x9741,
	0xE898: 0x9742,
	0xE899: 0x9743,
	0xE89A: 0x9744,
	0xE89B: 0x9745,
	0xE89C: 0x9746,
	0xE89D: 0x9747,
	0xE89E: 0x9748,
	0xE89F: 0x9749,
	0xE8A0: 0x974A,
	0xE8A1: 0x974B,
	0xE8A2: 0x974C,
	0xE8A3: 0x974D,
	0xE8A4: 0x974E,
	0xE8A5: 0x974F,
	0xE8A6: 0x9750,
	0xE8A7: 0x9751,
	0xE8A8: 0x9752,
	0xE8A9: 0x9753,
	0xE8AA: 0x9754,
	0xE8AB: 0x9755,
	0xE8AC: 0x9756,
	0xE8AD: 0x9757,
	0xE8AE: 0x9758,
	0xE8AF: 0x9759,
	0xE8B0: 0x975A,
	0xE8B1: 0x975B,
	0xE8B2: 0x975C,
	0xE8B3: 0x975D,
	0xE8B4: 0x975E,
	0xE8B5: 0x975F,
	0xE8B6: 0x9760,
	0xE8B7: 0x9761,
	0xE8B8: 0x9762,
	0xE8B9: 0x9763,
	0xE8BA: 0x9764,
	0xE8BB: 0x9765,
	0xE8BC: 0x9766,
	0xE8BD: 0x9767,
	0xE8BE: 0x9768,
	0xE8BF: 0x9769,
	0xE8C0: 0x976A,
	0xE8C1: 0x976B,
	0xE8C2: 0x976C,
	0xE8C3: 0x976D,
	0xE8C4: 0x976E,
	0xE8C5: 0x976F,
	0xE8C6: 0x9770,
	0xE8C7: 0x9771,
	0xE8C8: 0x9772,
	0xE8C9: 0x9773,
	0xE8CA: 0x9774,
	0xE8CB: 0x9775,
	0xE8CC: 0x9776,
	0xE8CD: 0x9777,
	0xE8CE: 0x9778,
	0xE8CF: 0x9779,
	0xE8D0: 0x977A,
	0xE8D1: 0x977B,
	0xE8D2: 0x977C,
	0xE8D3: 0x977D,
	0xE8D4: 0x977E,
	0xE8D5: 0x97A1,
	0xE8D6: 0x97A2,
	0xE8D7: 0x97A3,
	0xE8D8: 0x97A4,
	0xE8D9: 0x97A5,
	0xE8DA: 0x97A6,
	0xE8DB: 0x97A7,
	0xE8DC: 0x97A8,
	0xE8DD: 0x97A9,
	0xE8DE: 0x97AA,
	0xE8DF: 0x97AB,
	0xE8E0: 0x97AC,
	0xE8E1: 0x97AD,
	0xE8E2: 0x97AE,
	0xE8E3: 0x97AF,
	0xE8E4: 0x97B0,
	0xE8E5: 0x97B1,
	0xE8E6: 0x97B2,
	0xE8E7: 0x97B3,
	0xE8E8: 0x97B4,
	0xE8E9: 0x97B5,
	0xE8EA: 0x97B6,
	0xE8EB: 0x97B7,
	0xE8EC: 0x97B8,
	0xE8ED: 0x97B9,
	0xE8EE: 0x97BA,
	0xE8EF: 0x97BB,
	0xE8F0: 0x97BC,
	0xE8F1: 0x97BD,
	0xE8F2: 0x97BE,
	0xE8F3: 0x97BF,
	0xE8F4: 0x97C0,
	0xE8F5: 0x97C1,
	0xE8F6: 0x97C2,
	0xE8F7: 0x97C3,
	0xE8F8: 0x97C4,
	0xE8F9: 0x97C5,
	0xE8FA: 0x97C6,
	0xE8FB: 0x97C7,
	0xE8FC: 0x97C8,
	0xE8FD: 0x97C9,
	0xE8FE: 0x97CA,
	0xE8FF: 0x97CB,
	0xE900: 0x97CC,
	0xE901: 0x97CD,
	0xE902: 0x97CE,
	0xE903: 0x97CF,
	0xE904: 0x97D0,
	0xE905: 0x97D1,
	0xE906: 0x97D2,
	0xE907: 0x97D3,
	0xE908: 0x97D4,
	0xE909: 0x97D5,
	0xE90A: 0x97D6,
	0xE90B: 0x97D7,
	0xE90C: 0x97D8,
	0xE90D: 0x97D9,
	0xE90E: 0x97DA,
	0xE90F: 0x97DB,
	0xE910: 0x97DC,
	0xE911: 0x97DD,
	0xE912: 0x97DE,
	0xE913: 0x97DF,
	0xE914: 0x97E0,
	0xE915: 0x97E1,
	0xE916: 0x97E2,
	0xE917: 0x97E3,
	0xE918: 0x97E4,
	0xE919: 0x97E5,
	0xE91A: 0x97E6,
	0xE91B: 0x97E7,
	0xE91C: 0x97E8,
	0xE91D: 0x97E9,
	0xE91E: 0x97EA,
	0xE91F: 0x97EB,
	0xE920: 0x97EC,
	0xE921: 0x97ED,
	0xE922: 0x97EE,
	0xE923: 0x97EF,
	0xE924: 0x97F0,
	0xE925: 0x97F1,
	0xE926: 0x97F2,
	0xE927: 0x97F3,
	0xE928: 0x97F4,
	0xE929: 0x97F5,
	0xE92A: 0x97F6,
	0xE92B: 0x97F7,
	0xE92C: 0x97F8,
	0xE92D: 0x97F9,
	0xE92E: 0x97FA,
	0xE92F: 0x97FB,
	0xE930: 0x97FC,
	0xE931: 0x97FD,
	0xE932: 0x97FE,
	0xE933: 0x9840,
	0xE934: 0x9841,
	0xE935: 0x9842,
	0xE936: 0x9843,
	0xE937: 0x9844,
	0xE938: 0x9845,
	0xE939: 0x9846,
	0xE93A: 0x9847,
	0xE93B: 0x9848,
	0xE93C: 0x9849,
	0xE93D: 0x984A,
	0xE93E: 0x984B,
	0xE93F: 0x984C,
	0xE940: 0x984D,
	0xE941: 0x984E,
	0xE942: 0x984F,
	0xE943: 0x9850,
	0xE944: 0x9851,
	0xE945: 0x9852,
	0xE946: 0x9853,
	0xE947: 0x9854,
	0xE948: 0x9855,
	0xE949: 0x9856,
	0xE94A: 0x9857,
	0xE94B: 0x9858,
	0xE94C: 0x9859,
	0xE94D: 0x985A,
	0xE94E: 0x985B,
	0xE94F: 0x985C,
	0xE950: 0x985D,
	0xE951: 0x985E,
	0xE952: 0x985F,
	0xE953: 0x9860,
	0xE954: 0x9861,
	0xE955: 0x9862,
	0xE956: 0x9863,
	0xE957: 0x9864,
	0xE958: 0x9865,
	0xE959: 0x9866,
	0xE95A: 0x9867,
	0xE95B: 0x9868,
	0xE95C: 0x9869,
	0xE95D: 0x986A,
	0xE95E: 0x986B,
	0xE95F: 0x986C,
	0xE960: 0x986D,
	0xE961: 0x986E,
	0xE962: 0x986F,
	0xE963: 0x9870,
	0xE964: 0x9871,
	0xE965: 0x9872,
	0xE966: 0x9873,
	0xE967: 0x9874,
	0xE968: 0x9875,
	0xE969: 0x9876,
	0xE96A: 0x9877,
	0xE96B: 0x9878,
	0xE96C: 0x9879,
	0xE96D: 0x987A,
	0xE96E: 0x987B,
	0xE96F: 0x987C,
	0xE970: 0x987D,
	0xE971: 0x987E,
	0xE972: 0x98A1,
	0xE973: 0x98A2,
	0xE974: 0x98A3,
	0xE975: 0x98A4,
	0xE976: 0x98A5,
	0xE977: 0x98A6,
	0xE978: 0x98A7,
	0xE979: 0x98A8,
	0xE97A: 0x98A9,
	0xE97B: 0x98AA,
	0xE97C: 0x98AB,
	0xE97D: 0x98AC,
	0xE97E: 0x98AD,
	0xE97F: 0x98AE,
	0xE980: 0x98AF,
	0xE981: 0x98B0,
	0xE982: 0x98B1,
	0xE983: 0x98B2,
	0xE984: 0x98B3,
	0xE985: 0x98B4,
	0xE986: 0x98B5,
	0xE987: 0x98B6,
	0xE988: 0x98B7,
	0xE989: 0x98B8,
	0xE98A: 0x98B9,
	0xE98B: 0x98BA,
	0xE98C: 0x98BB,
	0xE98D: 0x98BC,
	0xE98E: 0x98BD,
	0xE98F: 0x98BE,
	0xE990: 0x98BF,
	0xE991: 0x98C0,
	0xE992: 0x98C1,
	0xE993: 0x98C2,
	0xE994: 0x98C3,
	0xE995: 0x98C4,
	0xE996: 0x98C5,
	0xE997: 0x98C6,
	0xE998: 0x98C7,
	0xE999: 0x98C8,
	0xE99A: 0x98C9,
	0xE99B: 0x98CA,
	0xE99C: 0x98CB,
	0xE99D: 0x98CC,
	0xE99E: 0x98CD,
	0xE99F: 0x98CE,
	0xE9A0: 0x98CF,
	0xE9A1: 0x98D0,
	0xE9A2: 0x98D1,
	0xE9A3: 0x98D2,
	0xE9A4: 0x98D3,
	0xE9A5: 0x98D4,
	0xE9A6: 0x98D5,
	0xE9A7: 0x98D6,
	0xE9A8: 0x98D7,
	0xE9A9: 0x98D8,
	0xE9AA: 0x98D9,
	0xE9AB: 0x98DA,
	0xE9AC: 0x98DB,
	0xE9AD: 0x98DC,
	0xE9AE: 0x98DD,
	0xE9AF: 0x98DE,
	0xE9B0: 0x98DF,
	0xE9B1: 0x98E0,
	0xE9B2: 0x98E1,
	0xE9B3: 0x98E2,
	0xE9B4: 0x98E3,
	0xE9B5: 0x98E4,
	0xE9B6: 0x98E5,
	0xE9B7: 0x98E6,
	0xE9B8: 0x98E7,
	0xE9B9: 0x98E8,
	0xE9BA: 0x98E9,
	0xE9BB: 0x98EA,
	0xE9BC: 0x98EB,
	0xE9BD: 0x98EC,
	0xE9BE: 0x98ED,
	0xE9BF: 0x98EE,
	0xE9C0: 0x98EF,
	0xE9C1: 0x98F0,
	0xE9C2: 0x98F1,
	0xE9C3: 0x98F2,
	0xE9C4: 0x98F3,
	0xE9C5: 0x98F4,
	0xE9C6: 0x98F5,
	0xE9C7: 0x98F6,
	0xE9C8: 0x98F7,
	0xE9C9: 0x98F8,
	0xE9CA: 0x98F9,
	0xE9CB: 0x98FA,
	0xE9CC: 0x98FB,
	0xE9CD: 0x98FC,
	0xE9CE: 0x98FD,
	0xE9CF: 0x98FE,
	0xE9D0: 0x9940,
	0xE9D1: 0x9941,
	0xE9D2: 0x9942,
	0xE9D3: 0x9943,
	0xE9D4: 0x9944,
	0xE9D5: 0x9945,
	0xE9D6: 0x9946,
	0xE9D7: 0x9947,
	0xE9D8: 0x9948,
	0xE9D9: 0x9949,
	0xE9DA: 0x994A,
	0xE9DB: 0x994B,
	0xE9DC: 0x994C,
	0xE9DD: 0x994D,
	0xE9DE: 0x994E,
	0xE9DF: 0x994F,
	0xE9E0: 0x9950,
	0xE9E1: 0x9951,
	0xE9E2: 0x9952,
	0xE9E3: 0x9953,
	0xE9E4: 0x9954,
	0xE9E5: 0x9955,
	0xE9E6: 0x9956,
	0xE9E7: 0x9957,
	0xE9E8: 0x9958,
	0xE9E9: 0x9959,
	0xE9EA: 0x995A,
	0xE9EB: 0x995B,
	0xE9EC: 0x995C,
	0xE9ED: 0x995D,
	0xE9EE: 0x995E,
	0xE9EF: 0x995F,
	0xE9F0: 0x9960,
	0xE9F1: 0x9961,
	0xE9F2: 0x9962,
	0xE9F3: 0x9963,
	0xE9F4: 0x9964,
	0xE9F5: 0x9965,
	0xE9F6: 0x9966,
	0xE9F7: 0x9967,
	0xE9F8: 0x9968,
	0xE9F9: 0x9969,
	0xE9FA: 0x996A,
	0xE9FB: 0x996B,
	0xE9FC: 0x996C,
	0xE9FD: 0x996D,
	0xE9FE: 0x996E,
	0xE9FF: 0x996F,
	0xEA00: 0x9970,
	0xEA01: 0x9971,
	0xEA02: 0x9972,
	0xEA03: 0x9973,
	0xEA04: 0x9974,
	0xEA05: 0x9975,
	0xEA06: 0x9976,
	0xEA07: 0x9977,
	0xEA08: 0x9978,
	0xEA09: 0x9979,
	0xEA0A: 0x997A,
	0xEA0B: 0x997B,
	0xEA0C: 0x997C,
	0xEA0D: 0x997D,
	0xEA0E: 0x997E,
	0xEA0F: 0x99A1,
	0xEA10: 0x99A2,
	0xEA11: 0x99A3,
	0xEA12: 0x99A4,
	0xEA13: 0x99A5,
	0xEA14: 0x99A6,
	0xEA15: 0x99A7,
	0xEA16: 0x99A8,
	0xEA17: 0x99A9,
	0xEA18: 0x99AA,
	0xEA19: 0x99AB,
	0xEA1A: 0x99AC,
	0xEA1B: 0x99AD,
	0xEA1C: 0x99AE,
	0xEA1D: 0x99AF,
	0xEA1E: 0x99B0,
	0xEA1F: 0x99B1,
	0xEA20: 0x99B2,
	0xEA21: 0x99B3,
	0xEA22: 0x99B4,
	0xEA23: 0x99B5,
	0xEA24: 0x99B6,
	0xEA25: 0x99B7,
	0xEA26: 0x99B8,
	0xEA27: 0x99B9,
	0xEA28: 0x99BA,
	0xEA29: 0x99BB,
	0xEA2A: 0x99BC,
	0xEA2B: 0x99BD,
	0xEA2C: 0x99BE,
	0xEA2D: 0x99BF,
	0xEA2E: 0x99C0,
	0xEA2F: 0x99C1,
	0xEA30: 0x99C2,
	0xEA31: 0x99C3,
	0xEA32: 0x99C4,
	0xEA33: 0x99C5,
	0xEA34: 0x99C6,
	0xEA35: 0x99C7,
	0xEA36: 0x99C8,
	0xEA37: 0x99C9,
	0xEA38: 0x99CA,
	0xEA39: 0x99CB,
	0xEA3A: 0x99CC,
	0xEA3B: 0x99CD,
	0xEA3C: 0x99CE,
	0xEA3D: 0x99CF,
	0xEA3E: 0x99D0,
	0xEA3F: 0x99D1,
	0xEA40: 0x99D2,
	0xEA41: 0x99D3,
	0xEA42: 0x99D4,
	0xEA43: 0x99D5,
	0xEA44: 0x99D6,
	0xEA45: 0x99D7,
	0xEA46: 0x99D8,
	0xEA47: 0x99D9,
	0xEA48: 0x99DA,
	0xEA49: 0x99DB,
	0xEA4A: 0x99DC,
	0xEA4B: 0x99DD,
	0xEA4C: 0x99DE,
	0xEA4D: 0x99DF,
	0xEA4E: 0x99E0,
	0xEA4F: 0x99E1,
	0xEA50: 0x99E2,
	0xEA51: 0x99E3,
	0xEA52: 0x99E4,
	0xEA53: 0x99E5,
	0xEA54: 0x99E6,
	0xEA55: 0x99E7,
	0xEA56: 0x99E8,
	0xEA57: 0x99E9,
	0xEA58: 0x99EA,
	0xEA59: 0x99EB,
	0xEA5A: 0x99EC,
	0xEA5B: 0x99ED,
	0xEA5C: 0x99EE,
	0xEA5D: 0x99EF,
	0xEA5E: 0x99F0,
	0xEA5F: 0x99F1,
	0xEA60: 0x99F2,
	0xEA61: 0x99F3,
	0xEA62: 0x99F4,
	0xEA63: 0x99F5,
	0xEA64: 0x99F6,
	0xEA65: 0x99F7,
	0xEA66: 0x99F8,
	0xEA67: 0x99F9,
	0xEA68: 0x99FA,
	0xEA69: 0x99FB,
	0xEA6A: 0x99FC,
	0xEA6B: 0x99FD,
	0xEA6C: 0x99FE,
	0xEA6D: 0x9A40,
	0xEA6E: 0x9A41,
	0xEA6F: 0x9A42,
	0xEA70: 0x9A43,
	0xEA71: 0x9A44,
	0xEA72: 0x9A45,
	0xEA73: 0x9A46,
	0xEA74: 0x9A47,
	0xEA75: 0x9A48,
	0xEA76: 0x9A49,
	0xEA77: 0x9A4A,
	0xEA78: 0x9A4B,
	0xEA79: 0x9A4C,
	0xEA7A: 0x9A4D,
	0xEA7B: 0x9A4E,
	0xEA7C: 0x9A4F,
	0xEA7D: 0x9A50,
	0xEA7E: 0x9A51,
	0xEA7F: 0x9A52,
	0xEA80: 0x9A53,
	0xEA81: 0x9A54,
	0xEA82: 0x9A55,
	0xEA83: 0x9A56,
	0xEA84: 0x9A57,
	0xEA85: 0x9A58,
	0xEA86: 0x9A59,
	0xEA87: 0x9A5A,
	0xEA88: 0x9A5B,
	0xEA89: 0x9A5C,
	0xEA8A: 0x9A5D,
	0xEA8B: 0x9A5E,
	0xEA8C: 0x9A5F,
	0xEA8D: 0x9A60,
	0xEA8E: 0x9A61,
	0xEA8F: 0x9A62,
	0xEA90: 0x9A63,
	0xEA91: 0x9A64,
	0xEA92: 0x9A65,
	0xEA93: 0x9A66,
	0xEA94: 0x9A67,
	0xEA95: 0x9A68,
	0xEA96: 0x9A69,
	0xEA97: 0x9A6A,
	0xEA98: 0x9A6B,
	0xEA99: 0x9A6C,
	0xEA9A: 0x9A6D,
	0xEA9B: 0x9A6E,
	0xEA9C: 0x9A6F,
	0xEA9D: 0x9A70,
	0xEA9E: 0x9A71,
	0xEA9F: 0x9A72,
	0xEAA0: 0x9A73,
	0xEAA1: 0x9A74,
	0xEAA2: 0x9A75,
	0xEAA3: 0x9A76,
	0xEAA4: 0x9A77,
	0xEAA5: 0x9A78,
	0xEAA6: 0x9A79,
	0xEAA7: 0x9A7A,
	0xEAA8: 0x9A7B,
	0xEAA9: 0x9A7C,
	0xEAAA: 0x9A7D,
	0xEAAB: 0x9A7E,
	0xEAAC: 0x9AA1,
	0xEAAD: 0x9AA2,
	0xEAAE: 0x9AA3,
	0xEAAF: 0x9AA4,
	0xEAB0: 0x9AA5,
	0xEAB1: 0x9AA6,
	0xEAB2: 0x9AA7,
	0xEAB3: 0x9AA8,
	0xEAB4: 0x9AA9,
	0xEAB5: 0x9AAA,
	0xEAB6: 0x9AAB,
	0xEAB7: 0x9AAC,
	0xEAB8: 0x9AAD,
	0xEAB9: 0x9AAE,
	0xEABA: 0x9AAF,
	0xEABB: 0x9AB0,
	0xEABC: 0x9AB1,
	0xEABD: 0x9AB2,
	0xEABE: 0x9AB3,
	0xEABF: 0x9AB4,
	0xEAC0: 0x9AB5,
	0xEAC1: 0x9AB6,
	0xEAC2: 0x9AB7,
	0xEAC3: 0x9AB8,
	0xEAC4: 0x9AB9,
	0xEAC5: 0x9ABA,
	0xEAC6: 0x9ABB,
	0xEAC7: 0x9ABC,
	0xEAC8: 0x9ABD,
	0xEAC9: 0x9ABE,
	0xEACA: 0x9ABF,
	0xEACB: 0x9AC0,
	0xEACC: 0x9AC1,
	0xEACD: 0x9AC2,
	0xEACE: 0x9AC3,
	0xEACF: 0x9AC4,
	0xEAD0: 0x9AC5,
	0xEAD1: 0x9AC6,
	0xEAD2: 0x9AC7,
	0xEAD3: 0x9AC8,
	0xEAD4: 0x9AC9,
	0xEAD5: 0x9ACA,
	0xEAD6: 0x9ACB,
	0xEAD7: 0x9ACC,
	0xEAD8: 0x9ACD,
	0xEAD9: 0x9ACE,
	0xEADA: 0x9ACF,
	0xEADB: 0x9AD0,
	0xEADC: 0x9AD1,
	0xEADD: 0x9AD2,
	0xEADE: 0x9AD3,
	0xEADF: 0x9AD4,
	0xEAE0: 0x9AD5,
	0xEAE1: 0x9AD6,
	0xEAE2: 0x9AD7,
	0xEAE3: 0x9AD8,
	0xEAE4: 0x9AD9,
	0xEAE5: 0x9ADA,
	0xEAE6: 0x9ADB,
	0xEAE7: 0x9ADC,
	0xEAE8: 0x9ADD,
	0xEAE9: 0x9ADE,
	0xEAEA: 0x9ADF,
	0xEAEB: 0x9AE0,
	0xEAEC: 0x9AE1,
	0xEAED: 0x9AE2,
	0xEAEE: 0x9AE3,
	0xEAEF: 0x9AE4,
	0xEAF0: 0x9AE5,
	0xEAF1: 0x9AE6,
	0xEAF2: 0x9AE7,
	0xEAF3: 0x9AE8,
	0xEAF4: 0x9AE9,
	0xEAF5: 0x9AEA,
	0xEAF6: 0x9AEB,
	0xEAF7: 0x9AEC,
	0xEAF8: 0x9AED,
	0xEAF9: 0x9AEE,
	0xEAFA: 0x9AEF,
	0xEAFB: 0x9AF0,
	0xEAFC: 0x9AF1,
	0xEAFD: 0x9AF2,
	0xEAFE: 0x9AF3,
	0xEAFF: 0x9AF4,
	0xEB00: 0x9AF5,
	0xEB01: 0x9AF6,
	0xEB02: 0x9AF7,
	0xEB03: 0x9AF8,
	0xEB04: 0x9AF9,
	0xEB05: 0x9AFA,
	0xEB06: 0x9AFB,
	0xEB07: 0x9AFC,
	0xEB08: 0x9AFD,
	0xEB09: 0x9AFE,
	0xEB0A: 0x9B40,
	0xEB0B: 0x9B41,
	0xEB0C: 0x9B42,
	0xEB0D: 0x9B43,
	0xEB0E: 0x9B44,
	0xEB0F: 0x9B45,
	0xEB10: 0x9B46,
	0xEB11: 0x9B47,
	0xEB12: 0x9B48,
	0xEB13: 0x9B49,
	0xEB14: 0x9B4A,
	0xEB15: 0x9B4B,
	0xEB16: 0x9B4C,
	0xEB17: 0x9B4D,
	0xEB18: 0x9B4E,
	0xEB19: 0x9B4F,
	0xEB1A: 0x9B50,
	0xEB1B: 0x9B51,
	0xEB1C: 0x9B52,
	0xEB1D: 0x9B53,
	0xEB1E: 0x9B54,
	0xEB1F: 0x9B55,
	0xEB20: 0x9B56,
	0xEB21: 0x9B57,
	0xEB22: 0x9B58,
	0xEB23: 0x9B59,
	0xEB24: 0x9B5A,
	0xEB25: 0x9B5B,
	0xEB26: 0x9B5C,
	0xEB27: 0x9B5D,
	0xEB28: 0x9B5E,
	0xEB29: 0x9B5F,
	0xEB2A: 0x9B60,
	0xEB2B: 0x9B61,
	0xEB2C: 0x9B62,
	0xEB2D: 0x9B63,
	0xEB2E: 0x9B64,
	0xEB2F: 0x9B65,
	0xEB30: 0x9B66,
	0xEB31: 0x9B67,
	0xEB32: 0x9B68,
	0xEB33: 0x9B69,
	0xEB34: 0x9B6A,
	0xEB35: 0x9B6B,
	0xEB36: 0x9B6C,
	0xEB37: 0x9B6D,
	0xEB38: 0x9B6E,
	0xEB39: 0x9B6F,
	0xEB3A: 0x9B70,
	0xEB3B: 0x9B71,
	0xEB3C: 0x9B72,
	0xEB3D: 0x9B73,
	0xEB3E: 0x9B74,
	0xEB3F: 0x9B75,
	0xEB40: 0x9B76,
	0xEB41: 0x9B77,
	0xEB42: 0x9B78,
	0xEB43: 0x9B79,
	0xEB44: 0x9B7A,
	0xEB45: 0x9B7B,
	0xEB46: 0x9B7C,
	0xEB47: 0x9B7D,
	0xEB48: 0x9B7E,
	0xEB49: 0x9BA1,
	0xEB4A: 0x9BA2,
	0xEB4B: 0x9BA3,
	0xEB4C: 0x9BA4,
	0xEB4D: 0x9BA5,
	0xEB4E: 0x9BA6,
	0xEB4F: 0x9BA7,
	0xEB50: 0x9BA8,
	0xEB51: 0x9BA9,
	0xEB52: 0x9BAA,
	0xEB53: 0x9BAB,
	0xEB54: 0x9BAC,
	0xEB55: 0x9BAD,
	0xEB56: 0x9BAE,
	0xEB57: 0x9BAF,
	0xEB58: 0x9BB0,
	0xEB59: 0x9BB1,
	0xEB5A: 0x9BB2,
	0xEB5B: 0x9BB3,
	0xEB5C: 0x9BB4,
	0xEB5D: 0x9BB5,
	0xEB5E: 0x9BB6,
	0xEB5F: 0x9BB7,
	0xEB60: 0x9BB8,
	0xEB61: 0x9BB9,
	0xEB62: 0x9BBA,
	0xEB63: 0x9BBB,
	0xEB64: 0x9BBC,
	0xEB65: 0x9BBD,
	0xEB66: 0x9BBE,
	0xEB67: 0x9BBF,
	0xEB68: 0x9BC0,
	0xEB69: 0x9BC1,
	0xEB6A: 0x9BC2,
	0xEB6B: 0x9BC3,
	0xEB6C: 0x9BC4,
	0xEB6D: 0x9BC5,
	0xEB6E: 0x9BC6,
	0xEB6F: 0x9BC7,
	0xEB70: 0x9BC8,
	0xEB71: 0x9BC9,
	0xEB72: 0x9BCA,
	0xEB73: 0x9BCB,
	0xEB74: 0x9BCC,
	0xEB75: 0x9BCD,
	0xEB76: 0x9BCE,
	0xEB77: 0x9BCF,
	0xEB78: 0x9BD0,
	0xEB79: 0x9BD1,
	0xEB7A: 0x9BD2,
	0xEB7B: 0x9BD3,
	0xEB7C: 0x9BD4,
	0xEB7D: 0x9BD5,
	0xEB7E: 0x9BD6,
	0xEB7F: 0x9BD7,
	0xEB80: 0x9BD8,
	0xEB81: 0x9BD9,
	0xEB82: 0x9BDA,
	0xEB83: 0x9BDB,
	0xEB84: 0x9BDC,
	0xEB85: 0x9BDD,
	0xEB86: 0x9BDE,
	0xEB87: 0x9BDF,
	0xEB88: 0x9BE0,
	0xEB89: 0x9BE1,
	0xEB8A: 0x9BE2,
	0xEB8B: 0x9BE3,
	0xEB8C: 0x9BE4,
	0xEB8D: 0x9BE5,
	0xEB8E: 0x9BE6,
	0xEB8F: 0x9BE7,
	0xEB90: 0x9BE8,
	0xEB91: 0x9BE9,
	0xEB92: 0x9BEA,
	0xEB93: 0x9BEB,
	0xEB94: 0x9BEC,
	0xEB95: 0x9BED,
	0xEB96: 0x9BEE,
	0xEB97: 0x9BEF,
	0xEB98: 0x9BF0,
	0xEB99: 0x9BF1,
	0xEB9A: 0x9BF2,
	0xEB9B: 0x9BF3,
	0xEB9C: 0x9BF4,
	0xEB9D: 0x9BF5,
	0xEB9E: 0x9BF6,
	0xEB9F: 0x9BF7,
	0xEBA0: 0x9BF8,
	0xEBA1: 0x9BF9,
	0xEBA2: 0x9BFA,
	0xEBA3: 0x9BFB,
	0xEBA4: 0x9BFC,
	0xEBA5: 0x9BFD,
	0xEBA6: 0x9BFE,
	0xEBA7: 0x9C40,
	0xEBA8: 0x9C41,
	0xEBA9: 0x9C42,
	0xEBAA: 0x9C43,
	0xEBAB: 0x9C44,
	0xEBAC: 0x9C45,
	0xEBAD: 0x9C46,
	0xEBAE: 0x9C47,
	0xEBAF: 0x9C48,
	0xEBB0: 0x9C49,
	0xEBB1: 0x9C4A,
	0xEBB2: 0x9C4B,
	0xEBB3: 0x9C4C,
	0xEBB4: 0x9C4D,
	0xEBB5: 0x9C4E,
	0xEBB6: 0x9C4F,
	0xEBB7: 0x9C50,
	0xEBB8: 0x9C51,
	0xEBB9: 0x9C52,
	0xEBBA: 0x9C53,
	0xEBBB: 0x9C54,
	0xEBBC: 0x9C55,
	0xEBBD: 0x9C56,
	0xEBBE: 0x9C57,
	0xEBBF: 0x9C58,
	0xEBC0: 0x9C59,
	0xEBC1: 0x9C5A,
	0xEBC2: 0x9C5B,
	0xEBC3: 0x9C5C,
	0xEBC4: 0x9C5D,
	0xEBC5: 0x9C5E,
	0xEBC6: 0x9C5F,
	0xEBC7: 0x9C60,
	0xEBC8: 0x9C61,
	0xEBC9: 0x9C62,
	0xEBCA: 0x9C63,
	0xEBCB: 0x9C64,
	0xEBCC: 0x9C65,
	0xEBCD: 0x9C66,
	0xEBCE: 0x9C67,
	0xEBCF: 0x9C68,
	0xEBD0: 0x9C69,
	0xEBD1: 0x9C6A,
	0xEBD2: 0x9C6B,
	0xEBD3: 0x9C6C,
	0xEBD4: 0x9C6D,
	0xEBD5: 0x9C6E,
	0xEBD6: 0x9C6F,
	0xEBD7: 0x9C70,
	0xEBD8: 0x9C71,
	0xEBD9: 0x9C72,
	0xEBDA: 0x9C73,
	0xEBDB: 0x9C74,
	0xEBDC: 0x9C75,
	0xEBDD: 0x9C76,
	0xEBDE: 0x9C77,
	0xEBDF: 0x9C78,
	0xEBE0: 0x9C79,
	0xEBE1: 0x9C7A,
	0xEBE2: 0x9C7B,
	0xEBE3: 0x9C7C,
	0xEBE4: 0x9C7D,
	0xEBE5: 0x9C7E,
	0xEBE6: 0x9CA1,
	0xEBE7: 0x9CA2,
	0xEBE8: 0x9CA3,
	0xEBE9: 0x9CA4,
	0xEBEA: 0x9CA5,
	0xEBEB: 0x9CA6,
	0xEBEC: 0x9CA7,
	0xEBED: 0x9CA8,
	0xEBEE: 0x9CA9,
	0xEBEF: 0x9CAA,
	0xEBF0: 0x9CAB,
	0xEBF1: 0x9CAC,
	0xEBF2: 0x9CAD,
	0xEBF3: 0x9CAE,
	0xEBF4: 0x9CAF,
	0xEBF5: 0x9CB0,
	0xEBF6: 0x9CB1,
	0xEBF7: 0x9CB2,
	0xEBF8: 0x9CB3,
	0xEBF9: 0x9CB4,
	0xEBFA: 0x9CB5,
	0xEBFB: 0x9CB6,
	0xEBFC: 0x9CB7,
	0xEBFD: 0x9CB8,
	0xEBFE: 0x9CB9,
	0xEBFF: 0x9CBA,
	0xEC00: 0x9CBB,
	0xEC01: 0x9CBC,
	0xEC02: 0x9CBD,
	0xEC03: 0x9CBE,
	0xEC04: 0x9CBF,
	0xEC05: 0x9CC0,
	0xEC06: 0x9CC1,
	0xEC07: 0x9CC2,
	0xEC08: 0x9CC3,
	0xEC09: 0x9CC4,
	0xEC0A: 0x9CC5,
	0xEC0B: 0x9CC6,
	0xEC0C: 0x9CC7,
	0xEC0D: 0x9CC8,
	0xEC0E: 0x9CC9,
	0xEC0F: 0x9CCA,
	0xEC10: 0x9CCB,
	0xEC11: 0x9CCC,
	0xEC12: 0x9CCD,
	0xEC13: 0x9CCE,
	0xEC14: 0x9CCF,
	0xEC15: 0x9CD0,
	0xEC16: 0x9CD1,
	0xEC17: 0x9CD2,
	0xEC18: 0x9CD3,
	0xEC19: 0x9CD4,
	0xEC1A: 0x9CD5,
	0xEC1B: 0x9CD6,
	0xEC1C: 0x9CD7,
	0xEC1D: 0x9CD8,
	0xEC1E: 0x9CD9,
	0xEC1F: 0x9CDA,
	0xEC20: 0x9CDB,
	0xEC21: 0x9CDC,
	0xEC22: 0x9CDD,
	0xEC23: 0x9CDE,
	0xEC24: 0x9CDF,
	0xEC25: 0x9CE0,
	0xEC26: 0x9CE1,
	0xEC27: 0x9CE2,
	0xEC28: 0x9CE3,
	0xEC29: 0x9CE4,
	0xEC2A: 0x9CE5,
	0xEC2B: 0x9CE6,
	0xEC2C: 0x9CE7,
	0xEC2D: 0x9CE8,
	0xEC2E: 0x9CE9,
	0xEC2F: 0x9CEA,
	0xEC30: 0x9CEB,
	0xEC31: 0x9CEC,
	0xEC32: 0x9CED,
	0xEC33: 0x9CEE,
	0xEC34: 0x9CEF,
	0xEC35: 0x9CF0,
	0xEC36: 0x9CF1,
	0xEC37: 0x9CF2,
	0xEC38: 0x9CF3,
	0xEC39: 0x9CF4,
	0xEC3A: 0x9CF5,
	0xEC3B: 0x9CF6,
	0xEC3C: 0x9CF7,
	0xEC3D: 0x9CF8,
	0xEC3E: 0x9CF9,
	0xEC3F: 0x9CFA,
	0xEC40: 0x9CFB,
	0xEC41: 0x9CFC,
	0xEC42: 0x9CFD,
	0xEC43: 0x9CFE,
	0xEC44: 0x9D40,
	0xEC45: 0x9D41,
	0xEC46: 0x9D42,
	0xEC47: 0x9D43,
	0xEC48: 0x9D44,
	0xEC49: 0x9D45,
	0xEC4A: 0x9D46,
	0xEC4B: 0x9D47,
	0xEC4C: 0x9D48,
	0xEC4D: 0x9D49,
	0xEC4E: 0x9D4A,
	0xEC4F: 0x9D4B,
	0xEC50: 0x9D4C,
	0xEC51: 0x9D4D,
	0xEC52: 0x9D4E,
	0xEC53: 0x9D4F,
	0xEC54: 0x9D50,
	0xEC55: 0x9D51,
	0xEC56: 0x9D52,
	0xEC57: 0x9D53,
	0xEC58: 0x9D54,
	0xEC59: 0x9D55,
	0xEC5A: 0x9D56,
	0xEC5B: 0x9D57,
	0xEC5C: 0x9D58,
	0xEC5D: 0x9D59,
	0xEC5E: 0x9D5A,
	0xEC5F: 0x9D5B,
	0xEC60: 0x9D5C,
	0xEC61: 0x9D5D,
	0xEC62: 0x9D5E,
	0xEC63: 0x9D5F,
	0xEC64: 0x9D60,
	0xEC65: 0x9D61,
	0xEC66: 0x9D62,
	0xEC67: 0x9D63,
	0xEC68: 0x9D64,
	0xEC69: 0x9D65,
	0xEC6A: 0x9D66,
	0xEC6B: 0x9D67,
	0xEC6C: 0x9D68,
	0xEC6D: 0x9D69,
	0xEC6E: 0x9D6A,
	0xEC6F: 0x9D6B,
	0xEC70: 0x9D6C,
	0xEC71: 0x9D6D,
	0xEC72: 0x9D6E,
	0xEC73: 0x9D6F,
	0xEC74: 0x9D70,
	0xEC75: 0x9D71,
	0xEC76: 0x9D72,
	0xEC77: 0x9D73,
	0xEC78: 0x9D74,
	0xEC79: 0x9D75,
	0xEC7A: 0x9D76,
	0xEC7B: 0x9D77,
	0xEC7C: 0x9D78,
	0xEC7D: 0x9D79,
	0xEC7E: 0x9D7A,
	0xEC7F: 0x9D7B,
	0xEC80: 0x9D7C,
	0xEC81: 0x9D7D,
	0xEC82: 0x9D7E,
	0xEC83: 0x9DA1,
	0xEC84: 0x9DA2,
	0xEC85: 0x9DA3,
	0xEC86: 0x9DA4,
	0xEC87: 0x9DA5,
	0xEC88: 0x9DA6,
	0xEC89: 0x9DA7,
	0xEC8A: 0x9DA8,
	0xEC8B: 0x9DA9,
	0xEC8C: 0x9DAA,
	0xEC8D: 0x9DAB,
	0xEC8E: 0x9DAC,
	0xEC8F: 0x9DAD,
	0xEC90: 0x9DAE,
	0xEC91: 0x9DAF,
	0xEC92: 0x9DB0,
	0xEC93: 0x9DB1,
	0xEC94: 0x9DB2,
	0xEC95: 0x9DB3,
	0xEC96: 0x9DB4,
	0xEC97: 0x9DB5,
	0xEC98: 0x9DB6,
	0xEC99: 0x9DB7,
	0xEC9A: 0x9DB8,
	0xEC9B: 0x9DB9,
	0xEC9C: 0x9DBA,
	0xEC9D: 0x9DBB,
	0xEC9E: 0x9DBC,
	0xEC9F: 0x9DBD,
	0xECA0: 0x9DBE,
	0xECA1: 0x9DBF,
	0xECA2: 0x9DC0,
	0xECA3: 0x9DC1,
	0xECA4: 0x9DC2,
	0xECA5: 0x9DC3,
	0xECA6: 0x9DC4,
	0xECA7: 0x9DC5,
	0xECA8: 0x9DC6,
	0xECA9: 0x9DC7,
	0xECAA: 0x9DC8,
	0xECAB: 0x9DC9,
	0xECAC: 0x9DCA,
	0xECAD: 0x9DCB,
	0xECAE: 0x9DCC,
	0xECAF: 0x9DCD,
	0xECB0: 0x9DCE,
	0xECB1: 0x9DCF,
	0xECB2: 0x9DD0,
	0xECB3: 0x9DD1,
	0xECB4: 0x9DD2,
	0xECB5: 0x9DD3,
	0xECB6: 0x9DD4,
	0xECB7: 0x9DD5,
	0xECB8: 0x9DD6,
	0xECB9: 0x9DD7,
	0xECBA: 0x9DD8,
	0xECBB: 0x9DD9,
	0xECBC: 0x9DDA,
	0xECBD: 0x9DDB,
	0xECBE: 0x9DDC,
	0xECBF: 0x9DDD,
	0xECC0: 0x9DDE,
	0xECC1: 0x9DDF,
	0xECC2: 0x9DE0,
	0xECC3: 0x9DE1,
	0xECC4: 0x9DE2,
	0xECC5: 0x9DE3,
	0xECC6: 0x9DE4,
	0xECC7: 0x9DE5,
	0xECC8: 0x9DE6,
	0xECC9: 0x9DE7,
	0xECCA: 0x9DE8,
	0xECCB: 0x9DE9,
	0xECCC: 0x9DEA,
	0xECCD: 0x9DEB,
	0xECCE: 0x9DEC,
	0xECCF: 0x9DED,
	0xECD0: 0x9DEE,
	0xECD1: 0x9DEF,
	0xECD2: 0x9DF0,
	0xECD3: 0x9DF1,
	0xECD4: 0x9DF2,
	0xECD5: 0x9DF3,
	0xECD6: 0x9DF4,
	0xECD7: 0x9DF5,
	0xECD8: 0x9DF6,
	0xECD9: 0x9DF7,
	0xECDA: 0x9DF8,
	0xECDB: 0x9DF9,
	0xECDC: 0x9DFA,
	0xECDD: 0x9DFB,
	0xECDE: 0x9DFC,
	0xECDF: 0x9DFD,
	0xECE0: 0x9DFE,
	0xECE1: 0x9E40,
	0xECE2: 0x9E41,
	0xECE3: 0x9E42,
	0xECE4: 0x9E43,
	0xECE5: 0x9E44,
	0xECE6: 0x9E45,
	0xECE7: 0x9E46,
	0xECE8: 0x9E47,
	0xECE9: 0x9E48,
	0xECEA: 0x9E49,
	0xECEB: 0x9E4A,
	0xECEC: 0x9E4B,
	0xECED: 0x9E4C,
	0xECEE: 0x9E4D,
	0xECEF: 0x9E4E,
	0xECF0: 0x9E4F,
	0xECF1: 0x9E50,
	0xECF2: 0x9E51,
	0xECF3: 0x9E52,
	0xECF4: 0x9E53,
	0xECF5: 0x9E54,
	0xECF6: 0x9E55,
	0xECF7: 0x9E56,
	0xECF8: 0x9E57,
	0xECF9: 0x9E58,
	0xECFA: 0x9E59,
	0xECFB: 0x9E5A,
	0xECFC: 0x9E5B,
	0xECFD: 0x9E5C,
	0xECFE: 0x9E5D,
	0xECFF: 0x9E5E,
	0xED00: 0x9E5F,
	0xED01: 0x9E60,
	0xED02: 0x9E61,
	0xED03: 0x9E62,
	0xED04: 0x9E63,
	0xED05: 0x9E64,
	0xED06: 0x9E65,
	0xED07: 0x9E66,
	0xED08: 0x9E67,
	0xED09: 0x9E68,
	0xED0A: 0x9E69,
	0xED0B: 0x9E6A,
	0xED0C: 0x9E6B,
	0xED0D: 0x9E6C,
	0xED0E: 0x9E6D,
	0xED0F: 0x9E6E,
	0xED10: 0x9E6F,
	0xED11: 0x9E70,
	0xED12: 0x9E71,
	0xED13: 0x9E72,
	0xED14: 0x9E73,
	0xED15: 0x9E74,
	0xED16: 0x9E75,
	0xED17: 0x9E76,
	0xED18: 0x9E77,
	0xED19: 0x9E78,
	0xED1A: 0x9E79,
	0xED1B: 0x9E7A,
	0xED1C: 0x9E7B,
	0xED1D: 0x9E7C,
	0xED1E: 0x9E7D,
	0xED1F: 0x9E7E,
	0xED20: 0x9EA1,
	0xED21: 0x9EA2,
	0xED22: 0x9EA3,
	0xED23: 0x9EA4,
	0xED24: 0x9EA5,
	0xED25: 0x9EA6,
	0xED26: 0x9EA7,
	0xED27: 0x9EA8,
	0xED28: 0x9EA9,
	0xED29: 0x9EAA,
	0xED2A: 0x9EAB,
	0xED2B: 0x9EAC,
	0xED2C: 0x9EAD,
	0xED2D: 0x9EAE,
	0xED2E: 0x9EAF,
	0xED2F: 0x9EB0,
	0xED30: 0x9EB1,
	0xED31: 0x9EB2,
	0xED32: 0x9EB3,
	0xED33: 0x9EB4,
	0xED34: 0x9EB5,
	0xED35: 0x9EB6,
	0xED36: 0x9EB7,
	0xED37: 0x9EB8,
	0xED38: 0x9EB9,
	0xED39: 0x9EBA,
	0xED3A: 0x9EBB,
	0xED3B: 0x9EBC,
	0xED3C: 0x9EBD,
	0xED3D: 0x9EBE,
	0xED3E: 0x9EBF,
	0xED3F: 0x9EC0,
	0xED40: 0x9EC1,
	0xED41: 0x9EC2,
	0xED42: 0x9EC3,
	0xED43: 0x9EC4,
	0xED44: 0x9EC5,
	0xED45: 0x9EC6,
	0xED46: 0x9EC7,
	0xED47: 0x9EC8,
	0xED48: 0x9EC9,
	0xED49: 0x9ECA,
	0xED4A: 0x9ECB,
	0xED4B: 0x9ECC,
	0xED4C: 0x9ECD,
	0xED4D: 0x9ECE,
	0xED4E: 0x9ECF,
	0xED4F: 0x9ED0,
	0xED50: 0x9ED1,
	0xED51: 0x9ED2,
	0xED52: 0x9ED3,
	0xED53: 0x9ED4,
	0xED54: 0x9ED5,
	0xED55: 0x9ED6,
	0xED56: 0x9ED7,
	0xED57: 0x9ED8,
	0xED58: 0x9ED9,
	0xED59: 0x9EDA,
	0xED5A: 0x9EDB,
	0xED5B: 0x9EDC,
	0xED5C: 0x9EDD,
	0xED5D: 0x9EDE,
	0xED5E: 0x9EDF,
	0xED5F: 0x9EE0,
	0xED60: 0x9EE1,
	0xED61: 0x9EE2,
	0xED62: 0x9EE3,
	0xED63: 0x9EE4,
	0xED64: 0x9EE5,
	0xED65: 0x9EE6,
	0xED66: 0x9EE7,
	0xED67: 0x9EE8,
	0xED68: 0x9EE9,
	0xED69: 0x9EEA,
	0xED6A: 0x9EEB,
	0xED6B: 0x9EEC,
	0xED6C: 0x9EED,
	0xED6D: 0x9EEE,
	0xED6E: 0x9EEF,
	0xED6F: 0x9EF0,
	0xED70: 0x9EF1,
	0xED71: 0x9EF2,
	0xED72: 0x9EF3,
	0xED73: 0x9EF4,
	0xED74: 0x9EF5,
	0xED75: 0x9EF6,
	0xED76: 0x9EF7,
	0xED77: 0x9EF8,
	0xED78: 0x9EF9,
	0xED79: 0x9EFA,
	0xED7A: 0x9EFB,
	0xED7B: 0x9EFC,
	0xED7C: 0x9EFD,
	0xED7D: 0x9EFE,
	0xED7E: 0x9F40,
	0xED7F: 0x9F41,
	0xED80: 0x9F42,
	0xED81: 0x9F43,
	0xED82: 0x9F44,
	0xED83: 0x9F45,
	0xED84: 0x9F46,
	0xED85: 0x9F47,
	0xED86: 0x9F48,
	0xED87: 0x9F49,
	0xED88: 0x9F4A,
	0xED89: 0x9F4B,
	0xED8A: 0x9F4C,
	0xED8B: 0x9F4D,
	0xED8C: 0x9F4E,
	0xED8D: 0x9F4F,
	0xED8E: 0x9F50,
	0xED8F: 0x9F51,
	0xED90: 0x9F52,
	0xED91: 0x9F53,
	0xED92: 0x9F54,
	0xED93: 0x9F55,
	0xED94: 0x9F56,
	0xED95: 0x9F57,
	0xED96: 0x9F58,
	0xED97: 0x9F59,
	0xED98: 0x9F5A,
	0xED99: 0x9F5B,
	0xED9A: 0x9F5C,
	0xED9B: 0x9F5D,
	0xED9C: 0x9F5E,
	0xED9D: 0x9F5F,
	0xED9E: 0x9F60,
	0xED9F: 0x9F61,
	0xEDA0: 0x9F62,
	0xEDA1: 0x9F63,
	0xEDA2: 0x9F64,
	0xEDA3: 0x9F65,
	0xEDA4: 0x9F66,
	0xEDA5: 0x9F67,
	0xEDA6: 0x9F68,
	0xEDA7: 0x9F69,
	0xEDA8: 0x9F6A,
	0xEDA9: 0x9F6B,
	0xEDAA: 0x9F6C,
	0xEDAB: 0x9F6D,
	0xEDAC: 0x9F6E,
	0xEDAD: 0x9F6F,
	0xEDAE: 0x9F70,
	0xEDAF: 0x9F71,
	0xEDB0: 0x9F72,
	0xEDB1: 0x9F73,
	0xEDB2: 0x9F74,
	0xEDB3: 0x9F75,
	0xEDB4: 0x9F76,
	0xEDB5: 0x9F77,
	0xEDB6: 0x9F78,
	0xEDB7: 0x9F79,
	0xEDB8: 0x9F7A,
	0xEDB9: 0x9F7B,
	0xEDBA: 0x9F7C,
	0xEDBB: 0x9F7D,
	0xEDBC: 0x9F7E,
	0xEDBD: 0x9FA1,
	0xEDBE: 0x9FA2,
	0xEDBF: 0x9FA3,
	0xEDC0: 0x9FA4,
	0xEDC1: 0x9FA5,
	0xEDC2: 0x9FA6,
	0xEDC3: 0x9FA7,
	0xEDC4: 0x9FA8,
	0xEDC5: 0x9FA9,
	0xEDC6: 0x9FAA,
	0xEDC7: 0x9FAB,
	0xEDC8: 0x9FAC,
	0xEDC9: 0x9FAD,
	0xEDCA: 0x9FAE,
	0xEDCB: 0x9FAF,
	0xEDCC: 0x9FB0,
	0xEDCD: 0x9FB1,
	0xEDCE: 0x9FB2,
	0xEDCF: 0x9FB3,
	0xEDD0: 0x9FB4,
	0xEDD1: 0x9FB5,
	0xEDD2: 0x9FB6,
	0xEDD3: 0x9FB7,
	0xEDD4: 0x9FB8,
	0xEDD5: 0x9FB9,
	0xEDD6: 0x9FBA,
	0xEDD7: 0x9FBB,
	0xEDD8: 0x9FBC,
	0xEDD9: 0x9FBD,
	0xEDDA: 0x9FBE,
	0xEDDB: 0x9FBF,
	0xEDDC: 0x9FC0,
	0xEDDD: 0x9FC1,
	0xEDDE: 0x9FC2,
	0xEDDF: 0x9FC3,
	0xEDE0: 0x9FC4,
	0xEDE1: 0x9FC5,
	0xEDE2: 0x9FC6,
	0xEDE3: 0x9FC7,
	0xEDE4: 0x9FC8,
	0xEDE5: 0x9FC9,
	0xEDE6: 0x9FCA,
	0xEDE7: 0x9FCB,
	0xEDE8: 0x9FCC,
	0xEDE9: 0x9FCD,
	0xEDEA: 0x9FCE,
	0xEDEB: 0x9FCF,
	0xEDEC: 0x9FD0,
	0xEDED: 0x9FD1,
	0xEDEE: 0x9FD2,
	0xEDEF: 0x9FD3,
	0xEDF0: 0x9FD4,
	0xEDF1: 0x9FD5,
	0xEDF2: 0x9FD6,
	0xEDF3: 0x9FD7,
	0xEDF4: 0x9FD8,
	0xEDF5: 0x9FD9,
	0xEDF6: 0x9FDA,
	0xEDF7: 0x9FDB,
	0xEDF8: 0x9FDC,
	0xEDF9: 0x9FDD,
	0xEDFA: 0x9FDE,
	0xEDFB: 0x9FDF,
	0xEDFC: 0x9FE0,
	0xEDFD: 0x9FE1,
	0xEDFE: 0x9FE2,
	0xEDFF: 0x9FE3,
	0xEE00: 0x9FE4,
	0xEE01: 0x9FE5,
	0xEE02: 0x9FE6,
	0xEE03: 0x9FE7,
	0xEE04: 0x9FE8,
	0xEE05: 0x9FE9,
	0xEE06: 0x9FEA,
	0xEE07: 0x9FEB,
	0xEE08: 0x9FEC,
	0xEE09: 0x9FED,
	0xEE0A: 0x9FEE,
	0xEE0B: 0x9FEF,
	0xEE0C: 0x9FF0,
	0xEE0D: 0x9FF1,
	0xEE0E: 0x9FF2,
	0xEE0F: 0x9FF3,
	0xEE10: 0x9FF4,
	0xEE11: 0x9FF5,
	0xEE12: 0x9FF6,
	0xEE13: 0x9FF7,
	0xEE14: 0x9FF8,
	0xEE15: 0x9FF9,
	0xEE16: 0x9FFA,
	0xEE17: 0x9FFB,
	0xEE18: 0x9FFC,
	0xEE19: 0x9FFD,
	0xEE1A: 0x9FFE,
	0xEE1B: 0xA040,
	0xEE1C: 0xA041,
	0xEE1D: 0xA042,
	0xEE1E: 0xA043,
	0xEE1F: 0xA044,
	0xEE20: 0xA045,
	0xEE21: 0xA046,
	0xEE22: 0xA047,
	0xEE23: 0xA048,
	0xEE24: 0xA049,
	0xEE25: 0xA04A,
	0xEE26: 0xA04B,
	0xEE27: 0xA04C,
	0xEE28: 0xA04D,
	0xEE29: 0xA04E,
	0xEE2A: 0xA04F,
	0xEE2B: 0xA050,
	0xEE2C: 0xA051,
	0xEE2D: 0xA052,
	0xEE2E: 0xA053,
	0xEE2F: 0xA054,
	0xEE30: 0xA055,
	0xEE31: 0xA056,
	0xEE32: 0xA057,
	0xEE33: 0xA058,
	0xEE34: 0xA059,
	0xEE35: 0xA05A,
	0xEE36: 0xA05B,
	0xEE37: 0xA05C,
	0xEE38: 0xA05D,
	0xEE39: 0xA05E,
	0xEE3A: 0xA05F,
	0xEE3B: 0xA060,
	0xEE3C: 0xA061,
	0xEE3D: 0xA062,
	0xEE3E: 0xA063,
	0xEE3F: 0xA064,
	0xEE40: 0xA065,
	0xEE41: 0xA066,
	0xEE42: 0xA067,
	0xEE43: 0xA068,
	0xEE44: 0xA069,
	0xEE45: 0xA06A,
	0xEE46: 0xA06B,
	0xEE47: 0xA06C,
	0xEE48: 0xA06D,
	0xEE49: 0xA06E,
	0xEE4A: 0xA06F,
	0xEE4B: 0xA070,
	0xEE4C: 0xA071,
	0xEE4D: 0xA072,
	0xEE4E: 0xA073,
	0xEE4F: 0xA074,
	0xEE50: 0xA075,
	0xEE51: 0xA076,
	0xEE52: 0xA077,
	0xEE53: 0xA078,
	0xEE54: 0xA079,
	0xEE55: 0xA07A,
	0xEE56: 0xA07B,
	0xEE57: 0xA07C,
	0xEE58: 0xA07D,
	0xEE59: 0xA07E,
	0xEE5A: 0xA0A1,
	0xEE5B: 0xA0A2,
	0xEE5C: 0xA0A3,
	0xEE5D: 0xA0A4,
	0xEE5E: 0xA0A5,
	0xEE5F: 0xA0A6,
	0xEE60: 0xA0A7,
	0xEE61: 0xA0A8,
	0xEE62: 0xA0A9,
	0xEE63: 0xA0AA,
	0xEE64: 0xA0AB,
	0xEE65: 0xA0AC,
	0xEE66: 0xA0AD,
	0xEE67: 0xA0AE,
	0xEE68: 0xA0AF,
	0xEE69: 0xA0B0,
	0xEE6A: 0xA0B1,
	0xEE6B: 0xA0B2,
	0xEE6C: 0xA0B3,
	0xEE6D: 0xA0B4,
	0xEE6E: 0xA0B5,
	0xEE6F: 0xA0B6,
	0xEE70: 0xA0B7,
	0xEE71: 0xA0B8,
	0xEE72: 0xA0B9,
	0xEE73: 0xA0BA,
	0xEE74: 0xA0BB,
	0xEE75: 0xA0BC,
	0xEE76: 0xA0BD,
	0xEE77: 0xA0BE,
	0xEE78: 0xA0BF,
	0xEE79: 0xA0C0,
	0xEE7A: 0xA0C1,
	0xEE7B: 0xA0C2,
	0xEE7C: 0xA0C3,
	0xEE7D: 0xA0C4,
	0xEE7E: 0xA0C5,
	0xEE7F: 0xA0C6,
	0xEE80: 0xA0C7,
	0xEE81: 0xA0C8,
	0xEE82: 0xA0C9,
	0xEE83: 0xA0CA,
	0xEE84: 0xA0CB,
	0xEE85: 0xA0CC,
	0xEE86: 0xA0CD,
	0xEE87: 0xA0CE,
	0xEE88: 0xA0CF,
	0xEE89: 0xA0D0,
	0xEE8A: 0xA0D1,
	0xEE8B: 0xA0D2,
	0xEE8C: 0xA0D3,
	0xEE8D: 0xA0D4,
	0xEE8E: 0xA0D5,
	0xEE8F: 0xA0D6,
	0xEE90: 0xA0D7,
	0xEE91: 0xA0D8,
	0xEE92: 0xA0D9,
	0xEE93: 0xA0DA,
	0xEE94: 0xA0DB,
	0xEE95: 0xA0DC,
	0xEE96: 0xA0DD,
	0xEE97: 0xA0DE,
	0xEE98: 0xA0DF,
	0xEE99: 0xA0E0,
	0xEE9A: 0xA0E1,
	0xEE9B: 0xA0E2,
	0xEE9C: 0xA0E3,
	0xEE9D: 0xA0E4,
	0xEE9E: 0xA0E5,
	0xEE9F: 0xA0E6,
	0xEEA0: 0xA0E7,
	0xEEA1: 0xA0E8,
	0xEEA2: 0xA0E9,
	0xEEA3: 0xA0EA,
	0xEEA4: 0xA0EB,
	0xEEA5: 0xA0EC,
	0xEEA6: 0xA0ED,
	0xEEA7: 0xA0EE,
	0xEEA8: 0xA0EF,
	0xEEA9: 0xA0F0,
	0xEEAA: 0xA0F1,
	0xEEAB: 0xA0F2,
	0xEEAC: 0xA0F3,
	0xEEAD: 0xA0F4,
	0xEEAE: 0xA0F5,
	0xEEAF: 0xA0F6,
	0xEEB0: 0xA0F7,
	0xEEB1: 0xA0F8,
	0xEEB2: 0xA0F9,
	0xEEB3: 0xA0FA,
	0xEEB4: 0xA0FB,
	0xEEB5: 0xA0FC,
	0xEEB6: 0xA0FD,
	0xEEB7: 0xA0FE,
	0xEEB8: 0x8140,
	0xEEB9: 0x8141,
	0xEEBA: 0x8142,
	0xEEBB: 0x8143,
	0xEEBC: 0x8144,
	0xEEBD: 0x8145,
	0xEEBE: 0x8146,
	0xEEBF: 0x8147,
	0xEEC0: 0x8148,
	0xEEC1: 0x8149,
	0xEEC2: 0x814A,
	0xEEC3: 0x814B,
	0xEEC4: 0x814C,
	0xEEC5: 0x814D,
	0xEEC6: 0x814E,
	0xEEC7: 0x814F,
	0xEEC8: 0x8150,
	0xEEC9: 0x8151,
	0xEECA: 0x8152,
	0xEECB: 0x8153,
	0xEECC: 0x8154,
	0xEECD: 0x8155,
	0xEECE: 0x8156,
	0xEECF: 0x8157,
	0xEED0: 0x8158,
	0xEED1: 0x8159,
	0xEED2: 0x815A,
	0xEED3: 0x815B,
	0xEED4: 0x815C,
	0xEED5: 0x815D,
	0xEED6: 0x815E,
	0xEED7: 0x815F,
	0xEED8: 0x8160,
	0xEED9: 0x8161,
	0xEEDA: 0x8162,
	0xEEDB: 0x8163,
	0xEEDC: 0x8164,
	0xEEDD: 0x8165,
	0xEEDE: 0x8166,
	0xEEDF: 0x8167,
	0xEEE0: 0x8168,
	0xEEE1: 0x8169,
	0xEEE2: 0x816A,
	0xEEE3: 0x816B,
	0xEEE4: 0x816C,
	0xEEE5: 0x816D,
	0xEEE6: 0x816E,
	0xEEE7: 0x816F,
	0xEEE8: 0x8170,
	0xEEE9: 0x8171,
	0xEEEA: 0x8172,
	0xEEEB: 0x8173,
	0xEEEC: 0x8174,
	0xEEED: 0x8175,
	0xEEEE: 0x8176,
	0xEEEF: 0x8177,
	0xEEF0: 0x8178,
	0xEEF1: 0x8179,
	0xEEF2: 0x817A,
	0xEEF3: 0x817B,
	0xEEF4: 0x817C,
	0xEEF5: 0x817D,
	0xEEF6: 0x817E,
	0xEEF7: 0x81A1,
	0xEEF8: 0x81A2,
	0xEEF9: 0x81A3,
	0xEEFA: 0x81A4,
	0xEEFB: 0x81A5,
	0xEEFC: 0x81A6,
	0xEEFD: 0x81A7,
	0xEEFE: 0x81A8,
	0xEEFF: 0x81A9,
	0xEF00: 0x81AA,
	0xEF01: 0x81AB,
	0xEF02: 0x81AC,
	0xEF03: 0x81AD,
	0xEF04: 0x81AE,
	0xEF05: 0x81AF,
	0xEF06: 0x81B0,
	0xEF07: 0x81B1,
	0xEF08: 0x81B2,
	0xEF09: 0x81B3,
	0xEF0A: 0x81B4,
	0xEF0B: 0x81B5,
	0xEF0C: 0x81B6,
	0xEF0D: 0x81B7,
	0xEF0E: 0x81B8,
	0xEF0F: 0x81B9,
	0xEF10: 0x81BA,
	0xEF11: 0x81BB,
	0xEF12: 0x81BC,
	0xEF13: 0x81BD,
	0xEF14: 0x81BE,
	0xEF15: 0x81BF,
	0xEF16: 0x81C0,
	0xEF17: 0x81C1,
	0xEF18: 0x81C2,
	0xEF19: 0x81C3,
	0xEF1A: 0x81C4,
	0xEF1B: 0x81C5,
	0xEF1C: 0x81C6,
	0xEF1D: 0x81C7,
	0xEF1E: 0x81C8,
	0xEF1F: 0x81C9,
	0xEF20: 0x81CA,
	0xEF21: 0x81CB,
	0xEF22: 0x81CC,
	0xEF23: 0x81CD,
	0xEF24: 0x81CE,
	0xEF25: 0x81CF,
	0xEF26: 0x81D0,
	0xEF27: 0x81D1,
	0xEF28: 0x81D2,
	0xEF29: 0x81D3,
	0xEF2A: 0x81D4,
	0xEF2B: 0x81D5,
	0xEF2C: 0x81D6,
	0xEF2D: 0x81D7,
	0xEF2E: 0x81D8,
	0xEF2F: 0x81D9,
	0xEF30: 0x81DA,
	0xEF31: 0x81DB,
	0xEF32: 0x81DC,
	0xEF33: 0x81DD,
	0xEF34: 0x81DE,
	0xEF35: 0x81DF,
	0xEF36: 0x81E0,
	0xEF37: 0x81E1,
	0xEF38: 0x81E2,
	0xEF39: 0x81E3,
	0xEF3A: 0x81E4,
	0xEF3B: 0x81E5,
	0xEF3C: 0x81E6,
	0xEF3D: 0x81E7,
	0xEF3E: 0x81E8,
	0xEF3F: 0x81E9,
	0xEF40: 0x81EA,
	0xEF41: 0x81EB,
	0xEF42: 0x81EC,
	0xEF43: 0x81ED,
	0xEF44: 0x81EE,
	0xEF45: 0x81EF,
	0xEF46: 0x81F0,
	0xEF47: 0x81F1,
	0xEF48: 0x81F2,
	0xEF49: 0x81F3,
	0xEF4A: 0x81F4,
	0xEF4B: 0x81F5,
	0xEF4C: 0x81F6,
	0xEF4D: 0x81F7,
	0xEF4E: 0x81F8,
	0xEF4F: 0x81F9,
	0xEF50: 0x81FA,
	0xEF51: 0x81FB,
	0xEF52: 0x81FC,
	0xEF53: 0x81FD,
	0xEF54: 0x81FE,
	0xEF55: 0x8240,
	0xEF56: 0x8241,
	0xEF57: 0x8242,
	0xEF58: 0x8243,
	0xEF59: 0x8244,
	0xEF5A: 0x8245,
	0xEF5B: 0x8246,
	0xEF5C: 0x8247,
	0xEF5D: 0x8248,
	0xEF5E: 0x8249,
	0xEF5F: 0x824A,
	0xEF60: 0x824B,
	0xEF61: 0x824C,
	0xEF62: 0x824D,
	0xEF63: 0x824E,
	0xEF64: 0x824F,
	0xEF65: 0x8250,
	0xEF66: 0x8251,
	0xEF67: 0x8252,
	0xEF68: 0x8253,
	0xEF69: 0x8254,
	0xEF6A: 0x8255,
	0xEF6B: 0x8256,
	0xEF6C: 0x8257,
	0xEF6D: 0x8258,
	0xEF6E: 0x8259,
	0xEF6F: 0x825A,
	0xEF70: 0x825B,
	0xEF71: 0x825C,
	0xEF72: 0x825D,
	0xEF73: 0x825E,
	0xEF74: 0x825F,
	0xEF75: 0x8260,
	0xEF76: 0x8261,
	0xEF77: 0x8262,
	0xEF78: 0x8263,
	0xEF79: 0x8264,
	0xEF7A: 0x8265,
	0xEF7B: 0x8266,
	0xEF7C: 0x8267,
	0xEF7D: 0x8268,
	0xEF7E: 0x8269,
	0xEF7F: 0x826A,
	0xEF80: 0x826B,
	0xEF81: 0x826C,
	0xEF82: 0x826D,
	0xEF83: 0x826E,
	0xEF84: 0x826F,
	0xEF85: 0x8270,
	0xEF86: 0x8271,
	0xEF87: 0x8272,
	0xEF88: 0x8273,
	0xEF89: 0x8274,
	0xEF8A: 0x8275,
	0xEF8B: 0x8276,
	0xEF8C: 0x8277,
	0xEF8D: 0x8278,
	0xEF8E: 0x8279,
	0xEF8F: 0x827A,
	0xEF90: 0x827B,
	0xEF91: 0x827C,
	0xEF92: 0x827D,
	0xEF93: 0x827E,
	0xEF94: 0x82A1,
	0xEF95: 0x82A2,
	0xEF96: 0x82A3,
	0xEF97: 0x82A4,
	0xEF98: 0x82A5,
	0xEF99: 0x82A6,
	0xEF9A: 0x82A7,
	0xEF9B: 0x82A8,
	0xEF9C: 0x82A9,
	0xEF9D: 0x82AA,
	0xEF9E: 0x82AB,
	0xEF9F: 0x82AC,
	0xEFA0: 0x82AD,
	0xEFA1: 0x82AE,
	0xEFA2: 0x82AF,
	0xEFA3: 0x82B0,
	0xEFA4: 0x82B1,
	0xEFA5: 0x82B2,
	0xEFA6: 0x82B3,
	0xEFA7: 0x82B4,
	0xEFA8: 0x82B5,
	0xEFA9: 0x82B6,
	0xEFAA: 0x82B7,
	0xEFAB: 0x82B8,
	0xEFAC: 0x82B9,
	0xEFAD: 0x82BA,
	0xEFAE: 0x82BB,
	0xEFAF: 0x82BC,
	0xEFB0: 0x82BD,
	0xEFB1: 0x82BE,
	0xEFB2: 0x82BF,
	0xEFB3: 0x82C0,
	0xEFB4: 0x82C1,
	0xEFB5: 0x82C2,
	0xEFB6: 0x82C3,
	0xEFB7: 0x82C4,
	0xEFB8: 0x82C5,
	0xEFB9: 0x82C6,
	0xEFBA: 0x82C7,
	0xEFBB: 0x82C8,
	0xEFBC: 0x82C9,
	0xEFBD: 0x82CA,
	0xEFBE: 0x82CB,
	0xEFBF: 0x82CC,
	0xEFC0: 0x82CD,
	0xEFC1: 0x82CE,
	0xEFC2: 0x82CF,
	0xEFC3: 0x82D0,
	0xEFC4: 0x82D1,
	0xEFC5: 0x82D2,
	0xEFC6: 0x82D3,
	0xEFC7: 0x82D4,
	0xEFC8: 0x82D5,
	0xEFC9: 0x82D6,
	0xEFCA: 0x82D7,
	0xEFCB: 0x82D8,
	0xEFCC: 0x82D9,
	0xEFCD: 0x82DA,
	0xEFCE: 0x82DB,
	0xEFCF: 0x82DC,
	0xEFD0: 0x82DD,
	0xEFD1: 0x82DE,
	0xEFD2: 0x82DF,
	0xEFD3: 0x82E0,
	0xEFD4: 0x82E1,
	0xEFD5: 0x82E2,
	0xEFD6: 0x82E3,
	0xEFD7: 0x82E4,
	0xEFD8: 0x82E5,
	0xEFD9: 0x82E6,
	0xEFDA: 0x82E7,
	0xEFDB: 0x82E8,
	0xEFDC: 0x82E9,
	0xEFDD: 0x82EA,
	0xEFDE: 0x82EB,
	0xEFDF: 0x82EC,
	0xEFE0: 0x82ED,
	0xEFE1: 0x82EE,
	0xEFE2: 0x82EF,
	0xEFE3: 0x82F0,
	0xEFE4: 0x82F1,
	0xEFE5: 0x82F2,
	0xEFE6: 0x82F3,
	0xEFE7: 0x82F4,
	0xEFE8: 0x82F5,
	0xEFE9: 0x82F6,
	0xEFEA: 0x82F7,
	0xEFEB: 0x82F8,
	0xEFEC: 0x82F9,
	0xEFED: 0x82FA,
	0xEFEE: 0x82FB,
	0xEFEF: 0x82FC,
	0xEFF0: 0x82FD,
	0xEFF1: 0x82FE,
	0xEFF2: 0x8340,
	0xEFF3: 0x8341,
	0xEFF4: 0x8342,
	0xEFF5: 0x8343,
	0xEFF6: 0x8344,
	0xEFF7: 0x8345,
	0xEFF8: 0x8346,
	0xEFF9: 0x8347,
	0xEFFA: 0x8348,
	0xEFFB: 0x8349,
	0xEFFC: 0x834A,
	0xEFFD: 0x834B,
	0xEFFE: 0x834C,
	0xEFFF: 0x834D,
	0xF000: 0x834E,
	0xF001: 0x834F,
	0xF002: 0x8350,
	0xF003: 0x8351,
	0xF004: 0x8352,
	0xF005: 0x8353,
	0xF006: 0x8354,
	0xF007: 0x8355,
	0xF008: 0x8356,
	0xF009: 0x8357,
	0xF00A: 0x8358,
	0xF00B: 0x8359,
	0xF00C: 0x835A,
	0xF00D: 0x835B,
	0xF00E: 0x835C,
	0xF00F: 0x835D,
	0xF010: 0x835E,
	0xF011: 0x835F,
	0xF012: 0x8360,
	0xF013: 0x8361,
	0xF014: 0x8362,
	0xF015: 0x8363,
	0xF016: 0x8364,
	0xF017: 0x8365,
	0xF018: 0x8366,
	0xF019: 0x8367,
	0xF01A: 0x8368,
	0xF01B: 0x8369,
	0xF01C: 0x836A,
	0xF01D: 0x836B,
	0xF01E: 0x836C,
	0xF01F: 0x836D,
	0xF020: 0x836E,
	0xF021: 0x836F,
	0xF022: 0x8370,
	0xF023: 0x8371,
	0xF024: 0x8372,
	0xF025: 0x8373,
	0xF026: 0x8374,
	0xF027: 0x8375,
	0xF028: 0x8376,
	0xF029: 0x8377,
	0xF02A: 0x8378,
	0xF02B: 0x8379,
	0xF02C: 0x837A,
	0xF02D: 0x837B,
	0xF02E: 0x837C,
	0xF02F: 0x837D,
	0xF030: 0x837E,
	0xF031: 0x83A1,
	0xF032: 0x83A2,
	0xF033: 0x83A3,
	0xF034: 0x83A4,
	0xF035: 0x83A5,
	0xF036: 0x83A6,
	0xF037: 0x83A7,
	0xF038: 0x83A8,
	0xF039: 0x83A9,
	0xF03A: 0x83AA,
	0xF03B: 0x83AB,
	0xF03C: 0x83AC,
	0xF03D: 0x83AD,
	0xF03E: 0x83AE,
	0xF03F: 0x83AF,
	0xF040: 0x83B0,
	0xF041: 0x83B1,
	0xF042: 0x83B2,
	0xF043: 0x83B3,
	0xF044: 0x83B4,
	0xF045: 0x83B5,
	0xF046: 0x83B6,
	0xF047: 0x83B7,
	0xF048: 0x83B8,
	0xF049: 0x83B9,
	0xF04A: 0x83BA,
	0xF04B: 0x83BB,
	0xF04C: 0x83BC,
	0xF04D: 0x83BD,
	0xF04E: 0x83BE,
	0xF04F: 0x83BF,
	0xF050: 0x83C0,
	0xF051: 0x83C1,
	0xF052: 0x83C2,
	0xF053: 0x83C3,
	0xF054: 0x83C4,
	0xF055: 0x83C5,
	0xF056: 0x83C6,
	0xF057: 0x83C7,
	0xF058: 0x83C8,
	0xF059: 0x83C9,
	0xF05A: 0x83CA,
	0xF05B: 0x83CB,
	0xF05C: 0x83CC,
	0xF05D: 0x83CD,
	0xF05E: 0x83CE,
	0xF05F: 0x83CF,
	0xF060: 0x83D0,
	0xF061: 0x83D1,
	0xF062: 0x83D2,
	0xF063: 0x83D3,
	0xF064: 0x83D4,
	0xF065: 0x83D5,
	0xF066: 0x83D6,
	0xF067: 0x83D7,
	0xF068: 0x83D8,
	0xF069: 0x83D9,
	0xF06A: 0x83DA,
	0xF06B: 0x83DB,
	0xF06C: 0x83DC,
	0xF06D: 0x83DD,
	0xF06E: 0x83DE,
	0xF06F: 0x83DF,
	0xF070: 0x83E0,
	0xF071: 0x83E1,
	0xF072: 0x83E2,
	0xF073: 0x83E3,
	0xF074: 0x83E4,
	0xF075: 0x83E5,
	0xF076: 0x83E6,
	0xF077: 0x83E7,
	0xF078: 0x83E8,
	0xF079: 0x83E9,
	0xF07A: 0x83EA,
	0xF07B: 0x83EB,
	0xF07C: 0x83EC,
	0xF07D: 0x83ED,
	0xF07E: 0x83EE,
	0xF07F: 0x83EF,
	0xF080: 0x83F0,
	0xF081: 0x83F1,
	0xF082: 0x83F2,
	0xF083: 0x83F3,
	0xF084: 0x83F4,
	0xF085: 0x83F5,
	0xF086: 0x83F6,
	0xF087: 0x83F7,
	0xF088: 0x83F8,
	0xF089: 0x83F9,
	0xF08A: 0x83FA,
	0xF08B: 0x83FB,
	0xF08C: 0x83FC,
	0xF08D: 0x83FD,
	0xF08E: 0x83FE,
	0xF08F: 0x8440,
	0xF090: 0x8441,
	0xF091: 0x8442,
	0xF092: 0x8443,
	0xF093: 0x8444,
	0xF094: 0x8445,
	0xF095: 0x8446,
	0xF096: 0x8447,
	0xF097: 0x8448,
	0xF098: 0x8449,
	0xF099: 0x844A,
	0xF09A: 0x844B,
	0xF09B: 0x844C,
	0xF09C: 0x844D,
	0xF09D: 0x844E,
	0xF09E: 0x844F,
	0xF09F: 0x8450,
	0xF0A0: 0x8451,
	0xF0A1: 0x8452,
	0xF0A2: 0x8453,
	0xF0A3: 0x8454,
	0xF0A4: 0x8455,
	0xF0A5: 0x8456,
	0xF0A6: 0x8457,
	0xF0A7: 0x8458,
	0xF0A8: 0x8459,
	0xF0A9: 0x845A,
	0xF0AA: 0x845B,
	0xF0AB: 0x845C,
	0xF0AC: 0x845D,
	0xF0AD: 0x845E,
	0xF0AE: 0x845F,
	0xF0AF: 0x8460,
	0xF0B0: 0x8461,
	0xF0B1: 0x8462,
	0xF0B2: 0x8463,
	0xF0B3: 0x8464,
	0xF0B4: 0x8465,
	0xF0B5: 0x8466,
	0xF0B6: 0x8467,
	0xF0B7: 0x8468,
	0xF0B8: 0x8469,
	0xF0B9: 0x846A,
	0xF0BA: 0x846B,
	0xF0BB: 0x846C,
	0xF0BC: 0x846D,
	0xF0BD: 0x846E,
	0xF0BE: 0x846F,
	0xF0BF: 0x8470,
	0xF0C0: 0x8471,
	0xF0C1: 0x8472,
	0xF0C2: 0x8473,
	0xF0C3: 0x8474,
	0xF0C4: 0x8475,
	0xF0C5: 0x8476,
	0xF0C6: 0x8477,
	0xF0C7: 0x8478,
	0xF0C8: 0x8479,
	0xF0C9: 0x847A,
	0xF0CA: 0x847B,
	0xF0CB: 0x847C,
	0xF0CC: 0x847D,
	0xF0CD: 0x847E,
	0xF0CE: 0x84A1,
	0xF0CF: 0x84A2,
	0xF0D0: 0x84A3,
	0xF0D1: 0x84A4,
	0xF0D2: 0x84A5,
	0xF0D3: 0x84A6,
	0xF0D4: 0x84A7,
	0xF0D5: 0x84A8,
	0xF0D6: 0x84A9,
	0xF0D7: 0x84AA,
	0xF0D8: 0x84AB,
	0xF0D9: 0x84AC,
	0xF0DA: 0x84AD,
	0xF0DB: 0x84AE,
	0xF0DC: 0x84AF,
	0xF0DD: 0x84B0,
	0xF0DE: 0x84B1,
	0xF0DF: 0x84B2,
	0xF0E0: 0x84B3,
	0xF0E1: 0x84B4,
	0xF0E2: 0x84B5,
	0xF0E3: 0x84B6,
	0xF0E4: 0x84B7,
	0xF0E5: 0x84B8,
	0xF0E6: 0x84B9,
	0xF0E7: 0x84BA,
	0xF0E8: 0x84BB,
	0xF0E9: 0x84BC,
	0xF0EA: 0x84BD,
	0xF0EB: 0x84BE,
	0xF0EC: 0x84BF,
	0xF0ED: 0x84C0,
	0xF0EE: 0x84C1,
	0xF0EF: 0x84C2,
	0xF0F0: 0x84C3,
	0xF0F1: 0x84C4,
	0xF0F2: 0x84C5,
	0xF0F3: 0x84C6,
	0xF0F4: 0x84C7,
	0xF0F5: 0x84C8,
	0xF0F6: 0x84C9,
	0xF0F7: 0x84CA,
	0xF0F8: 0x84CB,
	0xF0F9: 0x84CC,
	0xF0FA: 0x84CD,
	0xF0FB: 0x84CE,
	0xF0FC: 0x84CF,
	0xF0FD: 0x84D0,
	0xF0FE: 0x84D1,
	0xF0FF: 0x84D2,
	0xF100: 0x84D3,
	0xF101: 0x84D4,
	0xF102: 0x84D5,
	0xF103: 0x84D6,
	0xF104: 0x84D7,
	0xF105: 0x84D8,
	0xF106: 0x84D9,
	0xF107: 0x84DA,
	0xF108: 0x84DB,
	0xF109: 0x84DC,
	0xF10A: 0x84DD,
	0xF10B: 0x84DE,
	0xF10C: 0x84DF,
	0xF10D: 0x84E0,
	0xF10E: 0x84E1,
	0xF10F: 0x84E2,
	0xF110: 0x84E3,
	0xF111: 0x84E4,
	0xF112: 0x84E5,
	0xF113: 0x84E6,
	0xF114: 0x84E7,
	0xF115: 0x84E8,
	0xF116: 0x84E9,
	0xF117: 0x84EA,
	0xF118: 0x84EB,
	0xF119: 0x84EC,
	0xF11A: 0x84ED,
	0xF11B: 0x84EE,
	0xF11C: 0x84EF,
	0xF11D: 0x84F0,
	0xF11E: 0x84F1,
	0xF11F: 0x84F2,
	0xF120: 0x84F3,
	0xF121: 0x84F4,
	0xF122: 0x84F5,
	0xF123: 0x84F6,
	0xF124: 0x84F7,
	0xF125: 0x84F8,
	0xF126: 0x84F9,
	0xF127: 0x84FA,
	0xF128: 0x84FB,
	0xF129: 0x84FC,
	0xF12A: 0x84FD,
	0xF12B: 0x84FE,
	0xF12C: 0x8540,
	0xF12D: 0x8541,
	0xF12E: 0x8542,
	0xF12F: 0x8543,
	0xF130: 0x8544,
	0xF131: 0x8545,
	0xF132: 0x8546,
	0xF133: 0x8547,
	0xF134: 0x8548,
	0xF135: 0x8549,
	0xF136: 0x854A,
	0xF137: 0x854B,
	0xF138: 0x854C,
	0xF139: 0x854D,
	0xF13A: 0x854E,
	0xF13B: 0x854F,
	0xF13C: 0x8550,
	0xF13D: 0x8551,
	0xF13E: 0x8552,
	0xF13F: 0x8553,
	0xF140: 0x8554,
	0xF141: 0x8555,
	0xF142: 0x8556,
	0xF143: 0x8557,
	0xF144: 0x8558,
	0xF145: 0x8559,
	0xF146: 0x855A,
	0xF147: 0x855B,
	0xF148: 0x855C,
	0xF149: 0x855D,
	0xF14A: 0x855E,
	0xF14B: 0x855F,
	0xF14C: 0x8560,
	0xF14D: 0x8561,
	0xF14E: 0x8562,
	0xF14F: 0x8563,
	0xF150: 0x8564,
	0xF151: 0x8565,
	0xF152: 0x8566,
	0xF153: 0x8567,
	0xF154: 0x8568,
	0xF155: 0x8569,
	0xF156: 0x856A,
	0xF157: 0x856B,
	0xF158: 0x856C,
	0xF159: 0x856D,
	0xF15A: 0x856E,
	0xF15B: 0x856F,
	0xF15C: 0x8570,
	0xF15D: 0x8571,
	0xF15E: 0x8572,
	0xF15F: 0x8573,
	0xF160: 0x8574,
	0xF161: 0x8575,
	0xF162: 0x8576,
	0xF163: 0x8577,
	0xF164: 0x8578,
	0xF165: 0x8579,
	0xF166: 0x857A,
	0xF167: 0x857B,
	0xF168: 0x857C,
	0xF169: 0x857D,
	0xF16A: 0x857E,
	0xF16B: 0x85A1,
	0xF16C: 0x85A2,
	0xF16D: 0x85A3,
	0xF16E: 0x85A4,
	0xF16F: 0x85A5,
	0xF170: 0x85A6,
	0xF171: 0x85A7,
	0xF172: 0x85A8,
	0xF173: 0x85A9,
	0xF174: 0x85AA,
	0xF175: 0x85AB,
	0xF176: 0x85AC,
	0xF177: 0x85AD,
	0xF178: 0x85AE,
	0xF179: 0x85AF,
	0xF17A: 0x85B0,
	0xF17B: 0x85B1,
	0xF17C: 0x85B2,
	0xF17D: 0x85B3,
	0xF17E: 0x85B4,
	0xF17F: 0x85B5,
	0xF180: 0x85B6,
	0xF181: 0x85B7,
	0xF182: 0x85B8,
	0xF183: 0x85B9,
	0xF184: 0x85BA,
	0xF185: 0x85BB,
	0xF186: 0x85BC,
	0xF187: 0x85BD,
	0xF188: 0x85BE,
	0xF189: 0x85BF,
	0xF18A: 0x85C0,
	0xF18B: 0x85C1,
	0xF18C: 0x85C2,
	0xF18D: 0x85C3,
	0xF18E: 0x85C4,
	0xF18F: 0x85C5,
	0xF190: 0x85C6,
	0xF191: 0x85C7,
	0xF192: 0x85C8,
	0xF193: 0x85C9,
	0xF194: 0x85CA,
	0xF195: 0x85CB,
	0xF196: 0x85CC,
	0xF197: 0x85CD,
	0xF198: 0x85CE,
	0xF199: 0x85CF,
	0xF19A: 0x85D0,
	0xF19B: 0x85D1,
	0xF19C: 0x85D2,
	0xF19D: 0x85D3,
	0xF19E: 0x85D4,
	0xF19F: 0x85D5,
	0xF1A0: 0x85D6,
	0xF1A1: 0x85D7,
	0xF1A2: 0x85D8,
	0xF1A3: 0x85D9,
	0xF1A4: 0x85DA,
	0xF1A5: 0x85DB,
	0xF1A6: 0x85DC,
	0xF1A7: 0x85DD,
	0xF1A8: 0x85DE,
	0xF1A9: 0x85DF,
	0xF1AA: 0x85E0,
	0xF1AB: 0x85E1,
	0xF1AC: 0x85E2,
	0xF1AD: 0x85E3,
	0xF1AE: 0x85E4,
	0xF1AF: 0x85E5,
	0xF1B0: 0x85E6,
	0xF1B1: 0x85E7,
	0xF1B2: 0x85E8,
	0xF1B3: 0x85E9,
	0xF1B4: 0x85EA,
	0xF1B5: 0x85EB,
	0xF1B6: 0x85EC,
	0xF1B7: 0x85ED,
	0xF1B8: 0x85EE,
	0xF1B9: 0x85EF,
	0xF1BA: 0x85F0,
	0xF1BB: 0x85F1,
	0xF1BC: 0x85F2,
	0xF1BD: 0x85F3,
	0xF1BE: 0x85F4,
	0xF1BF: 0x85F5,
	0xF1C0: 0x85F6,
	0xF1C1: 0x85F7,
	0xF1C2: 0x85F8,
	0xF1C3: 0x85F9,
	0xF1C4: 0x85FA,
	0xF1C5: 0x85FB,
	0xF1C6: 0x85FC,
	0xF1C7: 0x85FD,
	0xF1C8: 0x85FE,
	0xF1C9: 0x8640,
	0xF1CA: 0x8641,
	0xF1CB: 0x8642,
	0xF1CC: 0x8643,
	0xF1CD: 0x8644,
	0xF1CE: 0x8645,
	0xF1CF: 0x8646,
	0xF1D0: 0x8647,
	0xF1D1: 0x8648,
	0xF1D2: 0x8649,
	0xF1D3: 0x864A,
	0xF1D4: 0x864B,
	0xF1D5: 0x864C,
	0xF1D6: 0x864D,
	0xF1D7: 0x864E,
	0xF1D8: 0x864F,
	0xF1D9: 0x8650,
	0xF1DA: 0x8651,
	0xF1DB: 0x8652,
	0xF1DC: 0x8653,
	0xF1DD: 0x8654,
	0xF1DE: 0x8655,
	0xF1DF: 0x8656,
	0xF1E0: 0x8657,
	0xF1E1: 0x8658,
	0xF1E2: 0x8659,
	0xF1E3: 0x865A,
	0xF1E4: 0x865B,
	0xF1E5: 0x865C,
	0xF1E6: 0x865D,
	0xF1E7: 0x865E,
	0xF1E8: 0x865F,
	0xF1E9: 0x8660,
	0xF1EA: 0x8661,
	0xF1EB: 0x8662,
	0xF1EC: 0x8663,
	0xF1ED: 0x8664,
	0xF1EE: 0x8665,
	0xF1EF: 0x8666,
	0xF1F0: 0x8667,
	0xF1F1: 0x8668,
	0xF1F2: 0x8669,
	0xF1F3: 0x866A,
	0xF1F4: 0x866B,
	0xF1F5: 0x866C,
	0xF1F6: 0x866D,
	0xF1F7: 0x866E,
	0xF1F8: 0x866F,
	0xF1F9: 0x8670,
	0xF1FA: 0x8671,
	0xF1FB: 0x8672,
	0xF1FC: 0x8673,
	0xF1FD: 0x8674,
	0xF1FE: 0x8675,
	0xF1FF: 0x8676,
	0xF200: 0x8677,
	0xF201: 0x8678,
	0xF202: 0x8679,
	0xF203: 0x867A,
	0xF204: 0x867B,
	0xF205: 0x867C,
	0xF206: 0x867D,
	0xF207: 0x867E,
	0xF208: 0x86A1,
	0xF209: 0x86A2,
	0xF20A: 0x86A3,
	0xF20B: 0x86A4,
	0xF20C: 0x86A5,
	0xF20D: 0x86A6,
	0xF20E: 0x86A7,
	0xF20F: 0x86A8,
	0xF210: 0x86A9,
	0xF211: 0x86AA,
	0xF212: 0x86AB,
	0xF213: 0x86AC,
	0xF214: 0x86AD,
	0xF215: 0x86AE,
	0xF216: 0x86AF,
	0xF217: 0x86B0,
	0xF218: 0x86B1,
	0xF219: 0x86B2,
	0xF21A: 0x86B3,
	0xF21B: 0x86B4,
	0xF21C: 0x86B5,
	0xF21D: 0x86B6,
	0xF21E: 0x86B7,
	0xF21F: 0x86B8,
	0xF220: 0x86B9,
	0xF221: 0x86BA,
	0xF222: 0x86BB,
	0xF223: 0x86BC,
	0xF224: 0x86BD,
	0xF225: 0x86BE,
	0xF226: 0x86BF,
	0xF227: 0x86C0,
	0xF228: 0x86C1,
	0xF229: 0x86C2,
	0xF22A: 0x86C3,
	0xF22B: 0x86C4,
	0xF22C: 0x86C5,
	0xF22D: 0x86C6,
	0xF22E: 0x86C7,
	0xF22F: 0x86C8,
	0xF230: 0x86C9,
	0xF231: 0x86CA,
	0xF232: 0x86CB,
	0xF233: 0x86CC,
	0xF234: 0x86CD,
	0xF235: 0x86CE,
	0xF236: 0x86CF,
	0xF237: 0x86D0,
	0xF238: 0x86D1,
	0xF239: 0x86D2,
	0xF23A: 0x86D3,
	0xF23B: 0x86D4,
	0xF23C: 0x86D5,
	0xF23D: 0x86D6,
	0xF23E: 0x86D7,
	0xF23F: 0x86D8,
	0xF240: 0x86D9,
	0xF241: 0x86DA,
	0xF242: 0x86DB,
	0xF243: 0x86DC,
	0xF244: 0x86DD,
	0xF245: 0x86DE,
	0xF246: 0x86DF,
	0xF247: 0x86E0,
	0xF248: 0x86E1,
	0xF249: 0x86E2,
	0xF24A: 0x86E3,
	0xF24B: 0x86E4,
	0xF24C: 0x86E5,
	0xF24D: 0x86E6,
	0xF24E: 0x86E7,
	0xF24F: 0x86E8,
	0xF250: 0x86E9,
	0xF251: 0x86EA,
	0xF252: 0x86EB,
	0xF253: 0x86EC,
	0xF254: 0x86ED,
	0xF255: 0x86EE,
	0xF256: 0x86EF,
	0xF257: 0x86F0,
	0xF258: 0x86F1,
	0xF259: 0x86F2,
	0xF25A: 0x86F3,
	0xF25B: 0x86F4,
	0xF25C: 0x86F5,
	0xF25D: 0x86F6,
	0xF25E: 0x86F7,
	0xF25F: 0x86F8,
	0xF260: 0x86F9,
	0xF261: 0x86FA,
	0xF262: 0x86FB,
	0xF263: 0x86FC,
	0xF264: 0x86FD,
	0xF265: 0x86FE,
	0xF266: 0x8740,
	0xF267: 0x8741,
	0xF268: 0x8742,
	0xF269: 0x8743,
	0xF26A: 0x8744,
	0xF26B: 0x8745,
	0xF26C: 0x8746,
	0xF26D: 0x8747,
	0xF26E: 0x8748,
	0xF26F: 0x8749,
	0xF270: 0x874A,
	0xF271: 0x874B,
	0xF272: 0x874C,
	0xF273: 0x874D,
	0xF274: 0x874E,
	0xF275: 0x874F,
	0xF276: 0x8750,
	0xF277: 0x8751,
	0xF278: 0x8752,
	0xF279: 0x8753,
	0xF27A: 0x8754,
	0xF27B: 0x8755,
	0xF27C: 0x8756,
	0xF27D: 0x8757,
	0xF27E: 0x8758,
	0xF27F: 0x8759,
	0xF280: 0x875A,
	0xF281: 0x875B,
	0xF282: 0x875C,
	0xF283: 0x875D,
	0xF284: 0x875E,
	0xF285: 0x875F,
	0xF286: 0x8760,
	0xF287: 0x8761,
	0xF288: 0x8762,
	0xF289: 0x8763,
	0xF28A: 0x8764,
	0xF28B: 0x8765,
	0xF28C: 0x8766,
	0xF28D: 0x8767,
	0xF28E: 0x8768,
	0xF28F: 0x8769,
	0xF290: 0x876A,
	0xF291: 0x876B,
	0xF292: 0x876C,
	0xF293: 0x876D,
	0xF294: 0x876E,
	0xF295: 0x876F,
	0xF296: 0x8770,
	0xF297: 0x8771,
	0xF298: 0x8772,
	0xF299: 0x8773,
	0xF29A: 0x8774,
	0xF29B: 0x8775,
	0xF29C: 0x8776,
	0xF29D: 0x8777,
	0xF29E: 0x8778,
	0xF29F: 0x8779,
	0xF2A0: 0x877A,
	0xF2A1: 0x877B,
	0xF2A2: 0x877C,
	0xF2A3: 0x877D,
	0xF2A4: 0x877E,
	0xF2A5: 0x87A1,
	0xF2A6: 0x87A2,
	0xF2A7: 0x87A3,
	0xF2A8: 0x87A4,
	0xF2A9: 0x87A5,
	0xF2AA: 0x87A6,
	0xF2AB: 0x87A7,
	0xF2AC: 0x87A8,
	0xF2AD: 0x87A9,
	0xF2AE: 0x87AA,
	0xF2AF: 0x87AB,
	0xF2B0: 0x87AC,
	0xF2B1: 0x87AD,
	0xF2B2: 0x87AE,
	0xF2B3: 0x87AF,
	0xF2B4: 0x87B0,
	0xF2B5: 0x87B1,
	0xF2B6: 0x87B2,
	0xF2B7: 0x87B3,
	0xF2B8: 0x87B4,
	0xF2B9: 0x87B5,
	0xF2BA: 0x87B6,
	0xF2BB: 0x87B7,
	0xF2BC: 0x87B8,
	0xF2BD: 0x87B9,
	0xF2BE: 0x87BA,
	0xF2BF: 0x87BB,
	0xF2C0: 0x87BC,
	0xF2C1: 0x87BD,
	0xF2C2: 0x87BE,
	0xF2C3: 0x87BF,
	0xF2C4: 0x87C0,
	0xF2C5: 0x87C1,
	0xF2C6: 0x87C2,
	0xF2C7: 0x87C3,
	0xF2C8: 0x87C4,
	0xF2C9: 0x87C5,
	0xF2CA: 0x87C6,
	0xF2CB: 0x87C7,
	0xF2CC: 0x87C8,
	0xF2CD: 0x87C9,
	0xF2CE: 0x87CA,
	0xF2CF: 0x87CB,
	0xF2D0: 0x87CC,
	0xF2D1: 0x87CD,
	0xF2D2: 0x87CE,
	0xF2D3: 0x87CF,
	0xF2D4: 0x87D0,
	0xF2D5: 0x87D1,
	0xF2D6: 0x87D2,
	0xF2D7: 0x87D3,
	0xF2D8: 0x87D4,
	0xF2D9: 0x87D5,
	0xF2DA: 0x87D6,
	0xF2DB: 0x87D7,
	0xF2DC: 0x87D8,
	0xF2DD: 0x87D9,
	0xF2DE: 0x87DA,
	0xF2DF: 0x87DB,
	0xF2E0: 0x87DC,
	0xF2E1: 0x87DD,
	0xF2E2: 0x87DE,
	0xF2E3: 0x87DF,
	0xF2E4: 0x87E0,
	0xF2E5: 0x87E1,
	0xF2E6: 0x87E2,
	0xF2E7: 0x87E3,
	0xF2E8: 0x87E4,
	0xF2E9: 0x87E5,
	0xF2EA: 0x87E6,
	0xF2EB: 0x87E7,
	0xF2EC: 0x87E8,
	0xF2ED: 0x87E9,
	0xF2EE: 0x87EA,
	0xF2EF: 0x87EB,
	0xF2F0: 0x87EC,
	0xF2F1: 0x87ED,
	0xF2F2: 0x87EE,
	0xF2F3: 0x87EF,
	0xF2F4: 0x87F0,
	0xF2F5: 0x87F1,
	0xF2F6: 0x87F2,
	0xF2F7: 0x87F3,
	0xF2F8: 0x87F4,
	0xF2F9: 0x87F5,
	0xF2FA: 0x87F6,
	0xF2FB: 0x87F7,
	0xF2FC: 0x87F8,
	0xF2FD: 0x87F9,
	0xF2FE: 0x87FA,
	0xF2FF: 0x87FB,
	0xF300: 0x87FC,
	0xF301: 0x87FD,
	0xF302: 0x87FE,
	0xF303: 0x8840,
	0xF304: 0x8841,
	0xF305: 0x8842,
	0xF306: 0x8843,
	0xF307: 0x8844,
	0xF308: 0x8845,
	0xF309: 0x8846,
	0xF30A: 0x8847,
	0xF30B: 0x8848,
	0xF30C: 0x8849,
	0xF30D: 0x884A,
	0xF30E: 0x884B,
	0xF30F: 0x884C,
	0xF310: 0x884D,
	0xF311: 0x884E,
	0xF312: 0x884F,
	0xF313: 0x8850,
	0xF314: 0x8851,
	0xF315: 0x8852,
	0xF316: 0x8853,
	0xF317: 0x8854,
	0xF318: 0x8855,
	0xF319: 0x8856,
	0xF31A: 0x8857,
	0xF31B: 0x8858,
	0xF31C: 0x8859,
	0xF31D: 0x885A,
	0xF31E: 0x885B,
	0xF31F: 0x885C,
	0xF320: 0x885D,
	0xF321: 0x885E,
	0xF322: 0x885F,
	0xF323: 0x8860,
	0xF324: 0x8861,
	0xF325: 0x8862,
	0xF326: 0x8863,
	0xF327: 0x8864,
	0xF328: 0x8865,
	0xF329: 0x8866,
	0xF32A: 0x8867,
	0xF32B: 0x8868,
	0xF32C: 0x8869,
	0xF32D: 0x886A,
	0xF32E: 0x886B,
	0xF32F: 0x886C,
	0xF330: 0x886D,
	0xF331: 0x886E,
	0xF332: 0x886F,
	0xF333: 0x8870,
	0xF334: 0x8871,
	0xF335: 0x8872,
	0xF336: 0x8873,
	0xF337: 0x8874,
	0xF338: 0x8875,
	0xF339: 0x8876,
	0xF33A: 0x8877,
	0xF33B: 0x8878,
	0xF33C: 0x8879,
	0xF33D: 0x887A,
	0xF33E: 0x887B,
	0xF33F: 0x887C,
	0xF340: 0x887D,
	0xF341: 0x887E,
	0xF342: 0x88A1,
	0xF343: 0x88A2,
	0xF344: 0x88A3,
	0xF345: 0x88A4,
	0xF346: 0x88A5,
	0xF347: 0x88A6,
	0xF348: 0x88A7,
	0xF349: 0x88A8,
	0xF34A: 0x88A9,
	0xF34B: 0x88AA,
	0xF34C: 0x88AB,
	0xF34D: 0x88AC,
	0xF34E: 0x88AD,
	0xF34F: 0x88AE,
	0xF350: 0x88AF,
	0xF351: 0x88B0,
	0xF352: 0x88B1,
	0xF353: 0x88B2,
	0xF354: 0x88B3,
	0xF355: 0x88B4,
	0xF356: 0x88B5,
	0xF357: 0x88B6,
	0xF358: 0x88B7,
	0xF359: 0x88B8,
	0xF35A: 0x88B9,
	0xF35B: 0x88BA,
	0xF35C: 0x88BB,
	0xF35D: 0x88BC,
	0xF35E: 0x88BD,
	0xF35F: 0x88BE,
	0xF360: 0x88BF,
	0xF361: 0x88C0,
	0xF362: 0x88C1,
	0xF363: 0x88C2,
	0xF364: 0x88C3,
	0xF365: 0x88C4,
	0xF366: 0x88C5,
	0xF367: 0x88C6,
	0xF368: 0x88C7,
	0xF369: 0x88C8,
	0xF36A: 0x88C9,
	0xF36B: 0x88CA,
	0xF36C: 0x88CB,
	0xF36D: 0x88CC,
	0xF36E: 0x88CD,
	0xF36F: 0x88CE,
	0xF370: 0x88CF,
	0xF371: 0x88D0,
	0xF372: 0x88D1,
	0xF373: 0x88D2,
	0xF374: 0x88D3,
	0xF375: 0x88D4,
	0xF376: 0x88D5,
	0xF377: 0x88D6,
	0xF378: 0x88D7,
	0xF379: 0x88D8,
	0xF37A: 0x88D9,
	0xF37B: 0x88DA,
	0xF37C: 0x88DB,
	0xF37D: 0x88DC,
	0xF37E: 0x88DD,
	0xF37F: 0x88DE,
	0xF380: 0x88DF,
	0xF381: 0x88E0,
	0xF382: 0x88E1,
	0xF383: 0x88E2,
	0xF384: 0x88E3,
	0xF385: 0x88E4,
	0xF386: 0x88E5,
	0xF387: 0x88E6,
	0xF388: 0x88E7,
	0xF389: 0x88E8,
	0xF38A: 0x88E9,
	0xF38B: 0x88EA,
	0xF38C: 0x88EB,
	0xF38D: 0x88EC,
	0xF38E: 0x88ED,
	0xF38F: 0x88EE,
	0xF390: 0x88EF,
	0xF391: 0x88F0,
	0xF392: 0x88F1,
	0xF393: 0x88F2,
	0xF394: 0x88F3,
	0xF395: 0x88F4,
	0xF396: 0x88F5,
	0xF397: 0x88F6,
	0xF398: 0x88F7,
	0xF399: 0x88F8,
	0xF39A: 0x88F9,
	0xF39B: 0x88FA,
	0xF39C: 0x88FB,
	0xF39D: 0x88FC,
	0xF39E: 0x88FD,
	0xF39F: 0x88FE,
	0xF3A0: 0x8940,
	0xF3A1: 0x8941,
	0xF3A2: 0x8942,
	0xF3A3: 0x8943,
	0xF3A4: 0x8944,
	0xF3A5: 0x8945,
	0xF3A6: 0x8946,
	0xF3A7: 0x8947,
	0xF3A8: 0x8948,
	0xF3A9: 0x8949,
	0xF3AA: 0x894A,
	0xF3AB: 0x894B,
	0xF3AC: 0x894C,
	0xF3AD: 0x894D,
	0xF3AE: 0x894E,
	0xF3AF: 0x894F,
	0xF3B0: 0x8950,
	0xF3B1: 0x8951,
	0xF3B2: 0x8952,
	0xF3B3: 0x8953,
	0xF3B4: 0x8954,
	0xF3B5: 0x8955,
	0xF3B6: 0x8956,
	0xF3B7: 0x8957,
	0xF3B8: 0x8958,
	0xF3B9: 0x8959,
	0xF3BA: 0x895A,
	0xF3BB: 0x895B,
	0xF3BC: 0x895C,
	0xF3BD: 0x895D,
	0xF3BE: 0x895E,
	0xF3BF: 0x895F,
	0xF3C0: 0x8960,
	0xF3C1: 0x8961,
	0xF3C2: 0x8962,
	0xF3C3: 0x8963,
	0xF3C4: 0x8964,
	0xF3C5: 0x8965,
	0xF3C6: 0x8966,
	0xF3C7: 0x8967,
	0xF3C8: 0x8968,
	0xF3C9: 0x8969,
	0xF3CA: 0x896A,
	0xF3CB: 0x896B,
	0xF3CC: 0x896C,
	0xF3CD: 0x896D,
	0xF3CE: 0x896E,
	0xF3CF: 0x896F,
	0xF3D0: 0x8970,
	0xF3D1: 0x8971,
	0xF3D2: 0x8972,
	0xF3D3: 0x8973,
	0xF3D4: 0x8974,
	0xF3D5: 0x8975,
	0xF3D6: 0x8976,
	0xF3D7: 0x8977,
	0xF3D8: 0x8978,
	0xF3D9: 0x8979,
	0xF3DA: 0x897A,
	0xF3DB: 0x897B,
	0xF3DC: 0x897C,
	0xF3DD: 0x897D,
	0xF3DE: 0x897E,
	0xF3DF: 0x89A1,
	0xF3E0: 0x89A2,
	0xF3E1: 0x89A3,
	0xF3E2: 0x89A4,
	0xF3E3: 0x89A5,
	0xF3E4: 0x89A6,
	0xF3E5: 0x89A7,
	0xF3E6: 0x89A8,
	0xF3E7: 0x89A9,
	0xF3E8: 0x89AA,
	0xF3E9: 0x89AB,
	0xF3EA: 0x89AC,
	0xF3EB: 0x89AD,
	0xF3EC: 0x89AE,
	0xF3ED: 0x89AF,
	0xF3EE: 0x89B0,
	0xF3EF: 0x89B1,
	0xF3F0: 0x89B2,
	0xF3F1: 0x89B3,
	0xF3F2: 0x89B4,
	0xF3F3: 0x89B5,
	0xF3F4: 0x89B6,
	0xF3F5: 0x89B7,
	0xF3F6: 0x89B8,
	0xF3F7: 0x89B9,
	0xF3F8: 0x89BA,
	0xF3F9: 0x89BB,
	0xF3FA: 0x89BC,
	0xF3FB: 0x89BD,
	0xF3FC: 0x89BE,
	0xF3FD: 0x89BF,
	0xF3FE: 0x89C0,
	0xF3FF: 0x89C1,
	0xF400: 0x89C2,
	0xF401: 0x89C3,
	0xF402: 0x89C4,
	0xF403: 0x89C5,
	0xF404: 0x89C6,
	0xF405: 0x89C7,
	0xF406: 0x89C8,
	0xF407: 0x89C9,
	0xF408: 0x89CA,
	0xF409: 0x89CB,
	0xF40A: 0x89CC,
	0xF40B: 0x89CD,
	0xF40C: 0x89CE,
	0xF40D: 0x89CF,
	0xF40E: 0x89D0,
	0xF40F: 0x89D1,
	0xF410: 0x89D2,
	0xF411: 0x89D3,
	0xF412: 0x89D4,
	0xF413: 0x89D5,
	0xF414: 0x89D6,
	0xF415: 0x89D7,
	0xF416: 0x89D8,
	0xF417: 0x89D9,
	0xF418: 0x89DA,
	0xF419: 0x89DB,
	0xF41A: 0x89DC,
	0xF41B: 0x89DD,
	0xF41C: 0x89DE,
	0xF41D: 0x89DF,
	0xF41E: 0x89E0,
	0xF41F: 0x89E1,
	0xF420: 0x89E2,
	0xF421: 0x89E3,
	0xF422: 0x89E4,
	0xF423: 0x89E5,
	0xF424: 0x89E6,
	0xF425: 0x89E7,
	0xF426: 0x89E8,
	0xF427: 0x89E9,
	0xF428: 0x89EA,
	0xF429: 0x89EB,
	0xF42A: 0x89EC,
	0xF42B: 0x89ED,
	0xF42C: 0x89EE,
	0xF42D: 0x89EF,
	0xF42E: 0x89F0,
	0xF42F: 0x89F1,
	0xF430: 0x89F2,
	0xF431: 0x89F3,
	0xF432: 0x89F4,
	0xF433: 0x89F5,
	0xF434: 0x89F6,
	0xF435: 0x89F7,
	0xF436: 0x89F8,
	0xF437: 0x89F9,
	0xF438: 0x89FA,
	0xF439: 0x89FB,
	0xF43A: 0x89FC,
	0xF43B: 0x89FD,
	0xF43C: 0x89FE,
	0xF43D: 0x8A40,
	0xF43E: 0x8A41,
	0xF43F: 0x8A42,
	0xF440: 0x8A43,
	0xF441: 0x8A44,
	0xF442: 0x8A45,
	0xF443: 0x8A46,
	0xF444: 0x8A47,
	0xF445: 0x8A48,
	0xF446: 0x8A49,
	0xF447: 0x8A4A,
	0xF448: 0x8A4B,
	0xF449: 0x8A4C,
	0xF44A: 0x8A4D,
	0xF44B: 0x8A4E,
	0xF44C: 0x8A4F,
	0xF44D: 0x8A50,
	0xF44E: 0x8A51,
	0xF44F: 0x8A52,
	0xF450: 0x8A53,
	0xF451: 0x8A54,
	0xF452: 0x8A55,
	0xF453: 0x8A56,
	0xF454: 0x8A57,
	0xF455: 0x8A58,
	0xF456: 0x8A59,
	0xF457: 0x8A5A,
	0xF458: 0x8A5B,
	0xF459: 0x8A5C,
	0xF45A: 0x8A5D,
	0xF45B: 0x8A5E,
	0xF45C: 0x8A5F,
	0xF45D: 0x8A60,
	0xF45E: 0x8A61,
	0xF45F: 0x8A62,
	0xF460: 0x8A63,
	0xF461: 0x8A64,
	0xF462: 0x8A65,
	0xF463: 0x8A66,
	0xF464: 0x8A67,
	0xF465: 0x8A68,
	0xF466: 0x8A69,
	0xF467: 0x8A6A,
	0xF468: 0x8A6B,
	0xF469: 0x8A6C,
	0xF46A: 0x8A6D,
	0xF46B: 0x8A6E,
	0xF46C: 0x8A6F,
	0xF46D: 0x8A70,
	0xF46E: 0x8A71,
	0xF46F: 0x8A72,
	0xF470: 0x8A73,
	0xF471: 0x8A74,
	0xF472: 0x8A75,
	0xF473: 0x8A76,
	0xF474: 0x8A77,
	0xF475: 0x8A78,
	0xF476: 0x8A79,
	0xF477: 0x8A7A,
	0xF478: 0x8A7B,
	0xF479: 0x8A7C,
	0xF47A: 0x8A7D,
	0xF47B: 0x8A7E,
	0xF47C: 0x8AA1,
	0xF47D: 0x8AA2,
	0xF47E: 0x8AA3,
	0xF47F: 0x8AA4,
	0xF480: 0x8AA5,
	0xF481: 0x8AA6,
	0xF482: 0x8AA7,
	0xF483: 0x8AA8,
	0xF484: 0x8AA9,
	0xF485: 0x8AAA,
	0xF486: 0x8AAB,
	0xF487: 0x8AAC,
	0xF488: 0x8AAD,
	0xF489: 0x8AAE,
	0xF48A: 0x8AAF,
	0xF48B: 0x8AB0,
	0xF48C: 0x8AB1,
	0xF48D: 0x8AB2,
	0xF48E: 0x8AB3,
	0xF48F: 0x8AB4,
	0xF490: 0x8AB5,
	0xF491: 0x8AB6,
	0xF492: 0x8AB7,
	0xF493: 0x8AB8,
	0xF494: 0x8AB9,
	0xF495: 0x8ABA,
	0xF496: 0x8ABB,
	0xF497: 0x8ABC,
	0xF498: 0x8ABD,
	0xF499: 0x8ABE,
	0xF49A: 0x8ABF,
	0xF49B: 0x8AC0,
	0xF49C: 0x8AC1,
	0xF49D: 0x8AC2,
	0xF49E: 0x8AC3,
	0xF49F: 0x8AC4,
	0xF4A0: 0x8AC5,
	0xF4A1: 0x8AC6,
	0xF4A2: 0x8AC7,
	0xF4A3: 0x8AC8,
	0xF4A4: 0x8AC9,
	0xF4A5: 0x8ACA,
	0xF4A6: 0x8ACB,
	0xF4A7: 0x8ACC,
	0xF4A8: 0x8ACD,
	0xF4A9: 0x8ACE,
	0xF4AA: 0x8ACF,
	0xF4AB: 0x8AD0,
	0xF4AC: 0x8AD1,
	0xF4AD: 0x8AD2,
	0xF4AE: 0x8AD3,
	0xF4AF: 0x8AD4,
	0xF4B0: 0x8AD5,
	0xF4B1: 0x8AD6,
	0xF4B2: 0x8AD7,
	0xF4B3: 0x8AD8,
	0xF4B4: 0x8AD9,
	0xF4B5: 0x8ADA,
	0xF4B6: 0x8ADB,
	0xF4B7: 0x8ADC,
	0xF4B8: 0x8ADD,
	0xF4B9: 0x8ADE,
	0xF4BA: 0x8ADF,
	0xF4BB: 0x8AE0,
	0xF4BC: 0x8AE1,
	0xF4BD: 0x8AE2,
	0xF4BE: 0x8AE3,
	0xF4BF: 0x8AE4,
	0xF4C0: 0x8AE5,
	0xF4C1: 0x8AE6,
	0xF4C2: 0x8AE7,
	0xF4C3: 0x8AE8,
	0xF4C4: 0x8AE9,
	0xF4C5: 0x8AEA,
	0xF4C6: 0x8AEB,
	0xF4C7: 0x8AEC,
	0xF4C8: 0x8AED,
	0xF4C9: 0x8AEE,
	0xF4CA: 0x8AEF,
	0xF4CB: 0x8AF0,
	0xF4CC: 0x8AF1,
	0xF4CD: 0x8AF2,
	0xF4CE: 0x8AF3,
	0xF4CF: 0x8AF4,
	0xF4D0: 0x8AF5,
	0xF4D1: 0x8AF6,
	0xF4D2: 0x8AF7,
	0xF4D3: 0x8AF8,
	0xF4D4: 0x8AF9,
	0xF4D5: 0x8AFA,
	0xF4D6: 0x8AFB,
	0xF4D7: 0x8AFC,
	0xF4D8: 0x8AFD,
	0xF4D9: 0x8AFE,
	0xF4DA: 0x8B40,
	0xF4DB: 0x8B41,
	0xF4DC: 0x8B42,
	0xF4DD: 0x8B43,
	0xF4DE: 0x8B44,
	0xF4DF: 0x8B45,
	0xF4E0: 0x8B46,
	0xF4E1: 0x8B47,
	0xF4E2: 0x8B48,
	0xF4E3: 0x8B49,
	0xF4E4: 0x8B4A,
	0xF4E5: 0x8B4B,
	0xF4E6: 0x8B4C,
	0xF4E7: 0x8B4D,
	0xF4E8: 0x8B4E,
	0xF4E9: 0x8B4F,
	0xF4EA: 0x8B50,
	0xF4EB: 0x8B51,
	0xF4EC: 0x8B52,
	0xF4ED: 0x8B53,
	0xF4EE: 0x8B54,
	0xF4EF: 0x8B55,
	0xF4F0: 0x8B56,
	0xF4F1: 0x8B57,
	0xF4F2: 0x8B58,
	0xF4F3: 0x8B59,
	0xF4F4: 0x8B5A,
	0xF4F5: 0x8B5B,
	0xF4F6: 0x8B5C,
	0xF4F7: 0x8B5D,
	0xF4F8: 0x8B5E,
	0xF4F9: 0x8B5F,
	0xF4FA: 0x8B60,
	0xF4FB: 0x8B61,
	0xF4FC: 0x8B62,
	0xF4FD: 0x8B63,
	0xF4FE: 0x8B64,
	0xF4FF: 0x8B65,
	0xF500: 0x8B66,
	0xF501: 0x8B67,
	0xF502: 0x8B68,
	0xF503: 0x8B69,
	0xF504: 0x8B6A,
	0xF505: 0x8B6B,
	0xF506: 0x8B6C,
	0xF507: 0x8B6D,
	0xF508: 0x8B6E,
	0xF509: 0x8B6F,
	0xF50A: 0x8B70,
	0xF50B: 0x8B71,
	0xF50C: 0x8B72,
	0xF50D: 0x8B73,
	0xF50E: 0x8B74,
	0xF50F: 0x8B75,
	0xF510: 0x8B76,
	0xF511: 0x8B77,
	0xF512: 0x8B78,
	0xF513: 0x8B79,
	0xF514: 0x8B7A,
	0xF515: 0x8B7B,
	0xF516: 0x8B7C,
	0xF517: 0x8B7D,
	0xF518: 0x8B7E,
	0xF519: 0x8BA1,
	0xF51A: 0x8BA2,
	0xF51B: 0x8BA3,
	0xF51C: 0x8BA4,
	0xF51D: 0x8BA5,
	0xF51E: 0x8BA6,
	0xF51F: 0x8BA7,
	0xF520: 0x8BA8,
	0xF521: 0x8BA9,
	0xF522: 0x8BAA,
	0xF523: 0x8BAB,
	0xF524: 0x8BAC,
	0xF525: 0x8BAD,
	0xF526: 0x8BAE,
	0xF527: 0x8BAF,
	0xF528: 0x8BB0,
	0xF529: 0x8BB1,
	0xF52A: 0x8BB2,
	0xF52B: 0x8BB3,
	0xF52C: 0x8BB4,
	0xF52D: 0x8BB5,
	0xF52E: 0x8BB6,
	0xF52F: 0x8BB7,
	0xF530: 0x8BB8,
	0xF531: 0x8BB9,
	0xF532: 0x8BBA,
	0xF533: 0x8BBB,
	0xF534: 0x8BBC,
	0xF535: 0x8BBD,
	0xF536: 0x8BBE,
	0xF537: 0x8BBF,
	0xF538: 0x8BC0,
	0xF539: 0x8BC1,
	0xF53A: 0x8BC2,
	0xF53B: 0x8BC3,
	0xF53C: 0x8BC4,
	0xF53D: 0x8BC5,
	0xF53E: 0x8BC6,
	0xF53F: 0x8BC7,
	0xF540: 0x8BC8,
	0xF541: 0x8BC9,
	0xF542: 0x8BCA,
	0xF543: 0x8BCB,
	0xF544: 0x8BCC,
	0xF545: 0x8BCD,
	0xF546: 0x8BCE,
	0xF547: 0x8BCF,
	0xF548: 0x8BD0,
	0xF549: 0x8BD1,
	0xF54A: 0x8BD2,
	0xF54B: 0x8BD3,
	0xF54C: 0x8BD4,
	0xF54D: 0x8BD5,
	0xF54E: 0x8BD6,
	0xF54F: 0x8BD7,
	0xF550: 0x8BD8,
	0xF551: 0x8BD9,
	0xF552: 0x8BDA,
	0xF553: 0x8BDB,
	0xF554: 0x8BDC,
	0xF555: 0x8BDD,
	0xF556: 0x8BDE,
	0xF557: 0x8BDF,
	0xF558: 0x8BE0,
	0xF559: 0x8BE1,
	0xF55A: 0x8BE2,
	0xF55B: 0x8BE3,
	0xF55C: 0x8BE4,
	0xF55D: 0x8BE5,
	0xF55E: 0x8BE6,
	0xF55F: 0x8BE7,
	0xF560: 0x8BE8,
	0xF561: 0x8BE9,
	0xF562: 0x8BEA,
	0xF563: 0x8BEB,
	0xF564: 0x8BEC,
	0xF565: 0x8BED,
	0xF566: 0x8BEE,
	0xF567: 0x8BEF,
	0xF568: 0x8BF0,
	0xF569: 0x8BF1,
	0xF56A: 0x8BF2,
	0xF56B: 0x8BF3,
	0xF56C: 0x8BF4,
	0xF56D: 0x8BF5,
	0xF56E: 0x8BF6,
	0xF56F: 0x8BF7,
	0xF570: 0x8BF8,
	0xF571: 0x8BF9,
	0xF572: 0x8BFA,
	0xF573: 0x8BFB,
	0xF574: 0x8BFC,
	0xF575: 0x8BFD,
	0xF576: 0x8BFE,
	0xF577: 0x8C40,
	0xF578: 0x8C41,
	0xF579: 0x8C42,
	0xF57A: 0x8C43,
	0xF57B: 0x8C44,
	0xF57C: 0x8C45,
	0xF57D: 0x8C46,
	0xF57E: 0x8C47,
	0xF57F: 0x8C48,
	0xF580: 0x8C49,
	0xF581: 0x8C4A,
	0xF582: 0x8C4B,
	0xF583: 0x8C4C,
	0xF584: 0x8C4D,
	0xF585: 0x8C4E,
	0xF586: 0x8C4F,
	0xF587: 0x8C50,
	0xF588: 0x8C51,
	0xF589: 0x8C52,
	0xF58A: 0x8C53,
	0xF58B: 0x8C54,
	0xF58C: 0x8C55,
	0xF58D: 0x8C56,
	0xF58E: 0x8C57,
	0xF58F: 0x8C58,
	0xF590: 0x8C59,
	0xF591: 0x8C5A,
	0xF592: 0x8C5B,
	0xF593: 0x8C5C,
	0xF594: 0x8C5D,
	0xF595: 0x8C5E,
	0xF596: 0x8C5F,
	0xF597: 0x8C60,
	0xF598: 0x8C61,
	0xF599: 0x8C62,
	0xF59A: 0x8C63,
	0xF59B: 0x8C64,
	0xF59C: 0x8C65,
	0xF59D: 0x8C66,
	0xF59E: 0x8C67,
	0xF59F: 0x8C68,
	0xF5A0: 0x8C69,
	0xF5A1: 0x8C6A,
	0xF5A2: 0x8C6B,
	0xF5A3: 0x8C6C,
	0xF5A4: 0x8C6D,
	0xF5A5: 0x8C6E,
	0xF5A6: 0x8C6F,
	0xF5A7: 0x8C70,
	0xF5A8: 0x8C71,
	0xF5A9: 0x8C72,
	0xF5AA: 0x8C73,
	0xF5AB: 0x8C74,
	0xF5AC: 0x8C75,
	0xF5AD: 0x8C76,
	0xF5AE: 0x8C77,
	0xF5AF: 0x8C78,
	0xF5B0: 0x8C79,
	0xF5B1: 0x8C7A,
	0xF5B2: 0x8C7B,
	0xF5B3: 0x8C7C,
	0xF5B4: 0x8C7D,
	0xF5B5: 0x8C7E,
	0xF5B6: 0x8CA1,
	0xF5B7: 0x8CA2,
	0xF5B8: 0x8CA3,
	0xF5B9: 0x8CA4,
	0xF5BA: 0x8CA5,
	0xF5BB: 0x8CA6,
	0xF5BC: 0x8CA7,
	0xF5BD: 0x8CA8,
	0xF5BE: 0x8CA9,
	0xF5BF: 0x8CAA,
	0xF5C0: 0x8CAB,
	0xF5C1: 0x8CAC,
	0xF5C2: 0x8CAD,
	0xF5C3: 0x8CAE,
	0xF5C4: 0x8CAF,
	0xF5C5: 0x8CB0,
	0xF5C6: 0x8CB1,
	0xF5C7: 0x8CB2,
	0xF5C8: 0x8CB3,
	0xF5C9: 0x8CB4,
	0xF5CA: 0x8CB5,
	0xF5CB: 0x8CB6,
	0xF5CC: 0x8CB7,
	0xF5CD: 0x8CB8,
	0xF5CE: 0x8CB9,
	0xF5CF: 0x8CBA,
	0xF5D0: 0x8CBB,
	0xF5D1: 0x8CBC,
	0xF5D2: 0x8CBD,
	0xF5D3: 0x8CBE,
	0xF5D4: 0x8CBF,
	0xF5D5: 0x8CC0,
	0xF5D6: 0x8CC1,
	0xF5D7: 0x8CC2,
	0xF5D8: 0x8CC3,
	0xF5D9: 0x8CC4,
	0xF5DA: 0x8CC5,
	0xF5DB: 0x8CC6,
	0xF5DC: 0x8CC7,
	0xF5DD: 0x8CC8,
	0xF5DE: 0x8CC9,
	0xF5DF: 0x8CCA,
	0xF5E0: 0x8CCB,
	0xF5E1: 0x8CCC,
	0xF5E2: 0x8CCD,
	0xF5E3: 0x8CCE,
	0xF5E4: 0x8CCF,
	0xF5E5: 0x8CD0,
	0xF5E6: 0x8CD1,
	0xF5E7: 0x8CD2,
	0xF5E8: 0x8CD3,
	0xF5E9: 0x8CD4,
	0xF5EA: 0x8CD5,
	0xF5EB: 0x8CD6,
	0xF5EC: 0x8CD7,
	0xF5ED: 0x8CD8,
	0xF5EE: 0x8CD9,
	0xF5EF: 0x8CDA,
	0xF5F0: 0x8CDB,
	0xF5F1: 0x8CDC,
	0xF5F2: 0x8CDD,
	0xF5F3: 0x8CDE,
	0xF5F4: 0x8CDF,
	0xF5F5: 0x8CE0,
	0xF5F6: 0x8CE1,
	0xF5F7: 0x8CE2,
	0xF5F8: 0x8CE3,
	0xF5F9: 0x8CE4,
	0xF5FA: 0x8CE5,
	0xF5FB: 0x8CE6,
	0xF5FC: 0x8CE7,
	0xF5FD: 0x8CE8,
	0xF5FE: 0x8CE9,
	0xF5FF: 0x8CEA,
	0xF600: 0x8CEB,
	0xF601: 0x8CEC,
	0xF602: 0x8CED,
	0xF603: 0x8CEE,
	0xF604: 0x8CEF,
	0xF605: 0x8CF0,
	0xF606: 0x8CF1,
	0xF607: 0x8CF2,
	0xF608: 0x8CF3,
	0xF609: 0x8CF4,
	0xF60A: 0x8CF5,
	0xF60B: 0x8CF6,
	0xF60C: 0x8CF7,
	0xF60D: 0x8CF8,
	0xF60E: 0x8CF9,
	0xF60F: 0x8CFA,
	0xF610: 0x8CFB,
	0xF611: 0x8CFC,
	0xF612: 0x8CFD,
	0xF613: 0x8CFE,
	0xF614: 0x8D40,
	0xF615: 0x8D41,
	0xF616: 0x8D42,
	0xF617: 0x8D43,
	0xF618: 0x8D44,
	0xF619: 0x8D45,
	0xF61A: 0x8D46,
	0xF61B: 0x8D47,
	0xF61C: 0x8D48,
	0xF61D: 0x8D49,
	0xF61E: 0x8D4A,
	0xF61F: 0x8D4B,
	0xF620: 0x8D4C,
	0xF621: 0x8D4D,
	0xF622: 0x8D4E,
	0xF623: 0x8D4F,
	0xF624: 0x8D50,
	0xF625: 0x8D51,
	0xF626: 0x8D52,
	0xF627: 0x8D53,
	0xF628: 0x8D54,
	0xF629: 0x8D55,
	0xF62A: 0x8D56,
	0xF62B: 0x8D57,
	0xF62C: 0x8D58,
	0xF62D: 0x8D59,
	0xF62E: 0x8D5A,
	0xF62F: 0x8D5B,
	0xF630: 0x8D5C,
	0xF631: 0x8D5D,
	0xF632: 0x8D5E,
	0xF633: 0x8D5F,
	0xF634: 0x8D60,
	0xF635: 0x8D61,
	0xF636: 0x8D62,
	0xF637: 0x8D63,
	0xF638: 0x8D64,
	0xF639: 0x8D65,
	0xF63A: 0x8D66,
	0xF63B: 0x8D67,
	0xF63C: 0x8D68,
	0xF63D: 0x8D69,
	0xF63E: 0x8D6A,
	0xF63F: 0x8D6B,
	0xF640: 0x8D6C,
	0xF641: 0x8D6D,
	0xF642: 0x8D6E,
	0xF643: 0x8D6F,
	0xF644: 0x8D70,
	0xF645: 0x8D71,
	0xF646: 0x8D72,
	0xF647: 0x8D73,
	0xF648: 0x8D74,
	0xF649: 0x8D75,
	0xF64A: 0x8D76,
	0xF64B: 0x8D77,
	0xF64C: 0x8D78,
	0xF64D: 0x8D79,
	0xF64E: 0x8D7A,
	0xF64F: 0x8D7B,
	0xF650: 0x8D7C,
	0xF651: 0x8D7D,
	0xF652: 0x8D7E,
	0xF653: 0x8DA1,
	0xF654: 0x8DA2,
	0xF655: 0x8DA3,
	0xF656: 0x8DA4,
	0xF657: 0x8DA5,
	0xF658: 0x8DA6,
	0xF659: 0x8DA7,
	0xF65A: 0x8DA8,
	0xF65B: 0x8DA9,
	0xF65C: 0x8DAA,
	0xF65D: 0x8DAB,
	0xF65E: 0x8DAC,
	0xF65F: 0x8DAD,
	0xF660: 0x8DAE,
	0xF661: 0x8DAF,
	0xF662: 0x8DB0,
	0xF663: 0x8DB1,
	0xF664: 0x8DB2,
	0xF665: 0x8DB3,
	0xF666: 0x8DB4,
	0xF667: 0x8DB5,
	0xF668: 0x8DB6,
	0xF669: 0x8DB7,
	0xF66A: 0x8DB8,
	0xF66B: 0x8DB9,
	0xF66C: 0x8DBA,
	0xF66D: 0x8DBB,
	0xF66E: 0x8DBC,
	0xF66F: 0x8DBD,
	0xF670: 0x8DBE,
	0xF671: 0x8DBF,
	0xF672: 0x8DC0,
	0xF673: 0x8DC1,
	0xF674: 0x8DC2,
	0xF675: 0x8DC3,
	0xF676: 0x8DC4,
	0xF677: 0x8DC5,
	0xF678: 0x8DC6,
	0xF679: 0x8DC7,
	0xF67A: 0x8DC8,
	0xF67B: 0x8DC9,
	0xF67C: 0x8DCA,
	0xF67D: 0x8DCB,
	0xF67E: 0x8DCC,
	0xF67F: 0x8DCD,
	0xF680: 0x8DCE,
	0xF681: 0x8DCF,
	0xF682: 0x8DD0,
	0xF683: 0x8DD1,
	0xF684: 0x8DD2,
	0xF685: 0x8DD3,
	0xF686: 0x8DD4,
	0xF687: 0x8DD5,
	0xF688: 0x8DD6,
	0xF689: 0x8DD7,
	0xF68A: 0x8DD8,
	0xF68B: 0x8DD9,
	0xF68C: 0x8DDA,
	0xF68D: 0x8DDB,
	0xF68E: 0x8DDC,
	0xF68F: 0x8DDD,
	0xF690: 0x8DDE,
	0xF691: 0x8DDF,
	0xF692: 0x8DE0,
	0xF693: 0x8DE1,
	0xF694: 0x8DE2,
	0xF695: 0x8DE3,
	0xF696: 0x8DE4,
	0xF697: 0x8DE5,
	0xF698: 0x8DE6,
	0xF699: 0x8DE7,
	0xF69A: 0x8DE8,
	0xF69B: 0x8DE9,
	0xF69C: 0x8DEA,
	0xF69D: 0x8DEB,
	0xF69E: 0x8DEC,
	0xF69F: 0x8DED,
	0xF6A0: 0x8DEE,
	0xF6A1: 0x8DEF,
	0xF6A2: 0x8DF0,
	0xF6A3: 0x8DF1,
	0xF6A4: 0x8DF2,
	0xF6A5: 0x8DF3,
	0xF6A6: 0x8DF4,
	0xF6A7: 0x8DF5,
	0xF6A8: 0x8DF6,
	0xF6A9: 0x8DF7,
	0xF6AA: 0x8DF8,
	0xF6AB: 0x8DF9,
	0xF6AC: 0x8DFA,
	0xF6AD: 0x8DFB,
	0xF6AE: 0x8DFC,
	0xF6AF: 0x8DFD,
	0xF6B0: 0x8DFE,
	0xF6B1: 0xC6A1,
	0xF6B2: 0xC6A2,
	0xF6B3: 0xC6A3,
	0xF6B4: 0xC6A4,
	0xF6B5: 0xC6A5,
	0xF6B6: 0xC6A6,
	0xF6B7: 0xC6A7,
	0xF6B8: 0xC6A8,
	0xF6B9: 0xC6A9,
	0xF6BA: 0xC6AA,
	0xF6BB: 0xC6AB,
	0xF6BC: 0xC6AC,
	0xF6BD: 0xC6AD,
	0xF6BE: 0xC6AE,
	0xF6BF: 0xC6AF,
	0xF6C0: 0xC6B0,
	0xF6C1: 0xC6B1,
	0xF6C2: 0xC6B2,
	0xF6C3: 0xC6B3,
	0xF6C4: 0xC6B4,
	0xF6C5: 0xC6B5,
	0xF6C6: 0xC6B6,
	0xF6C7: 0xC6B7,
	0xF6C8: 0xC6B8,
	0xF6C9: 0xC6B9,
	0xF6CA: 0xC6BA,
	0xF6CB: 0xC6BB,
	0xF6CC: 0xC6BC,
	0xF6CD: 0xC6BD,
	0xF6CE: 0xC6BE,
	0xF6CF: 0xC6BF,
	0xF6D0: 0xC6C0,
	0xF6D1: 0xC6C1,
	0xF6D2: 0xC6C2,
	0xF6D3: 0xC6C3,
	0xF6D4: 0xC6C4,
	0xF6D5: 0xC6C5,
	0xF6D6: 0xC6C6,
	0xF6D7: 0xC6C7,
	0xF6D8: 0xC6C8,
	0xF6D9: 0xC6C9,
	0xF6DA: 0xC6CA,
	0xF6DB: 0xC6CB,
	0xF6DC: 0xC6CC,
	0xF6DD: 0xC6CD,
	0xF6DE: 0xC6CE,
	0xF6DF: 0xC6CF,
	0xF6E0: 0xC6D0,
	0xF6E1: 0xC6D1,
	0xF6E2: 0xC6D2,
	0xF6E3: 0xC6D3,
	0xF6E4: 0xC6D4,
	0xF6E5: 0xC6D5,
	0xF6E6: 0xC6D6,
	0xF6E7: 0xC6D7,
	0xF6E8: 0xC6D8,
	0xF6E9: 0xC6D9,
	0xF6EA: 0xC6DA,
	0xF6EB: 0xC6DB,
	0xF6EC: 0xC6DC,
	0xF6ED: 0xC6DD,
	0xF6EE: 0xC6DE,
	0xF6EF: 0xC6DF,
	0xF6F0: 0xC6E0,
	0xF6F1: 0xC6E1,
	0xF6F2: 0xC6E2,
	0xF6F3: 0xC6E3,
	0xF6F4: 0xC6E4,
	0xF6F5: 0xC6E5,
	0xF6F6: 0xC6E6,
	0xF6F7: 0xC6E7,
	0xF6F8: 0xC6E8,
	0xF6F9: 0xC6E9,
	0xF6FA: 0xC6EA,
	0xF6FB: 0xC6EB,
	0xF6FC: 0xC6EC,
	0xF6FD: 0xC6ED,
	0xF6FE: 0xC6EE,
	0xF6FF: 0xC6EF,
	0xF700: 0xC6F0,
	0xF701: 0xC6F1,
	0xF702: 0xC6F2,
	0xF703: 0xC6F3,
	0xF704: 0xC6F4,
	0xF705: 0xC6F5,
	0xF706: 0xC6F6,
	0xF707: 0xC6F7,
	0xF708: 0xC6F8,
	0xF709: 0xC6F9,
	0xF70A: 0xC6FA,
	0xF70B: 0xC6FB,
	0xF70C: 0xC6FC,
	0xF70D: 0xC6FD,
	0xF70E: 0xC6FE,
	0xF70F: 0xC740,
	0xF710: 0xC741,
	0xF711: 0xC742,
	0xF712: 0xC743,
	0xF713: 0xC744,
	0xF714: 0xC745,
	0xF715: 0xC746,
	0xF716: 0xC747,
	0xF717: 0xC748,
	0xF718: 0xC749,
	0xF719: 0xC74A,
	0xF71A: 0xC74B,
	0xF71B: 0xC74C,
	0xF71C: 0xC74D,
	0xF71D: 0xC74E,
	0xF71E: 0xC74F,
	0xF71F: 0xC750,
	0xF720: 0xC751,
	0xF721: 0xC752,
	0xF722: 0xC753,
	0xF723: 0xC754,
	0xF724: 0xC755,
	0xF725: 0xC756,
	0xF726: 0xC757,
	0xF727: 0xC758,
	0xF728: 0xC759,
	0xF729: 0xC75A,
	0xF72A: 0xC75B,
	0xF72B: 0xC75C,
	0xF72C: 0xC75D,
	0xF72D: 0xC75E,
	0xF72E: 0xC75F,
	0xF72F: 0xC760,
	0xF730: 0xC761,
	0xF731: 0xC762,
	0xF732: 0xC763,
	0xF733: 0xC764,
	0xF734: 0xC765,
	0xF735: 0xC766,
	0xF736: 0xC767,
	0xF737: 0xC768,
	0xF738: 0xC769,
	0xF739: 0xC76A,
	0xF73A: 0xC76B,
	0xF73B: 0xC76C,
	0xF73C: 0xC76D,
	0xF73D: 0xC76E,
	0xF73E: 0xC76F,
	0xF73F: 0xC770,
	0xF740: 0xC771,
	0xF741: 0xC772,
	0xF742: 0xC773,
	0xF743: 0xC774,
	0xF744: 0xC775,
	0xF745: 0xC776,
	0xF746: 0xC777,
	0xF747: 0xC778,
	0xF748: 0xC779,
	0xF749: 0xC77A,
	0xF74A: 0xC77B,
	0xF74B: 0xC77C,
	0xF74C: 0xC77D,
	0xF74D: 0xC77E,
	0xF74E: 0xC7A1,
	0xF74F: 0xC7A2,
	0xF750: 0xC7A3,
	0xF751: 0xC7A4,
	0xF752: 0xC7A5,
	0xF753: 0xC7A6,
	0xF754: 0xC7A7,
	0xF755: 0xC7A8,
	0xF756: 0xC7A9,
	0xF757: 0xC7AA,
	0xF758: 0xC7AB,
	0xF759: 0xC7AC,
	0xF75A: 0xC7AD,
	0xF75B: 0xC7AE,
	0xF75C: 0xC7AF,
	0xF75D: 0xC7B0,
	0xF75E: 0xC7B1,
	0xF75F: 0xC7B2,
	0xF760: 0xC7B3,
	0xF761: 0xC7B4,
	0xF762: 0xC7B5,
	0xF763: 0xC7B6,
	0xF764: 0xC7B7,
	0xF765: 0xC7B8,
	0xF766: 0xC7B9,
	0xF767: 0xC7BA,
	0xF768: 0xC7BB,
	0xF769: 0xC7BC,
	0xF76A: 0xC7BD,
	0xF76B: 0xC7BE,
	0xF76C: 0xC7BF,
	0xF76D: 0xC7C0,
	0xF76E: 0xC7C1,
	0xF76F: 0xC7C2,
	0xF770: 0xC7C3,
	0xF771: 0xC7C4,
	0xF772: 0xC7C5,
	0xF773: 0xC7C6,
	0xF774: 0xC7C7,
	0xF775: 0xC7C8,
	0xF776: 0xC7C9,
	0xF777: 0xC7CA,
	0xF778: 0xC7CB,
	0xF779: 0xC7CC,
	0xF77A: 0xC7CD,
	0xF77B: 0xC7CE,
	0xF77C: 0xC7CF,
	0xF77D: 0xC7D0,
	0xF77E: 0xC7D1,
	0xF77F: 0xC7D2,
	0xF780: 0xC7D3,
	0xF781: 0xC7D4,
	0xF782: 0xC7D5,
	0xF783: 0xC7D6,
	0xF784: 0xC7D7,
	0xF785: 0xC7D8,
	0xF786: 0xC7D9,
	0xF787: 0xC7DA,
	0xF788: 0xC7DB,
	0xF789: 0xC7DC,
	0xF78A: 0xC7DD,
	0xF78B: 0xC7DE,
	0xF78C: 0xC7DF,
	0xF78D: 0xC7E0,
	0xF78E: 0xC7E1,
	0xF78F: 0xC7E2,
	0xF790: 0xC7E3,
	0xF791: 0xC7E4,
	0xF792: 0xC7E5,
	0xF793: 0xC7E6,
	0xF794: 0xC7E7,
	0xF795: 0xC7E8,
	0xF796: 0xC7E9,
	0xF797: 0xC7EA,
	0xF798: 0xC7EB,
	0xF799: 0xC7EC,
	0xF79A: 0xC7ED,
	0xF79B: 0xC7EE,
	0xF79C: 0xC7EF,
	0xF79D: 0xC7F0,
	0xF79E: 0xC7F1,
	0xF79F: 0xC7F2,
	0xF7A0: 0xC7F3,
	0xF7A1: 0xC7F4,
	0xF7A2: 0xC7F5,
	0xF7A3: 0xC7F6,
	0xF7A4: 0xC7F7,
	0xF7A5: 0xC7F8,
	0xF7A6: 0xC7F9,
	0xF7A7: 0xC7FA,
	0xF7A8: 0xC7FB,
	0xF7A9: 0xC7FC,
	0xF7AA: 0xC7FD,
	0xF7AB: 0xC7FE,
	0xF7AC: 0xC840,
	0xF7AD: 0xC841,
	0xF7AE: 0xC842,
	0xF7AF: 0xC843,
	0xF7B0: 0xC844,
	0xF7B1: 0xC845,
	0xF7B2: 0xC846,
	0xF7B3: 0xC847,
	0xF7B4: 0xC848,
	0xF7B5: 0xC849,
	0xF7B6: 0xC84A,
	0xF7B7: 0xC84B,
	0xF7B8: 0xC84C,
	0xF7B9: 0xC84D,
	0xF7BA: 0xC84E,
	0xF7BB: 0xC84F,
	0xF7BC: 0xC850,
	0xF7BD: 0xC851,
	0xF7BE: 0xC852,
	0xF7BF: 0xC853,
	0xF7C0: 0xC854,
	0xF7C1: 0xC855,
	0xF7C2: 0xC856,
	0xF7C3: 0xC857,
	0xF7C4: 0xC858,
	0xF7C5: 0xC859,
	0xF7C6: 0xC85A,
	0xF7C7: 0xC85B,
	0xF7C8: 0xC85C,
	0xF7C9: 0xC85D,
	0xF7CA: 0xC85E,
	0xF7CB: 0xC85F,
	0xF7CC: 0xC860,
	0xF7CD: 0xC861,
	0xF7CE: 0xC862,
	0xF7CF: 0xC863,
	0xF7D0: 0xC864,
	0xF7D1: 0xC865,
	0xF7D2: 0xC866,
	0xF7D3: 0xC867,
	0xF7D4: 0xC868,
	0xF7D5: 0xC869,
	0xF7D6: 0xC86A,
	0xF7D7: 0xC86B,
	0xF7D8: 0xC86C,
	0xF7D9: 0xC86D,
	0xF7DA: 0xC86E,
	0xF7DB: 0xC86F,
	0xF7DC: 0xC870,
	0xF7DD: 0xC871,
	0xF7DE: 0xC872,
	0xF7DF: 0xC873,
	0xF7E0: 0xC874,
	0xF7E1: 0xC875,
	0xF7E2: 0xC876,
	0xF7E3: 0xC877,
	0xF7E4: 0xC878,
	0xF7E5: 0xC879,
	0xF7E6: 0xC87A,
	0xF7E7: 0xC87B,
	0xF7E8: 0xC87C,
	0xF7E9: 0xC87D,
	0xF7EA: 0xC87E,
	0xF7EB: 0xC8A1,
	0xF7EC: 0xC8A2,
	0xF7ED: 0xC8A3,
	0xF7EE: 0xC8A4,
	0xF7EF: 0xC8A5,
	0xF7F0: 0xC8A6,
	0xF7F1: 0xC8A7,
	0xF7F2: 0xC8A8,
	0xF7F3: 0xC8A9,
	0xF7F4: 0xC8AA,
	0xF7F5: 0xC8AB,
	0xF7F6: 0xC8AC,
	0xF7F7: 0xC8AD,
	0xF7F8: 0xC8AE,
	0xF7F9: 0xC8AF,
	0xF7FA: 0xC8B0,
	0xF7FB: 0xC8B1,
	0xF7FC: 0xC8B2,
	0xF7FD: 0xC8B3,
	0xF7FE: 0xC8B4,
	0xF7FF: 0xC8B5,
	0xF800: 0xC8B6,
	0xF801: 0xC8B7,
	0xF802: 0xC8B8,
	0xF803: 0xC8B9,
	0xF804: 0xC8BA,
	0xF805: 0xC8BB,
	0xF806: 0xC8BC,
	0xF807: 0xC8BD,
	0xF808: 0xC8BE,
	0xF809: 0xC8BF,
	0xF80A: 0xC8C0,
	0xF80B: 0xC8C1,
	0xF80C: 0xC8C2,
	0xF80D: 0xC8C3,
	0xF80E: 0xC8C4,
	0xF80F: 0xC8C5,
	0xF810: 0xC8C6,
	0xF811: 0xC8C7,
	0xF812: 0xC8C8,
	0xF813: 0xC8C9,
	0xF814: 0xC8CA,
	0xF815: 0xC8CB,
	0xF816: 0xC8CC,
	0xF817: 0xC8CD,
	0xF818: 0xC8CE,
	0xF819: 0xC8CF,
	0xF81A: 0xC8D0,
	0xF81B: 0xC8D1,
	0xF81C: 0xC8D2,
	0xF81D: 0xC8D3,
	0xF81E: 0xC8D4,
	0xF81F: 0xC8D5,
	0xF820: 0xC8D6,
	0xF821: 0xC8D7,
	0xF822: 0xC8D8,
	0xF823: 0xC8D9,
	0xF824: 0xC8DA,
	0xF825: 0xC8DB,
	0xF826: 0xC8DC,
	0xF827: 0xC8DD,
	0xF828: 0xC8DE,
	0xF829: 0xC8DF,
	0xF82A: 0xC8E0,
	0xF82B: 0xC8E1,
	0xF82C: 0xC8E2,
	0xF82D: 0xC8E3,
	0xF82E: 0xC8E4,
	0xF82F: 0xC8E5,
	0xF830: 0xC8E6,
	0xF831: 0xC8E7,
	0xF832: 0xC8E8,
	0xF833: 0xC8E9,
	0xF834: 0xC8EA,
	0xF835: 0xC8EB,
	0xF836: 0xC8EC,
	0xF837: 0xC8ED,
	0xF838: 0xC8EE,
	0xF839: 0xC8EF,
	0xF83A: 0xC8F0,
	0xF83B: 0xC8F1,
	0xF83C: 0xC8F2,
	0xF83D: 0xC8F3,
	0xF83E: 0xC8F4,
	0xF83F: 0xC8F5,
	0xF840: 0xC8F6,
	0xF841: 0xC8F7,
	0xF842: 0xC8F8,
	0xF843: 0xC8F9,
	0xF844: 0xC8FA,
	0xF845: 0xC8FB,
	0xF846: 0xC8FC,
	0xF847: 0xC8FD,
	0xF848: 0xC8FE,
	0xF849: 0xA3E2,
	0xF84A: 0xA3E3,
	0xF84B: 0xA3E4,
	0xF84C: 0xA3E5,
	0xF84D: 0xA3E6,
	0xF84E: 0xA3E7,
	0xF84F: 0xA3E8,
	0xF850: 0xA3E9,
	0xF851: 0xA3EA,
	0xF852: 0xA3EB,
	0xF853: 0xA3EC,
	0xF854: 0xA3ED,
	0xF855: 0xA3EE,
	0xF856: 0xA3EF,
	0xF857: 0xA3F0,
	0xF858: 0xA3F1,
	0xF859: 0xA3F2,
	0xF85A: 0xA3F3,
	0xF85B: 0xA3F4,
	0xF85C: 0xA3F5,
	0xF85D: 0xA3F6,
	0xF85E: 0xA3F7,
	0xF85F: 0xA3F8,
	0xF860: 0xA3F9,
	0xF861: 0xA3FA,
	0xF862: 0xA3FB,
	0xF863: 0xA3FC,
	0xF864: 0xA3FD,
	0xF865: 0xA3FE,
	0xF866: 0xC6DE,
	0xF867: 0xC6DF,
	0xF868: 0xFFFD,
	0xF869: 0xFFFD,
	0xF86A: 0xFFFD,
	0xF86B: 0xFFFD,
	0xF86C: 0xFFFD,
	0xF86D: 0xFFFD,
	0xF86E: 0xFFFD,
	0xF86F: 0xFFFD,
	0xF870: 0xFFFD,
	0xF871: 0xFFFD,
	0xF872: 0xFFFD,
	0xF873: 0xFFFD,
	0xF874: 0xFFFD,
	0xF875: 0xFFFD,
	0xF876: 0xFFFD,
	0xF877: 0xFFFD,
	0xF878: 0xFFFD,
	0xF879: 0xFFFD,
	0xF87A: 0xFFFD,
	0xF87B: 0xFFFD,
	0xF87C: 0xFFFD,
	0xF87D: 0xFFFD,
	0xF87E: 0xFFFD,
	0xF87F: 0xFFFD,
	0xF880: 0xFFFD,
	0xF881: 0xFFFD,
	0xF882: 0xFFFD,
	0xF883: 0xFFFD,
	0xF884: 0xFFFD,
	0xF885: 0xFFFD,
	0xF886: 0xFFFD,
	0xF887: 0xFFFD,
	0xF888: 0xFFFD,
	0xF889: 0xFFFD,
	0xF88A: 0xFFFD,
	0xF88B: 0xFFFD,
	0xF88C: 0xFFFD,
	0xF88D: 0xFFFD,
	0xF88E: 0xFFFD,
	0xF88F: 0xFFFD,
	0xF890: 0xFFFD,
	0xF891: 0xFFFD,
	0xF892: 0xFFFD,
	0xF893: 0xFFFD,
	0xF894: 0xFFFD,
	0xF895: 0xFFFD,
	0xF896: 0xFFFD,
	0xF897: 0xFFFD,
	0xF898: 0xFFFD,
	0xF899: 0xFFFD,
	0xF89A: 0xFFFD,
	0xF89B: 0xFFFD,
	0xF89C: 0xFFFD,
	0xF89D: 0xFFFD,
	0xF89E: 0xFFFD,
	0xF89F: 0xFFFD,
	0xF8A0: 0xFFFD,
	0xF8A1: 0xFFFD,
	0xF8A2: 0xFFFD,
	0xF8A3: 0xFFFD,
	0xF8A4: 0xFFFD,
	0xF8A5: 0xFFFD,
	0xF8A6: 0xFFFD,
	0xF8A7: 0xFFFD,
	0xF8A8: 0xFFFD,
	0xF8A9: 0xFFFD,
	0xF8AA: 0xFFFD,
	0xF8AB: 0xFFFD,
	0xF8AC: 0xFFFD,
	0xF8AD: 0xFFFD,
	0xF8AE: 0xFFFD,
	0xF8AF: 0xFFFD,
	0xF8B0: 0xFFFD,
	0xF8B1: 0xFFFD,
	0xF8B2: 0xFFFD,
	0xF8B3: 0xFFFD,
	0xF8B4: 0xFFFD,
	0xF8B5: 0xFFFD,
	0xF8B6: 0xFFFD,
	0xF8B7: 0xFFFD,
	0xF8B8: 0xFFFD,
	0xF8B9: 0xFFFD,
	0xF8BA: 0xFFFD,
	0xF8BB: 0xFFFD,
	0xF8BC: 0xFFFD,
	0xF8BD: 0xFFFD,
	0xF8BE: 0xFFFD,
	0xF8BF: 0xFFFD,
	0xF8C0: 0xFFFD,
	0xF8C1: 0xFFFD,
	0xF8C2: 0xFFFD,
	0xF8C3: 0xFFFD,
	0xF8C4: 0xFFFD,
	0xF8C5: 0xFFFD,
	0xF8C6: 0xFFFD,
	0xF8C7: 0xFFFD,
	0xF8C8: 0xFFFD,
	0xF8C9: 0xFFFD,
	0xF8CA: 0xFFFD,
	0xF8CB: 0xFFFD,
	0xF8CC: 0xFFFD,
	0xF8CD: 0xFFFD,
	0xF8CE: 0xFFFD,
	0xF8CF: 0xFFFD,
	0xF8D0: 0xFFFD,
	0xF8D1: 0xFFFD,
	0xF8D2: 0xFFFD,
	0xF8D3: 0xFFFD,
	0xF8D4: 0xFFFD,
	0xF8D5: 0xFFFD,
	0xF8D6: 0xFFFD,
	0xF8D7: 0xFFFD,
	0xF8D8: 0xFFFD,
	0xF8D9: 0xFFFD,
	0xF8DA: 0xFFFD,
	0xF8DB: 0xFFFD,
	0xF8DC: 0xFFFD,
	0xF8DD: 0xFFFD,
	0xF8DE: 0xFFFD,
	0xF8DF: 0xFFFD,
	0xF8E0: 0xFFFD,
	0xF8E1: 0xFFFD,
	0xF8E2: 0xFFFD,
	0xF8E3: 0xFFFD,
	0xF8E4: 0xFFFD,
	0xF8E5: 0xFFFD,
	0xF8E6: 0xFFFD,
	0xF8E7: 0xFFFD,
	0xF8E8: 0xFFFD,
	0xF8E9: 0xFFFD,
	0xF8EA: 0xFFFD,
	0xF8EB: 0xFFFD,
	0xF8EC: 0xFFFD,
	0xF8ED: 0xFFFD,
	0xF8EE: 0xFFFD,
	0xF8EF: 0xFFFD,
	0xF8F0: 0xFFFD,
	0xF8F1: 0xFFFD,
	0xF8F2: 0xFFFD,
	0xF8F3: 0xFFFD,
	0xF8F4: 0xFFFD,
	0xF8F5: 0xFFFD,
	0xF8F6: 0xFFFD,
	0xF8F7: 0xFFFD,
	0xF8F8: 0x00FF,
	0xF8F9: 0xFFFD,
	0xF8FA: 0xFFFD,
	0xF8FB: 0xFFFD,
	0xF8FC: 0xFFFD,
	0xF8FD: 0xFFFD,
	0xF8FE: 0xFFFD,
	0xF8FF: 0xFFFD,
	0xF900: 0xB05A,
	0xF901: 0xA7F3,
	0xF902: 0xA8AE,
	0xF903: 0xB8EB,
	0xF904: 0xB7C6,
	0xF905: 0xA6EA,
	0xF906: 0xA579,
	0xF907: 0xC074,
	0xF908: 0xC074,
	0xF909: 0xABB4,
	0xF90A: 0xAAF7,
	0xF90B: 0xB3E2,
	0xF90C: 0xA960,
	0xF90D: 0xC369,
	0xF90E: 0xC4EE,
	0xF90F: 0xC3B9,
	0xF910: 0xC5DA,
	0xF911: 0xC1B3,
	0xF912: 0xBB72,
	0xF913: 0xC5DE,
	0xF914: 0xBCD6,
	0xF915: 0xACA5,
	0xF916: 0xAF4F,
	0xF917: 0xAF5F,
	0xF918: 0xB8A8,
	0xF919: 0xB954,
	0xF91A: 0xC064,
	0xF91B: 0xB6C3,
	0xF91C: 0xA75A,
	0xF91D: 0xC4E6,
	0xF91E: 0xC4EA,
	0xF91F: 0xC4F5,
	0xF920: 0xC67D,
	0xF921: 0xB450,
	0xF922: 0xC0DD,
	0xF923: 0xC2C5,
	0xF924: 0xC4B0,
	0xF925: 0xA9D4,
	0xF926: 0xC3BE,
	0xF927: 0xC4FA,
	0xF928: 0xB459,
	0xF929: 0xAED4,
	0xF92A: 0xAEF6,
	0xF92B: 0xAF54,
	0xF92C: 0xADA6,
	0xF92D: 0xA8D3,
	0xF92E: 0xA74E,
	0xF92F: 0xB3D2,
	0xF930: 0xBEDB,
	0xF931: 0xC372,
	0xF932: 0xC46C,
	0xF933: 0xBF63,
	0xF934: 0xA6D1,
	0xF935: 0xC4AA,
	0xF936: 0xB8B8,
	0xF937: 0xB8F4,
	0xF938: 0xC553,
	0xF939: 0xBE7C,
	0xF93A: 0xC64F,
	0xF93B: 0xB84C,
	0xF93C: 0xB853,
	0xF93D: 0xBAF1,
	0xF93E: 0xDB77,
	0xF93F: 0xBFFD,
	0xF940: 0xB3C0,
	0xF941: 0xBDD7,
	0xF942: 0xC362,
	0xF943: 0xA7CB,
	0xF944: 0xC5A2,
	0xF945: 0xC5A4,
	0xF946: 0xA863,
	0xF947: 0xBD55,
	0xF948: 0xB8EF,
	0xF949: 0xB970,
	0xF94A: 0xC253,
	0xF94B: 0xB9F0,
	0xF94C: 0xBCD3,
	0xF94D: 0xB25C,
	0xF94E: 0xBA7C,
	0xF94F: 0xB2D6,
	0xF950: 0xC15C,
	0xF951: 0xADAE,
	0xF952: 0xB0C7,
	0xF953: 0xA6D8,
	0xF954: 0xBBFE,
	0xF955: 0xADE2,
	0xF956: 0xB857,
	0xF957: 0xBAF0,
	0xF958: 0xB5D9,
	0xF959: 0xB3AE,
	0xF95A: 0xC5AA,
	0xF95B: 0xCED4,
	0xF95C: 0xBCD6,
	0xF95D: 0xBFD5,
	0xF95E: 0xA4A6,
	0xF95F: 0xB9E7,
	0xF960: 0xABE3,
	0xF961: 0xB276,
	0xF962: 0xB2A7,
	0xF963: 0xA55F,
	0xF964: 0xEDA8,
	0xF965: 0xAB4B,
	0xF966: 0xB45F,
	0xF967: 0xA4A3,
	0xF968: 0xAA63,
	0xF969: 0xBCC6,
	0xF96A: 0xAFC1,
	0xF96B: 0xB0D1,
	0xF96C: 0xB6EB,
	0xF96D: 0xACD9,
	0xF96E: 0xB8AD,
	0xF96F: 0xBBA1,
	0xF970: 0xB1FE,
	0xF971: 0xA8B0,
	0xF972: 0xA848,
	0xF973: 0xAC42,
	0xF974: 0xAD59,
	0xF975: 0xB1B0,
	0xF976: 0xB2A4,
	0xF977: 0xAB47,
	0xF978: 0xA8E2,
	0xF979: 0x845B,
	0xF97A: 0xB1E7,
	0xF97B: 0xC2B3,
	0xF97C: 0xA87D,
	0xF97D: 0xBDCC,
	0xF97E: 0xB671,
	0xF97F: 0xC079,
	0xF980: 0xA766,
	0xF981: 0xA46B,
	0xF982: 0xC366,
	0xF983: 0xAEC8,
	0xF984: 0xC26F,
	0xF985: 0xC472,
	0xF986: 0xBE5B,
	0xF987: 0xC67A,
	0xF988: 0xC452,
	0xF989: 0xBEA4,
	0xF98A: 0xA44F,
	0xF98B: 0xBEE4,
	0xF98C: 0xBEFA,
	0xF98D: 0xF765,
	0xF98E: 0xA67E,
	0xF98F: 0xBCA6,
	0xF990: 0xC5CA,
	0xF991: 0xBCBF,
	0xF992: 0xBAA7,
	0xF993: 0xB7D2,
	0xF994: 0xE6A3,
	0xF995: 0x9DCE,
	0xF996: 0xBD6D,
	0xF997: 0xC170,
	0xF998: 0xBDFB,
	0xF999: 0xBDAC,
	0xF99A: 0xB373,
	0xF99B: 0xC1E5,
	0xF99C: 0xA643,
	0xF99D: 0xA648,
	0xF99E: 0xAB7C,
	0xF99F: 0xAF50,
	0xF9A0: 0xB5F5,
	0xF9A1: 0xBBA1,
	0xF9A2: 0xB747,
	0xF9A3: 0xA9C0,
	0xF9A4: 0xB1C9,
	0xF9A5: 0xC0D4,
	0xF9A6: 0xC3AE,
	0xF9A7: 0xC279,
	0xF9A8: 0xA54F,
	0xF9A9: 0xCBF1,
	0xF9AA: 0xB9E7,
	0xF9AB: 0xC0AD,
	0xF9AC: 0xCCB0,
	0xF9AD: 0xACC2,
	0xF9AE: 0xBCFC,
	0xF9AF: 0xB2DC,
	0xF9B0: 0xB2E2,
	0xF9B1: 0xB961,
	0xF9B2: 0xB973,
	0xF9B3: 0xC646,
	0xF9B4: 0xBBE2,
	0xF9B5: 0xA8D2,
	0xF9B6: 0xC2A7,
	0xF9B7: 0xC4BF,
	0xF9B8: 0xC1F5,
	0xF9B9: 0xB463,
	0xF9BA: 0xA446,
	0xF9BB: 0xB9B1,
	0xF9BC: 0xBC64,
	0xF9BD: 0xA7BF,
	0xF9BE: 0xAEC6,
	0xF9BF: 0xBCD6,
	0xF9C0: 0xBF52,
	0xF9C1: 0xC0F8,
	0xF9C2: 0xE764,
	0xF9C3: 0xBFF1,
	0xF9C4: 0xC073,
	0xF9C5: 0xB777,
	0xF9C6: 0xA8BF,
	0xF9C7: 0xBC42,
	0xF9C8: 0xCCD8,
	0xF9C9: 0xAC68,
	0xF9CA: 0xAC79,
	0xF9CB: 0xB7C8,
	0xF9CC: 0xAF5B,
	0xF9CD: 0xAF64,
	0xF9CE: 0xB2B8,
	0xF9CF: 0xAFC3,
	0xF9D0: 0xC3FE,
	0xF9D1: 0xA4BB,
	0xF9D2: 0xBCAE,
	0xF9D3: 0xB3B0,
	0xF9D4: 0xADDB,
	0xF9D5: 0xB15B,
	0xF9D6: 0xB25F,
	0xF9D7: 0xBDFC,
	0xF9D8: 0xABDF,
	0xF9D9: 0xB758,
	0xF9DA: 0xAEDF,
	0xF9DB: 0xB276,
	0xF9DC: 0xB6A9,
	0xF9DD: 0xA751,
	0xF9DE: 0xA64F,
	0xF9DF: 0xBC69,
	0xF9E0: 0xA9F6,
	0xF9E1: 0xA7F5,
	0xF9E2: 0xB1F9,
	0xF9E3: 0xAA64,
	0xF9E4: 0xB27A,
	0xF9E5: 0xB567,
	0xF9E6: 0xBFA9,
	0xF9E7: 0xF9D8,
	0xF9E8: 0xB8CC,
	0xF9E9: 0xA8BD,
	0xF9EA: 0xC2F7,
	0xF9EB: 0xB0CE,
	0xF9EC: 0xB7C4,
	0xF9ED: 0xA75B,
	0xF9EE: 0xBF4D,
	0xF9EF: 0xBF5A,
	0xF9F0: 0xC4A9,
	0xF9F1: 0x95F9,
	0xF9F2: 0xC5EC,
	0xF9F3: 0xC5EF,
	0xF9F4: 0xAA4C,
	0xF9F5: 0xB24F,
	0xF9F6: 0xC17B,
	0xF9F7: 0xA5DF,
	0xF9F8: 0xB2C1,
	0xF9F9: 0xB2C9,
	0xF9FA: 0xAAAC,
	0xF9FB: 0xAAA5,
	0xF9FC: 0xC3D1,
	0xF9FD: 0xA4B0,
	0xF9FE: 0xAFF9,
	0xF9FF: 0xA8EB,
	0xFA00: 0xA4C1,
	0xFA01: 0xABD7,
	0xFA02: 0xA9DD,
	0xFA03: 0xBF7D,
	0xFA04: 0xA676,
	0xFA05: 0xAC7D,
	0xFA06: 0xBCC9,
	0xFA07: 0xBFE7,
	0xFA08: 0xA6E6,
	0xFA09: 0xADB0,
	0xFA0A: 0xA8A3,
	0xFA0B: 0xB9F8,
	0xFA0C: 0xC94A,
	0xFA0D: 0xDDFC,
	0xFA0E: 0x9877,
	0xFA0F: 0x9878,
	0xFA10: 0xB6EF,
	0xFA11: 0x9879,
	0xFA12: 0xB4B8,
	0xFA13: 0x987A,
	0xFA14: 0x987B,
	0xFA15: 0xE8F9,
	0xFA16: 0x95BD,
	0xFA17: 0xAF71,
	0xFA18: 0x987C,
	0xFA19: 0xAFAB,
	0xFA1A: 0xB2BB,
	0xFA1B: 0xBAD6,
	0xFA1C: 0xB974,
	0xFA1D: 0xBAEB,
	0xFA1E: 0xA6D0,
	0xFA1F: 0x987D,
	0xFA20: 0x987E,
	0xFA21: 0x98A1,
	0xFA22: 0xBDD1,
	0xFA23: 0x98A2,
	0xFA24: 0x98A3,
	0xFA25: 0xB668,
	0xFA26: 0xB3A3,
	0xFA27: 0x98A4,
	0xFA28: 0x98A5,
	0xFA29: 0x98A6,
	0xFA2A: 0xB6BA,
	0xFA2B: 0xB97D,
	0xFA2C: 0xC05D,
	0xFA2D: 0xC562,
	0xFA2E: 0xFFFD,
	0xFA2F: 0xFFFD,
	0xFA30: 0xAB56,
	0xFA31: 0xB9AC,
	0xFA32: 0xA74B,
	0xFA33: 0xAB6A,
	0xFA34: 0xB6D4,
	0xFA35: 0xA8F5,
	0xFA36: 0xB3DC,
	0xFA37: 0xB9C4,
	0xFA38: 0xBEB9,
	0xFA39: 0x9459,
	0xFA3A: 0xBEA5,
	0xFA3B: 0xBC68,
	0xFA3C: 0xC94B,
	0xFA3D: 0xAEAC,
	0xFA3E: 0xB46E,
	0xFA3F: 0xBCA8,
	0xFA40: 0xC367,
	0xFA41: 0xB1D3,
	0xFA42: 0xAC4A,
	0xFA43: 0xB4BB,
	0xFA44: 0xB1F6,
	0xFA45: 0xAEFC,
	0xFA46: 0xB25A,
	0xFA47: 0xBA7E,
	0xFA48: 0xB54E,
	0xFA49: 0x9C70,
	0xFA4A: 0xB55A,
	0xFA4B: 0xB84F,
	0xFA4C: 0xAAC0,
	0xFA4D: 0xACE7,
	0xFA4E: 0xACE8,
	0xFA4F: 0xAFA7,
	0xFA50: 0xAFAA,
	0xFA51: 0xAFAC,
	0xFA52: 0xBAD7,
	0xFA53: 0xBAD5,
	0xFA54: 0xBD5C,
	0xFA55: 0xACF0,
	0xFA56: 0xB860,
	0xFA57: 0xBD6D,
	0xFA58: 0xBFA7,
	0xFA59: 0xC163,
	0xFA5A: 0xB870,
	0xFA5B: 0xAACC,
	0xFA5C: 0xAFE4,
	0xFA5D: 0x9CD2,
	0xFA5E: 0x9CD2,
	0xFA5F: 0xB5DB,
	0xFA60: 0xBDC5,
	0xFA61: 0xB5F8,
	0xFA62: 0xBFD6,
	0xFA63: 0xC2D4,
	0xFA64: 0xBBAB,
	0xFA65: 0xC3D8,
	0xFA66: 0x9CE0,
	0xFA67: 0xB668,
	0xFA68: 0xC3F8,
	0xFA69: 0xC554,
	0xFA6A: 0xC057,
	0xFA6B: 0xFFFD,
	0xFA6C: 0xFFFD,
	0xFA6D: 0xFFFD,
	0xFA6E: 0xFFFD,
	0xFA6F: 0xFFFD,
	0xFA70: 0xFFFD,
	0xFA71: 0xFFFD,
	0xFA72: 0xFFFD,
	0xFA73: 0xFFFD,
	0xFA74: 0xFFFD,
	0xFA75: 0xFFFD,
	0xFA76: 0xFFFD,
	0xFA77: 0xFFFD,
	0xFA78: 0xFFFD,
	0xFA79: 0xFFFD,
	0xFA7A: 0xFFFD,
	0xFA7B: 0xFFFD,
	0xFA7C: 0xFFFD,
	0xFA7D: 0xFFFD,
	0xFA7E: 0xFFFD,
	0xFA7F: 0xFFFD,
	0xFA80: 0xFFFD,
	0xFA81: 0xFFFD,
	0xFA82: 0xFFFD,
	0xFA83: 0xFFFD,
	0xFA84: 0xFFFD,
	0xFA85: 0xFFFD,
	0xFA86: 0xFFFD,
	0xFA87: 0xFFFD,
	0xFA88: 0xFFFD,
	0xFA89: 0xFFFD,
	0xFA8A: 0xFFFD,
	0xFA8B: 0xFFFD,
	0xFA8C: 0xFFFD,
	0xFA8D: 0xFFFD,
	0xFA8E: 0xFFFD,
	0xFA8F: 0xFFFD,
	0xFA90: 0xFFFD,
	0xFA91: 0xFFFD,
	0xFA92: 0xFFFD,
	0xFA93: 0xFFFD,
	0xFA94: 0xFFFD,
	0xFA95: 0xFFFD,
	0xFA96: 0xFFFD,
	0xFA97: 0xFFFD,
	0xFA98: 0xFFFD,
	0xFA99: 0xFFFD,
	0xFA9A: 0xFFFD,
	0xFA9B: 0xFFFD,
	0xFA9C: 0xFFFD,
	0xFA9D: 0xFFFD,
	0xFA9E: 0xFFFD,
	0xFA9F: 0xFFFD,
	0xFAA0: 0xFFFD,
	0xFAA1: 0xFFFD,
	0xFAA2: 0xFFFD,
	0xFAA3: 0xFFFD,
	0xFAA4: 0xFFFD,
	0xFAA5: 0xFFFD,
	0xFAA6: 0xFFFD,
	0xFAA7: 0xFFFD,
	0xFAA8: 0xFFFD,
	0xFAA9: 0xFFFD,
	0xFAAA: 0xFFFD,
	0xFAAB: 0xFFFD,
	0xFAAC: 0xFFFD,
	0xFAAD: 0xFFFD,
	0xFAAE: 0xFFFD,
	0xFAAF: 0xFFFD,
	0xFAB0: 0xFFFD,
	0xFAB1: 0xFFFD,
	0xFAB2: 0xFFFD,
	0xFAB3: 0xFFFD,
	0xFAB4: 0xFFFD,
	0xFAB5: 0xFFFD,
	0xFAB6: 0xFFFD,
	0xFAB7: 0xFFFD,
	0xFAB8: 0xFFFD,
	0xFAB9: 0xFFFD,
	0xFABA: 0xFFFD,
	0xFABB: 0xFFFD,
	0xFABC: 0xFFFD,
	0xFABD: 0xFFFD,
	0xFABE: 0xFFFD,
	0xFABF: 0xFFFD,
	0xFAC0: 0xFFFD,
	0xFAC1: 0xFFFD,
	0xFAC2: 0xFFFD,
	0xFAC3: 0xFFFD,
	0xFAC4: 0xFFFD,
	0xFAC5: 0xFFFD,
	0xFAC6: 0xFFFD,
	0xFAC7: 0xFFFD,
	0xFAC8: 0xFFFD,
	0xFAC9: 0xFFFD,
	0xFACA: 0xFFFD,
	0xFACB: 0xFFFD,
	0xFACC: 0xFFFD,
	0xFACD: 0xFFFD,
	0xFACE: 0xFFFD,
	0xFACF: 0xFFFD,
	0xFAD0: 0xFFFD,
	0xFAD1: 0xFFFD,
	0xFAD2: 0xFFFD,
	0xFAD3: 0xFFFD,
	0xFAD4: 0xFFFD,
	0xFAD5: 0xFFFD,
	0xFAD6: 0xFFFD,
	0xFAD7: 0xFFFD,
	0xFAD8: 0xFFFD,
	0xFAD9: 0xFFFD,
	0xFADA: 0xFFFD,
	0xFADB: 0xFFFD,
	0xFADC: 0xFFFD,
	0xFADD: 0xFFFD,
	0xFADE: 0xFFFD,
	0xFADF: 0xFFFD,
	0xFAE0: 0xFFFD,
	0xFAE1: 0xFFFD,
	0xFAE2: 0xFFFD,
	0xFAE3: 0xFFFD,
	0xFAE4: 0xFFFD,
	0xFAE5: 0xFFFD,
	0xFAE6: 0xFFFD,
	0xFAE7: 0xFFFD,
	0xFAE8: 0xFFFD,
	0xFAE9: 0xFFFD,
	0xFAEA: 0xFFFD,
	0xFAEB: 0xFFFD,
	0xFAEC: 0xFFFD,
	0xFAED: 0xFFFD,
	0xFAEE: 0xFFFD,
	0xFAEF: 0xFFFD,
	0xFAF0: 0xFFFD,
	0xFAF1: 0xFFFD,
	0xFAF2: 0xFFFD,
	0xFAF3: 0xFFFD,
	0xFAF4: 0xFFFD,
	0xFAF5: 0xFFFD,
	0xFAF6: 0xFFFD,
	0xFAF7: 0xFFFD,
	0xFAF8: 0xFFFD,
	0xFAF9: 0xFFFD,
	0xFAFA: 0xFFFD,
	0xFAFB: 0xFFFD,
	0xFAFC: 0xFFFD,
	0xFAFD: 0xFFFD,
	0xFAFE: 0xFFFD,
	0xFAFF: 0xFFFD,
	0xFB00: 0xFFFD,
	0xFB01: 0xFFFD,
	0xFB02: 0xFFFD,
	0xFB03: 0xFFFD,
	0xFB04: 0xFFFD,
	0xFB05: 0xFFFD,
	0xFB06: 0xFFFD,
	0xFB07: 0xFFFD,
	0xFB08: 0xFFFD,
	0xFB09: 0xFFFD,
	0xFB0A: 0xFFFD,
	0xFB0B: 0xFFFD,
	0xFB0C: 0xFFFD,
	0xFB0D: 0xFFFD,
	0xFB0E: 0xFFFD,
	0xFB0F: 0xFFFD,
	0xFB10: 0xFFFD,
	0xFB11: 0xFFFD,
	0xFB12: 0xFFFD,
	0xFB13: 0xFFFD,
	0xFB14: 0xFFFD,
	0xFB15: 0xFFFD,
	0xFB16: 0xFFFD,
	0xFB17: 0xFFFD,
	0xFB18: 0xFFFD,
	0xFB19: 0xFFFD,
	0xFB1A: 0xFFFD,
	0xFB1B: 0xFFFD,
	0xFB1C: 0xFFFD,
	0xFB1D: 0xFFFD,
	0xFB1E: 0xFFFD,
	0xFB1F: 0xFFFD,
	0xFB20: 0xFFFD,
	0xFB21: 0xFFFD,
	0xFB22: 0xFFFD,
	0xFB23: 0xFFFD,
	0xFB24: 0xFFFD,
	0xFB25: 0xFFFD,
	0xFB26: 0xFFFD,
	0xFB27: 0xFFFD,
	0xFB28: 0xFFFD,
	0xFB29: 0xFFFD,
	0xFB2A: 0xFFFD,
	0xFB2B: 0xFFFD,
	0xFB2C: 0xFFFD,
	0xFB2D: 0xFFFD,
	0xFB2E: 0xFFFD,
	0xFB2F: 0xFFFD,
	0xFB30: 0xFFFD,
	0xFB31: 0xFFFD,
	0xFB32: 0xFFFD,
	0xFB33: 0xFFFD,
	0xFB34: 0xFFFD,
	0xFB35: 0xFFFD,
	0xFB36: 0xFFFD,
	0xFB37: 0xFFFD,
	0xFB38: 0xFFFD,
	0xFB39: 0xFFFD,
	0xFB3A: 0xFFFD,
	0xFB3B: 0xFFFD,
	0xFB3C: 0xFFFD,
	0xFB3D: 0xFFFD,
	0xFB3E: 0xFFFD,
	0xFB3F: 0xFFFD,
	0xFB40: 0xFFFD,
	0xFB41: 0xFFFD,
	0xFB42: 0xFFFD,
	0xFB43: 0xFFFD,
	0xFB44: 0xFFFD,
	0xFB45: 0xFFFD,
	0xFB46: 0xFFFD,
	0xFB47: 0xFFFD,
	0xFB48: 0xFFFD,
	0xFB49: 0xFFFD,
	0xFB4A: 0xFFFD,
	0xFB4B: 0xFFFD,
	0xFB4C: 0xFFFD,
	0xFB4D: 0xFFFD,
	0xFB4E: 0xFFFD,
	0xFB4F: 0xFFFD,
	0xFB50: 0xFFFD,
	0xFB51: 0xFFFD,
	0xFB52: 0xFFFD,
	0xFB53: 0xFFFD,
	0xFB54: 0xFFFD,
	0xFB55: 0xFFFD,
	0xFB56: 0xFFFD,
	0xFB57: 0xFFFD,
	0xFB58: 0xFFFD,
	0xFB59: 0xFFFD,
	0xFB5A: 0xFFFD,
	0xFB5B: 0xFFFD,
	0xFB5C: 0xFFFD,
	0xFB5D: 0xFFFD,
	0xFB5E: 0xFFFD,
	0xFB5F: 0xFFFD,
	0xFB60: 0xFFFD,
	0xFB61: 0xFFFD,
	0xFB62: 0xFFFD,
	0xFB63: 0xFFFD,
	0xFB64: 0xFFFD,
	0xFB65: 0xFFFD,
	0xFB66: 0xFFFD,
	0xFB67: 0xFFFD,
	0xFB68: 0xFFFD,
	0xFB69: 0xFFFD,
	0xFB6A: 0xFFFD,
	0xFB6B: 0xFFFD,
	0xFB6C: 0xFFFD,
	0xFB6D: 0xFFFD,
	0xFB6E: 0xFFFD,
	0xFB6F: 0xFFFD,
	0xFB70: 0xFFFD,
	0xFB71: 0xFFFD,
	0xFB72: 0xFFFD,
	0xFB73: 0xFFFD,
	0xFB74: 0xFFFD,
	0xFB75: 0xFFFD,
	0xFB76: 0xFFFD,
	0xFB77: 0xFFFD,
	0xFB78: 0xFFFD,
	0xFB79: 0xFFFD,
	0xFB7A: 0xFFFD,
	0xFB7B: 0xFFFD,
	0xFB7C: 0xFFFD,
	0xFB7D: 0xFFFD,
	0xFB7E: 0xFFFD,
	0xFB7F: 0xFFFD,
	0xFB80: 0xFFFD,
	0xFB81: 0xFFFD,
	0xFB82: 0xFFFD,
	0xFB83: 0xFFFD,
	0xFB84: 0xFFFD,
	0xFB85: 0xFFFD,
	0xFB86: 0xFFFD,
	0xFB87: 0xFFFD,
	0xFB88: 0xFFFD,
	0xFB89: 0xFFFD,
	0xFB8A: 0xFFFD,
	0xFB8B: 0xFFFD,
	0xFB8C: 0xFFFD,
	0xFB8D: 0xFFFD,
	0xFB8E: 0xFFFD,
	0xFB8F: 0xFFFD,
	0xFB90: 0xFFFD,
	0xFB91: 0xFFFD,
	0xFB92: 0xFFFD,
	0xFB93: 0xFFFD,
	0xFB94: 0xFFFD,
	0xFB95: 0xFFFD,
	0xFB96: 0xFFFD,
	0xFB97: 0xFFFD,
	0xFB98: 0xFFFD,
	0xFB99: 0xFFFD,
	0xFB9A: 0xFFFD,
	0xFB9B: 0xFFFD,
	0xFB9C: 0xFFFD,
	0xFB9D: 0xFFFD,
	0xFB9E: 0xFFFD,
	0xFB9F: 0xFFFD,
	0xFBA0: 0xFFFD,
	0xFBA1: 0xFFFD,
	0xFBA2: 0xFFFD,
	0xFBA3: 0xFFFD,
	0xFBA4: 0xFFFD,
	0xFBA5: 0xFFFD,
	0xFBA6: 0xFFFD,
	0xFBA7: 0xFFFD,
	0xFBA8: 0xFFFD,
	0xFBA9: 0xFFFD,
	0xFBAA: 0xFFFD,
	0xFBAB: 0xFFFD,
	0xFBAC: 0xFFFD,
	0xFBAD: 0xFFFD,
	0xFBAE: 0xFFFD,
	0xFBAF: 0xFFFD,
	0xFBB0: 0xFFFD,
	0xFBB1: 0xFFFD,
	0xFBB2: 0xFFFD,
	0xFBB3: 0xFFFD,
	0xFBB4: 0xFFFD,
	0xFBB5: 0xFFFD,
	0xFBB6: 0xFFFD,
	0xFBB7: 0xFFFD,
	0xFBB8: 0xFFFD,
	0xFBB9: 0xFFFD,
	0xFBBA: 0xFFFD,
	0xFBBB: 0xFFFD,
	0xFBBC: 0xFFFD,
	0xFBBD: 0xFFFD,
	0xFBBE: 0xFFFD,
	0xFBBF: 0xFFFD,
	0xFBC0: 0xFFFD,
	0xFBC1: 0xFFFD,
	0xFBC2: 0xFFFD,
	0xFBC3: 0xFFFD,
	0xFBC4: 0xFFFD,
	0xFBC5: 0xFFFD,
	0xFBC6: 0xFFFD,
	0xFBC7: 0xFFFD,
	0xFBC8: 0xFFFD,
	0xFBC9: 0xFFFD,
	0xFBCA: 0xFFFD,
	0xFBCB: 0xFFFD,
	0xFBCC: 0xFFFD,
	0xFBCD: 0xFFFD,
	0xFBCE: 0xFFFD,
	0xFBCF: 0xFFFD,
	0xFBD0: 0xFFFD,
	0xFBD1: 0xFFFD,
	0xFBD2: 0xFFFD,
	0xFBD3: 0xFFFD,
	0xFBD4: 0xFFFD,
	0xFBD5: 0xFFFD,
	0xFBD6: 0xFFFD,
	0xFBD7: 0xFFFD,
	0xFBD8: 0xFFFD,
	0xFBD9: 0xFFFD,
	0xFBDA: 0xFFFD,
	0xFBDB: 0xFFFD,
	0xFBDC: 0xFFFD,
	0xFBDD: 0xFFFD,
	0xFBDE: 0xFFFD,
	0xFBDF: 0xFFFD,
	0xFBE0: 0xFFFD,
	0xFBE1: 0xFFFD,
	0xFBE2: 0xFFFD,
	0xFBE3: 0xFFFD,
	0xFBE4: 0xFFFD,
	0xFBE5: 0xFFFD,
	0xFBE6: 0xFFFD,
	0xFBE7: 0xFFFD,
	0xFBE8: 0xFFFD,
	0xFBE9: 0xFFFD,
	0xFBEA: 0xFFFD,
	0xFBEB: 0xFFFD,
	0xFBEC: 0xFFFD,
	0xFBED: 0xFFFD,
	0xFBEE: 0xFFFD,
	0xFBEF: 0xFFFD,
	0xFBF0: 0xFFFD,
	0xFBF1: 0xFFFD,
	0xFBF2: 0xFFFD,
	0xFBF3: 0xFFFD,
	0xFBF4: 0xFFFD,
	0xFBF5: 0xFFFD,
	0xFBF6: 0xFFFD,
	0xFBF7: 0xFFFD,
	0xFBF8: 0xFFFD,
	0xFBF9: 0xFFFD,
	0xFBFA: 0xFFFD,
	0xFBFB: 0xFFFD,
	0xFBFC: 0xFFFD,
	0xFBFD: 0xFFFD,
	0xFBFE: 0xFFFD,
	0xFBFF: 0xFFFD,
	0xFC00: 0xFFFD,
	0xFC01: 0xFFFD,
	0xFC02: 0xFFFD,
	0xFC03: 0xFFFD,
	0xFC04: 0xFFFD,
	0xFC05: 0xFFFD,
	0xFC06: 0xFFFD,
	0xFC07: 0xFFFD,
	0xFC08: 0xFFFD,
	0xFC09: 0xFFFD,
	0xFC0A: 0xFFFD,
	0xFC0B: 0xFFFD,
	0xFC0C: 0xFFFD,
	0xFC0D: 0xFFFD,
	0xFC0E: 0xFFFD,
	0xFC0F: 0xFFFD,
	0xFC10: 0xFFFD,
	0xFC11: 0xFFFD,
	0xFC12: 0xFFFD,
	0xFC13: 0xFFFD,
	0xFC14: 0xFFFD,
	0xFC15: 0xFFFD,
	0xFC16: 0xFFFD,
	0xFC17: 0xFFFD,
	0xFC18: 0xFFFD,
	0xFC19: 0xFFFD,
	0xFC1A: 0xFFFD,
	0xFC1B: 0xFFFD,
	0xFC1C: 0xFFFD,
	0xFC1D: 0xFFFD,
	0xFC1E: 0xFFFD,
	0xFC1F: 0xFFFD,
	0xFC20: 0xFFFD,
	0xFC21: 0xFFFD,
	0xFC22: 0xFFFD,
	0xFC23: 0xFFFD,
	0xFC24: 0xFFFD,
	0xFC25: 0xFFFD,
	0xFC26: 0xFFFD,
	0xFC27: 0xFFFD,
	0xFC28: 0xFFFD,
	0xFC29: 0xFFFD,
	0xFC2A: 0xFFFD,
	0xFC2B: 0xFFFD,
	0xFC2C: 0xFFFD,
	0xFC2D: 0xFFFD,
	0xFC2E: 0xFFFD,
	0xFC2F: 0xFFFD,
	0xFC30: 0xFFFD,
	0xFC31: 0xFFFD,
	0xFC32: 0xFFFD,
	0xFC33: 0xFFFD,
	0xFC34: 0xFFFD,
	0xFC35: 0xFFFD,
	0xFC36: 0xFFFD,
	0xFC37: 0xFFFD,
	0xFC38: 0xFFFD,
	0xFC39: 0xFFFD,
	0xFC3A: 0xFFFD,
	0xFC3B: 0xFFFD,
	0xFC3C: 0xFFFD,
	0xFC3D: 0xFFFD,
	0xFC3E: 0xFFFD,
	0xFC3F: 0xFFFD,
	0xFC40: 0xFFFD,
	0xFC41: 0xFFFD,
	0xFC42: 0xFFFD,
	0xFC43: 0xFFFD,
	0xFC44: 0xFFFD,
	0xFC45: 0xFFFD,
	0xFC46: 0xFFFD,
	0xFC47: 0xFFFD,
	0xFC48: 0xFFFD,
	0xFC49: 0xFFFD,
	0xFC4A: 0xFFFD,
	0xFC4B: 0xFFFD,
	0xFC4C: 0xFFFD,
	0xFC4D: 0xFFFD,
	0xFC4E: 0xFFFD,
	0xFC4F: 0xFFFD,
	0xFC50: 0xFFFD,
	0xFC51: 0xFFFD,
	0xFC52: 0xFFFD,
	0xFC53: 0xFFFD,
	0xFC54: 0xFFFD,
	0xFC55: 0xFFFD,
	0xFC56: 0xFFFD,
	0xFC57: 0xFFFD,
	0xFC58: 0xFFFD,
	0xFC59: 0xFFFD,
	0xFC5A: 0xFFFD,
	0xFC5B: 0xFFFD,
	0xFC5C: 0xFFFD,
	0xFC5D: 0xFFFD,
	0xFC5E: 0xFFFD,
	0xFC5F: 0xFFFD,
	0xFC60: 0xFFFD,
	0xFC61: 0xFFFD,
	0xFC62: 0xFFFD,
	0xFC63: 0xFFFD,
	0xFC64: 0xFFFD,
	0xFC65: 0xFFFD,
	0xFC66: 0xFFFD,
	0xFC67: 0xFFFD,
	0xFC68: 0xFFFD,
	0xFC69: 0xFFFD,
	0xFC6A: 0xFFFD,
	0xFC6B: 0xFFFD,
	0xFC6C: 0xFFFD,
	0xFC6D: 0xFFFD,
	0xFC6E: 0xFFFD,
	0xFC6F: 0xFFFD,
	0xFC70: 0xFFFD,
	0xFC71: 0xFFFD,
	0xFC72: 0xFFFD,
	0xFC73: 0xFFFD,
	0xFC74: 0xFFFD,
	0xFC75: 0xFFFD,
	0xFC76: 0xFFFD,
	0xFC77: 0xFFFD,
	0xFC78: 0xFFFD,
	0xFC79: 0xFFFD,
	0xFC7A: 0xFFFD,
	0xFC7B: 0xFFFD,
	0xFC7C: 0xFFFD,
	0xFC7D: 0xFFFD,
	0xFC7E: 0xFFFD,
	0xFC7F: 0xFFFD,
	0xFC80: 0xFFFD,
	0xFC81: 0xFFFD,
	0xFC82: 0xFFFD,
	0xFC83: 0xFFFD,
	0xFC84: 0xFFFD,
	0xFC85: 0xFFFD,
	0xFC86: 0xFFFD,
	0xFC87: 0xFFFD,
	0xFC88: 0xFFFD,
	0xFC89: 0xFFFD,
	0xFC8A: 0xFFFD,
	0xFC8B: 0xFFFD,
	0xFC8C: 0xFFFD,
	0xFC8D: 0xFFFD,
	0xFC8E: 0xFFFD,
	0xFC8F: 0xFFFD,
	0xFC90: 0xFFFD,
	0xFC91: 0xFFFD,
	0xFC92: 0xFFFD,
	0xFC93: 0xFFFD,
	0xFC94: 0xFFFD,
	0xFC95: 0xFFFD,
	0xFC96: 0xFFFD,
	0xFC97: 0xFFFD,
	0xFC98: 0xFFFD,
	0xFC99: 0xFFFD,
	0xFC9A: 0xFFFD,
	0xFC9B: 0xFFFD,
	0xFC9C: 0xFFFD,
	0xFC9D: 0xFFFD,
	0xFC9E: 0xFFFD,
	0xFC9F: 0xFFFD,
	0xFCA0: 0xFFFD,
	0xFCA1: 0xFFFD,
	0xFCA2: 0xFFFD,
	0xFCA3: 0xFFFD,
	0xFCA4: 0xFFFD,
	0xFCA5: 0xFFFD,
	0xFCA6: 0xFFFD,
	0xFCA7: 0xFFFD,
	0xFCA8: 0xFFFD,
	0xFCA9: 0xFFFD,
	0xFCAA: 0xFFFD,
	0xFCAB: 0xFFFD,
	0xFCAC: 0xFFFD,
	0xFCAD: 0xFFFD,
	0xFCAE: 0xFFFD,
	0xFCAF: 0xFFFD,
	0xFCB0: 0xFFFD,
	0xFCB1: 0xFFFD,
	0xFCB2: 0xFFFD,
	0xFCB3: 0xFFFD,
	0xFCB4: 0xFFFD,
	0xFCB5: 0xFFFD,
	0xFCB6: 0xFFFD,
	0xFCB7: 0xFFFD,
	0xFCB8: 0xFFFD,
	0xFCB9: 0xFFFD,
	0xFCBA: 0xFFFD,
	0xFCBB: 0xFFFD,
	0xFCBC: 0xFFFD,
	0xFCBD: 0xFFFD,
	0xFCBE: 0xFFFD,
	0xFCBF: 0xFFFD,
	0xFCC0: 0xFFFD,
	0xFCC1: 0xFFFD,
	0xFCC2: 0xFFFD,
	0xFCC3: 0xFFFD,
	0xFCC4: 0xFFFD,
	0xFCC5: 0xFFFD,
	0xFCC6: 0xFFFD,
	0xFCC7: 0xFFFD,
	0xFCC8: 0xFFFD,
	0xFCC9: 0xFFFD,
	0xFCCA: 0xFFFD,
	0xFCCB: 0xFFFD,
	0xFCCC: 0xFFFD,
	0xFCCD: 0xFFFD,
	0xFCCE: 0xFFFD,
	0xFCCF: 0xFFFD,
	0xFCD0: 0xFFFD,
	0xFCD1: 0xFFFD,
	0xFCD2: 0xFFFD,
	0xFCD3: 0xFFFD,
	0xFCD4: 0xFFFD,
	0xFCD5: 0xFFFD,
	0xFCD6: 0xFFFD,
	0xFCD7: 0xFFFD,
	0xFCD8: 0xFFFD,
	0xFCD9: 0xFFFD,
	0xFCDA: 0xFFFD,
	0xFCDB: 0xFFFD,
	0xFCDC: 0xFFFD,
	0xFCDD: 0xFFFD,
	0xFCDE: 0xFFFD,
	0xFCDF: 0xFFFD,
	0xFCE0: 0xFFFD,
	0xFCE1: 0xFFFD,
	0xFCE2: 0xFFFD,
	0xFCE3: 0xFFFD,
	0xFCE4: 0xFFFD,
	0xFCE5: 0xFFFD,
	0xFCE6: 0xFFFD,
	0xFCE7: 0xFFFD,
	0xFCE8: 0xFFFD,
	0xFCE9: 0xFFFD,
	0xFCEA: 0xFFFD,
	0xFCEB: 0xFFFD,
	0xFCEC: 0xFFFD,
	0xFCED: 0xFFFD,
	0xFCEE: 0xFFFD,
	0xFCEF: 0xFFFD,
	0xFCF0: 0xFFFD,
	0xFCF1: 0xFFFD,
	0xFCF2: 0xFFFD,
	0xFCF3: 0xFFFD,
	0xFCF4: 0xFFFD,
	0xFCF5: 0xFFFD,
	0xFCF6: 0xFFFD,
	0xFCF7: 0xFFFD,
	0xFCF8: 0xFFFD,
	0xFCF9: 0xFFFD,
	0xFCFA: 0xFFFD,
	0xFCFB: 0xFFFD,
	0xFCFC: 0xFFFD,
	0xFCFD: 0xFFFD,
	0xFCFE: 0xFFFD,
	0xFCFF: 0xFFFD,
	0xFD00: 0xFFFD,
	0xFD01: 0xFFFD,
	0xFD02: 0xFFFD,
	0xFD03: 0xFFFD,
	0xFD04: 0xFFFD,
	0xFD05: 0xFFFD,
	0xFD06: 0xFFFD,
	0xFD07: 0xFFFD,
	0xFD08: 0xFFFD,
	0xFD09: 0xFFFD,
	0xFD0A: 0xFFFD,
	0xFD0B: 0xFFFD,
	0xFD0C: 0xFFFD,
	0xFD0D: 0xFFFD,
	0xFD0E: 0xFFFD,
	0xFD0F: 0xFFFD,
	0xFD10: 0xFFFD,
	0xFD11: 0xFFFD,
	0xFD12: 0xFFFD,
	0xFD13: 0xFFFD,
	0xFD14: 0xFFFD,
	0xFD15: 0xFFFD,
	0xFD16: 0xFFFD,
	0xFD17: 0xFFFD,
	0xFD18: 0xFFFD,
	0xFD19: 0xFFFD,
	0xFD1A: 0xFFFD,
	0xFD1B: 0xFFFD,
	0xFD1C: 0xFFFD,
	0xFD1D: 0xFFFD,
	0xFD1E: 0xFFFD,
	0xFD1F: 0xFFFD,
	0xFD20: 0xFFFD,
	0xFD21: 0xFFFD,
	0xFD22: 0xFFFD,
	0xFD23: 0xFFFD,
	0xFD24: 0xFFFD,
	0xFD25: 0xFFFD,
	0xFD26: 0xFFFD,
	0xFD27: 0xFFFD,
	0xFD28: 0xFFFD,
	0xFD29: 0xFFFD,
	0xFD2A: 0xFFFD,
	0xFD2B: 0xFFFD,
	0xFD2C: 0xFFFD,
	0xFD2D: 0xFFFD,
	0xFD2E: 0xFFFD,
	0xFD2F: 0xFFFD,
	0xFD30: 0xFFFD,
	0xFD31: 0xFFFD,
	0xFD32: 0xFFFD,
	0xFD33: 0xFFFD,
	0xFD34: 0xFFFD,
	0xFD35: 0xFFFD,
	0xFD36: 0xFFFD,
	0xFD37: 0xFFFD,
	0xFD38: 0xFFFD,
	0xFD39: 0xFFFD,
	0xFD3A: 0xFFFD,
	0xFD3B: 0xFFFD,
	0xFD3C: 0xFFFD,
	0xFD3D: 0xFFFD,
	0xFD3E: 0xFFFD,
	0xFD3F: 0xFFFD,
	0xFD40: 0xFFFD,
	0xFD41: 0xFFFD,
	0xFD42: 0xFFFD,
	0xFD43: 0xFFFD,
	0xFD44: 0xFFFD,
	0xFD45: 0xFFFD,
	0xFD46: 0xFFFD,
	0xFD47: 0xFFFD,
	0xFD48: 0xFFFD,
	0xFD49: 0xFFFD,
	0xFD4A: 0xFFFD,
	0xFD4B: 0xFFFD,
	0xFD4C: 0xFFFD,
	0xFD4D: 0xFFFD,
	0xFD4E: 0xFFFD,
	0xFD4F: 0xFFFD,
	0xFD50: 0xFFFD,
	0xFD51: 0xFFFD,
	0xFD52: 0xFFFD,
	0xFD53: 0xFFFD,
	0xFD54: 0xFFFD,
	0xFD55: 0xFFFD,
	0xFD56: 0xFFFD,
	0xFD57: 0xFFFD,
	0xFD58: 0xFFFD,
	0xFD59: 0xFFFD,
	0xFD5A: 0xFFFD,
	0xFD5B: 0xFFFD,
	0xFD5C: 0xFFFD,
	0xFD5D: 0xFFFD,
	0xFD5E: 0xFFFD,
	0xFD5F: 0xFFFD,
	0xFD60: 0xFFFD,
	0xFD61: 0xFFFD,
	0xFD62: 0xFFFD,
	0xFD63: 0xFFFD,
	0xFD64: 0xFFFD,
	0xFD65: 0xFFFD,
	0xFD66: 0xFFFD,
	0xFD67: 0xFFFD,
	0xFD68: 0xFFFD,
	0xFD69: 0xFFFD,
	0xFD6A: 0xFFFD,
	0xFD6B: 0xFFFD,
	0xFD6C: 0xFFFD,
	0xFD6D: 0xFFFD,
	0xFD6E: 0xFFFD,
	0xFD6F: 0xFFFD,
	0xFD70: 0xFFFD,
	0xFD71: 0xFFFD,
	0xFD72: 0xFFFD,
	0xFD73: 0xFFFD,
	0xFD74: 0xFFFD,
	0xFD75: 0xFFFD,
	0xFD76: 0xFFFD,
	0xFD77: 0xFFFD,
	0xFD78: 0xFFFD,
	0xFD79: 0xFFFD,
	0xFD7A: 0xFFFD,
	0xFD7B: 0xFFFD,
	0xFD7C: 0xFFFD,
	0xFD7D: 0xFFFD,
	0xFD7E: 0xFFFD,
	0xFD7F: 0xFFFD,
	0xFD80: 0xFFFD,
	0xFD81: 0xFFFD,
	0xFD82: 0xFFFD,
	0xFD83: 0xFFFD,
	0xFD84: 0xFFFD,
	0xFD85: 0xFFFD,
	0xFD86: 0xFFFD,
	0xFD87: 0xFFFD,
	0xFD88: 0xFFFD,
	0xFD89: 0xFFFD,
	0xFD8A: 0xFFFD,
	0xFD8B: 0xFFFD,
	0xFD8C: 0xFFFD,
	0xFD8D: 0xFFFD,
	0xFD8E: 0xFFFD,
	0xFD8F: 0xFFFD,
	0xFD90: 0xFFFD,
	0xFD91: 0xFFFD,
	0xFD92: 0xFFFD,
	0xFD93: 0xFFFD,
	0xFD94: 0xFFFD,
	0xFD95: 0xFFFD,
	0xFD96: 0xFFFD,
	0xFD97: 0xFFFD,
	0xFD98: 0xFFFD,
	0xFD99: 0xFFFD,
	0xFD9A: 0xFFFD,
	0xFD9B: 0xFFFD,
	0xFD9C: 0xFFFD,
	0xFD9D: 0xFFFD,
	0xFD9E: 0xFFFD,
	0xFD9F: 0xFFFD,
	0xFDA0: 0xFFFD,
	0xFDA1: 0xFFFD,
	0xFDA2: 0xFFFD,
	0xFDA3: 0xFFFD,
	0xFDA4: 0xFFFD,
	0xFDA5: 0xFFFD,
	0xFDA6: 0xFFFD,
	0xFDA7: 0xFFFD,
	0xFDA8: 0xFFFD,
	0xFDA9: 0xFFFD,
	0xFDAA: 0xFFFD,
	0xFDAB: 0xFFFD,
	0xFDAC: 0xFFFD,
	0xFDAD: 0xFFFD,
	0xFDAE: 0xFFFD,
	0xFDAF: 0xFFFD,
	0xFDB0: 0xFFFD,
	0xFDB1: 0xFFFD,
	0xFDB2: 0xFFFD,
	0xFDB3: 0xFFFD,
	0xFDB4: 0xFFFD,
	0xFDB5: 0xFFFD,
	0xFDB6: 0xFFFD,
	0xFDB7: 0xFFFD,
	0xFDB8: 0xFFFD,
	0xFDB9: 0xFFFD,
	0xFDBA: 0xFFFD,
	0xFDBB: 0xFFFD,
	0xFDBC: 0xFFFD,
	0xFDBD: 0xFFFD,
	0xFDBE: 0xFFFD,
	0xFDBF: 0xFFFD,
	0xFDC0: 0xFFFD,
	0xFDC1: 0xFFFD,
	0xFDC2: 0xFFFD,
	0xFDC3: 0xFFFD,
	0xFDC4: 0xFFFD,
	0xFDC5: 0xFFFD,
	0xFDC6: 0xFFFD,
	0xFDC7: 0xFFFD,
	0xFDC8: 0xFFFD,
	0xFDC9: 0xFFFD,
	0xFDCA: 0xFFFD,
	0xFDCB: 0xFFFD,
	0xFDCC: 0xFFFD,
	0xFDCD: 0xFFFD,
	0xFDCE: 0xFFFD,
	0xFDCF: 0xFFFD,
	0xFDD0: 0xFFFD,
	0xFDD1: 0xFFFD,
	0xFDD2: 0xFFFD,
	0xFDD3: 0xFFFD,
	0xFDD4: 0xFFFD,
	0xFDD5: 0xFFFD,
	0xFDD6: 0xFFFD,
	0xFDD7: 0xFFFD,
	0xFDD8: 0xFFFD,
	0xFDD9: 0xFFFD,
	0xFDDA: 0xFFFD,
	0xFDDB: 0xFFFD,
	0xFDDC: 0xFFFD,
	0xFDDD: 0xFFFD,
	0xFDDE: 0xFFFD,
	0xFDDF: 0xFFFD,
	0xFDE0: 0xFFFD,
	0xFDE1: 0xFFFD,
	0xFDE2: 0xFFFD,
	0xFDE3: 0xFFFD,
	0xFDE4: 0xFFFD,
	0xFDE5: 0xFFFD,
	0xFDE6: 0xFFFD,
	0xFDE7: 0xFFFD,
	0xFDE8: 0xFFFD,
	0xFDE9: 0xFFFD,
	0xFDEA: 0xFFFD,
	0xFDEB: 0xFFFD,
	0xFDEC: 0xFFFD,
	0xFDED: 0xFFFD,
	0xFDEE: 0xFFFD,
	0xFDEF: 0xFFFD,
	0xFDF0: 0xFFFD,
	0xFDF1: 0xFFFD,
	0xFDF2: 0xFFFD,
	0xFDF3: 0xFFFD,
	0xFDF4: 0xFFFD,
	0xFDF5: 0xFFFD,
	0xFDF6: 0xFFFD,
	0xFDF7: 0xFFFD,
	0xFDF8: 0xFFFD,
	0xFDF9: 0xFFFD,
	0xFDFA: 0xFFFD,
	0xFDFB: 0xFFFD,
	0xFDFC: 0xFFFD,
	0xFDFD: 0xFFFD,
	0xFDFE: 0xFFFD,
	0xFDFF: 0xFFFD,
	0xFE00: 0xFFFD,
	0xFE01: 0xFFFD,
	0xFE02: 0xFFFD,
	0xFE03: 0xFFFD,
	0xFE04: 0xFFFD,
	0xFE05: 0xFFFD,
	0xFE06: 0xFFFD,
	0xFE07: 0xFFFD,
	0xFE08: 0xFFFD,
	0xFE09: 0xFFFD,
	0xFE0A: 0xFFFD,
	0xFE0B: 0xFFFD,
	0xFE0C: 0xFFFD,
	0xFE0D: 0xFFFD,
	0xFE0E: 0xFFFD,
	0xFE0F: 0xFFFD,
	0xFE10: 0xFFFD,
	0xFE11: 0xFFFD,
	0xFE12: 0xFFFD,
	0xFE13: 0xFFFD,
	0xFE14: 0xFFFD,
	0xFE15: 0xFFFD,
	0xFE16: 0xFFFD,
	0xFE17: 0xFFFD,
	0xFE18: 0xFFFD,
	0xFE19: 0xFFFD,
	0xFE1A: 0xFFFD,
	0xFE1B: 0xFFFD,
	0xFE1C: 0xFFFD,
	0xFE1D: 0xFFFD,
	0xFE1E: 0xFFFD,
	0xFE1F: 0xFFFD,
	0xFE20: 0xFFFD,
	0xFE21: 0xFFFD,
	0xFE22: 0xFFFD,
	0xFE23: 0xFFFD,
	0xFE24: 0xFFFD,
	0xFE25: 0xFFFD,
	0xFE26: 0xFFFD,
	0xFE27: 0xFFFD,
	0xFE28: 0xFFFD,
	0xFE29: 0xFFFD,
	0xFE2A: 0xFFFD,
	0xFE2B: 0xFFFD,
	0xFE2C: 0xFFFD,
	0xFE2D: 0xFFFD,
	0xFE2E: 0xFFFD,
	0xFE2F: 0xFFFD,
	0xFE30: 0xA14A,
	0xFE31: 0xA157,
	0xFE32: 0xFFFD,
	0xFE33: 0xA159,
	0xFE34: 0xA15B,
	0xFE35: 0xA15F,
	0xFE36: 0xA160,
	0xFE37: 0xA163,
	0xFE38: 0xA164,
	0xFE39: 0xA167,
	0xFE3A: 0xA168,
	0xFE3B: 0xA16B,
	0xFE3C: 0xA16C,
	0xFE3D: 0xA16F,
	0xFE3E: 0xA170,
	0xFE3F: 0xA173,
	0xFE40: 0xA174,
	0xFE41: 0xA177,
	0xFE42: 0xA178,
	0xFE43: 0xA17B,
	0xFE44: 0xA17C,
	0xFE45: 0xFFFD,
	0xFE46: 0xFFFD,
	0xFE47: 0xFFFD,
	0xFE48: 0xFFFD,
	0xFE49: 0xA1C6,
	0xFE4A: 0xA1C7,
	0xFE4B: 0xA1CA,
	0xFE4C: 0xA1CB,
	0xFE4D: 0xA1C8,
	0xFE4E: 0xA1C9,
	0xFE4F: 0xA15C,
	0xFE50: 0xA14D,
	0xFE51: 0xA14E,
	0xFE52: 0xA14F,
	0xFE53: 0xFFFD,
	0xFE54: 0xA151,
	0xFE55: 0xA152,
	0xFE56: 0xA153,
	0xFE57: 0xA154,
	0xFE58: 0xFFFD,
	0xFE59: 0xA17D,
	0xFE5A: 0xA17E,
	0xFE5B: 0xA1A1,
	0xFE5C: 0xA1A2,
	0xFE5D: 0xA1A3,
	0xFE5E: 0xA1A4,
	0xFE5F: 0xA1CC,
	0xFE60: 0xA1CD,
	0xFE61: 0xA1CE,
	0xFE62: 0xA1DE,
	0xFE63: 0xA1DF,
	0xFE64: 0xA1E0,
	0xFE65: 0xA1E1,
	0xFE66: 0xA1E2,
	0xFE67: 0xFFFD,
	0xFE68: 0xA242,
	0xFE69: 0xA24C,
	0xFE6A: 0xA24D,
	0xFE6B: 0xA24E,
	0xFE6C: 0xFFFD,
	0xFE6D: 0xFFFD,
	0xFE6E: 0xFFFD,
	0xFE6F: 0xFFFD,
	0xFE70: 0xFFFD,
	0xFE71: 0xFFFD,
	0xFE72: 0xFFFD,
	0xFE73: 0xFFFD,
	0xFE74: 0xFFFD,
	0xFE75: 0xFFFD,
	0xFE76: 0xFFFD,
	0xFE77: 0xFFFD,
	0xFE78: 0xFFFD,
	0xFE79: 0xFFFD,
	0xFE7A: 0xFFFD,
	0xFE7B: 0xFFFD,
	0xFE7C: 0xFFFD,
	0xFE7D: 0xFFFD,
	0xFE7E: 0xFFFD,
	0xFE7F: 0xFFFD,
	0xFE80: 0xFFFD,
	0xFE81: 0xFFFD,
	0xFE82: 0xFFFD,
	0xFE83: 0xFFFD,
	0xFE84: 0xFFFD,
	0xFE85: 0xFFFD,
	0xFE86: 0xFFFD,
	0xFE87: 0xFFFD,
	0xFE88: 0xFFFD,
	0xFE89: 0xFFFD,
	0xFE8A: 0xFFFD,
	0xFE8B: 0xFFFD,
	0xFE8C: 0xFFFD,
	0xFE8D: 0xFFFD,
	0xFE8E: 0xFFFD,
	0xFE8F: 0xFFFD,
	0xFE90: 0xFFFD,
	0xFE91: 0xFFFD,
	0xFE92: 0xFFFD,
	0xFE93: 0xFFFD,
	0xFE94: 0xFFFD,
	0xFE95: 0xFFFD,
	0xFE96: 0xFFFD,
	0xFE97: 0xFFFD,
	0xFE98: 0xFFFD,
	0xFE99: 0xFFFD,
	0xFE9A: 0xFFFD,
	0xFE9B: 0xFFFD,
	0xFE9C: 0xFFFD,
	0xFE9D: 0xFFFD,
	0xFE9E: 0xFFFD,
	0xFE9F: 0xFFFD,
	0xFEA0: 0xFFFD,
	0xFEA1: 0xFFFD,
	0xFEA2: 0xFFFD,
	0xFEA3: 0xFFFD,
	0xFEA4: 0xFFFD,
	0xFEA5: 0xFFFD,
	0xFEA6: 0xFFFD,
	0xFEA7: 0xFFFD,
	0xFEA8: 0xFFFD,
	0xFEA9: 0xFFFD,
	0xFEAA: 0xFFFD,
	0xFEAB: 0xFFFD,
	0xFEAC: 0xFFFD,
	0xFEAD: 0xFFFD,
	0xFEAE: 0xFFFD,
	0xFEAF: 0xFFFD,
	0xFEB0: 0xFFFD,
	0xFEB1: 0xFFFD,
	0xFEB2: 0xFFFD,
	0xFEB3: 0xFFFD,
	0xFEB4: 0xFFFD,
	0xFEB5: 0xFFFD,
	0xFEB6: 0xFFFD,
	0xFEB7: 0xFFFD,
	0xFEB8: 0xFFFD,
	0xFEB9: 0xFFFD,
	0xFEBA: 0xFFFD,
	0xFEBB: 0xFFFD,
	0xFEBC: 0xFFFD,
	0xFEBD: 0xFFFD,
	0xFEBE: 0xFFFD,
	0xFEBF: 0xFFFD,
	0xFEC0: 0xFFFD,
	0xFEC1: 0xFFFD,
	0xFEC2: 0xFFFD,
	0xFEC3: 0xFFFD,
	0xFEC4: 0xFFFD,
	0xFEC5: 0xFFFD,
	0xFEC6: 0xFFFD,
	0xFEC7: 0xFFFD,
	0xFEC8: 0xFFFD,
	0xFEC9: 0xFFFD,
	0xFECA: 0xFFFD,
	0xFECB: 0xFFFD,
	0xFECC: 0xFFFD,
	0xFECD: 0xFFFD,
	0xFECE: 0xFFFD,
	0xFECF: 0xFFFD,
	0xFED0: 0xFFFD,
	0xFED1: 0xFFFD,
	0xFED2: 0xFFFD,
	0xFED3: 0xFFFD,
	0xFED4: 0xFFFD,
	0xFED5: 0xFFFD,
	0xFED6: 0xFFFD,
	0xFED7: 0xFFFD,
	0xFED8: 0xFFFD,
	0xFED9: 0xFFFD,
	0xFEDA: 0xFFFD,
	0xFEDB: 0xFFFD,
	0xFEDC: 0xFFFD,
	0xFEDD: 0xFFFD,
	0xFEDE: 0xFFFD,
	0xFEDF: 0xFFFD,
	0xFEE0: 0xFFFD,
	0xFEE1: 0xFFFD,
	0xFEE2: 0xFFFD,
	0xFEE3: 0xFFFD,
	0xFEE4: 0xFFFD,
	0xFEE5: 0xFFFD,
	0xFEE6: 0xFFFD,
	0xFEE7: 0xFFFD,
	0xFEE8: 0xFFFD,
	0xFEE9: 0xFFFD,
	0xFEEA: 0xFFFD,
	0xFEEB: 0xFFFD,
	0xFEEC: 0xFFFD,
	0xFEED: 0xFFFD,
	0xFEEE: 0xFFFD,
	0xFEEF: 0xFFFD,
	0xFEF0: 0xFFFD,
	0xFEF1: 0xFFFD,
	0xFEF2: 0xFFFD,
	0xFEF3: 0xFFFD,
	0xFEF4: 0xFFFD,
	0xFEF5: 0xFFFD,
	0xFEF6: 0xFFFD,
	0xFEF7: 0xFFFD,
	0xFEF8: 0xFFFD,
	0xFEF9: 0xFFFD,
	0xFEFA: 0xFFFD,
	0xFEFB: 0xFFFD,
	0xFEFC: 0xFFFD,
	0xFEFD: 0xFFFD,
	0xFEFE: 0xFFFD,
	0xFEFF: 0xFFFD,
	0xFF00: 0xFFFD,
	0xFF01: 0xA149,
	0xFF02: 0xC8D0,
	0xFF03: 0xA1AD,
	0xFF04: 0xA243,
	0xFF05: 0xA248,
	0xFF06: 0xA1AE,
	0xFF07: 0x91C2,
	0xFF08: 0xA15D,
	0xFF09: 0xA15E,
	0xFF0A: 0xA1AF,
	0xFF0B: 0xA1CF,
	0xFF0C: 0xA141,
	0xFF0D: 0xA1D0,
	0xFF0E: 0xA144,
	0xFF0F: 0xA1FE,
	0xFF10: 0xA2AF,
	0xFF11: 0xA2B0,
	0xFF12: 0xA2B1,
	0xFF13: 0xA2B2,
	0xFF14: 0xA2B3,
	0xFF15: 0xA2B4,
	0xFF16: 0xA2B5,
	0xFF17: 0xA2B6,
	0xFF18: 0xA2B7,
	0xFF19: 0xA2B8,
	0xFF1A: 0xA147,
	0xFF1B: 0xA146,
	0xFF1C: 0xA1D5,
	0xFF1D: 0xA1D7,
	0xFF1E: 0xA1D6,
	0xFF1F: 0xA148,
	0xFF20: 0xA249,
	0xFF21: 0xA2CF,
	0xFF22: 0xA2D0,
	0xFF23: 0xA2D1,
	0xFF24: 0xA2D2,
	0xFF25: 0xA2D3,
	0xFF26: 0xA2D4,
	0xFF27: 0xA2D5,
	0xFF28: 0xA2D6,
	0xFF29: 0xA2D7,
	0xFF2A: 0xA2D8,
	0xFF2B: 0xA2D9,
	0xFF2C: 0xA2DA,
	0xFF2D: 0xA2DB,
	0xFF2E: 0xA2DC,
	0xFF2F: 0xA2DD,
	0xFF30: 0xA2DE,
	0xFF31: 0xA2DF,
	0xFF32: 0xA2E0,
	0xFF33: 0xA2E1,
	0xFF34: 0xA2E2,
	0xFF35: 0xA2E3,
	0xFF36: 0xA2E4,
	0xFF37: 0xA2E5,
	0xFF38: 0xA2E6,
	0xFF39: 0xA2E7,
	0xFF3A: 0xA2E8,
	0xFF3B: 0xC6E4,
	0xFF3C: 0xA240,
	0xFF3D: 0xC6E5,
	0xFF3E: 0x5E20,
	0xFF3F: 0xA1C4,
	0xFF40: 0xA1AB,
	0xFF41: 0xA2E9,
	0xFF42: 0xA2EA,
	0xFF43: 0xA2EB,
	0xFF44: 0xA2EC,
	0xFF45: 0xA2ED,
	0xFF46: 0xA2EE,
	0xFF47: 0xA2EF,
	0xFF48: 0xA2F0,
	0xFF49: 0xA2F1,
	0xFF4A: 0xA2F2,
	0xFF4B: 0xA2F3,
	0xFF4C: 0xA2F4,
	0xFF4D: 0xA2F5,
	0xFF4E: 0xA2F6,
	0xFF4F: 0xA2F7,
	0xFF50: 0xA2F8,
	0xFF51: 0xA2F9,
	0xFF52: 0xA2FA,
	0xFF53: 0xA2FB,
	0xFF54: 0xA2FC,
	0xFF55: 0xA2FD,
	0xFF56: 0xA2FE,
	0xFF57: 0xA340,
	0xFF58: 0xA341,
	0xFF59: 0xA342,
	0xFF5A: 0xA343,
	0xFF5B: 0xA161,
	0xFF5C: 0xA155,
	0xFF5D: 0xA162,
	0xFF5E: 0xA1E3,
	0xFF5F: 0xFFFD,
	0xFF60: 0xFFFD,
	0xFF61: 0xC8B9,
	0xFF62: 0xC8BA,
	0xFF63: 0xC8BB,
	0xFF64: 0xC8BC,
	0xFF65: 0xC8BD,
	0xFF66: 0xC8BE,
	0xFF67: 0xC8BF,
	0xFF68: 0xC8C0,
	0xFF69: 0xC8C1,
	0xFF6A: 0xC8C2,
	0xFF6B: 0xC8C3,
	0xFF6C: 0xC8C4,
	0xFF6D: 0xC8C5,
	0xFF6E: 0xC8C6,
	0xFF6F: 0xC8C7,
	0xFF70: 0xC8C8,
	0xFF71: 0xC8C9,
	0xFF72: 0xC8CA,
	0xFF73: 0xC8CB,
	0xFF74: 0xC8CC,
	0xFF75: 0xC8D4,
	0xFF76: 0xC8D5,
	0xFF77: 0xC8D6,
	0xFF78: 0xC8D7,
	0xFF79: 0xC8D8,
	0xFF7A: 0xC8D9,
	0xFF7B: 0xC8DA,
	0xFF7C: 0xC8DB,
	0xFF7D: 0xC8DC,
	0xFF7E: 0xC8DD,
	0xFF7F: 0xC8DE,
	0xFF80: 0xC8DF,
	0xFF81: 0xC8E0,
	0xFF82: 0xC8E1,
	0xFF83: 0xC8E2,
	0xFF84: 0xC8E3,
	0xFF85: 0xC8E4,
	0xFF86: 0xC8E5,
	0xFF87: 0xC8E6,
	0xFF88: 0xC8E7,
	0xFF89: 0xC8E8,
	0xFF8A: 0xC8E9,
	0xFF8B: 0xC8EA,
	0xFF8C: 0xC8EB,
	0xFF8D: 0xC8EC,
	0xFF8E: 0xC8ED,
	0xFF8F: 0xC8EE,
	0xFF90: 0xC8EF,
	0xFF91: 0xC8F0,
	0xFF92: 0xC8F1,
	0xFF93: 0xC8F2,
	0xFF94: 0xC8F3,
	0xFF95: 0xC8F4,
	0xFF96: 0xC8F5,
	0xFF97: 0xC8F6,
	0xFF98: 0xC8F7,
	0xFF99: 0xC8F8,
	0xFF9A: 0xC8F9,
	0xFF9B: 0xC8FA,
	0xFF9C: 0xC8FB,
	0xFF9D: 0xC8FC,
	0xFF9E: 0xC8FD,
	0xFF9F: 0xC8FE,
	0xFFA0: 0xFFFD,
	0xFFA1: 0xFFFD,
	0xFFA2: 0xFFFD,
	0xFFA3: 0xFFFD,
	0xFFA4: 0xFFFD,
	0xFFA5: 0xFFFD,
	0xFFA6: 0xFFFD,
	0xFFA7: 0xFFFD,
	0xFFA8: 0xFFFD,
	0xFFA9: 0xFFFD,
	0xFFAA: 0xFFFD,
	0xFFAB: 0xFFFD,
	0xFFAC: 0xFFFD,
	0xFFAD: 0xFFFD,
	0xFFAE: 0xFFFD,
	0xFFAF: 0xFFFD,
	0xFFB0: 0xFFFD,
	0xFFB1: 0xFFFD,
	0xFFB2: 0xFFFD,
	0xFFB3: 0xFFFD,
	0xFFB4: 0xFFFD,
	0xFFB5: 0xFFFD,
	0xFFB6: 0xFFFD,
	0xFFB7: 0xFFFD,
	0xFFB8: 0xFFFD,
	0xFFB9: 0xFFFD,
	0xFFBA: 0xFFFD,
	0xFFBB: 0xFFFD,
	0xFFBC: 0xFFFD,
	0xFFBD: 0xFFFD,
	0xFFBE: 0xFFFD,
	0xFFBF: 0xFFFD,
	0xFFC0: 0xFFFD,
	0xFFC1: 0xFFFD,
	0xFFC2: 0xFFFD,
	0xFFC3: 0xFFFD,
	0xFFC4: 0xFFFD,
	0xFFC5: 0xFFFD,
	0xFFC6: 0xFFFD,
	0xFFC7: 0xFFFD,
	0xFFC8: 0xFFFD,
	0xFFC9: 0xFFFD,
	0xFFCA: 0xFFFD,
	0xFFCB: 0xFFFD,
	0xFFCC: 0xFFFD,
	0xFFCD: 0xFFFD,
	0xFFCE: 0xFFFD,
	0xFFCF: 0xFFFD,
	0xFFD0: 0xFFFD,
	0xFFD1: 0xFFFD,
	0xFFD2: 0xFFFD,
	0xFFD3: 0xFFFD,
	0xFFD4: 0xFFFD,
	0xFFD5: 0xFFFD,
	0xFFD6: 0xFFFD,
	0xFFD7: 0xFFFD,
	0xFFD8: 0xFFFD,
	0xFFD9: 0xFFFD,
	0xFFDA: 0xFFFD,
	0xFFDB: 0xFFFD,
	0xFFDC: 0xFFFD,
	0xFFDD: 0xFFFD,
	0xFFDE: 0xFFFD,
	0xFFDF: 0xFFFD,
	0xFFE0: 0xA246,
	0xFFE1: 0xA247,
	0xFFE2: 0xC8CD,
	0xFFE3: 0xA1C3,
	0xFFE4: 0xC8CE,
	0xFFE5: 0xA244,
	0xFFE6: 0xFFFD,
	0xFFE7: 0xFFFD,
	0xFFE8: 0xA278,
	0xFFE9: 0xA1F6,
	0xFFEA: 0xA1F4,
	0xFFEB: 0xA1F7,
	0xFFEC: 0xA1F5,
	0xFFED: 0xA1BD,
	0xFFEE: 0xA1B3,
	0xFFEF: 0xFFFD,
	0xFFF0: 0xFFFD,
	0xFFF1: 0xFFFD,
	0xFFF2: 0xFFFD,
	0xFFF3: 0xFFFD,
	0xFFF4: 0xFFFD,
	0xFFF5: 0xFFFD,
	0xFFF6: 0xFFFD,
	0xFFF7: 0xFFFD,
	0xFFF8: 0xFFFD,
	0xFFF9: 0xFFFD,
	0xFFFA: 0xFFFD,
	0xFFFB: 0xFFFD,
	0xFFFC: 0xFFFD,
	0xFFFD: 0xFFFD,
	0xFFFE: 0xFFFD,
	0xFFFF: 0xFFFD,
}